#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 20534
#define LARGE_STATE_COUNT 6920
#define SYMBOL_COUNT 1202
#define ALIAS_COUNT 21
#define TOKEN_COUNT 436
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 21
#define PRODUCTION_ID_COUNT 141

enum ts_symbol_identifiers {
  sym_simple_identifier = 1,
  anon_sym_DQUOTE = 2,
  aux_sym_double_quoted_string_token1 = 3,
  anon_sym_LT = 4,
  aux_sym_include_compiler_directive_standard_token1 = 5,
  anon_sym_GT = 6,
  aux_sym_include_compiler_directive_token1 = 7,
  sym_default_text = 8,
  sym_macro_text = 9,
  anon_sym_LPAREN = 10,
  anon_sym_RPAREN = 11,
  anon_sym_COMMA = 12,
  anon_sym_EQ = 13,
  aux_sym_text_macro_definition_token1 = 14,
  anon_sym_LF = 15,
  anon_sym_BQUOTE = 16,
  aux_sym_id_directive_token1 = 17,
  aux_sym_id_directive_token2 = 18,
  aux_sym_id_directive_token3 = 19,
  aux_sym_id_directive_token4 = 20,
  aux_sym_zero_directive_token1 = 21,
  aux_sym_zero_directive_token2 = 22,
  aux_sym_zero_directive_token3 = 23,
  aux_sym_zero_directive_token4 = 24,
  aux_sym_zero_directive_token5 = 25,
  aux_sym_zero_directive_token6 = 26,
  aux_sym_zero_directive_token7 = 27,
  aux_sym_zero_directive_token8 = 28,
  aux_sym_timescale_compiler_directive_token1 = 29,
  anon_sym_SLASH = 30,
  aux_sym_default_nettype_compiler_directive_token1 = 31,
  anon_sym_wire = 32,
  anon_sym_tri = 33,
  anon_sym_tri0 = 34,
  anon_sym_tri1 = 35,
  anon_sym_wand = 36,
  anon_sym_triand = 37,
  anon_sym_wor = 38,
  anon_sym_trior = 39,
  anon_sym_trireg = 40,
  anon_sym_uwire = 41,
  anon_sym_none = 42,
  aux_sym_unconnected_drive_token1 = 43,
  anon_sym_pull0 = 44,
  anon_sym_pull1 = 45,
  aux_sym_line_compiler_directive_token1 = 46,
  aux_sym_begin_keywords_token1 = 47,
  anon_sym_DOT_STAR = 48,
  anon_sym_SEMI = 49,
  anon_sym_endmodule = 50,
  anon_sym_COLON = 51,
  anon_sym_extern = 52,
  anon_sym_module = 53,
  anon_sym_macromodule = 54,
  anon_sym_endinterface = 55,
  anon_sym_interface = 56,
  anon_sym_endprogram = 57,
  anon_sym_program = 58,
  anon_sym_checker = 59,
  anon_sym_endchecker = 60,
  anon_sym_virtual = 61,
  anon_sym_class = 62,
  anon_sym_extends = 63,
  anon_sym_implements = 64,
  anon_sym_endclass = 65,
  anon_sym_pure = 66,
  anon_sym_package = 67,
  anon_sym_endpackage = 68,
  anon_sym_timeunit = 69,
  anon_sym_timeprecision = 70,
  anon_sym_POUND = 71,
  anon_sym_type = 72,
  anon_sym_DOT = 73,
  anon_sym_LBRACE = 74,
  anon_sym_RBRACE = 75,
  anon_sym_input = 76,
  anon_sym_output = 77,
  anon_sym_inout = 78,
  anon_sym_ref = 79,
  anon_sym_DOLLARfatal = 80,
  anon_sym_DOLLARerror = 81,
  anon_sym_DOLLARwarning = 82,
  anon_sym_DOLLARinfo = 83,
  anon_sym_0 = 84,
  anon_sym_1 = 85,
  anon_sym_2 = 86,
  anon_sym_default = 87,
  anon_sym_clocking = 88,
  anon_sym_disable = 89,
  anon_sym_iff = 90,
  anon_sym_defparam = 91,
  anon_sym_bind = 92,
  anon_sym_forkjoin = 93,
  anon_sym_rand = 94,
  anon_sym_const = 95,
  anon_sym_function = 96,
  anon_sym_new = 97,
  anon_sym_static = 98,
  anon_sym_protected = 99,
  anon_sym_local = 100,
  anon_sym_randc = 101,
  anon_sym_super = 102,
  anon_sym_endfunction = 103,
  anon_sym_constraint = 104,
  anon_sym_solve = 105,
  anon_sym_before = 106,
  anon_sym_soft = 107,
  anon_sym_u2013_GT = 108,
  anon_sym_if = 109,
  anon_sym_else = 110,
  anon_sym_foreach = 111,
  anon_sym_LBRACK = 112,
  anon_sym_RBRACK = 113,
  anon_sym_unique = 114,
  anon_sym_COLON_EQ = 115,
  anon_sym_COLON_SLASH = 116,
  anon_sym_localparam = 117,
  anon_sym_parameter = 118,
  anon_sym_specparam = 119,
  anon_sym_var = 120,
  anon_sym_import = 121,
  anon_sym_COLON_COLON = 122,
  anon_sym_STAR = 123,
  anon_sym_export = 124,
  anon_sym_STAR_COLON_COLON_STAR = 125,
  anon_sym_genvar = 126,
  anon_sym_vectored = 127,
  anon_sym_scalared = 128,
  anon_sym_interconnect = 129,
  anon_sym_typedef = 130,
  anon_sym_enum = 131,
  anon_sym_struct = 132,
  anon_sym_union = 133,
  anon_sym_nettype = 134,
  anon_sym_with = 135,
  anon_sym_automatic = 136,
  anon_sym_string = 137,
  anon_sym_packed = 138,
  anon_sym_chandle = 139,
  anon_sym_event = 140,
  anon_sym_byte = 141,
  anon_sym_shortint = 142,
  anon_sym_int = 143,
  anon_sym_longint = 144,
  anon_sym_integer = 145,
  anon_sym_time = 146,
  anon_sym_bit = 147,
  anon_sym_logic = 148,
  anon_sym_reg = 149,
  anon_sym_shortreal = 150,
  anon_sym_real = 151,
  anon_sym_realtime = 152,
  anon_sym_supply0 = 153,
  anon_sym_supply1 = 154,
  anon_sym_signed = 155,
  anon_sym_unsigned = 156,
  anon_sym_void = 157,
  anon_sym_tagged = 158,
  anon_sym_highz1 = 159,
  anon_sym_highz0 = 160,
  anon_sym_strong0 = 161,
  anon_sym_weak0 = 162,
  anon_sym_strong1 = 163,
  anon_sym_weak1 = 164,
  anon_sym_small = 165,
  anon_sym_medium = 166,
  anon_sym_large = 167,
  anon_sym_1step = 168,
  anon_sym_PATHPULSE_DOLLAR_EQ = 169,
  anon_sym_DOLLAR = 170,
  anon_sym_task = 171,
  anon_sym_DQUOTEDPI_DASHC_DQUOTE = 172,
  anon_sym_DQUOTEDPI_DQUOTE = 173,
  anon_sym_context = 174,
  anon_sym_endtask = 175,
  anon_sym_PLUS = 176,
  anon_sym_PLUS_PLUS = 177,
  anon_sym_u2013 = 178,
  anon_sym_u2013u2013 = 179,
  anon_sym_STAR_STAR = 180,
  anon_sym_PERCENT = 181,
  anon_sym_EQ_EQ = 182,
  anon_sym_BANG_EQ = 183,
  anon_sym_LT_EQ = 184,
  anon_sym_GT_EQ = 185,
  anon_sym_modport = 186,
  anon_sym_assert = 187,
  anon_sym_property = 188,
  anon_sym_assume = 189,
  anon_sym_cover = 190,
  anon_sym_expect = 191,
  anon_sym_sequence = 192,
  anon_sym_restrict = 193,
  anon_sym_endproperty = 194,
  anon_sym_strong = 195,
  anon_sym_weak = 196,
  anon_sym_not = 197,
  anon_sym_or = 198,
  anon_sym_and = 199,
  anon_sym_PIPE_DASH_GT = 200,
  anon_sym_PIPE_EQ_GT = 201,
  anon_sym_case = 202,
  anon_sym_endcase = 203,
  anon_sym_POUND_DASH_POUND = 204,
  anon_sym_POUND_EQ_POUND = 205,
  anon_sym_nexttime = 206,
  anon_sym_s_nexttime = 207,
  anon_sym_always = 208,
  anon_sym_s_always = 209,
  anon_sym_s_eventually = 210,
  anon_sym_eventually = 211,
  anon_sym_until = 212,
  anon_sym_s_until = 213,
  anon_sym_until_with = 214,
  anon_sym_s_until_with = 215,
  anon_sym_implies = 216,
  anon_sym_accept_on = 217,
  anon_sym_reject_on = 218,
  anon_sym_sync_accept_on = 219,
  anon_sym_sync_reject_on = 220,
  anon_sym_endsequence = 221,
  anon_sym_untyped = 222,
  anon_sym_intersect = 223,
  anon_sym_first_match = 224,
  anon_sym_throughout = 225,
  anon_sym_within = 226,
  anon_sym_POUND_POUND = 227,
  anon_sym_POUND_POUND_LBRACK_STAR_RBRACK = 228,
  anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK = 229,
  anon_sym_LBRACK_STAR = 230,
  anon_sym_LBRACK_STAR_RBRACK = 231,
  anon_sym_LBRACK_PLUS_RBRACK = 232,
  anon_sym_LBRACK_EQ = 233,
  anon_sym_LBRACK_DASH_GT = 234,
  anon_sym_dist = 235,
  anon_sym_covergroup = 236,
  anon_sym_endgroup = 237,
  anon_sym_option = 238,
  anon_sym_type_option = 239,
  anon_sym_sample = 240,
  anon_sym_AT_AT = 241,
  anon_sym_begin = 242,
  anon_sym_end = 243,
  anon_sym_coverpoint = 244,
  anon_sym_wildcard = 245,
  anon_sym_bins = 246,
  anon_sym_illegal_bins = 247,
  anon_sym_ignore_bins = 248,
  anon_sym_EQ_GT = 249,
  anon_sym_LBRACKu2013_GT = 250,
  anon_sym_cross = 251,
  anon_sym_BANG = 252,
  anon_sym_AMP_AMP = 253,
  anon_sym_PIPE_PIPE = 254,
  anon_sym_matches = 255,
  anon_sym_binsof = 256,
  anon_sym_let = 257,
  anon_sym_pulldown = 258,
  anon_sym_pullup = 259,
  anon_sym_cmos = 260,
  anon_sym_rcmos = 261,
  anon_sym_bufif0 = 262,
  anon_sym_bufif1 = 263,
  anon_sym_notif0 = 264,
  anon_sym_notif1 = 265,
  anon_sym_nmos = 266,
  anon_sym_pmos = 267,
  anon_sym_rnmos = 268,
  anon_sym_rpmos = 269,
  anon_sym_nand = 270,
  anon_sym_nor = 271,
  anon_sym_xor = 272,
  anon_sym_xnor = 273,
  anon_sym_buf = 274,
  anon_sym_tranif0 = 275,
  anon_sym_tranif1 = 276,
  anon_sym_rtranif1 = 277,
  anon_sym_rtranif0 = 278,
  anon_sym_tran = 279,
  anon_sym_rtran = 280,
  anon_sym_generate = 281,
  anon_sym_endgenerate = 282,
  anon_sym_for = 283,
  anon_sym_primitive = 284,
  anon_sym_endprimitive = 285,
  anon_sym_table = 286,
  anon_sym_endtable = 287,
  anon_sym_initial = 288,
  anon_sym_1_SQUOTEb0 = 289,
  anon_sym_1_SQUOTEb1 = 290,
  anon_sym_1_SQUOTEbx = 291,
  anon_sym_1_SQUOTEbX = 292,
  anon_sym_1_SQUOTEB0 = 293,
  anon_sym_1_SQUOTEB1 = 294,
  anon_sym_1_SQUOTEBx = 295,
  anon_sym_1_SQUOTEBX = 296,
  anon_sym_DASH = 297,
  sym_output_symbol = 298,
  sym_level_symbol = 299,
  sym_edge_symbol = 300,
  anon_sym_assign = 301,
  anon_sym_alias = 302,
  anon_sym_always_comb = 303,
  anon_sym_always_latch = 304,
  anon_sym_always_ff = 305,
  anon_sym_final = 306,
  anon_sym_PLUS_EQ = 307,
  anon_sym_DASH_EQ = 308,
  anon_sym_STAR_EQ = 309,
  anon_sym_SLASH_EQ = 310,
  anon_sym_PERCENT_EQ = 311,
  anon_sym_AMP_EQ = 312,
  anon_sym_PIPE_EQ = 313,
  anon_sym_CARET_EQ = 314,
  anon_sym_LT_LT_EQ = 315,
  anon_sym_GT_GT_EQ = 316,
  anon_sym_LT_LT_LT_EQ = 317,
  anon_sym_GT_GT_GT_EQ = 318,
  anon_sym_deassign = 319,
  anon_sym_force = 320,
  anon_sym_release = 321,
  anon_sym_fork = 322,
  anon_sym_join = 323,
  anon_sym_join_any = 324,
  anon_sym_join_none = 325,
  anon_sym_repeat = 326,
  anon_sym_AT = 327,
  anon_sym_AT_STAR = 328,
  anon_sym_return = 329,
  anon_sym_break = 330,
  anon_sym_continue = 331,
  anon_sym_wait = 332,
  anon_sym_wait_order = 333,
  anon_sym_DASH_GT = 334,
  anon_sym_DASH_GT_GT = 335,
  anon_sym_unique0 = 336,
  anon_sym_priority = 337,
  anon_sym_AMP_AMP_AMP = 338,
  anon_sym_inside = 339,
  anon_sym_casez = 340,
  anon_sym_casex = 341,
  anon_sym_randcase = 342,
  anon_sym_SQUOTE_LBRACE = 343,
  anon_sym_forever = 344,
  anon_sym_while = 345,
  anon_sym_do = 346,
  anon_sym_POUND0 = 347,
  anon_sym_endclocking = 348,
  anon_sym_global = 349,
  anon_sym_specify = 350,
  anon_sym_endspecify = 351,
  anon_sym_pulsestyle_onevent = 352,
  anon_sym_pulsestyle_ondetect = 353,
  anon_sym_showcancelled = 354,
  anon_sym_noshowcancelled = 355,
  anon_sym_STAR_GT = 356,
  anon_sym_posedge = 357,
  anon_sym_negedge = 358,
  anon_sym_edge = 359,
  anon_sym_ifnone = 360,
  anon_sym_DOLLARsetup = 361,
  anon_sym_DOLLARhold = 362,
  anon_sym_DOLLARsetuphold = 363,
  anon_sym_DOLLARrecovery = 364,
  anon_sym_DOLLARremoval = 365,
  anon_sym_DOLLARrecrem = 366,
  anon_sym_DOLLARskew = 367,
  anon_sym_DOLLARtimeskew = 368,
  anon_sym_DOLLARfullskew = 369,
  anon_sym_DOLLARperiod = 370,
  anon_sym_DOLLARwidth = 371,
  anon_sym_DOLLARnochange = 372,
  anon_sym_01 = 373,
  anon_sym_10 = 374,
  aux_sym_edge_descriptor_token1 = 375,
  aux_sym_edge_descriptor_token2 = 376,
  anon_sym_TILDE = 377,
  anon_sym_EQ_EQ_EQ = 378,
  anon_sym_BANG_EQ_EQ = 379,
  anon_sym_SQUOTEb0 = 380,
  anon_sym_SQUOTEb1 = 381,
  anon_sym_SQUOTEB0 = 382,
  anon_sym_SQUOTEB1 = 383,
  anon_sym_GT_GT = 384,
  anon_sym_LT_LT = 385,
  anon_sym_PLUS_COLON = 386,
  anon_sym_DASH_COLON = 387,
  anon_sym_std = 388,
  anon_sym_randomize = 389,
  anon_sym_null = 390,
  anon_sym_QMARK = 391,
  anon_sym_EQ_EQ_QMARK = 392,
  anon_sym_BANG_EQ_QMARK = 393,
  anon_sym_AMP = 394,
  anon_sym_PIPE = 395,
  anon_sym_CARET = 396,
  anon_sym_CARET_TILDE = 397,
  anon_sym_TILDE_CARET = 398,
  anon_sym_GT_GT_GT = 399,
  anon_sym_LT_LT_LT = 400,
  anon_sym_LT_DASH_GT = 401,
  anon_sym_this = 402,
  anon_sym_s = 403,
  anon_sym_ms = 404,
  anon_sym_us = 405,
  anon_sym_ns = 406,
  anon_sym_ps = 407,
  anon_sym_fs = 408,
  aux_sym_string_literal_token1 = 409,
  aux_sym_string_literal_token2 = 410,
  aux_sym_string_literal_token3 = 411,
  anon_sym_SQUOTE = 412,
  anon_sym_TILDE_AMP = 413,
  anon_sym_TILDE_PIPE = 414,
  anon_sym_DASH_DASH = 415,
  aux_sym_decimal_number_token1 = 416,
  aux_sym_decimal_number_token2 = 417,
  sym_binary_number = 418,
  sym_octal_number = 419,
  sym_hex_number = 420,
  aux_sym_real_number_token1 = 421,
  sym_fixed_point_number = 422,
  sym_unsigned_number = 423,
  anon_sym_SQUOTE0 = 424,
  anon_sym_SQUOTE1 = 425,
  aux_sym_unbased_unsized_literal_token1 = 426,
  anon_sym_LPAREN_STAR = 427,
  anon_sym_STAR_RPAREN = 428,
  sym_comment = 429,
  sym_c_identifier = 430,
  anon_sym_BSLASH = 431,
  aux_sym_escaped_identifier_token1 = 432,
  anon_sym_DOLLARroot = 433,
  anon_sym_DOLLARunit = 434,
  sym_system_tf_identifier = 435,
  sym_source_file = 436,
  sym_double_quoted_string = 437,
  sym_include_compiler_directive_standard = 438,
  sym_include_compiler_directive = 439,
  sym_text_macro_name = 440,
  sym_list_of_formal_arguments = 441,
  sym_formal_argument = 442,
  sym_text_macro_identifier = 443,
  sym_text_macro_definition = 444,
  sym_text_macro_usage = 445,
  sym_simple_text_macro_usage = 446,
  sym_id_directive = 447,
  sym_zero_directive = 448,
  sym_timescale_compiler_directive = 449,
  sym_default_nettype_compiler_directive = 450,
  sym_default_nettype_value = 451,
  sym_unconnected_drive = 452,
  sym_line_compiler_directive = 453,
  sym_begin_keywords = 454,
  sym__directives = 455,
  sym_list_of_actual_arguments = 456,
  sym__actual_argument = 457,
  sym__description = 458,
  sym_module_header = 459,
  sym_module_nonansi_header = 460,
  sym_module_ansi_header = 461,
  sym_module_declaration = 462,
  sym_module_keyword = 463,
  sym_interface_declaration = 464,
  sym_interface_nonansi_header = 465,
  sym_interface_ansi_header = 466,
  sym_program_declaration = 467,
  sym_program_nonansi_header = 468,
  sym_program_ansi_header = 469,
  sym_checker_declaration = 470,
  sym_class_declaration = 471,
  sym_interface_class_type = 472,
  sym_interface_class_declaration = 473,
  sym_interface_class_item = 474,
  sym_interface_class_method = 475,
  sym_package_declaration = 476,
  sym_timeunits_declaration = 477,
  sym_parameter_port_list = 478,
  sym_parameter_port_declaration = 479,
  sym_list_of_ports = 480,
  sym_list_of_port_declarations = 481,
  sym_port_declaration = 482,
  sym_port = 483,
  sym__port_expression = 484,
  sym_port_reference = 485,
  sym_port_direction = 486,
  sym_net_port_header1 = 487,
  sym_variable_port_header = 488,
  sym_interface_port_header = 489,
  sym_ansi_port_declaration = 490,
  sym_elaboration_system_task = 491,
  sym_finish_number = 492,
  sym__module_common_item = 493,
  sym__module_item = 494,
  sym_module_or_generate_item = 495,
  sym__module_or_generate_item_declaration = 496,
  sym__non_port_module_item = 497,
  sym_parameter_override = 498,
  sym_bind_directive = 499,
  sym_bind_target_scope = 500,
  sym_bind_target_instance = 501,
  sym_bind_target_instance_list = 502,
  sym__bind_instantiation = 503,
  sym_interface_or_generate_item = 504,
  sym_extern_tf_declaration = 505,
  sym_interface_item = 506,
  sym__non_port_interface_item = 507,
  sym_program_item = 508,
  sym_non_port_program_item = 509,
  sym__program_generate_item = 510,
  sym_checker_port_list = 511,
  sym_checker_port_item = 512,
  sym_checker_port_direction = 513,
  sym__checker_or_generate_item = 514,
  sym_checker_or_generate_item_declaration = 515,
  sym__checker_generate_item = 516,
  sym_class_item = 517,
  sym_class_property = 518,
  sym_class_method = 519,
  sym_class_constructor_prototype = 520,
  sym__class_constraint = 521,
  sym_class_item_qualifier = 522,
  sym__property_qualifier = 523,
  sym_random_qualifier = 524,
  sym_method_qualifier = 525,
  sym__method_prototype = 526,
  sym_class_constructor_declaration = 527,
  sym_constraint_declaration = 528,
  sym_constraint_block = 529,
  sym_constraint_block_item = 530,
  sym_solve_before_list = 531,
  sym_constraint_primary = 532,
  sym_constraint_expression = 533,
  sym_uniqueness_constraint = 534,
  sym_constraint_set = 535,
  sym_dist_list = 536,
  sym_dist_item = 537,
  sym_dist_weight = 538,
  sym_constraint_prototype = 539,
  sym_constraint_prototype_qualifier = 540,
  sym_extern_constraint_declaration = 541,
  sym_identifier_list = 542,
  sym__package_item = 543,
  sym_package_or_generate_item_declaration = 544,
  sym_anonymous_program = 545,
  sym_anonymous_program_item = 546,
  sym_local_parameter_declaration = 547,
  sym_parameter_declaration = 548,
  sym__any_parameter_declaration = 549,
  sym_specparam_declaration = 550,
  sym_inout_declaration = 551,
  sym_input_declaration = 552,
  sym_output_declaration = 553,
  sym_interface_port_declaration = 554,
  sym_ref_declaration = 555,
  sym_data_declaration = 556,
  sym_package_import_declaration = 557,
  sym_package_import_item = 558,
  sym_package_export_declaration = 559,
  sym_genvar_declaration = 560,
  sym_net_declaration = 561,
  sym_type_declaration = 562,
  sym_net_type_declaration = 563,
  sym_lifetime = 564,
  sym_casting_type = 565,
  sym_data_type = 566,
  sym_data_type_or_implicit1 = 567,
  sym_implicit_data_type1 = 568,
  sym_enum_base_type = 569,
  sym_enum_name_declaration = 570,
  sym_class_scope = 571,
  sym_class_type = 572,
  sym__integer_type = 573,
  sym_integer_atom_type = 574,
  sym_integer_vector_type = 575,
  sym_non_integer_type = 576,
  sym_net_type = 577,
  sym_net_port_type1 = 578,
  sym__variable_port_type = 579,
  sym__var_data_type = 580,
  sym__signing = 581,
  sym__simple_type = 582,
  sym_struct_union_member = 583,
  sym_data_type_or_void = 584,
  sym_struct_union = 585,
  sym_type_reference = 586,
  sym_drive_strength = 587,
  sym_strength0 = 588,
  sym_strength1 = 589,
  sym_charge_strength = 590,
  sym_delay3 = 591,
  sym_delay2 = 592,
  sym_delay_value = 593,
  sym_list_of_defparam_assignments = 594,
  sym_list_of_genvar_identifiers = 595,
  sym_list_of_interface_identifiers = 596,
  sym_list_of_net_decl_assignments = 597,
  sym_list_of_param_assignments = 598,
  sym_list_of_port_identifiers = 599,
  sym_list_of_udp_port_identifiers = 600,
  sym_list_of_specparam_assignments = 601,
  sym_list_of_tf_variable_identifiers = 602,
  sym_list_of_type_assignments = 603,
  sym_list_of_variable_decl_assignments = 604,
  sym_list_of_variable_identifiers = 605,
  sym_list_of_variable_port_identifiers = 606,
  sym_defparam_assignment = 607,
  sym_net_decl_assignment = 608,
  sym_param_assignment = 609,
  sym_specparam_assignment = 610,
  sym_type_assignment = 611,
  sym_pulse_control_specparam = 612,
  sym_error_limit_value = 613,
  sym_reject_limit_value = 614,
  sym_limit_value = 615,
  sym_variable_decl_assignment = 616,
  sym_class_new = 617,
  sym_dynamic_array_new = 618,
  sym_unpacked_dimension = 619,
  sym_packed_dimension = 620,
  sym_associative_dimension = 621,
  sym__variable_dimension = 622,
  sym_queue_dimension = 623,
  sym_unsized_dimension = 624,
  sym_function_data_type_or_implicit1 = 625,
  sym_function_declaration = 626,
  sym_function_body_declaration = 627,
  sym_function_prototype = 628,
  sym_dpi_import_export = 629,
  sym_dpi_spec_string = 630,
  sym_dpi_function_import_property = 631,
  sym_dpi_task_import_property = 632,
  sym_dpi_function_proto = 633,
  sym_dpi_task_proto = 634,
  sym_task_declaration = 635,
  sym_task_body_declaration = 636,
  sym_tf_item_declaration = 637,
  sym_tf_port_list = 638,
  sym_tf_port_item1 = 639,
  sym_tf_port_direction = 640,
  sym_tf_port_declaration = 641,
  sym_task_prototype = 642,
  sym_block_item_declaration = 643,
  sym_overload_declaration = 644,
  sym_overload_operator = 645,
  sym_overload_proto_formals = 646,
  sym_modport_declaration = 647,
  sym_modport_item = 648,
  sym_modport_ports_declaration = 649,
  sym_modport_clocking_declaration = 650,
  sym_modport_simple_ports_declaration = 651,
  sym_modport_simple_port = 652,
  sym_modport_tf_ports_declaration = 653,
  sym__modport_tf_port = 654,
  sym_import_export = 655,
  sym_concurrent_assertion_item = 656,
  sym__concurrent_assertion_statement = 657,
  sym_assert_property_statement = 658,
  sym_assume_property_statement = 659,
  sym_cover_property_statement = 660,
  sym_expect_property_statement = 661,
  sym_cover_sequence_statement = 662,
  sym_restrict_property_statement = 663,
  sym__property_actual_arg = 664,
  sym__assertion_item_declaration = 665,
  sym_property_declaration = 666,
  sym_property_port_list = 667,
  sym_property_port_item = 668,
  sym_property_lvar_port_direction = 669,
  sym_property_formal_type1 = 670,
  sym_property_spec = 671,
  sym_property_expr = 672,
  sym_property_case_item = 673,
  sym_sequence_declaration = 674,
  sym_sequence_port_list = 675,
  sym_sequence_port_item = 676,
  sym_sequence_lvar_port_direction = 677,
  sym_sequence_formal_type1 = 678,
  sym_sequence_expr = 679,
  sym_cycle_delay_range = 680,
  sym_sequence_method_call = 681,
  sym__sequence_match_item = 682,
  sym_sequence_instance = 683,
  sym_sequence_list_of_arguments = 684,
  sym__sequence_actual_arg = 685,
  sym__boolean_abbrev = 686,
  sym_sequence_abbrev = 687,
  sym_consecutive_repetition = 688,
  sym_non_consecutive_repetition = 689,
  sym_goto_repetition = 690,
  sym__const_or_range_expression = 691,
  sym_cycle_delay_const_range_expression = 692,
  sym_expression_or_dist = 693,
  sym_assertion_variable_declaration = 694,
  sym_covergroup_declaration = 695,
  sym_coverage_spec_or_option = 696,
  sym_coverage_option = 697,
  sym__coverage_spec = 698,
  sym_coverage_event = 699,
  sym_block_event_expression = 700,
  sym_hierarchical_btf_identifier = 701,
  sym_cover_point = 702,
  sym_bins_or_empty = 703,
  sym_bins_or_options = 704,
  sym_bins_keyword = 705,
  sym_trans_list = 706,
  sym_trans_set = 707,
  sym_trans_range_list = 708,
  sym_trans_item = 709,
  sym_repeat_range = 710,
  sym_cover_cross = 711,
  sym_list_of_cross_items = 712,
  sym__cross_item = 713,
  sym_cross_body = 714,
  sym_cross_body_item = 715,
  sym_bins_selection_or_option = 716,
  sym_bins_selection = 717,
  sym_select_expression = 718,
  sym_select_condition = 719,
  sym_bins_expression = 720,
  sym_covergroup_range_list = 721,
  sym_covergroup_value_range = 722,
  sym__with_covergroup_expression = 723,
  sym__set_covergroup_expression = 724,
  sym__integer_covergroup_expression = 725,
  sym__cross_set_expression = 726,
  sym__covergroup_expression = 727,
  sym_let_declaration = 728,
  sym_let_port_list = 729,
  sym_let_port_item = 730,
  sym_let_formal_type1 = 731,
  sym_let_expression = 732,
  sym_let_list_of_arguments = 733,
  sym_let_actual_arg = 734,
  sym_gate_instantiation = 735,
  sym_cmos_switch_instance = 736,
  sym_enable_gate_instance = 737,
  sym_mos_switch_instance = 738,
  sym_n_input_gate_instance = 739,
  sym_n_output_gate_instance = 740,
  sym_pass_switch_instance = 741,
  sym_pass_enable_switch_instance = 742,
  sym_pull_gate_instance = 743,
  sym_pulldown_strength = 744,
  sym_pullup_strength = 745,
  sym_enable_terminal = 746,
  sym_inout_terminal = 747,
  sym_input_terminal = 748,
  sym_ncontrol_terminal = 749,
  sym_output_terminal = 750,
  sym_pcontrol_terminal = 751,
  sym_cmos_switchtype = 752,
  sym_enable_gatetype = 753,
  sym_mos_switchtype = 754,
  sym_n_input_gatetype = 755,
  sym_n_output_gatetype = 756,
  sym_pass_en_switchtype = 757,
  sym_pass_switchtype = 758,
  sym_module_instantiation = 759,
  sym_parameter_value_assignment = 760,
  sym_list_of_parameter_assignments = 761,
  sym_ordered_parameter_assignment = 762,
  sym_named_parameter_assignment = 763,
  sym_hierarchical_instance = 764,
  sym_name_of_instance = 765,
  sym_list_of_port_connections = 766,
  sym_ordered_port_connection = 767,
  sym_named_port_connection = 768,
  sym_interface_instantiation = 769,
  sym_program_instantiation = 770,
  sym_checker_instantiation = 771,
  sym_generate_region = 772,
  sym_loop_generate_construct = 773,
  sym_genvar_initialization = 774,
  sym_genvar_iteration = 775,
  sym__conditional_generate_construct = 776,
  sym_if_generate_construct = 777,
  sym_case_generate_construct = 778,
  sym_case_generate_item = 779,
  sym_generate_block = 780,
  sym__generate_item = 781,
  sym_udp_nonansi_declaration = 782,
  sym_udp_ansi_declaration = 783,
  sym_udp_declaration = 784,
  sym_udp_port_list = 785,
  sym_udp_declaration_port_list = 786,
  sym_udp_port_declaration = 787,
  sym_udp_output_declaration = 788,
  sym_udp_input_declaration = 789,
  sym_udp_reg_declaration = 790,
  sym__udp_body = 791,
  sym_combinational_body = 792,
  sym_combinational_entry = 793,
  sym_sequential_body = 794,
  sym_udp_initial_statement = 795,
  sym_init_val = 796,
  sym_sequential_entry = 797,
  sym__seq_input_list = 798,
  sym_level_input_list = 799,
  sym_edge_input_list = 800,
  sym_edge_indicator = 801,
  sym__current_state = 802,
  sym_next_state = 803,
  sym_udp_instantiation = 804,
  sym_udp_instance = 805,
  sym_continuous_assign = 806,
  sym_list_of_net_assignments = 807,
  sym_list_of_variable_assignments = 808,
  sym_net_alias = 809,
  sym_net_assignment = 810,
  sym_initial_construct = 811,
  sym_always_construct = 812,
  sym_always_keyword = 813,
  sym_final_construct = 814,
  sym_blocking_assignment = 815,
  sym_operator_assignment = 816,
  sym_assignment_operator = 817,
  sym_nonblocking_assignment = 818,
  sym_procedural_continuous_assignment = 819,
  sym_variable_assignment = 820,
  sym_action_block = 821,
  sym_seq_block = 822,
  sym_par_block = 823,
  sym_join_keyword = 824,
  sym_statement_or_null = 825,
  sym_statement = 826,
  sym_statement_item = 827,
  sym_function_statement = 828,
  sym_function_statement_or_null = 829,
  sym_variable_identifier_list = 830,
  sym_procedural_timing_control_statement = 831,
  sym_delay_or_event_control = 832,
  sym_delay_control = 833,
  sym_event_control = 834,
  sym_event_expression = 835,
  sym__procedural_timing_control = 836,
  sym_jump_statement = 837,
  sym_wait_statement = 838,
  sym_event_trigger = 839,
  sym_disable_statement = 840,
  sym_conditional_statement = 841,
  sym_unique_priority = 842,
  sym_cond_predicate = 843,
  sym__expression_or_cond_pattern = 844,
  sym_cond_pattern = 845,
  sym_case_statement = 846,
  sym_case_keyword = 847,
  sym_case_expression = 848,
  sym_case_item = 849,
  sym_case_pattern_item = 850,
  sym_case_inside_item = 851,
  sym_case_item_expression = 852,
  sym_randcase_statement = 853,
  sym_randcase_item = 854,
  sym_open_range_list = 855,
  sym_open_value_range = 856,
  sym_pattern = 857,
  sym_assignment_pattern = 858,
  sym__array_pattern_key = 859,
  sym_assignment_pattern_key = 860,
  sym_assignment_pattern_expression = 861,
  sym__assignment_pattern_expression_type = 862,
  sym_assignment_pattern_net_lvalue = 863,
  sym_assignment_pattern_variable_lvalue = 864,
  sym_loop_statement = 865,
  sym_for_initialization = 866,
  sym_for_variable_declaration = 867,
  sym_for_step = 868,
  sym__for_step_assignment = 869,
  sym_loop_variables1 = 870,
  sym__assertion_item = 871,
  sym_deferred_immediate_assertion_item = 872,
  sym__procedural_assertion_statement = 873,
  sym__immediate_assertion_statement = 874,
  sym__simple_immediate_assertion_statement = 875,
  sym_simple_immediate_assert_statement = 876,
  sym_simple_immediate_assume_statement = 877,
  sym_simple_immediate_cover_statement = 878,
  sym__deferred_immediate_assertion_statement = 879,
  sym_deferred_immediate_assert_statement = 880,
  sym_deferred_immediate_assume_statement = 881,
  sym_deferred_immediate_cover_statement = 882,
  sym_clocking_declaration = 883,
  sym_clocking_event = 884,
  sym_clocking_item = 885,
  sym_default_skew = 886,
  sym_clocking_direction = 887,
  sym_list_of_clocking_decl_assign = 888,
  sym_clocking_decl_assign = 889,
  sym_clocking_skew = 890,
  sym_clocking_drive = 891,
  sym_cycle_delay = 892,
  sym_clockvar = 893,
  sym_clockvar_expression = 894,
  sym_specify_block = 895,
  sym__specify_item = 896,
  sym_pulsestyle_declaration = 897,
  sym_showcancelled_declaration = 898,
  sym_path_declaration = 899,
  sym_simple_path_declaration = 900,
  sym_parallel_path_description = 901,
  sym_full_path_description = 902,
  sym_list_of_path_inputs = 903,
  sym_list_of_path_outputs = 904,
  sym_specify_input_terminal_descriptor = 905,
  sym_specify_output_terminal_descriptor = 906,
  sym_input_identifier = 907,
  sym_output_identifier = 908,
  sym_path_delay_value = 909,
  sym_list_of_path_delay_expressions = 910,
  sym_path_delay_expression = 911,
  sym_edge_sensitive_path_declaration = 912,
  sym_parallel_edge_sensitive_path_description = 913,
  sym_full_edge_sensitive_path_description = 914,
  sym_data_source_expression = 915,
  sym_edge_identifier = 916,
  sym_state_dependent_path_declaration = 917,
  sym_polarity_operator = 918,
  sym__system_timing_check = 919,
  sym_DOLLARsetup_timing_check = 920,
  sym_DOLLARhold_timing_check = 921,
  sym_DOLLARsetuphold_timing_check = 922,
  sym_DOLLARrecovery_timing_check = 923,
  sym_DOLLARremoval_timing_check = 924,
  sym_DOLLARrecrem_timing_check = 925,
  sym_DOLLARskew_timing_check = 926,
  sym_DOLLARtimeskew_timing_check = 927,
  sym_DOLLARfullskew_timing_check = 928,
  sym_DOLLARperiod_timing_check = 929,
  sym_DOLLARwidth_timing_check = 930,
  sym_DOLLARnochange_timing_check = 931,
  sym_timecheck_condition = 932,
  sym_controlled_reference_event = 933,
  sym_data_event = 934,
  sym_delayed_data = 935,
  sym_delayed_reference = 936,
  sym_end_edge_offset = 937,
  sym_event_based_flag = 938,
  sym_notifier = 939,
  sym_reference_event = 940,
  sym_remain_active_flag = 941,
  sym_timestamp_condition = 942,
  sym_start_edge_offset = 943,
  sym_threshold = 944,
  sym_timing_check_limit = 945,
  sym_timing_check_event = 946,
  sym_controlled_timing_check_event = 947,
  sym_timing_check_event_control = 948,
  sym__specify_terminal_descriptor = 949,
  sym_edge_control_specifier = 950,
  sym_edge_descriptor = 951,
  sym_timing_check_condition = 952,
  sym_scalar_timing_check_condition = 953,
  sym_scalar_constant = 954,
  sym_concatenation = 955,
  sym_constant_concatenation = 956,
  sym_constant_multiple_concatenation = 957,
  sym_module_path_concatenation = 958,
  sym_module_path_multiple_concatenation = 959,
  sym_multiple_concatenation = 960,
  sym_streaming_concatenation = 961,
  sym_stream_operator = 962,
  sym_slice_size = 963,
  sym_stream_concatenation = 964,
  sym_stream_expression = 965,
  sym_array_range_expression = 966,
  sym_empty_unpacked_array_concatenation = 967,
  sym_tf_call = 968,
  sym_system_tf_call = 969,
  sym_subroutine_call = 970,
  sym_function_subroutine_call = 971,
  sym_list_of_arguments = 972,
  sym_list_of_arguments_parent = 973,
  sym_method_call = 974,
  sym_method_call_body = 975,
  sym__built_in_method_call = 976,
  sym_array_manipulation_call = 977,
  sym_randomize_call = 978,
  sym__method_call_root = 979,
  sym_array_method_name = 980,
  sym_inc_or_dec_expression = 981,
  sym_conditional_expression = 982,
  sym_constant_expression = 983,
  sym_constant_mintypmax_expression = 984,
  sym_constant_param_expression = 985,
  sym_param_expression = 986,
  sym__constant_range_expression = 987,
  sym__constant_part_select_range = 988,
  sym_constant_range = 989,
  sym_constant_indexed_range = 990,
  sym_expression = 991,
  sym_tagged_union_expression = 992,
  sym_inside_expression = 993,
  sym_value_range = 994,
  sym_mintypmax_expression = 995,
  sym_module_path_expression = 996,
  sym_module_path_mintypmax_expression = 997,
  sym__part_select_range = 998,
  sym_indexed_range = 999,
  sym__genvar_expression = 1000,
  sym_constant_primary = 1001,
  sym_module_path_primary = 1002,
  sym_primary = 1003,
  sym_class_qualifier = 1004,
  sym_range_expression = 1005,
  sym_primary_literal = 1006,
  sym_time_literal = 1007,
  sym_time_unit = 1008,
  sym_string_literal = 1009,
  sym_implicit_class_handle = 1010,
  sym_bit_select1 = 1011,
  sym_select1 = 1012,
  sym_nonrange_select1 = 1013,
  sym_constant_bit_select1 = 1014,
  sym_constant_select1 = 1015,
  sym_cast = 1016,
  sym_net_lvalue = 1017,
  sym_variable_lvalue = 1018,
  sym_nonrange_variable_lvalue = 1019,
  sym_unary_operator = 1020,
  sym_inc_or_dec_operator = 1021,
  sym__number = 1022,
  sym_integral_number = 1023,
  sym_decimal_number = 1024,
  sym_real_number = 1025,
  sym_unbased_unsized_literal = 1026,
  sym_attribute_instance = 1027,
  sym_attr_spec = 1028,
  sym__attr_name = 1029,
  sym__bin_identifier = 1030,
  sym_clocking_identifier = 1031,
  sym_const_identifier = 1032,
  sym_constraint_identifier = 1033,
  sym_escaped_identifier = 1034,
  sym_function_identifier = 1035,
  sym_generate_block_identifier = 1036,
  sym__hierarchical_array_identifier = 1037,
  sym__hierarchical_event_identifier = 1038,
  sym__hierarchical_parameter_identifier = 1039,
  sym__identifier = 1040,
  sym_index_variable_identifier = 1041,
  sym_inout_port_identifier = 1042,
  sym_input_port_identifier = 1043,
  sym_method_identifier = 1044,
  sym_modport_identifier = 1045,
  sym_output_port_identifier = 1046,
  sym_package_scope = 1047,
  sym_ps_identifier = 1048,
  sym_ps_or_hierarchical_array_identifier = 1049,
  sym__sequence_identifier = 1050,
  sym__signal_identifier = 1051,
  sym_task_identifier = 1052,
  sym_terminal_identifier = 1053,
  aux_sym_source_file_repeat1 = 1054,
  aux_sym_list_of_formal_arguments_repeat1 = 1055,
  aux_sym_list_of_actual_arguments_repeat1 = 1056,
  aux_sym__description_repeat1 = 1057,
  aux_sym_module_nonansi_header_repeat1 = 1058,
  aux_sym_module_declaration_repeat1 = 1059,
  aux_sym_interface_declaration_repeat1 = 1060,
  aux_sym_interface_declaration_repeat2 = 1061,
  aux_sym_program_declaration_repeat1 = 1062,
  aux_sym_program_declaration_repeat2 = 1063,
  aux_sym_checker_declaration_repeat1 = 1064,
  aux_sym_class_declaration_repeat1 = 1065,
  aux_sym_class_declaration_repeat2 = 1066,
  aux_sym_interface_class_declaration_repeat1 = 1067,
  aux_sym_package_declaration_repeat1 = 1068,
  aux_sym_parameter_port_list_repeat1 = 1069,
  aux_sym_list_of_ports_repeat1 = 1070,
  aux_sym_list_of_port_declarations_repeat1 = 1071,
  aux_sym__port_expression_repeat1 = 1072,
  aux_sym_ansi_port_declaration_repeat1 = 1073,
  aux_sym_ansi_port_declaration_repeat2 = 1074,
  aux_sym_bind_target_instance_list_repeat1 = 1075,
  aux_sym_checker_port_list_repeat1 = 1076,
  aux_sym_class_property_repeat1 = 1077,
  aux_sym_class_property_repeat2 = 1078,
  aux_sym_class_method_repeat1 = 1079,
  aux_sym_class_constructor_declaration_repeat1 = 1080,
  aux_sym_class_constructor_declaration_repeat2 = 1081,
  aux_sym_constraint_block_repeat1 = 1082,
  aux_sym_solve_before_list_repeat1 = 1083,
  aux_sym_constraint_set_repeat1 = 1084,
  aux_sym_dist_list_repeat1 = 1085,
  aux_sym_identifier_list_repeat1 = 1086,
  aux_sym_anonymous_program_repeat1 = 1087,
  aux_sym_package_import_declaration_repeat1 = 1088,
  aux_sym_net_declaration_repeat1 = 1089,
  aux_sym_data_type_repeat1 = 1090,
  aux_sym_data_type_repeat2 = 1091,
  aux_sym_data_type_repeat3 = 1092,
  aux_sym_class_type_repeat1 = 1093,
  aux_sym_list_of_defparam_assignments_repeat1 = 1094,
  aux_sym_list_of_genvar_identifiers_repeat1 = 1095,
  aux_sym_list_of_interface_identifiers_repeat1 = 1096,
  aux_sym_list_of_net_decl_assignments_repeat1 = 1097,
  aux_sym_list_of_param_assignments_repeat1 = 1098,
  aux_sym_list_of_port_identifiers_repeat1 = 1099,
  aux_sym_list_of_udp_port_identifiers_repeat1 = 1100,
  aux_sym_list_of_specparam_assignments_repeat1 = 1101,
  aux_sym_list_of_tf_variable_identifiers_repeat1 = 1102,
  aux_sym_list_of_type_assignments_repeat1 = 1103,
  aux_sym_list_of_variable_decl_assignments_repeat1 = 1104,
  aux_sym_list_of_variable_identifiers_repeat1 = 1105,
  aux_sym_list_of_variable_port_identifiers_repeat1 = 1106,
  aux_sym_function_body_declaration_repeat1 = 1107,
  aux_sym_task_body_declaration_repeat1 = 1108,
  aux_sym_tf_port_list_repeat1 = 1109,
  aux_sym_overload_proto_formals_repeat1 = 1110,
  aux_sym_modport_declaration_repeat1 = 1111,
  aux_sym_modport_item_repeat1 = 1112,
  aux_sym_modport_simple_ports_declaration_repeat1 = 1113,
  aux_sym_modport_tf_ports_declaration_repeat1 = 1114,
  aux_sym_property_declaration_repeat1 = 1115,
  aux_sym_property_port_list_repeat1 = 1116,
  aux_sym_property_expr_repeat1 = 1117,
  aux_sym_property_case_item_repeat1 = 1118,
  aux_sym_sequence_port_list_repeat1 = 1119,
  aux_sym_sequence_expr_repeat1 = 1120,
  aux_sym_sequence_expr_repeat2 = 1121,
  aux_sym_sequence_expr_repeat3 = 1122,
  aux_sym_sequence_list_of_arguments_repeat1 = 1123,
  aux_sym_covergroup_declaration_repeat1 = 1124,
  aux_sym_bins_or_empty_repeat1 = 1125,
  aux_sym_trans_list_repeat1 = 1126,
  aux_sym_trans_set_repeat1 = 1127,
  aux_sym_list_of_cross_items_repeat1 = 1128,
  aux_sym_cross_body_repeat1 = 1129,
  aux_sym_covergroup_range_list_repeat1 = 1130,
  aux_sym_let_port_list_repeat1 = 1131,
  aux_sym_let_list_of_arguments_repeat1 = 1132,
  aux_sym_gate_instantiation_repeat1 = 1133,
  aux_sym_gate_instantiation_repeat2 = 1134,
  aux_sym_gate_instantiation_repeat3 = 1135,
  aux_sym_gate_instantiation_repeat4 = 1136,
  aux_sym_gate_instantiation_repeat5 = 1137,
  aux_sym_gate_instantiation_repeat6 = 1138,
  aux_sym_gate_instantiation_repeat7 = 1139,
  aux_sym_gate_instantiation_repeat8 = 1140,
  aux_sym_n_input_gate_instance_repeat1 = 1141,
  aux_sym_n_output_gate_instance_repeat1 = 1142,
  aux_sym_module_instantiation_repeat1 = 1143,
  aux_sym_list_of_parameter_assignments_repeat1 = 1144,
  aux_sym_list_of_parameter_assignments_repeat2 = 1145,
  aux_sym_list_of_port_connections_repeat1 = 1146,
  aux_sym_list_of_port_connections_repeat2 = 1147,
  aux_sym_checker_instantiation_repeat1 = 1148,
  aux_sym_checker_instantiation_repeat2 = 1149,
  aux_sym_generate_region_repeat1 = 1150,
  aux_sym_case_generate_construct_repeat1 = 1151,
  aux_sym_case_generate_item_repeat1 = 1152,
  aux_sym_udp_declaration_repeat1 = 1153,
  aux_sym_udp_port_list_repeat1 = 1154,
  aux_sym_udp_declaration_port_list_repeat1 = 1155,
  aux_sym_combinational_body_repeat1 = 1156,
  aux_sym_sequential_body_repeat1 = 1157,
  aux_sym_level_input_list_repeat1 = 1158,
  aux_sym_udp_instantiation_repeat1 = 1159,
  aux_sym_list_of_net_assignments_repeat1 = 1160,
  aux_sym_list_of_variable_assignments_repeat1 = 1161,
  aux_sym_net_alias_repeat1 = 1162,
  aux_sym_variable_identifier_list_repeat1 = 1163,
  aux_sym_wait_statement_repeat1 = 1164,
  aux_sym_cond_predicate_repeat1 = 1165,
  aux_sym_case_statement_repeat1 = 1166,
  aux_sym_case_statement_repeat2 = 1167,
  aux_sym_case_statement_repeat3 = 1168,
  aux_sym_case_item_repeat1 = 1169,
  aux_sym_randcase_statement_repeat1 = 1170,
  aux_sym_open_range_list_repeat1 = 1171,
  aux_sym_pattern_repeat1 = 1172,
  aux_sym_pattern_repeat2 = 1173,
  aux_sym_assignment_pattern_repeat1 = 1174,
  aux_sym_assignment_pattern_repeat2 = 1175,
  aux_sym_assignment_pattern_net_lvalue_repeat1 = 1176,
  aux_sym_assignment_pattern_variable_lvalue_repeat1 = 1177,
  aux_sym_for_initialization_repeat1 = 1178,
  aux_sym_for_variable_declaration_repeat1 = 1179,
  aux_sym_for_step_repeat1 = 1180,
  aux_sym_loop_variables1_repeat1 = 1181,
  aux_sym_clocking_declaration_repeat1 = 1182,
  aux_sym_list_of_clocking_decl_assign_repeat1 = 1183,
  aux_sym_specify_block_repeat1 = 1184,
  aux_sym_list_of_path_inputs_repeat1 = 1185,
  aux_sym_list_of_path_outputs_repeat1 = 1186,
  aux_sym_list_of_path_delay_expressions_repeat1 = 1187,
  aux_sym_edge_control_specifier_repeat1 = 1188,
  aux_sym_module_path_concatenation_repeat1 = 1189,
  aux_sym_stream_concatenation_repeat1 = 1190,
  aux_sym_list_of_arguments_repeat1 = 1191,
  aux_sym_list_of_arguments_parent_repeat1 = 1192,
  aux_sym_list_of_arguments_parent_repeat2 = 1193,
  aux_sym_string_literal_repeat1 = 1194,
  aux_sym_bit_select1_repeat1 = 1195,
  aux_sym_select1_repeat1 = 1196,
  aux_sym_constant_bit_select1_repeat1 = 1197,
  aux_sym_constant_select1_repeat1 = 1198,
  aux_sym_attribute_instance_repeat1 = 1199,
  aux_sym_hierarchical_identifier_repeat1 = 1200,
  aux_sym_ps_parameter_identifier_repeat1 = 1201,
  alias_sym__ordered_parameter_assignment = 1202,
  alias_sym_checker_identifier = 1203,
  alias_sym_class_identifier = 1204,
  alias_sym_cover_point_identifier = 1205,
  alias_sym_covergroup_identifier = 1206,
  alias_sym_cross_identifier = 1207,
  alias_sym_dynamic_array_variable_identifier = 1208,
  alias_sym_enum_identifier = 1209,
  alias_sym_formal_port_identifier = 1210,
  alias_sym_genvar_identifier = 1211,
  alias_sym_instance_identifier = 1212,
  alias_sym_interface_identifier = 1213,
  alias_sym_interface_instance_identifier = 1214,
  alias_sym_member_identifier = 1215,
  alias_sym_package_identifier = 1216,
  alias_sym_parameter_identifier = 1217,
  alias_sym_port_identifier = 1218,
  alias_sym_program_identifier = 1219,
  alias_sym_property_identifier = 1220,
  alias_sym_specparam_identifier = 1221,
  alias_sym_tf_identifier = 1222,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_simple_identifier] = "simple_identifier",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_double_quoted_string_token1] = "double_quoted_string_token1",
  [anon_sym_LT] = "<",
  [aux_sym_include_compiler_directive_standard_token1] = "include_compiler_directive_standard_token1",
  [anon_sym_GT] = ">",
  [aux_sym_include_compiler_directive_token1] = "directive_include",
  [sym_default_text] = "default_text",
  [sym_macro_text] = "macro_text",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_COMMA] = ",",
  [anon_sym_EQ] = "=",
  [aux_sym_text_macro_definition_token1] = "directive_define",
  [anon_sym_LF] = "\n",
  [anon_sym_BQUOTE] = "`",
  [aux_sym_id_directive_token1] = "directive_ifdef",
  [aux_sym_id_directive_token2] = "directive_ifndef",
  [aux_sym_id_directive_token3] = "directive_elsif",
  [aux_sym_id_directive_token4] = "directive_undef",
  [aux_sym_zero_directive_token1] = "directive_resetall",
  [aux_sym_zero_directive_token2] = "directive_undefineall",
  [aux_sym_zero_directive_token3] = "directive_endif",
  [aux_sym_zero_directive_token4] = "directive_else",
  [aux_sym_zero_directive_token5] = "directive_nounconnected_drive",
  [aux_sym_zero_directive_token6] = "directive_celldefine",
  [aux_sym_zero_directive_token7] = "directive_endcelldefine",
  [aux_sym_zero_directive_token8] = "directive_end_keywords",
  [aux_sym_timescale_compiler_directive_token1] = "directive_timescale",
  [anon_sym_SLASH] = "/",
  [aux_sym_default_nettype_compiler_directive_token1] = "directive_default_nettype",
  [anon_sym_wire] = "wire",
  [anon_sym_tri] = "tri",
  [anon_sym_tri0] = "tri0",
  [anon_sym_tri1] = "tri1",
  [anon_sym_wand] = "wand",
  [anon_sym_triand] = "triand",
  [anon_sym_wor] = "wor",
  [anon_sym_trior] = "trior",
  [anon_sym_trireg] = "trireg",
  [anon_sym_uwire] = "uwire",
  [anon_sym_none] = "none",
  [aux_sym_unconnected_drive_token1] = "directive_unconnected_drive",
  [anon_sym_pull0] = "pull0",
  [anon_sym_pull1] = "pull1",
  [aux_sym_line_compiler_directive_token1] = "directive_line",
  [aux_sym_begin_keywords_token1] = "directive_begin_keywords",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SEMI] = ";",
  [anon_sym_endmodule] = "endmodule",
  [anon_sym_COLON] = ":",
  [anon_sym_extern] = "extern",
  [anon_sym_module] = "module",
  [anon_sym_macromodule] = "macromodule",
  [anon_sym_endinterface] = "endinterface",
  [anon_sym_interface] = "interface",
  [anon_sym_endprogram] = "endprogram",
  [anon_sym_program] = "program",
  [anon_sym_checker] = "checker",
  [anon_sym_endchecker] = "endchecker",
  [anon_sym_virtual] = "virtual",
  [anon_sym_class] = "class",
  [anon_sym_extends] = "extends",
  [anon_sym_implements] = "implements",
  [anon_sym_endclass] = "endclass",
  [anon_sym_pure] = "pure",
  [anon_sym_package] = "package",
  [anon_sym_endpackage] = "endpackage",
  [anon_sym_timeunit] = "timeunit",
  [anon_sym_timeprecision] = "timeprecision",
  [anon_sym_POUND] = "#",
  [anon_sym_type] = "type",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_input] = "input",
  [anon_sym_output] = "output",
  [anon_sym_inout] = "inout",
  [anon_sym_ref] = "ref",
  [anon_sym_DOLLARfatal] = "$fatal",
  [anon_sym_DOLLARerror] = "$error",
  [anon_sym_DOLLARwarning] = "$warning",
  [anon_sym_DOLLARinfo] = "$info",
  [anon_sym_0] = "0",
  [anon_sym_1] = "1",
  [anon_sym_2] = "2",
  [anon_sym_default] = "default",
  [anon_sym_clocking] = "clocking",
  [anon_sym_disable] = "disable",
  [anon_sym_iff] = "iff",
  [anon_sym_defparam] = "defparam",
  [anon_sym_bind] = "bind",
  [anon_sym_forkjoin] = "forkjoin",
  [anon_sym_rand] = "rand",
  [anon_sym_const] = "const",
  [anon_sym_function] = "function",
  [anon_sym_new] = "new",
  [anon_sym_static] = "static",
  [anon_sym_protected] = "protected",
  [anon_sym_local] = "local",
  [anon_sym_randc] = "randc",
  [anon_sym_super] = "super",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_constraint] = "constraint",
  [anon_sym_solve] = "solve",
  [anon_sym_before] = "before",
  [anon_sym_soft] = "soft",
  [anon_sym_u2013_GT] = "\u2013>",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_foreach] = "foreach",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_unique] = "unique",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_COLON_SLASH] = ":/",
  [anon_sym_localparam] = "localparam",
  [anon_sym_parameter] = "parameter",
  [anon_sym_specparam] = "specparam",
  [anon_sym_var] = "var",
  [anon_sym_import] = "import",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_STAR] = "*",
  [anon_sym_export] = "export",
  [anon_sym_STAR_COLON_COLON_STAR] = "*::*",
  [anon_sym_genvar] = "genvar",
  [anon_sym_vectored] = "vectored",
  [anon_sym_scalared] = "scalared",
  [anon_sym_interconnect] = "interconnect",
  [anon_sym_typedef] = "typedef",
  [anon_sym_enum] = "enum",
  [anon_sym_struct] = "struct",
  [anon_sym_union] = "union",
  [anon_sym_nettype] = "nettype",
  [anon_sym_with] = "with",
  [anon_sym_automatic] = "automatic",
  [anon_sym_string] = "string",
  [anon_sym_packed] = "packed",
  [anon_sym_chandle] = "chandle",
  [anon_sym_event] = "event",
  [anon_sym_byte] = "byte",
  [anon_sym_shortint] = "shortint",
  [anon_sym_int] = "int",
  [anon_sym_longint] = "longint",
  [anon_sym_integer] = "integer",
  [anon_sym_time] = "time",
  [anon_sym_bit] = "bit",
  [anon_sym_logic] = "logic",
  [anon_sym_reg] = "reg",
  [anon_sym_shortreal] = "shortreal",
  [anon_sym_real] = "real",
  [anon_sym_realtime] = "realtime",
  [anon_sym_supply0] = "supply0",
  [anon_sym_supply1] = "supply1",
  [anon_sym_signed] = "signed",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_void] = "void",
  [anon_sym_tagged] = "tagged",
  [anon_sym_highz1] = "highz1",
  [anon_sym_highz0] = "highz0",
  [anon_sym_strong0] = "strong0",
  [anon_sym_weak0] = "weak0",
  [anon_sym_strong1] = "strong1",
  [anon_sym_weak1] = "weak1",
  [anon_sym_small] = "small",
  [anon_sym_medium] = "medium",
  [anon_sym_large] = "large",
  [anon_sym_1step] = "1step",
  [anon_sym_PATHPULSE_DOLLAR_EQ] = "PATHPULSE$=",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_task] = "task",
  [anon_sym_DQUOTEDPI_DASHC_DQUOTE] = "\"DPI-C\"",
  [anon_sym_DQUOTEDPI_DQUOTE] = "\"DPI\"",
  [anon_sym_context] = "context",
  [anon_sym_endtask] = "endtask",
  [anon_sym_PLUS] = "+",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_u2013] = "\u2013",
  [anon_sym_u2013u2013] = "\u2013\u2013",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_PERCENT] = "%",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_modport] = "modport",
  [anon_sym_assert] = "assert",
  [anon_sym_property] = "property",
  [anon_sym_assume] = "assume",
  [anon_sym_cover] = "cover",
  [anon_sym_expect] = "expect",
  [anon_sym_sequence] = "sequence",
  [anon_sym_restrict] = "restrict",
  [anon_sym_endproperty] = "endproperty",
  [anon_sym_strong] = "strong",
  [anon_sym_weak] = "weak",
  [anon_sym_not] = "not",
  [anon_sym_or] = "or",
  [anon_sym_and] = "and",
  [anon_sym_PIPE_DASH_GT] = "|->",
  [anon_sym_PIPE_EQ_GT] = "|=>",
  [anon_sym_case] = "case",
  [anon_sym_endcase] = "endcase",
  [anon_sym_POUND_DASH_POUND] = "#-#",
  [anon_sym_POUND_EQ_POUND] = "#=#",
  [anon_sym_nexttime] = "nexttime",
  [anon_sym_s_nexttime] = "s_nexttime",
  [anon_sym_always] = "always",
  [anon_sym_s_always] = "s_always",
  [anon_sym_s_eventually] = "s_eventually",
  [anon_sym_eventually] = "eventually",
  [anon_sym_until] = "until",
  [anon_sym_s_until] = "s_until",
  [anon_sym_until_with] = "until_with",
  [anon_sym_s_until_with] = "s_until_with",
  [anon_sym_implies] = "implies",
  [anon_sym_accept_on] = "accept_on",
  [anon_sym_reject_on] = "reject_on",
  [anon_sym_sync_accept_on] = "sync_accept_on",
  [anon_sym_sync_reject_on] = "sync_reject_on",
  [anon_sym_endsequence] = "endsequence",
  [anon_sym_untyped] = "untyped",
  [anon_sym_intersect] = "intersect",
  [anon_sym_first_match] = "first_match",
  [anon_sym_throughout] = "throughout",
  [anon_sym_within] = "within",
  [anon_sym_POUND_POUND] = "##",
  [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = "##[*]",
  [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = "##[+]",
  [anon_sym_LBRACK_STAR] = "[*",
  [anon_sym_LBRACK_STAR_RBRACK] = "[*]",
  [anon_sym_LBRACK_PLUS_RBRACK] = "[+]",
  [anon_sym_LBRACK_EQ] = "[=",
  [anon_sym_LBRACK_DASH_GT] = "[->",
  [anon_sym_dist] = "dist",
  [anon_sym_covergroup] = "covergroup",
  [anon_sym_endgroup] = "endgroup",
  [anon_sym_option] = "option",
  [anon_sym_type_option] = "type_option",
  [anon_sym_sample] = "sample",
  [anon_sym_AT_AT] = "@@",
  [anon_sym_begin] = "begin",
  [anon_sym_end] = "end",
  [anon_sym_coverpoint] = "coverpoint",
  [anon_sym_wildcard] = "wildcard",
  [anon_sym_bins] = "bins",
  [anon_sym_illegal_bins] = "illegal_bins",
  [anon_sym_ignore_bins] = "ignore_bins",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_LBRACKu2013_GT] = "[\u2013>",
  [anon_sym_cross] = "cross",
  [anon_sym_BANG] = "!",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_matches] = "matches",
  [anon_sym_binsof] = "binsof",
  [anon_sym_let] = "let",
  [anon_sym_pulldown] = "pulldown",
  [anon_sym_pullup] = "pullup",
  [anon_sym_cmos] = "cmos",
  [anon_sym_rcmos] = "rcmos",
  [anon_sym_bufif0] = "bufif0",
  [anon_sym_bufif1] = "bufif1",
  [anon_sym_notif0] = "notif0",
  [anon_sym_notif1] = "notif1",
  [anon_sym_nmos] = "nmos",
  [anon_sym_pmos] = "pmos",
  [anon_sym_rnmos] = "rnmos",
  [anon_sym_rpmos] = "rpmos",
  [anon_sym_nand] = "nand",
  [anon_sym_nor] = "nor",
  [anon_sym_xor] = "xor",
  [anon_sym_xnor] = "xnor",
  [anon_sym_buf] = "buf",
  [anon_sym_tranif0] = "tranif0",
  [anon_sym_tranif1] = "tranif1",
  [anon_sym_rtranif1] = "rtranif1",
  [anon_sym_rtranif0] = "rtranif0",
  [anon_sym_tran] = "tran",
  [anon_sym_rtran] = "rtran",
  [anon_sym_generate] = "generate",
  [anon_sym_endgenerate] = "endgenerate",
  [anon_sym_for] = "for",
  [anon_sym_primitive] = "primitive",
  [anon_sym_endprimitive] = "endprimitive",
  [anon_sym_table] = "table",
  [anon_sym_endtable] = "endtable",
  [anon_sym_initial] = "initial",
  [anon_sym_1_SQUOTEb0] = "1'b0",
  [anon_sym_1_SQUOTEb1] = "1'b1",
  [anon_sym_1_SQUOTEbx] = "1'bx",
  [anon_sym_1_SQUOTEbX] = "1'bX",
  [anon_sym_1_SQUOTEB0] = "1'B0",
  [anon_sym_1_SQUOTEB1] = "1'B1",
  [anon_sym_1_SQUOTEBx] = "1'Bx",
  [anon_sym_1_SQUOTEBX] = "1'BX",
  [anon_sym_DASH] = "-",
  [sym_output_symbol] = "output_symbol",
  [sym_level_symbol] = "level_symbol",
  [sym_edge_symbol] = "edge_symbol",
  [anon_sym_assign] = "assign",
  [anon_sym_alias] = "alias",
  [anon_sym_always_comb] = "always_comb",
  [anon_sym_always_latch] = "always_latch",
  [anon_sym_always_ff] = "always_ff",
  [anon_sym_final] = "final",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_LT_LT_LT_EQ] = "<<<=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_deassign] = "deassign",
  [anon_sym_force] = "force",
  [anon_sym_release] = "release",
  [anon_sym_fork] = "fork",
  [anon_sym_join] = "join",
  [anon_sym_join_any] = "join_any",
  [anon_sym_join_none] = "join_none",
  [anon_sym_repeat] = "repeat",
  [anon_sym_AT] = "@",
  [anon_sym_AT_STAR] = "@*",
  [anon_sym_return] = "return",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_wait] = "wait",
  [anon_sym_wait_order] = "wait_order",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_DASH_GT_GT] = "->>",
  [anon_sym_unique0] = "unique0",
  [anon_sym_priority] = "priority",
  [anon_sym_AMP_AMP_AMP] = "&&&",
  [anon_sym_inside] = "inside",
  [anon_sym_casez] = "casez",
  [anon_sym_casex] = "casex",
  [anon_sym_randcase] = "randcase",
  [anon_sym_SQUOTE_LBRACE] = "'{",
  [anon_sym_forever] = "forever",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_POUND0] = "#0",
  [anon_sym_endclocking] = "endclocking",
  [anon_sym_global] = "global",
  [anon_sym_specify] = "specify",
  [anon_sym_endspecify] = "endspecify",
  [anon_sym_pulsestyle_onevent] = "pulsestyle_onevent",
  [anon_sym_pulsestyle_ondetect] = "pulsestyle_ondetect",
  [anon_sym_showcancelled] = "showcancelled",
  [anon_sym_noshowcancelled] = "noshowcancelled",
  [anon_sym_STAR_GT] = "*>",
  [anon_sym_posedge] = "posedge",
  [anon_sym_negedge] = "negedge",
  [anon_sym_edge] = "edge",
  [anon_sym_ifnone] = "ifnone",
  [anon_sym_DOLLARsetup] = "$setup",
  [anon_sym_DOLLARhold] = "$hold",
  [anon_sym_DOLLARsetuphold] = "$setuphold",
  [anon_sym_DOLLARrecovery] = "$recovery",
  [anon_sym_DOLLARremoval] = "$removal",
  [anon_sym_DOLLARrecrem] = "$recrem",
  [anon_sym_DOLLARskew] = "$skew",
  [anon_sym_DOLLARtimeskew] = "$timeskew",
  [anon_sym_DOLLARfullskew] = "$fullskew",
  [anon_sym_DOLLARperiod] = "$period",
  [anon_sym_DOLLARwidth] = "$width",
  [anon_sym_DOLLARnochange] = "$nochange",
  [anon_sym_01] = "01",
  [anon_sym_10] = "10",
  [aux_sym_edge_descriptor_token1] = "edge_descriptor_token1",
  [aux_sym_edge_descriptor_token2] = "edge_descriptor_token2",
  [anon_sym_TILDE] = "~",
  [anon_sym_EQ_EQ_EQ] = "===",
  [anon_sym_BANG_EQ_EQ] = "!==",
  [anon_sym_SQUOTEb0] = "'b0",
  [anon_sym_SQUOTEb1] = "'b1",
  [anon_sym_SQUOTEB0] = "'B0",
  [anon_sym_SQUOTEB1] = "'B1",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_PLUS_COLON] = "+:",
  [anon_sym_DASH_COLON] = "-:",
  [anon_sym_std] = "std",
  [anon_sym_randomize] = "randomize",
  [anon_sym_null] = "null",
  [anon_sym_QMARK] = "\?",
  [anon_sym_EQ_EQ_QMARK] = "==\?",
  [anon_sym_BANG_EQ_QMARK] = "!=\?",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_CARET_TILDE] = "^~",
  [anon_sym_TILDE_CARET] = "~^",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_LT_LT_LT] = "<<<",
  [anon_sym_LT_DASH_GT] = "<->",
  [anon_sym_this] = "this",
  [anon_sym_s] = "s",
  [anon_sym_ms] = "ms",
  [anon_sym_us] = "us",
  [anon_sym_ns] = "ns",
  [anon_sym_ps] = "ps",
  [anon_sym_fs] = "fs",
  [aux_sym_string_literal_token1] = "string_literal_token1",
  [aux_sym_string_literal_token2] = "string_literal_token2",
  [aux_sym_string_literal_token3] = "string_literal_token3",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_TILDE_AMP] = "~&",
  [anon_sym_TILDE_PIPE] = "~|",
  [anon_sym_DASH_DASH] = "--",
  [aux_sym_decimal_number_token1] = "decimal_number_token1",
  [aux_sym_decimal_number_token2] = "decimal_number_token2",
  [sym_binary_number] = "binary_number",
  [sym_octal_number] = "octal_number",
  [sym_hex_number] = "hex_number",
  [aux_sym_real_number_token1] = "real_number_token1",
  [sym_fixed_point_number] = "fixed_point_number",
  [sym_unsigned_number] = "unsigned_number",
  [anon_sym_SQUOTE0] = "'0",
  [anon_sym_SQUOTE1] = "'1",
  [aux_sym_unbased_unsized_literal_token1] = "unbased_unsized_literal_token1",
  [anon_sym_LPAREN_STAR] = "(*",
  [anon_sym_STAR_RPAREN] = "*)",
  [sym_comment] = "comment",
  [sym_c_identifier] = "c_identifier",
  [anon_sym_BSLASH] = "\\",
  [aux_sym_escaped_identifier_token1] = "escaped_identifier_token1",
  [anon_sym_DOLLARroot] = "$root",
  [anon_sym_DOLLARunit] = "$unit",
  [sym_system_tf_identifier] = "system_tf_identifier",
  [sym_source_file] = "source_file",
  [sym_double_quoted_string] = "double_quoted_string",
  [sym_include_compiler_directive_standard] = "include_compiler_directive_standard",
  [sym_include_compiler_directive] = "include_compiler_directive",
  [sym_text_macro_name] = "text_macro_name",
  [sym_list_of_formal_arguments] = "list_of_formal_arguments",
  [sym_formal_argument] = "formal_argument",
  [sym_text_macro_identifier] = "text_macro_identifier",
  [sym_text_macro_definition] = "text_macro_definition",
  [sym_text_macro_usage] = "text_macro_usage",
  [sym_simple_text_macro_usage] = "simple_text_macro_usage",
  [sym_id_directive] = "id_directive",
  [sym_zero_directive] = "zero_directive",
  [sym_timescale_compiler_directive] = "timescale_compiler_directive",
  [sym_default_nettype_compiler_directive] = "default_nettype_compiler_directive",
  [sym_default_nettype_value] = "default_nettype_value",
  [sym_unconnected_drive] = "unconnected_drive",
  [sym_line_compiler_directive] = "line_compiler_directive",
  [sym_begin_keywords] = "begin_keywords",
  [sym__directives] = "_directives",
  [sym_list_of_actual_arguments] = "list_of_actual_arguments",
  [sym__actual_argument] = "_actual_argument",
  [sym__description] = "_description",
  [sym_module_header] = "module_header",
  [sym_module_nonansi_header] = "module_nonansi_header",
  [sym_module_ansi_header] = "module_ansi_header",
  [sym_module_declaration] = "module_declaration",
  [sym_module_keyword] = "module_keyword",
  [sym_interface_declaration] = "interface_declaration",
  [sym_interface_nonansi_header] = "interface_nonansi_header",
  [sym_interface_ansi_header] = "interface_ansi_header",
  [sym_program_declaration] = "program_declaration",
  [sym_program_nonansi_header] = "program_nonansi_header",
  [sym_program_ansi_header] = "program_ansi_header",
  [sym_checker_declaration] = "checker_declaration",
  [sym_class_declaration] = "class_declaration",
  [sym_interface_class_type] = "interface_class_type",
  [sym_interface_class_declaration] = "interface_class_declaration",
  [sym_interface_class_item] = "interface_class_item",
  [sym_interface_class_method] = "interface_class_method",
  [sym_package_declaration] = "package_declaration",
  [sym_timeunits_declaration] = "timeunits_declaration",
  [sym_parameter_port_list] = "parameter_port_list",
  [sym_parameter_port_declaration] = "parameter_port_declaration",
  [sym_list_of_ports] = "list_of_ports",
  [sym_list_of_port_declarations] = "list_of_port_declarations",
  [sym_port_declaration] = "port_declaration",
  [sym_port] = "port",
  [sym__port_expression] = "_port_expression",
  [sym_port_reference] = "port_reference",
  [sym_port_direction] = "port_direction",
  [sym_net_port_header1] = "net_port_header1",
  [sym_variable_port_header] = "variable_port_header",
  [sym_interface_port_header] = "interface_port_header",
  [sym_ansi_port_declaration] = "ansi_port_declaration",
  [sym_elaboration_system_task] = "elaboration_system_task",
  [sym_finish_number] = "finish_number",
  [sym__module_common_item] = "_module_common_item",
  [sym__module_item] = "_module_item",
  [sym_module_or_generate_item] = "module_or_generate_item",
  [sym__module_or_generate_item_declaration] = "_module_or_generate_item_declaration",
  [sym__non_port_module_item] = "_non_port_module_item",
  [sym_parameter_override] = "parameter_override",
  [sym_bind_directive] = "bind_directive",
  [sym_bind_target_scope] = "bind_target_scope",
  [sym_bind_target_instance] = "bind_target_instance",
  [sym_bind_target_instance_list] = "bind_target_instance_list",
  [sym__bind_instantiation] = "_bind_instantiation",
  [sym_interface_or_generate_item] = "interface_or_generate_item",
  [sym_extern_tf_declaration] = "extern_tf_declaration",
  [sym_interface_item] = "interface_item",
  [sym__non_port_interface_item] = "_non_port_interface_item",
  [sym_program_item] = "program_item",
  [sym_non_port_program_item] = "non_port_program_item",
  [sym__program_generate_item] = "_program_generate_item",
  [sym_checker_port_list] = "checker_port_list",
  [sym_checker_port_item] = "checker_port_item",
  [sym_checker_port_direction] = "checker_port_direction",
  [sym__checker_or_generate_item] = "_checker_or_generate_item",
  [sym_checker_or_generate_item_declaration] = "checker_or_generate_item_declaration",
  [sym__checker_generate_item] = "_checker_generate_item",
  [sym_class_item] = "class_item",
  [sym_class_property] = "class_property",
  [sym_class_method] = "class_method",
  [sym_class_constructor_prototype] = "class_constructor_prototype",
  [sym__class_constraint] = "_class_constraint",
  [sym_class_item_qualifier] = "class_item_qualifier",
  [sym__property_qualifier] = "_property_qualifier",
  [sym_random_qualifier] = "random_qualifier",
  [sym_method_qualifier] = "method_qualifier",
  [sym__method_prototype] = "_method_prototype",
  [sym_class_constructor_declaration] = "class_constructor_declaration",
  [sym_constraint_declaration] = "constraint_declaration",
  [sym_constraint_block] = "constraint_block",
  [sym_constraint_block_item] = "constraint_block_item",
  [sym_solve_before_list] = "solve_before_list",
  [sym_constraint_primary] = "constraint_primary",
  [sym_constraint_expression] = "constraint_expression",
  [sym_uniqueness_constraint] = "uniqueness_constraint",
  [sym_constraint_set] = "constraint_set",
  [sym_dist_list] = "dist_list",
  [sym_dist_item] = "dist_item",
  [sym_dist_weight] = "dist_weight",
  [sym_constraint_prototype] = "constraint_prototype",
  [sym_constraint_prototype_qualifier] = "constraint_prototype_qualifier",
  [sym_extern_constraint_declaration] = "extern_constraint_declaration",
  [sym_identifier_list] = "identifier_list",
  [sym__package_item] = "_package_item",
  [sym_package_or_generate_item_declaration] = "package_or_generate_item_declaration",
  [sym_anonymous_program] = "anonymous_program",
  [sym_anonymous_program_item] = "anonymous_program_item",
  [sym_local_parameter_declaration] = "local_parameter_declaration",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym__any_parameter_declaration] = "_any_parameter_declaration",
  [sym_specparam_declaration] = "specparam_declaration",
  [sym_inout_declaration] = "inout_declaration",
  [sym_input_declaration] = "input_declaration",
  [sym_output_declaration] = "output_declaration",
  [sym_interface_port_declaration] = "interface_port_declaration",
  [sym_ref_declaration] = "ref_declaration",
  [sym_data_declaration] = "data_declaration",
  [sym_package_import_declaration] = "package_import_declaration",
  [sym_package_import_item] = "package_import_item",
  [sym_package_export_declaration] = "package_export_declaration",
  [sym_genvar_declaration] = "genvar_declaration",
  [sym_net_declaration] = "net_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_net_type_declaration] = "net_type_declaration",
  [sym_lifetime] = "lifetime",
  [sym_casting_type] = "casting_type",
  [sym_data_type] = "data_type",
  [sym_data_type_or_implicit1] = "data_type_or_implicit1",
  [sym_implicit_data_type1] = "implicit_data_type1",
  [sym_enum_base_type] = "enum_base_type",
  [sym_enum_name_declaration] = "enum_name_declaration",
  [sym_class_scope] = "class_scope",
  [sym_class_type] = "class_type",
  [sym__integer_type] = "_integer_type",
  [sym_integer_atom_type] = "integer_atom_type",
  [sym_integer_vector_type] = "integer_vector_type",
  [sym_non_integer_type] = "non_integer_type",
  [sym_net_type] = "net_type",
  [sym_net_port_type1] = "net_port_type1",
  [sym__variable_port_type] = "_variable_port_type",
  [sym__var_data_type] = "_var_data_type",
  [sym__signing] = "_signing",
  [sym__simple_type] = "_simple_type",
  [sym_struct_union_member] = "struct_union_member",
  [sym_data_type_or_void] = "data_type_or_void",
  [sym_struct_union] = "struct_union",
  [sym_type_reference] = "type_reference",
  [sym_drive_strength] = "drive_strength",
  [sym_strength0] = "strength0",
  [sym_strength1] = "strength1",
  [sym_charge_strength] = "charge_strength",
  [sym_delay3] = "delay3",
  [sym_delay2] = "delay2",
  [sym_delay_value] = "delay_value",
  [sym_list_of_defparam_assignments] = "list_of_defparam_assignments",
  [sym_list_of_genvar_identifiers] = "list_of_genvar_identifiers",
  [sym_list_of_interface_identifiers] = "list_of_interface_identifiers",
  [sym_list_of_net_decl_assignments] = "list_of_net_decl_assignments",
  [sym_list_of_param_assignments] = "list_of_param_assignments",
  [sym_list_of_port_identifiers] = "list_of_port_identifiers",
  [sym_list_of_udp_port_identifiers] = "list_of_udp_port_identifiers",
  [sym_list_of_specparam_assignments] = "list_of_specparam_assignments",
  [sym_list_of_tf_variable_identifiers] = "list_of_tf_variable_identifiers",
  [sym_list_of_type_assignments] = "list_of_type_assignments",
  [sym_list_of_variable_decl_assignments] = "list_of_variable_decl_assignments",
  [sym_list_of_variable_identifiers] = "list_of_variable_identifiers",
  [sym_list_of_variable_port_identifiers] = "list_of_variable_port_identifiers",
  [sym_defparam_assignment] = "defparam_assignment",
  [sym_net_decl_assignment] = "net_decl_assignment",
  [sym_param_assignment] = "param_assignment",
  [sym_specparam_assignment] = "specparam_assignment",
  [sym_type_assignment] = "type_assignment",
  [sym_pulse_control_specparam] = "pulse_control_specparam",
  [sym_error_limit_value] = "error_limit_value",
  [sym_reject_limit_value] = "reject_limit_value",
  [sym_limit_value] = "limit_value",
  [sym_variable_decl_assignment] = "variable_decl_assignment",
  [sym_class_new] = "class_new",
  [sym_dynamic_array_new] = "dynamic_array_new",
  [sym_unpacked_dimension] = "unpacked_dimension",
  [sym_packed_dimension] = "packed_dimension",
  [sym_associative_dimension] = "associative_dimension",
  [sym__variable_dimension] = "_variable_dimension",
  [sym_queue_dimension] = "queue_dimension",
  [sym_unsized_dimension] = "unsized_dimension",
  [sym_function_data_type_or_implicit1] = "function_data_type_or_implicit1",
  [sym_function_declaration] = "function_declaration",
  [sym_function_body_declaration] = "function_body_declaration",
  [sym_function_prototype] = "function_prototype",
  [sym_dpi_import_export] = "dpi_import_export",
  [sym_dpi_spec_string] = "dpi_spec_string",
  [sym_dpi_function_import_property] = "dpi_function_import_property",
  [sym_dpi_task_import_property] = "dpi_task_import_property",
  [sym_dpi_function_proto] = "dpi_function_proto",
  [sym_dpi_task_proto] = "dpi_task_proto",
  [sym_task_declaration] = "task_declaration",
  [sym_task_body_declaration] = "task_body_declaration",
  [sym_tf_item_declaration] = "tf_item_declaration",
  [sym_tf_port_list] = "tf_port_list",
  [sym_tf_port_item1] = "tf_port_item1",
  [sym_tf_port_direction] = "tf_port_direction",
  [sym_tf_port_declaration] = "tf_port_declaration",
  [sym_task_prototype] = "task_prototype",
  [sym_block_item_declaration] = "block_item_declaration",
  [sym_overload_declaration] = "overload_declaration",
  [sym_overload_operator] = "overload_operator",
  [sym_overload_proto_formals] = "overload_proto_formals",
  [sym_modport_declaration] = "modport_declaration",
  [sym_modport_item] = "modport_item",
  [sym_modport_ports_declaration] = "modport_ports_declaration",
  [sym_modport_clocking_declaration] = "modport_clocking_declaration",
  [sym_modport_simple_ports_declaration] = "modport_simple_ports_declaration",
  [sym_modport_simple_port] = "modport_simple_port",
  [sym_modport_tf_ports_declaration] = "modport_tf_ports_declaration",
  [sym__modport_tf_port] = "_modport_tf_port",
  [sym_import_export] = "import_export",
  [sym_concurrent_assertion_item] = "concurrent_assertion_item",
  [sym__concurrent_assertion_statement] = "_concurrent_assertion_statement",
  [sym_assert_property_statement] = "assert_property_statement",
  [sym_assume_property_statement] = "assume_property_statement",
  [sym_cover_property_statement] = "cover_property_statement",
  [sym_expect_property_statement] = "expect_property_statement",
  [sym_cover_sequence_statement] = "cover_sequence_statement",
  [sym_restrict_property_statement] = "restrict_property_statement",
  [sym__property_actual_arg] = "_property_actual_arg",
  [sym__assertion_item_declaration] = "_assertion_item_declaration",
  [sym_property_declaration] = "property_declaration",
  [sym_property_port_list] = "property_port_list",
  [sym_property_port_item] = "property_port_item",
  [sym_property_lvar_port_direction] = "property_lvar_port_direction",
  [sym_property_formal_type1] = "property_formal_type1",
  [sym_property_spec] = "property_spec",
  [sym_property_expr] = "property_expr",
  [sym_property_case_item] = "property_case_item",
  [sym_sequence_declaration] = "sequence_declaration",
  [sym_sequence_port_list] = "sequence_port_list",
  [sym_sequence_port_item] = "sequence_port_item",
  [sym_sequence_lvar_port_direction] = "sequence_lvar_port_direction",
  [sym_sequence_formal_type1] = "sequence_formal_type1",
  [sym_sequence_expr] = "sequence_expr",
  [sym_cycle_delay_range] = "cycle_delay_range",
  [sym_sequence_method_call] = "sequence_method_call",
  [sym__sequence_match_item] = "_sequence_match_item",
  [sym_sequence_instance] = "sequence_instance",
  [sym_sequence_list_of_arguments] = "sequence_list_of_arguments",
  [sym__sequence_actual_arg] = "_sequence_actual_arg",
  [sym__boolean_abbrev] = "_boolean_abbrev",
  [sym_sequence_abbrev] = "sequence_abbrev",
  [sym_consecutive_repetition] = "consecutive_repetition",
  [sym_non_consecutive_repetition] = "non_consecutive_repetition",
  [sym_goto_repetition] = "goto_repetition",
  [sym__const_or_range_expression] = "_const_or_range_expression",
  [sym_cycle_delay_const_range_expression] = "cycle_delay_const_range_expression",
  [sym_expression_or_dist] = "expression_or_dist",
  [sym_assertion_variable_declaration] = "assertion_variable_declaration",
  [sym_covergroup_declaration] = "covergroup_declaration",
  [sym_coverage_spec_or_option] = "coverage_spec_or_option",
  [sym_coverage_option] = "coverage_option",
  [sym__coverage_spec] = "_coverage_spec",
  [sym_coverage_event] = "coverage_event",
  [sym_block_event_expression] = "block_event_expression",
  [sym_hierarchical_btf_identifier] = "hierarchical_btf_identifier",
  [sym_cover_point] = "cover_point",
  [sym_bins_or_empty] = "bins_or_empty",
  [sym_bins_or_options] = "bins_or_options",
  [sym_bins_keyword] = "bins_keyword",
  [sym_trans_list] = "trans_list",
  [sym_trans_set] = "trans_set",
  [sym_trans_range_list] = "trans_range_list",
  [sym_trans_item] = "trans_item",
  [sym_repeat_range] = "repeat_range",
  [sym_cover_cross] = "cover_cross",
  [sym_list_of_cross_items] = "list_of_cross_items",
  [sym__cross_item] = "_cross_item",
  [sym_cross_body] = "cross_body",
  [sym_cross_body_item] = "cross_body_item",
  [sym_bins_selection_or_option] = "bins_selection_or_option",
  [sym_bins_selection] = "bins_selection",
  [sym_select_expression] = "select_expression",
  [sym_select_condition] = "select_condition",
  [sym_bins_expression] = "bins_expression",
  [sym_covergroup_range_list] = "covergroup_range_list",
  [sym_covergroup_value_range] = "covergroup_value_range",
  [sym__with_covergroup_expression] = "_with_covergroup_expression",
  [sym__set_covergroup_expression] = "_set_covergroup_expression",
  [sym__integer_covergroup_expression] = "_integer_covergroup_expression",
  [sym__cross_set_expression] = "_cross_set_expression",
  [sym__covergroup_expression] = "_covergroup_expression",
  [sym_let_declaration] = "let_declaration",
  [sym_let_port_list] = "let_port_list",
  [sym_let_port_item] = "let_port_item",
  [sym_let_formal_type1] = "let_formal_type1",
  [sym_let_expression] = "let_expression",
  [sym_let_list_of_arguments] = "let_list_of_arguments",
  [sym_let_actual_arg] = "let_actual_arg",
  [sym_gate_instantiation] = "gate_instantiation",
  [sym_cmos_switch_instance] = "cmos_switch_instance",
  [sym_enable_gate_instance] = "enable_gate_instance",
  [sym_mos_switch_instance] = "mos_switch_instance",
  [sym_n_input_gate_instance] = "n_input_gate_instance",
  [sym_n_output_gate_instance] = "n_output_gate_instance",
  [sym_pass_switch_instance] = "pass_switch_instance",
  [sym_pass_enable_switch_instance] = "pass_enable_switch_instance",
  [sym_pull_gate_instance] = "pull_gate_instance",
  [sym_pulldown_strength] = "pulldown_strength",
  [sym_pullup_strength] = "pullup_strength",
  [sym_enable_terminal] = "enable_terminal",
  [sym_inout_terminal] = "inout_terminal",
  [sym_input_terminal] = "input_terminal",
  [sym_ncontrol_terminal] = "ncontrol_terminal",
  [sym_output_terminal] = "output_terminal",
  [sym_pcontrol_terminal] = "pcontrol_terminal",
  [sym_cmos_switchtype] = "cmos_switchtype",
  [sym_enable_gatetype] = "enable_gatetype",
  [sym_mos_switchtype] = "mos_switchtype",
  [sym_n_input_gatetype] = "n_input_gatetype",
  [sym_n_output_gatetype] = "n_output_gatetype",
  [sym_pass_en_switchtype] = "pass_en_switchtype",
  [sym_pass_switchtype] = "pass_switchtype",
  [sym_module_instantiation] = "module_instantiation",
  [sym_parameter_value_assignment] = "parameter_value_assignment",
  [sym_list_of_parameter_assignments] = "list_of_parameter_assignments",
  [sym_ordered_parameter_assignment] = "ordered_parameter_assignment",
  [sym_named_parameter_assignment] = "named_parameter_assignment",
  [sym_hierarchical_instance] = "hierarchical_instance",
  [sym_name_of_instance] = "name_of_instance",
  [sym_list_of_port_connections] = "list_of_port_connections",
  [sym_ordered_port_connection] = "ordered_port_connection",
  [sym_named_port_connection] = "named_port_connection",
  [sym_interface_instantiation] = "interface_instantiation",
  [sym_program_instantiation] = "program_instantiation",
  [sym_checker_instantiation] = "checker_instantiation",
  [sym_generate_region] = "generate_region",
  [sym_loop_generate_construct] = "loop_generate_construct",
  [sym_genvar_initialization] = "genvar_initialization",
  [sym_genvar_iteration] = "genvar_iteration",
  [sym__conditional_generate_construct] = "_conditional_generate_construct",
  [sym_if_generate_construct] = "if_generate_construct",
  [sym_case_generate_construct] = "case_generate_construct",
  [sym_case_generate_item] = "case_generate_item",
  [sym_generate_block] = "generate_block",
  [sym__generate_item] = "_generate_item",
  [sym_udp_nonansi_declaration] = "udp_nonansi_declaration",
  [sym_udp_ansi_declaration] = "udp_ansi_declaration",
  [sym_udp_declaration] = "udp_declaration",
  [sym_udp_port_list] = "udp_port_list",
  [sym_udp_declaration_port_list] = "udp_declaration_port_list",
  [sym_udp_port_declaration] = "udp_port_declaration",
  [sym_udp_output_declaration] = "udp_output_declaration",
  [sym_udp_input_declaration] = "udp_input_declaration",
  [sym_udp_reg_declaration] = "udp_reg_declaration",
  [sym__udp_body] = "_udp_body",
  [sym_combinational_body] = "combinational_body",
  [sym_combinational_entry] = "combinational_entry",
  [sym_sequential_body] = "sequential_body",
  [sym_udp_initial_statement] = "udp_initial_statement",
  [sym_init_val] = "init_val",
  [sym_sequential_entry] = "sequential_entry",
  [sym__seq_input_list] = "_seq_input_list",
  [sym_level_input_list] = "level_input_list",
  [sym_edge_input_list] = "edge_input_list",
  [sym_edge_indicator] = "edge_indicator",
  [sym__current_state] = "_current_state",
  [sym_next_state] = "next_state",
  [sym_udp_instantiation] = "udp_instantiation",
  [sym_udp_instance] = "udp_instance",
  [sym_continuous_assign] = "continuous_assign",
  [sym_list_of_net_assignments] = "list_of_net_assignments",
  [sym_list_of_variable_assignments] = "list_of_variable_assignments",
  [sym_net_alias] = "net_alias",
  [sym_net_assignment] = "net_assignment",
  [sym_initial_construct] = "initial_construct",
  [sym_always_construct] = "always_construct",
  [sym_always_keyword] = "always_keyword",
  [sym_final_construct] = "final_construct",
  [sym_blocking_assignment] = "blocking_assignment",
  [sym_operator_assignment] = "operator_assignment",
  [sym_assignment_operator] = "assignment_operator",
  [sym_nonblocking_assignment] = "nonblocking_assignment",
  [sym_procedural_continuous_assignment] = "procedural_continuous_assignment",
  [sym_variable_assignment] = "variable_assignment",
  [sym_action_block] = "action_block",
  [sym_seq_block] = "seq_block",
  [sym_par_block] = "par_block",
  [sym_join_keyword] = "join_keyword",
  [sym_statement_or_null] = "statement_or_null",
  [sym_statement] = "statement",
  [sym_statement_item] = "statement_item",
  [sym_function_statement] = "function_statement",
  [sym_function_statement_or_null] = "function_statement_or_null",
  [sym_variable_identifier_list] = "variable_identifier_list",
  [sym_procedural_timing_control_statement] = "procedural_timing_control_statement",
  [sym_delay_or_event_control] = "delay_or_event_control",
  [sym_delay_control] = "delay_control",
  [sym_event_control] = "event_control",
  [sym_event_expression] = "event_expression",
  [sym__procedural_timing_control] = "_procedural_timing_control",
  [sym_jump_statement] = "jump_statement",
  [sym_wait_statement] = "wait_statement",
  [sym_event_trigger] = "event_trigger",
  [sym_disable_statement] = "disable_statement",
  [sym_conditional_statement] = "conditional_statement",
  [sym_unique_priority] = "unique_priority",
  [sym_cond_predicate] = "cond_predicate",
  [sym__expression_or_cond_pattern] = "_expression_or_cond_pattern",
  [sym_cond_pattern] = "cond_pattern",
  [sym_case_statement] = "case_statement",
  [sym_case_keyword] = "case_keyword",
  [sym_case_expression] = "case_expression",
  [sym_case_item] = "case_item",
  [sym_case_pattern_item] = "case_pattern_item",
  [sym_case_inside_item] = "case_inside_item",
  [sym_case_item_expression] = "case_item_expression",
  [sym_randcase_statement] = "randcase_statement",
  [sym_randcase_item] = "randcase_item",
  [sym_open_range_list] = "open_range_list",
  [sym_open_value_range] = "open_value_range",
  [sym_pattern] = "pattern",
  [sym_assignment_pattern] = "assignment_pattern",
  [sym__array_pattern_key] = "_array_pattern_key",
  [sym_assignment_pattern_key] = "assignment_pattern_key",
  [sym_assignment_pattern_expression] = "assignment_pattern_expression",
  [sym__assignment_pattern_expression_type] = "_assignment_pattern_expression_type",
  [sym_assignment_pattern_net_lvalue] = "assignment_pattern_net_lvalue",
  [sym_assignment_pattern_variable_lvalue] = "assignment_pattern_variable_lvalue",
  [sym_loop_statement] = "loop_statement",
  [sym_for_initialization] = "for_initialization",
  [sym_for_variable_declaration] = "for_variable_declaration",
  [sym_for_step] = "for_step",
  [sym__for_step_assignment] = "_for_step_assignment",
  [sym_loop_variables1] = "loop_variables1",
  [sym__assertion_item] = "_assertion_item",
  [sym_deferred_immediate_assertion_item] = "deferred_immediate_assertion_item",
  [sym__procedural_assertion_statement] = "_procedural_assertion_statement",
  [sym__immediate_assertion_statement] = "_immediate_assertion_statement",
  [sym__simple_immediate_assertion_statement] = "_simple_immediate_assertion_statement",
  [sym_simple_immediate_assert_statement] = "simple_immediate_assert_statement",
  [sym_simple_immediate_assume_statement] = "simple_immediate_assume_statement",
  [sym_simple_immediate_cover_statement] = "simple_immediate_cover_statement",
  [sym__deferred_immediate_assertion_statement] = "_deferred_immediate_assertion_statement",
  [sym_deferred_immediate_assert_statement] = "deferred_immediate_assert_statement",
  [sym_deferred_immediate_assume_statement] = "deferred_immediate_assume_statement",
  [sym_deferred_immediate_cover_statement] = "deferred_immediate_cover_statement",
  [sym_clocking_declaration] = "clocking_declaration",
  [sym_clocking_event] = "clocking_event",
  [sym_clocking_item] = "clocking_item",
  [sym_default_skew] = "default_skew",
  [sym_clocking_direction] = "clocking_direction",
  [sym_list_of_clocking_decl_assign] = "list_of_clocking_decl_assign",
  [sym_clocking_decl_assign] = "clocking_decl_assign",
  [sym_clocking_skew] = "clocking_skew",
  [sym_clocking_drive] = "clocking_drive",
  [sym_cycle_delay] = "cycle_delay",
  [sym_clockvar] = "clockvar",
  [sym_clockvar_expression] = "clockvar_expression",
  [sym_specify_block] = "specify_block",
  [sym__specify_item] = "_specify_item",
  [sym_pulsestyle_declaration] = "pulsestyle_declaration",
  [sym_showcancelled_declaration] = "showcancelled_declaration",
  [sym_path_declaration] = "path_declaration",
  [sym_simple_path_declaration] = "simple_path_declaration",
  [sym_parallel_path_description] = "parallel_path_description",
  [sym_full_path_description] = "full_path_description",
  [sym_list_of_path_inputs] = "list_of_path_inputs",
  [sym_list_of_path_outputs] = "list_of_path_outputs",
  [sym_specify_input_terminal_descriptor] = "specify_input_terminal_descriptor",
  [sym_specify_output_terminal_descriptor] = "specify_output_terminal_descriptor",
  [sym_input_identifier] = "input_identifier",
  [sym_output_identifier] = "output_identifier",
  [sym_path_delay_value] = "path_delay_value",
  [sym_list_of_path_delay_expressions] = "list_of_path_delay_expressions",
  [sym_path_delay_expression] = "path_delay_expression",
  [sym_edge_sensitive_path_declaration] = "edge_sensitive_path_declaration",
  [sym_parallel_edge_sensitive_path_description] = "parallel_edge_sensitive_path_description",
  [sym_full_edge_sensitive_path_description] = "full_edge_sensitive_path_description",
  [sym_data_source_expression] = "data_source_expression",
  [sym_edge_identifier] = "edge_identifier",
  [sym_state_dependent_path_declaration] = "state_dependent_path_declaration",
  [sym_polarity_operator] = "polarity_operator",
  [sym__system_timing_check] = "_system_timing_check",
  [sym_DOLLARsetup_timing_check] = "$setup_timing_check",
  [sym_DOLLARhold_timing_check] = "$hold_timing_check",
  [sym_DOLLARsetuphold_timing_check] = "$setuphold_timing_check",
  [sym_DOLLARrecovery_timing_check] = "$recovery_timing_check",
  [sym_DOLLARremoval_timing_check] = "$removal_timing_check",
  [sym_DOLLARrecrem_timing_check] = "$recrem_timing_check",
  [sym_DOLLARskew_timing_check] = "$skew_timing_check",
  [sym_DOLLARtimeskew_timing_check] = "$timeskew_timing_check",
  [sym_DOLLARfullskew_timing_check] = "$fullskew_timing_check",
  [sym_DOLLARperiod_timing_check] = "$period_timing_check",
  [sym_DOLLARwidth_timing_check] = "$width_timing_check",
  [sym_DOLLARnochange_timing_check] = "$nochange_timing_check",
  [sym_timecheck_condition] = "timecheck_condition",
  [sym_controlled_reference_event] = "controlled_reference_event",
  [sym_data_event] = "data_event",
  [sym_delayed_data] = "delayed_data",
  [sym_delayed_reference] = "delayed_reference",
  [sym_end_edge_offset] = "end_edge_offset",
  [sym_event_based_flag] = "event_based_flag",
  [sym_notifier] = "notifier",
  [sym_reference_event] = "reference_event",
  [sym_remain_active_flag] = "remain_active_flag",
  [sym_timestamp_condition] = "timestamp_condition",
  [sym_start_edge_offset] = "start_edge_offset",
  [sym_threshold] = "threshold",
  [sym_timing_check_limit] = "timing_check_limit",
  [sym_timing_check_event] = "timing_check_event",
  [sym_controlled_timing_check_event] = "controlled_reference_event",
  [sym_timing_check_event_control] = "timing_check_event_control",
  [sym__specify_terminal_descriptor] = "_specify_terminal_descriptor",
  [sym_edge_control_specifier] = "edge_control_specifier",
  [sym_edge_descriptor] = "edge_descriptor",
  [sym_timing_check_condition] = "timing_check_condition",
  [sym_scalar_timing_check_condition] = "scalar_timing_check_condition",
  [sym_scalar_constant] = "scalar_constant",
  [sym_concatenation] = "concatenation",
  [sym_constant_concatenation] = "constant_concatenation",
  [sym_constant_multiple_concatenation] = "constant_multiple_concatenation",
  [sym_module_path_concatenation] = "module_path_concatenation",
  [sym_module_path_multiple_concatenation] = "module_path_multiple_concatenation",
  [sym_multiple_concatenation] = "multiple_concatenation",
  [sym_streaming_concatenation] = "streaming_concatenation",
  [sym_stream_operator] = "stream_operator",
  [sym_slice_size] = "slice_size",
  [sym_stream_concatenation] = "stream_concatenation",
  [sym_stream_expression] = "stream_expression",
  [sym_array_range_expression] = "array_range_expression",
  [sym_empty_unpacked_array_concatenation] = "empty_unpacked_array_concatenation",
  [sym_tf_call] = "tf_call",
  [sym_system_tf_call] = "system_tf_call",
  [sym_subroutine_call] = "subroutine_call",
  [sym_function_subroutine_call] = "function_subroutine_call",
  [sym_list_of_arguments] = "list_of_arguments",
  [sym_list_of_arguments_parent] = "list_of_arguments_parent",
  [sym_method_call] = "method_call",
  [sym_method_call_body] = "method_call_body",
  [sym__built_in_method_call] = "_built_in_method_call",
  [sym_array_manipulation_call] = "array_manipulation_call",
  [sym_randomize_call] = "randomize_call",
  [sym__method_call_root] = "_method_call_root",
  [sym_array_method_name] = "array_method_name",
  [sym_inc_or_dec_expression] = "inc_or_dec_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_constant_expression] = "constant_expression",
  [sym_constant_mintypmax_expression] = "constant_mintypmax_expression",
  [sym_constant_param_expression] = "constant_param_expression",
  [sym_param_expression] = "param_expression",
  [sym__constant_range_expression] = "_constant_range_expression",
  [sym__constant_part_select_range] = "_constant_part_select_range",
  [sym_constant_range] = "constant_range",
  [sym_constant_indexed_range] = "constant_indexed_range",
  [sym_expression] = "expression",
  [sym_tagged_union_expression] = "tagged_union_expression",
  [sym_inside_expression] = "inside_expression",
  [sym_value_range] = "value_range",
  [sym_mintypmax_expression] = "mintypmax_expression",
  [sym_module_path_expression] = "module_path_expression",
  [sym_module_path_mintypmax_expression] = "module_path_mintypmax_expression",
  [sym__part_select_range] = "_part_select_range",
  [sym_indexed_range] = "indexed_range",
  [sym__genvar_expression] = "_genvar_expression",
  [sym_constant_primary] = "constant_primary",
  [sym_module_path_primary] = "module_path_primary",
  [sym_primary] = "primary",
  [sym_class_qualifier] = "class_qualifier",
  [sym_range_expression] = "range_expression",
  [sym_primary_literal] = "primary_literal",
  [sym_time_literal] = "time_literal",
  [sym_time_unit] = "time_unit",
  [sym_string_literal] = "string_literal",
  [sym_implicit_class_handle] = "implicit_class_handle",
  [sym_bit_select1] = "bit_select1",
  [sym_select1] = "select1",
  [sym_nonrange_select1] = "nonrange_select1",
  [sym_constant_bit_select1] = "constant_bit_select1",
  [sym_constant_select1] = "constant_select1",
  [sym_cast] = "cast",
  [sym_net_lvalue] = "net_lvalue",
  [sym_variable_lvalue] = "variable_lvalue",
  [sym_nonrange_variable_lvalue] = "nonrange_variable_lvalue",
  [sym_unary_operator] = "unary_operator",
  [sym_inc_or_dec_operator] = "inc_or_dec_operator",
  [sym__number] = "_number",
  [sym_integral_number] = "integral_number",
  [sym_decimal_number] = "decimal_number",
  [sym_real_number] = "real_number",
  [sym_unbased_unsized_literal] = "unbased_unsized_literal",
  [sym_attribute_instance] = "attribute_instance",
  [sym_attr_spec] = "attr_spec",
  [sym__attr_name] = "_attr_name",
  [sym__bin_identifier] = "_bin_identifier",
  [sym_clocking_identifier] = "clocking_identifier",
  [sym_const_identifier] = "const_identifier",
  [sym_constraint_identifier] = "constraint_identifier",
  [sym_escaped_identifier] = "escaped_identifier",
  [sym_function_identifier] = "function_identifier",
  [sym_generate_block_identifier] = "generate_block_identifier",
  [sym__hierarchical_array_identifier] = "_hierarchical_array_identifier",
  [sym__hierarchical_event_identifier] = "_hierarchical_event_identifier",
  [sym__hierarchical_parameter_identifier] = "_hierarchical_parameter_identifier",
  [sym__identifier] = "_identifier",
  [sym_index_variable_identifier] = "index_variable_identifier",
  [sym_inout_port_identifier] = "inout_port_identifier",
  [sym_input_port_identifier] = "input_port_identifier",
  [sym_method_identifier] = "method_identifier",
  [sym_modport_identifier] = "modport_identifier",
  [sym_output_port_identifier] = "output_port_identifier",
  [sym_package_scope] = "package_scope",
  [sym_ps_identifier] = "ps_identifier",
  [sym_ps_or_hierarchical_array_identifier] = "ps_or_hierarchical_array_identifier",
  [sym__sequence_identifier] = "_sequence_identifier",
  [sym__signal_identifier] = "_signal_identifier",
  [sym_task_identifier] = "task_identifier",
  [sym_terminal_identifier] = "terminal_identifier",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_list_of_formal_arguments_repeat1] = "list_of_formal_arguments_repeat1",
  [aux_sym_list_of_actual_arguments_repeat1] = "list_of_actual_arguments_repeat1",
  [aux_sym__description_repeat1] = "_description_repeat1",
  [aux_sym_module_nonansi_header_repeat1] = "module_nonansi_header_repeat1",
  [aux_sym_module_declaration_repeat1] = "module_declaration_repeat1",
  [aux_sym_interface_declaration_repeat1] = "interface_declaration_repeat1",
  [aux_sym_interface_declaration_repeat2] = "interface_declaration_repeat2",
  [aux_sym_program_declaration_repeat1] = "program_declaration_repeat1",
  [aux_sym_program_declaration_repeat2] = "program_declaration_repeat2",
  [aux_sym_checker_declaration_repeat1] = "checker_declaration_repeat1",
  [aux_sym_class_declaration_repeat1] = "class_declaration_repeat1",
  [aux_sym_class_declaration_repeat2] = "class_declaration_repeat2",
  [aux_sym_interface_class_declaration_repeat1] = "interface_class_declaration_repeat1",
  [aux_sym_package_declaration_repeat1] = "package_declaration_repeat1",
  [aux_sym_parameter_port_list_repeat1] = "parameter_port_list_repeat1",
  [aux_sym_list_of_ports_repeat1] = "list_of_ports_repeat1",
  [aux_sym_list_of_port_declarations_repeat1] = "list_of_port_declarations_repeat1",
  [aux_sym__port_expression_repeat1] = "_port_expression_repeat1",
  [aux_sym_ansi_port_declaration_repeat1] = "ansi_port_declaration_repeat1",
  [aux_sym_ansi_port_declaration_repeat2] = "ansi_port_declaration_repeat2",
  [aux_sym_bind_target_instance_list_repeat1] = "bind_target_instance_list_repeat1",
  [aux_sym_checker_port_list_repeat1] = "checker_port_list_repeat1",
  [aux_sym_class_property_repeat1] = "class_property_repeat1",
  [aux_sym_class_property_repeat2] = "class_property_repeat2",
  [aux_sym_class_method_repeat1] = "class_method_repeat1",
  [aux_sym_class_constructor_declaration_repeat1] = "class_constructor_declaration_repeat1",
  [aux_sym_class_constructor_declaration_repeat2] = "class_constructor_declaration_repeat2",
  [aux_sym_constraint_block_repeat1] = "constraint_block_repeat1",
  [aux_sym_solve_before_list_repeat1] = "solve_before_list_repeat1",
  [aux_sym_constraint_set_repeat1] = "constraint_set_repeat1",
  [aux_sym_dist_list_repeat1] = "dist_list_repeat1",
  [aux_sym_identifier_list_repeat1] = "identifier_list_repeat1",
  [aux_sym_anonymous_program_repeat1] = "anonymous_program_repeat1",
  [aux_sym_package_import_declaration_repeat1] = "package_import_declaration_repeat1",
  [aux_sym_net_declaration_repeat1] = "net_declaration_repeat1",
  [aux_sym_data_type_repeat1] = "data_type_repeat1",
  [aux_sym_data_type_repeat2] = "data_type_repeat2",
  [aux_sym_data_type_repeat3] = "data_type_repeat3",
  [aux_sym_class_type_repeat1] = "class_type_repeat1",
  [aux_sym_list_of_defparam_assignments_repeat1] = "list_of_defparam_assignments_repeat1",
  [aux_sym_list_of_genvar_identifiers_repeat1] = "list_of_genvar_identifiers_repeat1",
  [aux_sym_list_of_interface_identifiers_repeat1] = "list_of_interface_identifiers_repeat1",
  [aux_sym_list_of_net_decl_assignments_repeat1] = "list_of_net_decl_assignments_repeat1",
  [aux_sym_list_of_param_assignments_repeat1] = "list_of_param_assignments_repeat1",
  [aux_sym_list_of_port_identifiers_repeat1] = "list_of_port_identifiers_repeat1",
  [aux_sym_list_of_udp_port_identifiers_repeat1] = "list_of_udp_port_identifiers_repeat1",
  [aux_sym_list_of_specparam_assignments_repeat1] = "list_of_specparam_assignments_repeat1",
  [aux_sym_list_of_tf_variable_identifiers_repeat1] = "list_of_tf_variable_identifiers_repeat1",
  [aux_sym_list_of_type_assignments_repeat1] = "list_of_type_assignments_repeat1",
  [aux_sym_list_of_variable_decl_assignments_repeat1] = "list_of_variable_decl_assignments_repeat1",
  [aux_sym_list_of_variable_identifiers_repeat1] = "list_of_variable_identifiers_repeat1",
  [aux_sym_list_of_variable_port_identifiers_repeat1] = "list_of_variable_port_identifiers_repeat1",
  [aux_sym_function_body_declaration_repeat1] = "function_body_declaration_repeat1",
  [aux_sym_task_body_declaration_repeat1] = "task_body_declaration_repeat1",
  [aux_sym_tf_port_list_repeat1] = "tf_port_list_repeat1",
  [aux_sym_overload_proto_formals_repeat1] = "overload_proto_formals_repeat1",
  [aux_sym_modport_declaration_repeat1] = "modport_declaration_repeat1",
  [aux_sym_modport_item_repeat1] = "modport_item_repeat1",
  [aux_sym_modport_simple_ports_declaration_repeat1] = "modport_simple_ports_declaration_repeat1",
  [aux_sym_modport_tf_ports_declaration_repeat1] = "modport_tf_ports_declaration_repeat1",
  [aux_sym_property_declaration_repeat1] = "property_declaration_repeat1",
  [aux_sym_property_port_list_repeat1] = "property_port_list_repeat1",
  [aux_sym_property_expr_repeat1] = "property_expr_repeat1",
  [aux_sym_property_case_item_repeat1] = "property_case_item_repeat1",
  [aux_sym_sequence_port_list_repeat1] = "sequence_port_list_repeat1",
  [aux_sym_sequence_expr_repeat1] = "sequence_expr_repeat1",
  [aux_sym_sequence_expr_repeat2] = "sequence_expr_repeat2",
  [aux_sym_sequence_expr_repeat3] = "sequence_expr_repeat3",
  [aux_sym_sequence_list_of_arguments_repeat1] = "sequence_list_of_arguments_repeat1",
  [aux_sym_covergroup_declaration_repeat1] = "covergroup_declaration_repeat1",
  [aux_sym_bins_or_empty_repeat1] = "bins_or_empty_repeat1",
  [aux_sym_trans_list_repeat1] = "trans_list_repeat1",
  [aux_sym_trans_set_repeat1] = "trans_set_repeat1",
  [aux_sym_list_of_cross_items_repeat1] = "list_of_cross_items_repeat1",
  [aux_sym_cross_body_repeat1] = "cross_body_repeat1",
  [aux_sym_covergroup_range_list_repeat1] = "covergroup_range_list_repeat1",
  [aux_sym_let_port_list_repeat1] = "let_port_list_repeat1",
  [aux_sym_let_list_of_arguments_repeat1] = "let_list_of_arguments_repeat1",
  [aux_sym_gate_instantiation_repeat1] = "gate_instantiation_repeat1",
  [aux_sym_gate_instantiation_repeat2] = "gate_instantiation_repeat2",
  [aux_sym_gate_instantiation_repeat3] = "gate_instantiation_repeat3",
  [aux_sym_gate_instantiation_repeat4] = "gate_instantiation_repeat4",
  [aux_sym_gate_instantiation_repeat5] = "gate_instantiation_repeat5",
  [aux_sym_gate_instantiation_repeat6] = "gate_instantiation_repeat6",
  [aux_sym_gate_instantiation_repeat7] = "gate_instantiation_repeat7",
  [aux_sym_gate_instantiation_repeat8] = "gate_instantiation_repeat8",
  [aux_sym_n_input_gate_instance_repeat1] = "n_input_gate_instance_repeat1",
  [aux_sym_n_output_gate_instance_repeat1] = "n_output_gate_instance_repeat1",
  [aux_sym_module_instantiation_repeat1] = "module_instantiation_repeat1",
  [aux_sym_list_of_parameter_assignments_repeat1] = "list_of_parameter_assignments_repeat1",
  [aux_sym_list_of_parameter_assignments_repeat2] = "list_of_parameter_assignments_repeat2",
  [aux_sym_list_of_port_connections_repeat1] = "list_of_port_connections_repeat1",
  [aux_sym_list_of_port_connections_repeat2] = "list_of_port_connections_repeat2",
  [aux_sym_checker_instantiation_repeat1] = "checker_instantiation_repeat1",
  [aux_sym_checker_instantiation_repeat2] = "checker_instantiation_repeat2",
  [aux_sym_generate_region_repeat1] = "generate_region_repeat1",
  [aux_sym_case_generate_construct_repeat1] = "case_generate_construct_repeat1",
  [aux_sym_case_generate_item_repeat1] = "case_generate_item_repeat1",
  [aux_sym_udp_declaration_repeat1] = "udp_declaration_repeat1",
  [aux_sym_udp_port_list_repeat1] = "udp_port_list_repeat1",
  [aux_sym_udp_declaration_port_list_repeat1] = "udp_declaration_port_list_repeat1",
  [aux_sym_combinational_body_repeat1] = "combinational_body_repeat1",
  [aux_sym_sequential_body_repeat1] = "sequential_body_repeat1",
  [aux_sym_level_input_list_repeat1] = "level_input_list_repeat1",
  [aux_sym_udp_instantiation_repeat1] = "udp_instantiation_repeat1",
  [aux_sym_list_of_net_assignments_repeat1] = "list_of_net_assignments_repeat1",
  [aux_sym_list_of_variable_assignments_repeat1] = "list_of_variable_assignments_repeat1",
  [aux_sym_net_alias_repeat1] = "net_alias_repeat1",
  [aux_sym_variable_identifier_list_repeat1] = "variable_identifier_list_repeat1",
  [aux_sym_wait_statement_repeat1] = "wait_statement_repeat1",
  [aux_sym_cond_predicate_repeat1] = "cond_predicate_repeat1",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_case_statement_repeat2] = "case_statement_repeat2",
  [aux_sym_case_statement_repeat3] = "case_statement_repeat3",
  [aux_sym_case_item_repeat1] = "case_item_repeat1",
  [aux_sym_randcase_statement_repeat1] = "randcase_statement_repeat1",
  [aux_sym_open_range_list_repeat1] = "open_range_list_repeat1",
  [aux_sym_pattern_repeat1] = "pattern_repeat1",
  [aux_sym_pattern_repeat2] = "pattern_repeat2",
  [aux_sym_assignment_pattern_repeat1] = "assignment_pattern_repeat1",
  [aux_sym_assignment_pattern_repeat2] = "assignment_pattern_repeat2",
  [aux_sym_assignment_pattern_net_lvalue_repeat1] = "assignment_pattern_net_lvalue_repeat1",
  [aux_sym_assignment_pattern_variable_lvalue_repeat1] = "assignment_pattern_variable_lvalue_repeat1",
  [aux_sym_for_initialization_repeat1] = "for_initialization_repeat1",
  [aux_sym_for_variable_declaration_repeat1] = "for_variable_declaration_repeat1",
  [aux_sym_for_step_repeat1] = "for_step_repeat1",
  [aux_sym_loop_variables1_repeat1] = "loop_variables1_repeat1",
  [aux_sym_clocking_declaration_repeat1] = "clocking_declaration_repeat1",
  [aux_sym_list_of_clocking_decl_assign_repeat1] = "list_of_clocking_decl_assign_repeat1",
  [aux_sym_specify_block_repeat1] = "specify_block_repeat1",
  [aux_sym_list_of_path_inputs_repeat1] = "list_of_path_inputs_repeat1",
  [aux_sym_list_of_path_outputs_repeat1] = "list_of_path_outputs_repeat1",
  [aux_sym_list_of_path_delay_expressions_repeat1] = "list_of_path_delay_expressions_repeat1",
  [aux_sym_edge_control_specifier_repeat1] = "edge_control_specifier_repeat1",
  [aux_sym_module_path_concatenation_repeat1] = "module_path_concatenation_repeat1",
  [aux_sym_stream_concatenation_repeat1] = "stream_concatenation_repeat1",
  [aux_sym_list_of_arguments_repeat1] = "list_of_arguments_repeat1",
  [aux_sym_list_of_arguments_parent_repeat1] = "list_of_arguments_parent_repeat1",
  [aux_sym_list_of_arguments_parent_repeat2] = "list_of_arguments_parent_repeat2",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_bit_select1_repeat1] = "bit_select1_repeat1",
  [aux_sym_select1_repeat1] = "select1_repeat1",
  [aux_sym_constant_bit_select1_repeat1] = "constant_bit_select1_repeat1",
  [aux_sym_constant_select1_repeat1] = "constant_select1_repeat1",
  [aux_sym_attribute_instance_repeat1] = "attribute_instance_repeat1",
  [aux_sym_hierarchical_identifier_repeat1] = "hierarchical_identifier_repeat1",
  [aux_sym_ps_parameter_identifier_repeat1] = "ps_parameter_identifier_repeat1",
  [alias_sym__ordered_parameter_assignment] = "_ordered_parameter_assignment",
  [alias_sym_checker_identifier] = "checker_identifier",
  [alias_sym_class_identifier] = "class_identifier",
  [alias_sym_cover_point_identifier] = "cover_point_identifier",
  [alias_sym_covergroup_identifier] = "covergroup_identifier",
  [alias_sym_cross_identifier] = "cross_identifier",
  [alias_sym_dynamic_array_variable_identifier] = "dynamic_array_variable_identifier",
  [alias_sym_enum_identifier] = "enum_identifier",
  [alias_sym_formal_port_identifier] = "formal_port_identifier",
  [alias_sym_genvar_identifier] = "genvar_identifier",
  [alias_sym_instance_identifier] = "instance_identifier",
  [alias_sym_interface_identifier] = "interface_identifier",
  [alias_sym_interface_instance_identifier] = "interface_instance_identifier",
  [alias_sym_member_identifier] = "member_identifier",
  [alias_sym_package_identifier] = "package_identifier",
  [alias_sym_parameter_identifier] = "parameter_identifier",
  [alias_sym_port_identifier] = "port_identifier",
  [alias_sym_program_identifier] = "program_identifier",
  [alias_sym_property_identifier] = "property_identifier",
  [alias_sym_specparam_identifier] = "specparam_identifier",
  [alias_sym_tf_identifier] = "tf_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_simple_identifier] = sym_simple_identifier,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_double_quoted_string_token1] = aux_sym_double_quoted_string_token1,
  [anon_sym_LT] = anon_sym_LT,
  [aux_sym_include_compiler_directive_standard_token1] = aux_sym_include_compiler_directive_standard_token1,
  [anon_sym_GT] = anon_sym_GT,
  [aux_sym_include_compiler_directive_token1] = aux_sym_include_compiler_directive_token1,
  [sym_default_text] = sym_default_text,
  [sym_macro_text] = sym_macro_text,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_text_macro_definition_token1] = aux_sym_text_macro_definition_token1,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [aux_sym_id_directive_token1] = aux_sym_id_directive_token1,
  [aux_sym_id_directive_token2] = aux_sym_id_directive_token2,
  [aux_sym_id_directive_token3] = aux_sym_id_directive_token3,
  [aux_sym_id_directive_token4] = aux_sym_id_directive_token4,
  [aux_sym_zero_directive_token1] = aux_sym_zero_directive_token1,
  [aux_sym_zero_directive_token2] = aux_sym_zero_directive_token2,
  [aux_sym_zero_directive_token3] = aux_sym_zero_directive_token3,
  [aux_sym_zero_directive_token4] = aux_sym_zero_directive_token4,
  [aux_sym_zero_directive_token5] = aux_sym_zero_directive_token5,
  [aux_sym_zero_directive_token6] = aux_sym_zero_directive_token6,
  [aux_sym_zero_directive_token7] = aux_sym_zero_directive_token7,
  [aux_sym_zero_directive_token8] = aux_sym_zero_directive_token8,
  [aux_sym_timescale_compiler_directive_token1] = aux_sym_timescale_compiler_directive_token1,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [aux_sym_default_nettype_compiler_directive_token1] = aux_sym_default_nettype_compiler_directive_token1,
  [anon_sym_wire] = anon_sym_wire,
  [anon_sym_tri] = anon_sym_tri,
  [anon_sym_tri0] = anon_sym_tri0,
  [anon_sym_tri1] = anon_sym_tri1,
  [anon_sym_wand] = anon_sym_wand,
  [anon_sym_triand] = anon_sym_triand,
  [anon_sym_wor] = anon_sym_wor,
  [anon_sym_trior] = anon_sym_trior,
  [anon_sym_trireg] = anon_sym_trireg,
  [anon_sym_uwire] = anon_sym_uwire,
  [anon_sym_none] = anon_sym_none,
  [aux_sym_unconnected_drive_token1] = aux_sym_unconnected_drive_token1,
  [anon_sym_pull0] = anon_sym_pull0,
  [anon_sym_pull1] = anon_sym_pull1,
  [aux_sym_line_compiler_directive_token1] = aux_sym_line_compiler_directive_token1,
  [aux_sym_begin_keywords_token1] = aux_sym_begin_keywords_token1,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_endmodule] = anon_sym_endmodule,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_extern] = anon_sym_extern,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_macromodule] = anon_sym_macromodule,
  [anon_sym_endinterface] = anon_sym_endinterface,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_endprogram] = anon_sym_endprogram,
  [anon_sym_program] = anon_sym_program,
  [anon_sym_checker] = anon_sym_checker,
  [anon_sym_endchecker] = anon_sym_endchecker,
  [anon_sym_virtual] = anon_sym_virtual,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_implements] = anon_sym_implements,
  [anon_sym_endclass] = anon_sym_endclass,
  [anon_sym_pure] = anon_sym_pure,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_endpackage] = anon_sym_endpackage,
  [anon_sym_timeunit] = anon_sym_timeunit,
  [anon_sym_timeprecision] = anon_sym_timeprecision,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_input] = anon_sym_input,
  [anon_sym_output] = anon_sym_output,
  [anon_sym_inout] = anon_sym_inout,
  [anon_sym_ref] = anon_sym_ref,
  [anon_sym_DOLLARfatal] = anon_sym_DOLLARfatal,
  [anon_sym_DOLLARerror] = anon_sym_DOLLARerror,
  [anon_sym_DOLLARwarning] = anon_sym_DOLLARwarning,
  [anon_sym_DOLLARinfo] = anon_sym_DOLLARinfo,
  [anon_sym_0] = anon_sym_0,
  [anon_sym_1] = anon_sym_1,
  [anon_sym_2] = anon_sym_2,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_clocking] = anon_sym_clocking,
  [anon_sym_disable] = anon_sym_disable,
  [anon_sym_iff] = anon_sym_iff,
  [anon_sym_defparam] = anon_sym_defparam,
  [anon_sym_bind] = anon_sym_bind,
  [anon_sym_forkjoin] = anon_sym_forkjoin,
  [anon_sym_rand] = anon_sym_rand,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_local] = anon_sym_local,
  [anon_sym_randc] = anon_sym_randc,
  [anon_sym_super] = anon_sym_super,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_constraint] = anon_sym_constraint,
  [anon_sym_solve] = anon_sym_solve,
  [anon_sym_before] = anon_sym_before,
  [anon_sym_soft] = anon_sym_soft,
  [anon_sym_u2013_GT] = anon_sym_u2013_GT,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_foreach] = anon_sym_foreach,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_unique] = anon_sym_unique,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_COLON_SLASH] = anon_sym_COLON_SLASH,
  [anon_sym_localparam] = anon_sym_localparam,
  [anon_sym_parameter] = anon_sym_parameter,
  [anon_sym_specparam] = anon_sym_specparam,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_STAR_COLON_COLON_STAR] = anon_sym_STAR_COLON_COLON_STAR,
  [anon_sym_genvar] = anon_sym_genvar,
  [anon_sym_vectored] = anon_sym_vectored,
  [anon_sym_scalared] = anon_sym_scalared,
  [anon_sym_interconnect] = anon_sym_interconnect,
  [anon_sym_typedef] = anon_sym_typedef,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_nettype] = anon_sym_nettype,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_automatic] = anon_sym_automatic,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_packed] = anon_sym_packed,
  [anon_sym_chandle] = anon_sym_chandle,
  [anon_sym_event] = anon_sym_event,
  [anon_sym_byte] = anon_sym_byte,
  [anon_sym_shortint] = anon_sym_shortint,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_longint] = anon_sym_longint,
  [anon_sym_integer] = anon_sym_integer,
  [anon_sym_time] = anon_sym_time,
  [anon_sym_bit] = anon_sym_bit,
  [anon_sym_logic] = anon_sym_logic,
  [anon_sym_reg] = anon_sym_reg,
  [anon_sym_shortreal] = anon_sym_shortreal,
  [anon_sym_real] = anon_sym_real,
  [anon_sym_realtime] = anon_sym_realtime,
  [anon_sym_supply0] = anon_sym_supply0,
  [anon_sym_supply1] = anon_sym_supply1,
  [anon_sym_signed] = anon_sym_signed,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_tagged] = anon_sym_tagged,
  [anon_sym_highz1] = anon_sym_highz1,
  [anon_sym_highz0] = anon_sym_highz0,
  [anon_sym_strong0] = anon_sym_strong0,
  [anon_sym_weak0] = anon_sym_weak0,
  [anon_sym_strong1] = anon_sym_strong1,
  [anon_sym_weak1] = anon_sym_weak1,
  [anon_sym_small] = anon_sym_small,
  [anon_sym_medium] = anon_sym_medium,
  [anon_sym_large] = anon_sym_large,
  [anon_sym_1step] = anon_sym_1step,
  [anon_sym_PATHPULSE_DOLLAR_EQ] = anon_sym_PATHPULSE_DOLLAR_EQ,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_task] = anon_sym_task,
  [anon_sym_DQUOTEDPI_DASHC_DQUOTE] = anon_sym_DQUOTEDPI_DASHC_DQUOTE,
  [anon_sym_DQUOTEDPI_DQUOTE] = anon_sym_DQUOTEDPI_DQUOTE,
  [anon_sym_context] = anon_sym_context,
  [anon_sym_endtask] = anon_sym_endtask,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_u2013] = anon_sym_u2013,
  [anon_sym_u2013u2013] = anon_sym_u2013u2013,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_modport] = anon_sym_modport,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_property] = anon_sym_property,
  [anon_sym_assume] = anon_sym_assume,
  [anon_sym_cover] = anon_sym_cover,
  [anon_sym_expect] = anon_sym_expect,
  [anon_sym_sequence] = anon_sym_sequence,
  [anon_sym_restrict] = anon_sym_restrict,
  [anon_sym_endproperty] = anon_sym_endproperty,
  [anon_sym_strong] = anon_sym_strong,
  [anon_sym_weak] = anon_sym_weak,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_PIPE_DASH_GT] = anon_sym_PIPE_DASH_GT,
  [anon_sym_PIPE_EQ_GT] = anon_sym_PIPE_EQ_GT,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_endcase] = anon_sym_endcase,
  [anon_sym_POUND_DASH_POUND] = anon_sym_POUND_DASH_POUND,
  [anon_sym_POUND_EQ_POUND] = anon_sym_POUND_EQ_POUND,
  [anon_sym_nexttime] = anon_sym_nexttime,
  [anon_sym_s_nexttime] = anon_sym_s_nexttime,
  [anon_sym_always] = anon_sym_always,
  [anon_sym_s_always] = anon_sym_s_always,
  [anon_sym_s_eventually] = anon_sym_s_eventually,
  [anon_sym_eventually] = anon_sym_eventually,
  [anon_sym_until] = anon_sym_until,
  [anon_sym_s_until] = anon_sym_s_until,
  [anon_sym_until_with] = anon_sym_until_with,
  [anon_sym_s_until_with] = anon_sym_s_until_with,
  [anon_sym_implies] = anon_sym_implies,
  [anon_sym_accept_on] = anon_sym_accept_on,
  [anon_sym_reject_on] = anon_sym_reject_on,
  [anon_sym_sync_accept_on] = anon_sym_sync_accept_on,
  [anon_sym_sync_reject_on] = anon_sym_sync_reject_on,
  [anon_sym_endsequence] = anon_sym_endsequence,
  [anon_sym_untyped] = anon_sym_untyped,
  [anon_sym_intersect] = anon_sym_intersect,
  [anon_sym_first_match] = anon_sym_first_match,
  [anon_sym_throughout] = anon_sym_throughout,
  [anon_sym_within] = anon_sym_within,
  [anon_sym_POUND_POUND] = anon_sym_POUND_POUND,
  [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = anon_sym_POUND_POUND_LBRACK_STAR_RBRACK,
  [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK,
  [anon_sym_LBRACK_STAR] = anon_sym_LBRACK_STAR,
  [anon_sym_LBRACK_STAR_RBRACK] = anon_sym_LBRACK_STAR_RBRACK,
  [anon_sym_LBRACK_PLUS_RBRACK] = anon_sym_LBRACK_PLUS_RBRACK,
  [anon_sym_LBRACK_EQ] = anon_sym_LBRACK_EQ,
  [anon_sym_LBRACK_DASH_GT] = anon_sym_LBRACK_DASH_GT,
  [anon_sym_dist] = anon_sym_dist,
  [anon_sym_covergroup] = anon_sym_covergroup,
  [anon_sym_endgroup] = anon_sym_endgroup,
  [anon_sym_option] = anon_sym_option,
  [anon_sym_type_option] = anon_sym_type_option,
  [anon_sym_sample] = anon_sym_sample,
  [anon_sym_AT_AT] = anon_sym_AT_AT,
  [anon_sym_begin] = anon_sym_begin,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_coverpoint] = anon_sym_coverpoint,
  [anon_sym_wildcard] = anon_sym_wildcard,
  [anon_sym_bins] = anon_sym_bins,
  [anon_sym_illegal_bins] = anon_sym_illegal_bins,
  [anon_sym_ignore_bins] = anon_sym_ignore_bins,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_LBRACKu2013_GT] = anon_sym_LBRACKu2013_GT,
  [anon_sym_cross] = anon_sym_cross,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_matches] = anon_sym_matches,
  [anon_sym_binsof] = anon_sym_binsof,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_pulldown] = anon_sym_pulldown,
  [anon_sym_pullup] = anon_sym_pullup,
  [anon_sym_cmos] = anon_sym_cmos,
  [anon_sym_rcmos] = anon_sym_rcmos,
  [anon_sym_bufif0] = anon_sym_bufif0,
  [anon_sym_bufif1] = anon_sym_bufif1,
  [anon_sym_notif0] = anon_sym_notif0,
  [anon_sym_notif1] = anon_sym_notif1,
  [anon_sym_nmos] = anon_sym_nmos,
  [anon_sym_pmos] = anon_sym_pmos,
  [anon_sym_rnmos] = anon_sym_rnmos,
  [anon_sym_rpmos] = anon_sym_rpmos,
  [anon_sym_nand] = anon_sym_nand,
  [anon_sym_nor] = anon_sym_nor,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_xnor] = anon_sym_xnor,
  [anon_sym_buf] = anon_sym_buf,
  [anon_sym_tranif0] = anon_sym_tranif0,
  [anon_sym_tranif1] = anon_sym_tranif1,
  [anon_sym_rtranif1] = anon_sym_rtranif1,
  [anon_sym_rtranif0] = anon_sym_rtranif0,
  [anon_sym_tran] = anon_sym_tran,
  [anon_sym_rtran] = anon_sym_rtran,
  [anon_sym_generate] = anon_sym_generate,
  [anon_sym_endgenerate] = anon_sym_endgenerate,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_primitive] = anon_sym_primitive,
  [anon_sym_endprimitive] = anon_sym_endprimitive,
  [anon_sym_table] = anon_sym_table,
  [anon_sym_endtable] = anon_sym_endtable,
  [anon_sym_initial] = anon_sym_initial,
  [anon_sym_1_SQUOTEb0] = anon_sym_1_SQUOTEb0,
  [anon_sym_1_SQUOTEb1] = anon_sym_1_SQUOTEb1,
  [anon_sym_1_SQUOTEbx] = anon_sym_1_SQUOTEbx,
  [anon_sym_1_SQUOTEbX] = anon_sym_1_SQUOTEbX,
  [anon_sym_1_SQUOTEB0] = anon_sym_1_SQUOTEB0,
  [anon_sym_1_SQUOTEB1] = anon_sym_1_SQUOTEB1,
  [anon_sym_1_SQUOTEBx] = anon_sym_1_SQUOTEBx,
  [anon_sym_1_SQUOTEBX] = anon_sym_1_SQUOTEBX,
  [anon_sym_DASH] = anon_sym_DASH,
  [sym_output_symbol] = sym_output_symbol,
  [sym_level_symbol] = sym_level_symbol,
  [sym_edge_symbol] = sym_edge_symbol,
  [anon_sym_assign] = anon_sym_assign,
  [anon_sym_alias] = anon_sym_alias,
  [anon_sym_always_comb] = anon_sym_always_comb,
  [anon_sym_always_latch] = anon_sym_always_latch,
  [anon_sym_always_ff] = anon_sym_always_ff,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_LT_LT_LT_EQ] = anon_sym_LT_LT_LT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_deassign] = anon_sym_deassign,
  [anon_sym_force] = anon_sym_force,
  [anon_sym_release] = anon_sym_release,
  [anon_sym_fork] = anon_sym_fork,
  [anon_sym_join] = anon_sym_join,
  [anon_sym_join_any] = anon_sym_join_any,
  [anon_sym_join_none] = anon_sym_join_none,
  [anon_sym_repeat] = anon_sym_repeat,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_AT_STAR] = anon_sym_AT_STAR,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_wait] = anon_sym_wait,
  [anon_sym_wait_order] = anon_sym_wait_order,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_DASH_GT_GT] = anon_sym_DASH_GT_GT,
  [anon_sym_unique0] = anon_sym_unique0,
  [anon_sym_priority] = anon_sym_priority,
  [anon_sym_AMP_AMP_AMP] = anon_sym_AMP_AMP_AMP,
  [anon_sym_inside] = anon_sym_inside,
  [anon_sym_casez] = anon_sym_casez,
  [anon_sym_casex] = anon_sym_casex,
  [anon_sym_randcase] = anon_sym_randcase,
  [anon_sym_SQUOTE_LBRACE] = anon_sym_SQUOTE_LBRACE,
  [anon_sym_forever] = anon_sym_forever,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_POUND0] = anon_sym_POUND0,
  [anon_sym_endclocking] = anon_sym_endclocking,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_specify] = anon_sym_specify,
  [anon_sym_endspecify] = anon_sym_endspecify,
  [anon_sym_pulsestyle_onevent] = anon_sym_pulsestyle_onevent,
  [anon_sym_pulsestyle_ondetect] = anon_sym_pulsestyle_ondetect,
  [anon_sym_showcancelled] = anon_sym_showcancelled,
  [anon_sym_noshowcancelled] = anon_sym_noshowcancelled,
  [anon_sym_STAR_GT] = anon_sym_STAR_GT,
  [anon_sym_posedge] = anon_sym_posedge,
  [anon_sym_negedge] = anon_sym_negedge,
  [anon_sym_edge] = anon_sym_edge,
  [anon_sym_ifnone] = anon_sym_ifnone,
  [anon_sym_DOLLARsetup] = anon_sym_DOLLARsetup,
  [anon_sym_DOLLARhold] = anon_sym_DOLLARhold,
  [anon_sym_DOLLARsetuphold] = anon_sym_DOLLARsetuphold,
  [anon_sym_DOLLARrecovery] = anon_sym_DOLLARrecovery,
  [anon_sym_DOLLARremoval] = anon_sym_DOLLARremoval,
  [anon_sym_DOLLARrecrem] = anon_sym_DOLLARrecrem,
  [anon_sym_DOLLARskew] = anon_sym_DOLLARskew,
  [anon_sym_DOLLARtimeskew] = anon_sym_DOLLARtimeskew,
  [anon_sym_DOLLARfullskew] = anon_sym_DOLLARfullskew,
  [anon_sym_DOLLARperiod] = anon_sym_DOLLARperiod,
  [anon_sym_DOLLARwidth] = anon_sym_DOLLARwidth,
  [anon_sym_DOLLARnochange] = anon_sym_DOLLARnochange,
  [anon_sym_01] = anon_sym_01,
  [anon_sym_10] = anon_sym_10,
  [aux_sym_edge_descriptor_token1] = aux_sym_edge_descriptor_token1,
  [aux_sym_edge_descriptor_token2] = aux_sym_edge_descriptor_token2,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_EQ_EQ_EQ] = anon_sym_EQ_EQ_EQ,
  [anon_sym_BANG_EQ_EQ] = anon_sym_BANG_EQ_EQ,
  [anon_sym_SQUOTEb0] = anon_sym_SQUOTEb0,
  [anon_sym_SQUOTEb1] = anon_sym_SQUOTEb1,
  [anon_sym_SQUOTEB0] = anon_sym_SQUOTEB0,
  [anon_sym_SQUOTEB1] = anon_sym_SQUOTEB1,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_PLUS_COLON] = anon_sym_PLUS_COLON,
  [anon_sym_DASH_COLON] = anon_sym_DASH_COLON,
  [anon_sym_std] = anon_sym_std,
  [anon_sym_randomize] = anon_sym_randomize,
  [anon_sym_null] = anon_sym_null,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_EQ_EQ_QMARK] = anon_sym_EQ_EQ_QMARK,
  [anon_sym_BANG_EQ_QMARK] = anon_sym_BANG_EQ_QMARK,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_CARET_TILDE] = anon_sym_CARET_TILDE,
  [anon_sym_TILDE_CARET] = anon_sym_TILDE_CARET,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_LT_LT_LT] = anon_sym_LT_LT_LT,
  [anon_sym_LT_DASH_GT] = anon_sym_LT_DASH_GT,
  [anon_sym_this] = anon_sym_this,
  [anon_sym_s] = anon_sym_s,
  [anon_sym_ms] = anon_sym_ms,
  [anon_sym_us] = anon_sym_us,
  [anon_sym_ns] = anon_sym_ns,
  [anon_sym_ps] = anon_sym_ps,
  [anon_sym_fs] = anon_sym_fs,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [aux_sym_string_literal_token2] = aux_sym_string_literal_token2,
  [aux_sym_string_literal_token3] = aux_sym_string_literal_token3,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_TILDE_AMP] = anon_sym_TILDE_AMP,
  [anon_sym_TILDE_PIPE] = anon_sym_TILDE_PIPE,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [aux_sym_decimal_number_token1] = aux_sym_decimal_number_token1,
  [aux_sym_decimal_number_token2] = aux_sym_decimal_number_token2,
  [sym_binary_number] = sym_binary_number,
  [sym_octal_number] = sym_octal_number,
  [sym_hex_number] = sym_hex_number,
  [aux_sym_real_number_token1] = aux_sym_real_number_token1,
  [sym_fixed_point_number] = sym_fixed_point_number,
  [sym_unsigned_number] = sym_unsigned_number,
  [anon_sym_SQUOTE0] = anon_sym_SQUOTE0,
  [anon_sym_SQUOTE1] = anon_sym_SQUOTE1,
  [aux_sym_unbased_unsized_literal_token1] = aux_sym_unbased_unsized_literal_token1,
  [anon_sym_LPAREN_STAR] = anon_sym_LPAREN_STAR,
  [anon_sym_STAR_RPAREN] = anon_sym_STAR_RPAREN,
  [sym_comment] = sym_comment,
  [sym_c_identifier] = sym_c_identifier,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [aux_sym_escaped_identifier_token1] = aux_sym_escaped_identifier_token1,
  [anon_sym_DOLLARroot] = anon_sym_DOLLARroot,
  [anon_sym_DOLLARunit] = anon_sym_DOLLARunit,
  [sym_system_tf_identifier] = sym_system_tf_identifier,
  [sym_source_file] = sym_source_file,
  [sym_double_quoted_string] = sym_double_quoted_string,
  [sym_include_compiler_directive_standard] = sym_include_compiler_directive_standard,
  [sym_include_compiler_directive] = sym_include_compiler_directive,
  [sym_text_macro_name] = sym_text_macro_name,
  [sym_list_of_formal_arguments] = sym_list_of_formal_arguments,
  [sym_formal_argument] = sym_formal_argument,
  [sym_text_macro_identifier] = sym_text_macro_identifier,
  [sym_text_macro_definition] = sym_text_macro_definition,
  [sym_text_macro_usage] = sym_text_macro_usage,
  [sym_simple_text_macro_usage] = sym_simple_text_macro_usage,
  [sym_id_directive] = sym_id_directive,
  [sym_zero_directive] = sym_zero_directive,
  [sym_timescale_compiler_directive] = sym_timescale_compiler_directive,
  [sym_default_nettype_compiler_directive] = sym_default_nettype_compiler_directive,
  [sym_default_nettype_value] = sym_default_nettype_value,
  [sym_unconnected_drive] = sym_unconnected_drive,
  [sym_line_compiler_directive] = sym_line_compiler_directive,
  [sym_begin_keywords] = sym_begin_keywords,
  [sym__directives] = sym__directives,
  [sym_list_of_actual_arguments] = sym_list_of_actual_arguments,
  [sym__actual_argument] = sym__actual_argument,
  [sym__description] = sym__description,
  [sym_module_header] = sym_module_header,
  [sym_module_nonansi_header] = sym_module_nonansi_header,
  [sym_module_ansi_header] = sym_module_ansi_header,
  [sym_module_declaration] = sym_module_declaration,
  [sym_module_keyword] = sym_module_keyword,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_interface_nonansi_header] = sym_interface_nonansi_header,
  [sym_interface_ansi_header] = sym_interface_ansi_header,
  [sym_program_declaration] = sym_program_declaration,
  [sym_program_nonansi_header] = sym_program_nonansi_header,
  [sym_program_ansi_header] = sym_program_ansi_header,
  [sym_checker_declaration] = sym_checker_declaration,
  [sym_class_declaration] = sym_class_declaration,
  [sym_interface_class_type] = sym_interface_class_type,
  [sym_interface_class_declaration] = sym_interface_class_declaration,
  [sym_interface_class_item] = sym_interface_class_item,
  [sym_interface_class_method] = sym_interface_class_method,
  [sym_package_declaration] = sym_package_declaration,
  [sym_timeunits_declaration] = sym_timeunits_declaration,
  [sym_parameter_port_list] = sym_parameter_port_list,
  [sym_parameter_port_declaration] = sym_parameter_port_declaration,
  [sym_list_of_ports] = sym_list_of_ports,
  [sym_list_of_port_declarations] = sym_list_of_port_declarations,
  [sym_port_declaration] = sym_port_declaration,
  [sym_port] = sym_port,
  [sym__port_expression] = sym__port_expression,
  [sym_port_reference] = sym_port_reference,
  [sym_port_direction] = sym_port_direction,
  [sym_net_port_header1] = sym_net_port_header1,
  [sym_variable_port_header] = sym_variable_port_header,
  [sym_interface_port_header] = sym_interface_port_header,
  [sym_ansi_port_declaration] = sym_ansi_port_declaration,
  [sym_elaboration_system_task] = sym_elaboration_system_task,
  [sym_finish_number] = sym_finish_number,
  [sym__module_common_item] = sym__module_common_item,
  [sym__module_item] = sym__module_item,
  [sym_module_or_generate_item] = sym_module_or_generate_item,
  [sym__module_or_generate_item_declaration] = sym__module_or_generate_item_declaration,
  [sym__non_port_module_item] = sym__non_port_module_item,
  [sym_parameter_override] = sym_parameter_override,
  [sym_bind_directive] = sym_bind_directive,
  [sym_bind_target_scope] = sym_bind_target_scope,
  [sym_bind_target_instance] = sym_bind_target_instance,
  [sym_bind_target_instance_list] = sym_bind_target_instance_list,
  [sym__bind_instantiation] = sym__bind_instantiation,
  [sym_interface_or_generate_item] = sym_interface_or_generate_item,
  [sym_extern_tf_declaration] = sym_extern_tf_declaration,
  [sym_interface_item] = sym_interface_item,
  [sym__non_port_interface_item] = sym__non_port_interface_item,
  [sym_program_item] = sym_program_item,
  [sym_non_port_program_item] = sym_non_port_program_item,
  [sym__program_generate_item] = sym__program_generate_item,
  [sym_checker_port_list] = sym_checker_port_list,
  [sym_checker_port_item] = sym_checker_port_item,
  [sym_checker_port_direction] = sym_checker_port_direction,
  [sym__checker_or_generate_item] = sym__checker_or_generate_item,
  [sym_checker_or_generate_item_declaration] = sym_checker_or_generate_item_declaration,
  [sym__checker_generate_item] = sym__checker_generate_item,
  [sym_class_item] = sym_class_item,
  [sym_class_property] = sym_class_property,
  [sym_class_method] = sym_class_method,
  [sym_class_constructor_prototype] = sym_class_constructor_prototype,
  [sym__class_constraint] = sym__class_constraint,
  [sym_class_item_qualifier] = sym_class_item_qualifier,
  [sym__property_qualifier] = sym__property_qualifier,
  [sym_random_qualifier] = sym_random_qualifier,
  [sym_method_qualifier] = sym_method_qualifier,
  [sym__method_prototype] = sym__method_prototype,
  [sym_class_constructor_declaration] = sym_class_constructor_declaration,
  [sym_constraint_declaration] = sym_constraint_declaration,
  [sym_constraint_block] = sym_constraint_block,
  [sym_constraint_block_item] = sym_constraint_block_item,
  [sym_solve_before_list] = sym_solve_before_list,
  [sym_constraint_primary] = sym_constraint_primary,
  [sym_constraint_expression] = sym_constraint_expression,
  [sym_uniqueness_constraint] = sym_uniqueness_constraint,
  [sym_constraint_set] = sym_constraint_set,
  [sym_dist_list] = sym_dist_list,
  [sym_dist_item] = sym_dist_item,
  [sym_dist_weight] = sym_dist_weight,
  [sym_constraint_prototype] = sym_constraint_prototype,
  [sym_constraint_prototype_qualifier] = sym_constraint_prototype_qualifier,
  [sym_extern_constraint_declaration] = sym_extern_constraint_declaration,
  [sym_identifier_list] = sym_identifier_list,
  [sym__package_item] = sym__package_item,
  [sym_package_or_generate_item_declaration] = sym_package_or_generate_item_declaration,
  [sym_anonymous_program] = sym_anonymous_program,
  [sym_anonymous_program_item] = sym_anonymous_program_item,
  [sym_local_parameter_declaration] = sym_local_parameter_declaration,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym__any_parameter_declaration] = sym__any_parameter_declaration,
  [sym_specparam_declaration] = sym_specparam_declaration,
  [sym_inout_declaration] = sym_inout_declaration,
  [sym_input_declaration] = sym_input_declaration,
  [sym_output_declaration] = sym_output_declaration,
  [sym_interface_port_declaration] = sym_interface_port_declaration,
  [sym_ref_declaration] = sym_ref_declaration,
  [sym_data_declaration] = sym_data_declaration,
  [sym_package_import_declaration] = sym_package_import_declaration,
  [sym_package_import_item] = sym_package_import_item,
  [sym_package_export_declaration] = sym_package_export_declaration,
  [sym_genvar_declaration] = sym_genvar_declaration,
  [sym_net_declaration] = sym_net_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_net_type_declaration] = sym_net_type_declaration,
  [sym_lifetime] = sym_lifetime,
  [sym_casting_type] = sym_casting_type,
  [sym_data_type] = sym_data_type,
  [sym_data_type_or_implicit1] = sym_data_type_or_implicit1,
  [sym_implicit_data_type1] = sym_implicit_data_type1,
  [sym_enum_base_type] = sym_enum_base_type,
  [sym_enum_name_declaration] = sym_enum_name_declaration,
  [sym_class_scope] = sym_class_scope,
  [sym_class_type] = sym_class_type,
  [sym__integer_type] = sym__integer_type,
  [sym_integer_atom_type] = sym_integer_atom_type,
  [sym_integer_vector_type] = sym_integer_vector_type,
  [sym_non_integer_type] = sym_non_integer_type,
  [sym_net_type] = sym_net_type,
  [sym_net_port_type1] = sym_net_port_type1,
  [sym__variable_port_type] = sym__variable_port_type,
  [sym__var_data_type] = sym__var_data_type,
  [sym__signing] = sym__signing,
  [sym__simple_type] = sym__simple_type,
  [sym_struct_union_member] = sym_struct_union_member,
  [sym_data_type_or_void] = sym_data_type_or_void,
  [sym_struct_union] = sym_struct_union,
  [sym_type_reference] = sym_type_reference,
  [sym_drive_strength] = sym_drive_strength,
  [sym_strength0] = sym_strength0,
  [sym_strength1] = sym_strength1,
  [sym_charge_strength] = sym_charge_strength,
  [sym_delay3] = sym_delay3,
  [sym_delay2] = sym_delay2,
  [sym_delay_value] = sym_delay_value,
  [sym_list_of_defparam_assignments] = sym_list_of_defparam_assignments,
  [sym_list_of_genvar_identifiers] = sym_list_of_genvar_identifiers,
  [sym_list_of_interface_identifiers] = sym_list_of_interface_identifiers,
  [sym_list_of_net_decl_assignments] = sym_list_of_net_decl_assignments,
  [sym_list_of_param_assignments] = sym_list_of_param_assignments,
  [sym_list_of_port_identifiers] = sym_list_of_port_identifiers,
  [sym_list_of_udp_port_identifiers] = sym_list_of_udp_port_identifiers,
  [sym_list_of_specparam_assignments] = sym_list_of_specparam_assignments,
  [sym_list_of_tf_variable_identifiers] = sym_list_of_tf_variable_identifiers,
  [sym_list_of_type_assignments] = sym_list_of_type_assignments,
  [sym_list_of_variable_decl_assignments] = sym_list_of_variable_decl_assignments,
  [sym_list_of_variable_identifiers] = sym_list_of_variable_identifiers,
  [sym_list_of_variable_port_identifiers] = sym_list_of_variable_port_identifiers,
  [sym_defparam_assignment] = sym_defparam_assignment,
  [sym_net_decl_assignment] = sym_net_decl_assignment,
  [sym_param_assignment] = sym_param_assignment,
  [sym_specparam_assignment] = sym_specparam_assignment,
  [sym_type_assignment] = sym_type_assignment,
  [sym_pulse_control_specparam] = sym_pulse_control_specparam,
  [sym_error_limit_value] = sym_error_limit_value,
  [sym_reject_limit_value] = sym_reject_limit_value,
  [sym_limit_value] = sym_limit_value,
  [sym_variable_decl_assignment] = sym_variable_decl_assignment,
  [sym_class_new] = sym_class_new,
  [sym_dynamic_array_new] = sym_dynamic_array_new,
  [sym_unpacked_dimension] = sym_unpacked_dimension,
  [sym_packed_dimension] = sym_packed_dimension,
  [sym_associative_dimension] = sym_associative_dimension,
  [sym__variable_dimension] = sym__variable_dimension,
  [sym_queue_dimension] = sym_queue_dimension,
  [sym_unsized_dimension] = sym_unsized_dimension,
  [sym_function_data_type_or_implicit1] = sym_function_data_type_or_implicit1,
  [sym_function_declaration] = sym_function_declaration,
  [sym_function_body_declaration] = sym_function_body_declaration,
  [sym_function_prototype] = sym_function_prototype,
  [sym_dpi_import_export] = sym_dpi_import_export,
  [sym_dpi_spec_string] = sym_dpi_spec_string,
  [sym_dpi_function_import_property] = sym_dpi_function_import_property,
  [sym_dpi_task_import_property] = sym_dpi_task_import_property,
  [sym_dpi_function_proto] = sym_dpi_function_proto,
  [sym_dpi_task_proto] = sym_dpi_task_proto,
  [sym_task_declaration] = sym_task_declaration,
  [sym_task_body_declaration] = sym_task_body_declaration,
  [sym_tf_item_declaration] = sym_tf_item_declaration,
  [sym_tf_port_list] = sym_tf_port_list,
  [sym_tf_port_item1] = sym_tf_port_item1,
  [sym_tf_port_direction] = sym_tf_port_direction,
  [sym_tf_port_declaration] = sym_tf_port_declaration,
  [sym_task_prototype] = sym_task_prototype,
  [sym_block_item_declaration] = sym_block_item_declaration,
  [sym_overload_declaration] = sym_overload_declaration,
  [sym_overload_operator] = sym_overload_operator,
  [sym_overload_proto_formals] = sym_overload_proto_formals,
  [sym_modport_declaration] = sym_modport_declaration,
  [sym_modport_item] = sym_modport_item,
  [sym_modport_ports_declaration] = sym_modport_ports_declaration,
  [sym_modport_clocking_declaration] = sym_modport_clocking_declaration,
  [sym_modport_simple_ports_declaration] = sym_modport_simple_ports_declaration,
  [sym_modport_simple_port] = sym_modport_simple_port,
  [sym_modport_tf_ports_declaration] = sym_modport_tf_ports_declaration,
  [sym__modport_tf_port] = sym__modport_tf_port,
  [sym_import_export] = sym_import_export,
  [sym_concurrent_assertion_item] = sym_concurrent_assertion_item,
  [sym__concurrent_assertion_statement] = sym__concurrent_assertion_statement,
  [sym_assert_property_statement] = sym_assert_property_statement,
  [sym_assume_property_statement] = sym_assume_property_statement,
  [sym_cover_property_statement] = sym_cover_property_statement,
  [sym_expect_property_statement] = sym_expect_property_statement,
  [sym_cover_sequence_statement] = sym_cover_sequence_statement,
  [sym_restrict_property_statement] = sym_restrict_property_statement,
  [sym__property_actual_arg] = sym__property_actual_arg,
  [sym__assertion_item_declaration] = sym__assertion_item_declaration,
  [sym_property_declaration] = sym_property_declaration,
  [sym_property_port_list] = sym_property_port_list,
  [sym_property_port_item] = sym_property_port_item,
  [sym_property_lvar_port_direction] = sym_property_lvar_port_direction,
  [sym_property_formal_type1] = sym_property_formal_type1,
  [sym_property_spec] = sym_property_spec,
  [sym_property_expr] = sym_property_expr,
  [sym_property_case_item] = sym_property_case_item,
  [sym_sequence_declaration] = sym_sequence_declaration,
  [sym_sequence_port_list] = sym_sequence_port_list,
  [sym_sequence_port_item] = sym_sequence_port_item,
  [sym_sequence_lvar_port_direction] = sym_sequence_lvar_port_direction,
  [sym_sequence_formal_type1] = sym_sequence_formal_type1,
  [sym_sequence_expr] = sym_sequence_expr,
  [sym_cycle_delay_range] = sym_cycle_delay_range,
  [sym_sequence_method_call] = sym_sequence_method_call,
  [sym__sequence_match_item] = sym__sequence_match_item,
  [sym_sequence_instance] = sym_sequence_instance,
  [sym_sequence_list_of_arguments] = sym_sequence_list_of_arguments,
  [sym__sequence_actual_arg] = sym__sequence_actual_arg,
  [sym__boolean_abbrev] = sym__boolean_abbrev,
  [sym_sequence_abbrev] = sym_sequence_abbrev,
  [sym_consecutive_repetition] = sym_consecutive_repetition,
  [sym_non_consecutive_repetition] = sym_non_consecutive_repetition,
  [sym_goto_repetition] = sym_goto_repetition,
  [sym__const_or_range_expression] = sym__const_or_range_expression,
  [sym_cycle_delay_const_range_expression] = sym_cycle_delay_const_range_expression,
  [sym_expression_or_dist] = sym_expression_or_dist,
  [sym_assertion_variable_declaration] = sym_assertion_variable_declaration,
  [sym_covergroup_declaration] = sym_covergroup_declaration,
  [sym_coverage_spec_or_option] = sym_coverage_spec_or_option,
  [sym_coverage_option] = sym_coverage_option,
  [sym__coverage_spec] = sym__coverage_spec,
  [sym_coverage_event] = sym_coverage_event,
  [sym_block_event_expression] = sym_block_event_expression,
  [sym_hierarchical_btf_identifier] = sym_hierarchical_btf_identifier,
  [sym_cover_point] = sym_cover_point,
  [sym_bins_or_empty] = sym_bins_or_empty,
  [sym_bins_or_options] = sym_bins_or_options,
  [sym_bins_keyword] = sym_bins_keyword,
  [sym_trans_list] = sym_trans_list,
  [sym_trans_set] = sym_trans_set,
  [sym_trans_range_list] = sym_trans_range_list,
  [sym_trans_item] = sym_trans_item,
  [sym_repeat_range] = sym_repeat_range,
  [sym_cover_cross] = sym_cover_cross,
  [sym_list_of_cross_items] = sym_list_of_cross_items,
  [sym__cross_item] = sym__cross_item,
  [sym_cross_body] = sym_cross_body,
  [sym_cross_body_item] = sym_cross_body_item,
  [sym_bins_selection_or_option] = sym_bins_selection_or_option,
  [sym_bins_selection] = sym_bins_selection,
  [sym_select_expression] = sym_select_expression,
  [sym_select_condition] = sym_select_condition,
  [sym_bins_expression] = sym_bins_expression,
  [sym_covergroup_range_list] = sym_covergroup_range_list,
  [sym_covergroup_value_range] = sym_covergroup_value_range,
  [sym__with_covergroup_expression] = sym__with_covergroup_expression,
  [sym__set_covergroup_expression] = sym__set_covergroup_expression,
  [sym__integer_covergroup_expression] = sym__integer_covergroup_expression,
  [sym__cross_set_expression] = sym__cross_set_expression,
  [sym__covergroup_expression] = sym__covergroup_expression,
  [sym_let_declaration] = sym_let_declaration,
  [sym_let_port_list] = sym_let_port_list,
  [sym_let_port_item] = sym_let_port_item,
  [sym_let_formal_type1] = sym_let_formal_type1,
  [sym_let_expression] = sym_let_expression,
  [sym_let_list_of_arguments] = sym_let_list_of_arguments,
  [sym_let_actual_arg] = sym_let_actual_arg,
  [sym_gate_instantiation] = sym_gate_instantiation,
  [sym_cmos_switch_instance] = sym_cmos_switch_instance,
  [sym_enable_gate_instance] = sym_enable_gate_instance,
  [sym_mos_switch_instance] = sym_mos_switch_instance,
  [sym_n_input_gate_instance] = sym_n_input_gate_instance,
  [sym_n_output_gate_instance] = sym_n_output_gate_instance,
  [sym_pass_switch_instance] = sym_pass_switch_instance,
  [sym_pass_enable_switch_instance] = sym_pass_enable_switch_instance,
  [sym_pull_gate_instance] = sym_pull_gate_instance,
  [sym_pulldown_strength] = sym_pulldown_strength,
  [sym_pullup_strength] = sym_pullup_strength,
  [sym_enable_terminal] = sym_enable_terminal,
  [sym_inout_terminal] = sym_inout_terminal,
  [sym_input_terminal] = sym_input_terminal,
  [sym_ncontrol_terminal] = sym_ncontrol_terminal,
  [sym_output_terminal] = sym_output_terminal,
  [sym_pcontrol_terminal] = sym_pcontrol_terminal,
  [sym_cmos_switchtype] = sym_cmos_switchtype,
  [sym_enable_gatetype] = sym_enable_gatetype,
  [sym_mos_switchtype] = sym_mos_switchtype,
  [sym_n_input_gatetype] = sym_n_input_gatetype,
  [sym_n_output_gatetype] = sym_n_output_gatetype,
  [sym_pass_en_switchtype] = sym_pass_en_switchtype,
  [sym_pass_switchtype] = sym_pass_switchtype,
  [sym_module_instantiation] = sym_module_instantiation,
  [sym_parameter_value_assignment] = sym_parameter_value_assignment,
  [sym_list_of_parameter_assignments] = sym_list_of_parameter_assignments,
  [sym_ordered_parameter_assignment] = sym_ordered_parameter_assignment,
  [sym_named_parameter_assignment] = sym_named_parameter_assignment,
  [sym_hierarchical_instance] = sym_hierarchical_instance,
  [sym_name_of_instance] = sym_name_of_instance,
  [sym_list_of_port_connections] = sym_list_of_port_connections,
  [sym_ordered_port_connection] = sym_ordered_port_connection,
  [sym_named_port_connection] = sym_named_port_connection,
  [sym_interface_instantiation] = sym_interface_instantiation,
  [sym_program_instantiation] = sym_program_instantiation,
  [sym_checker_instantiation] = sym_checker_instantiation,
  [sym_generate_region] = sym_generate_region,
  [sym_loop_generate_construct] = sym_loop_generate_construct,
  [sym_genvar_initialization] = sym_genvar_initialization,
  [sym_genvar_iteration] = sym_genvar_iteration,
  [sym__conditional_generate_construct] = sym__conditional_generate_construct,
  [sym_if_generate_construct] = sym_if_generate_construct,
  [sym_case_generate_construct] = sym_case_generate_construct,
  [sym_case_generate_item] = sym_case_generate_item,
  [sym_generate_block] = sym_generate_block,
  [sym__generate_item] = sym__generate_item,
  [sym_udp_nonansi_declaration] = sym_udp_nonansi_declaration,
  [sym_udp_ansi_declaration] = sym_udp_ansi_declaration,
  [sym_udp_declaration] = sym_udp_declaration,
  [sym_udp_port_list] = sym_udp_port_list,
  [sym_udp_declaration_port_list] = sym_udp_declaration_port_list,
  [sym_udp_port_declaration] = sym_udp_port_declaration,
  [sym_udp_output_declaration] = sym_udp_output_declaration,
  [sym_udp_input_declaration] = sym_udp_input_declaration,
  [sym_udp_reg_declaration] = sym_udp_reg_declaration,
  [sym__udp_body] = sym__udp_body,
  [sym_combinational_body] = sym_combinational_body,
  [sym_combinational_entry] = sym_combinational_entry,
  [sym_sequential_body] = sym_sequential_body,
  [sym_udp_initial_statement] = sym_udp_initial_statement,
  [sym_init_val] = sym_init_val,
  [sym_sequential_entry] = sym_sequential_entry,
  [sym__seq_input_list] = sym__seq_input_list,
  [sym_level_input_list] = sym_level_input_list,
  [sym_edge_input_list] = sym_edge_input_list,
  [sym_edge_indicator] = sym_edge_indicator,
  [sym__current_state] = sym__current_state,
  [sym_next_state] = sym_next_state,
  [sym_udp_instantiation] = sym_udp_instantiation,
  [sym_udp_instance] = sym_udp_instance,
  [sym_continuous_assign] = sym_continuous_assign,
  [sym_list_of_net_assignments] = sym_list_of_net_assignments,
  [sym_list_of_variable_assignments] = sym_list_of_variable_assignments,
  [sym_net_alias] = sym_net_alias,
  [sym_net_assignment] = sym_net_assignment,
  [sym_initial_construct] = sym_initial_construct,
  [sym_always_construct] = sym_always_construct,
  [sym_always_keyword] = sym_always_keyword,
  [sym_final_construct] = sym_final_construct,
  [sym_blocking_assignment] = sym_blocking_assignment,
  [sym_operator_assignment] = sym_operator_assignment,
  [sym_assignment_operator] = sym_assignment_operator,
  [sym_nonblocking_assignment] = sym_nonblocking_assignment,
  [sym_procedural_continuous_assignment] = sym_procedural_continuous_assignment,
  [sym_variable_assignment] = sym_variable_assignment,
  [sym_action_block] = sym_action_block,
  [sym_seq_block] = sym_seq_block,
  [sym_par_block] = sym_par_block,
  [sym_join_keyword] = sym_join_keyword,
  [sym_statement_or_null] = sym_statement_or_null,
  [sym_statement] = sym_statement,
  [sym_statement_item] = sym_statement_item,
  [sym_function_statement] = sym_function_statement,
  [sym_function_statement_or_null] = sym_function_statement_or_null,
  [sym_variable_identifier_list] = sym_variable_identifier_list,
  [sym_procedural_timing_control_statement] = sym_procedural_timing_control_statement,
  [sym_delay_or_event_control] = sym_delay_or_event_control,
  [sym_delay_control] = sym_delay_control,
  [sym_event_control] = sym_event_control,
  [sym_event_expression] = sym_event_expression,
  [sym__procedural_timing_control] = sym__procedural_timing_control,
  [sym_jump_statement] = sym_jump_statement,
  [sym_wait_statement] = sym_wait_statement,
  [sym_event_trigger] = sym_event_trigger,
  [sym_disable_statement] = sym_disable_statement,
  [sym_conditional_statement] = sym_conditional_statement,
  [sym_unique_priority] = sym_unique_priority,
  [sym_cond_predicate] = sym_cond_predicate,
  [sym__expression_or_cond_pattern] = sym__expression_or_cond_pattern,
  [sym_cond_pattern] = sym_cond_pattern,
  [sym_case_statement] = sym_case_statement,
  [sym_case_keyword] = sym_case_keyword,
  [sym_case_expression] = sym_case_expression,
  [sym_case_item] = sym_case_item,
  [sym_case_pattern_item] = sym_case_pattern_item,
  [sym_case_inside_item] = sym_case_inside_item,
  [sym_case_item_expression] = sym_case_item_expression,
  [sym_randcase_statement] = sym_randcase_statement,
  [sym_randcase_item] = sym_randcase_item,
  [sym_open_range_list] = sym_open_range_list,
  [sym_open_value_range] = sym_open_value_range,
  [sym_pattern] = sym_pattern,
  [sym_assignment_pattern] = sym_assignment_pattern,
  [sym__array_pattern_key] = sym__array_pattern_key,
  [sym_assignment_pattern_key] = sym_assignment_pattern_key,
  [sym_assignment_pattern_expression] = sym_assignment_pattern_expression,
  [sym__assignment_pattern_expression_type] = sym__assignment_pattern_expression_type,
  [sym_assignment_pattern_net_lvalue] = sym_assignment_pattern_net_lvalue,
  [sym_assignment_pattern_variable_lvalue] = sym_assignment_pattern_variable_lvalue,
  [sym_loop_statement] = sym_loop_statement,
  [sym_for_initialization] = sym_for_initialization,
  [sym_for_variable_declaration] = sym_for_variable_declaration,
  [sym_for_step] = sym_for_step,
  [sym__for_step_assignment] = sym__for_step_assignment,
  [sym_loop_variables1] = sym_loop_variables1,
  [sym__assertion_item] = sym__assertion_item,
  [sym_deferred_immediate_assertion_item] = sym_deferred_immediate_assertion_item,
  [sym__procedural_assertion_statement] = sym__procedural_assertion_statement,
  [sym__immediate_assertion_statement] = sym__immediate_assertion_statement,
  [sym__simple_immediate_assertion_statement] = sym__simple_immediate_assertion_statement,
  [sym_simple_immediate_assert_statement] = sym_simple_immediate_assert_statement,
  [sym_simple_immediate_assume_statement] = sym_simple_immediate_assume_statement,
  [sym_simple_immediate_cover_statement] = sym_simple_immediate_cover_statement,
  [sym__deferred_immediate_assertion_statement] = sym__deferred_immediate_assertion_statement,
  [sym_deferred_immediate_assert_statement] = sym_deferred_immediate_assert_statement,
  [sym_deferred_immediate_assume_statement] = sym_deferred_immediate_assume_statement,
  [sym_deferred_immediate_cover_statement] = sym_deferred_immediate_cover_statement,
  [sym_clocking_declaration] = sym_clocking_declaration,
  [sym_clocking_event] = sym_clocking_event,
  [sym_clocking_item] = sym_clocking_item,
  [sym_default_skew] = sym_default_skew,
  [sym_clocking_direction] = sym_clocking_direction,
  [sym_list_of_clocking_decl_assign] = sym_list_of_clocking_decl_assign,
  [sym_clocking_decl_assign] = sym_clocking_decl_assign,
  [sym_clocking_skew] = sym_clocking_skew,
  [sym_clocking_drive] = sym_clocking_drive,
  [sym_cycle_delay] = sym_cycle_delay,
  [sym_clockvar] = sym_clockvar,
  [sym_clockvar_expression] = sym_clockvar_expression,
  [sym_specify_block] = sym_specify_block,
  [sym__specify_item] = sym__specify_item,
  [sym_pulsestyle_declaration] = sym_pulsestyle_declaration,
  [sym_showcancelled_declaration] = sym_showcancelled_declaration,
  [sym_path_declaration] = sym_path_declaration,
  [sym_simple_path_declaration] = sym_simple_path_declaration,
  [sym_parallel_path_description] = sym_parallel_path_description,
  [sym_full_path_description] = sym_full_path_description,
  [sym_list_of_path_inputs] = sym_list_of_path_inputs,
  [sym_list_of_path_outputs] = sym_list_of_path_outputs,
  [sym_specify_input_terminal_descriptor] = sym_specify_input_terminal_descriptor,
  [sym_specify_output_terminal_descriptor] = sym_specify_output_terminal_descriptor,
  [sym_input_identifier] = sym_input_identifier,
  [sym_output_identifier] = sym_output_identifier,
  [sym_path_delay_value] = sym_path_delay_value,
  [sym_list_of_path_delay_expressions] = sym_list_of_path_delay_expressions,
  [sym_path_delay_expression] = sym_path_delay_expression,
  [sym_edge_sensitive_path_declaration] = sym_edge_sensitive_path_declaration,
  [sym_parallel_edge_sensitive_path_description] = sym_parallel_edge_sensitive_path_description,
  [sym_full_edge_sensitive_path_description] = sym_full_edge_sensitive_path_description,
  [sym_data_source_expression] = sym_data_source_expression,
  [sym_edge_identifier] = sym_edge_identifier,
  [sym_state_dependent_path_declaration] = sym_state_dependent_path_declaration,
  [sym_polarity_operator] = sym_polarity_operator,
  [sym__system_timing_check] = sym__system_timing_check,
  [sym_DOLLARsetup_timing_check] = sym_DOLLARsetup_timing_check,
  [sym_DOLLARhold_timing_check] = sym_DOLLARhold_timing_check,
  [sym_DOLLARsetuphold_timing_check] = sym_DOLLARsetuphold_timing_check,
  [sym_DOLLARrecovery_timing_check] = sym_DOLLARrecovery_timing_check,
  [sym_DOLLARremoval_timing_check] = sym_DOLLARremoval_timing_check,
  [sym_DOLLARrecrem_timing_check] = sym_DOLLARrecrem_timing_check,
  [sym_DOLLARskew_timing_check] = sym_DOLLARskew_timing_check,
  [sym_DOLLARtimeskew_timing_check] = sym_DOLLARtimeskew_timing_check,
  [sym_DOLLARfullskew_timing_check] = sym_DOLLARfullskew_timing_check,
  [sym_DOLLARperiod_timing_check] = sym_DOLLARperiod_timing_check,
  [sym_DOLLARwidth_timing_check] = sym_DOLLARwidth_timing_check,
  [sym_DOLLARnochange_timing_check] = sym_DOLLARnochange_timing_check,
  [sym_timecheck_condition] = sym_timecheck_condition,
  [sym_controlled_reference_event] = sym_controlled_reference_event,
  [sym_data_event] = sym_data_event,
  [sym_delayed_data] = sym_delayed_data,
  [sym_delayed_reference] = sym_delayed_reference,
  [sym_end_edge_offset] = sym_end_edge_offset,
  [sym_event_based_flag] = sym_event_based_flag,
  [sym_notifier] = sym_notifier,
  [sym_reference_event] = sym_reference_event,
  [sym_remain_active_flag] = sym_remain_active_flag,
  [sym_timestamp_condition] = sym_timestamp_condition,
  [sym_start_edge_offset] = sym_start_edge_offset,
  [sym_threshold] = sym_threshold,
  [sym_timing_check_limit] = sym_timing_check_limit,
  [sym_timing_check_event] = sym_timing_check_event,
  [sym_controlled_timing_check_event] = sym_controlled_reference_event,
  [sym_timing_check_event_control] = sym_timing_check_event_control,
  [sym__specify_terminal_descriptor] = sym__specify_terminal_descriptor,
  [sym_edge_control_specifier] = sym_edge_control_specifier,
  [sym_edge_descriptor] = sym_edge_descriptor,
  [sym_timing_check_condition] = sym_timing_check_condition,
  [sym_scalar_timing_check_condition] = sym_scalar_timing_check_condition,
  [sym_scalar_constant] = sym_scalar_constant,
  [sym_concatenation] = sym_concatenation,
  [sym_constant_concatenation] = sym_constant_concatenation,
  [sym_constant_multiple_concatenation] = sym_constant_multiple_concatenation,
  [sym_module_path_concatenation] = sym_module_path_concatenation,
  [sym_module_path_multiple_concatenation] = sym_module_path_multiple_concatenation,
  [sym_multiple_concatenation] = sym_multiple_concatenation,
  [sym_streaming_concatenation] = sym_streaming_concatenation,
  [sym_stream_operator] = sym_stream_operator,
  [sym_slice_size] = sym_slice_size,
  [sym_stream_concatenation] = sym_stream_concatenation,
  [sym_stream_expression] = sym_stream_expression,
  [sym_array_range_expression] = sym_array_range_expression,
  [sym_empty_unpacked_array_concatenation] = sym_empty_unpacked_array_concatenation,
  [sym_tf_call] = sym_tf_call,
  [sym_system_tf_call] = sym_system_tf_call,
  [sym_subroutine_call] = sym_subroutine_call,
  [sym_function_subroutine_call] = sym_function_subroutine_call,
  [sym_list_of_arguments] = sym_list_of_arguments,
  [sym_list_of_arguments_parent] = sym_list_of_arguments_parent,
  [sym_method_call] = sym_method_call,
  [sym_method_call_body] = sym_method_call_body,
  [sym__built_in_method_call] = sym__built_in_method_call,
  [sym_array_manipulation_call] = sym_array_manipulation_call,
  [sym_randomize_call] = sym_randomize_call,
  [sym__method_call_root] = sym__method_call_root,
  [sym_array_method_name] = sym_array_method_name,
  [sym_inc_or_dec_expression] = sym_inc_or_dec_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_constant_expression] = sym_constant_expression,
  [sym_constant_mintypmax_expression] = sym_constant_mintypmax_expression,
  [sym_constant_param_expression] = sym_constant_param_expression,
  [sym_param_expression] = sym_param_expression,
  [sym__constant_range_expression] = sym__constant_range_expression,
  [sym__constant_part_select_range] = sym__constant_part_select_range,
  [sym_constant_range] = sym_constant_range,
  [sym_constant_indexed_range] = sym_constant_indexed_range,
  [sym_expression] = sym_expression,
  [sym_tagged_union_expression] = sym_tagged_union_expression,
  [sym_inside_expression] = sym_inside_expression,
  [sym_value_range] = sym_value_range,
  [sym_mintypmax_expression] = sym_mintypmax_expression,
  [sym_module_path_expression] = sym_module_path_expression,
  [sym_module_path_mintypmax_expression] = sym_module_path_mintypmax_expression,
  [sym__part_select_range] = sym__part_select_range,
  [sym_indexed_range] = sym_indexed_range,
  [sym__genvar_expression] = sym__genvar_expression,
  [sym_constant_primary] = sym_constant_primary,
  [sym_module_path_primary] = sym_module_path_primary,
  [sym_primary] = sym_primary,
  [sym_class_qualifier] = sym_class_qualifier,
  [sym_range_expression] = sym_range_expression,
  [sym_primary_literal] = sym_primary_literal,
  [sym_time_literal] = sym_time_literal,
  [sym_time_unit] = sym_time_unit,
  [sym_string_literal] = sym_string_literal,
  [sym_implicit_class_handle] = sym_implicit_class_handle,
  [sym_bit_select1] = sym_bit_select1,
  [sym_select1] = sym_select1,
  [sym_nonrange_select1] = sym_nonrange_select1,
  [sym_constant_bit_select1] = sym_constant_bit_select1,
  [sym_constant_select1] = sym_constant_select1,
  [sym_cast] = sym_cast,
  [sym_net_lvalue] = sym_net_lvalue,
  [sym_variable_lvalue] = sym_variable_lvalue,
  [sym_nonrange_variable_lvalue] = sym_nonrange_variable_lvalue,
  [sym_unary_operator] = sym_unary_operator,
  [sym_inc_or_dec_operator] = sym_inc_or_dec_operator,
  [sym__number] = sym__number,
  [sym_integral_number] = sym_integral_number,
  [sym_decimal_number] = sym_decimal_number,
  [sym_real_number] = sym_real_number,
  [sym_unbased_unsized_literal] = sym_unbased_unsized_literal,
  [sym_attribute_instance] = sym_attribute_instance,
  [sym_attr_spec] = sym_attr_spec,
  [sym__attr_name] = sym__attr_name,
  [sym__bin_identifier] = sym__bin_identifier,
  [sym_clocking_identifier] = sym_clocking_identifier,
  [sym_const_identifier] = sym_const_identifier,
  [sym_constraint_identifier] = sym_constraint_identifier,
  [sym_escaped_identifier] = sym_escaped_identifier,
  [sym_function_identifier] = sym_function_identifier,
  [sym_generate_block_identifier] = sym_generate_block_identifier,
  [sym__hierarchical_array_identifier] = sym__hierarchical_array_identifier,
  [sym__hierarchical_event_identifier] = sym__hierarchical_event_identifier,
  [sym__hierarchical_parameter_identifier] = sym__hierarchical_parameter_identifier,
  [sym__identifier] = sym__identifier,
  [sym_index_variable_identifier] = sym_index_variable_identifier,
  [sym_inout_port_identifier] = sym_inout_port_identifier,
  [sym_input_port_identifier] = sym_input_port_identifier,
  [sym_method_identifier] = sym_method_identifier,
  [sym_modport_identifier] = sym_modport_identifier,
  [sym_output_port_identifier] = sym_output_port_identifier,
  [sym_package_scope] = sym_package_scope,
  [sym_ps_identifier] = sym_ps_identifier,
  [sym_ps_or_hierarchical_array_identifier] = sym_ps_or_hierarchical_array_identifier,
  [sym__sequence_identifier] = sym__sequence_identifier,
  [sym__signal_identifier] = sym__signal_identifier,
  [sym_task_identifier] = sym_task_identifier,
  [sym_terminal_identifier] = sym_terminal_identifier,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_list_of_formal_arguments_repeat1] = aux_sym_list_of_formal_arguments_repeat1,
  [aux_sym_list_of_actual_arguments_repeat1] = aux_sym_list_of_actual_arguments_repeat1,
  [aux_sym__description_repeat1] = aux_sym__description_repeat1,
  [aux_sym_module_nonansi_header_repeat1] = aux_sym_module_nonansi_header_repeat1,
  [aux_sym_module_declaration_repeat1] = aux_sym_module_declaration_repeat1,
  [aux_sym_interface_declaration_repeat1] = aux_sym_interface_declaration_repeat1,
  [aux_sym_interface_declaration_repeat2] = aux_sym_interface_declaration_repeat2,
  [aux_sym_program_declaration_repeat1] = aux_sym_program_declaration_repeat1,
  [aux_sym_program_declaration_repeat2] = aux_sym_program_declaration_repeat2,
  [aux_sym_checker_declaration_repeat1] = aux_sym_checker_declaration_repeat1,
  [aux_sym_class_declaration_repeat1] = aux_sym_class_declaration_repeat1,
  [aux_sym_class_declaration_repeat2] = aux_sym_class_declaration_repeat2,
  [aux_sym_interface_class_declaration_repeat1] = aux_sym_interface_class_declaration_repeat1,
  [aux_sym_package_declaration_repeat1] = aux_sym_package_declaration_repeat1,
  [aux_sym_parameter_port_list_repeat1] = aux_sym_parameter_port_list_repeat1,
  [aux_sym_list_of_ports_repeat1] = aux_sym_list_of_ports_repeat1,
  [aux_sym_list_of_port_declarations_repeat1] = aux_sym_list_of_port_declarations_repeat1,
  [aux_sym__port_expression_repeat1] = aux_sym__port_expression_repeat1,
  [aux_sym_ansi_port_declaration_repeat1] = aux_sym_ansi_port_declaration_repeat1,
  [aux_sym_ansi_port_declaration_repeat2] = aux_sym_ansi_port_declaration_repeat2,
  [aux_sym_bind_target_instance_list_repeat1] = aux_sym_bind_target_instance_list_repeat1,
  [aux_sym_checker_port_list_repeat1] = aux_sym_checker_port_list_repeat1,
  [aux_sym_class_property_repeat1] = aux_sym_class_property_repeat1,
  [aux_sym_class_property_repeat2] = aux_sym_class_property_repeat2,
  [aux_sym_class_method_repeat1] = aux_sym_class_method_repeat1,
  [aux_sym_class_constructor_declaration_repeat1] = aux_sym_class_constructor_declaration_repeat1,
  [aux_sym_class_constructor_declaration_repeat2] = aux_sym_class_constructor_declaration_repeat2,
  [aux_sym_constraint_block_repeat1] = aux_sym_constraint_block_repeat1,
  [aux_sym_solve_before_list_repeat1] = aux_sym_solve_before_list_repeat1,
  [aux_sym_constraint_set_repeat1] = aux_sym_constraint_set_repeat1,
  [aux_sym_dist_list_repeat1] = aux_sym_dist_list_repeat1,
  [aux_sym_identifier_list_repeat1] = aux_sym_identifier_list_repeat1,
  [aux_sym_anonymous_program_repeat1] = aux_sym_anonymous_program_repeat1,
  [aux_sym_package_import_declaration_repeat1] = aux_sym_package_import_declaration_repeat1,
  [aux_sym_net_declaration_repeat1] = aux_sym_net_declaration_repeat1,
  [aux_sym_data_type_repeat1] = aux_sym_data_type_repeat1,
  [aux_sym_data_type_repeat2] = aux_sym_data_type_repeat2,
  [aux_sym_data_type_repeat3] = aux_sym_data_type_repeat3,
  [aux_sym_class_type_repeat1] = aux_sym_class_type_repeat1,
  [aux_sym_list_of_defparam_assignments_repeat1] = aux_sym_list_of_defparam_assignments_repeat1,
  [aux_sym_list_of_genvar_identifiers_repeat1] = aux_sym_list_of_genvar_identifiers_repeat1,
  [aux_sym_list_of_interface_identifiers_repeat1] = aux_sym_list_of_interface_identifiers_repeat1,
  [aux_sym_list_of_net_decl_assignments_repeat1] = aux_sym_list_of_net_decl_assignments_repeat1,
  [aux_sym_list_of_param_assignments_repeat1] = aux_sym_list_of_param_assignments_repeat1,
  [aux_sym_list_of_port_identifiers_repeat1] = aux_sym_list_of_port_identifiers_repeat1,
  [aux_sym_list_of_udp_port_identifiers_repeat1] = aux_sym_list_of_udp_port_identifiers_repeat1,
  [aux_sym_list_of_specparam_assignments_repeat1] = aux_sym_list_of_specparam_assignments_repeat1,
  [aux_sym_list_of_tf_variable_identifiers_repeat1] = aux_sym_list_of_tf_variable_identifiers_repeat1,
  [aux_sym_list_of_type_assignments_repeat1] = aux_sym_list_of_type_assignments_repeat1,
  [aux_sym_list_of_variable_decl_assignments_repeat1] = aux_sym_list_of_variable_decl_assignments_repeat1,
  [aux_sym_list_of_variable_identifiers_repeat1] = aux_sym_list_of_variable_identifiers_repeat1,
  [aux_sym_list_of_variable_port_identifiers_repeat1] = aux_sym_list_of_variable_port_identifiers_repeat1,
  [aux_sym_function_body_declaration_repeat1] = aux_sym_function_body_declaration_repeat1,
  [aux_sym_task_body_declaration_repeat1] = aux_sym_task_body_declaration_repeat1,
  [aux_sym_tf_port_list_repeat1] = aux_sym_tf_port_list_repeat1,
  [aux_sym_overload_proto_formals_repeat1] = aux_sym_overload_proto_formals_repeat1,
  [aux_sym_modport_declaration_repeat1] = aux_sym_modport_declaration_repeat1,
  [aux_sym_modport_item_repeat1] = aux_sym_modport_item_repeat1,
  [aux_sym_modport_simple_ports_declaration_repeat1] = aux_sym_modport_simple_ports_declaration_repeat1,
  [aux_sym_modport_tf_ports_declaration_repeat1] = aux_sym_modport_tf_ports_declaration_repeat1,
  [aux_sym_property_declaration_repeat1] = aux_sym_property_declaration_repeat1,
  [aux_sym_property_port_list_repeat1] = aux_sym_property_port_list_repeat1,
  [aux_sym_property_expr_repeat1] = aux_sym_property_expr_repeat1,
  [aux_sym_property_case_item_repeat1] = aux_sym_property_case_item_repeat1,
  [aux_sym_sequence_port_list_repeat1] = aux_sym_sequence_port_list_repeat1,
  [aux_sym_sequence_expr_repeat1] = aux_sym_sequence_expr_repeat1,
  [aux_sym_sequence_expr_repeat2] = aux_sym_sequence_expr_repeat2,
  [aux_sym_sequence_expr_repeat3] = aux_sym_sequence_expr_repeat3,
  [aux_sym_sequence_list_of_arguments_repeat1] = aux_sym_sequence_list_of_arguments_repeat1,
  [aux_sym_covergroup_declaration_repeat1] = aux_sym_covergroup_declaration_repeat1,
  [aux_sym_bins_or_empty_repeat1] = aux_sym_bins_or_empty_repeat1,
  [aux_sym_trans_list_repeat1] = aux_sym_trans_list_repeat1,
  [aux_sym_trans_set_repeat1] = aux_sym_trans_set_repeat1,
  [aux_sym_list_of_cross_items_repeat1] = aux_sym_list_of_cross_items_repeat1,
  [aux_sym_cross_body_repeat1] = aux_sym_cross_body_repeat1,
  [aux_sym_covergroup_range_list_repeat1] = aux_sym_covergroup_range_list_repeat1,
  [aux_sym_let_port_list_repeat1] = aux_sym_let_port_list_repeat1,
  [aux_sym_let_list_of_arguments_repeat1] = aux_sym_let_list_of_arguments_repeat1,
  [aux_sym_gate_instantiation_repeat1] = aux_sym_gate_instantiation_repeat1,
  [aux_sym_gate_instantiation_repeat2] = aux_sym_gate_instantiation_repeat2,
  [aux_sym_gate_instantiation_repeat3] = aux_sym_gate_instantiation_repeat3,
  [aux_sym_gate_instantiation_repeat4] = aux_sym_gate_instantiation_repeat4,
  [aux_sym_gate_instantiation_repeat5] = aux_sym_gate_instantiation_repeat5,
  [aux_sym_gate_instantiation_repeat6] = aux_sym_gate_instantiation_repeat6,
  [aux_sym_gate_instantiation_repeat7] = aux_sym_gate_instantiation_repeat7,
  [aux_sym_gate_instantiation_repeat8] = aux_sym_gate_instantiation_repeat8,
  [aux_sym_n_input_gate_instance_repeat1] = aux_sym_n_input_gate_instance_repeat1,
  [aux_sym_n_output_gate_instance_repeat1] = aux_sym_n_output_gate_instance_repeat1,
  [aux_sym_module_instantiation_repeat1] = aux_sym_module_instantiation_repeat1,
  [aux_sym_list_of_parameter_assignments_repeat1] = aux_sym_list_of_parameter_assignments_repeat1,
  [aux_sym_list_of_parameter_assignments_repeat2] = aux_sym_list_of_parameter_assignments_repeat2,
  [aux_sym_list_of_port_connections_repeat1] = aux_sym_list_of_port_connections_repeat1,
  [aux_sym_list_of_port_connections_repeat2] = aux_sym_list_of_port_connections_repeat2,
  [aux_sym_checker_instantiation_repeat1] = aux_sym_checker_instantiation_repeat1,
  [aux_sym_checker_instantiation_repeat2] = aux_sym_checker_instantiation_repeat2,
  [aux_sym_generate_region_repeat1] = aux_sym_generate_region_repeat1,
  [aux_sym_case_generate_construct_repeat1] = aux_sym_case_generate_construct_repeat1,
  [aux_sym_case_generate_item_repeat1] = aux_sym_case_generate_item_repeat1,
  [aux_sym_udp_declaration_repeat1] = aux_sym_udp_declaration_repeat1,
  [aux_sym_udp_port_list_repeat1] = aux_sym_udp_port_list_repeat1,
  [aux_sym_udp_declaration_port_list_repeat1] = aux_sym_udp_declaration_port_list_repeat1,
  [aux_sym_combinational_body_repeat1] = aux_sym_combinational_body_repeat1,
  [aux_sym_sequential_body_repeat1] = aux_sym_sequential_body_repeat1,
  [aux_sym_level_input_list_repeat1] = aux_sym_level_input_list_repeat1,
  [aux_sym_udp_instantiation_repeat1] = aux_sym_udp_instantiation_repeat1,
  [aux_sym_list_of_net_assignments_repeat1] = aux_sym_list_of_net_assignments_repeat1,
  [aux_sym_list_of_variable_assignments_repeat1] = aux_sym_list_of_variable_assignments_repeat1,
  [aux_sym_net_alias_repeat1] = aux_sym_net_alias_repeat1,
  [aux_sym_variable_identifier_list_repeat1] = aux_sym_variable_identifier_list_repeat1,
  [aux_sym_wait_statement_repeat1] = aux_sym_wait_statement_repeat1,
  [aux_sym_cond_predicate_repeat1] = aux_sym_cond_predicate_repeat1,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_case_statement_repeat2] = aux_sym_case_statement_repeat2,
  [aux_sym_case_statement_repeat3] = aux_sym_case_statement_repeat3,
  [aux_sym_case_item_repeat1] = aux_sym_case_item_repeat1,
  [aux_sym_randcase_statement_repeat1] = aux_sym_randcase_statement_repeat1,
  [aux_sym_open_range_list_repeat1] = aux_sym_open_range_list_repeat1,
  [aux_sym_pattern_repeat1] = aux_sym_pattern_repeat1,
  [aux_sym_pattern_repeat2] = aux_sym_pattern_repeat2,
  [aux_sym_assignment_pattern_repeat1] = aux_sym_assignment_pattern_repeat1,
  [aux_sym_assignment_pattern_repeat2] = aux_sym_assignment_pattern_repeat2,
  [aux_sym_assignment_pattern_net_lvalue_repeat1] = aux_sym_assignment_pattern_net_lvalue_repeat1,
  [aux_sym_assignment_pattern_variable_lvalue_repeat1] = aux_sym_assignment_pattern_variable_lvalue_repeat1,
  [aux_sym_for_initialization_repeat1] = aux_sym_for_initialization_repeat1,
  [aux_sym_for_variable_declaration_repeat1] = aux_sym_for_variable_declaration_repeat1,
  [aux_sym_for_step_repeat1] = aux_sym_for_step_repeat1,
  [aux_sym_loop_variables1_repeat1] = aux_sym_loop_variables1_repeat1,
  [aux_sym_clocking_declaration_repeat1] = aux_sym_clocking_declaration_repeat1,
  [aux_sym_list_of_clocking_decl_assign_repeat1] = aux_sym_list_of_clocking_decl_assign_repeat1,
  [aux_sym_specify_block_repeat1] = aux_sym_specify_block_repeat1,
  [aux_sym_list_of_path_inputs_repeat1] = aux_sym_list_of_path_inputs_repeat1,
  [aux_sym_list_of_path_outputs_repeat1] = aux_sym_list_of_path_outputs_repeat1,
  [aux_sym_list_of_path_delay_expressions_repeat1] = aux_sym_list_of_path_delay_expressions_repeat1,
  [aux_sym_edge_control_specifier_repeat1] = aux_sym_edge_control_specifier_repeat1,
  [aux_sym_module_path_concatenation_repeat1] = aux_sym_module_path_concatenation_repeat1,
  [aux_sym_stream_concatenation_repeat1] = aux_sym_stream_concatenation_repeat1,
  [aux_sym_list_of_arguments_repeat1] = aux_sym_list_of_arguments_repeat1,
  [aux_sym_list_of_arguments_parent_repeat1] = aux_sym_list_of_arguments_parent_repeat1,
  [aux_sym_list_of_arguments_parent_repeat2] = aux_sym_list_of_arguments_parent_repeat2,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_bit_select1_repeat1] = aux_sym_bit_select1_repeat1,
  [aux_sym_select1_repeat1] = aux_sym_select1_repeat1,
  [aux_sym_constant_bit_select1_repeat1] = aux_sym_constant_bit_select1_repeat1,
  [aux_sym_constant_select1_repeat1] = aux_sym_constant_select1_repeat1,
  [aux_sym_attribute_instance_repeat1] = aux_sym_attribute_instance_repeat1,
  [aux_sym_hierarchical_identifier_repeat1] = aux_sym_hierarchical_identifier_repeat1,
  [aux_sym_ps_parameter_identifier_repeat1] = aux_sym_ps_parameter_identifier_repeat1,
  [alias_sym__ordered_parameter_assignment] = alias_sym__ordered_parameter_assignment,
  [alias_sym_checker_identifier] = alias_sym_checker_identifier,
  [alias_sym_class_identifier] = alias_sym_class_identifier,
  [alias_sym_cover_point_identifier] = alias_sym_cover_point_identifier,
  [alias_sym_covergroup_identifier] = alias_sym_covergroup_identifier,
  [alias_sym_cross_identifier] = alias_sym_cross_identifier,
  [alias_sym_dynamic_array_variable_identifier] = alias_sym_dynamic_array_variable_identifier,
  [alias_sym_enum_identifier] = alias_sym_enum_identifier,
  [alias_sym_formal_port_identifier] = alias_sym_formal_port_identifier,
  [alias_sym_genvar_identifier] = alias_sym_genvar_identifier,
  [alias_sym_instance_identifier] = alias_sym_instance_identifier,
  [alias_sym_interface_identifier] = alias_sym_interface_identifier,
  [alias_sym_interface_instance_identifier] = alias_sym_interface_instance_identifier,
  [alias_sym_member_identifier] = alias_sym_member_identifier,
  [alias_sym_package_identifier] = alias_sym_package_identifier,
  [alias_sym_parameter_identifier] = alias_sym_parameter_identifier,
  [alias_sym_port_identifier] = alias_sym_port_identifier,
  [alias_sym_program_identifier] = alias_sym_program_identifier,
  [alias_sym_property_identifier] = alias_sym_property_identifier,
  [alias_sym_specparam_identifier] = alias_sym_specparam_identifier,
  [alias_sym_tf_identifier] = alias_sym_tf_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_simple_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quoted_string_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_include_compiler_directive_standard_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_include_compiler_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [sym_default_text] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_text] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_text_macro_definition_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_id_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_id_directive_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_id_directive_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_id_directive_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token6] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token7] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_zero_directive_token8] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_timescale_compiler_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_default_nettype_compiler_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wire] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tri] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tri0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tri1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_triand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trior] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trireg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uwire] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_none] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_unconnected_drive_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pull0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pull1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_line_compiler_directive_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_begin_keywords_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endmodule] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_macromodule] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endinterface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endprogram] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_program] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_checker] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endchecker] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_virtual] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endclass] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pure] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endpackage] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_timeunit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_timeprecision] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_input] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_output] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ref] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARfatal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARerror] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARwarning] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARinfo] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_clocking] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_disable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iff] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defparam] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bind] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_forkjoin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_randc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_super] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constraint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_solve] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_before] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_soft] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2013_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unique] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_localparam] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parameter] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_specparam] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_COLON_COLON_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_genvar] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vectored] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_scalared] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interconnect] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typedef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nettype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_automatic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_packed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_chandle] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_event] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_byte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shortint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_longint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_integer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_time] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_logic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shortreal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_real] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_realtime] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_supply0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_supply1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tagged] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_highz1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_highz0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strong0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_weak0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strong1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_weak1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_small] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_medium] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_large] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1step] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PATHPULSE_DOLLAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_task] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEDPI_DASHC_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEDPI_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_context] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endtask] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2013] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2013u2013] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_modport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_property] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assume] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cover] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_expect] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sequence] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_restrict] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endproperty] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strong] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_weak] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endcase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_DASH_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_EQ_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nexttime] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s_nexttime] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_always] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s_always] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s_eventually] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eventually] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s_until_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implies] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_accept_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reject_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sync_accept_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sync_reject_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endsequence] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_untyped] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_intersect] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_first_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throughout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_within] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_STAR_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_PLUS_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dist] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_covergroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endgroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sample] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_begin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_coverpoint] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wildcard] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bins] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_illegal_bins] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ignore_bins] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACKu2013_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cross] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_matches] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_binsof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pulldown] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pullup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rcmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bufif0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bufif1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_notif0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_notif1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rnmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rpmos] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xnor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_buf] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tranif0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tranif1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rtranif1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rtranif0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tran] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rtran] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_generate] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endgenerate] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_primitive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endprimitive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_table] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endtable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_initial] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEb0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEb1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEbx] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEbX] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEB0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEB1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEBx] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_1_SQUOTEBX] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [sym_output_symbol] = {
    .visible = true,
    .named = true,
  },
  [sym_level_symbol] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_symbol] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_assign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alias] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_always_comb] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_always_latch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_always_ff] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_deassign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_force] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_release] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fork] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_join] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_join_any] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_join_none] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wait] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wait_order] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unique0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_priority] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inside] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_casez] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_casex] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_randcase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_forever] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endclocking] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_specify] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endspecify] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pulsestyle_onevent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pulsestyle_ondetect] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_showcancelled] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noshowcancelled] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_posedge] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_negedge] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_edge] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ifnone] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARsetup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARhold] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARsetuphold] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARrecovery] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARremoval] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARrecrem] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARskew] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARtimeskew] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARfullskew] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARperiod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARwidth] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARnochange] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_01] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_10] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_edge_descriptor_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_edge_descriptor_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTEb0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTEb1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTEB0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTEB1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_std] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_randomize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_null] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_this] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_s] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ms] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_us] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ns] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ps] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fs] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_decimal_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_decimal_number_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_binary_number] = {
    .visible = true,
    .named = true,
  },
  [sym_octal_number] = {
    .visible = true,
    .named = true,
  },
  [sym_hex_number] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_real_number_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_fixed_point_number] = {
    .visible = true,
    .named = true,
  },
  [sym_unsigned_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_unbased_unsized_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LPAREN_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_c_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_escaped_identifier_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOLLARroot] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLARunit] = {
    .visible = true,
    .named = false,
  },
  [sym_system_tf_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_double_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym_include_compiler_directive_standard] = {
    .visible = true,
    .named = true,
  },
  [sym_include_compiler_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_text_macro_name] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_formal_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_text_macro_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_text_macro_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_text_macro_usage] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_text_macro_usage] = {
    .visible = true,
    .named = true,
  },
  [sym_id_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_zero_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_timescale_compiler_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_default_nettype_compiler_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_default_nettype_value] = {
    .visible = true,
    .named = true,
  },
  [sym_unconnected_drive] = {
    .visible = true,
    .named = true,
  },
  [sym_line_compiler_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_keywords] = {
    .visible = true,
    .named = true,
  },
  [sym__directives] = {
    .visible = false,
    .named = true,
  },
  [sym_list_of_actual_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__actual_argument] = {
    .visible = false,
    .named = true,
  },
  [sym__description] = {
    .visible = false,
    .named = true,
  },
  [sym_module_header] = {
    .visible = true,
    .named = true,
  },
  [sym_module_nonansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_module_ansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_module_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_module_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_nonansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_ansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_program_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_program_nonansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_program_ansi_header] = {
    .visible = true,
    .named = true,
  },
  [sym_checker_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_class_item] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_class_method] = {
    .visible = true,
    .named = true,
  },
  [sym_package_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_timeunits_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_ports] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_port_declarations] = {
    .visible = true,
    .named = true,
  },
  [sym_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_port] = {
    .visible = true,
    .named = true,
  },
  [sym__port_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_port_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_port_direction] = {
    .visible = true,
    .named = true,
  },
  [sym_net_port_header1] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_port_header] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_port_header] = {
    .visible = true,
    .named = true,
  },
  [sym_ansi_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_elaboration_system_task] = {
    .visible = true,
    .named = true,
  },
  [sym_finish_number] = {
    .visible = true,
    .named = true,
  },
  [sym__module_common_item] = {
    .visible = false,
    .named = true,
  },
  [sym__module_item] = {
    .visible = false,
    .named = true,
  },
  [sym_module_or_generate_item] = {
    .visible = true,
    .named = true,
  },
  [sym__module_or_generate_item_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__non_port_module_item] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter_override] = {
    .visible = true,
    .named = true,
  },
  [sym_bind_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_bind_target_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_bind_target_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_bind_target_instance_list] = {
    .visible = true,
    .named = true,
  },
  [sym__bind_instantiation] = {
    .visible = false,
    .named = true,
  },
  [sym_interface_or_generate_item] = {
    .visible = true,
    .named = true,
  },
  [sym_extern_tf_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_item] = {
    .visible = true,
    .named = true,
  },
  [sym__non_port_interface_item] = {
    .visible = false,
    .named = true,
  },
  [sym_program_item] = {
    .visible = true,
    .named = true,
  },
  [sym_non_port_program_item] = {
    .visible = true,
    .named = true,
  },
  [sym__program_generate_item] = {
    .visible = false,
    .named = true,
  },
  [sym_checker_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_checker_port_item] = {
    .visible = true,
    .named = true,
  },
  [sym_checker_port_direction] = {
    .visible = true,
    .named = true,
  },
  [sym__checker_or_generate_item] = {
    .visible = false,
    .named = true,
  },
  [sym_checker_or_generate_item_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__checker_generate_item] = {
    .visible = false,
    .named = true,
  },
  [sym_class_item] = {
    .visible = true,
    .named = true,
  },
  [sym_class_property] = {
    .visible = true,
    .named = true,
  },
  [sym_class_method] = {
    .visible = true,
    .named = true,
  },
  [sym_class_constructor_prototype] = {
    .visible = true,
    .named = true,
  },
  [sym__class_constraint] = {
    .visible = false,
    .named = true,
  },
  [sym_class_item_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__property_qualifier] = {
    .visible = false,
    .named = true,
  },
  [sym_random_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_method_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__method_prototype] = {
    .visible = false,
    .named = true,
  },
  [sym_class_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_block] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_block_item] = {
    .visible = true,
    .named = true,
  },
  [sym_solve_before_list] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_primary] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_uniqueness_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_set] = {
    .visible = true,
    .named = true,
  },
  [sym_dist_list] = {
    .visible = true,
    .named = true,
  },
  [sym_dist_item] = {
    .visible = true,
    .named = true,
  },
  [sym_dist_weight] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_prototype] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_prototype_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extern_constraint_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier_list] = {
    .visible = true,
    .named = true,
  },
  [sym__package_item] = {
    .visible = false,
    .named = true,
  },
  [sym_package_or_generate_item_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_anonymous_program] = {
    .visible = true,
    .named = true,
  },
  [sym_anonymous_program_item] = {
    .visible = true,
    .named = true,
  },
  [sym_local_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__any_parameter_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_specparam_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_inout_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_input_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_output_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_data_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_package_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_package_import_item] = {
    .visible = true,
    .named = true,
  },
  [sym_package_export_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_genvar_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_net_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_net_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_lifetime] = {
    .visible = true,
    .named = true,
  },
  [sym_casting_type] = {
    .visible = true,
    .named = true,
  },
  [sym_data_type] = {
    .visible = true,
    .named = true,
  },
  [sym_data_type_or_implicit1] = {
    .visible = true,
    .named = true,
  },
  [sym_implicit_data_type1] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_base_type] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_name_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_class_type] = {
    .visible = true,
    .named = true,
  },
  [sym__integer_type] = {
    .visible = false,
    .named = true,
  },
  [sym_integer_atom_type] = {
    .visible = true,
    .named = true,
  },
  [sym_integer_vector_type] = {
    .visible = true,
    .named = true,
  },
  [sym_non_integer_type] = {
    .visible = true,
    .named = true,
  },
  [sym_net_type] = {
    .visible = true,
    .named = true,
  },
  [sym_net_port_type1] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_port_type] = {
    .visible = false,
    .named = true,
  },
  [sym__var_data_type] = {
    .visible = false,
    .named = true,
  },
  [sym__signing] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
  },
  [sym_struct_union_member] = {
    .visible = true,
    .named = true,
  },
  [sym_data_type_or_void] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_union] = {
    .visible = true,
    .named = true,
  },
  [sym_type_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_drive_strength] = {
    .visible = true,
    .named = true,
  },
  [sym_strength0] = {
    .visible = true,
    .named = true,
  },
  [sym_strength1] = {
    .visible = true,
    .named = true,
  },
  [sym_charge_strength] = {
    .visible = true,
    .named = true,
  },
  [sym_delay3] = {
    .visible = true,
    .named = true,
  },
  [sym_delay2] = {
    .visible = true,
    .named = true,
  },
  [sym_delay_value] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_defparam_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_genvar_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_interface_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_net_decl_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_param_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_port_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_udp_port_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_specparam_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_tf_variable_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_type_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_variable_decl_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_variable_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_variable_port_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_defparam_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_net_decl_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_param_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_specparam_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_type_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_pulse_control_specparam] = {
    .visible = true,
    .named = true,
  },
  [sym_error_limit_value] = {
    .visible = true,
    .named = true,
  },
  [sym_reject_limit_value] = {
    .visible = true,
    .named = true,
  },
  [sym_limit_value] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_decl_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_class_new] = {
    .visible = true,
    .named = true,
  },
  [sym_dynamic_array_new] = {
    .visible = true,
    .named = true,
  },
  [sym_unpacked_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_packed_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_associative_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_dimension] = {
    .visible = false,
    .named = true,
  },
  [sym_queue_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_unsized_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_function_data_type_or_implicit1] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_function_body_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_function_prototype] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_import_export] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_spec_string] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_function_import_property] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_task_import_property] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_function_proto] = {
    .visible = true,
    .named = true,
  },
  [sym_dpi_task_proto] = {
    .visible = true,
    .named = true,
  },
  [sym_task_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_task_body_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_item_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_port_item1] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_port_direction] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_task_prototype] = {
    .visible = true,
    .named = true,
  },
  [sym_block_item_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_overload_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_overload_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_overload_proto_formals] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_item] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_ports_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_clocking_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_simple_ports_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_simple_port] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_tf_ports_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__modport_tf_port] = {
    .visible = false,
    .named = true,
  },
  [sym_import_export] = {
    .visible = true,
    .named = true,
  },
  [sym_concurrent_assertion_item] = {
    .visible = true,
    .named = true,
  },
  [sym__concurrent_assertion_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_assert_property_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assume_property_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cover_property_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expect_property_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cover_sequence_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_restrict_property_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__property_actual_arg] = {
    .visible = false,
    .named = true,
  },
  [sym__assertion_item_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_property_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_property_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_property_port_item] = {
    .visible = true,
    .named = true,
  },
  [sym_property_lvar_port_direction] = {
    .visible = true,
    .named = true,
  },
  [sym_property_formal_type1] = {
    .visible = true,
    .named = true,
  },
  [sym_property_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_property_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_property_case_item] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_port_item] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_lvar_port_direction] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_formal_type1] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_cycle_delay_range] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_method_call] = {
    .visible = true,
    .named = true,
  },
  [sym__sequence_match_item] = {
    .visible = false,
    .named = true,
  },
  [sym_sequence_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_list_of_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__sequence_actual_arg] = {
    .visible = false,
    .named = true,
  },
  [sym__boolean_abbrev] = {
    .visible = false,
    .named = true,
  },
  [sym_sequence_abbrev] = {
    .visible = true,
    .named = true,
  },
  [sym_consecutive_repetition] = {
    .visible = true,
    .named = true,
  },
  [sym_non_consecutive_repetition] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_repetition] = {
    .visible = true,
    .named = true,
  },
  [sym__const_or_range_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_cycle_delay_const_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_or_dist] = {
    .visible = true,
    .named = true,
  },
  [sym_assertion_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_covergroup_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_coverage_spec_or_option] = {
    .visible = true,
    .named = true,
  },
  [sym_coverage_option] = {
    .visible = true,
    .named = true,
  },
  [sym__coverage_spec] = {
    .visible = false,
    .named = true,
  },
  [sym_coverage_event] = {
    .visible = true,
    .named = true,
  },
  [sym_block_event_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hierarchical_btf_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_cover_point] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_or_empty] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_or_options] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_trans_list] = {
    .visible = true,
    .named = true,
  },
  [sym_trans_set] = {
    .visible = true,
    .named = true,
  },
  [sym_trans_range_list] = {
    .visible = true,
    .named = true,
  },
  [sym_trans_item] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_range] = {
    .visible = true,
    .named = true,
  },
  [sym_cover_cross] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_cross_items] = {
    .visible = true,
    .named = true,
  },
  [sym__cross_item] = {
    .visible = false,
    .named = true,
  },
  [sym_cross_body] = {
    .visible = true,
    .named = true,
  },
  [sym_cross_body_item] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_selection_or_option] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_selection] = {
    .visible = true,
    .named = true,
  },
  [sym_select_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_select_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_bins_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_covergroup_range_list] = {
    .visible = true,
    .named = true,
  },
  [sym_covergroup_value_range] = {
    .visible = true,
    .named = true,
  },
  [sym__with_covergroup_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__set_covergroup_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__integer_covergroup_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__cross_set_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__covergroup_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_let_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_let_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_let_port_item] = {
    .visible = true,
    .named = true,
  },
  [sym_let_formal_type1] = {
    .visible = true,
    .named = true,
  },
  [sym_let_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_let_list_of_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_let_actual_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_gate_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_cmos_switch_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_enable_gate_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_mos_switch_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_n_input_gate_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_n_output_gate_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_switch_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_enable_switch_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_pull_gate_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_pulldown_strength] = {
    .visible = true,
    .named = true,
  },
  [sym_pullup_strength] = {
    .visible = true,
    .named = true,
  },
  [sym_enable_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_inout_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_input_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_ncontrol_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_output_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_pcontrol_terminal] = {
    .visible = true,
    .named = true,
  },
  [sym_cmos_switchtype] = {
    .visible = true,
    .named = true,
  },
  [sym_enable_gatetype] = {
    .visible = true,
    .named = true,
  },
  [sym_mos_switchtype] = {
    .visible = true,
    .named = true,
  },
  [sym_n_input_gatetype] = {
    .visible = true,
    .named = true,
  },
  [sym_n_output_gatetype] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_en_switchtype] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_switchtype] = {
    .visible = true,
    .named = true,
  },
  [sym_module_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_value_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_parameter_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_ordered_parameter_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_named_parameter_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_hierarchical_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_name_of_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_port_connections] = {
    .visible = true,
    .named = true,
  },
  [sym_ordered_port_connection] = {
    .visible = true,
    .named = true,
  },
  [sym_named_port_connection] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_program_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_checker_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_generate_region] = {
    .visible = true,
    .named = true,
  },
  [sym_loop_generate_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_genvar_initialization] = {
    .visible = true,
    .named = true,
  },
  [sym_genvar_iteration] = {
    .visible = true,
    .named = true,
  },
  [sym__conditional_generate_construct] = {
    .visible = false,
    .named = true,
  },
  [sym_if_generate_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_case_generate_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_case_generate_item] = {
    .visible = true,
    .named = true,
  },
  [sym_generate_block] = {
    .visible = true,
    .named = true,
  },
  [sym__generate_item] = {
    .visible = false,
    .named = true,
  },
  [sym_udp_nonansi_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_ansi_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_declaration_port_list] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_port_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_output_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_input_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_reg_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__udp_body] = {
    .visible = false,
    .named = true,
  },
  [sym_combinational_body] = {
    .visible = true,
    .named = true,
  },
  [sym_combinational_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_sequential_body] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_initial_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_init_val] = {
    .visible = true,
    .named = true,
  },
  [sym_sequential_entry] = {
    .visible = true,
    .named = true,
  },
  [sym__seq_input_list] = {
    .visible = false,
    .named = true,
  },
  [sym_level_input_list] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_input_list] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_indicator] = {
    .visible = true,
    .named = true,
  },
  [sym__current_state] = {
    .visible = false,
    .named = true,
  },
  [sym_next_state] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_udp_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_continuous_assign] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_net_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_variable_assignments] = {
    .visible = true,
    .named = true,
  },
  [sym_net_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_net_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_initial_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_always_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_always_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_final_construct] = {
    .visible = true,
    .named = true,
  },
  [sym_blocking_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_nonblocking_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_procedural_continuous_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_action_block] = {
    .visible = true,
    .named = true,
  },
  [sym_seq_block] = {
    .visible = true,
    .named = true,
  },
  [sym_par_block] = {
    .visible = true,
    .named = true,
  },
  [sym_join_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_statement_or_null] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_statement_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_statement_or_null] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_identifier_list] = {
    .visible = true,
    .named = true,
  },
  [sym_procedural_timing_control_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delay_or_event_control] = {
    .visible = true,
    .named = true,
  },
  [sym_delay_control] = {
    .visible = true,
    .named = true,
  },
  [sym_event_control] = {
    .visible = true,
    .named = true,
  },
  [sym_event_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__procedural_timing_control] = {
    .visible = false,
    .named = true,
  },
  [sym_jump_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_wait_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_event_trigger] = {
    .visible = true,
    .named = true,
  },
  [sym_disable_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_unique_priority] = {
    .visible = true,
    .named = true,
  },
  [sym_cond_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym__expression_or_cond_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_cond_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_case_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_case_item] = {
    .visible = true,
    .named = true,
  },
  [sym_case_pattern_item] = {
    .visible = true,
    .named = true,
  },
  [sym_case_inside_item] = {
    .visible = true,
    .named = true,
  },
  [sym_case_item_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_randcase_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_randcase_item] = {
    .visible = true,
    .named = true,
  },
  [sym_open_range_list] = {
    .visible = true,
    .named = true,
  },
  [sym_open_value_range] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__array_pattern_key] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_pattern_key] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_pattern_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_pattern_expression_type] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_pattern_net_lvalue] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_pattern_variable_lvalue] = {
    .visible = true,
    .named = true,
  },
  [sym_loop_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_initialization] = {
    .visible = true,
    .named = true,
  },
  [sym_for_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_for_step] = {
    .visible = true,
    .named = true,
  },
  [sym__for_step_assignment] = {
    .visible = false,
    .named = true,
  },
  [sym_loop_variables1] = {
    .visible = true,
    .named = true,
  },
  [sym__assertion_item] = {
    .visible = false,
    .named = true,
  },
  [sym_deferred_immediate_assertion_item] = {
    .visible = true,
    .named = true,
  },
  [sym__procedural_assertion_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__immediate_assertion_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_immediate_assertion_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_simple_immediate_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_immediate_assume_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_immediate_cover_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__deferred_immediate_assertion_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_deferred_immediate_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_deferred_immediate_assume_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_deferred_immediate_cover_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_event] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_item] = {
    .visible = true,
    .named = true,
  },
  [sym_default_skew] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_direction] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_clocking_decl_assign] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_decl_assign] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_skew] = {
    .visible = true,
    .named = true,
  },
  [sym_clocking_drive] = {
    .visible = true,
    .named = true,
  },
  [sym_cycle_delay] = {
    .visible = true,
    .named = true,
  },
  [sym_clockvar] = {
    .visible = true,
    .named = true,
  },
  [sym_clockvar_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_specify_block] = {
    .visible = true,
    .named = true,
  },
  [sym__specify_item] = {
    .visible = false,
    .named = true,
  },
  [sym_pulsestyle_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_showcancelled_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_path_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_path_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parallel_path_description] = {
    .visible = true,
    .named = true,
  },
  [sym_full_path_description] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_path_inputs] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_path_outputs] = {
    .visible = true,
    .named = true,
  },
  [sym_specify_input_terminal_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_specify_output_terminal_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_input_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_output_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_path_delay_value] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_path_delay_expressions] = {
    .visible = true,
    .named = true,
  },
  [sym_path_delay_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_sensitive_path_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parallel_edge_sensitive_path_description] = {
    .visible = true,
    .named = true,
  },
  [sym_full_edge_sensitive_path_description] = {
    .visible = true,
    .named = true,
  },
  [sym_data_source_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_state_dependent_path_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_polarity_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__system_timing_check] = {
    .visible = false,
    .named = true,
  },
  [sym_DOLLARsetup_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARhold_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARsetuphold_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARrecovery_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARremoval_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARrecrem_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARskew_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARtimeskew_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARfullskew_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARperiod_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARwidth_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_DOLLARnochange_timing_check] = {
    .visible = true,
    .named = true,
  },
  [sym_timecheck_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_controlled_reference_event] = {
    .visible = true,
    .named = true,
  },
  [sym_data_event] = {
    .visible = true,
    .named = true,
  },
  [sym_delayed_data] = {
    .visible = true,
    .named = true,
  },
  [sym_delayed_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_end_edge_offset] = {
    .visible = true,
    .named = true,
  },
  [sym_event_based_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_notifier] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_event] = {
    .visible = true,
    .named = true,
  },
  [sym_remain_active_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_timestamp_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_start_edge_offset] = {
    .visible = true,
    .named = true,
  },
  [sym_threshold] = {
    .visible = true,
    .named = true,
  },
  [sym_timing_check_limit] = {
    .visible = true,
    .named = true,
  },
  [sym_timing_check_event] = {
    .visible = true,
    .named = true,
  },
  [sym_controlled_timing_check_event] = {
    .visible = true,
    .named = true,
  },
  [sym_timing_check_event_control] = {
    .visible = true,
    .named = true,
  },
  [sym__specify_terminal_descriptor] = {
    .visible = false,
    .named = true,
  },
  [sym_edge_control_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_timing_check_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_scalar_timing_check_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_scalar_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_multiple_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_multiple_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_multiple_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_streaming_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_stream_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_size] = {
    .visible = true,
    .named = true,
  },
  [sym_stream_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_stream_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_unpacked_array_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_tf_call] = {
    .visible = true,
    .named = true,
  },
  [sym_system_tf_call] = {
    .visible = true,
    .named = true,
  },
  [sym_subroutine_call] = {
    .visible = true,
    .named = true,
  },
  [sym_function_subroutine_call] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_list_of_arguments_parent] = {
    .visible = true,
    .named = true,
  },
  [sym_method_call] = {
    .visible = true,
    .named = true,
  },
  [sym_method_call_body] = {
    .visible = true,
    .named = true,
  },
  [sym__built_in_method_call] = {
    .visible = false,
    .named = true,
  },
  [sym_array_manipulation_call] = {
    .visible = true,
    .named = true,
  },
  [sym_randomize_call] = {
    .visible = true,
    .named = true,
  },
  [sym__method_call_root] = {
    .visible = false,
    .named = true,
  },
  [sym_array_method_name] = {
    .visible = true,
    .named = true,
  },
  [sym_inc_or_dec_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_mintypmax_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_param_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_param_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__constant_range_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__constant_part_select_range] = {
    .visible = false,
    .named = true,
  },
  [sym_constant_range] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_indexed_range] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_tagged_union_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_inside_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_value_range] = {
    .visible = true,
    .named = true,
  },
  [sym_mintypmax_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_mintypmax_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__part_select_range] = {
    .visible = false,
    .named = true,
  },
  [sym_indexed_range] = {
    .visible = true,
    .named = true,
  },
  [sym__genvar_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_constant_primary] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_primary] = {
    .visible = true,
    .named = true,
  },
  [sym_primary] = {
    .visible = true,
    .named = true,
  },
  [sym_class_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_time_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_time_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_implicit_class_handle] = {
    .visible = true,
    .named = true,
  },
  [sym_bit_select1] = {
    .visible = true,
    .named = true,
  },
  [sym_select1] = {
    .visible = true,
    .named = true,
  },
  [sym_nonrange_select1] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_bit_select1] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_select1] = {
    .visible = true,
    .named = true,
  },
  [sym_cast] = {
    .visible = true,
    .named = true,
  },
  [sym_net_lvalue] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_lvalue] = {
    .visible = true,
    .named = true,
  },
  [sym_nonrange_variable_lvalue] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_inc_or_dec_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__number] = {
    .visible = false,
    .named = true,
  },
  [sym_integral_number] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal_number] = {
    .visible = true,
    .named = true,
  },
  [sym_real_number] = {
    .visible = true,
    .named = true,
  },
  [sym_unbased_unsized_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_instance] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_spec] = {
    .visible = true,
    .named = true,
  },
  [sym__attr_name] = {
    .visible = false,
    .named = true,
  },
  [sym__bin_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_clocking_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_const_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_escaped_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_function_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_generate_block_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__hierarchical_array_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hierarchical_event_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hierarchical_parameter_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_index_variable_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_inout_port_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_input_port_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_method_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_modport_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_output_port_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_package_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_ps_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ps_or_hierarchical_array_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__sequence_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__signal_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_task_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_terminal_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_formal_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_actual_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__description_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_nonansi_header_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_checker_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_class_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_package_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_ports_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_port_declarations_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__port_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ansi_port_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ansi_port_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bind_target_instance_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_checker_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_property_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_property_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_method_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_constructor_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_constructor_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constraint_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_solve_before_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constraint_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dist_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_identifier_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_anonymous_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_package_import_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_net_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_data_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_data_type_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_data_type_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_defparam_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_genvar_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_interface_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_net_decl_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_param_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_port_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_udp_port_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_specparam_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_tf_variable_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_type_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_variable_decl_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_variable_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_variable_port_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_body_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_task_body_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tf_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_overload_proto_formals_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modport_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modport_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modport_simple_ports_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modport_tf_ports_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_case_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_expr_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_expr_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_list_of_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_covergroup_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bins_or_empty_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trans_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trans_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_cross_items_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_cross_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_covergroup_range_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_list_of_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gate_instantiation_repeat8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_n_input_gate_instance_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_n_output_gate_instance_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_instantiation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_parameter_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_parameter_assignments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_port_connections_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_port_connections_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_checker_instantiation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_checker_instantiation_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_generate_region_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_generate_construct_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_generate_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_udp_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_udp_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_udp_declaration_port_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_combinational_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequential_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_level_input_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_udp_instantiation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_net_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_variable_assignments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_net_alias_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_identifier_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_wait_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_cond_predicate_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_item_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_randcase_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_open_range_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assignment_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assignment_pattern_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assignment_pattern_net_lvalue_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assignment_pattern_variable_lvalue_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_initialization_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_step_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_loop_variables1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_clocking_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_clocking_decl_assign_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_specify_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_path_inputs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_path_outputs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_path_delay_expressions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_edge_control_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_path_concatenation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_stream_concatenation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_arguments_parent_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_of_arguments_parent_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bit_select1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_select1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constant_bit_select1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constant_select1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_instance_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hierarchical_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ps_parameter_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym__ordered_parameter_assignment] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_checker_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_class_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_cover_point_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_covergroup_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_cross_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_dynamic_array_variable_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_enum_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_formal_port_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_genvar_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_instance_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_interface_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_interface_instance_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_member_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_package_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_parameter_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_port_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_program_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_property_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_specparam_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_tf_identifier] = {
    .visible = true,
    .named = true,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_covergroup_identifier,
  },
  [2] = {
    [0] = alias_sym_class_identifier,
  },
  [3] = {
    [1] = alias_sym_interface_identifier,
  },
  [4] = {
    [0] = sym_function_identifier,
  },
  [5] = {
    [0] = alias_sym_parameter_identifier,
  },
  [6] = {
    [0] = sym_generate_block_identifier,
  },
  [7] = {
    [0] = sym_task_identifier,
  },
  [8] = {
    [0] = alias_sym_package_identifier,
  },
  [9] = {
    [0] = alias_sym_dynamic_array_variable_identifier,
  },
  [10] = {
    [1] = alias_sym_covergroup_identifier,
  },
  [11] = {
    [1] = alias_sym_class_identifier,
  },
  [12] = {
    [1] = alias_sym_program_identifier,
  },
  [13] = {
    [2] = alias_sym_interface_identifier,
  },
  [14] = {
    [0] = sym_constraint_identifier,
  },
  [15] = {
    [1] = alias_sym_parameter_identifier,
  },
  [16] = {
    [0] = alias_sym_enum_identifier,
  },
  [17] = {
    [0] = alias_sym_port_identifier,
  },
  [18] = {
    [0] = alias_sym_interface_identifier,
  },
  [19] = {
    [0] = sym_clocking_identifier,
  },
  [20] = {
    [0] = alias_sym_genvar_identifier,
  },
  [21] = {
    [0] = sym_modport_identifier,
  },
  [22] = {
    [0] = alias_sym_instance_identifier,
  },
  [23] = {
    [1] = alias_sym_port_identifier,
  },
  [24] = {
    [0] = sym_output_port_identifier,
  },
  [25] = {
    [2] = alias_sym_class_identifier,
  },
  [26] = {
    [2] = alias_sym_program_identifier,
  },
  [27] = {
    [0] = alias_sym_formal_port_identifier,
  },
  [28] = {
    [1] = alias_sym_checker_identifier,
  },
  [29] = {
    [1] = alias_sym_package_identifier,
  },
  [30] = {
    [1] = alias_sym_member_identifier,
  },
  [31] = {
    [3] = alias_sym_interface_identifier,
  },
  [32] = {
    [0] = alias_sym_program_identifier,
  },
  [33] = {
    [3] = alias_sym_program_identifier,
  },
  [34] = {
    [2] = alias_sym_port_identifier,
  },
  [35] = {
    [0] = alias_sym__ordered_parameter_assignment,
  },
  [36] = {
    [1] = alias_sym_formal_port_identifier,
  },
  [37] = {
    [2] = alias_sym_package_identifier,
  },
  [38] = {
    [0] = sym_method_identifier,
  },
  [39] = {
    [1] = alias_sym_property_identifier,
  },
  [40] = {
    [0] = alias_sym_cover_point_identifier,
  },
  [41] = {
    [0] = sym_inout_port_identifier,
  },
  [42] = {
    [0] = sym_input_port_identifier,
  },
  [43] = {
    [1] = alias_sym_genvar_identifier,
  },
  [44] = {
    [4] = alias_sym_interface_identifier,
  },
  [45] = {
    [4] = alias_sym_program_identifier,
  },
  [46] = {
    [3] = alias_sym_port_identifier,
  },
  [47] = {
    [2] = alias_sym_class_identifier,
    [5] = alias_sym_class_identifier,
  },
  [48] = {
    [2] = alias_sym_formal_port_identifier,
  },
  [49] = {
    [1] = alias_sym_checker_identifier,
    [5] = alias_sym_checker_identifier,
  },
  [50] = {
    [3] = alias_sym_class_identifier,
  },
  [51] = {
    [1] = alias_sym_class_identifier,
    [5] = alias_sym_class_identifier,
  },
  [52] = {
    [0] = sym_const_identifier,
  },
  [53] = {
    [1] = alias_sym_package_identifier,
    [5] = alias_sym_package_identifier,
  },
  [54] = {
    [2] = alias_sym_member_identifier,
  },
  [55] = {
    [1] = alias_sym_interface_instance_identifier,
  },
  [56] = {
    [4] = alias_sym_tf_identifier,
  },
  [57] = {
    [1] = alias_sym_covergroup_identifier,
    [5] = alias_sym_covergroup_identifier,
  },
  [58] = {
    [0] = alias_sym_specparam_identifier,
  },
  [59] = {
    [0] = alias_sym_tf_identifier,
  },
  [60] = {
    [5] = alias_sym_interface_identifier,
  },
  [61] = {
    [0] = alias_sym_checker_identifier,
  },
  [62] = {
    [5] = alias_sym_program_identifier,
  },
  [63] = {
    [3] = alias_sym_package_identifier,
  },
  [64] = {
    [2] = alias_sym_class_identifier,
    [6] = alias_sym_class_identifier,
  },
  [65] = {
    [3] = alias_sym_formal_port_identifier,
  },
  [66] = {
    [1] = alias_sym_checker_identifier,
    [6] = alias_sym_checker_identifier,
  },
  [67] = {
    [1] = alias_sym_class_identifier,
    [6] = alias_sym_class_identifier,
  },
  [68] = {
    [2] = alias_sym_package_identifier,
    [6] = alias_sym_package_identifier,
  },
  [69] = {
    [1] = alias_sym_package_identifier,
    [6] = alias_sym_package_identifier,
  },
  [70] = {
    [5] = alias_sym_tf_identifier,
  },
  [71] = {
    [1] = alias_sym_property_identifier,
    [6] = alias_sym_property_identifier,
  },
  [72] = {
    [1] = alias_sym_covergroup_identifier,
    [6] = alias_sym_covergroup_identifier,
  },
  [73] = {
    [0] = alias_sym_interface_identifier,
    [2] = alias_sym_port_identifier,
  },
  [74] = {
    [0] = sym_index_variable_identifier,
  },
  [75] = {
    [2] = alias_sym_class_identifier,
    [7] = alias_sym_class_identifier,
  },
  [76] = {
    [1] = alias_sym_checker_identifier,
    [7] = alias_sym_checker_identifier,
  },
  [77] = {
    [3] = alias_sym_class_identifier,
    [7] = alias_sym_class_identifier,
  },
  [78] = {
    [1] = alias_sym_class_identifier,
    [7] = alias_sym_class_identifier,
  },
  [79] = {
    [2] = alias_sym_package_identifier,
    [7] = alias_sym_package_identifier,
  },
  [80] = {
    [1] = alias_sym_package_identifier,
    [7] = alias_sym_package_identifier,
  },
  [81] = {
    [4] = alias_sym_port_identifier,
  },
  [82] = {
    [4] = alias_sym_formal_port_identifier,
  },
  [83] = {
    [1] = alias_sym_property_identifier,
    [7] = alias_sym_property_identifier,
  },
  [84] = {
    [1] = alias_sym_covergroup_identifier,
    [7] = alias_sym_covergroup_identifier,
  },
  [85] = {
    [0] = alias_sym_cross_identifier,
  },
  [86] = {
    [0] = alias_sym_checker_identifier,
    [4] = alias_sym_formal_port_identifier,
  },
  [87] = {
    [3] = alias_sym_package_identifier,
    [7] = alias_sym_package_identifier,
  },
  [88] = {
    [2] = alias_sym_class_identifier,
    [8] = alias_sym_class_identifier,
  },
  [89] = {
    [1] = alias_sym_interface_identifier,
    [8] = alias_sym_interface_identifier,
  },
  [90] = {
    [1] = alias_sym_program_identifier,
    [8] = alias_sym_program_identifier,
  },
  [91] = {
    [1] = alias_sym_checker_identifier,
    [8] = alias_sym_checker_identifier,
  },
  [92] = {
    [3] = alias_sym_class_identifier,
    [8] = alias_sym_class_identifier,
  },
  [93] = {
    [1] = alias_sym_class_identifier,
    [8] = alias_sym_class_identifier,
  },
  [94] = {
    [2] = alias_sym_package_identifier,
    [8] = alias_sym_package_identifier,
  },
  [95] = {
    [1] = alias_sym_property_identifier,
    [8] = alias_sym_property_identifier,
  },
  [96] = {
    [1] = alias_sym_covergroup_identifier,
    [8] = alias_sym_covergroup_identifier,
  },
  [97] = {
    [1] = alias_sym_cover_point_identifier,
  },
  [98] = {
    [0] = alias_sym_checker_identifier,
    [5] = alias_sym_formal_port_identifier,
  },
  [99] = {
    [1] = alias_sym_checker_identifier,
    [5] = alias_sym_formal_port_identifier,
  },
  [100] = {
    [3] = alias_sym_package_identifier,
    [8] = alias_sym_package_identifier,
  },
  [101] = {
    [2] = alias_sym_class_identifier,
    [9] = alias_sym_class_identifier,
  },
  [102] = {
    [1] = alias_sym_interface_identifier,
    [9] = alias_sym_interface_identifier,
  },
  [103] = {
    [1] = alias_sym_program_identifier,
    [9] = alias_sym_program_identifier,
  },
  [104] = {
    [1] = alias_sym_checker_identifier,
    [9] = alias_sym_checker_identifier,
  },
  [105] = {
    [3] = alias_sym_class_identifier,
    [9] = alias_sym_class_identifier,
  },
  [106] = {
    [1] = alias_sym_class_identifier,
    [9] = alias_sym_class_identifier,
  },
  [107] = {
    [1] = alias_sym_property_identifier,
    [9] = alias_sym_property_identifier,
  },
  [108] = {
    [1] = alias_sym_covergroup_identifier,
    [9] = alias_sym_covergroup_identifier,
  },
  [109] = {
    [1] = alias_sym_checker_identifier,
    [6] = alias_sym_formal_port_identifier,
  },
  [110] = {
    [2] = alias_sym_interface_identifier,
    [9] = alias_sym_interface_identifier,
  },
  [111] = {
    [2] = alias_sym_program_identifier,
    [9] = alias_sym_program_identifier,
  },
  [112] = {
    [3] = alias_sym_package_identifier,
    [9] = alias_sym_package_identifier,
  },
  [113] = {
    [2] = alias_sym_class_identifier,
    [10] = alias_sym_class_identifier,
  },
  [114] = {
    [1] = alias_sym_interface_identifier,
    [10] = alias_sym_interface_identifier,
  },
  [115] = {
    [1] = alias_sym_program_identifier,
    [10] = alias_sym_program_identifier,
  },
  [116] = {
    [3] = alias_sym_class_identifier,
    [10] = alias_sym_class_identifier,
  },
  [117] = {
    [1] = alias_sym_class_identifier,
    [10] = alias_sym_class_identifier,
  },
  [118] = {
    [1] = alias_sym_property_identifier,
    [10] = alias_sym_property_identifier,
  },
  [119] = {
    [1] = alias_sym_covergroup_identifier,
    [10] = alias_sym_covergroup_identifier,
  },
  [120] = {
    [2] = alias_sym_interface_identifier,
    [10] = alias_sym_interface_identifier,
  },
  [121] = {
    [2] = alias_sym_program_identifier,
    [10] = alias_sym_program_identifier,
  },
  [122] = {
    [2] = alias_sym_class_identifier,
    [11] = alias_sym_class_identifier,
  },
  [123] = {
    [3] = alias_sym_class_identifier,
    [11] = alias_sym_class_identifier,
  },
  [124] = {
    [1] = alias_sym_class_identifier,
    [11] = alias_sym_class_identifier,
  },
  [125] = {
    [1] = alias_sym_property_identifier,
    [11] = alias_sym_property_identifier,
  },
  [126] = {
    [2] = alias_sym_interface_identifier,
    [11] = alias_sym_interface_identifier,
  },
  [127] = {
    [2] = alias_sym_program_identifier,
    [11] = alias_sym_program_identifier,
  },
  [128] = {
    [3] = alias_sym_class_identifier,
    [12] = alias_sym_class_identifier,
  },
  [129] = {
    [2] = alias_sym_class_identifier,
    [12] = alias_sym_class_identifier,
  },
  [130] = {
    [1] = alias_sym_class_identifier,
    [12] = alias_sym_class_identifier,
  },
  [131] = {
    [3] = alias_sym_class_identifier,
    [13] = alias_sym_class_identifier,
  },
  [132] = {
    [2] = alias_sym_class_identifier,
    [13] = alias_sym_class_identifier,
  },
  [133] = {
    [1] = alias_sym_class_identifier,
    [13] = alias_sym_class_identifier,
  },
  [134] = {
    [3] = alias_sym_class_identifier,
    [14] = alias_sym_class_identifier,
  },
  [135] = {
    [2] = alias_sym_class_identifier,
    [14] = alias_sym_class_identifier,
  },
  [136] = {
    [4] = alias_sym_cover_point_identifier,
  },
  [137] = {
    [3] = alias_sym_class_identifier,
    [15] = alias_sym_class_identifier,
  },
  [138] = {
    [0] = sym_terminal_identifier,
  },
  [139] = {
    [6] = alias_sym_cover_point_identifier,
  },
  [140] = {
    [7] = alias_sym_cover_point_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_param_expression, 2,
    sym_param_expression,
    alias_sym__ordered_parameter_assignment,
  sym__identifier, 33,
    sym__identifier,
    alias_sym_checker_identifier,
    alias_sym_class_identifier,
    alias_sym_cover_point_identifier,
    alias_sym_covergroup_identifier,
    alias_sym_cross_identifier,
    alias_sym_enum_identifier,
    alias_sym_formal_port_identifier,
    alias_sym_genvar_identifier,
    alias_sym_instance_identifier,
    alias_sym_interface_identifier,
    alias_sym_interface_instance_identifier,
    alias_sym_member_identifier,
    alias_sym_package_identifier,
    alias_sym_parameter_identifier,
    alias_sym_port_identifier,
    alias_sym_program_identifier,
    alias_sym_property_identifier,
    alias_sym_specparam_identifier,
    alias_sym_tf_identifier,
    sym_clocking_identifier,
    sym_const_identifier,
    sym_constraint_identifier,
    sym_function_identifier,
    sym_generate_block_identifier,
    sym_index_variable_identifier,
    sym_inout_port_identifier,
    sym_input_port_identifier,
    sym_method_identifier,
    sym_modport_identifier,
    sym_output_port_identifier,
    sym_task_identifier,
    sym_terminal_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 16,
  [22] = 22,
  [23] = 23,
  [24] = 17,
  [25] = 19,
  [26] = 23,
  [27] = 17,
  [28] = 18,
  [29] = 19,
  [30] = 16,
  [31] = 23,
  [32] = 23,
  [33] = 17,
  [34] = 18,
  [35] = 19,
  [36] = 16,
  [37] = 23,
  [38] = 17,
  [39] = 18,
  [40] = 19,
  [41] = 16,
  [42] = 23,
  [43] = 17,
  [44] = 18,
  [45] = 17,
  [46] = 17,
  [47] = 17,
  [48] = 23,
  [49] = 23,
  [50] = 23,
  [51] = 23,
  [52] = 17,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 55,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 53,
  [61] = 61,
  [62] = 54,
  [63] = 57,
  [64] = 55,
  [65] = 57,
  [66] = 58,
  [67] = 59,
  [68] = 53,
  [69] = 61,
  [70] = 54,
  [71] = 58,
  [72] = 55,
  [73] = 57,
  [74] = 58,
  [75] = 59,
  [76] = 53,
  [77] = 61,
  [78] = 54,
  [79] = 53,
  [80] = 55,
  [81] = 57,
  [82] = 61,
  [83] = 58,
  [84] = 59,
  [85] = 85,
  [86] = 54,
  [87] = 85,
  [88] = 61,
  [89] = 59,
  [90] = 90,
  [91] = 90,
  [92] = 90,
  [93] = 90,
  [94] = 90,
  [95] = 90,
  [96] = 90,
  [97] = 90,
  [98] = 90,
  [99] = 90,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 120,
  [127] = 121,
  [128] = 128,
  [129] = 129,
  [130] = 118,
  [131] = 122,
  [132] = 123,
  [133] = 125,
  [134] = 119,
  [135] = 124,
  [136] = 124,
  [137] = 120,
  [138] = 121,
  [139] = 128,
  [140] = 129,
  [141] = 118,
  [142] = 122,
  [143] = 123,
  [144] = 125,
  [145] = 119,
  [146] = 124,
  [147] = 120,
  [148] = 121,
  [149] = 129,
  [150] = 118,
  [151] = 122,
  [152] = 123,
  [153] = 125,
  [154] = 119,
  [155] = 124,
  [156] = 119,
  [157] = 124,
  [158] = 120,
  [159] = 121,
  [160] = 128,
  [161] = 129,
  [162] = 118,
  [163] = 128,
  [164] = 122,
  [165] = 123,
  [166] = 125,
  [167] = 119,
  [168] = 120,
  [169] = 124,
  [170] = 120,
  [171] = 121,
  [172] = 128,
  [173] = 129,
  [174] = 121,
  [175] = 122,
  [176] = 123,
  [177] = 125,
  [178] = 119,
  [179] = 128,
  [180] = 129,
  [181] = 118,
  [182] = 129,
  [183] = 122,
  [184] = 123,
  [185] = 125,
  [186] = 118,
  [187] = 128,
  [188] = 188,
  [189] = 189,
  [190] = 188,
  [191] = 191,
  [192] = 189,
  [193] = 191,
  [194] = 194,
  [195] = 195,
  [196] = 194,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 189,
  [202] = 188,
  [203] = 188,
  [204] = 191,
  [205] = 194,
  [206] = 197,
  [207] = 197,
  [208] = 198,
  [209] = 191,
  [210] = 194,
  [211] = 189,
  [212] = 191,
  [213] = 194,
  [214] = 198,
  [215] = 188,
  [216] = 216,
  [217] = 217,
  [218] = 191,
  [219] = 194,
  [220] = 197,
  [221] = 198,
  [222] = 197,
  [223] = 198,
  [224] = 197,
  [225] = 198,
  [226] = 189,
  [227] = 189,
  [228] = 189,
  [229] = 191,
  [230] = 194,
  [231] = 188,
  [232] = 197,
  [233] = 198,
  [234] = 188,
  [235] = 235,
  [236] = 235,
  [237] = 235,
  [238] = 235,
  [239] = 235,
  [240] = 235,
  [241] = 235,
  [242] = 235,
  [243] = 243,
  [244] = 244,
  [245] = 243,
  [246] = 244,
  [247] = 247,
  [248] = 247,
  [249] = 243,
  [250] = 247,
  [251] = 244,
  [252] = 243,
  [253] = 244,
  [254] = 247,
  [255] = 247,
  [256] = 243,
  [257] = 244,
  [258] = 244,
  [259] = 247,
  [260] = 243,
  [261] = 247,
  [262] = 243,
  [263] = 244,
  [264] = 247,
  [265] = 244,
  [266] = 243,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 270,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 275,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 269,
  [283] = 273,
  [284] = 276,
  [285] = 277,
  [286] = 281,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 268,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 271,
  [304] = 272,
  [305] = 270,
  [306] = 275,
  [307] = 279,
  [308] = 280,
  [309] = 269,
  [310] = 287,
  [311] = 288,
  [312] = 273,
  [313] = 276,
  [314] = 277,
  [315] = 289,
  [316] = 290,
  [317] = 281,
  [318] = 271,
  [319] = 291,
  [320] = 287,
  [321] = 288,
  [322] = 289,
  [323] = 290,
  [324] = 291,
  [325] = 292,
  [326] = 293,
  [327] = 268,
  [328] = 295,
  [329] = 296,
  [330] = 297,
  [331] = 298,
  [332] = 299,
  [333] = 300,
  [334] = 301,
  [335] = 302,
  [336] = 271,
  [337] = 272,
  [338] = 272,
  [339] = 270,
  [340] = 275,
  [341] = 279,
  [342] = 280,
  [343] = 269,
  [344] = 273,
  [345] = 276,
  [346] = 277,
  [347] = 281,
  [348] = 292,
  [349] = 287,
  [350] = 288,
  [351] = 289,
  [352] = 290,
  [353] = 293,
  [354] = 291,
  [355] = 268,
  [356] = 295,
  [357] = 292,
  [358] = 293,
  [359] = 268,
  [360] = 295,
  [361] = 296,
  [362] = 297,
  [363] = 298,
  [364] = 302,
  [365] = 300,
  [366] = 301,
  [367] = 296,
  [368] = 297,
  [369] = 302,
  [370] = 271,
  [371] = 272,
  [372] = 270,
  [373] = 275,
  [374] = 279,
  [375] = 280,
  [376] = 269,
  [377] = 273,
  [378] = 276,
  [379] = 277,
  [380] = 281,
  [381] = 287,
  [382] = 288,
  [383] = 289,
  [384] = 290,
  [385] = 291,
  [386] = 292,
  [387] = 293,
  [388] = 268,
  [389] = 295,
  [390] = 296,
  [391] = 297,
  [392] = 298,
  [393] = 298,
  [394] = 299,
  [395] = 300,
  [396] = 301,
  [397] = 299,
  [398] = 302,
  [399] = 300,
  [400] = 271,
  [401] = 301,
  [402] = 272,
  [403] = 270,
  [404] = 275,
  [405] = 279,
  [406] = 280,
  [407] = 269,
  [408] = 279,
  [409] = 273,
  [410] = 276,
  [411] = 277,
  [412] = 281,
  [413] = 287,
  [414] = 288,
  [415] = 289,
  [416] = 290,
  [417] = 291,
  [418] = 292,
  [419] = 293,
  [420] = 268,
  [421] = 295,
  [422] = 296,
  [423] = 297,
  [424] = 298,
  [425] = 299,
  [426] = 300,
  [427] = 301,
  [428] = 302,
  [429] = 272,
  [430] = 272,
  [431] = 302,
  [432] = 280,
  [433] = 269,
  [434] = 277,
  [435] = 281,
  [436] = 289,
  [437] = 290,
  [438] = 291,
  [439] = 293,
  [440] = 295,
  [441] = 296,
  [442] = 297,
  [443] = 298,
  [444] = 299,
  [445] = 300,
  [446] = 301,
  [447] = 299,
  [448] = 448,
  [449] = 448,
  [450] = 450,
  [451] = 450,
  [452] = 452,
  [453] = 453,
  [454] = 453,
  [455] = 455,
  [456] = 456,
  [457] = 456,
  [458] = 458,
  [459] = 448,
  [460] = 460,
  [461] = 450,
  [462] = 452,
  [463] = 463,
  [464] = 458,
  [465] = 460,
  [466] = 463,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 467,
  [471] = 468,
  [472] = 469,
  [473] = 473,
  [474] = 473,
  [475] = 467,
  [476] = 468,
  [477] = 469,
  [478] = 478,
  [479] = 452,
  [480] = 453,
  [481] = 455,
  [482] = 456,
  [483] = 448,
  [484] = 450,
  [485] = 452,
  [486] = 458,
  [487] = 460,
  [488] = 463,
  [489] = 453,
  [490] = 467,
  [491] = 468,
  [492] = 469,
  [493] = 473,
  [494] = 455,
  [495] = 456,
  [496] = 455,
  [497] = 473,
  [498] = 453,
  [499] = 453,
  [500] = 448,
  [501] = 455,
  [502] = 456,
  [503] = 450,
  [504] = 452,
  [505] = 505,
  [506] = 448,
  [507] = 450,
  [508] = 452,
  [509] = 458,
  [510] = 460,
  [511] = 463,
  [512] = 458,
  [513] = 460,
  [514] = 463,
  [515] = 515,
  [516] = 467,
  [517] = 468,
  [518] = 469,
  [519] = 455,
  [520] = 456,
  [521] = 473,
  [522] = 467,
  [523] = 453,
  [524] = 456,
  [525] = 452,
  [526] = 468,
  [527] = 469,
  [528] = 453,
  [529] = 456,
  [530] = 452,
  [531] = 458,
  [532] = 460,
  [533] = 455,
  [534] = 448,
  [535] = 450,
  [536] = 473,
  [537] = 458,
  [538] = 460,
  [539] = 463,
  [540] = 463,
  [541] = 467,
  [542] = 468,
  [543] = 469,
  [544] = 473,
  [545] = 545,
  [546] = 545,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 550,
  [552] = 550,
  [553] = 550,
  [554] = 550,
  [555] = 267,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 102,
  [572] = 103,
  [573] = 573,
  [574] = 573,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 578,
  [580] = 573,
  [581] = 575,
  [582] = 576,
  [583] = 577,
  [584] = 578,
  [585] = 578,
  [586] = 573,
  [587] = 575,
  [588] = 576,
  [589] = 576,
  [590] = 578,
  [591] = 575,
  [592] = 576,
  [593] = 577,
  [594] = 578,
  [595] = 575,
  [596] = 576,
  [597] = 577,
  [598] = 578,
  [599] = 575,
  [600] = 576,
  [601] = 577,
  [602] = 577,
  [603] = 573,
  [604] = 575,
  [605] = 576,
  [606] = 577,
  [607] = 578,
  [608] = 575,
  [609] = 577,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 611,
  [616] = 612,
  [617] = 610,
  [618] = 618,
  [619] = 613,
  [620] = 614,
  [621] = 611,
  [622] = 612,
  [623] = 612,
  [624] = 610,
  [625] = 618,
  [626] = 613,
  [627] = 611,
  [628] = 611,
  [629] = 612,
  [630] = 613,
  [631] = 618,
  [632] = 610,
  [633] = 610,
  [634] = 613,
  [635] = 618,
  [636] = 618,
  [637] = 614,
  [638] = 614,
  [639] = 614,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 267,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 100,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 101,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 267,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 861,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 876,
  [899] = 877,
  [900] = 900,
  [901] = 892,
  [902] = 902,
  [903] = 861,
  [904] = 876,
  [905] = 877,
  [906] = 892,
  [907] = 861,
  [908] = 876,
  [909] = 877,
  [910] = 892,
  [911] = 861,
  [912] = 876,
  [913] = 877,
  [914] = 892,
  [915] = 861,
  [916] = 876,
  [917] = 877,
  [918] = 892,
  [919] = 861,
  [920] = 876,
  [921] = 877,
  [922] = 892,
  [923] = 861,
  [924] = 876,
  [925] = 877,
  [926] = 892,
  [927] = 860,
  [928] = 875,
  [929] = 929,
  [930] = 860,
  [931] = 875,
  [932] = 860,
  [933] = 875,
  [934] = 860,
  [935] = 875,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 267,
  [943] = 267,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 103,
  [998] = 998,
  [999] = 999,
  [1000] = 102,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 267,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 267,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1036,
  [1066] = 1045,
  [1067] = 1067,
  [1068] = 267,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1067,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1112,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 267,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 267,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 267,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 267,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1233,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1268,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 267,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1291,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1291,
  [1295] = 1290,
  [1296] = 1292,
  [1297] = 1293,
  [1298] = 1291,
  [1299] = 1299,
  [1300] = 1293,
  [1301] = 1292,
  [1302] = 1292,
  [1303] = 1291,
  [1304] = 1299,
  [1305] = 1293,
  [1306] = 1292,
  [1307] = 1291,
  [1308] = 1299,
  [1309] = 1293,
  [1310] = 1293,
  [1311] = 1291,
  [1312] = 1293,
  [1313] = 1290,
  [1314] = 1292,
  [1315] = 1292,
  [1316] = 1292,
  [1317] = 1290,
  [1318] = 1291,
  [1319] = 1292,
  [1320] = 1291,
  [1321] = 1290,
  [1322] = 1292,
  [1323] = 1299,
  [1324] = 1290,
  [1325] = 1293,
  [1326] = 1293,
  [1327] = 1291,
  [1328] = 1299,
  [1329] = 1290,
  [1330] = 1292,
  [1331] = 1293,
  [1332] = 1291,
  [1333] = 1290,
  [1334] = 1299,
  [1335] = 1292,
  [1336] = 1293,
  [1337] = 1291,
  [1338] = 1299,
  [1339] = 1293,
  [1340] = 1291,
  [1341] = 1292,
  [1342] = 1299,
  [1343] = 1292,
  [1344] = 1299,
  [1345] = 1299,
  [1346] = 1299,
  [1347] = 1299,
  [1348] = 1299,
  [1349] = 1299,
  [1350] = 1299,
  [1351] = 1299,
  [1352] = 1293,
  [1353] = 1293,
  [1354] = 1293,
  [1355] = 1291,
  [1356] = 1292,
  [1357] = 1293,
  [1358] = 1291,
  [1359] = 1292,
  [1360] = 1291,
  [1361] = 1291,
  [1362] = 1362,
  [1363] = 1362,
  [1364] = 1362,
  [1365] = 1365,
  [1366] = 1362,
  [1367] = 1365,
  [1368] = 1365,
  [1369] = 1369,
  [1370] = 1365,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1376,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1372,
  [1385] = 1381,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 1388,
  [1389] = 1386,
  [1390] = 1390,
  [1391] = 1376,
  [1392] = 1377,
  [1393] = 1378,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1387,
  [1397] = 1397,
  [1398] = 1395,
  [1399] = 1399,
  [1400] = 1382,
  [1401] = 1401,
  [1402] = 1402,
  [1403] = 1376,
  [1404] = 1382,
  [1405] = 1383,
  [1406] = 1374,
  [1407] = 1383,
  [1408] = 1372,
  [1409] = 1381,
  [1410] = 1386,
  [1411] = 1387,
  [1412] = 1374,
  [1413] = 1377,
  [1414] = 1378,
  [1415] = 1382,
  [1416] = 1374,
  [1417] = 1383,
  [1418] = 1372,
  [1419] = 1381,
  [1420] = 1386,
  [1421] = 1387,
  [1422] = 1377,
  [1423] = 1378,
  [1424] = 1382,
  [1425] = 102,
  [1426] = 103,
  [1427] = 1427,
  [1428] = 1427,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 1431,
  [1432] = 1432,
  [1433] = 1433,
  [1434] = 1427,
  [1435] = 1429,
  [1436] = 1430,
  [1437] = 1431,
  [1438] = 1432,
  [1439] = 1433,
  [1440] = 1427,
  [1441] = 1429,
  [1442] = 1431,
  [1443] = 1433,
  [1444] = 1429,
  [1445] = 1430,
  [1446] = 1431,
  [1447] = 1430,
  [1448] = 1432,
  [1449] = 1430,
  [1450] = 1432,
  [1451] = 1433,
  [1452] = 1431,
  [1453] = 1432,
  [1454] = 1433,
  [1455] = 1429,
  [1456] = 1427,
  [1457] = 1429,
  [1458] = 1430,
  [1459] = 1431,
  [1460] = 103,
  [1461] = 102,
  [1462] = 1433,
  [1463] = 1432,
  [1464] = 1427,
  [1465] = 1465,
  [1466] = 1466,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1480,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1483,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1486,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1489,
  [1491] = 1489,
  [1492] = 1488,
  [1493] = 1489,
  [1494] = 1488,
  [1495] = 1488,
  [1496] = 1488,
  [1497] = 1488,
  [1498] = 1489,
  [1499] = 1489,
  [1500] = 1489,
  [1501] = 1501,
  [1502] = 1488,
  [1503] = 1489,
  [1504] = 1488,
  [1505] = 1505,
  [1506] = 1489,
  [1507] = 1488,
  [1508] = 1508,
  [1509] = 1509,
  [1510] = 1510,
  [1511] = 1509,
  [1512] = 1512,
  [1513] = 1509,
  [1514] = 1509,
  [1515] = 1509,
  [1516] = 1516,
  [1517] = 1517,
  [1518] = 1518,
  [1519] = 1517,
  [1520] = 1517,
  [1521] = 1517,
  [1522] = 1522,
  [1523] = 1517,
  [1524] = 1517,
  [1525] = 1517,
  [1526] = 1516,
  [1527] = 1517,
  [1528] = 1516,
  [1529] = 1517,
  [1530] = 1517,
  [1531] = 1517,
  [1532] = 1517,
  [1533] = 1517,
  [1534] = 1517,
  [1535] = 1516,
  [1536] = 1516,
  [1537] = 1517,
  [1538] = 1516,
  [1539] = 1516,
  [1540] = 1516,
  [1541] = 1516,
  [1542] = 1516,
  [1543] = 1516,
  [1544] = 1516,
  [1545] = 1516,
  [1546] = 1516,
  [1547] = 1516,
  [1548] = 1516,
  [1549] = 1517,
  [1550] = 1550,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1554,
  [1555] = 1555,
  [1556] = 1556,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1556,
  [1560] = 1554,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1550,
  [1564] = 1551,
  [1565] = 1565,
  [1566] = 1550,
  [1567] = 1551,
  [1568] = 1568,
  [1569] = 1561,
  [1570] = 1550,
  [1571] = 1551,
  [1572] = 1555,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 1550,
  [1577] = 1551,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1578,
  [1582] = 1550,
  [1583] = 1573,
  [1584] = 1574,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1551,
  [1588] = 1562,
  [1589] = 1589,
  [1590] = 1568,
  [1591] = 1580,
  [1592] = 1578,
  [1593] = 1593,
  [1594] = 1580,
  [1595] = 1573,
  [1596] = 1574,
  [1597] = 1561,
  [1598] = 1598,
  [1599] = 1562,
  [1600] = 1554,
  [1601] = 1556,
  [1602] = 1562,
  [1603] = 1568,
  [1604] = 1561,
  [1605] = 1558,
  [1606] = 1606,
  [1607] = 1575,
  [1608] = 1555,
  [1609] = 1609,
  [1610] = 1578,
  [1611] = 1611,
  [1612] = 1585,
  [1613] = 1586,
  [1614] = 1598,
  [1615] = 1550,
  [1616] = 1579,
  [1617] = 1550,
  [1618] = 1551,
  [1619] = 1606,
  [1620] = 1551,
  [1621] = 1550,
  [1622] = 1551,
  [1623] = 1550,
  [1624] = 1551,
  [1625] = 1550,
  [1626] = 1551,
  [1627] = 1550,
  [1628] = 1551,
  [1629] = 1629,
  [1630] = 1611,
  [1631] = 1550,
  [1632] = 1551,
  [1633] = 1580,
  [1634] = 1550,
  [1635] = 1551,
  [1636] = 1578,
  [1637] = 1575,
  [1638] = 1638,
  [1639] = 1555,
  [1640] = 1640,
  [1641] = 1573,
  [1642] = 1568,
  [1643] = 1580,
  [1644] = 1573,
  [1645] = 1550,
  [1646] = 1551,
  [1647] = 1551,
  [1648] = 1557,
  [1649] = 1574,
  [1650] = 1606,
  [1651] = 1651,
  [1652] = 1598,
  [1653] = 1556,
  [1654] = 1574,
  [1655] = 1555,
  [1656] = 1606,
  [1657] = 1598,
  [1658] = 1606,
  [1659] = 1554,
  [1660] = 1550,
  [1661] = 1575,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1663,
  [1666] = 1666,
  [1667] = 1666,
  [1668] = 1662,
  [1669] = 1669,
  [1670] = 1662,
  [1671] = 1662,
  [1672] = 1662,
  [1673] = 1673,
  [1674] = 1662,
  [1675] = 1673,
  [1676] = 1673,
  [1677] = 1663,
  [1678] = 1663,
  [1679] = 1673,
  [1680] = 1666,
  [1681] = 1663,
  [1682] = 1673,
  [1683] = 1666,
  [1684] = 1666,
  [1685] = 1673,
  [1686] = 1673,
  [1687] = 1666,
  [1688] = 1666,
  [1689] = 1673,
  [1690] = 1666,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1705,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1708,
  [1709] = 1709,
  [1710] = 1704,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 1718,
  [1719] = 1719,
  [1720] = 1705,
  [1721] = 1721,
  [1722] = 1706,
  [1723] = 1691,
  [1724] = 1724,
  [1725] = 1707,
  [1726] = 1708,
  [1727] = 1709,
  [1728] = 1728,
  [1729] = 1729,
  [1730] = 1730,
  [1731] = 1693,
  [1732] = 1711,
  [1733] = 1691,
  [1734] = 1734,
  [1735] = 1712,
  [1736] = 1713,
  [1737] = 1714,
  [1738] = 1738,
  [1739] = 1739,
  [1740] = 1691,
  [1741] = 1741,
  [1742] = 1691,
  [1743] = 1691,
  [1744] = 1691,
  [1745] = 1691,
  [1746] = 1691,
  [1747] = 1691,
  [1748] = 1748,
  [1749] = 1749,
  [1750] = 1715,
  [1751] = 1751,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1716,
  [1755] = 1717,
  [1756] = 1718,
  [1757] = 1691,
  [1758] = 1719,
  [1759] = 1691,
  [1760] = 1760,
  [1761] = 1761,
  [1762] = 1762,
  [1763] = 1763,
  [1764] = 1764,
  [1765] = 1765,
  [1766] = 1691,
  [1767] = 1767,
  [1768] = 1761,
  [1769] = 1762,
  [1770] = 1694,
  [1771] = 1771,
  [1772] = 1702,
  [1773] = 1763,
  [1774] = 1703,
  [1775] = 1691,
  [1776] = 1691,
  [1777] = 1691,
  [1778] = 1721,
  [1779] = 1724,
  [1780] = 1764,
  [1781] = 1765,
  [1782] = 1694,
  [1783] = 1695,
  [1784] = 1703,
  [1785] = 1691,
  [1786] = 1721,
  [1787] = 1724,
  [1788] = 1728,
  [1789] = 1696,
  [1790] = 1697,
  [1791] = 1751,
  [1792] = 1698,
  [1793] = 1699,
  [1794] = 1771,
  [1795] = 1728,
  [1796] = 1751,
  [1797] = 1771,
  [1798] = 1702,
  [1799] = 1799,
  [1800] = 1691,
  [1801] = 1691,
  [1802] = 1694,
  [1803] = 1700,
  [1804] = 1703,
  [1805] = 1696,
  [1806] = 1701,
  [1807] = 1721,
  [1808] = 1724,
  [1809] = 1729,
  [1810] = 1697,
  [1811] = 1730,
  [1812] = 1693,
  [1813] = 1752,
  [1814] = 1711,
  [1815] = 1753,
  [1816] = 1760,
  [1817] = 1767,
  [1818] = 1799,
  [1819] = 1819,
  [1820] = 1771,
  [1821] = 1702,
  [1822] = 1698,
  [1823] = 1728,
  [1824] = 1691,
  [1825] = 1691,
  [1826] = 1699,
  [1827] = 1751,
  [1828] = 1700,
  [1829] = 1701,
  [1830] = 1691,
  [1831] = 1752,
  [1832] = 1761,
  [1833] = 1753,
  [1834] = 1762,
  [1835] = 1763,
  [1836] = 1734,
  [1837] = 1764,
  [1838] = 1761,
  [1839] = 1765,
  [1840] = 1762,
  [1841] = 1763,
  [1842] = 1738,
  [1843] = 1739,
  [1844] = 1741,
  [1845] = 1748,
  [1846] = 1749,
  [1847] = 1771,
  [1848] = 1702,
  [1849] = 1760,
  [1850] = 1767,
  [1851] = 1691,
  [1852] = 1691,
  [1853] = 1799,
  [1854] = 1712,
  [1855] = 1734,
  [1856] = 1738,
  [1857] = 1819,
  [1858] = 1739,
  [1859] = 1741,
  [1860] = 1771,
  [1861] = 1702,
  [1862] = 1691,
  [1863] = 1863,
  [1864] = 1819,
  [1865] = 1696,
  [1866] = 1866,
  [1867] = 1764,
  [1868] = 1697,
  [1869] = 1771,
  [1870] = 1702,
  [1871] = 1698,
  [1872] = 1699,
  [1873] = 1691,
  [1874] = 1700,
  [1875] = 1701,
  [1876] = 1748,
  [1877] = 1749,
  [1878] = 1694,
  [1879] = 1765,
  [1880] = 1771,
  [1881] = 1702,
  [1882] = 1691,
  [1883] = 1703,
  [1884] = 1721,
  [1885] = 1724,
  [1886] = 1691,
  [1887] = 1728,
  [1888] = 1751,
  [1889] = 1691,
  [1890] = 1718,
  [1891] = 1891,
  [1892] = 1691,
  [1893] = 1691,
  [1894] = 1691,
  [1895] = 1704,
  [1896] = 1705,
  [1897] = 1752,
  [1898] = 1753,
  [1899] = 1760,
  [1900] = 1706,
  [1901] = 1767,
  [1902] = 1799,
  [1903] = 1819,
  [1904] = 1707,
  [1905] = 1708,
  [1906] = 1709,
  [1907] = 1711,
  [1908] = 1713,
  [1909] = 1734,
  [1910] = 1738,
  [1911] = 1739,
  [1912] = 1741,
  [1913] = 1748,
  [1914] = 1749,
  [1915] = 1714,
  [1916] = 1712,
  [1917] = 1713,
  [1918] = 1714,
  [1919] = 1715,
  [1920] = 1716,
  [1921] = 1704,
  [1922] = 1717,
  [1923] = 1705,
  [1924] = 1696,
  [1925] = 1697,
  [1926] = 1706,
  [1927] = 1707,
  [1928] = 1698,
  [1929] = 1699,
  [1930] = 1700,
  [1931] = 1701,
  [1932] = 1719,
  [1933] = 1718,
  [1934] = 1719,
  [1935] = 1695,
  [1936] = 1695,
  [1937] = 1695,
  [1938] = 1704,
  [1939] = 1705,
  [1940] = 1706,
  [1941] = 1707,
  [1942] = 1708,
  [1943] = 1709,
  [1944] = 1711,
  [1945] = 1712,
  [1946] = 1713,
  [1947] = 1714,
  [1948] = 1715,
  [1949] = 1716,
  [1950] = 1717,
  [1951] = 1718,
  [1952] = 1719,
  [1953] = 1729,
  [1954] = 1704,
  [1955] = 1695,
  [1956] = 1729,
  [1957] = 1716,
  [1958] = 1730,
  [1959] = 1693,
  [1960] = 1705,
  [1961] = 1706,
  [1962] = 1707,
  [1963] = 1708,
  [1964] = 1964,
  [1965] = 1734,
  [1966] = 1691,
  [1967] = 1761,
  [1968] = 1752,
  [1969] = 1753,
  [1970] = 1762,
  [1971] = 1708,
  [1972] = 1763,
  [1973] = 1764,
  [1974] = 1709,
  [1975] = 1765,
  [1976] = 1760,
  [1977] = 1738,
  [1978] = 1739,
  [1979] = 1741,
  [1980] = 1748,
  [1981] = 1691,
  [1982] = 1749,
  [1983] = 1709,
  [1984] = 1729,
  [1985] = 1985,
  [1986] = 1863,
  [1987] = 1715,
  [1988] = 1730,
  [1989] = 1729,
  [1990] = 1694,
  [1991] = 1693,
  [1992] = 1703,
  [1993] = 1721,
  [1994] = 1724,
  [1995] = 1728,
  [1996] = 1751,
  [1997] = 1711,
  [1998] = 1712,
  [1999] = 1713,
  [2000] = 1714,
  [2001] = 1767,
  [2002] = 1717,
  [2003] = 1715,
  [2004] = 1799,
  [2005] = 1730,
  [2006] = 1819,
  [2007] = 1716,
  [2008] = 1717,
  [2009] = 1691,
  [2010] = 1730,
  [2011] = 1718,
  [2012] = 1752,
  [2013] = 1753,
  [2014] = 1760,
  [2015] = 1767,
  [2016] = 1799,
  [2017] = 1761,
  [2018] = 2018,
  [2019] = 1819,
  [2020] = 1762,
  [2021] = 1763,
  [2022] = 1764,
  [2023] = 1765,
  [2024] = 1719,
  [2025] = 1696,
  [2026] = 1697,
  [2027] = 1698,
  [2028] = 1699,
  [2029] = 1700,
  [2030] = 1734,
  [2031] = 1738,
  [2032] = 1739,
  [2033] = 1741,
  [2034] = 1748,
  [2035] = 1749,
  [2036] = 1701,
  [2037] = 1693,
  [2038] = 2038,
  [2039] = 2039,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 2042,
  [2043] = 2040,
  [2044] = 2038,
  [2045] = 2038,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 2038,
  [2049] = 2039,
  [2050] = 2039,
  [2051] = 2038,
  [2052] = 2046,
  [2053] = 2041,
  [2054] = 2042,
  [2055] = 2055,
  [2056] = 2046,
  [2057] = 2041,
  [2058] = 2047,
  [2059] = 2047,
  [2060] = 2040,
  [2061] = 2061,
  [2062] = 2038,
  [2063] = 2042,
  [2064] = 2055,
  [2065] = 2040,
  [2066] = 2046,
  [2067] = 2047,
  [2068] = 2038,
  [2069] = 2038,
  [2070] = 2038,
  [2071] = 2046,
  [2072] = 2047,
  [2073] = 2038,
  [2074] = 2047,
  [2075] = 2042,
  [2076] = 2039,
  [2077] = 2046,
  [2078] = 2039,
  [2079] = 2039,
  [2080] = 2046,
  [2081] = 2038,
  [2082] = 2041,
  [2083] = 2083,
  [2084] = 2042,
  [2085] = 2085,
  [2086] = 2040,
  [2087] = 2087,
  [2088] = 2088,
  [2089] = 2040,
  [2090] = 2039,
  [2091] = 2047,
  [2092] = 2042,
  [2093] = 2047,
  [2094] = 2038,
  [2095] = 2040,
  [2096] = 2061,
  [2097] = 2041,
  [2098] = 2041,
  [2099] = 2099,
  [2100] = 2046,
  [2101] = 2042,
  [2102] = 2041,
  [2103] = 2042,
  [2104] = 2104,
  [2105] = 2040,
  [2106] = 2041,
  [2107] = 2038,
  [2108] = 2039,
  [2109] = 2109,
  [2110] = 2110,
  [2111] = 2111,
  [2112] = 2112,
  [2113] = 2112,
  [2114] = 2109,
  [2115] = 2115,
  [2116] = 2109,
  [2117] = 2117,
  [2118] = 2111,
  [2119] = 2119,
  [2120] = 2120,
  [2121] = 2120,
  [2122] = 2122,
  [2123] = 2112,
  [2124] = 2110,
  [2125] = 2112,
  [2126] = 2120,
  [2127] = 2127,
  [2128] = 2110,
  [2129] = 2127,
  [2130] = 2130,
  [2131] = 2112,
  [2132] = 2132,
  [2133] = 2109,
  [2134] = 2110,
  [2135] = 2109,
  [2136] = 2127,
  [2137] = 2111,
  [2138] = 2138,
  [2139] = 2139,
  [2140] = 2109,
  [2141] = 2141,
  [2142] = 2110,
  [2143] = 2120,
  [2144] = 2127,
  [2145] = 2111,
  [2146] = 2127,
  [2147] = 2117,
  [2148] = 2127,
  [2149] = 2111,
  [2150] = 2119,
  [2151] = 2117,
  [2152] = 2112,
  [2153] = 2110,
  [2154] = 2117,
  [2155] = 2120,
  [2156] = 2127,
  [2157] = 2112,
  [2158] = 2158,
  [2159] = 2112,
  [2160] = 2117,
  [2161] = 2112,
  [2162] = 2120,
  [2163] = 2110,
  [2164] = 2127,
  [2165] = 2165,
  [2166] = 2117,
  [2167] = 2120,
  [2168] = 2112,
  [2169] = 2117,
  [2170] = 2120,
  [2171] = 2110,
  [2172] = 2119,
  [2173] = 2112,
  [2174] = 2117,
  [2175] = 2119,
  [2176] = 2112,
  [2177] = 2119,
  [2178] = 2111,
  [2179] = 2117,
  [2180] = 2180,
  [2181] = 2120,
  [2182] = 2119,
  [2183] = 2119,
  [2184] = 2112,
  [2185] = 2110,
  [2186] = 2110,
  [2187] = 2112,
  [2188] = 2188,
  [2189] = 2111,
  [2190] = 2112,
  [2191] = 2117,
  [2192] = 2127,
  [2193] = 2112,
  [2194] = 2120,
  [2195] = 2127,
  [2196] = 2111,
  [2197] = 2119,
  [2198] = 2198,
  [2199] = 2199,
  [2200] = 2200,
  [2201] = 2201,
  [2202] = 2202,
  [2203] = 2203,
  [2204] = 2204,
  [2205] = 2205,
  [2206] = 2206,
  [2207] = 2207,
  [2208] = 2208,
  [2209] = 2209,
  [2210] = 2210,
  [2211] = 2211,
  [2212] = 2212,
  [2213] = 2213,
  [2214] = 2214,
  [2215] = 2212,
  [2216] = 2216,
  [2217] = 2208,
  [2218] = 2214,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2221,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2207,
  [2227] = 2213,
  [2228] = 2210,
  [2229] = 2216,
  [2230] = 2230,
  [2231] = 2231,
  [2232] = 2220,
  [2233] = 2233,
  [2234] = 2234,
  [2235] = 2235,
  [2236] = 2236,
  [2237] = 2237,
  [2238] = 2200,
  [2239] = 2203,
  [2240] = 2240,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 2243,
  [2244] = 2244,
  [2245] = 2245,
  [2246] = 2246,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 2249,
  [2250] = 2199,
  [2251] = 2201,
  [2252] = 2252,
  [2253] = 2204,
  [2254] = 2254,
  [2255] = 2255,
  [2256] = 2256,
  [2257] = 2257,
  [2258] = 2222,
  [2259] = 2223,
  [2260] = 2224,
  [2261] = 2225,
  [2262] = 2230,
  [2263] = 2242,
  [2264] = 2243,
  [2265] = 2254,
  [2266] = 2255,
  [2267] = 2256,
  [2268] = 2244,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2271,
  [2272] = 2272,
  [2273] = 2245,
  [2274] = 2246,
  [2275] = 2211,
  [2276] = 2212,
  [2277] = 2213,
  [2278] = 2269,
  [2279] = 2270,
  [2280] = 2208,
  [2281] = 2214,
  [2282] = 2207,
  [2283] = 2210,
  [2284] = 2216,
  [2285] = 2198,
  [2286] = 2271,
  [2287] = 2220,
  [2288] = 2288,
  [2289] = 2233,
  [2290] = 2234,
  [2291] = 2235,
  [2292] = 2292,
  [2293] = 2237,
  [2294] = 2200,
  [2295] = 2203,
  [2296] = 2272,
  [2297] = 2297,
  [2298] = 2298,
  [2299] = 2242,
  [2300] = 2243,
  [2301] = 2244,
  [2302] = 2245,
  [2303] = 2246,
  [2304] = 2304,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2248,
  [2309] = 2249,
  [2310] = 2199,
  [2311] = 2311,
  [2312] = 2201,
  [2313] = 2204,
  [2314] = 2314,
  [2315] = 2222,
  [2316] = 2223,
  [2317] = 2224,
  [2318] = 2225,
  [2319] = 2230,
  [2320] = 2254,
  [2321] = 2255,
  [2322] = 2256,
  [2323] = 2269,
  [2324] = 2270,
  [2325] = 2198,
  [2326] = 2271,
  [2327] = 2272,
  [2328] = 2328,
  [2329] = 2211,
  [2330] = 2212,
  [2331] = 2213,
  [2332] = 2208,
  [2333] = 2214,
  [2334] = 2207,
  [2335] = 2210,
  [2336] = 2216,
  [2337] = 2211,
  [2338] = 2220,
  [2339] = 2233,
  [2340] = 2234,
  [2341] = 2235,
  [2342] = 2237,
  [2343] = 2200,
  [2344] = 2203,
  [2345] = 2242,
  [2346] = 2243,
  [2347] = 2244,
  [2348] = 2245,
  [2349] = 2246,
  [2350] = 2248,
  [2351] = 2249,
  [2352] = 2199,
  [2353] = 2201,
  [2354] = 2204,
  [2355] = 2222,
  [2356] = 2223,
  [2357] = 2224,
  [2358] = 2225,
  [2359] = 2230,
  [2360] = 2254,
  [2361] = 2255,
  [2362] = 2256,
  [2363] = 2269,
  [2364] = 2270,
  [2365] = 2198,
  [2366] = 2271,
  [2367] = 2211,
  [2368] = 2212,
  [2369] = 2213,
  [2370] = 2208,
  [2371] = 2214,
  [2372] = 2207,
  [2373] = 2210,
  [2374] = 2216,
  [2375] = 2220,
  [2376] = 2233,
  [2377] = 2234,
  [2378] = 2235,
  [2379] = 2237,
  [2380] = 2200,
  [2381] = 2203,
  [2382] = 2242,
  [2383] = 2243,
  [2384] = 2244,
  [2385] = 2245,
  [2386] = 2246,
  [2387] = 2387,
  [2388] = 2248,
  [2389] = 2249,
  [2390] = 2199,
  [2391] = 2201,
  [2392] = 2204,
  [2393] = 2222,
  [2394] = 2223,
  [2395] = 2224,
  [2396] = 2225,
  [2397] = 2230,
  [2398] = 2254,
  [2399] = 2255,
  [2400] = 2256,
  [2401] = 2269,
  [2402] = 2270,
  [2403] = 2198,
  [2404] = 2271,
  [2405] = 2272,
  [2406] = 2211,
  [2407] = 2212,
  [2408] = 2213,
  [2409] = 2208,
  [2410] = 2214,
  [2411] = 2233,
  [2412] = 2207,
  [2413] = 2210,
  [2414] = 2216,
  [2415] = 2220,
  [2416] = 2233,
  [2417] = 2234,
  [2418] = 2235,
  [2419] = 2237,
  [2420] = 2200,
  [2421] = 2203,
  [2422] = 2242,
  [2423] = 2243,
  [2424] = 2244,
  [2425] = 2245,
  [2426] = 2246,
  [2427] = 2248,
  [2428] = 2249,
  [2429] = 2199,
  [2430] = 2201,
  [2431] = 2204,
  [2432] = 2222,
  [2433] = 2223,
  [2434] = 2224,
  [2435] = 2225,
  [2436] = 2230,
  [2437] = 2254,
  [2438] = 2255,
  [2439] = 2256,
  [2440] = 2269,
  [2441] = 2270,
  [2442] = 2198,
  [2443] = 2271,
  [2444] = 2272,
  [2445] = 2207,
  [2446] = 2233,
  [2447] = 2207,
  [2448] = 2233,
  [2449] = 2207,
  [2450] = 2233,
  [2451] = 2207,
  [2452] = 2233,
  [2453] = 2207,
  [2454] = 2233,
  [2455] = 2207,
  [2456] = 2233,
  [2457] = 2207,
  [2458] = 2233,
  [2459] = 2207,
  [2460] = 2233,
  [2461] = 2207,
  [2462] = 2233,
  [2463] = 2207,
  [2464] = 2233,
  [2465] = 2207,
  [2466] = 2233,
  [2467] = 2207,
  [2468] = 2233,
  [2469] = 2231,
  [2470] = 2240,
  [2471] = 2247,
  [2472] = 2202,
  [2473] = 2205,
  [2474] = 2207,
  [2475] = 2387,
  [2476] = 2233,
  [2477] = 2257,
  [2478] = 2234,
  [2479] = 2207,
  [2480] = 2233,
  [2481] = 2207,
  [2482] = 2233,
  [2483] = 2231,
  [2484] = 2240,
  [2485] = 2247,
  [2486] = 2202,
  [2487] = 2205,
  [2488] = 2387,
  [2489] = 2257,
  [2490] = 2207,
  [2491] = 2233,
  [2492] = 2231,
  [2493] = 2240,
  [2494] = 2247,
  [2495] = 2202,
  [2496] = 2205,
  [2497] = 2387,
  [2498] = 2235,
  [2499] = 2257,
  [2500] = 2231,
  [2501] = 2240,
  [2502] = 2247,
  [2503] = 2202,
  [2504] = 2205,
  [2505] = 2387,
  [2506] = 2257,
  [2507] = 2231,
  [2508] = 2240,
  [2509] = 2247,
  [2510] = 2202,
  [2511] = 2205,
  [2512] = 2387,
  [2513] = 2257,
  [2514] = 2231,
  [2515] = 2247,
  [2516] = 2205,
  [2517] = 2387,
  [2518] = 2257,
  [2519] = 2247,
  [2520] = 2205,
  [2521] = 2387,
  [2522] = 2257,
  [2523] = 2247,
  [2524] = 2205,
  [2525] = 2387,
  [2526] = 2257,
  [2527] = 2247,
  [2528] = 2205,
  [2529] = 2387,
  [2530] = 2257,
  [2531] = 2247,
  [2532] = 2205,
  [2533] = 2387,
  [2534] = 2257,
  [2535] = 2247,
  [2536] = 2205,
  [2537] = 2387,
  [2538] = 2257,
  [2539] = 2247,
  [2540] = 2205,
  [2541] = 2387,
  [2542] = 2257,
  [2543] = 2247,
  [2544] = 2205,
  [2545] = 2387,
  [2546] = 2257,
  [2547] = 2247,
  [2548] = 2205,
  [2549] = 2387,
  [2550] = 2257,
  [2551] = 2247,
  [2552] = 2247,
  [2553] = 2247,
  [2554] = 2247,
  [2555] = 2247,
  [2556] = 2247,
  [2557] = 2247,
  [2558] = 2213,
  [2559] = 2214,
  [2560] = 2216,
  [2561] = 2220,
  [2562] = 2248,
  [2563] = 2237,
  [2564] = 2237,
  [2565] = 2200,
  [2566] = 2203,
  [2567] = 2244,
  [2568] = 2245,
  [2569] = 2246,
  [2570] = 2199,
  [2571] = 2201,
  [2572] = 2204,
  [2573] = 2224,
  [2574] = 2225,
  [2575] = 2230,
  [2576] = 2256,
  [2577] = 2249,
  [2578] = 2272,
  [2579] = 2579,
  [2580] = 2579,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2583,
  [2584] = 2584,
  [2585] = 2585,
  [2586] = 2586,
  [2587] = 2587,
  [2588] = 2579,
  [2589] = 2584,
  [2590] = 2590,
  [2591] = 2585,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2581,
  [2595] = 2582,
  [2596] = 2596,
  [2597] = 2597,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 2600,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2603,
  [2604] = 2604,
  [2605] = 2605,
  [2606] = 2606,
  [2607] = 2607,
  [2608] = 2608,
  [2609] = 2586,
  [2610] = 2583,
  [2611] = 2587,
  [2612] = 2612,
  [2613] = 2579,
  [2614] = 2614,
  [2615] = 2615,
  [2616] = 2616,
  [2617] = 2596,
  [2618] = 2618,
  [2619] = 2619,
  [2620] = 2620,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2632,
  [2633] = 2633,
  [2634] = 2597,
  [2635] = 2635,
  [2636] = 2598,
  [2637] = 2637,
  [2638] = 2584,
  [2639] = 2328,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2596,
  [2644] = 2644,
  [2645] = 2599,
  [2646] = 2600,
  [2647] = 2601,
  [2648] = 2597,
  [2649] = 2602,
  [2650] = 2603,
  [2651] = 2604,
  [2652] = 2652,
  [2653] = 2605,
  [2654] = 2654,
  [2655] = 2598,
  [2656] = 2614,
  [2657] = 2657,
  [2658] = 2641,
  [2659] = 2659,
  [2660] = 2606,
  [2661] = 2607,
  [2662] = 2662,
  [2663] = 2622,
  [2664] = 2623,
  [2665] = 2599,
  [2666] = 2624,
  [2667] = 2600,
  [2668] = 2601,
  [2669] = 2625,
  [2670] = 2602,
  [2671] = 2671,
  [2672] = 2603,
  [2673] = 2662,
  [2674] = 2626,
  [2675] = 2675,
  [2676] = 2604,
  [2677] = 2627,
  [2678] = 2628,
  [2679] = 2629,
  [2680] = 2630,
  [2681] = 2631,
  [2682] = 2605,
  [2683] = 2632,
  [2684] = 2642,
  [2685] = 2633,
  [2686] = 2593,
  [2687] = 2612,
  [2688] = 2581,
  [2689] = 2582,
  [2690] = 2583,
  [2691] = 2584,
  [2692] = 2644,
  [2693] = 2600,
  [2694] = 2585,
  [2695] = 2586,
  [2696] = 2587,
  [2697] = 2579,
  [2698] = 2698,
  [2699] = 2699,
  [2700] = 2596,
  [2701] = 2586,
  [2702] = 2597,
  [2703] = 2598,
  [2704] = 2599,
  [2705] = 2600,
  [2706] = 2601,
  [2707] = 2707,
  [2708] = 2602,
  [2709] = 2603,
  [2710] = 2604,
  [2711] = 2605,
  [2712] = 2606,
  [2713] = 2607,
  [2714] = 2601,
  [2715] = 2715,
  [2716] = 2716,
  [2717] = 2717,
  [2718] = 2590,
  [2719] = 2622,
  [2720] = 2592,
  [2721] = 2606,
  [2722] = 2608,
  [2723] = 2623,
  [2724] = 2624,
  [2725] = 2625,
  [2726] = 2616,
  [2727] = 2618,
  [2728] = 2619,
  [2729] = 2607,
  [2730] = 2596,
  [2731] = 2597,
  [2732] = 2626,
  [2733] = 2598,
  [2734] = 2627,
  [2735] = 2599,
  [2736] = 2600,
  [2737] = 2601,
  [2738] = 2602,
  [2739] = 2603,
  [2740] = 2604,
  [2741] = 2637,
  [2742] = 2605,
  [2743] = 2606,
  [2744] = 2607,
  [2745] = 2608,
  [2746] = 2641,
  [2747] = 2642,
  [2748] = 2644,
  [2749] = 2628,
  [2750] = 2629,
  [2751] = 2630,
  [2752] = 2631,
  [2753] = 2632,
  [2754] = 2652,
  [2755] = 2654,
  [2756] = 2614,
  [2757] = 2659,
  [2758] = 2633,
  [2759] = 2581,
  [2760] = 2582,
  [2761] = 2583,
  [2762] = 2584,
  [2763] = 2622,
  [2764] = 2671,
  [2765] = 2623,
  [2766] = 2624,
  [2767] = 2662,
  [2768] = 2625,
  [2769] = 2626,
  [2770] = 2627,
  [2771] = 2675,
  [2772] = 2628,
  [2773] = 2629,
  [2774] = 2630,
  [2775] = 2631,
  [2776] = 2632,
  [2777] = 2633,
  [2778] = 2585,
  [2779] = 2586,
  [2780] = 2587,
  [2781] = 2579,
  [2782] = 2602,
  [2783] = 2593,
  [2784] = 2612,
  [2785] = 2087,
  [2786] = 2592,
  [2787] = 2603,
  [2788] = 2604,
  [2789] = 2596,
  [2790] = 2698,
  [2791] = 2699,
  [2792] = 2597,
  [2793] = 2598,
  [2794] = 2599,
  [2795] = 2600,
  [2796] = 2601,
  [2797] = 2707,
  [2798] = 2602,
  [2799] = 2603,
  [2800] = 2604,
  [2801] = 2605,
  [2802] = 2606,
  [2803] = 2607,
  [2804] = 2608,
  [2805] = 2579,
  [2806] = 2715,
  [2807] = 2716,
  [2808] = 2717,
  [2809] = 2590,
  [2810] = 2592,
  [2811] = 2608,
  [2812] = 2605,
  [2813] = 2606,
  [2814] = 2607,
  [2815] = 2616,
  [2816] = 2618,
  [2817] = 2619,
  [2818] = 2715,
  [2819] = 2716,
  [2820] = 2717,
  [2821] = 2590,
  [2822] = 2587,
  [2823] = 2659,
  [2824] = 2616,
  [2825] = 2581,
  [2826] = 2582,
  [2827] = 2583,
  [2828] = 2637,
  [2829] = 2584,
  [2830] = 2641,
  [2831] = 2642,
  [2832] = 2644,
  [2833] = 2629,
  [2834] = 2618,
  [2835] = 2619,
  [2836] = 2596,
  [2837] = 2652,
  [2838] = 2654,
  [2839] = 2614,
  [2840] = 2659,
  [2841] = 2622,
  [2842] = 2622,
  [2843] = 2623,
  [2844] = 2624,
  [2845] = 2625,
  [2846] = 2671,
  [2847] = 2662,
  [2848] = 2848,
  [2849] = 2675,
  [2850] = 2626,
  [2851] = 2627,
  [2852] = 2628,
  [2853] = 2629,
  [2854] = 2630,
  [2855] = 2631,
  [2856] = 2593,
  [2857] = 2585,
  [2858] = 2612,
  [2859] = 2632,
  [2860] = 2633,
  [2861] = 2623,
  [2862] = 2624,
  [2863] = 2625,
  [2864] = 2698,
  [2865] = 2699,
  [2866] = 2637,
  [2867] = 2626,
  [2868] = 2627,
  [2869] = 2641,
  [2870] = 2642,
  [2871] = 2707,
  [2872] = 2628,
  [2873] = 2629,
  [2874] = 2618,
  [2875] = 2630,
  [2876] = 2637,
  [2877] = 2631,
  [2878] = 2644,
  [2879] = 2632,
  [2880] = 2715,
  [2881] = 2716,
  [2882] = 2717,
  [2883] = 2590,
  [2884] = 2592,
  [2885] = 2586,
  [2886] = 2608,
  [2887] = 2633,
  [2888] = 2597,
  [2889] = 2598,
  [2890] = 2616,
  [2891] = 2618,
  [2892] = 2619,
  [2893] = 2652,
  [2894] = 2581,
  [2895] = 2637,
  [2896] = 2641,
  [2897] = 2642,
  [2898] = 2582,
  [2899] = 2587,
  [2900] = 2644,
  [2901] = 2583,
  [2902] = 2654,
  [2903] = 2652,
  [2904] = 2652,
  [2905] = 2654,
  [2906] = 2614,
  [2907] = 2659,
  [2908] = 2654,
  [2909] = 2707,
  [2910] = 2715,
  [2911] = 2716,
  [2912] = 2717,
  [2913] = 2590,
  [2914] = 2671,
  [2915] = 2662,
  [2916] = 2675,
  [2917] = 2581,
  [2918] = 2582,
  [2919] = 2583,
  [2920] = 2579,
  [2921] = 2675,
  [2922] = 2614,
  [2923] = 2593,
  [2924] = 2612,
  [2925] = 2584,
  [2926] = 2926,
  [2927] = 2659,
  [2928] = 2630,
  [2929] = 2631,
  [2930] = 2698,
  [2931] = 2699,
  [2932] = 2584,
  [2933] = 2632,
  [2934] = 2585,
  [2935] = 2585,
  [2936] = 2707,
  [2937] = 2586,
  [2938] = 2587,
  [2939] = 2671,
  [2940] = 2619,
  [2941] = 2662,
  [2942] = 2579,
  [2943] = 2675,
  [2944] = 2715,
  [2945] = 2716,
  [2946] = 2717,
  [2947] = 2590,
  [2948] = 2608,
  [2949] = 2618,
  [2950] = 2619,
  [2951] = 2641,
  [2952] = 2642,
  [2953] = 2585,
  [2954] = 2614,
  [2955] = 2633,
  [2956] = 2675,
  [2957] = 2715,
  [2958] = 2716,
  [2959] = 2717,
  [2960] = 2590,
  [2961] = 2618,
  [2962] = 2619,
  [2963] = 2641,
  [2964] = 2642,
  [2965] = 2965,
  [2966] = 2614,
  [2967] = 2675,
  [2968] = 2715,
  [2969] = 2716,
  [2970] = 2717,
  [2971] = 2590,
  [2972] = 2586,
  [2973] = 2587,
  [2974] = 2715,
  [2975] = 2716,
  [2976] = 2717,
  [2977] = 2590,
  [2978] = 2597,
  [2979] = 2598,
  [2980] = 2715,
  [2981] = 2716,
  [2982] = 2717,
  [2983] = 2590,
  [2984] = 2599,
  [2985] = 2600,
  [2986] = 2715,
  [2987] = 2716,
  [2988] = 2717,
  [2989] = 2590,
  [2990] = 2601,
  [2991] = 2593,
  [2992] = 2715,
  [2993] = 2716,
  [2994] = 2717,
  [2995] = 2590,
  [2996] = 2592,
  [2997] = 2612,
  [2998] = 2586,
  [2999] = 2602,
  [3000] = 2603,
  [3001] = 2604,
  [3002] = 2605,
  [3003] = 2606,
  [3004] = 2607,
  [3005] = 2698,
  [3006] = 2699,
  [3007] = 3007,
  [3008] = 2599,
  [3009] = 2620,
  [3010] = 2596,
  [3011] = 2597,
  [3012] = 2598,
  [3013] = 2698,
  [3014] = 2599,
  [3015] = 2600,
  [3016] = 3016,
  [3017] = 2587,
  [3018] = 3018,
  [3019] = 2601,
  [3020] = 2602,
  [3021] = 2603,
  [3022] = 2604,
  [3023] = 2605,
  [3024] = 2606,
  [3025] = 2622,
  [3026] = 2607,
  [3027] = 2623,
  [3028] = 2624,
  [3029] = 2625,
  [3030] = 2596,
  [3031] = 2597,
  [3032] = 2598,
  [3033] = 2599,
  [3034] = 2600,
  [3035] = 2601,
  [3036] = 2602,
  [3037] = 2603,
  [3038] = 2604,
  [3039] = 2605,
  [3040] = 2606,
  [3041] = 2607,
  [3042] = 2622,
  [3043] = 2623,
  [3044] = 2624,
  [3045] = 2625,
  [3046] = 2626,
  [3047] = 2627,
  [3048] = 2628,
  [3049] = 2629,
  [3050] = 2630,
  [3051] = 2631,
  [3052] = 2632,
  [3053] = 2633,
  [3054] = 2626,
  [3055] = 2596,
  [3056] = 2597,
  [3057] = 2598,
  [3058] = 2599,
  [3059] = 2600,
  [3060] = 2601,
  [3061] = 2602,
  [3062] = 2603,
  [3063] = 2604,
  [3064] = 2605,
  [3065] = 2606,
  [3066] = 2607,
  [3067] = 2622,
  [3068] = 2623,
  [3069] = 2624,
  [3070] = 2625,
  [3071] = 2626,
  [3072] = 2627,
  [3073] = 2628,
  [3074] = 2629,
  [3075] = 2630,
  [3076] = 2631,
  [3077] = 2632,
  [3078] = 2633,
  [3079] = 2627,
  [3080] = 2628,
  [3081] = 2707,
  [3082] = 2616,
  [3083] = 2579,
  [3084] = 2620,
  [3085] = 2622,
  [3086] = 2623,
  [3087] = 2624,
  [3088] = 2625,
  [3089] = 2626,
  [3090] = 2627,
  [3091] = 2628,
  [3092] = 2629,
  [3093] = 2629,
  [3094] = 2630,
  [3095] = 2631,
  [3096] = 3016,
  [3097] = 2630,
  [3098] = 2631,
  [3099] = 2632,
  [3100] = 2633,
  [3101] = 2632,
  [3102] = 3016,
  [3103] = 2633,
  [3104] = 2699,
  [3105] = 2581,
  [3106] = 2582,
  [3107] = 2620,
  [3108] = 2715,
  [3109] = 2583,
  [3110] = 2716,
  [3111] = 3016,
  [3112] = 2657,
  [3113] = 2671,
  [3114] = 2717,
  [3115] = 2590,
  [3116] = 2581,
  [3117] = 2582,
  [3118] = 2583,
  [3119] = 2715,
  [3120] = 2715,
  [3121] = 2622,
  [3122] = 2584,
  [3123] = 2716,
  [3124] = 2717,
  [3125] = 2620,
  [3126] = 2590,
  [3127] = 3016,
  [3128] = 2581,
  [3129] = 2582,
  [3130] = 2583,
  [3131] = 2623,
  [3132] = 2584,
  [3133] = 2585,
  [3134] = 2585,
  [3135] = 2586,
  [3136] = 2620,
  [3137] = 2587,
  [3138] = 3016,
  [3139] = 2579,
  [3140] = 2715,
  [3141] = 2716,
  [3142] = 2717,
  [3143] = 2586,
  [3144] = 2590,
  [3145] = 2620,
  [3146] = 2581,
  [3147] = 3016,
  [3148] = 2582,
  [3149] = 2583,
  [3150] = 2584,
  [3151] = 2587,
  [3152] = 2620,
  [3153] = 2585,
  [3154] = 3016,
  [3155] = 2586,
  [3156] = 2587,
  [3157] = 2579,
  [3158] = 2579,
  [3159] = 2620,
  [3160] = 2716,
  [3161] = 3016,
  [3162] = 2581,
  [3163] = 2582,
  [3164] = 2583,
  [3165] = 2620,
  [3166] = 2584,
  [3167] = 3016,
  [3168] = 2585,
  [3169] = 2586,
  [3170] = 2587,
  [3171] = 2624,
  [3172] = 2579,
  [3173] = 2581,
  [3174] = 2582,
  [3175] = 2583,
  [3176] = 2584,
  [3177] = 2585,
  [3178] = 2586,
  [3179] = 2587,
  [3180] = 2579,
  [3181] = 2596,
  [3182] = 2597,
  [3183] = 2598,
  [3184] = 2599,
  [3185] = 2600,
  [3186] = 2601,
  [3187] = 2602,
  [3188] = 2603,
  [3189] = 2604,
  [3190] = 2605,
  [3191] = 2606,
  [3192] = 2607,
  [3193] = 2622,
  [3194] = 2623,
  [3195] = 2624,
  [3196] = 2625,
  [3197] = 2626,
  [3198] = 2627,
  [3199] = 2596,
  [3200] = 2620,
  [3201] = 2597,
  [3202] = 2628,
  [3203] = 2598,
  [3204] = 2599,
  [3205] = 2600,
  [3206] = 2616,
  [3207] = 2601,
  [3208] = 2602,
  [3209] = 2603,
  [3210] = 2604,
  [3211] = 3016,
  [3212] = 2629,
  [3213] = 2605,
  [3214] = 2606,
  [3215] = 2607,
  [3216] = 2625,
  [3217] = 2637,
  [3218] = 2630,
  [3219] = 2631,
  [3220] = 2632,
  [3221] = 2652,
  [3222] = 2633,
  [3223] = 2654,
  [3224] = 2581,
  [3225] = 2582,
  [3226] = 2583,
  [3227] = 2671,
  [3228] = 2622,
  [3229] = 2662,
  [3230] = 2623,
  [3231] = 2584,
  [3232] = 2624,
  [3233] = 2625,
  [3234] = 2626,
  [3235] = 2585,
  [3236] = 2627,
  [3237] = 2586,
  [3238] = 2628,
  [3239] = 2593,
  [3240] = 2629,
  [3241] = 2630,
  [3242] = 2612,
  [3243] = 2631,
  [3244] = 2632,
  [3245] = 2633,
  [3246] = 2587,
  [3247] = 2579,
  [3248] = 2717,
  [3249] = 2698,
  [3250] = 2699,
  [3251] = 2626,
  [3252] = 2581,
  [3253] = 2582,
  [3254] = 2583,
  [3255] = 2707,
  [3256] = 2584,
  [3257] = 2620,
  [3258] = 3016,
  [3259] = 2620,
  [3260] = 3016,
  [3261] = 2581,
  [3262] = 2582,
  [3263] = 2583,
  [3264] = 2585,
  [3265] = 2627,
  [3266] = 2584,
  [3267] = 2596,
  [3268] = 2597,
  [3269] = 2598,
  [3270] = 2599,
  [3271] = 2600,
  [3272] = 2601,
  [3273] = 2602,
  [3274] = 2603,
  [3275] = 2604,
  [3276] = 2605,
  [3277] = 2606,
  [3278] = 2607,
  [3279] = 2622,
  [3280] = 2623,
  [3281] = 2624,
  [3282] = 2625,
  [3283] = 2626,
  [3284] = 2627,
  [3285] = 2628,
  [3286] = 2629,
  [3287] = 2630,
  [3288] = 2631,
  [3289] = 2632,
  [3290] = 2633,
  [3291] = 2848,
  [3292] = 2628,
  [3293] = 2585,
  [3294] = 2586,
  [3295] = 2587,
  [3296] = 2620,
  [3297] = 3016,
  [3298] = 2596,
  [3299] = 3299,
  [3300] = 3300,
  [3301] = 3301,
  [3302] = 3302,
  [3303] = 3303,
  [3304] = 3304,
  [3305] = 3305,
  [3306] = 3306,
  [3307] = 3307,
  [3308] = 3308,
  [3309] = 3309,
  [3310] = 3310,
  [3311] = 3311,
  [3312] = 3312,
  [3313] = 3313,
  [3314] = 3314,
  [3315] = 3315,
  [3316] = 3316,
  [3317] = 3317,
  [3318] = 3310,
  [3319] = 3319,
  [3320] = 3320,
  [3321] = 3321,
  [3322] = 3322,
  [3323] = 3323,
  [3324] = 3324,
  [3325] = 3325,
  [3326] = 3326,
  [3327] = 3327,
  [3328] = 3328,
  [3329] = 3329,
  [3330] = 3330,
  [3331] = 3331,
  [3332] = 3332,
  [3333] = 3333,
  [3334] = 3334,
  [3335] = 3335,
  [3336] = 3336,
  [3337] = 3337,
  [3338] = 3338,
  [3339] = 3339,
  [3340] = 3340,
  [3341] = 3341,
  [3342] = 3336,
  [3343] = 3343,
  [3344] = 3344,
  [3345] = 3345,
  [3346] = 3346,
  [3347] = 3347,
  [3348] = 3348,
  [3349] = 3349,
  [3350] = 3350,
  [3351] = 3351,
  [3352] = 3352,
  [3353] = 3353,
  [3354] = 3354,
  [3355] = 3355,
  [3356] = 3346,
  [3357] = 3357,
  [3358] = 3347,
  [3359] = 3346,
  [3360] = 3347,
  [3361] = 3361,
  [3362] = 3362,
  [3363] = 3363,
  [3364] = 3364,
  [3365] = 3365,
  [3366] = 3366,
  [3367] = 3367,
  [3368] = 3368,
  [3369] = 3369,
  [3370] = 3370,
  [3371] = 3343,
  [3372] = 3372,
  [3373] = 3346,
  [3374] = 3374,
  [3375] = 3375,
  [3376] = 3337,
  [3377] = 3338,
  [3378] = 3339,
  [3379] = 3340,
  [3380] = 3341,
  [3381] = 3336,
  [3382] = 3343,
  [3383] = 3383,
  [3384] = 3384,
  [3385] = 3385,
  [3386] = 3337,
  [3387] = 3338,
  [3388] = 3339,
  [3389] = 3389,
  [3390] = 3385,
  [3391] = 3391,
  [3392] = 3391,
  [3393] = 3334,
  [3394] = 3394,
  [3395] = 3385,
  [3396] = 3334,
  [3397] = 3394,
  [3398] = 3370,
  [3399] = 3347,
  [3400] = 3400,
  [3401] = 3401,
  [3402] = 3402,
  [3403] = 3403,
  [3404] = 3400,
  [3405] = 3405,
  [3406] = 3406,
  [3407] = 3407,
  [3408] = 3370,
  [3409] = 3409,
  [3410] = 3400,
  [3411] = 3411,
  [3412] = 3412,
  [3413] = 3413,
  [3414] = 3405,
  [3415] = 3348,
  [3416] = 3405,
  [3417] = 3349,
  [3418] = 3335,
  [3419] = 3419,
  [3420] = 3405,
  [3421] = 3335,
  [3422] = 3346,
  [3423] = 3347,
  [3424] = 3337,
  [3425] = 3338,
  [3426] = 3339,
  [3427] = 3340,
  [3428] = 3341,
  [3429] = 3406,
  [3430] = 3430,
  [3431] = 3407,
  [3432] = 3343,
  [3433] = 3409,
  [3434] = 3434,
  [3435] = 3435,
  [3436] = 3436,
  [3437] = 3348,
  [3438] = 3349,
  [3439] = 3439,
  [3440] = 3440,
  [3441] = 3441,
  [3442] = 3442,
  [3443] = 3443,
  [3444] = 3335,
  [3445] = 3316,
  [3446] = 3446,
  [3447] = 3340,
  [3448] = 3385,
  [3449] = 3391,
  [3450] = 3334,
  [3451] = 3394,
  [3452] = 3337,
  [3453] = 3338,
  [3454] = 3339,
  [3455] = 3340,
  [3456] = 3341,
  [3457] = 3343,
  [3458] = 3458,
  [3459] = 3341,
  [3460] = 3460,
  [3461] = 3461,
  [3462] = 3462,
  [3463] = 3463,
  [3464] = 3464,
  [3465] = 3343,
  [3466] = 3466,
  [3467] = 3337,
  [3468] = 3338,
  [3469] = 3339,
  [3470] = 3385,
  [3471] = 3405,
  [3472] = 3340,
  [3473] = 3341,
  [3474] = 3385,
  [3475] = 3385,
  [3476] = 3391,
  [3477] = 3405,
  [3478] = 3478,
  [3479] = 3385,
  [3480] = 3394,
  [3481] = 3405,
  [3482] = 3340,
  [3483] = 3385,
  [3484] = 3346,
  [3485] = 3372,
  [3486] = 3347,
  [3487] = 3355,
  [3488] = 3362,
  [3489] = 3370,
  [3490] = 3405,
  [3491] = 3491,
  [3492] = 3492,
  [3493] = 3493,
  [3494] = 3400,
  [3495] = 3370,
  [3496] = 3405,
  [3497] = 3385,
  [3498] = 3406,
  [3499] = 3405,
  [3500] = 3407,
  [3501] = 3385,
  [3502] = 3409,
  [3503] = 3400,
  [3504] = 3405,
  [3505] = 3385,
  [3506] = 3405,
  [3507] = 3348,
  [3508] = 3336,
  [3509] = 3509,
  [3510] = 3337,
  [3511] = 3338,
  [3512] = 3372,
  [3513] = 3339,
  [3514] = 3349,
  [3515] = 3355,
  [3516] = 3343,
  [3517] = 3385,
  [3518] = 3335,
  [3519] = 3491,
  [3520] = 3492,
  [3521] = 3493,
  [3522] = 3391,
  [3523] = 3372,
  [3524] = 3355,
  [3525] = 3525,
  [3526] = 3337,
  [3527] = 3491,
  [3528] = 3492,
  [3529] = 3338,
  [3530] = 3339,
  [3531] = 3385,
  [3532] = 3493,
  [3533] = 3391,
  [3534] = 3493,
  [3535] = 3535,
  [3536] = 3334,
  [3537] = 3394,
  [3538] = 3372,
  [3539] = 3355,
  [3540] = 3370,
  [3541] = 3491,
  [3542] = 3492,
  [3543] = 3493,
  [3544] = 3400,
  [3545] = 3405,
  [3546] = 3346,
  [3547] = 3372,
  [3548] = 3347,
  [3549] = 3406,
  [3550] = 3407,
  [3551] = 3334,
  [3552] = 3552,
  [3553] = 3492,
  [3554] = 3493,
  [3555] = 3405,
  [3556] = 3409,
  [3557] = 3372,
  [3558] = 3558,
  [3559] = 3559,
  [3560] = 3492,
  [3561] = 3493,
  [3562] = 3394,
  [3563] = 3348,
  [3564] = 3349,
  [3565] = 3372,
  [3566] = 3341,
  [3567] = 3492,
  [3568] = 3335,
  [3569] = 3493,
  [3570] = 3406,
  [3571] = 3340,
  [3572] = 3313,
  [3573] = 3491,
  [3574] = 3407,
  [3575] = 3575,
  [3576] = 3341,
  [3577] = 3409,
  [3578] = 3578,
  [3579] = 3579,
  [3580] = 3580,
  [3581] = 3581,
  [3582] = 3346,
  [3583] = 3347,
  [3584] = 3584,
  [3585] = 3585,
  [3586] = 3586,
  [3587] = 3587,
  [3588] = 3588,
  [3589] = 3385,
  [3590] = 3348,
  [3591] = 3591,
  [3592] = 3492,
  [3593] = 3391,
  [3594] = 3349,
  [3595] = 3334,
  [3596] = 3394,
  [3597] = 3370,
  [3598] = 3598,
  [3599] = 3400,
  [3600] = 3600,
  [3601] = 3406,
  [3602] = 3602,
  [3603] = 3389,
  [3604] = 3402,
  [3605] = 3405,
  [3606] = 3606,
  [3607] = 3406,
  [3608] = 3407,
  [3609] = 3409,
  [3610] = 3368,
  [3611] = 3407,
  [3612] = 3348,
  [3613] = 3349,
  [3614] = 3335,
  [3615] = 3615,
  [3616] = 3616,
  [3617] = 3617,
  [3618] = 3618,
  [3619] = 3409,
  [3620] = 3620,
  [3621] = 3389,
  [3622] = 3368,
  [3623] = 3389,
  [3624] = 3368,
  [3625] = 3368,
  [3626] = 3368,
  [3627] = 3385,
  [3628] = 3391,
  [3629] = 3629,
  [3630] = 3602,
  [3631] = 3334,
  [3632] = 3394,
  [3633] = 3633,
  [3634] = 3346,
  [3635] = 3347,
  [3636] = 3336,
  [3637] = 3637,
  [3638] = 3638,
  [3639] = 3639,
  [3640] = 3419,
  [3641] = 3641,
  [3642] = 3642,
  [3643] = 3620,
  [3644] = 3337,
  [3645] = 3338,
  [3646] = 3339,
  [3647] = 3391,
  [3648] = 3334,
  [3649] = 3394,
  [3650] = 3370,
  [3651] = 3400,
  [3652] = 3370,
  [3653] = 3374,
  [3654] = 3400,
  [3655] = 3406,
  [3656] = 3602,
  [3657] = 3409,
  [3658] = 3658,
  [3659] = 3405,
  [3660] = 3348,
  [3661] = 3335,
  [3662] = 3340,
  [3663] = 3341,
  [3664] = 3346,
  [3665] = 3347,
  [3666] = 3337,
  [3667] = 3338,
  [3668] = 3339,
  [3669] = 3391,
  [3670] = 3334,
  [3671] = 3394,
  [3672] = 3370,
  [3673] = 3400,
  [3674] = 3406,
  [3675] = 3409,
  [3676] = 3348,
  [3677] = 3335,
  [3678] = 3340,
  [3679] = 3341,
  [3680] = 3346,
  [3681] = 3347,
  [3682] = 3337,
  [3683] = 3338,
  [3684] = 3339,
  [3685] = 3391,
  [3686] = 3334,
  [3687] = 3394,
  [3688] = 3370,
  [3689] = 3400,
  [3690] = 3406,
  [3691] = 3409,
  [3692] = 3348,
  [3693] = 3335,
  [3694] = 3340,
  [3695] = 3341,
  [3696] = 3346,
  [3697] = 3347,
  [3698] = 3391,
  [3699] = 3334,
  [3700] = 3394,
  [3701] = 3370,
  [3702] = 3400,
  [3703] = 3406,
  [3704] = 3409,
  [3705] = 3348,
  [3706] = 3335,
  [3707] = 3346,
  [3708] = 3347,
  [3709] = 3391,
  [3710] = 3334,
  [3711] = 3394,
  [3712] = 3370,
  [3713] = 3400,
  [3714] = 3406,
  [3715] = 3409,
  [3716] = 3348,
  [3717] = 3335,
  [3718] = 3346,
  [3719] = 3347,
  [3720] = 3391,
  [3721] = 3334,
  [3722] = 3394,
  [3723] = 3370,
  [3724] = 3400,
  [3725] = 3406,
  [3726] = 3409,
  [3727] = 3348,
  [3728] = 3335,
  [3729] = 3346,
  [3730] = 3347,
  [3731] = 3391,
  [3732] = 3334,
  [3733] = 3394,
  [3734] = 3370,
  [3735] = 3400,
  [3736] = 3406,
  [3737] = 3409,
  [3738] = 3348,
  [3739] = 3335,
  [3740] = 3346,
  [3741] = 3347,
  [3742] = 3391,
  [3743] = 3334,
  [3744] = 3394,
  [3745] = 3370,
  [3746] = 3400,
  [3747] = 3406,
  [3748] = 3409,
  [3749] = 3348,
  [3750] = 3335,
  [3751] = 3336,
  [3752] = 3337,
  [3753] = 3338,
  [3754] = 3339,
  [3755] = 3340,
  [3756] = 3341,
  [3757] = 3336,
  [3758] = 3337,
  [3759] = 3338,
  [3760] = 3339,
  [3761] = 3340,
  [3762] = 3341,
  [3763] = 3336,
  [3764] = 3337,
  [3765] = 3338,
  [3766] = 3339,
  [3767] = 3340,
  [3768] = 3341,
  [3769] = 3336,
  [3770] = 3337,
  [3771] = 3338,
  [3772] = 3339,
  [3773] = 3340,
  [3774] = 3341,
  [3775] = 3337,
  [3776] = 3338,
  [3777] = 3339,
  [3778] = 3340,
  [3779] = 3341,
  [3780] = 3492,
  [3781] = 3493,
  [3782] = 3492,
  [3783] = 3493,
  [3784] = 3492,
  [3785] = 3493,
  [3786] = 3492,
  [3787] = 3493,
  [3788] = 3406,
  [3789] = 3407,
  [3790] = 3492,
  [3791] = 3493,
  [3792] = 3409,
  [3793] = 3793,
  [3794] = 3492,
  [3795] = 3493,
  [3796] = 3492,
  [3797] = 3493,
  [3798] = 3419,
  [3799] = 3620,
  [3800] = 3374,
  [3801] = 3602,
  [3802] = 3419,
  [3803] = 3620,
  [3804] = 3374,
  [3805] = 3602,
  [3806] = 3419,
  [3807] = 3620,
  [3808] = 3374,
  [3809] = 3602,
  [3810] = 3419,
  [3811] = 3620,
  [3812] = 3374,
  [3813] = 3602,
  [3814] = 3419,
  [3815] = 3620,
  [3816] = 3374,
  [3817] = 3602,
  [3818] = 3419,
  [3819] = 3620,
  [3820] = 3374,
  [3821] = 3602,
  [3822] = 3374,
  [3823] = 3602,
  [3824] = 3374,
  [3825] = 3602,
  [3826] = 3374,
  [3827] = 3602,
  [3828] = 3374,
  [3829] = 3602,
  [3830] = 3374,
  [3831] = 3602,
  [3832] = 3374,
  [3833] = 3602,
  [3834] = 3374,
  [3835] = 3602,
  [3836] = 3336,
  [3837] = 3348,
  [3838] = 3349,
  [3839] = 3402,
  [3840] = 3375,
  [3841] = 3841,
  [3842] = 3842,
  [3843] = 3402,
  [3844] = 3492,
  [3845] = 3493,
  [3846] = 3375,
  [3847] = 3375,
  [3848] = 3375,
  [3849] = 3375,
  [3850] = 3375,
  [3851] = 3375,
  [3852] = 3335,
  [3853] = 3343,
  [3854] = 3374,
  [3855] = 3855,
  [3856] = 3856,
  [3857] = 3857,
  [3858] = 3858,
  [3859] = 3859,
  [3860] = 3860,
  [3861] = 3861,
  [3862] = 3862,
  [3863] = 3863,
  [3864] = 3864,
  [3865] = 3864,
  [3866] = 3864,
  [3867] = 3867,
  [3868] = 3864,
  [3869] = 3869,
  [3870] = 3870,
  [3871] = 3864,
  [3872] = 3864,
  [3873] = 3864,
  [3874] = 3864,
  [3875] = 3875,
  [3876] = 3864,
  [3877] = 3864,
  [3878] = 3878,
  [3879] = 3864,
  [3880] = 3864,
  [3881] = 3864,
  [3882] = 3882,
  [3883] = 3883,
  [3884] = 3884,
  [3885] = 3885,
  [3886] = 3863,
  [3887] = 3887,
  [3888] = 3888,
  [3889] = 3889,
  [3890] = 3875,
  [3891] = 3869,
  [3892] = 3878,
  [3893] = 3882,
  [3894] = 3894,
  [3895] = 3895,
  [3896] = 3857,
  [3897] = 3897,
  [3898] = 3898,
  [3899] = 3899,
  [3900] = 3889,
  [3901] = 3901,
  [3902] = 3902,
  [3903] = 3903,
  [3904] = 3904,
  [3905] = 3905,
  [3906] = 3902,
  [3907] = 3907,
  [3908] = 3908,
  [3909] = 3909,
  [3910] = 3910,
  [3911] = 3901,
  [3912] = 3859,
  [3913] = 3860,
  [3914] = 3914,
  [3915] = 3915,
  [3916] = 3870,
  [3917] = 3863,
  [3918] = 3894,
  [3919] = 3870,
  [3920] = 3863,
  [3921] = 3921,
  [3922] = 3922,
  [3923] = 3870,
  [3924] = 3895,
  [3925] = 3925,
  [3926] = 3870,
  [3927] = 3927,
  [3928] = 3863,
  [3929] = 3887,
  [3930] = 3884,
  [3931] = 3899,
  [3932] = 3915,
  [3933] = 3887,
  [3934] = 3888,
  [3935] = 3875,
  [3936] = 3869,
  [3937] = 3878,
  [3938] = 3882,
  [3939] = 3894,
  [3940] = 3857,
  [3941] = 3898,
  [3942] = 3899,
  [3943] = 3889,
  [3944] = 3901,
  [3945] = 3945,
  [3946] = 3903,
  [3947] = 3864,
  [3948] = 3905,
  [3949] = 3902,
  [3950] = 3908,
  [3951] = 3910,
  [3952] = 3952,
  [3953] = 3859,
  [3954] = 3914,
  [3955] = 3870,
  [3956] = 3884,
  [3957] = 3887,
  [3958] = 3888,
  [3959] = 3875,
  [3960] = 3869,
  [3961] = 3878,
  [3962] = 3882,
  [3963] = 3894,
  [3964] = 3857,
  [3965] = 3898,
  [3966] = 3889,
  [3967] = 3901,
  [3968] = 3968,
  [3969] = 3903,
  [3970] = 3905,
  [3971] = 3902,
  [3972] = 3908,
  [3973] = 3973,
  [3974] = 3925,
  [3975] = 3910,
  [3976] = 3859,
  [3977] = 3914,
  [3978] = 3870,
  [3979] = 3979,
  [3980] = 3884,
  [3981] = 3981,
  [3982] = 3982,
  [3983] = 3863,
  [3984] = 3887,
  [3985] = 3888,
  [3986] = 3875,
  [3987] = 3869,
  [3988] = 3878,
  [3989] = 3882,
  [3990] = 3894,
  [3991] = 3857,
  [3992] = 3898,
  [3993] = 3889,
  [3994] = 3901,
  [3995] = 3903,
  [3996] = 3905,
  [3997] = 3902,
  [3998] = 3908,
  [3999] = 3910,
  [4000] = 3859,
  [4001] = 3914,
  [4002] = 3870,
  [4003] = 3884,
  [4004] = 3887,
  [4005] = 3888,
  [4006] = 3875,
  [4007] = 3869,
  [4008] = 3878,
  [4009] = 3882,
  [4010] = 3894,
  [4011] = 3857,
  [4012] = 3898,
  [4013] = 4013,
  [4014] = 3889,
  [4015] = 3901,
  [4016] = 3864,
  [4017] = 3903,
  [4018] = 3905,
  [4019] = 3902,
  [4020] = 3908,
  [4021] = 3910,
  [4022] = 3859,
  [4023] = 3914,
  [4024] = 4024,
  [4025] = 3884,
  [4026] = 3925,
  [4027] = 4027,
  [4028] = 3887,
  [4029] = 3888,
  [4030] = 3875,
  [4031] = 3869,
  [4032] = 3878,
  [4033] = 3882,
  [4034] = 3894,
  [4035] = 3857,
  [4036] = 3898,
  [4037] = 3903,
  [4038] = 3905,
  [4039] = 3908,
  [4040] = 3925,
  [4041] = 4041,
  [4042] = 3887,
  [4043] = 3888,
  [4044] = 3875,
  [4045] = 3869,
  [4046] = 3878,
  [4047] = 3882,
  [4048] = 3894,
  [4049] = 3857,
  [4050] = 3898,
  [4051] = 3905,
  [4052] = 4052,
  [4053] = 4053,
  [4054] = 3887,
  [4055] = 3888,
  [4056] = 3869,
  [4057] = 3878,
  [4058] = 3882,
  [4059] = 3905,
  [4060] = 3887,
  [4061] = 3888,
  [4062] = 3869,
  [4063] = 3878,
  [4064] = 3882,
  [4065] = 3870,
  [4066] = 3905,
  [4067] = 3887,
  [4068] = 3888,
  [4069] = 3869,
  [4070] = 3878,
  [4071] = 3882,
  [4072] = 3905,
  [4073] = 4073,
  [4074] = 3887,
  [4075] = 3888,
  [4076] = 3869,
  [4077] = 3878,
  [4078] = 3882,
  [4079] = 3905,
  [4080] = 3887,
  [4081] = 3888,
  [4082] = 3869,
  [4083] = 3878,
  [4084] = 3882,
  [4085] = 3905,
  [4086] = 3887,
  [4087] = 3888,
  [4088] = 3869,
  [4089] = 3878,
  [4090] = 3882,
  [4091] = 3898,
  [4092] = 3887,
  [4093] = 3888,
  [4094] = 3869,
  [4095] = 3878,
  [4096] = 3882,
  [4097] = 4097,
  [4098] = 3905,
  [4099] = 4099,
  [4100] = 4100,
  [4101] = 3870,
  [4102] = 3863,
  [4103] = 3914,
  [4104] = 3870,
  [4105] = 4105,
  [4106] = 3857,
  [4107] = 3887,
  [4108] = 3888,
  [4109] = 3869,
  [4110] = 3878,
  [4111] = 3882,
  [4112] = 3863,
  [4113] = 3907,
  [4114] = 3864,
  [4115] = 4115,
  [4116] = 3864,
  [4117] = 3905,
  [4118] = 4118,
  [4119] = 3922,
  [4120] = 4120,
  [4121] = 4121,
  [4122] = 4052,
  [4123] = 3904,
  [4124] = 3863,
  [4125] = 3888,
  [4126] = 3910,
  [4127] = 4127,
  [4128] = 4128,
  [4129] = 4129,
  [4130] = 4130,
  [4131] = 3905,
  [4132] = 3907,
  [4133] = 4052,
  [4134] = 3870,
  [4135] = 3907,
  [4136] = 4136,
  [4137] = 4052,
  [4138] = 3907,
  [4139] = 4052,
  [4140] = 4140,
  [4141] = 3907,
  [4142] = 4052,
  [4143] = 3863,
  [4144] = 4144,
  [4145] = 4052,
  [4146] = 3915,
  [4147] = 4147,
  [4148] = 3863,
  [4149] = 4052,
  [4150] = 4150,
  [4151] = 4151,
  [4152] = 4152,
  [4153] = 4153,
  [4154] = 4154,
  [4155] = 4155,
  [4156] = 3925,
  [4157] = 4157,
  [4158] = 3863,
  [4159] = 4159,
  [4160] = 4160,
  [4161] = 4161,
  [4162] = 3870,
  [4163] = 4013,
  [4164] = 3863,
  [4165] = 4165,
  [4166] = 3898,
  [4167] = 4167,
  [4168] = 3863,
  [4169] = 4169,
  [4170] = 4170,
  [4171] = 4171,
  [4172] = 4172,
  [4173] = 4173,
  [4174] = 3925,
  [4175] = 3908,
  [4176] = 4176,
  [4177] = 4177,
  [4178] = 3925,
  [4179] = 4179,
  [4180] = 4180,
  [4181] = 4181,
  [4182] = 3925,
  [4183] = 4183,
  [4184] = 3925,
  [4185] = 3875,
  [4186] = 3894,
  [4187] = 3857,
  [4188] = 3898,
  [4189] = 4189,
  [4190] = 3875,
  [4191] = 3894,
  [4192] = 3857,
  [4193] = 3898,
  [4194] = 3875,
  [4195] = 3894,
  [4196] = 3857,
  [4197] = 3898,
  [4198] = 3875,
  [4199] = 3894,
  [4200] = 3857,
  [4201] = 3898,
  [4202] = 3875,
  [4203] = 3894,
  [4204] = 3857,
  [4205] = 3898,
  [4206] = 3884,
  [4207] = 3870,
  [4208] = 3875,
  [4209] = 3894,
  [4210] = 3857,
  [4211] = 3898,
  [4212] = 3875,
  [4213] = 3894,
  [4214] = 3857,
  [4215] = 3898,
  [4216] = 3864,
  [4217] = 4217,
  [4218] = 4218,
  [4219] = 3903,
  [4220] = 4220,
  [4221] = 4221,
  [4222] = 3925,
  [4223] = 3875,
  [4224] = 3894,
  [4225] = 3905,
  [4226] = 4226,
  [4227] = 4227,
  [4228] = 4228,
  [4229] = 4228,
  [4230] = 4227,
  [4231] = 4228,
  [4232] = 4232,
  [4233] = 4227,
  [4234] = 4228,
  [4235] = 4226,
  [4236] = 4227,
  [4237] = 4228,
  [4238] = 4227,
  [4239] = 4228,
  [4240] = 4227,
  [4241] = 4228,
  [4242] = 4226,
  [4243] = 4232,
  [4244] = 4227,
  [4245] = 4232,
  [4246] = 4226,
  [4247] = 4232,
  [4248] = 4232,
  [4249] = 4226,
  [4250] = 4232,
  [4251] = 4232,
  [4252] = 4228,
  [4253] = 4232,
  [4254] = 4227,
  [4255] = 4227,
  [4256] = 4232,
  [4257] = 4227,
  [4258] = 4232,
  [4259] = 4232,
  [4260] = 4232,
  [4261] = 4226,
  [4262] = 4226,
  [4263] = 4263,
  [4264] = 4227,
  [4265] = 4226,
  [4266] = 4228,
  [4267] = 4228,
  [4268] = 4228,
  [4269] = 4227,
  [4270] = 4227,
  [4271] = 4228,
  [4272] = 4232,
  [4273] = 4226,
  [4274] = 4227,
  [4275] = 4227,
  [4276] = 4228,
  [4277] = 4232,
  [4278] = 4228,
  [4279] = 4227,
  [4280] = 4228,
  [4281] = 4226,
  [4282] = 4228,
  [4283] = 4232,
  [4284] = 4232,
  [4285] = 4285,
  [4286] = 4285,
  [4287] = 4287,
  [4288] = 4285,
  [4289] = 4287,
  [4290] = 4290,
  [4291] = 4285,
  [4292] = 4287,
  [4293] = 4287,
  [4294] = 4290,
  [4295] = 4285,
  [4296] = 4287,
  [4297] = 4290,
  [4298] = 4290,
  [4299] = 4290,
  [4300] = 3327,
  [4301] = 4285,
  [4302] = 4290,
  [4303] = 4287,
  [4304] = 4290,
  [4305] = 4285,
  [4306] = 4285,
  [4307] = 4287,
  [4308] = 4287,
  [4309] = 4290,
  [4310] = 4285,
  [4311] = 4290,
  [4312] = 4290,
  [4313] = 103,
  [4314] = 4287,
  [4315] = 4285,
  [4316] = 4290,
  [4317] = 4287,
  [4318] = 4285,
  [4319] = 4290,
  [4320] = 4285,
  [4321] = 4287,
  [4322] = 4290,
  [4323] = 102,
  [4324] = 4285,
  [4325] = 4285,
  [4326] = 4287,
  [4327] = 4290,
  [4328] = 4290,
  [4329] = 4285,
  [4330] = 4287,
  [4331] = 4287,
  [4332] = 4287,
  [4333] = 4287,
  [4334] = 4290,
  [4335] = 4285,
  [4336] = 1010,
  [4337] = 762,
  [4338] = 690,
  [4339] = 682,
  [4340] = 699,
  [4341] = 763,
  [4342] = 764,
  [4343] = 1015,
  [4344] = 1017,
  [4345] = 700,
  [4346] = 990,
  [4347] = 717,
  [4348] = 678,
  [4349] = 994,
  [4350] = 1032,
  [4351] = 727,
  [4352] = 765,
  [4353] = 697,
  [4354] = 698,
  [4355] = 758,
  [4356] = 991,
  [4357] = 992,
  [4358] = 730,
  [4359] = 750,
  [4360] = 1090,
  [4361] = 762,
  [4362] = 1012,
  [4363] = 749,
  [4364] = 729,
  [4365] = 1024,
  [4366] = 759,
  [4367] = 663,
  [4368] = 1013,
  [4369] = 677,
  [4370] = 681,
  [4371] = 671,
  [4372] = 1136,
  [4373] = 695,
  [4374] = 744,
  [4375] = 754,
  [4376] = 715,
  [4377] = 1015,
  [4378] = 1017,
  [4379] = 661,
  [4380] = 694,
  [4381] = 747,
  [4382] = 684,
  [4383] = 1078,
  [4384] = 737,
  [4385] = 1090,
  [4386] = 714,
  [4387] = 1161,
  [4388] = 733,
  [4389] = 743,
  [4390] = 652,
  [4391] = 1084,
  [4392] = 719,
  [4393] = 693,
  [4394] = 701,
  [4395] = 731,
  [4396] = 721,
  [4397] = 763,
  [4398] = 722,
  [4399] = 723,
  [4400] = 658,
  [4401] = 708,
  [4402] = 740,
  [4403] = 745,
  [4404] = 748,
  [4405] = 657,
  [4406] = 726,
  [4407] = 727,
  [4408] = 673,
  [4409] = 1136,
  [4410] = 653,
  [4411] = 659,
  [4412] = 729,
  [4413] = 1158,
  [4414] = 731,
  [4415] = 658,
  [4416] = 725,
  [4417] = 659,
  [4418] = 732,
  [4419] = 725,
  [4420] = 1185,
  [4421] = 736,
  [4422] = 669,
  [4423] = 664,
  [4424] = 704,
  [4425] = 764,
  [4426] = 665,
  [4427] = 667,
  [4428] = 675,
  [4429] = 1084,
  [4430] = 745,
  [4431] = 1006,
  [4432] = 677,
  [4433] = 748,
  [4434] = 653,
  [4435] = 678,
  [4436] = 692,
  [4437] = 1010,
  [4438] = 1012,
  [4439] = 1050,
  [4440] = 991,
  [4441] = 690,
  [4442] = 709,
  [4443] = 992,
  [4444] = 682,
  [4445] = 699,
  [4446] = 700,
  [4447] = 1032,
  [4448] = 710,
  [4449] = 715,
  [4450] = 733,
  [4451] = 743,
  [4452] = 728,
  [4453] = 652,
  [4454] = 693,
  [4455] = 1158,
  [4456] = 765,
  [4457] = 739,
  [4458] = 709,
  [4459] = 710,
  [4460] = 728,
  [4461] = 746,
  [4462] = 692,
  [4463] = 1024,
  [4464] = 749,
  [4465] = 712,
  [4466] = 718,
  [4467] = 755,
  [4468] = 723,
  [4469] = 739,
  [4470] = 1013,
  [4471] = 746,
  [4472] = 671,
  [4473] = 1078,
  [4474] = 705,
  [4475] = 742,
  [4476] = 648,
  [4477] = 751,
  [4478] = 695,
  [4479] = 1031,
  [4480] = 705,
  [4481] = 742,
  [4482] = 648,
  [4483] = 751,
  [4484] = 714,
  [4485] = 707,
  [4486] = 752,
  [4487] = 756,
  [4488] = 1031,
  [4489] = 665,
  [4490] = 669,
  [4491] = 697,
  [4492] = 750,
  [4493] = 707,
  [4494] = 752,
  [4495] = 680,
  [4496] = 1050,
  [4497] = 703,
  [4498] = 664,
  [4499] = 711,
  [4500] = 754,
  [4501] = 663,
  [4502] = 713,
  [4503] = 744,
  [4504] = 747,
  [4505] = 679,
  [4506] = 655,
  [4507] = 686,
  [4508] = 667,
  [4509] = 675,
  [4510] = 644,
  [4511] = 720,
  [4512] = 737,
  [4513] = 755,
  [4514] = 704,
  [4515] = 757,
  [4516] = 758,
  [4517] = 680,
  [4518] = 759,
  [4519] = 756,
  [4520] = 698,
  [4521] = 1161,
  [4522] = 1006,
  [4523] = 1088,
  [4524] = 718,
  [4525] = 703,
  [4526] = 990,
  [4527] = 994,
  [4528] = 711,
  [4529] = 679,
  [4530] = 686,
  [4531] = 681,
  [4532] = 644,
  [4533] = 720,
  [4534] = 730,
  [4535] = 1088,
  [4536] = 670,
  [4537] = 683,
  [4538] = 688,
  [4539] = 691,
  [4540] = 683,
  [4541] = 688,
  [4542] = 702,
  [4543] = 691,
  [4544] = 708,
  [4545] = 740,
  [4546] = 702,
  [4547] = 657,
  [4548] = 660,
  [4549] = 660,
  [4550] = 662,
  [4551] = 662,
  [4552] = 650,
  [4553] = 672,
  [4554] = 661,
  [4555] = 673,
  [4556] = 649,
  [4557] = 736,
  [4558] = 650,
  [4559] = 672,
  [4560] = 670,
  [4561] = 684,
  [4562] = 685,
  [4563] = 687,
  [4564] = 689,
  [4565] = 696,
  [4566] = 694,
  [4567] = 712,
  [4568] = 757,
  [4569] = 685,
  [4570] = 687,
  [4571] = 713,
  [4572] = 689,
  [4573] = 696,
  [4574] = 726,
  [4575] = 649,
  [4576] = 717,
  [4577] = 701,
  [4578] = 719,
  [4579] = 721,
  [4580] = 722,
  [4581] = 732,
  [4582] = 655,
  [4583] = 1172,
  [4584] = 1131,
  [4585] = 770,
  [4586] = 797,
  [4587] = 840,
  [4588] = 771,
  [4589] = 1168,
  [4590] = 1064,
  [4591] = 1132,
  [4592] = 1196,
  [4593] = 1218,
  [4594] = 1128,
  [4595] = 1178,
  [4596] = 1137,
  [4597] = 777,
  [4598] = 1027,
  [4599] = 778,
  [4600] = 767,
  [4601] = 646,
  [4602] = 782,
  [4603] = 1111,
  [4604] = 883,
  [4605] = 885,
  [4606] = 1245,
  [4607] = 1224,
  [4608] = 1035,
  [4609] = 1226,
  [4610] = 773,
  [4611] = 1215,
  [4612] = 779,
  [4613] = 804,
  [4614] = 790,
  [4615] = 1129,
  [4616] = 780,
  [4617] = 886,
  [4618] = 838,
  [4619] = 868,
  [4620] = 1130,
  [4621] = 1247,
  [4622] = 645,
  [4623] = 1076,
  [4624] = 1131,
  [4625] = 1077,
  [4626] = 940,
  [4627] = 1229,
  [4628] = 1036,
  [4629] = 1204,
  [4630] = 887,
  [4631] = 890,
  [4632] = 1254,
  [4633] = 724,
  [4634] = 781,
  [4635] = 1195,
  [4636] = 1079,
  [4637] = 855,
  [4638] = 805,
  [4639] = 850,
  [4640] = 1230,
  [4641] = 1215,
  [4642] = 1044,
  [4643] = 782,
  [4644] = 798,
  [4645] = 1206,
  [4646] = 1239,
  [4647] = 1081,
  [4648] = 1238,
  [4649] = 799,
  [4650] = 1034,
  [4651] = 1035,
  [4652] = 1082,
  [4653] = 806,
  [4654] = 1045,
  [4655] = 783,
  [4656] = 784,
  [4657] = 1037,
  [4658] = 1231,
  [4659] = 1038,
  [4660] = 798,
  [4661] = 1046,
  [4662] = 1039,
  [4663] = 1040,
  [4664] = 1047,
  [4665] = 1086,
  [4666] = 1048,
  [4667] = 1041,
  [4668] = 783,
  [4669] = 1232,
  [4670] = 1233,
  [4671] = 4671,
  [4672] = 1049,
  [4673] = 735,
  [4674] = 936,
  [4675] = 741,
  [4676] = 1042,
  [4677] = 799,
  [4678] = 1043,
  [4679] = 824,
  [4680] = 1044,
  [4681] = 785,
  [4682] = 859,
  [4683] = 1046,
  [4684] = 1213,
  [4685] = 1051,
  [4686] = 967,
  [4687] = 793,
  [4688] = 816,
  [4689] = 1219,
  [4690] = 761,
  [4691] = 1069,
  [4692] = 1089,
  [4693] = 1185,
  [4694] = 1070,
  [4695] = 1132,
  [4696] = 1209,
  [4697] = 810,
  [4698] = 839,
  [4699] = 1188,
  [4700] = 1205,
  [4701] = 1211,
  [4702] = 803,
  [4703] = 1183,
  [4704] = 840,
  [4705] = 811,
  [4706] = 1047,
  [4707] = 804,
  [4708] = 1048,
  [4709] = 842,
  [4710] = 843,
  [4711] = 1207,
  [4712] = 1241,
  [4713] = 1256,
  [4714] = 4714,
  [4715] = 1213,
  [4716] = 1151,
  [4717] = 1179,
  [4718] = 1053,
  [4719] = 937,
  [4720] = 1054,
  [4721] = 4721,
  [4722] = 1245,
  [4723] = 1176,
  [4724] = 1250,
  [4725] = 1049,
  [4726] = 1055,
  [4727] = 938,
  [4728] = 1190,
  [4729] = 1211,
  [4730] = 800,
  [4731] = 807,
  [4732] = 642,
  [4733] = 2328,
  [4734] = 1233,
  [4735] = 1036,
  [4736] = 1045,
  [4737] = 1067,
  [4738] = 1244,
  [4739] = 772,
  [4740] = 1168,
  [4741] = 857,
  [4742] = 797,
  [4743] = 1036,
  [4744] = 808,
  [4745] = 1242,
  [4746] = 862,
  [4747] = 1162,
  [4748] = 871,
  [4749] = 1045,
  [4750] = 1067,
  [4751] = 1126,
  [4752] = 1036,
  [4753] = 1200,
  [4754] = 1051,
  [4755] = 1192,
  [4756] = 1151,
  [4757] = 1045,
  [4758] = 824,
  [4759] = 4759,
  [4760] = 841,
  [4761] = 796,
  [4762] = 809,
  [4763] = 845,
  [4764] = 1217,
  [4765] = 1220,
  [4766] = 825,
  [4767] = 810,
  [4768] = 1067,
  [4769] = 1253,
  [4770] = 1053,
  [4771] = 1054,
  [4772] = 1071,
  [4773] = 1055,
  [4774] = 846,
  [4775] = 1091,
  [4776] = 827,
  [4777] = 825,
  [4778] = 811,
  [4779] = 835,
  [4780] = 4780,
  [4781] = 4781,
  [4782] = 1073,
  [4783] = 1193,
  [4784] = 1231,
  [4785] = 836,
  [4786] = 1056,
  [4787] = 1106,
  [4788] = 816,
  [4789] = 1093,
  [4790] = 1058,
  [4791] = 847,
  [4792] = 1091,
  [4793] = 785,
  [4794] = 674,
  [4795] = 826,
  [4796] = 1092,
  [4797] = 1027,
  [4798] = 1093,
  [4799] = 786,
  [4800] = 1244,
  [4801] = 1255,
  [4802] = 845,
  [4803] = 812,
  [4804] = 846,
  [4805] = 1247,
  [4806] = 1194,
  [4807] = 813,
  [4808] = 814,
  [4809] = 787,
  [4810] = 847,
  [4811] = 1094,
  [4812] = 100,
  [4813] = 1239,
  [4814] = 791,
  [4815] = 818,
  [4816] = 812,
  [4817] = 1096,
  [4818] = 823,
  [4819] = 849,
  [4820] = 893,
  [4821] = 1097,
  [4822] = 801,
  [4823] = 643,
  [4824] = 1094,
  [4825] = 833,
  [4826] = 849,
  [4827] = 851,
  [4828] = 724,
  [4829] = 794,
  [4830] = 818,
  [4831] = 837,
  [4832] = 1099,
  [4833] = 817,
  [4834] = 767,
  [4835] = 788,
  [4836] = 1233,
  [4837] = 792,
  [4838] = 1187,
  [4839] = 1201,
  [4840] = 1224,
  [4841] = 1191,
  [4842] = 856,
  [4843] = 1096,
  [4844] = 654,
  [4845] = 826,
  [4846] = 1163,
  [4847] = 1101,
  [4848] = 1202,
  [4849] = 1102,
  [4850] = 753,
  [4851] = 1097,
  [4852] = 1186,
  [4853] = 853,
  [4854] = 802,
  [4855] = 854,
  [4856] = 645,
  [4857] = 855,
  [4858] = 1201,
  [4859] = 1103,
  [4860] = 1226,
  [4861] = 856,
  [4862] = 1208,
  [4863] = 800,
  [4864] = 958,
  [4865] = 654,
  [4866] = 848,
  [4867] = 830,
  [4868] = 1075,
  [4869] = 1104,
  [4870] = 1138,
  [4871] = 4871,
  [4872] = 1196,
  [4873] = 753,
  [4874] = 863,
  [4875] = 1139,
  [4876] = 869,
  [4877] = 1099,
  [4878] = 1236,
  [4879] = 864,
  [4880] = 859,
  [4881] = 1140,
  [4882] = 1067,
  [4883] = 674,
  [4884] = 1181,
  [4885] = 830,
  [4886] = 1141,
  [4887] = 813,
  [4888] = 1210,
  [4889] = 805,
  [4890] = 1184,
  [4891] = 852,
  [4892] = 857,
  [4893] = 1186,
  [4894] = 738,
  [4895] = 1160,
  [4896] = 967,
  [4897] = 836,
  [4898] = 789,
  [4899] = 1034,
  [4900] = 865,
  [4901] = 1225,
  [4902] = 1037,
  [4903] = 1038,
  [4904] = 1039,
  [4905] = 1040,
  [4906] = 1041,
  [4907] = 735,
  [4908] = 1252,
  [4909] = 4909,
  [4910] = 1142,
  [4911] = 844,
  [4912] = 1143,
  [4913] = 1042,
  [4914] = 858,
  [4915] = 1043,
  [4916] = 1208,
  [4917] = 1076,
  [4918] = 806,
  [4919] = 858,
  [4920] = 1101,
  [4921] = 1077,
  [4922] = 839,
  [4923] = 1079,
  [4924] = 1243,
  [4925] = 769,
  [4926] = 842,
  [4927] = 651,
  [4928] = 1242,
  [4929] = 1056,
  [4930] = 784,
  [4931] = 1081,
  [4932] = 1058,
  [4933] = 862,
  [4934] = 863,
  [4935] = 1248,
  [4936] = 864,
  [4937] = 1082,
  [4938] = 1176,
  [4939] = 814,
  [4940] = 865,
  [4941] = 878,
  [4942] = 1190,
  [4943] = 807,
  [4944] = 1246,
  [4945] = 1164,
  [4946] = 843,
  [4947] = 866,
  [4948] = 851,
  [4949] = 808,
  [4950] = 867,
  [4951] = 1126,
  [4952] = 4952,
  [4953] = 1256,
  [4954] = 1191,
  [4955] = 815,
  [4956] = 4956,
  [4957] = 1199,
  [4958] = 869,
  [4959] = 852,
  [4960] = 1165,
  [4961] = 1157,
  [4962] = 1110,
  [4963] = 870,
  [4964] = 871,
  [4965] = 1166,
  [4966] = 872,
  [4967] = 1206,
  [4968] = 1160,
  [4969] = 801,
  [4970] = 642,
  [4971] = 837,
  [4972] = 834,
  [4973] = 844,
  [4974] = 802,
  [4975] = 1144,
  [4976] = 873,
  [4977] = 848,
  [4978] = 1218,
  [4979] = 827,
  [4980] = 706,
  [4981] = 1162,
  [4982] = 1146,
  [4983] = 734,
  [4984] = 741,
  [4985] = 874,
  [4986] = 1138,
  [4987] = 651,
  [4988] = 1124,
  [4989] = 787,
  [4990] = 1139,
  [4991] = 803,
  [4992] = 738,
  [4993] = 1217,
  [4994] = 1220,
  [4995] = 1222,
  [4996] = 841,
  [4997] = 790,
  [4998] = 1147,
  [4999] = 1140,
  [5000] = 1223,
  [5001] = 1128,
  [5002] = 1137,
  [5003] = 788,
  [5004] = 1148,
  [5005] = 1030,
  [5006] = 1149,
  [5007] = 1150,
  [5008] = 893,
  [5009] = 791,
  [5010] = 792,
  [5011] = 868,
  [5012] = 1133,
  [5013] = 1134,
  [5014] = 829,
  [5015] = 1135,
  [5016] = 1145,
  [5017] = 1141,
  [5018] = 1219,
  [5019] = 1129,
  [5020] = 1194,
  [5021] = 101,
  [5022] = 1241,
  [5023] = 793,
  [5024] = 768,
  [5025] = 770,
  [5026] = 866,
  [5027] = 771,
  [5028] = 1142,
  [5029] = 1143,
  [5030] = 1227,
  [5031] = 1202,
  [5032] = 1092,
  [5033] = 1237,
  [5034] = 1210,
  [5035] = 1225,
  [5036] = 1243,
  [5037] = 794,
  [5038] = 795,
  [5039] = 1179,
  [5040] = 1246,
  [5041] = 1188,
  [5042] = 1205,
  [5043] = 1057,
  [5044] = 760,
  [5045] = 817,
  [5046] = 1248,
  [5047] = 1102,
  [5048] = 870,
  [5049] = 5049,
  [5050] = 1103,
  [5051] = 867,
  [5052] = 1249,
  [5053] = 761,
  [5054] = 1250,
  [5055] = 1153,
  [5056] = 1104,
  [5057] = 646,
  [5058] = 1144,
  [5059] = 1234,
  [5060] = 872,
  [5061] = 895,
  [5062] = 1156,
  [5063] = 1064,
  [5064] = 773,
  [5065] = 1069,
  [5066] = 878,
  [5067] = 768,
  [5068] = 873,
  [5069] = 853,
  [5070] = 706,
  [5071] = 1070,
  [5072] = 1071,
  [5073] = 1157,
  [5074] = 1030,
  [5075] = 1052,
  [5076] = 879,
  [5077] = 734,
  [5078] = 1222,
  [5079] = 1223,
  [5080] = 1252,
  [5081] = 1073,
  [5082] = 1086,
  [5083] = 1052,
  [5084] = 938,
  [5085] = 880,
  [5086] = 1163,
  [5087] = 1227,
  [5088] = 881,
  [5089] = 1237,
  [5090] = 1192,
  [5091] = 823,
  [5092] = 937,
  [5093] = 789,
  [5094] = 795,
  [5095] = 779,
  [5096] = 1061,
  [5097] = 958,
  [5098] = 1178,
  [5099] = 882,
  [5100] = 879,
  [5101] = 831,
  [5102] = 832,
  [5103] = 760,
  [5104] = 1229,
  [5105] = 1187,
  [5106] = 883,
  [5107] = 880,
  [5108] = 1253,
  [5109] = 881,
  [5110] = 1061,
  [5111] = 766,
  [5112] = 1230,
  [5113] = 1089,
  [5114] = 1232,
  [5115] = 884,
  [5116] = 831,
  [5117] = 882,
  [5118] = 1133,
  [5119] = 885,
  [5120] = 1234,
  [5121] = 874,
  [5122] = 884,
  [5123] = 854,
  [5124] = 832,
  [5125] = 780,
  [5126] = 886,
  [5127] = 1199,
  [5128] = 888,
  [5129] = 815,
  [5130] = 1134,
  [5131] = 887,
  [5132] = 888,
  [5133] = 643,
  [5134] = 1238,
  [5135] = 1135,
  [5136] = 889,
  [5137] = 889,
  [5138] = 1183,
  [5139] = 666,
  [5140] = 1145,
  [5141] = 668,
  [5142] = 772,
  [5143] = 833,
  [5144] = 1249,
  [5145] = 890,
  [5146] = 1153,
  [5147] = 1203,
  [5148] = 1181,
  [5149] = 940,
  [5150] = 5150,
  [5151] = 1109,
  [5152] = 1110,
  [5153] = 1111,
  [5154] = 5154,
  [5155] = 1062,
  [5156] = 1146,
  [5157] = 1147,
  [5158] = 796,
  [5159] = 1148,
  [5160] = 1149,
  [5161] = 1150,
  [5162] = 1207,
  [5163] = 895,
  [5164] = 716,
  [5165] = 1156,
  [5166] = 666,
  [5167] = 775,
  [5168] = 668,
  [5169] = 1236,
  [5170] = 1203,
  [5171] = 1195,
  [5172] = 1255,
  [5173] = 834,
  [5174] = 829,
  [5175] = 896,
  [5176] = 897,
  [5177] = 1184,
  [5178] = 900,
  [5179] = 1062,
  [5180] = 902,
  [5181] = 1172,
  [5182] = 896,
  [5183] = 929,
  [5184] = 1164,
  [5185] = 897,
  [5186] = 850,
  [5187] = 775,
  [5188] = 1165,
  [5189] = 1057,
  [5190] = 1173,
  [5191] = 1254,
  [5192] = 1173,
  [5193] = 809,
  [5194] = 900,
  [5195] = 1106,
  [5196] = 769,
  [5197] = 835,
  [5198] = 902,
  [5199] = 1166,
  [5200] = 929,
  [5201] = 936,
  [5202] = 1130,
  [5203] = 766,
  [5204] = 1075,
  [5205] = 716,
  [5206] = 786,
  [5207] = 1200,
  [5208] = 1193,
  [5209] = 1204,
  [5210] = 838,
  [5211] = 776,
  [5212] = 1209,
  [5213] = 777,
  [5214] = 778,
  [5215] = 781,
  [5216] = 776,
  [5217] = 1233,
  [5218] = 1124,
  [5219] = 1109,
  [5220] = 117,
  [5221] = 103,
  [5222] = 5222,
  [5223] = 102,
  [5224] = 3313,
  [5225] = 3316,
  [5226] = 2328,
  [5227] = 3313,
  [5228] = 3316,
  [5229] = 5229,
  [5230] = 103,
  [5231] = 102,
  [5232] = 5232,
  [5233] = 100,
  [5234] = 101,
  [5235] = 5235,
  [5236] = 5236,
  [5237] = 5237,
  [5238] = 5238,
  [5239] = 5239,
  [5240] = 5240,
  [5241] = 103,
  [5242] = 5238,
  [5243] = 5239,
  [5244] = 5240,
  [5245] = 5238,
  [5246] = 5238,
  [5247] = 5239,
  [5248] = 5240,
  [5249] = 5238,
  [5250] = 5239,
  [5251] = 5240,
  [5252] = 5238,
  [5253] = 5239,
  [5254] = 5240,
  [5255] = 5238,
  [5256] = 5239,
  [5257] = 5240,
  [5258] = 5238,
  [5259] = 5239,
  [5260] = 5240,
  [5261] = 102,
  [5262] = 5239,
  [5263] = 5240,
  [5264] = 5240,
  [5265] = 5239,
  [5266] = 5236,
  [5267] = 5238,
  [5268] = 5239,
  [5269] = 5240,
  [5270] = 5238,
  [5271] = 5239,
  [5272] = 5240,
  [5273] = 5238,
  [5274] = 5239,
  [5275] = 5240,
  [5276] = 5238,
  [5277] = 5239,
  [5278] = 5240,
  [5279] = 5238,
  [5280] = 5239,
  [5281] = 5240,
  [5282] = 5238,
  [5283] = 5239,
  [5284] = 5240,
  [5285] = 5238,
  [5286] = 5239,
  [5287] = 5240,
  [5288] = 5238,
  [5289] = 103,
  [5290] = 102,
  [5291] = 5291,
  [5292] = 5292,
  [5293] = 5293,
  [5294] = 5291,
  [5295] = 5295,
  [5296] = 5296,
  [5297] = 5297,
  [5298] = 5298,
  [5299] = 102,
  [5300] = 103,
  [5301] = 5301,
  [5302] = 5302,
  [5303] = 5303,
  [5304] = 5304,
  [5305] = 5305,
  [5306] = 5306,
  [5307] = 5307,
  [5308] = 5308,
  [5309] = 5309,
  [5310] = 5310,
  [5311] = 5303,
  [5312] = 5312,
  [5313] = 5313,
  [5314] = 5314,
  [5315] = 5309,
  [5316] = 5305,
  [5317] = 5317,
  [5318] = 5318,
  [5319] = 5319,
  [5320] = 5318,
  [5321] = 5319,
  [5322] = 5318,
  [5323] = 5317,
  [5324] = 5319,
  [5325] = 5325,
  [5326] = 5325,
  [5327] = 5318,
  [5328] = 5317,
  [5329] = 5319,
  [5330] = 5325,
  [5331] = 5317,
  [5332] = 5318,
  [5333] = 5317,
  [5334] = 5325,
  [5335] = 5319,
  [5336] = 5325,
  [5337] = 5319,
  [5338] = 5319,
  [5339] = 5325,
  [5340] = 5318,
  [5341] = 5317,
  [5342] = 5319,
  [5343] = 5319,
  [5344] = 5318,
  [5345] = 5318,
  [5346] = 5317,
  [5347] = 5325,
  [5348] = 5317,
  [5349] = 5319,
  [5350] = 5325,
  [5351] = 5318,
  [5352] = 5317,
  [5353] = 5325,
  [5354] = 5325,
  [5355] = 5317,
  [5356] = 5325,
  [5357] = 5318,
  [5358] = 5318,
  [5359] = 5319,
  [5360] = 5318,
  [5361] = 5319,
  [5362] = 5317,
  [5363] = 5363,
  [5364] = 5364,
  [5365] = 5365,
  [5366] = 5366,
  [5367] = 5367,
  [5368] = 5368,
  [5369] = 5369,
  [5370] = 5370,
  [5371] = 5371,
  [5372] = 5363,
  [5373] = 5373,
  [5374] = 5374,
  [5375] = 5375,
  [5376] = 5376,
  [5377] = 5377,
  [5378] = 5378,
  [5379] = 5379,
  [5380] = 5380,
  [5381] = 5381,
  [5382] = 5382,
  [5383] = 5383,
  [5384] = 5384,
  [5385] = 5385,
  [5386] = 5386,
  [5387] = 5387,
  [5388] = 5364,
  [5389] = 5370,
  [5390] = 5390,
  [5391] = 5391,
  [5392] = 5392,
  [5393] = 5393,
  [5394] = 5394,
  [5395] = 5395,
  [5396] = 5396,
  [5397] = 5236,
  [5398] = 5398,
  [5399] = 5399,
  [5400] = 837,
  [5401] = 645,
  [5402] = 855,
  [5403] = 834,
  [5404] = 5404,
  [5405] = 848,
  [5406] = 651,
  [5407] = 5407,
  [5408] = 5408,
  [5409] = 5409,
  [5410] = 836,
  [5411] = 642,
  [5412] = 844,
  [5413] = 857,
  [5414] = 5414,
  [5415] = 724,
  [5416] = 840,
  [5417] = 5417,
  [5418] = 5418,
  [5419] = 103,
  [5420] = 883,
  [5421] = 674,
  [5422] = 893,
  [5423] = 646,
  [5424] = 773,
  [5425] = 102,
  [5426] = 738,
  [5427] = 5427,
  [5428] = 5428,
  [5429] = 5429,
  [5430] = 826,
  [5431] = 643,
  [5432] = 5432,
  [5433] = 5433,
  [5434] = 833,
  [5435] = 5435,
  [5436] = 5436,
  [5437] = 5437,
  [5438] = 5438,
  [5439] = 5439,
  [5440] = 5440,
  [5441] = 5441,
  [5442] = 5442,
  [5443] = 5443,
  [5444] = 2328,
  [5445] = 5445,
  [5446] = 5446,
  [5447] = 5447,
  [5448] = 5448,
  [5449] = 5449,
  [5450] = 5450,
  [5451] = 5451,
  [5452] = 5452,
  [5453] = 5453,
  [5454] = 5454,
  [5455] = 5455,
  [5456] = 5291,
  [5457] = 5457,
  [5458] = 5458,
  [5459] = 5459,
  [5460] = 5380,
  [5461] = 5387,
  [5462] = 5462,
  [5463] = 5371,
  [5464] = 5365,
  [5465] = 5465,
  [5466] = 5466,
  [5467] = 5467,
  [5468] = 5365,
  [5469] = 5469,
  [5470] = 5470,
  [5471] = 5471,
  [5472] = 5366,
  [5473] = 5473,
  [5474] = 103,
  [5475] = 102,
  [5476] = 5378,
  [5477] = 5384,
  [5478] = 5366,
  [5479] = 5479,
  [5480] = 5480,
  [5481] = 3313,
  [5482] = 5482,
  [5483] = 5483,
  [5484] = 5484,
  [5485] = 5485,
  [5486] = 5486,
  [5487] = 5487,
  [5488] = 5488,
  [5489] = 5489,
  [5490] = 5490,
  [5491] = 5491,
  [5492] = 5492,
  [5493] = 5493,
  [5494] = 5494,
  [5495] = 3316,
  [5496] = 5496,
  [5497] = 5497,
  [5498] = 5498,
  [5499] = 5499,
  [5500] = 2328,
  [5501] = 5501,
  [5502] = 5502,
  [5503] = 5503,
  [5504] = 5504,
  [5505] = 5505,
  [5506] = 5297,
  [5507] = 5507,
  [5508] = 5508,
  [5509] = 5298,
  [5510] = 5510,
  [5511] = 5511,
  [5512] = 5512,
  [5513] = 5513,
  [5514] = 5514,
  [5515] = 5306,
  [5516] = 5516,
  [5517] = 5517,
  [5518] = 5518,
  [5519] = 5519,
  [5520] = 5396,
  [5521] = 5521,
  [5522] = 5398,
  [5523] = 5523,
  [5524] = 5524,
  [5525] = 5525,
  [5526] = 5526,
  [5527] = 5527,
  [5528] = 5396,
  [5529] = 5398,
  [5530] = 117,
  [5531] = 5531,
  [5532] = 5532,
  [5533] = 5533,
  [5534] = 5534,
  [5535] = 5535,
  [5536] = 5536,
  [5537] = 5537,
  [5538] = 5538,
  [5539] = 5539,
  [5540] = 5540,
  [5541] = 5395,
  [5542] = 3316,
  [5543] = 5543,
  [5544] = 5544,
  [5545] = 5427,
  [5546] = 5546,
  [5547] = 5547,
  [5548] = 5548,
  [5549] = 5549,
  [5550] = 5399,
  [5551] = 5551,
  [5552] = 103,
  [5553] = 5553,
  [5554] = 5554,
  [5555] = 5555,
  [5556] = 5556,
  [5557] = 5557,
  [5558] = 102,
  [5559] = 5559,
  [5560] = 5560,
  [5561] = 5561,
  [5562] = 5562,
  [5563] = 5563,
  [5564] = 5564,
  [5565] = 5565,
  [5566] = 5566,
  [5567] = 5567,
  [5568] = 5568,
  [5569] = 5569,
  [5570] = 5570,
  [5571] = 5429,
  [5572] = 5483,
  [5573] = 5432,
  [5574] = 5574,
  [5575] = 5575,
  [5576] = 5576,
  [5577] = 5433,
  [5578] = 5407,
  [5579] = 5579,
  [5580] = 5580,
  [5581] = 5581,
  [5582] = 5582,
  [5583] = 5583,
  [5584] = 5584,
  [5585] = 5585,
  [5586] = 3313,
  [5587] = 5587,
  [5588] = 2328,
  [5589] = 5589,
  [5590] = 5590,
  [5591] = 5591,
  [5592] = 5592,
  [5593] = 5593,
  [5594] = 5594,
  [5595] = 5595,
  [5596] = 5596,
  [5597] = 5597,
  [5598] = 5598,
  [5599] = 5599,
  [5600] = 5600,
  [5601] = 5601,
  [5602] = 5602,
  [5603] = 5603,
  [5604] = 5604,
  [5605] = 5605,
  [5606] = 5606,
  [5607] = 5418,
  [5608] = 5608,
  [5609] = 5409,
  [5610] = 5610,
  [5611] = 101,
  [5612] = 100,
  [5613] = 5613,
  [5614] = 5614,
  [5615] = 5615,
  [5616] = 5616,
  [5617] = 5617,
  [5618] = 5618,
  [5619] = 5619,
  [5620] = 5620,
  [5621] = 5621,
  [5622] = 5622,
  [5623] = 5623,
  [5624] = 5624,
  [5625] = 5625,
  [5626] = 5626,
  [5627] = 5627,
  [5628] = 5628,
  [5629] = 5629,
  [5630] = 5630,
  [5631] = 5631,
  [5632] = 5632,
  [5633] = 5633,
  [5634] = 5634,
  [5635] = 5635,
  [5636] = 5636,
  [5637] = 5637,
  [5638] = 5638,
  [5639] = 5639,
  [5640] = 5640,
  [5641] = 5641,
  [5642] = 5642,
  [5643] = 5643,
  [5644] = 5644,
  [5645] = 5645,
  [5646] = 5646,
  [5647] = 5647,
  [5648] = 5648,
  [5649] = 5303,
  [5650] = 5650,
  [5651] = 5651,
  [5652] = 5652,
  [5653] = 5653,
  [5654] = 5654,
  [5655] = 5655,
  [5656] = 5656,
  [5657] = 5657,
  [5658] = 5658,
  [5659] = 5659,
  [5660] = 5660,
  [5661] = 5661,
  [5662] = 5662,
  [5663] = 5663,
  [5664] = 5664,
  [5665] = 5665,
  [5666] = 5309,
  [5667] = 5667,
  [5668] = 5668,
  [5669] = 5305,
  [5670] = 5670,
  [5671] = 5671,
  [5672] = 5628,
  [5673] = 2328,
  [5674] = 5656,
  [5675] = 5624,
  [5676] = 5676,
  [5677] = 5617,
  [5678] = 5618,
  [5679] = 5619,
  [5680] = 5620,
  [5681] = 5621,
  [5682] = 5622,
  [5683] = 5623,
  [5684] = 5671,
  [5685] = 5625,
  [5686] = 5627,
  [5687] = 5687,
  [5688] = 3316,
  [5689] = 3313,
  [5690] = 5629,
  [5691] = 5630,
  [5692] = 5631,
  [5693] = 5632,
  [5694] = 5633,
  [5695] = 5634,
  [5696] = 5635,
  [5697] = 5636,
  [5698] = 5637,
  [5699] = 5638,
  [5700] = 5639,
  [5701] = 5640,
  [5702] = 103,
  [5703] = 5641,
  [5704] = 102,
  [5705] = 651,
  [5706] = 857,
  [5707] = 5408,
  [5708] = 837,
  [5709] = 834,
  [5710] = 848,
  [5711] = 5687,
  [5712] = 674,
  [5713] = 5435,
  [5714] = 836,
  [5715] = 642,
  [5716] = 844,
  [5717] = 645,
  [5718] = 738,
  [5719] = 5428,
  [5720] = 855,
  [5721] = 840,
  [5722] = 893,
  [5723] = 5232,
  [5724] = 646,
  [5725] = 773,
  [5726] = 826,
  [5727] = 643,
  [5728] = 833,
  [5729] = 883,
  [5730] = 724,
  [5731] = 5296,
  [5732] = 5236,
  [5733] = 3316,
  [5734] = 3313,
  [5735] = 5236,
  [5736] = 5736,
  [5737] = 5236,
  [5738] = 5370,
  [5739] = 5364,
  [5740] = 5363,
  [5741] = 5741,
  [5742] = 5742,
  [5743] = 5743,
  [5744] = 102,
  [5745] = 103,
  [5746] = 5746,
  [5747] = 5235,
  [5748] = 5748,
  [5749] = 5237,
  [5750] = 5750,
  [5751] = 5751,
  [5752] = 5291,
  [5753] = 5291,
  [5754] = 5754,
  [5755] = 5755,
  [5756] = 5756,
  [5757] = 5757,
  [5758] = 5758,
  [5759] = 5755,
  [5760] = 5236,
  [5761] = 5291,
  [5762] = 5762,
  [5763] = 5365,
  [5764] = 5366,
  [5765] = 5237,
  [5766] = 5766,
  [5767] = 5298,
  [5768] = 5295,
  [5769] = 5297,
  [5770] = 5305,
  [5771] = 5303,
  [5772] = 5309,
  [5773] = 5773,
  [5774] = 5395,
  [5775] = 5291,
  [5776] = 5396,
  [5777] = 5306,
  [5778] = 5309,
  [5779] = 5398,
  [5780] = 5303,
  [5781] = 5305,
  [5782] = 5418,
  [5783] = 5432,
  [5784] = 5309,
  [5785] = 5305,
  [5786] = 5409,
  [5787] = 5303,
  [5788] = 5407,
  [5789] = 5433,
  [5790] = 5371,
  [5791] = 5380,
  [5792] = 5387,
  [5793] = 5427,
  [5794] = 5384,
  [5795] = 5521,
  [5796] = 5378,
  [5797] = 5429,
  [5798] = 5399,
  [5799] = 2328,
  [5800] = 5232,
  [5801] = 5304,
  [5802] = 5308,
  [5803] = 5301,
  [5804] = 5307,
  [5805] = 5295,
  [5806] = 5302,
  [5807] = 5807,
  [5808] = 103,
  [5809] = 5809,
  [5810] = 102,
  [5811] = 5811,
  [5812] = 5812,
  [5813] = 5236,
  [5814] = 5814,
  [5815] = 5815,
  [5816] = 5816,
  [5817] = 5236,
  [5818] = 5370,
  [5819] = 5363,
  [5820] = 5364,
  [5821] = 5309,
  [5822] = 5370,
  [5823] = 5305,
  [5824] = 3313,
  [5825] = 3316,
  [5826] = 5363,
  [5827] = 5303,
  [5828] = 5828,
  [5829] = 5364,
  [5830] = 5830,
  [5831] = 5830,
  [5832] = 5830,
  [5833] = 102,
  [5834] = 5830,
  [5835] = 5830,
  [5836] = 5830,
  [5837] = 5830,
  [5838] = 5830,
  [5839] = 5830,
  [5840] = 5830,
  [5841] = 5235,
  [5842] = 5236,
  [5843] = 5830,
  [5844] = 5830,
  [5845] = 5830,
  [5846] = 5830,
  [5847] = 5830,
  [5848] = 103,
  [5849] = 5291,
  [5850] = 5237,
  [5851] = 102,
  [5852] = 5368,
  [5853] = 103,
  [5854] = 5369,
  [5855] = 2328,
  [5856] = 5291,
  [5857] = 5857,
  [5858] = 5236,
  [5859] = 5383,
  [5860] = 5236,
  [5861] = 5393,
  [5862] = 5368,
  [5863] = 5379,
  [5864] = 5676,
  [5865] = 5369,
  [5866] = 5866,
  [5867] = 5391,
  [5868] = 5376,
  [5869] = 5375,
  [5870] = 5390,
  [5871] = 5373,
  [5872] = 5392,
  [5873] = 746,
  [5874] = 756,
  [5875] = 733,
  [5876] = 743,
  [5877] = 732,
  [5878] = 736,
  [5879] = 745,
  [5880] = 737,
  [5881] = 757,
  [5882] = 726,
  [5883] = 727,
  [5884] = 729,
  [5885] = 759,
  [5886] = 744,
  [5887] = 747,
  [5888] = 103,
  [5889] = 102,
  [5890] = 758,
  [5891] = 5891,
  [5892] = 710,
  [5893] = 728,
  [5894] = 704,
  [5895] = 708,
  [5896] = 739,
  [5897] = 713,
  [5898] = 667,
  [5899] = 740,
  [5900] = 675,
  [5901] = 754,
  [5902] = 657,
  [5903] = 673,
  [5904] = 718,
  [5905] = 5404,
  [5906] = 762,
  [5907] = 5365,
  [5908] = 763,
  [5909] = 721,
  [5910] = 5291,
  [5911] = 722,
  [5912] = 712,
  [5913] = 697,
  [5914] = 698,
  [5915] = 764,
  [5916] = 765,
  [5917] = 5366,
  [5918] = 730,
  [5919] = 705,
  [5920] = 749,
  [5921] = 663,
  [5922] = 742,
  [5923] = 723,
  [5924] = 731,
  [5925] = 5366,
  [5926] = 700,
  [5927] = 3316,
  [5928] = 5237,
  [5929] = 752,
  [5930] = 725,
  [5931] = 680,
  [5932] = 703,
  [5933] = 677,
  [5934] = 5414,
  [5935] = 5417,
  [5936] = 661,
  [5937] = 3313,
  [5938] = 694,
  [5939] = 701,
  [5940] = 755,
  [5941] = 669,
  [5942] = 1198,
  [5943] = 748,
  [5944] = 711,
  [5945] = 679,
  [5946] = 715,
  [5947] = 686,
  [5948] = 5365,
  [5949] = 5949,
  [5950] = 655,
  [5951] = 671,
  [5952] = 695,
  [5953] = 714,
  [5954] = 683,
  [5955] = 688,
  [5956] = 691,
  [5957] = 719,
  [5958] = 682,
  [5959] = 699,
  [5960] = 702,
  [5961] = 660,
  [5962] = 662,
  [5963] = 685,
  [5964] = 687,
  [5965] = 689,
  [5966] = 696,
  [5967] = 799,
  [5968] = 5521,
  [5969] = 852,
  [5970] = 783,
  [5971] = 651,
  [5972] = 869,
  [5973] = 815,
  [5974] = 870,
  [5975] = 784,
  [5976] = 825,
  [5977] = 874,
  [5978] = 5427,
  [5979] = 5298,
  [5980] = 885,
  [5981] = 886,
  [5982] = 787,
  [5983] = 887,
  [5984] = 890,
  [5985] = 836,
  [5986] = 642,
  [5987] = 844,
  [5988] = 788,
  [5989] = 5384,
  [5990] = 850,
  [5991] = 789,
  [5992] = 776,
  [5993] = 5429,
  [5994] = 790,
  [5995] = 5371,
  [5996] = 827,
  [5997] = 936,
  [5998] = 794,
  [5999] = 937,
  [6000] = 938,
  [6001] = 795,
  [6002] = 772,
  [6003] = 1212,
  [6004] = 1264,
  [6005] = 1272,
  [6006] = 780,
  [6007] = 777,
  [6008] = 781,
  [6009] = 782,
  [6010] = 835,
  [6011] = 785,
  [6012] = 5447,
  [6013] = 791,
  [6014] = 792,
  [6015] = 796,
  [6016] = 793,
  [6017] = 800,
  [6018] = 801,
  [6019] = 802,
  [6020] = 5436,
  [6021] = 808,
  [6022] = 5380,
  [6023] = 5440,
  [6024] = 6024,
  [6025] = 6025,
  [6026] = 6026,
  [6027] = 6027,
  [6028] = 6028,
  [6029] = 857,
  [6030] = 846,
  [6031] = 769,
  [6032] = 797,
  [6033] = 847,
  [6034] = 893,
  [6035] = 778,
  [6036] = 5297,
  [6037] = 5399,
  [6038] = 646,
  [6039] = 816,
  [6040] = 840,
  [6041] = 773,
  [6042] = 798,
  [6043] = 5443,
  [6044] = 6044,
  [6045] = 803,
  [6046] = 804,
  [6047] = 5298,
  [6048] = 5297,
  [6049] = 5433,
  [6050] = 805,
  [6051] = 806,
  [6052] = 6052,
  [6053] = 807,
  [6054] = 849,
  [6055] = 5437,
  [6056] = 810,
  [6057] = 811,
  [6058] = 856,
  [6059] = 812,
  [6060] = 813,
  [6061] = 814,
  [6062] = 837,
  [6063] = 817,
  [6064] = 868,
  [6065] = 1265,
  [6066] = 1269,
  [6067] = 826,
  [6068] = 941,
  [6069] = 779,
  [6070] = 864,
  [6071] = 829,
  [6072] = 865,
  [6073] = 643,
  [6074] = 866,
  [6075] = 6044,
  [6076] = 833,
  [6077] = 834,
  [6078] = 838,
  [6079] = 1266,
  [6080] = 1268,
  [6081] = 6081,
  [6082] = 5432,
  [6083] = 867,
  [6084] = 1273,
  [6085] = 1257,
  [6086] = 5387,
  [6087] = 5438,
  [6088] = 872,
  [6089] = 6089,
  [6090] = 873,
  [6091] = 6091,
  [6092] = 6092,
  [6093] = 6093,
  [6094] = 6094,
  [6095] = 6095,
  [6096] = 6096,
  [6097] = 6097,
  [6098] = 6098,
  [6099] = 6099,
  [6100] = 6100,
  [6101] = 6101,
  [6102] = 6102,
  [6103] = 6103,
  [6104] = 880,
  [6105] = 5378,
  [6106] = 881,
  [6107] = 851,
  [6108] = 882,
  [6109] = 645,
  [6110] = 767,
  [6111] = 5409,
  [6112] = 5418,
  [6113] = 855,
  [6114] = 884,
  [6115] = 5442,
  [6116] = 888,
  [6117] = 859,
  [6118] = 848,
  [6119] = 889,
  [6120] = 897,
  [6121] = 900,
  [6122] = 1274,
  [6123] = 902,
  [6124] = 1276,
  [6125] = 2328,
  [6126] = 5407,
  [6127] = 1277,
  [6128] = 929,
  [6129] = 809,
  [6130] = 649,
  [6131] = 732,
  [6132] = 1015,
  [6133] = 5305,
  [6134] = 1017,
  [6135] = 736,
  [6136] = 5291,
  [6137] = 678,
  [6138] = 742,
  [6139] = 759,
  [6140] = 5291,
  [6141] = 648,
  [6142] = 751,
  [6143] = 5398,
  [6144] = 1158,
  [6145] = 719,
  [6146] = 5306,
  [6147] = 683,
  [6148] = 714,
  [6149] = 1031,
  [6150] = 5398,
  [6151] = 749,
  [6152] = 755,
  [6153] = 707,
  [6154] = 721,
  [6155] = 991,
  [6156] = 992,
  [6157] = 690,
  [6158] = 750,
  [6159] = 709,
  [6160] = 726,
  [6161] = 665,
  [6162] = 1078,
  [6163] = 1024,
  [6164] = 658,
  [6165] = 679,
  [6166] = 756,
  [6167] = 685,
  [6168] = 1013,
  [6169] = 681,
  [6170] = 5303,
  [6171] = 687,
  [6172] = 5309,
  [6173] = 754,
  [6174] = 727,
  [6175] = 5395,
  [6176] = 684,
  [6177] = 653,
  [6178] = 689,
  [6179] = 1090,
  [6180] = 5395,
  [6181] = 717,
  [6182] = 698,
  [6183] = 5291,
  [6184] = 5368,
  [6185] = 5369,
  [6186] = 663,
  [6187] = 744,
  [6188] = 747,
  [6189] = 692,
  [6190] = 722,
  [6191] = 718,
  [6192] = 723,
  [6193] = 686,
  [6194] = 1006,
  [6195] = 644,
  [6196] = 720,
  [6197] = 737,
  [6198] = 1010,
  [6199] = 1012,
  [6200] = 1088,
  [6201] = 731,
  [6202] = 664,
  [6203] = 725,
  [6204] = 680,
  [6205] = 752,
  [6206] = 711,
  [6207] = 745,
  [6208] = 652,
  [6209] = 1050,
  [6210] = 669,
  [6211] = 691,
  [6212] = 757,
  [6213] = 5295,
  [6214] = 696,
  [6215] = 704,
  [6216] = 1161,
  [6217] = 1136,
  [6218] = 712,
  [6219] = 702,
  [6220] = 697,
  [6221] = 659,
  [6222] = 667,
  [6223] = 675,
  [6224] = 729,
  [6225] = 758,
  [6226] = 5396,
  [6227] = 765,
  [6228] = 1084,
  [6229] = 762,
  [6230] = 660,
  [6231] = 693,
  [6232] = 990,
  [6233] = 994,
  [6234] = 708,
  [6235] = 740,
  [6236] = 657,
  [6237] = 670,
  [6238] = 661,
  [6239] = 694,
  [6240] = 730,
  [6241] = 650,
  [6242] = 672,
  [6243] = 673,
  [6244] = 763,
  [6245] = 677,
  [6246] = 662,
  [6247] = 1032,
  [6248] = 655,
  [6249] = 748,
  [6250] = 682,
  [6251] = 699,
  [6252] = 700,
  [6253] = 5396,
  [6254] = 715,
  [6255] = 5306,
  [6256] = 713,
  [6257] = 764,
  [6258] = 733,
  [6259] = 743,
  [6260] = 671,
  [6261] = 695,
  [6262] = 710,
  [6263] = 728,
  [6264] = 739,
  [6265] = 746,
  [6266] = 703,
  [6267] = 701,
  [6268] = 705,
  [6269] = 688,
  [6270] = 938,
  [6271] = 645,
  [6272] = 855,
  [6273] = 3313,
  [6274] = 654,
  [6275] = 5305,
  [6276] = 5365,
  [6277] = 753,
  [6278] = 859,
  [6279] = 674,
  [6280] = 1186,
  [6281] = 1034,
  [6282] = 1037,
  [6283] = 1038,
  [6284] = 1039,
  [6285] = 1040,
  [6286] = 1041,
  [6287] = 1042,
  [6288] = 1043,
  [6289] = 1208,
  [6290] = 5303,
  [6291] = 1056,
  [6292] = 1058,
  [6293] = 863,
  [6294] = 5366,
  [6295] = 5384,
  [6296] = 869,
  [6297] = 870,
  [6298] = 706,
  [6299] = 734,
  [6300] = 874,
  [6301] = 738,
  [6302] = 1222,
  [6303] = 1223,
  [6304] = 1227,
  [6305] = 1092,
  [6306] = 1237,
  [6307] = 1102,
  [6308] = 1103,
  [6309] = 1104,
  [6310] = 879,
  [6311] = 880,
  [6312] = 881,
  [6313] = 882,
  [6314] = 1036,
  [6315] = 1045,
  [6316] = 885,
  [6317] = 1067,
  [6318] = 886,
  [6319] = 887,
  [6320] = 666,
  [6321] = 668,
  [6322] = 890,
  [6323] = 1203,
  [6324] = 6324,
  [6325] = 1146,
  [6326] = 1147,
  [6327] = 1148,
  [6328] = 1149,
  [6329] = 1150,
  [6330] = 896,
  [6331] = 936,
  [6332] = 884,
  [6333] = 937,
  [6334] = 888,
  [6335] = 889,
  [6336] = 766,
  [6337] = 716,
  [6338] = 772,
  [6339] = 1200,
  [6340] = 1193,
  [6341] = 1157,
  [6342] = 1030,
  [6343] = 1052,
  [6344] = 1061,
  [6345] = 1062,
  [6346] = 6346,
  [6347] = 780,
  [6348] = 781,
  [6349] = 782,
  [6350] = 735,
  [6351] = 741,
  [6352] = 785,
  [6353] = 1176,
  [6354] = 1126,
  [6355] = 1106,
  [6356] = 1027,
  [6357] = 791,
  [6358] = 792,
  [6359] = 793,
  [6360] = 760,
  [6361] = 761,
  [6362] = 1086,
  [6363] = 1089,
  [6364] = 1109,
  [6365] = 1110,
  [6366] = 1111,
  [6367] = 800,
  [6368] = 801,
  [6369] = 802,
  [6370] = 1129,
  [6371] = 1130,
  [6372] = 1131,
  [6373] = 1132,
  [6374] = 808,
  [6375] = 1151,
  [6376] = 6376,
  [6377] = 857,
  [6378] = 1245,
  [6379] = 6379,
  [6380] = 6380,
  [6381] = 6381,
  [6382] = 816,
  [6383] = 840,
  [6384] = 897,
  [6385] = 6376,
  [6386] = 6386,
  [6387] = 900,
  [6388] = 6388,
  [6389] = 902,
  [6390] = 1234,
  [6391] = 929,
  [6392] = 837,
  [6393] = 817,
  [6394] = 1224,
  [6395] = 1226,
  [6396] = 834,
  [6397] = 850,
  [6398] = 864,
  [6399] = 769,
  [6400] = 5521,
  [6401] = 883,
  [6402] = 848,
  [6403] = 852,
  [6404] = 651,
  [6405] = 1247,
  [6406] = 940,
  [6407] = 1254,
  [6408] = 1206,
  [6409] = 1195,
  [6410] = 1239,
  [6411] = 1238,
  [6412] = 1187,
  [6413] = 5380,
  [6414] = 836,
  [6415] = 776,
  [6416] = 865,
  [6417] = 1236,
  [6418] = 1209,
  [6419] = 642,
  [6420] = 844,
  [6421] = 777,
  [6422] = 1196,
  [6423] = 1218,
  [6424] = 1188,
  [6425] = 1205,
  [6426] = 818,
  [6427] = 1183,
  [6428] = 1201,
  [6429] = 830,
  [6430] = 778,
  [6431] = 866,
  [6432] = 1207,
  [6433] = 1256,
  [6434] = 858,
  [6435] = 1213,
  [6436] = 1199,
  [6437] = 1249,
  [6438] = 1250,
  [6439] = 1252,
  [6440] = 1253,
  [6441] = 1255,
  [6442] = 1124,
  [6443] = 1128,
  [6444] = 1137,
  [6445] = 1215,
  [6446] = 779,
  [6447] = 783,
  [6448] = 784,
  [6449] = 867,
  [6450] = 967,
  [6451] = 839,
  [6452] = 1185,
  [6453] = 842,
  [6454] = 843,
  [6455] = 1241,
  [6456] = 1179,
  [6457] = 1190,
  [6458] = 1075,
  [6459] = 1076,
  [6460] = 1077,
  [6461] = 1079,
  [6462] = 1081,
  [6463] = 1082,
  [6464] = 1219,
  [6465] = 1211,
  [6466] = 768,
  [6467] = 770,
  [6468] = 771,
  [6469] = 1202,
  [6470] = 1210,
  [6471] = 1225,
  [6472] = 1243,
  [6473] = 1246,
  [6474] = 1057,
  [6475] = 787,
  [6476] = 5387,
  [6477] = 1064,
  [6478] = 1069,
  [6479] = 1070,
  [6480] = 1071,
  [6481] = 1073,
  [6482] = 788,
  [6483] = 823,
  [6484] = 5427,
  [6485] = 893,
  [6486] = 789,
  [6487] = 646,
  [6488] = 773,
  [6489] = 5429,
  [6490] = 872,
  [6491] = 958,
  [6492] = 1178,
  [6493] = 790,
  [6494] = 831,
  [6495] = 832,
  [6496] = 724,
  [6497] = 1229,
  [6498] = 1230,
  [6499] = 1232,
  [6500] = 1191,
  [6501] = 1160,
  [6502] = 794,
  [6503] = 1162,
  [6504] = 795,
  [6505] = 1163,
  [6506] = 1164,
  [6507] = 1165,
  [6508] = 1166,
  [6509] = 841,
  [6510] = 1233,
  [6511] = 5399,
  [6512] = 5433,
  [6513] = 1194,
  [6514] = 1192,
  [6515] = 853,
  [6516] = 854,
  [6517] = 824,
  [6518] = 1181,
  [6519] = 1184,
  [6520] = 1035,
  [6521] = 1036,
  [6522] = 1204,
  [6523] = 1044,
  [6524] = 1045,
  [6525] = 1046,
  [6526] = 1047,
  [6527] = 1048,
  [6528] = 1049,
  [6529] = 1051,
  [6530] = 796,
  [6531] = 1053,
  [6532] = 1054,
  [6533] = 1055,
  [6534] = 1242,
  [6535] = 862,
  [6536] = 873,
  [6537] = 5432,
  [6538] = 871,
  [6539] = 5371,
  [6540] = 1217,
  [6541] = 1220,
  [6542] = 1091,
  [6543] = 1093,
  [6544] = 1094,
  [6545] = 797,
  [6546] = 1096,
  [6547] = 5483,
  [6548] = 1097,
  [6549] = 1099,
  [6550] = 1067,
  [6551] = 1101,
  [6552] = 1248,
  [6553] = 878,
  [6554] = 5409,
  [6555] = 5418,
  [6556] = 5485,
  [6557] = 1138,
  [6558] = 1139,
  [6559] = 1140,
  [6560] = 1141,
  [6561] = 1142,
  [6562] = 1143,
  [6563] = 1144,
  [6564] = 895,
  [6565] = 5407,
  [6566] = 1133,
  [6567] = 1134,
  [6568] = 1135,
  [6569] = 1145,
  [6570] = 1153,
  [6571] = 1156,
  [6572] = 775,
  [6573] = 1172,
  [6574] = 1173,
  [6575] = 786,
  [6576] = 798,
  [6577] = 826,
  [6578] = 799,
  [6579] = 829,
  [6580] = 767,
  [6581] = 803,
  [6582] = 643,
  [6583] = 833,
  [6584] = 6584,
  [6585] = 868,
  [6586] = 815,
  [6587] = 838,
  [6588] = 804,
  [6589] = 1231,
  [6590] = 5365,
  [6591] = 1233,
  [6592] = 101,
  [6593] = 805,
  [6594] = 806,
  [6595] = 1244,
  [6596] = 1168,
  [6597] = 6597,
  [6598] = 6598,
  [6599] = 845,
  [6600] = 807,
  [6601] = 5366,
  [6602] = 100,
  [6603] = 5378,
  [6604] = 825,
  [6605] = 809,
  [6606] = 810,
  [6607] = 827,
  [6608] = 811,
  [6609] = 812,
  [6610] = 835,
  [6611] = 846,
  [6612] = 813,
  [6613] = 847,
  [6614] = 849,
  [6615] = 3316,
  [6616] = 814,
  [6617] = 851,
  [6618] = 856,
  [6619] = 5309,
  [6620] = 5298,
  [6621] = 6621,
  [6622] = 5309,
  [6623] = 6623,
  [6624] = 5305,
  [6625] = 6625,
  [6626] = 5303,
  [6627] = 6627,
  [6628] = 5236,
  [6629] = 6629,
  [6630] = 5523,
  [6631] = 6631,
  [6632] = 6632,
  [6633] = 5295,
  [6634] = 6634,
  [6635] = 6635,
  [6636] = 5297,
  [6637] = 117,
  [6638] = 6638,
  [6639] = 5533,
  [6640] = 5535,
  [6641] = 1013,
  [6642] = 5644,
  [6643] = 6643,
  [6644] = 5525,
  [6645] = 5492,
  [6646] = 5480,
  [6647] = 5304,
  [6648] = 5301,
  [6649] = 5497,
  [6650] = 5539,
  [6651] = 1006,
  [6652] = 1010,
  [6653] = 5526,
  [6654] = 5540,
  [6655] = 1012,
  [6656] = 5496,
  [6657] = 5396,
  [6658] = 5527,
  [6659] = 5519,
  [6660] = 1015,
  [6661] = 5398,
  [6662] = 6621,
  [6663] = 5517,
  [6664] = 5524,
  [6665] = 5518,
  [6666] = 5534,
  [6667] = 5516,
  [6668] = 991,
  [6669] = 5307,
  [6670] = 5368,
  [6671] = 1017,
  [6672] = 6672,
  [6673] = 5536,
  [6674] = 5395,
  [6675] = 992,
  [6676] = 6676,
  [6677] = 5537,
  [6678] = 5396,
  [6679] = 5513,
  [6680] = 5306,
  [6681] = 5486,
  [6682] = 5514,
  [6683] = 5538,
  [6684] = 5398,
  [6685] = 6685,
  [6686] = 6686,
  [6687] = 6687,
  [6688] = 1024,
  [6689] = 990,
  [6690] = 994,
  [6691] = 5531,
  [6692] = 6692,
  [6693] = 5532,
  [6694] = 5308,
  [6695] = 5302,
  [6696] = 1137,
  [6697] = 5591,
  [6698] = 5562,
  [6699] = 1168,
  [6700] = 5554,
  [6701] = 1134,
  [6702] = 1135,
  [6703] = 5556,
  [6704] = 5592,
  [6705] = 5602,
  [6706] = 6706,
  [6707] = 1075,
  [6708] = 5593,
  [6709] = 5603,
  [6710] = 992,
  [6711] = 1076,
  [6712] = 1077,
  [6713] = 5559,
  [6714] = 1034,
  [6715] = 1079,
  [6716] = 1081,
  [6717] = 1082,
  [6718] = 1037,
  [6719] = 1038,
  [6720] = 1039,
  [6721] = 5429,
  [6722] = 1040,
  [6723] = 1041,
  [6724] = 1042,
  [6725] = 1043,
  [6726] = 1141,
  [6727] = 5543,
  [6728] = 1056,
  [6729] = 5583,
  [6730] = 1058,
  [6731] = 5546,
  [6732] = 5363,
  [6733] = 5555,
  [6734] = 5604,
  [6735] = 5547,
  [6736] = 5561,
  [6737] = 5563,
  [6738] = 5594,
  [6739] = 1099,
  [6740] = 1067,
  [6741] = 5569,
  [6742] = 1160,
  [6743] = 5548,
  [6744] = 1092,
  [6745] = 5399,
  [6746] = 1102,
  [6747] = 1103,
  [6748] = 1104,
  [6749] = 6749,
  [6750] = 991,
  [6751] = 5303,
  [6752] = 5309,
  [6753] = 5565,
  [6754] = 5557,
  [6755] = 5605,
  [6756] = 5433,
  [6757] = 5603,
  [6758] = 5560,
  [6759] = 1013,
  [6760] = 5595,
  [6761] = 5429,
  [6762] = 5567,
  [6763] = 6763,
  [6764] = 1146,
  [6765] = 5606,
  [6766] = 5568,
  [6767] = 1147,
  [6768] = 1164,
  [6769] = 1148,
  [6770] = 5570,
  [6771] = 5305,
  [6772] = 5613,
  [6773] = 1149,
  [6774] = 1150,
  [6775] = 5614,
  [6776] = 1036,
  [6777] = 1045,
  [6778] = 5407,
  [6779] = 5432,
  [6780] = 5574,
  [6781] = 5549,
  [6782] = 5309,
  [6783] = 1124,
  [6784] = 5305,
  [6785] = 1035,
  [6786] = 1036,
  [6787] = 5303,
  [6788] = 1044,
  [6789] = 5575,
  [6790] = 5576,
  [6791] = 1067,
  [6792] = 5409,
  [6793] = 1045,
  [6794] = 1128,
  [6795] = 1145,
  [6796] = 1046,
  [6797] = 5418,
  [6798] = 1162,
  [6799] = 1157,
  [6800] = 1030,
  [6801] = 1052,
  [6802] = 1091,
  [6803] = 1166,
  [6804] = 1061,
  [6805] = 1062,
  [6806] = 1047,
  [6807] = 1048,
  [6808] = 5564,
  [6809] = 1049,
  [6810] = 1153,
  [6811] = 1051,
  [6812] = 5579,
  [6813] = 5584,
  [6814] = 5582,
  [6815] = 5531,
  [6816] = 5537,
  [6817] = 5595,
  [6818] = 5596,
  [6819] = 5407,
  [6820] = 1093,
  [6821] = 5305,
  [6822] = 1156,
  [6823] = 5513,
  [6824] = 5303,
  [6825] = 6825,
  [6826] = 117,
  [6827] = 5514,
  [6828] = 5538,
  [6829] = 5544,
  [6830] = 5587,
  [6831] = 1176,
  [6832] = 1126,
  [6833] = 100,
  [6834] = 1106,
  [6835] = 1027,
  [6836] = 5597,
  [6837] = 5610,
  [6838] = 6838,
  [6839] = 5535,
  [6840] = 5580,
  [6841] = 5364,
  [6842] = 5598,
  [6843] = 5599,
  [6844] = 6844,
  [6845] = 5536,
  [6846] = 6846,
  [6847] = 5615,
  [6848] = 1053,
  [6849] = 6849,
  [6850] = 1101,
  [6851] = 6851,
  [6852] = 1054,
  [6853] = 5237,
  [6854] = 1097,
  [6855] = 1006,
  [6856] = 1010,
  [6857] = 1012,
  [6858] = 5581,
  [6859] = 5562,
  [6860] = 1086,
  [6861] = 1089,
  [6862] = 5433,
  [6863] = 1109,
  [6864] = 1110,
  [6865] = 1111,
  [6866] = 1142,
  [6867] = 1143,
  [6868] = 1172,
  [6869] = 1055,
  [6870] = 1173,
  [6871] = 5583,
  [6872] = 1129,
  [6873] = 1094,
  [6874] = 1165,
  [6875] = 5566,
  [6876] = 5585,
  [6877] = 6877,
  [6878] = 5370,
  [6879] = 6879,
  [6880] = 1144,
  [6881] = 1130,
  [6882] = 1057,
  [6883] = 990,
  [6884] = 5601,
  [6885] = 994,
  [6886] = 1133,
  [6887] = 1096,
  [6888] = 1131,
  [6889] = 1132,
  [6890] = 5600,
  [6891] = 5608,
  [6892] = 101,
  [6893] = 5589,
  [6894] = 6894,
  [6895] = 1024,
  [6896] = 5590,
  [6897] = 103,
  [6898] = 1151,
  [6899] = 1064,
  [6900] = 1069,
  [6901] = 1070,
  [6902] = 1015,
  [6903] = 1017,
  [6904] = 1071,
  [6905] = 1073,
  [6906] = 5553,
  [6907] = 5432,
  [6908] = 102,
  [6909] = 5409,
  [6910] = 5309,
  [6911] = 5427,
  [6912] = 5533,
  [6913] = 5534,
  [6914] = 5418,
  [6915] = 1138,
  [6916] = 1139,
  [6917] = 1140,
  [6918] = 1163,
  [6919] = 5532,
  [6920] = 5634,
  [6921] = 1038,
  [6922] = 5639,
  [6923] = 5670,
  [6924] = 1145,
  [6925] = 1102,
  [6926] = 1146,
  [6927] = 5646,
  [6928] = 1153,
  [6929] = 1156,
  [6930] = 1157,
  [6931] = 1030,
  [6932] = 1052,
  [6933] = 5616,
  [6934] = 5291,
  [6935] = 1147,
  [6936] = 1061,
  [6937] = 1062,
  [6938] = 1148,
  [6939] = 1103,
  [6940] = 1149,
  [6941] = 1150,
  [6942] = 5378,
  [6943] = 6943,
  [6944] = 5626,
  [6945] = 6945,
  [6946] = 1043,
  [6947] = 1104,
  [6948] = 5651,
  [6949] = 5629,
  [6950] = 5387,
  [6951] = 1044,
  [6952] = 1036,
  [6953] = 1045,
  [6954] = 5653,
  [6955] = 5654,
  [6956] = 1067,
  [6957] = 1172,
  [6958] = 1173,
  [6959] = 1176,
  [6960] = 6960,
  [6961] = 1126,
  [6962] = 5641,
  [6963] = 1106,
  [6964] = 5630,
  [6965] = 6965,
  [6966] = 1027,
  [6967] = 1051,
  [6968] = 1099,
  [6969] = 1040,
  [6970] = 1045,
  [6971] = 5631,
  [6972] = 5642,
  [6973] = 1053,
  [6974] = 1138,
  [6975] = 5632,
  [6976] = 1046,
  [6977] = 1139,
  [6978] = 5380,
  [6979] = 1140,
  [6980] = 1067,
  [6981] = 1054,
  [6982] = 1047,
  [6983] = 5521,
  [6984] = 5370,
  [6985] = 1055,
  [6986] = 1086,
  [6987] = 1089,
  [6988] = 1109,
  [6989] = 1110,
  [6990] = 5659,
  [6991] = 1111,
  [6992] = 6706,
  [6993] = 5427,
  [6994] = 5661,
  [6995] = 1041,
  [6996] = 5652,
  [6997] = 5662,
  [6998] = 5624,
  [6999] = 5635,
  [7000] = 5363,
  [7001] = 1056,
  [7002] = 5636,
  [7003] = 1091,
  [7004] = 1039,
  [7005] = 5617,
  [7006] = 5618,
  [7007] = 5619,
  [7008] = 5657,
  [7009] = 5620,
  [7010] = 5663,
  [7011] = 1058,
  [7012] = 5621,
  [7013] = 5622,
  [7014] = 5623,
  [7015] = 5671,
  [7016] = 5625,
  [7017] = 1141,
  [7018] = 5627,
  [7019] = 5640,
  [7020] = 5628,
  [7021] = 5660,
  [7022] = 5364,
  [7023] = 5371,
  [7024] = 5399,
  [7025] = 103,
  [7026] = 5655,
  [7027] = 102,
  [7028] = 1092,
  [7029] = 1129,
  [7030] = 1130,
  [7031] = 1131,
  [7032] = 1124,
  [7033] = 1128,
  [7034] = 1137,
  [7035] = 1132,
  [7036] = 1093,
  [7037] = 1101,
  [7038] = 5644,
  [7039] = 5668,
  [7040] = 1075,
  [7041] = 1076,
  [7042] = 1077,
  [7043] = 1079,
  [7044] = 1048,
  [7045] = 1081,
  [7046] = 1082,
  [7047] = 1097,
  [7048] = 1142,
  [7049] = 1143,
  [7050] = 1094,
  [7051] = 1151,
  [7052] = 5645,
  [7053] = 5664,
  [7054] = 5665,
  [7055] = 1057,
  [7056] = 1042,
  [7057] = 1133,
  [7058] = 1064,
  [7059] = 1069,
  [7060] = 1070,
  [7061] = 1071,
  [7062] = 1073,
  [7063] = 1144,
  [7064] = 1134,
  [7065] = 103,
  [7066] = 1160,
  [7067] = 7067,
  [7068] = 1162,
  [7069] = 102,
  [7070] = 5667,
  [7071] = 5637,
  [7072] = 1163,
  [7073] = 1164,
  [7074] = 1165,
  [7075] = 1166,
  [7076] = 1168,
  [7077] = 1049,
  [7078] = 5638,
  [7079] = 1135,
  [7080] = 1096,
  [7081] = 5384,
  [7082] = 1034,
  [7083] = 1035,
  [7084] = 1036,
  [7085] = 1037,
  [7086] = 5633,
  [7087] = 7087,
  [7088] = 7088,
  [7089] = 6943,
  [7090] = 5236,
  [7091] = 7091,
  [7092] = 6960,
  [7093] = 7093,
  [7094] = 7088,
  [7095] = 5492,
  [7096] = 7087,
  [7097] = 5480,
  [7098] = 5497,
  [7099] = 7088,
  [7100] = 7087,
  [7101] = 7088,
  [7102] = 7088,
  [7103] = 5496,
  [7104] = 7104,
  [7105] = 7105,
  [7106] = 7088,
  [7107] = 7087,
  [7108] = 7108,
  [7109] = 5232,
  [7110] = 5523,
  [7111] = 7067,
  [7112] = 5516,
  [7113] = 7113,
  [7114] = 7087,
  [7115] = 7115,
  [7116] = 7088,
  [7117] = 5486,
  [7118] = 7087,
  [7119] = 7088,
  [7120] = 7087,
  [7121] = 7087,
  [7122] = 1015,
  [7123] = 7123,
  [7124] = 7124,
  [7125] = 5537,
  [7126] = 7126,
  [7127] = 1010,
  [7128] = 7126,
  [7129] = 5232,
  [7130] = 1012,
  [7131] = 7126,
  [7132] = 7132,
  [7133] = 7133,
  [7134] = 7133,
  [7135] = 1017,
  [7136] = 991,
  [7137] = 7126,
  [7138] = 103,
  [7139] = 5516,
  [7140] = 5535,
  [7141] = 5533,
  [7142] = 7133,
  [7143] = 7133,
  [7144] = 5536,
  [7145] = 1024,
  [7146] = 7126,
  [7147] = 5534,
  [7148] = 1013,
  [7149] = 5513,
  [7150] = 5514,
  [7151] = 5538,
  [7152] = 5595,
  [7153] = 7126,
  [7154] = 102,
  [7155] = 7155,
  [7156] = 7133,
  [7157] = 5237,
  [7158] = 990,
  [7159] = 7126,
  [7160] = 7133,
  [7161] = 7133,
  [7162] = 5531,
  [7163] = 5532,
  [7164] = 7133,
  [7165] = 7165,
  [7166] = 7126,
  [7167] = 7167,
  [7168] = 994,
  [7169] = 5236,
  [7170] = 1006,
  [7171] = 992,
  [7172] = 1160,
  [7173] = 5575,
  [7174] = 5543,
  [7175] = 5546,
  [7176] = 1139,
  [7177] = 1140,
  [7178] = 7178,
  [7179] = 5608,
  [7180] = 5576,
  [7181] = 1172,
  [7182] = 1173,
  [7183] = 5581,
  [7184] = 5570,
  [7185] = 5555,
  [7186] = 5390,
  [7187] = 5391,
  [7188] = 5613,
  [7189] = 5614,
  [7190] = 5592,
  [7191] = 5561,
  [7192] = 1057,
  [7193] = 5583,
  [7194] = 1168,
  [7195] = 7195,
  [7196] = 1064,
  [7197] = 1069,
  [7198] = 1070,
  [7199] = 1071,
  [7200] = 5579,
  [7201] = 5564,
  [7202] = 5295,
  [7203] = 1073,
  [7204] = 5597,
  [7205] = 5563,
  [7206] = 5582,
  [7207] = 5585,
  [7208] = 1034,
  [7209] = 5544,
  [7210] = 5427,
  [7211] = 1037,
  [7212] = 1038,
  [7213] = 1039,
  [7214] = 1040,
  [7215] = 1041,
  [7216] = 1042,
  [7217] = 1043,
  [7218] = 5593,
  [7219] = 1056,
  [7220] = 1141,
  [7221] = 1058,
  [7222] = 7108,
  [7223] = 5589,
  [7224] = 5379,
  [7225] = 5429,
  [7226] = 5574,
  [7227] = 5365,
  [7228] = 5569,
  [7229] = 1092,
  [7230] = 1142,
  [7231] = 5590,
  [7232] = 5366,
  [7233] = 7178,
  [7234] = 5591,
  [7235] = 5547,
  [7236] = 1162,
  [7237] = 1143,
  [7238] = 1163,
  [7239] = 1102,
  [7240] = 1103,
  [7241] = 1104,
  [7242] = 1164,
  [7243] = 1165,
  [7244] = 5548,
  [7245] = 1166,
  [7246] = 1144,
  [7247] = 5376,
  [7248] = 5599,
  [7249] = 5557,
  [7250] = 5370,
  [7251] = 5584,
  [7252] = 1082,
  [7253] = 1146,
  [7254] = 1147,
  [7255] = 1148,
  [7256] = 1149,
  [7257] = 1150,
  [7258] = 5594,
  [7259] = 5399,
  [7260] = 5549,
  [7261] = 1124,
  [7262] = 5595,
  [7263] = 1128,
  [7264] = 1137,
  [7265] = 5375,
  [7266] = 1157,
  [7267] = 1030,
  [7268] = 1052,
  [7269] = 1061,
  [7270] = 1062,
  [7271] = 5433,
  [7272] = 5363,
  [7273] = 1126,
  [7274] = 1106,
  [7275] = 1027,
  [7276] = 5596,
  [7277] = 1138,
  [7278] = 5370,
  [7279] = 5363,
  [7280] = 1086,
  [7281] = 1089,
  [7282] = 1109,
  [7283] = 1110,
  [7284] = 1111,
  [7285] = 5559,
  [7286] = 5566,
  [7287] = 1129,
  [7288] = 1130,
  [7289] = 1131,
  [7290] = 1132,
  [7291] = 1151,
  [7292] = 5891,
  [7293] = 5560,
  [7294] = 1035,
  [7295] = 1036,
  [7296] = 5407,
  [7297] = 5580,
  [7298] = 5615,
  [7299] = 1044,
  [7300] = 1045,
  [7301] = 1046,
  [7302] = 5237,
  [7303] = 1047,
  [7304] = 1048,
  [7305] = 1049,
  [7306] = 1051,
  [7307] = 1053,
  [7308] = 7308,
  [7309] = 1054,
  [7310] = 1055,
  [7311] = 5393,
  [7312] = 5364,
  [7313] = 5565,
  [7314] = 5587,
  [7315] = 5610,
  [7316] = 5598,
  [7317] = 5567,
  [7318] = 5601,
  [7319] = 5602,
  [7320] = 5603,
  [7321] = 5604,
  [7322] = 5605,
  [7323] = 5373,
  [7324] = 5432,
  [7325] = 5562,
  [7326] = 5364,
  [7327] = 5583,
  [7328] = 5553,
  [7329] = 5556,
  [7330] = 1036,
  [7331] = 5606,
  [7332] = 5237,
  [7333] = 5562,
  [7334] = 5603,
  [7335] = 5600,
  [7336] = 5568,
  [7337] = 1133,
  [7338] = 1091,
  [7339] = 1045,
  [7340] = 1093,
  [7341] = 1094,
  [7342] = 5383,
  [7343] = 1134,
  [7344] = 1096,
  [7345] = 1097,
  [7346] = 1099,
  [7347] = 1067,
  [7348] = 1101,
  [7349] = 1067,
  [7350] = 1075,
  [7351] = 1076,
  [7352] = 1077,
  [7353] = 1135,
  [7354] = 1145,
  [7355] = 1153,
  [7356] = 1156,
  [7357] = 5409,
  [7358] = 5418,
  [7359] = 5392,
  [7360] = 1079,
  [7361] = 5554,
  [7362] = 1081,
  [7363] = 1176,
  [7364] = 7364,
  [7365] = 5670,
  [7366] = 5404,
  [7367] = 5616,
  [7368] = 5236,
  [7369] = 7369,
  [7370] = 5660,
  [7371] = 7371,
  [7372] = 7372,
  [7373] = 7372,
  [7374] = 5642,
  [7375] = 5236,
  [7376] = 7376,
  [7377] = 7377,
  [7378] = 103,
  [7379] = 7379,
  [7380] = 5298,
  [7381] = 5236,
  [7382] = 5291,
  [7383] = 7383,
  [7384] = 5655,
  [7385] = 5626,
  [7386] = 5236,
  [7387] = 7387,
  [7388] = 7388,
  [7389] = 5236,
  [7390] = 7390,
  [7391] = 7391,
  [7392] = 102,
  [7393] = 5236,
  [7394] = 7394,
  [7395] = 5657,
  [7396] = 5305,
  [7397] = 5235,
  [7398] = 5663,
  [7399] = 5667,
  [7400] = 7400,
  [7401] = 5303,
  [7402] = 7402,
  [7403] = 5646,
  [7404] = 5645,
  [7405] = 5664,
  [7406] = 7402,
  [7407] = 5665,
  [7408] = 5662,
  [7409] = 5365,
  [7410] = 5653,
  [7411] = 1245,
  [7412] = 5414,
  [7413] = 7413,
  [7414] = 7369,
  [7415] = 5236,
  [7416] = 5417,
  [7417] = 5654,
  [7418] = 5866,
  [7419] = 5236,
  [7420] = 5661,
  [7421] = 5297,
  [7422] = 7422,
  [7423] = 5366,
  [7424] = 7424,
  [7425] = 5237,
  [7426] = 5309,
  [7427] = 7427,
  [7428] = 5758,
  [7429] = 7429,
  [7430] = 5651,
  [7431] = 5659,
  [7432] = 7413,
  [7433] = 7424,
  [7434] = 7434,
  [7435] = 5236,
  [7436] = 5668,
  [7437] = 5652,
  [7438] = 7429,
  [7439] = 5437,
  [7440] = 2328,
  [7441] = 5534,
  [7442] = 7442,
  [7443] = 5440,
  [7444] = 5298,
  [7445] = 7387,
  [7446] = 5443,
  [7447] = 7427,
  [7448] = 5438,
  [7449] = 7388,
  [7450] = 5236,
  [7451] = 5447,
  [7452] = 5436,
  [7453] = 5891,
  [7454] = 5758,
  [7455] = 5297,
  [7456] = 5291,
  [7457] = 7457,
  [7458] = 5533,
  [7459] = 7383,
  [7460] = 5398,
  [7461] = 5442,
  [7462] = 5235,
  [7463] = 5513,
  [7464] = 5396,
  [7465] = 7465,
  [7466] = 5514,
  [7467] = 5538,
  [7468] = 7468,
  [7469] = 7469,
  [7470] = 7470,
  [7471] = 5306,
  [7472] = 7472,
  [7473] = 5395,
  [7474] = 7474,
  [7475] = 5236,
  [7476] = 7476,
  [7477] = 7477,
  [7478] = 7371,
  [7479] = 5236,
  [7480] = 7477,
  [7481] = 7481,
  [7482] = 7482,
  [7483] = 7483,
  [7484] = 7484,
  [7485] = 7485,
  [7486] = 5236,
  [7487] = 7487,
  [7488] = 7482,
  [7489] = 7483,
  [7490] = 7490,
  [7491] = 7481,
  [7492] = 7485,
  [7493] = 7493,
  [7494] = 7494,
  [7495] = 7495,
  [7496] = 5302,
  [7497] = 7497,
  [7498] = 7498,
  [7499] = 7499,
  [7500] = 7500,
  [7501] = 7501,
  [7502] = 7502,
  [7503] = 7503,
  [7504] = 5237,
  [7505] = 7482,
  [7506] = 7485,
  [7507] = 7497,
  [7508] = 7508,
  [7509] = 5237,
  [7510] = 7508,
  [7511] = 7511,
  [7512] = 7511,
  [7513] = 7482,
  [7514] = 7503,
  [7515] = 7484,
  [7516] = 7487,
  [7517] = 7490,
  [7518] = 7481,
  [7519] = 7493,
  [7520] = 7520,
  [7521] = 7498,
  [7522] = 5237,
  [7523] = 7499,
  [7524] = 7501,
  [7525] = 7525,
  [7526] = 7526,
  [7527] = 7485,
  [7528] = 7497,
  [7529] = 5237,
  [7530] = 7530,
  [7531] = 7531,
  [7532] = 7508,
  [7533] = 7511,
  [7534] = 7531,
  [7535] = 7535,
  [7536] = 7536,
  [7537] = 5395,
  [7538] = 7538,
  [7539] = 7536,
  [7540] = 7540,
  [7541] = 7541,
  [7542] = 7542,
  [7543] = 7543,
  [7544] = 5237,
  [7545] = 7545,
  [7546] = 7526,
  [7547] = 7511,
  [7548] = 7497,
  [7549] = 7485,
  [7550] = 7550,
  [7551] = 7494,
  [7552] = 7494,
  [7553] = 7494,
  [7554] = 7543,
  [7555] = 7500,
  [7556] = 7503,
  [7557] = 7502,
  [7558] = 7525,
  [7559] = 7540,
  [7560] = 7526,
  [7561] = 7497,
  [7562] = 7562,
  [7563] = 7502,
  [7564] = 7508,
  [7565] = 7502,
  [7566] = 7543,
  [7567] = 7538,
  [7568] = 7545,
  [7569] = 7483,
  [7570] = 7482,
  [7571] = 7499,
  [7572] = 7530,
  [7573] = 5758,
  [7574] = 7511,
  [7575] = 7540,
  [7576] = 7501,
  [7577] = 7503,
  [7578] = 7484,
  [7579] = 7525,
  [7580] = 5308,
  [7581] = 7482,
  [7582] = 5307,
  [7583] = 7490,
  [7584] = 7530,
  [7585] = 7531,
  [7586] = 7562,
  [7587] = 7525,
  [7588] = 7545,
  [7589] = 7538,
  [7590] = 7536,
  [7591] = 5304,
  [7592] = 7592,
  [7593] = 7536,
  [7594] = 7490,
  [7595] = 7542,
  [7596] = 5301,
  [7597] = 7493,
  [7598] = 7543,
  [7599] = 7542,
  [7600] = 7540,
  [7601] = 7543,
  [7602] = 7562,
  [7603] = 7483,
  [7604] = 7501,
  [7605] = 7494,
  [7606] = 7606,
  [7607] = 7531,
  [7608] = 7525,
  [7609] = 7542,
  [7610] = 5237,
  [7611] = 7484,
  [7612] = 5237,
  [7613] = 7487,
  [7614] = 7481,
  [7615] = 7493,
  [7616] = 7490,
  [7617] = 7526,
  [7618] = 7498,
  [7619] = 7562,
  [7620] = 7545,
  [7621] = 7621,
  [7622] = 5396,
  [7623] = 5306,
  [7624] = 7481,
  [7625] = 7498,
  [7626] = 7494,
  [7627] = 7538,
  [7628] = 7536,
  [7629] = 7629,
  [7630] = 7538,
  [7631] = 7499,
  [7632] = 7562,
  [7633] = 7502,
  [7634] = 7634,
  [7635] = 7487,
  [7636] = 7540,
  [7637] = 5295,
  [7638] = 7543,
  [7639] = 7485,
  [7640] = 7497,
  [7641] = 7508,
  [7642] = 7502,
  [7643] = 7530,
  [7644] = 7501,
  [7645] = 7481,
  [7646] = 7487,
  [7647] = 7490,
  [7648] = 7498,
  [7649] = 7499,
  [7650] = 7485,
  [7651] = 7497,
  [7652] = 7508,
  [7653] = 7511,
  [7654] = 7526,
  [7655] = 7562,
  [7656] = 7493,
  [7657] = 7483,
  [7658] = 7526,
  [7659] = 7498,
  [7660] = 7484,
  [7661] = 7487,
  [7662] = 7490,
  [7663] = 7525,
  [7664] = 7540,
  [7665] = 7531,
  [7666] = 7501,
  [7667] = 7503,
  [7668] = 7493,
  [7669] = 5398,
  [7670] = 7531,
  [7671] = 7545,
  [7672] = 7545,
  [7673] = 7536,
  [7674] = 7511,
  [7675] = 7542,
  [7676] = 7498,
  [7677] = 7499,
  [7678] = 7530,
  [7679] = 7508,
  [7680] = 7484,
  [7681] = 7499,
  [7682] = 7538,
  [7683] = 7683,
  [7684] = 7487,
  [7685] = 7685,
  [7686] = 7686,
  [7687] = 7687,
  [7688] = 7688,
  [7689] = 7689,
  [7690] = 7690,
  [7691] = 7691,
  [7692] = 7692,
  [7693] = 7693,
  [7694] = 7694,
  [7695] = 7695,
  [7696] = 7696,
  [7697] = 7697,
  [7698] = 7698,
  [7699] = 7699,
  [7700] = 7700,
  [7701] = 7701,
  [7702] = 7702,
  [7703] = 7703,
  [7704] = 7704,
  [7705] = 7705,
  [7706] = 7706,
  [7707] = 7707,
  [7708] = 7708,
  [7709] = 7709,
  [7710] = 7710,
  [7711] = 7711,
  [7712] = 7712,
  [7713] = 5291,
  [7714] = 7714,
  [7715] = 7715,
  [7716] = 7716,
  [7717] = 7699,
  [7718] = 7686,
  [7719] = 7687,
  [7720] = 7688,
  [7721] = 7689,
  [7722] = 7722,
  [7723] = 7690,
  [7724] = 7724,
  [7725] = 7691,
  [7726] = 7692,
  [7727] = 7693,
  [7728] = 7694,
  [7729] = 7695,
  [7730] = 7696,
  [7731] = 7469,
  [7732] = 7732,
  [7733] = 7733,
  [7734] = 5237,
  [7735] = 7735,
  [7736] = 5291,
  [7737] = 5773,
  [7738] = 5297,
  [7739] = 7709,
  [7740] = 7740,
  [7741] = 7700,
  [7742] = 7701,
  [7743] = 7702,
  [7744] = 7703,
  [7745] = 7704,
  [7746] = 7705,
  [7747] = 7706,
  [7748] = 7707,
  [7749] = 7708,
  [7750] = 7709,
  [7751] = 7710,
  [7752] = 7752,
  [7753] = 7699,
  [7754] = 7754,
  [7755] = 7699,
  [7756] = 7686,
  [7757] = 7687,
  [7758] = 7688,
  [7759] = 7689,
  [7760] = 7690,
  [7761] = 7686,
  [7762] = 7691,
  [7763] = 7692,
  [7764] = 7693,
  [7765] = 7694,
  [7766] = 7695,
  [7767] = 7696,
  [7768] = 5485,
  [7769] = 7687,
  [7770] = 5365,
  [7771] = 5298,
  [7772] = 7752,
  [7773] = 7688,
  [7774] = 5237,
  [7775] = 7754,
  [7776] = 7689,
  [7777] = 7690,
  [7778] = 3316,
  [7779] = 5291,
  [7780] = 3313,
  [7781] = 5538,
  [7782] = 7752,
  [7783] = 7754,
  [7784] = 117,
  [7785] = 7740,
  [7786] = 7700,
  [7787] = 7701,
  [7788] = 7702,
  [7789] = 7703,
  [7790] = 7704,
  [7791] = 7705,
  [7792] = 7706,
  [7793] = 7707,
  [7794] = 7708,
  [7795] = 7709,
  [7796] = 7710,
  [7797] = 5365,
  [7798] = 5366,
  [7799] = 5366,
  [7800] = 7740,
  [7801] = 5533,
  [7802] = 5534,
  [7803] = 5365,
  [7804] = 7691,
  [7805] = 5366,
  [7806] = 7692,
  [7807] = 7693,
  [7808] = 7700,
  [7809] = 5291,
  [7810] = 5295,
  [7811] = 5291,
  [7812] = 5295,
  [7813] = 7701,
  [7814] = 5237,
  [7815] = 7752,
  [7816] = 7694,
  [7817] = 7695,
  [7818] = 7696,
  [7819] = 5365,
  [7820] = 5366,
  [7821] = 5291,
  [7822] = 5291,
  [7823] = 5291,
  [7824] = 7702,
  [7825] = 7710,
  [7826] = 7703,
  [7827] = 7704,
  [7828] = 7705,
  [7829] = 7829,
  [7830] = 7830,
  [7831] = 7706,
  [7832] = 7707,
  [7833] = 5291,
  [7834] = 5483,
  [7835] = 7754,
  [7836] = 7708,
  [7837] = 7740,
  [7838] = 5309,
  [7839] = 5297,
  [7840] = 100,
  [7841] = 7841,
  [7842] = 5298,
  [7843] = 7841,
  [7844] = 7844,
  [7845] = 7845,
  [7846] = 7841,
  [7847] = 7841,
  [7848] = 7848,
  [7849] = 5306,
  [7850] = 7850,
  [7851] = 7851,
  [7852] = 7852,
  [7853] = 7853,
  [7854] = 5291,
  [7855] = 7855,
  [7856] = 5303,
  [7857] = 7841,
  [7858] = 7858,
  [7859] = 5773,
  [7860] = 5370,
  [7861] = 7861,
  [7862] = 7853,
  [7863] = 5291,
  [7864] = 7848,
  [7865] = 101,
  [7866] = 5363,
  [7867] = 5291,
  [7868] = 5364,
  [7869] = 5295,
  [7870] = 7853,
  [7871] = 7853,
  [7872] = 7853,
  [7873] = 7873,
  [7874] = 5305,
  [7875] = 5540,
  [7876] = 7876,
  [7877] = 7877,
  [7878] = 5773,
  [7879] = 5527,
  [7880] = 5396,
  [7881] = 5395,
  [7882] = 7882,
  [7883] = 7883,
  [7884] = 5398,
  [7885] = 7885,
  [7886] = 5309,
  [7887] = 7887,
  [7888] = 5305,
  [7889] = 7885,
  [7890] = 5303,
  [7891] = 5539,
  [7892] = 5519,
  [7893] = 5398,
  [7894] = 7894,
  [7895] = 5395,
  [7896] = 5517,
  [7897] = 5518,
  [7898] = 7898,
  [7899] = 7899,
  [7900] = 7900,
  [7901] = 7898,
  [7902] = 5395,
  [7903] = 5526,
  [7904] = 5396,
  [7905] = 5398,
  [7906] = 7906,
  [7907] = 7882,
  [7908] = 5396,
  [7909] = 7909,
  [7910] = 5396,
  [7911] = 7876,
  [7912] = 7885,
  [7913] = 7913,
  [7914] = 7914,
  [7915] = 5306,
  [7916] = 7916,
  [7917] = 7885,
  [7918] = 7885,
  [7919] = 7876,
  [7920] = 7885,
  [7921] = 5398,
  [7922] = 5524,
  [7923] = 7876,
  [7924] = 5525,
  [7925] = 5516,
  [7926] = 5291,
  [7927] = 7876,
  [7928] = 7898,
  [7929] = 7899,
  [7930] = 7876,
  [7931] = 7876,
  [7932] = 7876,
  [7933] = 7876,
  [7934] = 7876,
  [7935] = 7898,
  [7936] = 7899,
  [7937] = 7899,
  [7938] = 7938,
  [7939] = 7939,
  [7940] = 5295,
  [7941] = 7941,
  [7942] = 5301,
  [7943] = 5603,
  [7944] = 7944,
  [7945] = 7945,
  [7946] = 7946,
  [7947] = 5521,
  [7948] = 7948,
  [7949] = 7949,
  [7950] = 5595,
  [7951] = 5295,
  [7952] = 7952,
  [7953] = 7949,
  [7954] = 5378,
  [7955] = 5387,
  [7956] = 7956,
  [7957] = 7949,
  [7958] = 5295,
  [7959] = 7959,
  [7960] = 7960,
  [7961] = 7961,
  [7962] = 5380,
  [7963] = 7963,
  [7964] = 7964,
  [7965] = 7949,
  [7966] = 7966,
  [7967] = 5295,
  [7968] = 7945,
  [7969] = 7945,
  [7970] = 5371,
  [7971] = 7971,
  [7972] = 7945,
  [7973] = 7973,
  [7974] = 7945,
  [7975] = 5307,
  [7976] = 7945,
  [7977] = 7945,
  [7978] = 7978,
  [7979] = 7979,
  [7980] = 7980,
  [7981] = 5384,
  [7982] = 5295,
  [7983] = 7945,
  [7984] = 5295,
  [7985] = 5603,
  [7986] = 7986,
  [7987] = 7987,
  [7988] = 5295,
  [7989] = 7989,
  [7990] = 7945,
  [7991] = 7980,
  [7992] = 7949,
  [7993] = 7993,
  [7994] = 7994,
  [7995] = 5429,
  [7996] = 7993,
  [7997] = 7997,
  [7998] = 7949,
  [7999] = 7945,
  [8000] = 5399,
  [8001] = 7993,
  [8002] = 5433,
  [8003] = 8003,
  [8004] = 8004,
  [8005] = 7961,
  [8006] = 5304,
  [8007] = 5595,
  [8008] = 8008,
  [8009] = 5583,
  [8010] = 5562,
  [8011] = 7961,
  [8012] = 7979,
  [8013] = 7980,
  [8014] = 5432,
  [8015] = 8015,
  [8016] = 7979,
  [8017] = 7980,
  [8018] = 5409,
  [8019] = 7979,
  [8020] = 7980,
  [8021] = 5302,
  [8022] = 5562,
  [8023] = 8023,
  [8024] = 5418,
  [8025] = 5407,
  [8026] = 7993,
  [8027] = 7952,
  [8028] = 8028,
  [8029] = 8029,
  [8030] = 8030,
  [8031] = 8031,
  [8032] = 7979,
  [8033] = 8033,
  [8034] = 7961,
  [8035] = 5583,
  [8036] = 7979,
  [8037] = 7952,
  [8038] = 7952,
  [8039] = 8039,
  [8040] = 5308,
  [8041] = 5427,
  [8042] = 5305,
  [8043] = 5295,
  [8044] = 5305,
  [8045] = 8045,
  [8046] = 8046,
  [8047] = 5295,
  [8048] = 5629,
  [8049] = 5630,
  [8050] = 5303,
  [8051] = 8046,
  [8052] = 5631,
  [8053] = 5644,
  [8054] = 5632,
  [8055] = 5633,
  [8056] = 5634,
  [8057] = 5635,
  [8058] = 5636,
  [8059] = 5637,
  [8060] = 5638,
  [8061] = 5639,
  [8062] = 5857,
  [8063] = 8046,
  [8064] = 5302,
  [8065] = 5393,
  [8066] = 5391,
  [8067] = 5640,
  [8068] = 5309,
  [8069] = 5305,
  [8070] = 5303,
  [8071] = 5816,
  [8072] = 8072,
  [8073] = 5308,
  [8074] = 5483,
  [8075] = 5485,
  [8076] = 5295,
  [8077] = 5624,
  [8078] = 5379,
  [8079] = 5617,
  [8080] = 5641,
  [8081] = 8072,
  [8082] = 8072,
  [8083] = 5618,
  [8084] = 8072,
  [8085] = 5815,
  [8086] = 5619,
  [8087] = 5375,
  [8088] = 8072,
  [8089] = 5620,
  [8090] = 8072,
  [8091] = 103,
  [8092] = 102,
  [8093] = 5621,
  [8094] = 8072,
  [8095] = 5622,
  [8096] = 5623,
  [8097] = 5671,
  [8098] = 5809,
  [8099] = 5390,
  [8100] = 5373,
  [8101] = 5625,
  [8102] = 5627,
  [8103] = 5383,
  [8104] = 5628,
  [8105] = 5376,
  [8106] = 5309,
  [8107] = 8046,
  [8108] = 8046,
  [8109] = 5304,
  [8110] = 5301,
  [8111] = 5303,
  [8112] = 8072,
  [8113] = 8072,
  [8114] = 8072,
  [8115] = 8072,
  [8116] = 8072,
  [8117] = 8072,
  [8118] = 8072,
  [8119] = 5307,
  [8120] = 8072,
  [8121] = 8121,
  [8122] = 5392,
  [8123] = 5309,
  [8124] = 8072,
  [8125] = 5486,
  [8126] = 8126,
  [8127] = 5370,
  [8128] = 8126,
  [8129] = 6844,
  [8130] = 103,
  [8131] = 5368,
  [8132] = 8126,
  [8133] = 8133,
  [8134] = 5496,
  [8135] = 5492,
  [8136] = 102,
  [8137] = 8126,
  [8138] = 5497,
  [8139] = 5816,
  [8140] = 5809,
  [8141] = 5815,
  [8142] = 5949,
  [8143] = 5309,
  [8144] = 5363,
  [8145] = 8145,
  [8146] = 5303,
  [8147] = 5368,
  [8148] = 5366,
  [8149] = 8126,
  [8150] = 5305,
  [8151] = 5364,
  [8152] = 5480,
  [8153] = 5417,
  [8154] = 5309,
  [8155] = 8133,
  [8156] = 5305,
  [8157] = 8133,
  [8158] = 8133,
  [8159] = 8133,
  [8160] = 8133,
  [8161] = 7113,
  [8162] = 8133,
  [8163] = 8126,
  [8164] = 5369,
  [8165] = 5365,
  [8166] = 5303,
  [8167] = 8126,
  [8168] = 5307,
  [8169] = 5395,
  [8170] = 5443,
  [8171] = 5304,
  [8172] = 5527,
  [8173] = 5302,
  [8174] = 5301,
  [8175] = 5442,
  [8176] = 5437,
  [8177] = 5370,
  [8178] = 5447,
  [8179] = 5414,
  [8180] = 8180,
  [8181] = 5440,
  [8182] = 5301,
  [8183] = 5363,
  [8184] = 5404,
  [8185] = 5436,
  [8186] = 5364,
  [8187] = 8187,
  [8188] = 5438,
  [8189] = 5540,
  [8190] = 5302,
  [8191] = 5308,
  [8192] = 5308,
  [8193] = 8193,
  [8194] = 8180,
  [8195] = 8195,
  [8196] = 5304,
  [8197] = 7195,
  [8198] = 8198,
  [8199] = 8199,
  [8200] = 103,
  [8201] = 102,
  [8202] = 8202,
  [8203] = 5307,
  [8204] = 5307,
  [8205] = 8205,
  [8206] = 5308,
  [8207] = 5364,
  [8208] = 8208,
  [8209] = 7372,
  [8210] = 8205,
  [8211] = 5302,
  [8212] = 8205,
  [8213] = 5363,
  [8214] = 8208,
  [8215] = 5396,
  [8216] = 5304,
  [8217] = 8208,
  [8218] = 5398,
  [8219] = 5301,
  [8220] = 8220,
  [8221] = 5370,
  [8222] = 8208,
  [8223] = 8208,
  [8224] = 103,
  [8225] = 102,
  [8226] = 8205,
  [8227] = 8208,
  [8228] = 8228,
  [8229] = 8208,
  [8230] = 8208,
  [8231] = 8205,
  [8232] = 7372,
  [8233] = 8233,
  [8234] = 8234,
  [8235] = 8235,
  [8236] = 5298,
  [8237] = 5365,
  [8238] = 5392,
  [8239] = 8235,
  [8240] = 5363,
  [8241] = 5370,
  [8242] = 8234,
  [8243] = 5373,
  [8244] = 5391,
  [8245] = 8234,
  [8246] = 5365,
  [8247] = 5366,
  [8248] = 5364,
  [8249] = 6692,
  [8250] = 6687,
  [8251] = 5375,
  [8252] = 5370,
  [8253] = 6584,
  [8254] = 8235,
  [8255] = 5393,
  [8256] = 5295,
  [8257] = 8257,
  [8258] = 8235,
  [8259] = 8259,
  [8260] = 5376,
  [8261] = 8261,
  [8262] = 5297,
  [8263] = 8234,
  [8264] = 5363,
  [8265] = 8234,
  [8266] = 5364,
  [8267] = 5390,
  [8268] = 8235,
  [8269] = 8234,
  [8270] = 8234,
  [8271] = 5379,
  [8272] = 5366,
  [8273] = 8235,
  [8274] = 8235,
  [8275] = 8234,
  [8276] = 8235,
  [8277] = 8277,
  [8278] = 5383,
  [8279] = 8279,
  [8280] = 5365,
  [8281] = 8281,
  [8282] = 8282,
  [8283] = 8283,
  [8284] = 8284,
  [8285] = 5375,
  [8286] = 8284,
  [8287] = 6676,
  [8288] = 8282,
  [8289] = 8282,
  [8290] = 5363,
  [8291] = 5517,
  [8292] = 103,
  [8293] = 102,
  [8294] = 8282,
  [8295] = 5513,
  [8296] = 5524,
  [8297] = 5521,
  [8298] = 5393,
  [8299] = 8281,
  [8300] = 8300,
  [8301] = 5537,
  [8302] = 8282,
  [8303] = 5383,
  [8304] = 5514,
  [8305] = 8282,
  [8306] = 8284,
  [8307] = 5414,
  [8308] = 5373,
  [8309] = 5417,
  [8310] = 6685,
  [8311] = 8300,
  [8312] = 5392,
  [8313] = 6879,
  [8314] = 5391,
  [8315] = 5370,
  [8316] = 5535,
  [8317] = 8300,
  [8318] = 5364,
  [8319] = 6686,
  [8320] = 8300,
  [8321] = 5525,
  [8322] = 8284,
  [8323] = 5306,
  [8324] = 5376,
  [8325] = 5536,
  [8326] = 5531,
  [8327] = 5366,
  [8328] = 8282,
  [8329] = 8329,
  [8330] = 8300,
  [8331] = 8284,
  [8332] = 6635,
  [8333] = 5532,
  [8334] = 6672,
  [8335] = 6894,
  [8336] = 5390,
  [8337] = 5379,
  [8338] = 5404,
  [8339] = 8339,
  [8340] = 5368,
  [8341] = 5526,
  [8342] = 5404,
  [8343] = 5442,
  [8344] = 5443,
  [8345] = 103,
  [8346] = 5298,
  [8347] = 102,
  [8348] = 5369,
  [8349] = 5297,
  [8350] = 6851,
  [8351] = 8351,
  [8352] = 5369,
  [8353] = 5539,
  [8354] = 8354,
  [8355] = 8355,
  [8356] = 5398,
  [8357] = 8354,
  [8358] = 6838,
  [8359] = 5395,
  [8360] = 5438,
  [8361] = 5437,
  [8362] = 5396,
  [8363] = 6877,
  [8364] = 5398,
  [8365] = 5519,
  [8366] = 8366,
  [8367] = 5447,
  [8368] = 5440,
  [8369] = 5414,
  [8370] = 6849,
  [8371] = 5396,
  [8372] = 5518,
  [8373] = 5436,
  [8374] = 8374,
  [8375] = 5442,
  [8376] = 5391,
  [8377] = 8377,
  [8378] = 8378,
  [8379] = 5373,
  [8380] = 8377,
  [8381] = 8381,
  [8382] = 8382,
  [8383] = 5376,
  [8384] = 8384,
  [8385] = 8377,
  [8386] = 8386,
  [8387] = 5376,
  [8388] = 8388,
  [8389] = 8378,
  [8390] = 8388,
  [8391] = 5443,
  [8392] = 5404,
  [8393] = 5383,
  [8394] = 8378,
  [8395] = 8377,
  [8396] = 8377,
  [8397] = 8388,
  [8398] = 5392,
  [8399] = 8377,
  [8400] = 5438,
  [8401] = 5383,
  [8402] = 8377,
  [8403] = 5373,
  [8404] = 8404,
  [8405] = 8388,
  [8406] = 5395,
  [8407] = 5414,
  [8408] = 5417,
  [8409] = 5368,
  [8410] = 5447,
  [8411] = 5379,
  [8412] = 8378,
  [8413] = 8413,
  [8414] = 8378,
  [8415] = 5390,
  [8416] = 5396,
  [8417] = 5392,
  [8418] = 5436,
  [8419] = 5440,
  [8420] = 8384,
  [8421] = 5398,
  [8422] = 5379,
  [8423] = 6825,
  [8424] = 5391,
  [8425] = 5375,
  [8426] = 8377,
  [8427] = 5393,
  [8428] = 5393,
  [8429] = 8378,
  [8430] = 5437,
  [8431] = 5404,
  [8432] = 8388,
  [8433] = 8413,
  [8434] = 8378,
  [8435] = 5369,
  [8436] = 8388,
  [8437] = 8388,
  [8438] = 8438,
  [8439] = 5306,
  [8440] = 5414,
  [8441] = 8388,
  [8442] = 5375,
  [8443] = 5390,
  [8444] = 8444,
  [8445] = 8378,
  [8446] = 5496,
  [8447] = 5376,
  [8448] = 5365,
  [8449] = 5366,
  [8450] = 5404,
  [8451] = 5383,
  [8452] = 8452,
  [8453] = 8453,
  [8454] = 8454,
  [8455] = 103,
  [8456] = 5513,
  [8457] = 102,
  [8458] = 8458,
  [8459] = 5514,
  [8460] = 103,
  [8461] = 102,
  [8462] = 5538,
  [8463] = 5404,
  [8464] = 8464,
  [8465] = 5414,
  [8466] = 5417,
  [8467] = 5417,
  [8468] = 5497,
  [8469] = 8469,
  [8470] = 5366,
  [8471] = 5492,
  [8472] = 5480,
  [8473] = 5390,
  [8474] = 5379,
  [8475] = 5375,
  [8476] = 5373,
  [8477] = 5365,
  [8478] = 5391,
  [8479] = 5486,
  [8480] = 5366,
  [8481] = 5414,
  [8482] = 5393,
  [8483] = 5537,
  [8484] = 8382,
  [8485] = 5523,
  [8486] = 8486,
  [8487] = 5392,
  [8488] = 5516,
  [8489] = 8489,
  [8490] = 5531,
  [8491] = 5365,
  [8492] = 5532,
  [8493] = 5533,
  [8494] = 5534,
  [8495] = 5366,
  [8496] = 5535,
  [8497] = 5536,
  [8498] = 5365,
  [8499] = 8499,
  [8500] = 8500,
  [8501] = 8501,
  [8502] = 8502,
  [8503] = 5436,
  [8504] = 5442,
  [8505] = 815,
  [8506] = 5438,
  [8507] = 8507,
  [8508] = 5298,
  [8509] = 8458,
  [8510] = 5442,
  [8511] = 5297,
  [8512] = 5447,
  [8513] = 5436,
  [8514] = 5440,
  [8515] = 8515,
  [8516] = 8502,
  [8517] = 8507,
  [8518] = 5297,
  [8519] = 5298,
  [8520] = 5437,
  [8521] = 8515,
  [8522] = 5447,
  [8523] = 8523,
  [8524] = 5438,
  [8525] = 5443,
  [8526] = 5440,
  [8527] = 5437,
  [8528] = 5298,
  [8529] = 8529,
  [8530] = 5297,
  [8531] = 8531,
  [8532] = 8507,
  [8533] = 5365,
  [8534] = 8507,
  [8535] = 5366,
  [8536] = 5365,
  [8537] = 5366,
  [8538] = 8515,
  [8539] = 8515,
  [8540] = 8540,
  [8541] = 816,
  [8542] = 5443,
  [8543] = 5584,
  [8544] = 5615,
  [8545] = 5553,
  [8546] = 5625,
  [8547] = 5585,
  [8548] = 5554,
  [8549] = 5637,
  [8550] = 5567,
  [8551] = 5589,
  [8552] = 5621,
  [8553] = 5568,
  [8554] = 5590,
  [8555] = 5638,
  [8556] = 5639,
  [8557] = 5591,
  [8558] = 5565,
  [8559] = 5592,
  [8560] = 5593,
  [8561] = 5440,
  [8562] = 5429,
  [8563] = 5399,
  [8564] = 5622,
  [8565] = 5594,
  [8566] = 5629,
  [8567] = 5306,
  [8568] = 5587,
  [8569] = 5517,
  [8570] = 5627,
  [8571] = 5556,
  [8572] = 5610,
  [8573] = 5623,
  [8574] = 5414,
  [8575] = 5404,
  [8576] = 5600,
  [8577] = 5641,
  [8578] = 5608,
  [8579] = 5396,
  [8580] = 5630,
  [8581] = 5306,
  [8582] = 5433,
  [8583] = 5570,
  [8584] = 5432,
  [8585] = 5574,
  [8586] = 5526,
  [8587] = 5557,
  [8588] = 5438,
  [8589] = 5547,
  [8590] = 5427,
  [8591] = 5579,
  [8592] = 5539,
  [8593] = 5566,
  [8594] = 5398,
  [8595] = 5569,
  [8596] = 5640,
  [8597] = 5559,
  [8598] = 5631,
  [8599] = 5395,
  [8600] = 5524,
  [8601] = 5525,
  [8602] = 5436,
  [8603] = 5598,
  [8604] = 5596,
  [8605] = 5443,
  [8606] = 5398,
  [8607] = 5398,
  [8608] = 5601,
  [8609] = 5602,
  [8610] = 5617,
  [8611] = 5604,
  [8612] = 5605,
  [8613] = 5606,
  [8614] = 5671,
  [8615] = 5618,
  [8616] = 5632,
  [8617] = 5619,
  [8618] = 5560,
  [8619] = 5543,
  [8620] = 5633,
  [8621] = 5409,
  [8622] = 5546,
  [8623] = 5634,
  [8624] = 5624,
  [8625] = 5620,
  [8626] = 5306,
  [8627] = 5418,
  [8628] = 5396,
  [8629] = 5628,
  [8630] = 5555,
  [8631] = 5407,
  [8632] = 5613,
  [8633] = 5548,
  [8634] = 5395,
  [8635] = 5614,
  [8636] = 5575,
  [8637] = 5576,
  [8638] = 5518,
  [8639] = 5549,
  [8640] = 5635,
  [8641] = 5516,
  [8642] = 5564,
  [8643] = 5561,
  [8644] = 5395,
  [8645] = 5396,
  [8646] = 5581,
  [8647] = 5544,
  [8648] = 8648,
  [8649] = 5521,
  [8650] = 5442,
  [8651] = 5563,
  [8652] = 5396,
  [8653] = 5519,
  [8654] = 5599,
  [8655] = 5398,
  [8656] = 5636,
  [8657] = 5580,
  [8658] = 5582,
  [8659] = 5597,
  [8660] = 5417,
  [8661] = 5366,
  [8662] = 5526,
  [8663] = 5432,
  [8664] = 5409,
  [8665] = 5378,
  [8666] = 5527,
  [8667] = 5365,
  [8668] = 8668,
  [8669] = 5651,
  [8670] = 5645,
  [8671] = 5418,
  [8672] = 5519,
  [8673] = 5409,
  [8674] = 5652,
  [8675] = 5653,
  [8676] = 5483,
  [8677] = 5668,
  [8678] = 5654,
  [8679] = 5518,
  [8680] = 8680,
  [8681] = 5670,
  [8682] = 5380,
  [8683] = 5384,
  [8684] = 5485,
  [8685] = 8685,
  [8686] = 5665,
  [8687] = 5626,
  [8688] = 5399,
  [8689] = 5483,
  [8690] = 5663,
  [8691] = 5371,
  [8692] = 5657,
  [8693] = 5371,
  [8694] = 5429,
  [8695] = 5366,
  [8696] = 5368,
  [8697] = 5427,
  [8698] = 5646,
  [8699] = 5485,
  [8700] = 8668,
  [8701] = 5384,
  [8702] = 5378,
  [8703] = 8703,
  [8704] = 5407,
  [8705] = 5662,
  [8706] = 5369,
  [8707] = 5380,
  [8708] = 5365,
  [8709] = 5583,
  [8710] = 5432,
  [8711] = 5366,
  [8712] = 5521,
  [8713] = 5395,
  [8714] = 5387,
  [8715] = 5396,
  [8716] = 5603,
  [8717] = 5642,
  [8718] = 5398,
  [8719] = 8719,
  [8720] = 5396,
  [8721] = 5365,
  [8722] = 5399,
  [8723] = 5398,
  [8724] = 5387,
  [8725] = 5429,
  [8726] = 5539,
  [8727] = 5660,
  [8728] = 5366,
  [8729] = 103,
  [8730] = 5655,
  [8731] = 5433,
  [8732] = 102,
  [8733] = 5857,
  [8734] = 5418,
  [8735] = 5365,
  [8736] = 5540,
  [8737] = 8668,
  [8738] = 5562,
  [8739] = 5595,
  [8740] = 5659,
  [8741] = 5664,
  [8742] = 5667,
  [8743] = 5427,
  [8744] = 5433,
  [8745] = 5595,
  [8746] = 5407,
  [8747] = 5661,
  [8748] = 5616,
  [8749] = 5637,
  [8750] = 5641,
  [8751] = 8751,
  [8752] = 8752,
  [8753] = 8753,
  [8754] = 8754,
  [8755] = 5298,
  [8756] = 5297,
  [8757] = 5624,
  [8758] = 5617,
  [8759] = 5618,
  [8760] = 5365,
  [8761] = 5366,
  [8762] = 5365,
  [8763] = 5366,
  [8764] = 5619,
  [8765] = 8765,
  [8766] = 5620,
  [8767] = 5621,
  [8768] = 5622,
  [8769] = 5623,
  [8770] = 5671,
  [8771] = 8752,
  [8772] = 5641,
  [8773] = 5625,
  [8774] = 5627,
  [8775] = 5628,
  [8776] = 5639,
  [8777] = 8777,
  [8778] = 8778,
  [8779] = 8752,
  [8780] = 5629,
  [8781] = 5630,
  [8782] = 5631,
  [8783] = 5632,
  [8784] = 8752,
  [8785] = 8785,
  [8786] = 8752,
  [8787] = 5633,
  [8788] = 5634,
  [8789] = 5298,
  [8790] = 5636,
  [8791] = 5637,
  [8792] = 5638,
  [8793] = 5624,
  [8794] = 5639,
  [8795] = 5617,
  [8796] = 5618,
  [8797] = 5619,
  [8798] = 5620,
  [8799] = 5621,
  [8800] = 5622,
  [8801] = 5623,
  [8802] = 5671,
  [8803] = 5640,
  [8804] = 5625,
  [8805] = 5627,
  [8806] = 5628,
  [8807] = 8807,
  [8808] = 8808,
  [8809] = 5638,
  [8810] = 5640,
  [8811] = 5636,
  [8812] = 5949,
  [8813] = 5857,
  [8814] = 5523,
  [8815] = 5297,
  [8816] = 5629,
  [8817] = 5630,
  [8818] = 5631,
  [8819] = 5632,
  [8820] = 5633,
  [8821] = 5634,
  [8822] = 5635,
  [8823] = 5635,
  [8824] = 1015,
  [8825] = 5516,
  [8826] = 8826,
  [8827] = 5516,
  [8828] = 5513,
  [8829] = 5514,
  [8830] = 5538,
  [8831] = 992,
  [8832] = 1006,
  [8833] = 5496,
  [8834] = 5624,
  [8835] = 5516,
  [8836] = 1010,
  [8837] = 5617,
  [8838] = 5518,
  [8839] = 5618,
  [8840] = 103,
  [8841] = 102,
  [8842] = 1012,
  [8843] = 5519,
  [8844] = 5524,
  [8845] = 5619,
  [8846] = 5396,
  [8847] = 5492,
  [8848] = 5620,
  [8849] = 5539,
  [8850] = 5398,
  [8851] = 5396,
  [8852] = 5398,
  [8853] = 5621,
  [8854] = 5396,
  [8855] = 5398,
  [8856] = 5857,
  [8857] = 5525,
  [8858] = 5526,
  [8859] = 103,
  [8860] = 102,
  [8861] = 5368,
  [8862] = 5369,
  [8863] = 5519,
  [8864] = 8864,
  [8865] = 5622,
  [8866] = 5535,
  [8867] = 5527,
  [8868] = 5623,
  [8869] = 5671,
  [8870] = 5516,
  [8871] = 5523,
  [8872] = 5516,
  [8873] = 990,
  [8874] = 994,
  [8875] = 5540,
  [8876] = 5625,
  [8877] = 5627,
  [8878] = 5628,
  [8879] = 5629,
  [8880] = 5516,
  [8881] = 5486,
  [8882] = 5396,
  [8883] = 8765,
  [8884] = 5631,
  [8885] = 5632,
  [8886] = 5633,
  [8887] = 5634,
  [8888] = 5398,
  [8889] = 5635,
  [8890] = 5636,
  [8891] = 5637,
  [8892] = 5638,
  [8893] = 5639,
  [8894] = 5640,
  [8895] = 5949,
  [8896] = 5641,
  [8897] = 5480,
  [8898] = 5539,
  [8899] = 5531,
  [8900] = 8900,
  [8901] = 5532,
  [8902] = 117,
  [8903] = 1024,
  [8904] = 5537,
  [8905] = 5306,
  [8906] = 5536,
  [8907] = 5540,
  [8908] = 5533,
  [8909] = 5534,
  [8910] = 117,
  [8911] = 8864,
  [8912] = 991,
  [8913] = 5517,
  [8914] = 5518,
  [8915] = 5516,
  [8916] = 8916,
  [8917] = 5395,
  [8918] = 1017,
  [8919] = 5497,
  [8920] = 5524,
  [8921] = 1013,
  [8922] = 8900,
  [8923] = 5395,
  [8924] = 5517,
  [8925] = 8925,
  [8926] = 5525,
  [8927] = 5306,
  [8928] = 5526,
  [8929] = 8929,
  [8930] = 8754,
  [8931] = 5527,
  [8932] = 5630,
  [8933] = 5537,
  [8934] = 5562,
  [8935] = 2328,
  [8936] = 5581,
  [8937] = 1027,
  [8938] = 1086,
  [8939] = 5538,
  [8940] = 5576,
  [8941] = 1097,
  [8942] = 1089,
  [8943] = 5580,
  [8944] = 5615,
  [8945] = 1062,
  [8946] = 5565,
  [8947] = 5583,
  [8948] = 5585,
  [8949] = 1172,
  [8950] = 5566,
  [8951] = 5589,
  [8952] = 5590,
  [8953] = 5427,
  [8954] = 5519,
  [8955] = 1091,
  [8956] = 5591,
  [8957] = 8916,
  [8958] = 5535,
  [8959] = 1109,
  [8960] = 5592,
  [8961] = 5544,
  [8962] = 1173,
  [8963] = 5593,
  [8964] = 5395,
  [8965] = 1092,
  [8966] = 5396,
  [8967] = 5398,
  [8968] = 5567,
  [8969] = 5396,
  [8970] = 1110,
  [8971] = 5398,
  [8972] = 1111,
  [8973] = 1099,
  [8974] = 8974,
  [8975] = 5536,
  [8976] = 5429,
  [8977] = 1093,
  [8978] = 1037,
  [8979] = 5399,
  [8980] = 5594,
  [8981] = 5568,
  [8982] = 1040,
  [8983] = 1075,
  [8984] = 1076,
  [8985] = 1077,
  [8986] = 1079,
  [8987] = 1101,
  [8988] = 1102,
  [8989] = 1081,
  [8990] = 1129,
  [8991] = 1103,
  [8992] = 1130,
  [8993] = 1082,
  [8994] = 1041,
  [8995] = 5597,
  [8996] = 1176,
  [8997] = 1042,
  [8998] = 1043,
  [8999] = 5433,
  [9000] = 1104,
  [9001] = 5598,
  [9002] = 5599,
  [9003] = 5608,
  [9004] = 1138,
  [9005] = 8785,
  [9006] = 1036,
  [9007] = 1139,
  [9008] = 5624,
  [9009] = 5617,
  [9010] = 5618,
  [9011] = 5619,
  [9012] = 1044,
  [9013] = 5620,
  [9014] = 5621,
  [9015] = 5622,
  [9016] = 5579,
  [9017] = 5623,
  [9018] = 1140,
  [9019] = 5671,
  [9020] = 5625,
  [9021] = 5584,
  [9022] = 5627,
  [9023] = 5628,
  [9024] = 8974,
  [9025] = 1141,
  [9026] = 1038,
  [9027] = 5596,
  [9028] = 5629,
  [9029] = 5630,
  [9030] = 5631,
  [9031] = 5632,
  [9032] = 5633,
  [9033] = 5634,
  [9034] = 5635,
  [9035] = 5636,
  [9036] = 5637,
  [9037] = 5638,
  [9038] = 5639,
  [9039] = 5559,
  [9040] = 5533,
  [9041] = 1039,
  [9042] = 5534,
  [9043] = 5640,
  [9044] = 1142,
  [9045] = 5641,
  [9046] = 1053,
  [9047] = 9047,
  [9048] = 1143,
  [9049] = 1045,
  [9050] = 8974,
  [9051] = 1054,
  [9052] = 1057,
  [9053] = 5610,
  [9054] = 1064,
  [9055] = 5560,
  [9056] = 5601,
  [9057] = 5602,
  [9058] = 5603,
  [9059] = 1069,
  [9060] = 1070,
  [9061] = 5604,
  [9062] = 1071,
  [9063] = 5605,
  [9064] = 1144,
  [9065] = 5606,
  [9066] = 1073,
  [9067] = 1146,
  [9068] = 1147,
  [9069] = 1148,
  [9070] = 1149,
  [9071] = 1035,
  [9072] = 1046,
  [9073] = 1150,
  [9074] = 1055,
  [9075] = 8974,
  [9076] = 1124,
  [9077] = 1133,
  [9078] = 8974,
  [9079] = 1134,
  [9080] = 1135,
  [9081] = 1145,
  [9082] = 1128,
  [9083] = 5432,
  [9084] = 1153,
  [9085] = 1067,
  [9086] = 1156,
  [9087] = 1047,
  [9088] = 1137,
  [9089] = 5409,
  [9090] = 9090,
  [9091] = 1048,
  [9092] = 1131,
  [9093] = 1132,
  [9094] = 1151,
  [9095] = 5418,
  [9096] = 5570,
  [9097] = 1056,
  [9098] = 1106,
  [9099] = 1160,
  [9100] = 1058,
  [9101] = 9101,
  [9102] = 1049,
  [9103] = 5600,
  [9104] = 5547,
  [9105] = 1157,
  [9106] = 5548,
  [9107] = 5549,
  [9108] = 9108,
  [9109] = 9109,
  [9110] = 1036,
  [9111] = 5553,
  [9112] = 1045,
  [9113] = 5554,
  [9114] = 5531,
  [9115] = 5532,
  [9116] = 5556,
  [9117] = 5949,
  [9118] = 9118,
  [9119] = 1067,
  [9120] = 1030,
  [9121] = 1162,
  [9122] = 5557,
  [9123] = 1163,
  [9124] = 1051,
  [9125] = 9125,
  [9126] = 1164,
  [9127] = 1165,
  [9128] = 1166,
  [9129] = 1168,
  [9130] = 5613,
  [9131] = 5614,
  [9132] = 5564,
  [9133] = 5407,
  [9134] = 1052,
  [9135] = 5582,
  [9136] = 5543,
  [9137] = 5546,
  [9138] = 8974,
  [9139] = 5555,
  [9140] = 8753,
  [9141] = 1061,
  [9142] = 8974,
  [9143] = 9143,
  [9144] = 9144,
  [9145] = 1094,
  [9146] = 5513,
  [9147] = 1034,
  [9148] = 5561,
  [9149] = 5574,
  [9150] = 5514,
  [9151] = 5563,
  [9152] = 1096,
  [9153] = 5587,
  [9154] = 5569,
  [9155] = 5575,
  [9156] = 1126,
  [9157] = 5610,
  [9158] = 5599,
  [9159] = 9159,
  [9160] = 5429,
  [9161] = 5613,
  [9162] = 5644,
  [9163] = 9163,
  [9164] = 5624,
  [9165] = 5629,
  [9166] = 5660,
  [9167] = 9167,
  [9168] = 5600,
  [9169] = 5638,
  [9170] = 5399,
  [9171] = 5616,
  [9172] = 5608,
  [9173] = 5618,
  [9174] = 5639,
  [9175] = 5655,
  [9176] = 5433,
  [9177] = 9177,
  [9178] = 9178,
  [9179] = 9179,
  [9180] = 5630,
  [9181] = 5551,
  [9182] = 9182,
  [9183] = 5566,
  [9184] = 9177,
  [9185] = 9177,
  [9186] = 9177,
  [9187] = 5631,
  [9188] = 5641,
  [9189] = 840,
  [9190] = 9190,
  [9191] = 5614,
  [9192] = 5565,
  [9193] = 5632,
  [9194] = 5432,
  [9195] = 9177,
  [9196] = 5633,
  [9197] = 5645,
  [9198] = 5567,
  [9199] = 5634,
  [9200] = 5568,
  [9201] = 9177,
  [9202] = 5570,
  [9203] = 5628,
  [9204] = 5409,
  [9205] = 5574,
  [9206] = 5601,
  [9207] = 5575,
  [9208] = 9177,
  [9209] = 5418,
  [9210] = 5407,
  [9211] = 5576,
  [9212] = 5602,
  [9213] = 5662,
  [9214] = 9177,
  [9215] = 9215,
  [9216] = 5635,
  [9217] = 5564,
  [9218] = 9218,
  [9219] = 9177,
  [9220] = 5636,
  [9221] = 9221,
  [9222] = 5637,
  [9223] = 9223,
  [9224] = 5637,
  [9225] = 9177,
  [9226] = 9226,
  [9227] = 9177,
  [9228] = 9228,
  [9229] = 5657,
  [9230] = 9230,
  [9231] = 9231,
  [9232] = 5579,
  [9233] = 5584,
  [9234] = 5620,
  [9235] = 9235,
  [9236] = 9177,
  [9237] = 5596,
  [9238] = 9177,
  [9239] = 5659,
  [9240] = 9240,
  [9241] = 9241,
  [9242] = 9242,
  [9243] = 8826,
  [9244] = 5623,
  [9245] = 5638,
  [9246] = 5652,
  [9247] = 9247,
  [9248] = 9248,
  [9249] = 5639,
  [9250] = 5624,
  [9251] = 5670,
  [9252] = 5581,
  [9253] = 5617,
  [9254] = 5651,
  [9255] = 8900,
  [9256] = 5636,
  [9257] = 5626,
  [9258] = 9258,
  [9259] = 9259,
  [9260] = 5618,
  [9261] = 9261,
  [9262] = 5547,
  [9263] = 5582,
  [9264] = 5667,
  [9265] = 5548,
  [9266] = 5549,
  [9267] = 9267,
  [9268] = 5619,
  [9269] = 5553,
  [9270] = 5554,
  [9271] = 5556,
  [9272] = 9272,
  [9273] = 5640,
  [9274] = 5557,
  [9275] = 5620,
  [9276] = 5619,
  [9277] = 5629,
  [9278] = 9278,
  [9279] = 5621,
  [9280] = 5640,
  [9281] = 5668,
  [9282] = 5653,
  [9283] = 5624,
  [9284] = 5544,
  [9285] = 5654,
  [9286] = 5622,
  [9287] = 9177,
  [9288] = 5630,
  [9289] = 5559,
  [9290] = 9290,
  [9291] = 5623,
  [9292] = 9292,
  [9293] = 5631,
  [9294] = 5661,
  [9295] = 5560,
  [9296] = 5640,
  [9297] = 9297,
  [9298] = 5617,
  [9299] = 9299,
  [9300] = 9300,
  [9301] = 5618,
  [9302] = 5639,
  [9303] = 5605,
  [9304] = 5427,
  [9305] = 9177,
  [9306] = 5619,
  [9307] = 9307,
  [9308] = 5646,
  [9309] = 5632,
  [9310] = 5633,
  [9311] = 9311,
  [9312] = 5620,
  [9313] = 5634,
  [9314] = 5621,
  [9315] = 5635,
  [9316] = 9316,
  [9317] = 5543,
  [9318] = 9318,
  [9319] = 5622,
  [9320] = 5644,
  [9321] = 5623,
  [9322] = 5622,
  [9323] = 9177,
  [9324] = 5671,
  [9325] = 5625,
  [9326] = 5546,
  [9327] = 5638,
  [9328] = 5627,
  [9329] = 5555,
  [9330] = 5628,
  [9331] = 9331,
  [9332] = 9332,
  [9333] = 5671,
  [9334] = 5561,
  [9335] = 5563,
  [9336] = 5569,
  [9337] = 5580,
  [9338] = 5615,
  [9339] = 5671,
  [9340] = 5625,
  [9341] = 5587,
  [9342] = 6584,
  [9343] = 857,
  [9344] = 5627,
  [9345] = 5663,
  [9346] = 5604,
  [9347] = 5621,
  [9348] = 5585,
  [9349] = 5628,
  [9350] = 5589,
  [9351] = 5590,
  [9352] = 5591,
  [9353] = 5606,
  [9354] = 5642,
  [9355] = 5592,
  [9356] = 5636,
  [9357] = 5634,
  [9358] = 5629,
  [9359] = 5593,
  [9360] = 5630,
  [9361] = 5631,
  [9362] = 5632,
  [9363] = 5633,
  [9364] = 9364,
  [9365] = 5637,
  [9366] = 9366,
  [9367] = 5594,
  [9368] = 5617,
  [9369] = 5641,
  [9370] = 9370,
  [9371] = 9371,
  [9372] = 5625,
  [9373] = 5635,
  [9374] = 5627,
  [9375] = 5664,
  [9376] = 5597,
  [9377] = 5665,
  [9378] = 9378,
  [9379] = 9379,
  [9380] = 5598,
  [9381] = 5641,
  [9382] = 5236,
  [9383] = 9383,
  [9384] = 9384,
  [9385] = 9385,
  [9386] = 6687,
  [9387] = 9385,
  [9388] = 5626,
  [9389] = 9385,
  [9390] = 9385,
  [9391] = 9391,
  [9392] = 7113,
  [9393] = 9393,
  [9394] = 9394,
  [9395] = 9395,
  [9396] = 5663,
  [9397] = 5629,
  [9398] = 9391,
  [9399] = 5630,
  [9400] = 9385,
  [9401] = 5631,
  [9402] = 5632,
  [9403] = 5670,
  [9404] = 5633,
  [9405] = 5634,
  [9406] = 5635,
  [9407] = 5636,
  [9408] = 9385,
  [9409] = 9409,
  [9410] = 5624,
  [9411] = 9411,
  [9412] = 5617,
  [9413] = 5661,
  [9414] = 5618,
  [9415] = 5652,
  [9416] = 5662,
  [9417] = 9411,
  [9418] = 8785,
  [9419] = 5637,
  [9420] = 5624,
  [9421] = 5619,
  [9422] = 6584,
  [9423] = 9391,
  [9424] = 9411,
  [9425] = 9425,
  [9426] = 9409,
  [9427] = 5617,
  [9428] = 9385,
  [9429] = 5618,
  [9430] = 5619,
  [9431] = 5657,
  [9432] = 9409,
  [9433] = 5620,
  [9434] = 5638,
  [9435] = 5621,
  [9436] = 9391,
  [9437] = 5622,
  [9438] = 5620,
  [9439] = 5639,
  [9440] = 9440,
  [9441] = 6844,
  [9442] = 5623,
  [9443] = 5671,
  [9444] = 5625,
  [9445] = 9445,
  [9446] = 5627,
  [9447] = 9447,
  [9448] = 9448,
  [9449] = 9384,
  [9450] = 9385,
  [9451] = 9411,
  [9452] = 9385,
  [9453] = 5653,
  [9454] = 5628,
  [9455] = 9385,
  [9456] = 9456,
  [9457] = 5660,
  [9458] = 9385,
  [9459] = 9448,
  [9460] = 5656,
  [9461] = 9461,
  [9462] = 9395,
  [9463] = 9447,
  [9464] = 9384,
  [9465] = 9411,
  [9466] = 5646,
  [9467] = 9385,
  [9468] = 6635,
  [9469] = 5668,
  [9470] = 9395,
  [9471] = 9447,
  [9472] = 9395,
  [9473] = 3316,
  [9474] = 9448,
  [9475] = 9395,
  [9476] = 9384,
  [9477] = 9391,
  [9478] = 5616,
  [9479] = 9447,
  [9480] = 9385,
  [9481] = 9385,
  [9482] = 5621,
  [9483] = 5629,
  [9484] = 5630,
  [9485] = 9485,
  [9486] = 9384,
  [9487] = 9409,
  [9488] = 9385,
  [9489] = 8751,
  [9490] = 5622,
  [9491] = 5631,
  [9492] = 9445,
  [9493] = 9493,
  [9494] = 5642,
  [9495] = 5632,
  [9496] = 5633,
  [9497] = 5634,
  [9498] = 5635,
  [9499] = 9384,
  [9500] = 9090,
  [9501] = 5623,
  [9502] = 5636,
  [9503] = 9445,
  [9504] = 5637,
  [9505] = 5638,
  [9506] = 5639,
  [9507] = 5671,
  [9508] = 9384,
  [9509] = 5641,
  [9510] = 9445,
  [9511] = 9448,
  [9512] = 9512,
  [9513] = 9445,
  [9514] = 9514,
  [9515] = 5625,
  [9516] = 9384,
  [9517] = 5627,
  [9518] = 9445,
  [9519] = 5645,
  [9520] = 9445,
  [9521] = 9521,
  [9522] = 9522,
  [9523] = 5654,
  [9524] = 9447,
  [9525] = 9409,
  [9526] = 5641,
  [9527] = 5628,
  [9528] = 5667,
  [9529] = 9448,
  [9530] = 9385,
  [9531] = 9447,
  [9532] = 5640,
  [9533] = 9533,
  [9534] = 9534,
  [9535] = 9535,
  [9536] = 9536,
  [9537] = 9409,
  [9538] = 9448,
  [9539] = 6676,
  [9540] = 9540,
  [9541] = 9541,
  [9542] = 9395,
  [9543] = 7113,
  [9544] = 9445,
  [9545] = 6692,
  [9546] = 9395,
  [9547] = 9395,
  [9548] = 5651,
  [9549] = 9385,
  [9550] = 5640,
  [9551] = 5659,
  [9552] = 5664,
  [9553] = 5665,
  [9554] = 5655,
  [9555] = 9535,
  [9556] = 9411,
  [9557] = 9385,
  [9558] = 6672,
  [9559] = 3313,
  [9560] = 8753,
  [9561] = 6685,
  [9562] = 6686,
  [9563] = 9391,
  [9564] = 667,
  [9565] = 672,
  [9566] = 9566,
  [9567] = 726,
  [9568] = 683,
  [9569] = 688,
  [9570] = 712,
  [9571] = 9316,
  [9572] = 713,
  [9573] = 1158,
  [9574] = 649,
  [9575] = 9575,
  [9576] = 9576,
  [9577] = 9576,
  [9578] = 682,
  [9579] = 679,
  [9580] = 736,
  [9581] = 751,
  [9582] = 665,
  [9583] = 9583,
  [9584] = 678,
  [9585] = 675,
  [9586] = 1088,
  [9587] = 731,
  [9588] = 686,
  [9589] = 732,
  [9590] = 717,
  [9591] = 705,
  [9592] = 699,
  [9593] = 1090,
  [9594] = 9594,
  [9595] = 9595,
  [9596] = 663,
  [9597] = 6879,
  [9598] = 9598,
  [9599] = 742,
  [9600] = 697,
  [9601] = 657,
  [9602] = 644,
  [9603] = 744,
  [9604] = 9604,
  [9605] = 720,
  [9606] = 700,
  [9607] = 737,
  [9608] = 9576,
  [9609] = 715,
  [9610] = 747,
  [9611] = 9611,
  [9612] = 709,
  [9613] = 9613,
  [9614] = 755,
  [9615] = 756,
  [9616] = 9616,
  [9617] = 681,
  [9618] = 9604,
  [9619] = 757,
  [9620] = 9299,
  [9621] = 9604,
  [9622] = 758,
  [9623] = 759,
  [9624] = 9624,
  [9625] = 6584,
  [9626] = 9626,
  [9627] = 9576,
  [9628] = 685,
  [9629] = 687,
  [9630] = 691,
  [9631] = 670,
  [9632] = 9632,
  [9633] = 1032,
  [9634] = 704,
  [9635] = 689,
  [9636] = 8900,
  [9637] = 661,
  [9638] = 694,
  [9639] = 9639,
  [9640] = 710,
  [9641] = 733,
  [9642] = 743,
  [9643] = 9643,
  [9644] = 762,
  [9645] = 9645,
  [9646] = 728,
  [9647] = 763,
  [9648] = 701,
  [9649] = 764,
  [9650] = 9604,
  [9651] = 6838,
  [9652] = 9652,
  [9653] = 9653,
  [9654] = 9654,
  [9655] = 9655,
  [9656] = 684,
  [9657] = 9657,
  [9658] = 754,
  [9659] = 765,
  [9660] = 1050,
  [9661] = 1031,
  [9662] = 652,
  [9663] = 693,
  [9664] = 6849,
  [9665] = 9665,
  [9666] = 9666,
  [9667] = 658,
  [9668] = 9668,
  [9669] = 9669,
  [9670] = 9670,
  [9671] = 749,
  [9672] = 9672,
  [9673] = 1084,
  [9674] = 9674,
  [9675] = 9675,
  [9676] = 750,
  [9677] = 696,
  [9678] = 9678,
  [9679] = 9576,
  [9680] = 9680,
  [9681] = 9681,
  [9682] = 718,
  [9683] = 746,
  [9684] = 9684,
  [9685] = 9604,
  [9686] = 727,
  [9687] = 6851,
  [9688] = 698,
  [9689] = 739,
  [9690] = 707,
  [9691] = 9691,
  [9692] = 702,
  [9693] = 745,
  [9694] = 752,
  [9695] = 9316,
  [9696] = 1136,
  [9697] = 680,
  [9698] = 9258,
  [9699] = 6894,
  [9700] = 1161,
  [9701] = 719,
  [9702] = 721,
  [9703] = 9703,
  [9704] = 703,
  [9705] = 722,
  [9706] = 708,
  [9707] = 9707,
  [9708] = 664,
  [9709] = 6635,
  [9710] = 9710,
  [9711] = 653,
  [9712] = 1078,
  [9713] = 690,
  [9714] = 9714,
  [9715] = 723,
  [9716] = 740,
  [9717] = 9717,
  [9718] = 725,
  [9719] = 692,
  [9720] = 9720,
  [9721] = 5687,
  [9722] = 9576,
  [9723] = 729,
  [9724] = 9724,
  [9725] = 648,
  [9726] = 677,
  [9727] = 9727,
  [9728] = 655,
  [9729] = 671,
  [9730] = 695,
  [9731] = 9576,
  [9732] = 673,
  [9733] = 660,
  [9734] = 9604,
  [9735] = 662,
  [9736] = 714,
  [9737] = 650,
  [9738] = 669,
  [9739] = 748,
  [9740] = 659,
  [9741] = 711,
  [9742] = 9215,
  [9743] = 6877,
  [9744] = 9744,
  [9745] = 730,
  [9746] = 9746,
  [9747] = 808,
  [9748] = 9748,
  [9749] = 9749,
  [9750] = 9750,
  [9751] = 9751,
  [9752] = 724,
  [9753] = 9753,
  [9754] = 9754,
  [9755] = 9755,
  [9756] = 674,
  [9757] = 9757,
  [9758] = 9758,
  [9759] = 9759,
  [9760] = 738,
  [9761] = 9761,
  [9762] = 9762,
  [9763] = 9763,
  [9764] = 9764,
  [9765] = 837,
  [9766] = 117,
  [9767] = 9767,
  [9768] = 834,
  [9769] = 9769,
  [9770] = 848,
  [9771] = 651,
  [9772] = 6825,
  [9773] = 836,
  [9774] = 642,
  [9775] = 844,
  [9776] = 9167,
  [9777] = 893,
  [9778] = 101,
  [9779] = 646,
  [9780] = 773,
  [9781] = 9781,
  [9782] = 9159,
  [9783] = 9754,
  [9784] = 826,
  [9785] = 100,
  [9786] = 643,
  [9787] = 833,
  [9788] = 645,
  [9789] = 855,
  [9790] = 9613,
  [9791] = 9311,
  [9792] = 9179,
  [9793] = 9371,
  [9794] = 9261,
  [9795] = 9366,
  [9796] = 9378,
  [9797] = 9290,
  [9798] = 9297,
  [9799] = 9163,
  [9800] = 9230,
  [9801] = 9370,
  [9802] = 9231,
  [9803] = 9259,
  [9804] = 9804,
  [9805] = 9754,
  [9806] = 9754,
  [9807] = 1233,
  [9808] = 5516,
  [9809] = 9754,
  [9810] = 9223,
  [9811] = 9226,
  [9812] = 9247,
  [9813] = 9332,
  [9814] = 9241,
  [9815] = 9242,
  [9816] = 9248,
  [9817] = 9267,
  [9818] = 9272,
  [9819] = 9364,
  [9820] = 9379,
  [9821] = 9182,
  [9822] = 9754,
  [9823] = 9754,
  [9824] = 9824,
  [9825] = 9825,
  [9826] = 9754,
  [9827] = 9827,
  [9828] = 9828,
  [9829] = 9829,
  [9830] = 9754,
  [9831] = 9831,
  [9832] = 9832,
  [9833] = 9833,
  [9834] = 9754,
  [9835] = 9835,
  [9836] = 9836,
  [9837] = 9240,
  [9838] = 9838,
  [9839] = 9839,
  [9840] = 9840,
  [9841] = 1234,
  [9842] = 9842,
  [9843] = 9178,
  [9844] = 9626,
  [9845] = 9845,
  [9846] = 9846,
  [9847] = 9847,
  [9848] = 9848,
  [9849] = 9849,
  [9850] = 9757,
  [9851] = 9611,
  [9852] = 9824,
  [9853] = 9825,
  [9854] = 9827,
  [9855] = 9828,
  [9856] = 9829,
  [9857] = 9831,
  [9858] = 9832,
  [9859] = 9835,
  [9860] = 9836,
  [9861] = 9861,
  [9862] = 9862,
  [9863] = 9863,
  [9864] = 9861,
  [9865] = 9865,
  [9866] = 9866,
  [9867] = 9867,
  [9868] = 9868,
  [9869] = 1206,
  [9870] = 9870,
  [9871] = 9862,
  [9872] = 9863,
  [9873] = 9873,
  [9874] = 1187,
  [9875] = 9875,
  [9876] = 9876,
  [9877] = 9877,
  [9878] = 9754,
  [9879] = 1236,
  [9880] = 1209,
  [9881] = 1196,
  [9882] = 1218,
  [9883] = 5513,
  [9884] = 5514,
  [9885] = 5538,
  [9886] = 5531,
  [9887] = 5532,
  [9888] = 5535,
  [9889] = 5536,
  [9890] = 6635,
  [9891] = 9754,
  [9892] = 9842,
  [9893] = 5537,
  [9894] = 9845,
  [9895] = 9846,
  [9896] = 9847,
  [9897] = 1185,
  [9898] = 9848,
  [9899] = 9865,
  [9900] = 9849,
  [9901] = 9901,
  [9902] = 9757,
  [9903] = 9824,
  [9904] = 9825,
  [9905] = 9827,
  [9906] = 9828,
  [9907] = 9829,
  [9908] = 9831,
  [9909] = 9835,
  [9910] = 9836,
  [9911] = 9862,
  [9912] = 9863,
  [9913] = 9865,
  [9914] = 9868,
  [9915] = 9870,
  [9916] = 9873,
  [9917] = 9875,
  [9918] = 9754,
  [9919] = 9877,
  [9920] = 8754,
  [9921] = 9754,
  [9922] = 9842,
  [9923] = 9845,
  [9924] = 9924,
  [9925] = 9846,
  [9926] = 9847,
  [9927] = 9848,
  [9928] = 9867,
  [9929] = 9757,
  [9930] = 9824,
  [9931] = 9825,
  [9932] = 9827,
  [9933] = 9828,
  [9934] = 9829,
  [9935] = 9831,
  [9936] = 9835,
  [9937] = 9836,
  [9938] = 9938,
  [9939] = 9939,
  [9940] = 9940,
  [9941] = 9862,
  [9942] = 9863,
  [9943] = 9865,
  [9944] = 9868,
  [9945] = 9945,
  [9946] = 9870,
  [9947] = 9873,
  [9948] = 9948,
  [9949] = 9949,
  [9950] = 9875,
  [9951] = 9877,
  [9952] = 9845,
  [9953] = 9953,
  [9954] = 9754,
  [9955] = 9842,
  [9956] = 9868,
  [9957] = 9845,
  [9958] = 9846,
  [9959] = 9847,
  [9960] = 9960,
  [9961] = 9848,
  [9962] = 9757,
  [9963] = 9824,
  [9964] = 9825,
  [9965] = 9827,
  [9966] = 9828,
  [9967] = 9829,
  [9968] = 9831,
  [9969] = 9835,
  [9970] = 9836,
  [9971] = 9862,
  [9972] = 9863,
  [9973] = 9865,
  [9974] = 9868,
  [9975] = 818,
  [9976] = 9976,
  [9977] = 9842,
  [9978] = 9870,
  [9979] = 6672,
  [9980] = 1201,
  [9981] = 9873,
  [9982] = 830,
  [9983] = 5533,
  [9984] = 5534,
  [9985] = 9875,
  [9986] = 858,
  [9987] = 9877,
  [9988] = 1199,
  [9989] = 1249,
  [9990] = 1250,
  [9991] = 1252,
  [9992] = 1253,
  [9993] = 1255,
  [9994] = 1215,
  [9995] = 9842,
  [9996] = 8785,
  [9997] = 967,
  [9998] = 9845,
  [9999] = 839,
  [10000] = 9846,
  [10001] = 6676,
  [10002] = 9847,
  [10003] = 9870,
  [10004] = 9848,
  [10005] = 9746,
  [10006] = 9757,
  [10007] = 9824,
  [10008] = 9825,
  [10009] = 9827,
  [10010] = 9828,
  [10011] = 9829,
  [10012] = 9831,
  [10013] = 842,
  [10014] = 843,
  [10015] = 9835,
  [10016] = 9836,
  [10017] = 1179,
  [10018] = 9862,
  [10019] = 9863,
  [10020] = 1190,
  [10021] = 10021,
  [10022] = 9846,
  [10023] = 9865,
  [10024] = 9868,
  [10025] = 9870,
  [10026] = 9873,
  [10027] = 1219,
  [10028] = 9875,
  [10029] = 768,
  [10030] = 6685,
  [10031] = 6686,
  [10032] = 9877,
  [10033] = 770,
  [10034] = 771,
  [10035] = 1202,
  [10036] = 1210,
  [10037] = 1225,
  [10038] = 1243,
  [10039] = 1246,
  [10040] = 823,
  [10041] = 9846,
  [10042] = 9847,
  [10043] = 9848,
  [10044] = 9824,
  [10045] = 9825,
  [10046] = 9827,
  [10047] = 9828,
  [10048] = 9829,
  [10049] = 9831,
  [10050] = 9835,
  [10051] = 9836,
  [10052] = 9863,
  [10053] = 9865,
  [10054] = 9870,
  [10055] = 9754,
  [10056] = 9847,
  [10057] = 958,
  [10058] = 9848,
  [10059] = 1178,
  [10060] = 9824,
  [10061] = 9825,
  [10062] = 9827,
  [10063] = 9828,
  [10064] = 9829,
  [10065] = 9831,
  [10066] = 9835,
  [10067] = 9836,
  [10068] = 9863,
  [10069] = 831,
  [10070] = 832,
  [10071] = 10071,
  [10072] = 1229,
  [10073] = 1230,
  [10074] = 1232,
  [10075] = 9848,
  [10076] = 1191,
  [10077] = 9824,
  [10078] = 9825,
  [10079] = 9828,
  [10080] = 9829,
  [10081] = 9863,
  [10082] = 10082,
  [10083] = 9824,
  [10084] = 9825,
  [10085] = 9828,
  [10086] = 9829,
  [10087] = 841,
  [10088] = 9824,
  [10089] = 9825,
  [10090] = 9828,
  [10091] = 9829,
  [10092] = 9824,
  [10093] = 9825,
  [10094] = 9828,
  [10095] = 9829,
  [10096] = 9824,
  [10097] = 9825,
  [10098] = 9828,
  [10099] = 9829,
  [10100] = 1194,
  [10101] = 9824,
  [10102] = 9825,
  [10103] = 9828,
  [10104] = 9829,
  [10105] = 9824,
  [10106] = 9825,
  [10107] = 9828,
  [10108] = 9829,
  [10109] = 853,
  [10110] = 854,
  [10111] = 1181,
  [10112] = 1184,
  [10113] = 1204,
  [10114] = 1242,
  [10115] = 862,
  [10116] = 9848,
  [10117] = 871,
  [10118] = 9824,
  [10119] = 9825,
  [10120] = 9828,
  [10121] = 9829,
  [10122] = 1217,
  [10123] = 1220,
  [10124] = 9863,
  [10125] = 9924,
  [10126] = 9976,
  [10127] = 10071,
  [10128] = 10082,
  [10129] = 1248,
  [10130] = 9873,
  [10131] = 878,
  [10132] = 10132,
  [10133] = 895,
  [10134] = 9861,
  [10135] = 10135,
  [10136] = 775,
  [10137] = 9848,
  [10138] = 9863,
  [10139] = 786,
  [10140] = 10140,
  [10141] = 10141,
  [10142] = 10142,
  [10143] = 9848,
  [10144] = 9863,
  [10145] = 9924,
  [10146] = 10071,
  [10147] = 10082,
  [10148] = 767,
  [10149] = 1224,
  [10150] = 1226,
  [10151] = 10151,
  [10152] = 868,
  [10153] = 1247,
  [10154] = 940,
  [10155] = 1254,
  [10156] = 1195,
  [10157] = 1239,
  [10158] = 1238,
  [10159] = 9848,
  [10160] = 9863,
  [10161] = 9924,
  [10162] = 10162,
  [10163] = 10163,
  [10164] = 10071,
  [10165] = 10082,
  [10166] = 9847,
  [10167] = 1188,
  [10168] = 1205,
  [10169] = 1211,
  [10170] = 1183,
  [10171] = 1207,
  [10172] = 1256,
  [10173] = 1213,
  [10174] = 10174,
  [10175] = 9924,
  [10176] = 10071,
  [10177] = 10082,
  [10178] = 6687,
  [10179] = 9924,
  [10180] = 10071,
  [10181] = 10082,
  [10182] = 1192,
  [10183] = 824,
  [10184] = 825,
  [10185] = 9875,
  [10186] = 9876,
  [10187] = 9924,
  [10188] = 10071,
  [10189] = 10082,
  [10190] = 9754,
  [10191] = 10191,
  [10192] = 827,
  [10193] = 6692,
  [10194] = 835,
  [10195] = 1231,
  [10196] = 9924,
  [10197] = 10071,
  [10198] = 10082,
  [10199] = 1244,
  [10200] = 845,
  [10201] = 846,
  [10202] = 847,
  [10203] = 849,
  [10204] = 856,
  [10205] = 654,
  [10206] = 753,
  [10207] = 1186,
  [10208] = 1208,
  [10209] = 863,
  [10210] = 864,
  [10211] = 865,
  [10212] = 866,
  [10213] = 10162,
  [10214] = 867,
  [10215] = 10215,
  [10216] = 9781,
  [10217] = 872,
  [10218] = 873,
  [10219] = 10219,
  [10220] = 706,
  [10221] = 734,
  [10222] = 1222,
  [10223] = 1223,
  [10224] = 1227,
  [10225] = 1237,
  [10226] = 10226,
  [10227] = 10227,
  [10228] = 879,
  [10229] = 880,
  [10230] = 881,
  [10231] = 10231,
  [10232] = 882,
  [10233] = 884,
  [10234] = 9960,
  [10235] = 888,
  [10236] = 889,
  [10237] = 666,
  [10238] = 668,
  [10239] = 1203,
  [10240] = 10163,
  [10241] = 896,
  [10242] = 897,
  [10243] = 900,
  [10244] = 902,
  [10245] = 10245,
  [10246] = 929,
  [10247] = 850,
  [10248] = 769,
  [10249] = 766,
  [10250] = 716,
  [10251] = 1200,
  [10252] = 1193,
  [10253] = 10162,
  [10254] = 10254,
  [10255] = 776,
  [10256] = 777,
  [10257] = 778,
  [10258] = 779,
  [10259] = 10163,
  [10260] = 783,
  [10261] = 784,
  [10262] = 735,
  [10263] = 741,
  [10264] = 10162,
  [10265] = 787,
  [10266] = 788,
  [10267] = 789,
  [10268] = 790,
  [10269] = 794,
  [10270] = 795,
  [10271] = 760,
  [10272] = 761,
  [10273] = 10163,
  [10274] = 10162,
  [10275] = 796,
  [10276] = 797,
  [10277] = 9877,
  [10278] = 798,
  [10279] = 799,
  [10280] = 803,
  [10281] = 10163,
  [10282] = 804,
  [10283] = 805,
  [10284] = 10162,
  [10285] = 806,
  [10286] = 807,
  [10287] = 809,
  [10288] = 810,
  [10289] = 811,
  [10290] = 812,
  [10291] = 813,
  [10292] = 814,
  [10293] = 817,
  [10294] = 10163,
  [10295] = 10162,
  [10296] = 10162,
  [10297] = 852,
  [10298] = 1245,
  [10299] = 10299,
  [10300] = 10300,
  [10301] = 10301,
  [10302] = 10302,
  [10303] = 10303,
  [10304] = 10304,
  [10305] = 9848,
  [10306] = 10306,
  [10307] = 9754,
  [10308] = 829,
  [10309] = 9827,
  [10310] = 9831,
  [10311] = 9835,
  [10312] = 9836,
  [10313] = 838,
  [10314] = 1233,
  [10315] = 9827,
  [10316] = 9831,
  [10317] = 9835,
  [10318] = 9836,
  [10319] = 10319,
  [10320] = 9827,
  [10321] = 9831,
  [10322] = 9835,
  [10323] = 9836,
  [10324] = 9827,
  [10325] = 9831,
  [10326] = 9835,
  [10327] = 9836,
  [10328] = 10328,
  [10329] = 9827,
  [10330] = 9831,
  [10331] = 9835,
  [10332] = 9836,
  [10333] = 851,
  [10334] = 9827,
  [10335] = 9831,
  [10336] = 9835,
  [10337] = 9836,
  [10338] = 859,
  [10339] = 9827,
  [10340] = 9831,
  [10341] = 9835,
  [10342] = 9836,
  [10343] = 9924,
  [10344] = 10071,
  [10345] = 9924,
  [10346] = 10071,
  [10347] = 9924,
  [10348] = 10071,
  [10349] = 9924,
  [10350] = 10071,
  [10351] = 869,
  [10352] = 9924,
  [10353] = 10071,
  [10354] = 9849,
  [10355] = 870,
  [10356] = 874,
  [10357] = 9924,
  [10358] = 10071,
  [10359] = 9924,
  [10360] = 10071,
  [10361] = 883,
  [10362] = 885,
  [10363] = 886,
  [10364] = 887,
  [10365] = 890,
  [10366] = 936,
  [10367] = 937,
  [10368] = 938,
  [10369] = 772,
  [10370] = 9848,
  [10371] = 9827,
  [10372] = 9831,
  [10373] = 9835,
  [10374] = 9836,
  [10375] = 9863,
  [10376] = 780,
  [10377] = 781,
  [10378] = 782,
  [10379] = 785,
  [10380] = 791,
  [10381] = 792,
  [10382] = 793,
  [10383] = 10383,
  [10384] = 9924,
  [10385] = 10071,
  [10386] = 10386,
  [10387] = 9746,
  [10388] = 800,
  [10389] = 9746,
  [10390] = 801,
  [10391] = 9746,
  [10392] = 802,
  [10393] = 9746,
  [10394] = 9746,
  [10395] = 1241,
  [10396] = 10396,
  [10397] = 9267,
  [10398] = 9272,
  [10399] = 9364,
  [10400] = 9379,
  [10401] = 10401,
  [10402] = 9182,
  [10403] = 10403,
  [10404] = 9240,
  [10405] = 6692,
  [10406] = 6672,
  [10407] = 9178,
  [10408] = 6676,
  [10409] = 6685,
  [10410] = 6686,
  [10411] = 10411,
  [10412] = 9241,
  [10413] = 6687,
  [10414] = 6879,
  [10415] = 10415,
  [10416] = 6894,
  [10417] = 10417,
  [10418] = 10418,
  [10419] = 9242,
  [10420] = 9248,
  [10421] = 10421,
  [10422] = 10422,
  [10423] = 6825,
  [10424] = 10424,
  [10425] = 9167,
  [10426] = 9159,
  [10427] = 6838,
  [10428] = 6844,
  [10429] = 6849,
  [10430] = 6851,
  [10431] = 10431,
  [10432] = 9311,
  [10433] = 9179,
  [10434] = 9371,
  [10435] = 9261,
  [10436] = 9366,
  [10437] = 9378,
  [10438] = 9290,
  [10439] = 9297,
  [10440] = 9163,
  [10441] = 9230,
  [10442] = 9370,
  [10443] = 9231,
  [10444] = 9259,
  [10445] = 6877,
  [10446] = 9223,
  [10447] = 9226,
  [10448] = 9247,
  [10449] = 9332,
  [10450] = 10450,
  [10451] = 9248,
  [10452] = 10452,
  [10453] = 9261,
  [10454] = 9366,
  [10455] = 9378,
  [10456] = 9290,
  [10457] = 9297,
  [10458] = 10458,
  [10459] = 9163,
  [10460] = 9230,
  [10461] = 9370,
  [10462] = 9231,
  [10463] = 9259,
  [10464] = 10464,
  [10465] = 10465,
  [10466] = 10466,
  [10467] = 10467,
  [10468] = 10468,
  [10469] = 10469,
  [10470] = 10470,
  [10471] = 10471,
  [10472] = 10472,
  [10473] = 5513,
  [10474] = 5514,
  [10475] = 5538,
  [10476] = 5531,
  [10477] = 5532,
  [10478] = 10467,
  [10479] = 5535,
  [10480] = 5536,
  [10481] = 10467,
  [10482] = 6879,
  [10483] = 10483,
  [10484] = 6877,
  [10485] = 9223,
  [10486] = 5537,
  [10487] = 10487,
  [10488] = 9226,
  [10489] = 10467,
  [10490] = 9247,
  [10491] = 9332,
  [10492] = 9241,
  [10493] = 9242,
  [10494] = 10466,
  [10495] = 9267,
  [10496] = 9272,
  [10497] = 9364,
  [10498] = 9379,
  [10499] = 9182,
  [10500] = 10467,
  [10501] = 10501,
  [10502] = 6825,
  [10503] = 10431,
  [10504] = 10467,
  [10505] = 117,
  [10506] = 9240,
  [10507] = 10507,
  [10508] = 10487,
  [10509] = 10509,
  [10510] = 10510,
  [10511] = 10466,
  [10512] = 10512,
  [10513] = 10513,
  [10514] = 10514,
  [10515] = 10467,
  [10516] = 6894,
  [10517] = 10517,
  [10518] = 10518,
  [10519] = 10466,
  [10520] = 10520,
  [10521] = 10487,
  [10522] = 10487,
  [10523] = 10523,
  [10524] = 10466,
  [10525] = 10525,
  [10526] = 10487,
  [10527] = 5291,
  [10528] = 10466,
  [10529] = 9167,
  [10530] = 5533,
  [10531] = 5534,
  [10532] = 10532,
  [10533] = 10487,
  [10534] = 10517,
  [10535] = 10535,
  [10536] = 10536,
  [10537] = 10537,
  [10538] = 10538,
  [10539] = 10487,
  [10540] = 10540,
  [10541] = 10466,
  [10542] = 9159,
  [10543] = 10543,
  [10544] = 10544,
  [10545] = 10487,
  [10546] = 10546,
  [10547] = 10466,
  [10548] = 6838,
  [10549] = 10549,
  [10550] = 6844,
  [10551] = 10487,
  [10552] = 10552,
  [10553] = 10553,
  [10554] = 10554,
  [10555] = 10466,
  [10556] = 10487,
  [10557] = 6849,
  [10558] = 10466,
  [10559] = 10559,
  [10560] = 6851,
  [10561] = 9311,
  [10562] = 10517,
  [10563] = 10563,
  [10564] = 10564,
  [10565] = 10565,
  [10566] = 10517,
  [10567] = 10517,
  [10568] = 10517,
  [10569] = 10569,
  [10570] = 10570,
  [10571] = 9179,
  [10572] = 10467,
  [10573] = 9371,
  [10574] = 9178,
  [10575] = 10575,
  [10576] = 10576,
  [10577] = 10577,
  [10578] = 10578,
  [10579] = 10579,
  [10580] = 10580,
  [10581] = 10578,
  [10582] = 10582,
  [10583] = 10583,
  [10584] = 10584,
  [10585] = 10585,
  [10586] = 10586,
  [10587] = 10587,
  [10588] = 10588,
  [10589] = 10589,
  [10590] = 10590,
  [10591] = 10591,
  [10592] = 10578,
  [10593] = 10576,
  [10594] = 10594,
  [10595] = 10578,
  [10596] = 10588,
  [10597] = 10585,
  [10598] = 10598,
  [10599] = 10584,
  [10600] = 10600,
  [10601] = 10576,
  [10602] = 10576,
  [10603] = 10594,
  [10604] = 7422,
  [10605] = 10605,
  [10606] = 10606,
  [10607] = 10607,
  [10608] = 10588,
  [10609] = 10584,
  [10610] = 10578,
  [10611] = 10594,
  [10612] = 10588,
  [10613] = 10584,
  [10614] = 10594,
  [10615] = 10588,
  [10616] = 103,
  [10617] = 102,
  [10618] = 10618,
  [10619] = 10578,
  [10620] = 10620,
  [10621] = 10621,
  [10622] = 10585,
  [10623] = 10585,
  [10624] = 10578,
  [10625] = 10578,
  [10626] = 10626,
  [10627] = 10594,
  [10628] = 10578,
  [10629] = 10629,
  [10630] = 10578,
  [10631] = 10631,
  [10632] = 10632,
  [10633] = 10632,
  [10634] = 10634,
  [10635] = 10621,
  [10636] = 10636,
  [10637] = 5309,
  [10638] = 10632,
  [10639] = 5305,
  [10640] = 5303,
  [10641] = 10641,
  [10642] = 10632,
  [10643] = 10643,
  [10644] = 10634,
  [10645] = 10645,
  [10646] = 10634,
  [10647] = 10632,
  [10648] = 10634,
  [10649] = 10632,
  [10650] = 10634,
  [10651] = 10632,
  [10652] = 10634,
  [10653] = 10632,
  [10654] = 10634,
  [10655] = 10632,
  [10656] = 10634,
  [10657] = 10634,
  [10658] = 10634,
  [10659] = 10632,
  [10660] = 10660,
  [10661] = 10661,
  [10662] = 10660,
  [10663] = 10663,
  [10664] = 10661,
  [10665] = 10660,
  [10666] = 10666,
  [10667] = 10661,
  [10668] = 10668,
  [10669] = 9318,
  [10670] = 10670,
  [10671] = 10661,
  [10672] = 10661,
  [10673] = 10660,
  [10674] = 5857,
  [10675] = 10661,
  [10676] = 10661,
  [10677] = 10660,
  [10678] = 10678,
  [10679] = 10679,
  [10680] = 10680,
  [10681] = 10681,
  [10682] = 10682,
  [10683] = 10683,
  [10684] = 10684,
  [10685] = 10685,
  [10686] = 5949,
  [10687] = 10687,
  [10688] = 10688,
  [10689] = 10689,
  [10690] = 10690,
  [10691] = 10691,
  [10692] = 10692,
  [10693] = 10693,
  [10694] = 10691,
  [10695] = 10692,
  [10696] = 10696,
  [10697] = 10697,
  [10698] = 10693,
  [10699] = 10699,
  [10700] = 10691,
  [10701] = 10701,
  [10702] = 10691,
  [10703] = 10691,
  [10704] = 8680,
  [10705] = 10692,
  [10706] = 10706,
  [10707] = 10692,
  [10708] = 10693,
  [10709] = 10692,
  [10710] = 10710,
  [10711] = 10711,
  [10712] = 10712,
  [10713] = 10693,
  [10714] = 10693,
  [10715] = 10715,
  [10716] = 10716,
  [10717] = 10717,
  [10718] = 10718,
  [10719] = 10719,
  [10720] = 10720,
  [10721] = 10721,
  [10722] = 10722,
  [10723] = 10723,
  [10724] = 10724,
  [10725] = 10725,
  [10726] = 8807,
  [10727] = 10727,
  [10728] = 10728,
  [10729] = 10729,
  [10730] = 10730,
  [10731] = 10731,
  [10732] = 10732,
  [10733] = 10733,
  [10734] = 10734,
  [10735] = 10735,
  [10736] = 10736,
  [10737] = 10737,
  [10738] = 10738,
  [10739] = 10739,
  [10740] = 10740,
  [10741] = 10741,
  [10742] = 10742,
  [10743] = 10743,
  [10744] = 10744,
  [10745] = 10745,
  [10746] = 10746,
  [10747] = 10747,
  [10748] = 10748,
  [10749] = 10749,
  [10750] = 10750,
  [10751] = 10749,
  [10752] = 10750,
  [10753] = 10749,
  [10754] = 10749,
  [10755] = 10755,
  [10756] = 10756,
  [10757] = 10757,
  [10758] = 10749,
  [10759] = 6584,
  [10760] = 10750,
  [10761] = 10761,
  [10762] = 10762,
  [10763] = 10750,
  [10764] = 10750,
  [10765] = 10765,
  [10766] = 10765,
  [10767] = 10765,
  [10768] = 9218,
  [10769] = 6692,
  [10770] = 5373,
  [10771] = 5363,
  [10772] = 5390,
  [10773] = 5375,
  [10774] = 10765,
  [10775] = 5364,
  [10776] = 6635,
  [10777] = 5370,
  [10778] = 5379,
  [10779] = 6687,
  [10780] = 10765,
  [10781] = 6672,
  [10782] = 6676,
  [10783] = 10783,
  [10784] = 6763,
  [10785] = 6621,
  [10786] = 10786,
  [10787] = 10787,
  [10788] = 10788,
  [10789] = 10789,
  [10790] = 10790,
  [10791] = 10791,
  [10792] = 10792,
  [10793] = 6846,
  [10794] = 6686,
  [10795] = 6749,
  [10796] = 10796,
  [10797] = 10797,
  [10798] = 6685,
  [10799] = 10799,
  [10800] = 10800,
  [10801] = 10801,
  [10802] = 10802,
  [10803] = 10803,
  [10804] = 10804,
  [10805] = 10805,
  [10806] = 10806,
  [10807] = 10807,
  [10808] = 10808,
  [10809] = 10809,
  [10810] = 6879,
  [10811] = 10811,
  [10812] = 10812,
  [10813] = 10813,
  [10814] = 6894,
  [10815] = 10815,
  [10816] = 10816,
  [10817] = 5368,
  [10818] = 10818,
  [10819] = 10797,
  [10820] = 10820,
  [10821] = 10815,
  [10822] = 6877,
  [10823] = 10823,
  [10824] = 10807,
  [10825] = 6825,
  [10826] = 6844,
  [10827] = 6849,
  [10828] = 10807,
  [10829] = 8045,
  [10830] = 10801,
  [10831] = 6851,
  [10832] = 10811,
  [10833] = 6838,
  [10834] = 10806,
  [10835] = 10816,
  [10836] = 10808,
  [10837] = 10809,
  [10838] = 10815,
  [10839] = 10789,
  [10840] = 10812,
  [10841] = 10841,
  [10842] = 5645,
  [10843] = 10843,
  [10844] = 10844,
  [10845] = 10845,
  [10846] = 10846,
  [10847] = 8045,
  [10848] = 10848,
  [10849] = 10849,
  [10850] = 10850,
  [10851] = 10851,
  [10852] = 10852,
  [10853] = 10853,
  [10854] = 10854,
  [10855] = 5659,
  [10856] = 10856,
  [10857] = 5646,
  [10858] = 10858,
  [10859] = 5651,
  [10860] = 10860,
  [10861] = 5667,
  [10862] = 10862,
  [10863] = 10863,
  [10864] = 10864,
  [10865] = 5662,
  [10866] = 10866,
  [10867] = 10867,
  [10868] = 5670,
  [10869] = 10815,
  [10870] = 10870,
  [10871] = 8045,
  [10872] = 10872,
  [10873] = 10873,
  [10874] = 10874,
  [10875] = 10875,
  [10876] = 5661,
  [10877] = 10877,
  [10878] = 5663,
  [10879] = 10879,
  [10880] = 10880,
  [10881] = 10881,
  [10882] = 10882,
  [10883] = 10807,
  [10884] = 10884,
  [10885] = 10885,
  [10886] = 10886,
  [10887] = 10887,
  [10888] = 10888,
  [10889] = 10889,
  [10890] = 10890,
  [10891] = 10891,
  [10892] = 10892,
  [10893] = 10893,
  [10894] = 10894,
  [10895] = 10895,
  [10896] = 10802,
  [10897] = 10897,
  [10898] = 10799,
  [10899] = 10899,
  [10900] = 10900,
  [10901] = 10901,
  [10902] = 10902,
  [10903] = 10903,
  [10904] = 10904,
  [10905] = 10905,
  [10906] = 10906,
  [10907] = 5668,
  [10908] = 10908,
  [10909] = 5616,
  [10910] = 10910,
  [10911] = 1397,
  [10912] = 10912,
  [10913] = 10815,
  [10914] = 5653,
  [10915] = 5654,
  [10916] = 1388,
  [10917] = 6621,
  [10918] = 10918,
  [10919] = 10919,
  [10920] = 5368,
  [10921] = 10921,
  [10922] = 10922,
  [10923] = 10923,
  [10924] = 10924,
  [10925] = 10925,
  [10926] = 10926,
  [10927] = 10927,
  [10928] = 10928,
  [10929] = 10929,
  [10930] = 10930,
  [10931] = 10931,
  [10932] = 10932,
  [10933] = 5365,
  [10934] = 10934,
  [10935] = 5298,
  [10936] = 10621,
  [10937] = 5366,
  [10938] = 10934,
  [10939] = 10860,
  [10940] = 5366,
  [10941] = 10934,
  [10942] = 10934,
  [10943] = 10943,
  [10944] = 10944,
  [10945] = 5297,
  [10946] = 5365,
  [10947] = 10947,
  [10948] = 10948,
  [10949] = 10949,
  [10950] = 10950,
  [10951] = 10951,
  [10952] = 10952,
  [10953] = 10953,
  [10954] = 10954,
  [10955] = 10955,
  [10956] = 10956,
  [10957] = 10957,
  [10958] = 10958,
  [10959] = 10621,
  [10960] = 10960,
  [10961] = 10961,
  [10962] = 10950,
  [10963] = 10963,
  [10964] = 10964,
  [10965] = 10950,
  [10966] = 10950,
  [10967] = 5306,
  [10968] = 10968,
  [10969] = 10969,
  [10970] = 10970,
  [10971] = 10971,
  [10972] = 10950,
  [10973] = 10973,
  [10974] = 10974,
  [10975] = 10975,
  [10976] = 10976,
  [10977] = 10977,
  [10978] = 10978,
  [10979] = 10979,
  [10980] = 10980,
  [10981] = 10981,
  [10982] = 5395,
  [10983] = 10983,
  [10984] = 10984,
  [10985] = 5427,
  [10986] = 10986,
  [10987] = 5429,
  [10988] = 5396,
  [10989] = 5398,
  [10990] = 10990,
  [10991] = 10991,
  [10992] = 10992,
  [10993] = 5399,
  [10994] = 5368,
  [10995] = 10980,
  [10996] = 10981,
  [10997] = 5369,
  [10998] = 5396,
  [10999] = 5398,
  [11000] = 10991,
  [11001] = 5433,
  [11002] = 11002,
  [11003] = 11003,
  [11004] = 10983,
  [11005] = 11002,
  [11006] = 11003,
  [11007] = 11007,
  [11008] = 10991,
  [11009] = 11009,
  [11010] = 11010,
  [11011] = 10991,
  [11012] = 5432,
  [11013] = 10980,
  [11014] = 10981,
  [11015] = 11015,
  [11016] = 10980,
  [11017] = 10981,
  [11018] = 11002,
  [11019] = 11003,
  [11020] = 10983,
  [11021] = 11021,
  [11022] = 11022,
  [11023] = 10991,
  [11024] = 10980,
  [11025] = 10981,
  [11026] = 5409,
  [11027] = 5418,
  [11028] = 11028,
  [11029] = 11029,
  [11030] = 11030,
  [11031] = 11002,
  [11032] = 11003,
  [11033] = 11002,
  [11034] = 11003,
  [11035] = 10983,
  [11036] = 11036,
  [11037] = 11037,
  [11038] = 10983,
  [11039] = 5407,
  [11040] = 11040,
  [11041] = 11041,
  [11042] = 11042,
  [11043] = 11043,
  [11044] = 11044,
  [11045] = 11045,
  [11046] = 11046,
  [11047] = 10682,
  [11048] = 11046,
  [11049] = 11049,
  [11050] = 11046,
  [11051] = 11044,
  [11052] = 11052,
  [11053] = 11053,
  [11054] = 11046,
  [11055] = 5380,
  [11056] = 11044,
  [11057] = 5387,
  [11058] = 11044,
  [11059] = 5371,
  [11060] = 5521,
  [11061] = 11061,
  [11062] = 11062,
  [11063] = 11063,
  [11064] = 5378,
  [11065] = 11065,
  [11066] = 11066,
  [11067] = 11067,
  [11068] = 5301,
  [11069] = 5384,
  [11070] = 11044,
  [11071] = 11071,
  [11072] = 11046,
  [11073] = 5307,
  [11074] = 11044,
  [11075] = 11044,
  [11076] = 11076,
  [11077] = 11077,
  [11078] = 11044,
  [11079] = 11079,
  [11080] = 11080,
  [11081] = 11081,
  [11082] = 11082,
  [11083] = 11083,
  [11084] = 11084,
  [11085] = 11080,
  [11086] = 11086,
  [11087] = 11084,
  [11088] = 11080,
  [11089] = 11089,
  [11090] = 11090,
  [11091] = 5304,
  [11092] = 11092,
  [11093] = 11093,
  [11094] = 11092,
  [11095] = 11095,
  [11096] = 11096,
  [11097] = 11082,
  [11098] = 11083,
  [11099] = 11099,
  [11100] = 11092,
  [11101] = 11101,
  [11102] = 11093,
  [11103] = 11084,
  [11104] = 11080,
  [11105] = 11093,
  [11106] = 11090,
  [11107] = 11082,
  [11108] = 11083,
  [11109] = 11090,
  [11110] = 11090,
  [11111] = 5302,
  [11112] = 11079,
  [11113] = 11095,
  [11114] = 11084,
  [11115] = 11080,
  [11116] = 11079,
  [11117] = 11095,
  [11118] = 11101,
  [11119] = 11082,
  [11120] = 11083,
  [11121] = 11092,
  [11122] = 11093,
  [11123] = 5295,
  [11124] = 11079,
  [11125] = 11095,
  [11126] = 11092,
  [11127] = 11093,
  [11128] = 11101,
  [11129] = 11129,
  [11130] = 11130,
  [11131] = 5308,
  [11132] = 11132,
  [11133] = 11090,
  [11134] = 11079,
  [11135] = 11095,
  [11136] = 11082,
  [11137] = 11083,
  [11138] = 11101,
  [11139] = 11084,
  [11140] = 11132,
  [11141] = 11132,
  [11142] = 11101,
  [11143] = 11143,
  [11144] = 11144,
  [11145] = 11145,
  [11146] = 11143,
  [11147] = 11147,
  [11148] = 11148,
  [11149] = 11149,
  [11150] = 11150,
  [11151] = 11151,
  [11152] = 11152,
  [11153] = 11148,
  [11154] = 11154,
  [11155] = 11155,
  [11156] = 11156,
  [11157] = 11154,
  [11158] = 11154,
  [11159] = 11159,
  [11160] = 11160,
  [11161] = 11052,
  [11162] = 11162,
  [11163] = 5390,
  [11164] = 5375,
  [11165] = 5373,
  [11166] = 11148,
  [11167] = 11167,
  [11168] = 11168,
  [11169] = 11148,
  [11170] = 11170,
  [11171] = 11148,
  [11172] = 11143,
  [11173] = 11143,
  [11174] = 11174,
  [11175] = 11148,
  [11176] = 11071,
  [11177] = 11143,
  [11178] = 11143,
  [11179] = 11143,
  [11180] = 11180,
  [11181] = 11143,
  [11182] = 11148,
  [11183] = 11143,
  [11184] = 11143,
  [11185] = 11143,
  [11186] = 11143,
  [11187] = 11143,
  [11188] = 11143,
  [11189] = 11143,
  [11190] = 11148,
  [11191] = 11148,
  [11192] = 11192,
  [11193] = 5379,
  [11194] = 11194,
  [11195] = 11195,
  [11196] = 11148,
  [11197] = 11144,
  [11198] = 11144,
  [11199] = 11143,
  [11200] = 11159,
  [11201] = 11148,
  [11202] = 11148,
  [11203] = 5301,
  [11204] = 11204,
  [11205] = 11204,
  [11206] = 11206,
  [11207] = 11207,
  [11208] = 11204,
  [11209] = 11209,
  [11210] = 11210,
  [11211] = 11204,
  [11212] = 11212,
  [11213] = 11210,
  [11214] = 11214,
  [11215] = 11209,
  [11216] = 11210,
  [11217] = 5304,
  [11218] = 11218,
  [11219] = 11219,
  [11220] = 11220,
  [11221] = 11214,
  [11222] = 11209,
  [11223] = 11214,
  [11224] = 11209,
  [11225] = 11210,
  [11226] = 11226,
  [11227] = 11214,
  [11228] = 11209,
  [11229] = 11204,
  [11230] = 11214,
  [11231] = 5307,
  [11232] = 11232,
  [11233] = 11219,
  [11234] = 11234,
  [11235] = 11226,
  [11236] = 11210,
  [11237] = 11237,
  [11238] = 11238,
  [11239] = 5308,
  [11240] = 5302,
  [11241] = 11204,
  [11242] = 11242,
  [11243] = 11204,
  [11244] = 11219,
  [11245] = 11219,
  [11246] = 11219,
  [11247] = 11210,
  [11248] = 11219,
  [11249] = 11210,
  [11250] = 11250,
  [11251] = 11226,
  [11252] = 11252,
  [11253] = 11204,
  [11254] = 11226,
  [11255] = 11226,
  [11256] = 11226,
  [11257] = 11226,
  [11258] = 11210,
  [11259] = 11219,
  [11260] = 11226,
  [11261] = 11226,
  [11262] = 11226,
  [11263] = 11263,
  [11264] = 11264,
  [11265] = 11265,
  [11266] = 11266,
  [11267] = 11267,
  [11268] = 11268,
  [11269] = 11264,
  [11270] = 11270,
  [11271] = 6621,
  [11272] = 11272,
  [11273] = 11273,
  [11274] = 5366,
  [11275] = 11275,
  [11276] = 11276,
  [11277] = 11277,
  [11278] = 5365,
  [11279] = 11279,
  [11280] = 11264,
  [11281] = 11281,
  [11282] = 11264,
  [11283] = 11275,
  [11284] = 11264,
  [11285] = 11275,
  [11286] = 11268,
  [11287] = 11275,
  [11288] = 11275,
  [11289] = 11268,
  [11290] = 11290,
  [11291] = 11268,
  [11292] = 11268,
  [11293] = 11268,
  [11294] = 11268,
  [11295] = 11270,
  [11296] = 11296,
  [11297] = 11297,
  [11298] = 11298,
  [11299] = 11299,
  [11300] = 11300,
  [11301] = 11301,
  [11302] = 11301,
  [11303] = 10797,
  [11304] = 11304,
  [11305] = 10808,
  [11306] = 11306,
  [11307] = 11306,
  [11308] = 11308,
  [11309] = 10809,
  [11310] = 11310,
  [11311] = 11311,
  [11312] = 11301,
  [11313] = 10812,
  [11314] = 10791,
  [11315] = 10801,
  [11316] = 11316,
  [11317] = 11317,
  [11318] = 11306,
  [11319] = 11306,
  [11320] = 11320,
  [11321] = 5391,
  [11322] = 11322,
  [11323] = 11323,
  [11324] = 11324,
  [11325] = 11325,
  [11326] = 11326,
  [11327] = 11327,
  [11328] = 11328,
  [11329] = 11329,
  [11330] = 11330,
  [11331] = 10799,
  [11332] = 11332,
  [11333] = 11333,
  [11334] = 11334,
  [11335] = 11335,
  [11336] = 10789,
  [11337] = 11333,
  [11338] = 11338,
  [11339] = 11320,
  [11340] = 11304,
  [11341] = 11304,
  [11342] = 11342,
  [11343] = 11306,
  [11344] = 11304,
  [11345] = 11345,
  [11346] = 11301,
  [11347] = 11306,
  [11348] = 11348,
  [11349] = 11349,
  [11350] = 11306,
  [11351] = 11301,
  [11352] = 11352,
  [11353] = 11301,
  [11354] = 10816,
  [11355] = 11301,
  [11356] = 11356,
  [11357] = 10811,
  [11358] = 11358,
  [11359] = 10802,
  [11360] = 11306,
  [11361] = 11361,
  [11362] = 10806,
  [11363] = 11363,
  [11364] = 11364,
  [11365] = 11365,
  [11366] = 11366,
  [11367] = 11367,
  [11368] = 11304,
  [11369] = 11301,
  [11370] = 11370,
  [11371] = 11371,
  [11372] = 5404,
  [11373] = 11373,
  [11374] = 11374,
  [11375] = 11375,
  [11376] = 11376,
  [11377] = 11377,
  [11378] = 11378,
  [11379] = 11379,
  [11380] = 11380,
  [11381] = 11373,
  [11382] = 11382,
  [11383] = 11374,
  [11384] = 10811,
  [11385] = 11385,
  [11386] = 10789,
  [11387] = 11387,
  [11388] = 11388,
  [11389] = 10797,
  [11390] = 11379,
  [11391] = 11391,
  [11392] = 11392,
  [11393] = 11393,
  [11394] = 5396,
  [11395] = 11395,
  [11396] = 11396,
  [11397] = 11393,
  [11398] = 11379,
  [11399] = 11380,
  [11400] = 5398,
  [11401] = 11393,
  [11402] = 11402,
  [11403] = 11403,
  [11404] = 11380,
  [11405] = 11380,
  [11406] = 11379,
  [11407] = 11407,
  [11408] = 10806,
  [11409] = 10816,
  [11410] = 11380,
  [11411] = 11375,
  [11412] = 11382,
  [11413] = 11413,
  [11414] = 11382,
  [11415] = 11415,
  [11416] = 11375,
  [11417] = 11417,
  [11418] = 11388,
  [11419] = 10809,
  [11420] = 11420,
  [11421] = 11375,
  [11422] = 10812,
  [11423] = 11388,
  [11424] = 11424,
  [11425] = 11425,
  [11426] = 11426,
  [11427] = 11380,
  [11428] = 11371,
  [11429] = 11382,
  [11430] = 11430,
  [11431] = 11379,
  [11432] = 11327,
  [11433] = 10808,
  [11434] = 11320,
  [11435] = 11373,
  [11436] = 11436,
  [11437] = 11396,
  [11438] = 11373,
  [11439] = 11374,
  [11440] = 11374,
  [11441] = 11349,
  [11442] = 10801,
  [11443] = 11443,
  [11444] = 11207,
  [11445] = 11393,
  [11446] = 11382,
  [11447] = 11393,
  [11448] = 11388,
  [11449] = 11330,
  [11450] = 11450,
  [11451] = 11451,
  [11452] = 11452,
  [11453] = 11453,
  [11454] = 11396,
  [11455] = 11455,
  [11456] = 11393,
  [11457] = 11327,
  [11458] = 11328,
  [11459] = 11329,
  [11460] = 11330,
  [11461] = 11334,
  [11462] = 11462,
  [11463] = 11335,
  [11464] = 11371,
  [11465] = 11335,
  [11466] = 5414,
  [11467] = 11334,
  [11468] = 11388,
  [11469] = 11349,
  [11470] = 11462,
  [11471] = 11471,
  [11472] = 11320,
  [11473] = 11473,
  [11474] = 11474,
  [11475] = 11475,
  [11476] = 11375,
  [11477] = 11374,
  [11478] = 11478,
  [11479] = 11379,
  [11480] = 11328,
  [11481] = 11481,
  [11482] = 11388,
  [11483] = 11483,
  [11484] = 11329,
  [11485] = 11373,
  [11486] = 11382,
  [11487] = 11487,
  [11488] = 11488,
  [11489] = 11234,
  [11490] = 10802,
  [11491] = 11491,
  [11492] = 11492,
  [11493] = 11491,
  [11494] = 11494,
  [11495] = 11495,
  [11496] = 11496,
  [11497] = 11497,
  [11498] = 11492,
  [11499] = 11499,
  [11500] = 11500,
  [11501] = 11501,
  [11502] = 11502,
  [11503] = 11503,
  [11504] = 11504,
  [11505] = 11505,
  [11506] = 11506,
  [11507] = 11507,
  [11508] = 11508,
  [11509] = 11509,
  [11510] = 11491,
  [11511] = 11492,
  [11512] = 11501,
  [11513] = 11502,
  [11514] = 11503,
  [11515] = 11515,
  [11516] = 11516,
  [11517] = 11517,
  [11518] = 11365,
  [11519] = 11519,
  [11520] = 11520,
  [11521] = 11521,
  [11522] = 11522,
  [11523] = 11523,
  [11524] = 11524,
  [11525] = 11500,
  [11526] = 11526,
  [11527] = 11527,
  [11528] = 11528,
  [11529] = 11529,
  [11530] = 11311,
  [11531] = 11500,
  [11532] = 11501,
  [11533] = 11500,
  [11534] = 11502,
  [11535] = 11503,
  [11536] = 11536,
  [11537] = 11537,
  [11538] = 11538,
  [11539] = 11539,
  [11540] = 11540,
  [11541] = 11491,
  [11542] = 11542,
  [11543] = 11492,
  [11544] = 11352,
  [11545] = 11545,
  [11546] = 11546,
  [11547] = 11515,
  [11548] = 11548,
  [11549] = 11549,
  [11550] = 11550,
  [11551] = 11551,
  [11552] = 11552,
  [11553] = 11553,
  [11554] = 11554,
  [11555] = 11555,
  [11556] = 11556,
  [11557] = 11557,
  [11558] = 11558,
  [11559] = 11349,
  [11560] = 11500,
  [11561] = 11327,
  [11562] = 692,
  [11563] = 11328,
  [11564] = 11329,
  [11565] = 11330,
  [11566] = 11491,
  [11567] = 11567,
  [11568] = 11568,
  [11569] = 11569,
  [11570] = 11570,
  [11571] = 11571,
  [11572] = 11501,
  [11573] = 11502,
  [11574] = 11503,
  [11575] = 11334,
  [11576] = 11500,
  [11577] = 11577,
  [11578] = 11491,
  [11579] = 11436,
  [11580] = 11580,
  [11581] = 11491,
  [11582] = 11492,
  [11583] = 11583,
  [11584] = 11492,
  [11585] = 11500,
  [11586] = 11491,
  [11587] = 11492,
  [11588] = 11500,
  [11589] = 11491,
  [11590] = 11492,
  [11591] = 11500,
  [11592] = 751,
  [11593] = 11491,
  [11594] = 11492,
  [11595] = 11500,
  [11596] = 11500,
  [11597] = 11491,
  [11598] = 11492,
  [11599] = 11500,
  [11600] = 11600,
  [11601] = 11491,
  [11602] = 11492,
  [11603] = 11500,
  [11604] = 11604,
  [11605] = 11492,
  [11606] = 11491,
  [11607] = 11492,
  [11608] = 720,
  [11609] = 11609,
  [11610] = 11515,
  [11611] = 11611,
  [11612] = 672,
  [11613] = 717,
  [11614] = 11614,
  [11615] = 10799,
  [11616] = 11491,
  [11617] = 11617,
  [11618] = 11618,
  [11619] = 11492,
  [11620] = 11620,
  [11621] = 11621,
  [11622] = 11622,
  [11623] = 11623,
  [11624] = 11624,
  [11625] = 11625,
  [11626] = 11626,
  [11627] = 11335,
  [11628] = 11628,
  [11629] = 11629,
  [11630] = 11515,
  [11631] = 11515,
  [11632] = 11632,
  [11633] = 11515,
  [11634] = 11500,
  [11635] = 11635,
  [11636] = 11636,
  [11637] = 11500,
  [11638] = 11491,
  [11639] = 11492,
  [11640] = 11640,
  [11641] = 11641,
  [11642] = 11515,
  [11643] = 11643,
  [11644] = 11644,
  [11645] = 11645,
  [11646] = 11646,
  [11647] = 11647,
  [11648] = 11648,
  [11649] = 11371,
  [11650] = 11491,
  [11651] = 11651,
  [11652] = 11652,
  [11653] = 11492,
  [11654] = 11654,
  [11655] = 11501,
  [11656] = 11500,
  [11657] = 11657,
  [11658] = 11658,
  [11659] = 11502,
  [11660] = 11503,
  [11661] = 693,
  [11662] = 11662,
  [11663] = 11663,
  [11664] = 11664,
  [11665] = 11665,
  [11666] = 11666,
  [11667] = 11667,
  [11668] = 11662,
  [11669] = 11669,
  [11670] = 11670,
  [11671] = 11671,
  [11672] = 11672,
  [11673] = 11673,
  [11674] = 11665,
  [11675] = 11675,
  [11676] = 11676,
  [11677] = 11677,
  [11678] = 11666,
  [11679] = 11667,
  [11680] = 11680,
  [11681] = 11681,
  [11682] = 11682,
  [11683] = 11683,
  [11684] = 11684,
  [11685] = 11685,
  [11686] = 11670,
  [11687] = 11687,
  [11688] = 11688,
  [11689] = 11689,
  [11690] = 11675,
  [11691] = 11691,
  [11692] = 11567,
  [11693] = 11688,
  [11694] = 11694,
  [11695] = 11684,
  [11696] = 11662,
  [11697] = 11688,
  [11698] = 11680,
  [11699] = 11687,
  [11700] = 11688,
  [11701] = 11684,
  [11702] = 11662,
  [11703] = 11675,
  [11704] = 11680,
  [11705] = 11687,
  [11706] = 11706,
  [11707] = 11707,
  [11708] = 11680,
  [11709] = 11709,
  [11710] = 11710,
  [11711] = 11711,
  [11712] = 11712,
  [11713] = 11713,
  [11714] = 11665,
  [11715] = 11666,
  [11716] = 11716,
  [11717] = 11717,
  [11718] = 11667,
  [11719] = 11670,
  [11720] = 11720,
  [11721] = 11721,
  [11722] = 11688,
  [11723] = 11723,
  [11724] = 11724,
  [11725] = 11725,
  [11726] = 11726,
  [11727] = 11665,
  [11728] = 11666,
  [11729] = 11729,
  [11730] = 11730,
  [11731] = 11667,
  [11732] = 11670,
  [11733] = 11733,
  [11734] = 11734,
  [11735] = 11675,
  [11736] = 11736,
  [11737] = 11737,
  [11738] = 11738,
  [11739] = 11687,
  [11740] = 11684,
  [11741] = 11662,
  [11742] = 11742,
  [11743] = 11680,
  [11744] = 11687,
  [11745] = 11745,
  [11746] = 11746,
  [11747] = 11747,
  [11748] = 11748,
  [11749] = 11749,
  [11750] = 11750,
  [11751] = 11751,
  [11752] = 11752,
  [11753] = 11753,
  [11754] = 11754,
  [11755] = 11755,
  [11756] = 11756,
  [11757] = 11757,
  [11758] = 11688,
  [11759] = 11759,
  [11760] = 11760,
  [11761] = 11761,
  [11762] = 11688,
  [11763] = 11763,
  [11764] = 11764,
  [11765] = 11765,
  [11766] = 5391,
  [11767] = 11767,
  [11768] = 11768,
  [11769] = 11769,
  [11770] = 11770,
  [11771] = 11665,
  [11772] = 11666,
  [11773] = 11667,
  [11774] = 11774,
  [11775] = 11684,
  [11776] = 11776,
  [11777] = 11670,
  [11778] = 11778,
  [11779] = 11675,
  [11780] = 11780,
  [11781] = 11781,
  [11782] = 11782,
  [11783] = 11783,
  [11784] = 11784,
  [11785] = 704,
  [11786] = 11786,
  [11787] = 11787,
  [11788] = 11786,
  [11789] = 11789,
  [11790] = 11790,
  [11791] = 11791,
  [11792] = 11792,
  [11793] = 661,
  [11794] = 694,
  [11795] = 733,
  [11796] = 11796,
  [11797] = 743,
  [11798] = 11798,
  [11799] = 11799,
  [11800] = 11800,
  [11801] = 11801,
  [11802] = 11802,
  [11803] = 11803,
  [11804] = 11804,
  [11805] = 11782,
  [11806] = 11806,
  [11807] = 11792,
  [11808] = 11808,
  [11809] = 11809,
  [11810] = 11784,
  [11811] = 11798,
  [11812] = 655,
  [11813] = 11806,
  [11814] = 671,
  [11815] = 695,
  [11816] = 11800,
  [11817] = 705,
  [11818] = 11818,
  [11819] = 11786,
  [11820] = 742,
  [11821] = 11821,
  [11822] = 11822,
  [11823] = 11808,
  [11824] = 11792,
  [11825] = 11791,
  [11826] = 11808,
  [11827] = 11800,
  [11828] = 11828,
  [11829] = 11781,
  [11830] = 11792,
  [11831] = 11781,
  [11832] = 11832,
  [11833] = 11791,
  [11834] = 11789,
  [11835] = 11835,
  [11836] = 11835,
  [11837] = 11806,
  [11838] = 11800,
  [11839] = 11835,
  [11840] = 11800,
  [11841] = 663,
  [11842] = 744,
  [11843] = 11809,
  [11844] = 11844,
  [11845] = 747,
  [11846] = 11792,
  [11847] = 11847,
  [11848] = 679,
  [11849] = 686,
  [11850] = 11808,
  [11851] = 11804,
  [11852] = 11852,
  [11853] = 11853,
  [11854] = 11854,
  [11855] = 708,
  [11856] = 740,
  [11857] = 11782,
  [11858] = 657,
  [11859] = 660,
  [11860] = 662,
  [11861] = 11861,
  [11862] = 11862,
  [11863] = 732,
  [11864] = 11789,
  [11865] = 736,
  [11866] = 745,
  [11867] = 11867,
  [11868] = 712,
  [11869] = 713,
  [11870] = 11809,
  [11871] = 726,
  [11872] = 727,
  [11873] = 729,
  [11874] = 11804,
  [11875] = 731,
  [11876] = 759,
  [11877] = 11877,
  [11878] = 11809,
  [11879] = 11879,
  [11880] = 11806,
  [11881] = 11789,
  [11882] = 11789,
  [11883] = 11784,
  [11884] = 11884,
  [11885] = 11885,
  [11886] = 11784,
  [11887] = 11887,
  [11888] = 11804,
  [11889] = 11854,
  [11890] = 11481,
  [11891] = 11782,
  [11892] = 11789,
  [11893] = 11893,
  [11894] = 11801,
  [11895] = 11895,
  [11896] = 11896,
  [11897] = 11781,
  [11898] = 11835,
  [11899] = 11786,
  [11900] = 11780,
  [11901] = 11901,
  [11902] = 11902,
  [11903] = 11903,
  [11904] = 11791,
  [11905] = 697,
  [11906] = 11862,
  [11907] = 5383,
  [11908] = 11809,
  [11909] = 11909,
  [11910] = 11910,
  [11911] = 11911,
  [11912] = 754,
  [11913] = 5376,
  [11914] = 748,
  [11915] = 11804,
  [11916] = 11781,
  [11917] = 11798,
  [11918] = 11791,
  [11919] = 11835,
  [11920] = 11798,
  [11921] = 11801,
  [11922] = 11809,
  [11923] = 11796,
  [11924] = 11786,
  [11925] = 11925,
  [11926] = 11854,
  [11927] = 11789,
  [11928] = 11928,
  [11929] = 11809,
  [11930] = 11930,
  [11931] = 11931,
  [11932] = 11808,
  [11933] = 11808,
  [11934] = 11808,
  [11935] = 5393,
  [11936] = 11801,
  [11937] = 11784,
  [11938] = 11781,
  [11939] = 11809,
  [11940] = 11940,
  [11941] = 11804,
  [11942] = 8826,
  [11943] = 11808,
  [11944] = 11944,
  [11945] = 11854,
  [11946] = 11789,
  [11947] = 11947,
  [11948] = 11798,
  [11949] = 11801,
  [11950] = 11781,
  [11951] = 11951,
  [11952] = 11806,
  [11953] = 11953,
  [11954] = 11782,
  [11955] = 5392,
  [11956] = 11808,
  [11957] = 11957,
  [11958] = 11808,
  [11959] = 11959,
  [11960] = 11804,
  [11961] = 11961,
  [11962] = 11804,
  [11963] = 11854,
  [11964] = 11781,
  [11965] = 11965,
  [11966] = 11966,
  [11967] = 11967,
  [11968] = 11968,
  [11969] = 11969,
  [11970] = 11970,
  [11971] = 11971,
  [11972] = 11972,
  [11973] = 11973,
  [11974] = 11974,
  [11975] = 11975,
  [11976] = 11976,
  [11977] = 11966,
  [11978] = 11978,
  [11979] = 11971,
  [11980] = 11980,
  [11981] = 11981,
  [11982] = 11982,
  [11983] = 11983,
  [11984] = 11984,
  [11985] = 11985,
  [11986] = 11986,
  [11987] = 11970,
  [11988] = 11973,
  [11989] = 11989,
  [11990] = 11975,
  [11991] = 11991,
  [11992] = 11992,
  [11993] = 11993,
  [11994] = 11994,
  [11995] = 11995,
  [11996] = 11996,
  [11997] = 11997,
  [11998] = 11998,
  [11999] = 11982,
  [12000] = 12000,
  [12001] = 12001,
  [12002] = 12002,
  [12003] = 12003,
  [12004] = 11965,
  [12005] = 12005,
  [12006] = 12006,
  [12007] = 12007,
  [12008] = 12008,
  [12009] = 12009,
  [12010] = 10688,
  [12011] = 11998,
  [12012] = 12012,
  [12013] = 12013,
  [12014] = 12014,
  [12015] = 12015,
  [12016] = 12016,
  [12017] = 12012,
  [12018] = 12018,
  [12019] = 12019,
  [12020] = 12020,
  [12021] = 12021,
  [12022] = 11967,
  [12023] = 11978,
  [12024] = 12013,
  [12025] = 11991,
  [12026] = 12026,
  [12027] = 11982,
  [12028] = 11968,
  [12029] = 12029,
  [12030] = 12019,
  [12031] = 11986,
  [12032] = 11970,
  [12033] = 11973,
  [12034] = 12034,
  [12035] = 12035,
  [12036] = 12036,
  [12037] = 12037,
  [12038] = 11992,
  [12039] = 11993,
  [12040] = 11994,
  [12041] = 11995,
  [12042] = 11996,
  [12043] = 11976,
  [12044] = 12044,
  [12045] = 11974,
  [12046] = 12019,
  [12047] = 12047,
  [12048] = 12000,
  [12049] = 12001,
  [12050] = 12002,
  [12051] = 12003,
  [12052] = 12052,
  [12053] = 12020,
  [12054] = 12054,
  [12055] = 12055,
  [12056] = 12006,
  [12057] = 12007,
  [12058] = 12008,
  [12059] = 12009,
  [12060] = 12060,
  [12061] = 11991,
  [12062] = 11998,
  [12063] = 12012,
  [12064] = 12013,
  [12065] = 12005,
  [12066] = 12066,
  [12067] = 11976,
  [12068] = 12015,
  [12069] = 12016,
  [12070] = 12026,
  [12071] = 12018,
  [12072] = 11978,
  [12073] = 11966,
  [12074] = 12020,
  [12075] = 11966,
  [12076] = 11982,
  [12077] = 12066,
  [12078] = 11966,
  [12079] = 12029,
  [12080] = 11986,
  [12081] = 12019,
  [12082] = 11970,
  [12083] = 11973,
  [12084] = 11974,
  [12085] = 11991,
  [12086] = 12034,
  [12087] = 11992,
  [12088] = 11993,
  [12089] = 11994,
  [12090] = 11995,
  [12091] = 11996,
  [12092] = 12092,
  [12093] = 11966,
  [12094] = 12094,
  [12095] = 11975,
  [12096] = 11976,
  [12097] = 12000,
  [12098] = 12001,
  [12099] = 12002,
  [12100] = 12003,
  [12101] = 11965,
  [12102] = 12037,
  [12103] = 12006,
  [12104] = 12007,
  [12105] = 12008,
  [12106] = 12009,
  [12107] = 11998,
  [12108] = 12012,
  [12109] = 12013,
  [12110] = 12015,
  [12111] = 12016,
  [12112] = 12112,
  [12113] = 12044,
  [12114] = 12018,
  [12115] = 11971,
  [12116] = 11978,
  [12117] = 11983,
  [12118] = 11982,
  [12119] = 11984,
  [12120] = 11970,
  [12121] = 11973,
  [12122] = 11983,
  [12123] = 11972,
  [12124] = 12000,
  [12125] = 12001,
  [12126] = 11993,
  [12127] = 11994,
  [12128] = 11995,
  [12129] = 11996,
  [12130] = 12130,
  [12131] = 12131,
  [12132] = 12014,
  [12133] = 11974,
  [12134] = 12000,
  [12135] = 12001,
  [12136] = 12002,
  [12137] = 12003,
  [12138] = 11965,
  [12139] = 12139,
  [12140] = 11976,
  [12141] = 12026,
  [12142] = 12006,
  [12143] = 12007,
  [12144] = 12008,
  [12145] = 12009,
  [12146] = 12146,
  [12147] = 11998,
  [12148] = 12012,
  [12149] = 12013,
  [12150] = 12015,
  [12151] = 12016,
  [12152] = 12054,
  [12153] = 12018,
  [12154] = 12154,
  [12155] = 12002,
  [12156] = 12003,
  [12157] = 12157,
  [12158] = 12158,
  [12159] = 12009,
  [12160] = 12015,
  [12161] = 11975,
  [12162] = 12014,
  [12163] = 11966,
  [12164] = 12066,
  [12165] = 12029,
  [12166] = 12166,
  [12167] = 12026,
  [12168] = 12168,
  [12169] = 11975,
  [12170] = 12170,
  [12171] = 12130,
  [12172] = 12016,
  [12173] = 12173,
  [12174] = 12092,
  [12175] = 12019,
  [12176] = 12146,
  [12177] = 11967,
  [12178] = 11968,
  [12179] = 11966,
  [12180] = 12130,
  [12181] = 12020,
  [12182] = 11965,
  [12183] = 12183,
  [12184] = 12034,
  [12185] = 12185,
  [12186] = 12186,
  [12187] = 12029,
  [12188] = 12188,
  [12189] = 12189,
  [12190] = 12190,
  [12191] = 12191,
  [12192] = 11972,
  [12193] = 11974,
  [12194] = 12112,
  [12195] = 11971,
  [12196] = 11983,
  [12197] = 11984,
  [12198] = 12014,
  [12199] = 11991,
  [12200] = 11974,
  [12201] = 11975,
  [12202] = 12066,
  [12203] = 12037,
  [12204] = 11976,
  [12205] = 11976,
  [12206] = 11966,
  [12207] = 11975,
  [12208] = 11972,
  [12209] = 11972,
  [12210] = 12210,
  [12211] = 11967,
  [12212] = 12130,
  [12213] = 12213,
  [12214] = 12214,
  [12215] = 11986,
  [12216] = 12216,
  [12217] = 12026,
  [12218] = 12170,
  [12219] = 12146,
  [12220] = 11966,
  [12221] = 12221,
  [12222] = 12222,
  [12223] = 12092,
  [12224] = 11972,
  [12225] = 12014,
  [12226] = 12018,
  [12227] = 12227,
  [12228] = 12029,
  [12229] = 11968,
  [12230] = 12034,
  [12231] = 11974,
  [12232] = 11989,
  [12233] = 12170,
  [12234] = 11976,
  [12235] = 12235,
  [12236] = 12037,
  [12237] = 11966,
  [12238] = 12092,
  [12239] = 12239,
  [12240] = 11967,
  [12241] = 11968,
  [12242] = 11975,
  [12243] = 12044,
  [12244] = 11966,
  [12245] = 11966,
  [12246] = 12246,
  [12247] = 11975,
  [12248] = 12014,
  [12249] = 12130,
  [12250] = 12034,
  [12251] = 12014,
  [12252] = 12066,
  [12253] = 12014,
  [12254] = 11975,
  [12255] = 12255,
  [12256] = 12130,
  [12257] = 12257,
  [12258] = 12054,
  [12259] = 12037,
  [12260] = 11966,
  [12261] = 11989,
  [12262] = 12262,
  [12263] = 12263,
  [12264] = 11975,
  [12265] = 11972,
  [12266] = 12263,
  [12267] = 12267,
  [12268] = 12066,
  [12269] = 12269,
  [12270] = 12170,
  [12271] = 11966,
  [12272] = 11975,
  [12273] = 11974,
  [12274] = 11966,
  [12275] = 11967,
  [12276] = 11974,
  [12277] = 11974,
  [12278] = 12278,
  [12279] = 11968,
  [12280] = 11975,
  [12281] = 12281,
  [12282] = 12282,
  [12283] = 11967,
  [12284] = 12284,
  [12285] = 12014,
  [12286] = 11992,
  [12287] = 12044,
  [12288] = 12014,
  [12289] = 12289,
  [12290] = 12044,
  [12291] = 11966,
  [12292] = 12066,
  [12293] = 11974,
  [12294] = 12130,
  [12295] = 11975,
  [12296] = 12296,
  [12297] = 11966,
  [12298] = 11966,
  [12299] = 12112,
  [12300] = 11971,
  [12301] = 12267,
  [12302] = 12130,
  [12303] = 11983,
  [12304] = 11972,
  [12305] = 12006,
  [12306] = 12130,
  [12307] = 11966,
  [12308] = 11976,
  [12309] = 11976,
  [12310] = 11997,
  [12311] = 12130,
  [12312] = 11984,
  [12313] = 11966,
  [12314] = 12314,
  [12315] = 12130,
  [12316] = 11966,
  [12317] = 11966,
  [12318] = 11976,
  [12319] = 12319,
  [12320] = 12130,
  [12321] = 11976,
  [12322] = 12322,
  [12323] = 12007,
  [12324] = 11976,
  [12325] = 12325,
  [12326] = 11975,
  [12327] = 12130,
  [12328] = 12146,
  [12329] = 12005,
  [12330] = 12130,
  [12331] = 12331,
  [12332] = 12130,
  [12333] = 12333,
  [12334] = 12334,
  [12335] = 11975,
  [12336] = 11966,
  [12337] = 12166,
  [12338] = 12168,
  [12339] = 11975,
  [12340] = 12170,
  [12341] = 12341,
  [12342] = 12173,
  [12343] = 11972,
  [12344] = 11984,
  [12345] = 12170,
  [12346] = 12166,
  [12347] = 12168,
  [12348] = 12348,
  [12349] = 11974,
  [12350] = 12350,
  [12351] = 11978,
  [12352] = 12352,
  [12353] = 11968,
  [12354] = 12354,
  [12355] = 12355,
  [12356] = 12112,
  [12357] = 12168,
  [12358] = 12358,
  [12359] = 12166,
  [12360] = 12168,
  [12361] = 11966,
  [12362] = 12362,
  [12363] = 11982,
  [12364] = 12364,
  [12365] = 12365,
  [12366] = 12366,
  [12367] = 12367,
  [12368] = 12166,
  [12369] = 12168,
  [12370] = 11986,
  [12371] = 11970,
  [12372] = 11973,
  [12373] = 12173,
  [12374] = 12014,
  [12375] = 11972,
  [12376] = 11966,
  [12377] = 11974,
  [12378] = 11975,
  [12379] = 12379,
  [12380] = 12380,
  [12381] = 11976,
  [12382] = 11996,
  [12383] = 12054,
  [12384] = 12384,
  [12385] = 12221,
  [12386] = 12014,
  [12387] = 12387,
  [12388] = 12005,
  [12389] = 11992,
  [12390] = 12390,
  [12391] = 11993,
  [12392] = 11994,
  [12393] = 11995,
  [12394] = 11996,
  [12395] = 12092,
  [12396] = 11966,
  [12397] = 12397,
  [12398] = 12263,
  [12399] = 11975,
  [12400] = 11995,
  [12401] = 12401,
  [12402] = 11976,
  [12403] = 12014,
  [12404] = 11972,
  [12405] = 12170,
  [12406] = 12406,
  [12407] = 12173,
  [12408] = 11966,
  [12409] = 12092,
  [12410] = 12410,
  [12411] = 12000,
  [12412] = 12001,
  [12413] = 12092,
  [12414] = 12414,
  [12415] = 11966,
  [12416] = 12002,
  [12417] = 12003,
  [12418] = 11975,
  [12419] = 11965,
  [12420] = 12146,
  [12421] = 12421,
  [12422] = 12422,
  [12423] = 11974,
  [12424] = 12424,
  [12425] = 12014,
  [12426] = 11966,
  [12427] = 11972,
  [12428] = 11993,
  [12429] = 11972,
  [12430] = 12170,
  [12431] = 12431,
  [12432] = 11994,
  [12433] = 12173,
  [12434] = 12066,
  [12435] = 12435,
  [12436] = 12006,
  [12437] = 12007,
  [12438] = 12008,
  [12439] = 12009,
  [12440] = 12166,
  [12441] = 12441,
  [12442] = 11989,
  [12443] = 11975,
  [12444] = 11972,
  [12445] = 12014,
  [12446] = 11997,
  [12447] = 12447,
  [12448] = 11972,
  [12449] = 12166,
  [12450] = 12168,
  [12451] = 11974,
  [12452] = 12452,
  [12453] = 11998,
  [12454] = 12012,
  [12455] = 12455,
  [12456] = 12173,
  [12457] = 12146,
  [12458] = 12013,
  [12459] = 12130,
  [12460] = 11974,
  [12461] = 12461,
  [12462] = 12462,
  [12463] = 12054,
  [12464] = 12384,
  [12465] = 11967,
  [12466] = 11968,
  [12467] = 12008,
  [12468] = 11978,
  [12469] = 12005,
  [12470] = 12020,
  [12471] = 11997,
  [12472] = 12263,
  [12473] = 12015,
  [12474] = 12016,
  [12475] = 11972,
  [12476] = 12278,
  [12477] = 12112,
  [12478] = 12478,
  [12479] = 11989,
  [12480] = 12480,
  [12481] = 12481,
  [12482] = 11976,
  [12483] = 11997,
  [12484] = 12484,
  [12485] = 12018,
  [12486] = 12486,
  [12487] = 12146,
  [12488] = 12014,
  [12489] = 11975,
  [12490] = 12490,
  [12491] = 12491,
  [12492] = 12492,
  [12493] = 12493,
  [12494] = 12494,
  [12495] = 12495,
  [12496] = 12496,
  [12497] = 12497,
  [12498] = 12498,
  [12499] = 12498,
  [12500] = 12500,
  [12501] = 12501,
  [12502] = 12502,
  [12503] = 12503,
  [12504] = 12502,
  [12505] = 12505,
  [12506] = 12506,
  [12507] = 12507,
  [12508] = 12508,
  [12509] = 12495,
  [12510] = 12510,
  [12511] = 12511,
  [12512] = 12512,
  [12513] = 12513,
  [12514] = 12514,
  [12515] = 12515,
  [12516] = 12516,
  [12517] = 12517,
  [12518] = 12518,
  [12519] = 12515,
  [12520] = 12520,
  [12521] = 12521,
  [12522] = 12522,
  [12523] = 12502,
  [12524] = 12505,
  [12525] = 12525,
  [12526] = 12505,
  [12527] = 12507,
  [12528] = 12495,
  [12529] = 12529,
  [12530] = 12512,
  [12531] = 12531,
  [12532] = 12532,
  [12533] = 12533,
  [12534] = 12534,
  [12535] = 12505,
  [12536] = 12188,
  [12537] = 12537,
  [12538] = 12538,
  [12539] = 12539,
  [12540] = 12540,
  [12541] = 12541,
  [12542] = 12542,
  [12543] = 12543,
  [12544] = 12544,
  [12545] = 12513,
  [12546] = 12546,
  [12547] = 12547,
  [12548] = 12548,
  [12549] = 12492,
  [12550] = 12550,
  [12551] = 12539,
  [12552] = 12548,
  [12553] = 12495,
  [12554] = 12537,
  [12555] = 12498,
  [12556] = 12556,
  [12557] = 11689,
  [12558] = 12558,
  [12559] = 12559,
  [12560] = 12560,
  [12561] = 12543,
  [12562] = 12562,
  [12563] = 12512,
  [12564] = 12564,
  [12565] = 12565,
  [12566] = 12496,
  [12567] = 12503,
  [12568] = 12505,
  [12569] = 12507,
  [12570] = 12570,
  [12571] = 12571,
  [12572] = 12572,
  [12573] = 12507,
  [12574] = 12495,
  [12575] = 12498,
  [12576] = 12505,
  [12577] = 12577,
  [12578] = 12578,
  [12579] = 12579,
  [12580] = 12580,
  [12581] = 12581,
  [12582] = 12582,
  [12583] = 12570,
  [12584] = 12584,
  [12585] = 12585,
  [12586] = 12586,
  [12587] = 11844,
  [12588] = 12588,
  [12589] = 12511,
  [12590] = 12497,
  [12591] = 12591,
  [12592] = 12592,
  [12593] = 12511,
  [12594] = 12495,
  [12595] = 12498,
  [12596] = 12512,
  [12597] = 12592,
  [12598] = 12581,
  [12599] = 12582,
  [12600] = 12600,
  [12601] = 12601,
  [12602] = 12602,
  [12603] = 12546,
  [12604] = 12558,
  [12605] = 12605,
  [12606] = 12512,
  [12607] = 12505,
  [12608] = 12608,
  [12609] = 12609,
  [12610] = 12610,
  [12611] = 12611,
  [12612] = 12612,
  [12613] = 12562,
  [12614] = 12614,
  [12615] = 12615,
  [12616] = 12511,
  [12617] = 12546,
  [12618] = 12547,
  [12619] = 12548,
  [12620] = 12550,
  [12621] = 12588,
  [12622] = 12539,
  [12623] = 12495,
  [12624] = 12537,
  [12625] = 12625,
  [12626] = 12512,
  [12627] = 12558,
  [12628] = 12571,
  [12629] = 12585,
  [12630] = 12490,
  [12631] = 12512,
  [12632] = 12564,
  [12633] = 12565,
  [12634] = 12503,
  [12635] = 12635,
  [12636] = 12572,
  [12637] = 12511,
  [12638] = 12577,
  [12639] = 12579,
  [12640] = 12584,
  [12641] = 12588,
  [12642] = 12497,
  [12643] = 12512,
  [12644] = 12591,
  [12645] = 12645,
  [12646] = 12592,
  [12647] = 12602,
  [12648] = 12505,
  [12649] = 12546,
  [12650] = 12547,
  [12651] = 12548,
  [12652] = 12550,
  [12653] = 12492,
  [12654] = 12539,
  [12655] = 12498,
  [12656] = 12537,
  [12657] = 12558,
  [12658] = 12600,
  [12659] = 12601,
  [12660] = 12490,
  [12661] = 12564,
  [12662] = 12565,
  [12663] = 12503,
  [12664] = 12572,
  [12665] = 12577,
  [12666] = 12579,
  [12667] = 12584,
  [12668] = 12588,
  [12669] = 12497,
  [12670] = 12591,
  [12671] = 12511,
  [12672] = 12592,
  [12673] = 12673,
  [12674] = 12602,
  [12675] = 12546,
  [12676] = 12547,
  [12677] = 12548,
  [12678] = 12550,
  [12679] = 12539,
  [12680] = 12537,
  [12681] = 12547,
  [12682] = 12490,
  [12683] = 12683,
  [12684] = 12564,
  [12685] = 12572,
  [12686] = 12565,
  [12687] = 12503,
  [12688] = 12688,
  [12689] = 12502,
  [12690] = 12505,
  [12691] = 12572,
  [12692] = 12577,
  [12693] = 12579,
  [12694] = 12584,
  [12695] = 12695,
  [12696] = 12588,
  [12697] = 12497,
  [12698] = 12698,
  [12699] = 12591,
  [12700] = 12592,
  [12701] = 12602,
  [12702] = 12546,
  [12703] = 12547,
  [12704] = 12548,
  [12705] = 12550,
  [12706] = 12585,
  [12707] = 12564,
  [12708] = 12503,
  [12709] = 12572,
  [12710] = 12579,
  [12711] = 12584,
  [12712] = 12497,
  [12713] = 12505,
  [12714] = 12591,
  [12715] = 12592,
  [12716] = 12602,
  [12717] = 12546,
  [12718] = 12547,
  [12719] = 12548,
  [12720] = 12550,
  [12721] = 12537,
  [12722] = 11747,
  [12723] = 12564,
  [12724] = 12581,
  [12725] = 12602,
  [12726] = 12572,
  [12727] = 12579,
  [12728] = 12728,
  [12729] = 12729,
  [12730] = 12497,
  [12731] = 12591,
  [12732] = 12592,
  [12733] = 12602,
  [12734] = 12546,
  [12735] = 12547,
  [12736] = 12548,
  [12737] = 12550,
  [12738] = 12537,
  [12739] = 12564,
  [12740] = 12582,
  [12741] = 12572,
  [12742] = 12742,
  [12743] = 12743,
  [12744] = 12579,
  [12745] = 12577,
  [12746] = 12497,
  [12747] = 12591,
  [12748] = 12748,
  [12749] = 12592,
  [12750] = 12602,
  [12751] = 12507,
  [12752] = 12546,
  [12753] = 12572,
  [12754] = 12546,
  [12755] = 12572,
  [12756] = 12546,
  [12757] = 12757,
  [12758] = 12572,
  [12759] = 12546,
  [12760] = 12572,
  [12761] = 12546,
  [12762] = 12507,
  [12763] = 12763,
  [12764] = 12572,
  [12765] = 12570,
  [12766] = 12572,
  [12767] = 12572,
  [12768] = 12615,
  [12769] = 12495,
  [12770] = 12770,
  [12771] = 12564,
  [12772] = 12772,
  [12773] = 12581,
  [12774] = 12582,
  [12775] = 12584,
  [12776] = 12776,
  [12777] = 12572,
  [12778] = 12512,
  [12779] = 12578,
  [12780] = 12600,
  [12781] = 12601,
  [12782] = 12782,
  [12783] = 12783,
  [12784] = 12580,
  [12785] = 12571,
  [12786] = 12786,
  [12787] = 12585,
  [12788] = 12615,
  [12789] = 12789,
  [12790] = 12571,
  [12791] = 12585,
  [12792] = 12615,
  [12793] = 12793,
  [12794] = 12794,
  [12795] = 11742,
  [12796] = 12796,
  [12797] = 12615,
  [12798] = 12492,
  [12799] = 12799,
  [12800] = 12800,
  [12801] = 12801,
  [12802] = 12615,
  [12803] = 12511,
  [12804] = 12804,
  [12805] = 12518,
  [12806] = 12498,
  [12807] = 12570,
  [12808] = 12808,
  [12809] = 12511,
  [12810] = 12810,
  [12811] = 12550,
  [12812] = 12812,
  [12813] = 12579,
  [12814] = 12502,
  [12815] = 12505,
  [12816] = 12512,
  [12817] = 12817,
  [12818] = 12818,
  [12819] = 12819,
  [12820] = 12820,
  [12821] = 12821,
  [12822] = 12822,
  [12823] = 12823,
  [12824] = 12824,
  [12825] = 12825,
  [12826] = 12518,
  [12827] = 12827,
  [12828] = 12828,
  [12829] = 12829,
  [12830] = 12830,
  [12831] = 12518,
  [12832] = 12518,
  [12833] = 12507,
  [12834] = 12570,
  [12835] = 12495,
  [12836] = 12581,
  [12837] = 12582,
  [12838] = 12591,
  [12839] = 12615,
  [12840] = 12804,
  [12841] = 12786,
  [12842] = 12565,
  [12843] = 12843,
  [12844] = 12492,
  [12845] = 12490,
  [12846] = 12512,
  [12847] = 12847,
  [12848] = 12600,
  [12849] = 12849,
  [12850] = 12600,
  [12851] = 12601,
  [12852] = 12601,
  [12853] = 12558,
  [12854] = 12854,
  [12855] = 12855,
  [12856] = 12856,
  [12857] = 12495,
  [12858] = 12804,
  [12859] = 12804,
  [12860] = 12804,
  [12861] = 12804,
  [12862] = 12804,
  [12863] = 12498,
  [12864] = 12804,
  [12865] = 12515,
  [12866] = 12515,
  [12867] = 12515,
  [12868] = 12515,
  [12869] = 12515,
  [12870] = 12515,
  [12871] = 12515,
  [12872] = 12515,
  [12873] = 12571,
  [12874] = 12537,
  [12875] = 12875,
  [12876] = 12876,
  [12877] = 12877,
  [12878] = 12878,
  [12879] = 12879,
  [12880] = 12880,
  [12881] = 12881,
  [12882] = 12882,
  [12883] = 12883,
  [12884] = 12884,
  [12885] = 12885,
  [12886] = 12886,
  [12887] = 12887,
  [12888] = 12888,
  [12889] = 12889,
  [12890] = 12890,
  [12891] = 12891,
  [12892] = 12892,
  [12893] = 12893,
  [12894] = 12894,
  [12895] = 12895,
  [12896] = 12896,
  [12897] = 12897,
  [12898] = 12898,
  [12899] = 12899,
  [12900] = 12900,
  [12901] = 12901,
  [12902] = 12902,
  [12903] = 12897,
  [12904] = 12904,
  [12905] = 12900,
  [12906] = 12906,
  [12907] = 12907,
  [12908] = 12908,
  [12909] = 12909,
  [12910] = 12910,
  [12911] = 12911,
  [12912] = 12912,
  [12913] = 12882,
  [12914] = 12914,
  [12915] = 12915,
  [12916] = 12916,
  [12917] = 12917,
  [12918] = 12918,
  [12919] = 12919,
  [12920] = 12920,
  [12921] = 12921,
  [12922] = 12922,
  [12923] = 12895,
  [12924] = 12898,
  [12925] = 12925,
  [12926] = 12926,
  [12927] = 12927,
  [12928] = 12928,
  [12929] = 12929,
  [12930] = 12930,
  [12931] = 12931,
  [12932] = 12882,
  [12933] = 12933,
  [12934] = 12934,
  [12935] = 12935,
  [12936] = 12927,
  [12937] = 12937,
  [12938] = 12877,
  [12939] = 12878,
  [12940] = 12884,
  [12941] = 12886,
  [12942] = 12928,
  [12943] = 12888,
  [12944] = 12944,
  [12945] = 12945,
  [12946] = 12893,
  [12947] = 12894,
  [12948] = 12948,
  [12949] = 12949,
  [12950] = 12950,
  [12951] = 12896,
  [12952] = 12952,
  [12953] = 12953,
  [12954] = 12902,
  [12955] = 12915,
  [12956] = 12956,
  [12957] = 12906,
  [12958] = 12907,
  [12959] = 12896,
  [12960] = 12960,
  [12961] = 12961,
  [12962] = 12882,
  [12963] = 12963,
  [12964] = 12964,
  [12965] = 12965,
  [12966] = 12966,
  [12967] = 12967,
  [12968] = 12929,
  [12969] = 12930,
  [12970] = 12970,
  [12971] = 12933,
  [12972] = 12934,
  [12973] = 12877,
  [12974] = 12878,
  [12975] = 12884,
  [12976] = 12888,
  [12977] = 12893,
  [12978] = 12978,
  [12979] = 12979,
  [12980] = 12980,
  [12981] = 12981,
  [12982] = 12982,
  [12983] = 12983,
  [12984] = 12984,
  [12985] = 12906,
  [12986] = 12887,
  [12987] = 12916,
  [12988] = 12988,
  [12989] = 12929,
  [12990] = 12930,
  [12991] = 12933,
  [12992] = 12934,
  [12993] = 12877,
  [12994] = 12994,
  [12995] = 12884,
  [12996] = 12888,
  [12997] = 12893,
  [12998] = 12998,
  [12999] = 12999,
  [13000] = 13000,
  [13001] = 13001,
  [13002] = 12906,
  [13003] = 13003,
  [13004] = 13004,
  [13005] = 13005,
  [13006] = 12930,
  [13007] = 12933,
  [13008] = 12877,
  [13009] = 12884,
  [13010] = 13010,
  [13011] = 12888,
  [13012] = 13012,
  [13013] = 12893,
  [13014] = 13014,
  [13015] = 13015,
  [13016] = 13016,
  [13017] = 13017,
  [13018] = 13018,
  [13019] = 12906,
  [13020] = 13020,
  [13021] = 13021,
  [13022] = 12930,
  [13023] = 12933,
  [13024] = 12877,
  [13025] = 12884,
  [13026] = 12888,
  [13027] = 13027,
  [13028] = 12893,
  [13029] = 12899,
  [13030] = 12918,
  [13031] = 12919,
  [13032] = 12925,
  [13033] = 12906,
  [13034] = 12931,
  [13035] = 12930,
  [13036] = 12933,
  [13037] = 12877,
  [13038] = 13038,
  [13039] = 12884,
  [13040] = 12888,
  [13041] = 13041,
  [13042] = 12893,
  [13043] = 13043,
  [13044] = 12906,
  [13045] = 12944,
  [13046] = 13046,
  [13047] = 12930,
  [13048] = 12933,
  [13049] = 13049,
  [13050] = 12877,
  [13051] = 12884,
  [13052] = 12888,
  [13053] = 13038,
  [13054] = 12893,
  [13055] = 13043,
  [13056] = 13056,
  [13057] = 12906,
  [13058] = 12933,
  [13059] = 12877,
  [13060] = 12888,
  [13061] = 13061,
  [13062] = 13062,
  [13063] = 12933,
  [13064] = 13064,
  [13065] = 12877,
  [13066] = 12888,
  [13067] = 13067,
  [13068] = 12933,
  [13069] = 13069,
  [13070] = 12877,
  [13071] = 12888,
  [13072] = 12917,
  [13073] = 12945,
  [13074] = 12979,
  [13075] = 12933,
  [13076] = 13076,
  [13077] = 12877,
  [13078] = 12948,
  [13079] = 12888,
  [13080] = 13080,
  [13081] = 13081,
  [13082] = 13082,
  [13083] = 13083,
  [13084] = 12949,
  [13085] = 13085,
  [13086] = 13086,
  [13087] = 13087,
  [13088] = 13088,
  [13089] = 13089,
  [13090] = 12948,
  [13091] = 13091,
  [13092] = 12949,
  [13093] = 13093,
  [13094] = 12877,
  [13095] = 12980,
  [13096] = 13067,
  [13097] = 12926,
  [13098] = 11716,
  [13099] = 11664,
  [13100] = 13100,
  [13101] = 13101,
  [13102] = 12950,
  [13103] = 12933,
  [13104] = 13104,
  [13105] = 12907,
  [13106] = 13106,
  [13107] = 13107,
  [13108] = 13108,
  [13109] = 12897,
  [13110] = 13110,
  [13111] = 13111,
  [13112] = 13112,
  [13113] = 12895,
  [13114] = 12878,
  [13115] = 13115,
  [13116] = 13116,
  [13117] = 13117,
  [13118] = 13118,
  [13119] = 12927,
  [13120] = 13120,
  [13121] = 12933,
  [13122] = 13085,
  [13123] = 13123,
  [13124] = 13124,
  [13125] = 12877,
  [13126] = 12879,
  [13127] = 12882,
  [13128] = 13128,
  [13129] = 12881,
  [13130] = 13130,
  [13131] = 12883,
  [13132] = 12884,
  [13133] = 13133,
  [13134] = 13134,
  [13135] = 13135,
  [13136] = 12908,
  [13137] = 12793,
  [13138] = 13138,
  [13139] = 13139,
  [13140] = 12929,
  [13141] = 12930,
  [13142] = 12933,
  [13143] = 12896,
  [13144] = 12921,
  [13145] = 12929,
  [13146] = 12930,
  [13147] = 12904,
  [13148] = 13148,
  [13149] = 13149,
  [13150] = 13150,
  [13151] = 12900,
  [13152] = 13152,
  [13153] = 12998,
  [13154] = 12921,
  [13155] = 13155,
  [13156] = 12960,
  [13157] = 12933,
  [13158] = 11542,
  [13159] = 12999,
  [13160] = 12888,
  [13161] = 12934,
  [13162] = 13162,
  [13163] = 12890,
  [13164] = 12922,
  [13165] = 12891,
  [13166] = 12892,
  [13167] = 12893,
  [13168] = 13110,
  [13169] = 13111,
  [13170] = 12961,
  [13171] = 12935,
  [13172] = 12906,
  [13173] = 12921,
  [13174] = 13067,
  [13175] = 12922,
  [13176] = 13176,
  [13177] = 13138,
  [13178] = 13089,
  [13179] = 13179,
  [13180] = 13086,
  [13181] = 12895,
  [13182] = 13118,
  [13183] = 13183,
  [13184] = 11716,
  [13185] = 11664,
  [13186] = 12904,
  [13187] = 12898,
  [13188] = 12900,
  [13189] = 12906,
  [13190] = 12877,
  [13191] = 12878,
  [13192] = 12930,
  [13193] = 12915,
  [13194] = 13194,
  [13195] = 13195,
  [13196] = 13196,
  [13197] = 12879,
  [13198] = 12927,
  [13199] = 12895,
  [13200] = 12928,
  [13201] = 11672,
  [13202] = 12881,
  [13203] = 12898,
  [13204] = 12902,
  [13205] = 12883,
  [13206] = 12880,
  [13207] = 12933,
  [13208] = 12884,
  [13209] = 12984,
  [13210] = 12928,
  [13211] = 12897,
  [13212] = 12934,
  [13213] = 12950,
  [13214] = 13214,
  [13215] = 13000,
  [13216] = 12935,
  [13217] = 13217,
  [13218] = 13218,
  [13219] = 13219,
  [13220] = 12927,
  [13221] = 12883,
  [13222] = 12879,
  [13223] = 12921,
  [13224] = 12922,
  [13225] = 12895,
  [13226] = 12898,
  [13227] = 12927,
  [13228] = 12928,
  [13229] = 13229,
  [13230] = 12886,
  [13231] = 13231,
  [13232] = 13104,
  [13233] = 12960,
  [13234] = 12928,
  [13235] = 12944,
  [13236] = 12961,
  [13237] = 12945,
  [13238] = 12944,
  [13239] = 12948,
  [13240] = 12963,
  [13241] = 12901,
  [13242] = 13242,
  [13243] = 13243,
  [13244] = 12945,
  [13245] = 12934,
  [13246] = 13246,
  [13247] = 12964,
  [13248] = 13123,
  [13249] = 12965,
  [13250] = 12949,
  [13251] = 12888,
  [13252] = 11736,
  [13253] = 13253,
  [13254] = 11751,
  [13255] = 11752,
  [13256] = 11753,
  [13257] = 13088,
  [13258] = 13091,
  [13259] = 12966,
  [13260] = 13093,
  [13261] = 12960,
  [13262] = 12890,
  [13263] = 13067,
  [13264] = 12926,
  [13265] = 13091,
  [13266] = 12891,
  [13267] = 12961,
  [13268] = 13100,
  [13269] = 12963,
  [13270] = 12933,
  [13271] = 12892,
  [13272] = 12964,
  [13273] = 13104,
  [13274] = 12881,
  [13275] = 13107,
  [13276] = 13108,
  [13277] = 12965,
  [13278] = 12893,
  [13279] = 12948,
  [13280] = 12888,
  [13281] = 12949,
  [13282] = 12877,
  [13283] = 12894,
  [13284] = 13284,
  [13285] = 12883,
  [13286] = 12878,
  [13287] = 13287,
  [13288] = 13288,
  [13289] = 13289,
  [13290] = 13290,
  [13291] = 13124,
  [13292] = 12877,
  [13293] = 12879,
  [13294] = 12881,
  [13295] = 12883,
  [13296] = 12884,
  [13297] = 12978,
  [13298] = 12979,
  [13299] = 12980,
  [13300] = 12950,
  [13301] = 12896,
  [13302] = 13302,
  [13303] = 13303,
  [13304] = 13148,
  [13305] = 12879,
  [13306] = 12981,
  [13307] = 13307,
  [13308] = 12982,
  [13309] = 13309,
  [13310] = 12929,
  [13311] = 13311,
  [13312] = 12930,
  [13313] = 12888,
  [13314] = 12881,
  [13315] = 12890,
  [13316] = 12891,
  [13317] = 12892,
  [13318] = 12893,
  [13319] = 13110,
  [13320] = 13111,
  [13321] = 13321,
  [13322] = 13322,
  [13323] = 13138,
  [13324] = 13179,
  [13325] = 12904,
  [13326] = 12900,
  [13327] = 12906,
  [13328] = 12998,
  [13329] = 13195,
  [13330] = 13330,
  [13331] = 13331,
  [13332] = 13196,
  [13333] = 12883,
  [13334] = 12999,
  [13335] = 13000,
  [13336] = 12952,
  [13337] = 12880,
  [13338] = 13338,
  [13339] = 12984,
  [13340] = 13340,
  [13341] = 12904,
  [13342] = 13001,
  [13343] = 12884,
  [13344] = 12900,
  [13345] = 13003,
  [13346] = 13219,
  [13347] = 12921,
  [13348] = 12922,
  [13349] = 12895,
  [13350] = 12898,
  [13351] = 12927,
  [13352] = 12928,
  [13353] = 12906,
  [13354] = 13088,
  [13355] = 12886,
  [13356] = 13091,
  [13357] = 13148,
  [13358] = 13093,
  [13359] = 13014,
  [13360] = 13015,
  [13361] = 12907,
  [13362] = 13067,
  [13363] = 12926,
  [13364] = 13016,
  [13365] = 13100,
  [13366] = 13017,
  [13367] = 12933,
  [13368] = 13018,
  [13369] = 13104,
  [13370] = 13107,
  [13371] = 13108,
  [13372] = 13372,
  [13373] = 12908,
  [13374] = 13124,
  [13375] = 12877,
  [13376] = 12899,
  [13377] = 12918,
  [13378] = 12919,
  [13379] = 13148,
  [13380] = 12894,
  [13381] = 12925,
  [13382] = 12886,
  [13383] = 13001,
  [13384] = 13120,
  [13385] = 12888,
  [13386] = 13110,
  [13387] = 13111,
  [13388] = 12882,
  [13389] = 13389,
  [13390] = 13138,
  [13391] = 13179,
  [13392] = 13076,
  [13393] = 13038,
  [13394] = 13394,
  [13395] = 13195,
  [13396] = 13080,
  [13397] = 13196,
  [13398] = 12880,
  [13399] = 12884,
  [13400] = 12984,
  [13401] = 12967,
  [13402] = 12963,
  [13403] = 13403,
  [13404] = 13219,
  [13405] = 12970,
  [13406] = 13406,
  [13407] = 12929,
  [13408] = 12930,
  [13409] = 13088,
  [13410] = 13394,
  [13411] = 13091,
  [13412] = 13093,
  [13413] = 11316,
  [13414] = 13067,
  [13415] = 12926,
  [13416] = 12981,
  [13417] = 13100,
  [13418] = 13076,
  [13419] = 13080,
  [13420] = 12964,
  [13421] = 13104,
  [13422] = 13107,
  [13423] = 13108,
  [13424] = 11672,
  [13425] = 13425,
  [13426] = 11736,
  [13427] = 13427,
  [13428] = 13372,
  [13429] = 13003,
  [13430] = 13430,
  [13431] = 12890,
  [13432] = 13124,
  [13433] = 11751,
  [13434] = 12944,
  [13435] = 12888,
  [13436] = 12933,
  [13437] = 11752,
  [13438] = 13438,
  [13439] = 12934,
  [13440] = 12922,
  [13441] = 12935,
  [13442] = 13442,
  [13443] = 13443,
  [13444] = 13444,
  [13445] = 13148,
  [13446] = 12921,
  [13447] = 13447,
  [13448] = 13448,
  [13449] = 12965,
  [13450] = 12917,
  [13451] = 12907,
  [13452] = 12922,
  [13453] = 13110,
  [13454] = 13111,
  [13455] = 13455,
  [13456] = 12966,
  [13457] = 13176,
  [13458] = 13183,
  [13459] = 13459,
  [13460] = 13138,
  [13461] = 13179,
  [13462] = 13462,
  [13463] = 13463,
  [13464] = 13394,
  [13465] = 13195,
  [13466] = 12895,
  [13467] = 13196,
  [13468] = 12877,
  [13469] = 12880,
  [13470] = 12984,
  [13471] = 12898,
  [13472] = 13472,
  [13473] = 12878,
  [13474] = 13219,
  [13475] = 12879,
  [13476] = 13004,
  [13477] = 13088,
  [13478] = 12902,
  [13479] = 13479,
  [13480] = 12897,
  [13481] = 13043,
  [13482] = 12915,
  [13483] = 13067,
  [13484] = 13100,
  [13485] = 12881,
  [13486] = 12917,
  [13487] = 13487,
  [13488] = 11753,
  [13489] = 13124,
  [13490] = 13490,
  [13491] = 12982,
  [13492] = 13492,
  [13493] = 13124,
  [13494] = 12927,
  [13495] = 13107,
  [13496] = 13148,
  [13497] = 12928,
  [13498] = 12944,
  [13499] = 13108,
  [13500] = 12945,
  [13501] = 13152,
  [13502] = 12883,
  [13503] = 12948,
  [13504] = 12949,
  [13505] = 12950,
  [13506] = 12884,
  [13507] = 13138,
  [13508] = 13179,
  [13509] = 12952,
  [13510] = 13510,
  [13511] = 13195,
  [13512] = 13196,
  [13513] = 12984,
  [13514] = 13514,
  [13515] = 13515,
  [13516] = 12960,
  [13517] = 12961,
  [13518] = 12963,
  [13519] = 12921,
  [13520] = 12964,
  [13521] = 13155,
  [13522] = 13112,
  [13523] = 12886,
  [13524] = 12965,
  [13525] = 13005,
  [13526] = 12966,
  [13527] = 13067,
  [13528] = 12967,
  [13529] = 12970,
  [13530] = 12978,
  [13531] = 12979,
  [13532] = 13148,
  [13533] = 12904,
  [13534] = 13534,
  [13535] = 12898,
  [13536] = 12980,
  [13537] = 12978,
  [13538] = 12981,
  [13539] = 12982,
  [13540] = 12888,
  [13541] = 13541,
  [13542] = 12904,
  [13543] = 13138,
  [13544] = 13179,
  [13545] = 12983,
  [13546] = 12890,
  [13547] = 13195,
  [13548] = 12887,
  [13549] = 13196,
  [13550] = 12891,
  [13551] = 12916,
  [13552] = 12984,
  [13553] = 12892,
  [13554] = 13554,
  [13555] = 12998,
  [13556] = 12893,
  [13557] = 12999,
  [13558] = 12898,
  [13559] = 13000,
  [13560] = 13001,
  [13561] = 13003,
  [13562] = 12900,
  [13563] = 13004,
  [13564] = 13005,
  [13565] = 12979,
  [13566] = 13014,
  [13567] = 13015,
  [13568] = 12980,
  [13569] = 13148,
  [13570] = 12978,
  [13571] = 13016,
  [13572] = 13572,
  [13573] = 13573,
  [13574] = 13017,
  [13575] = 12908,
  [13576] = 13018,
  [13577] = 12981,
  [13578] = 12900,
  [13579] = 12894,
  [13580] = 12982,
  [13581] = 13138,
  [13582] = 13179,
  [13583] = 12979,
  [13584] = 13195,
  [13585] = 13020,
  [13586] = 13021,
  [13587] = 13196,
  [13588] = 12980,
  [13589] = 12984,
  [13590] = 12935,
  [13591] = 13591,
  [13592] = 12983,
  [13593] = 13593,
  [13594] = 13594,
  [13595] = 13595,
  [13596] = 13596,
  [13597] = 12899,
  [13598] = 12918,
  [13599] = 12919,
  [13600] = 12925,
  [13601] = 12931,
  [13602] = 12896,
  [13603] = 12981,
  [13604] = 13179,
  [13605] = 12982,
  [13606] = 13196,
  [13607] = 12984,
  [13608] = 13179,
  [13609] = 13038,
  [13610] = 13196,
  [13611] = 12984,
  [13612] = 13043,
  [13613] = 12983,
  [13614] = 13179,
  [13615] = 13196,
  [13616] = 12984,
  [13617] = 13617,
  [13618] = 12929,
  [13619] = 12930,
  [13620] = 12895,
  [13621] = 13179,
  [13622] = 13196,
  [13623] = 12984,
  [13624] = 12998,
  [13625] = 13625,
  [13626] = 12904,
  [13627] = 13627,
  [13628] = 12900,
  [13629] = 13179,
  [13630] = 13630,
  [13631] = 13196,
  [13632] = 12984,
  [13633] = 12906,
  [13634] = 12999,
  [13635] = 13179,
  [13636] = 13196,
  [13637] = 12984,
  [13638] = 13638,
  [13639] = 13639,
  [13640] = 13179,
  [13641] = 13196,
  [13642] = 12984,
  [13643] = 13643,
  [13644] = 13644,
  [13645] = 12891,
  [13646] = 13646,
  [13647] = 12906,
  [13648] = 13444,
  [13649] = 13649,
  [13650] = 13650,
  [13651] = 12907,
  [13652] = 12933,
  [13653] = 13000,
  [13654] = 12934,
  [13655] = 13014,
  [13656] = 13106,
  [13657] = 13229,
  [13658] = 13001,
  [13659] = 13231,
  [13660] = 13660,
  [13661] = 12935,
  [13662] = 13287,
  [13663] = 12890,
  [13664] = 13003,
  [13665] = 12891,
  [13666] = 12908,
  [13667] = 12892,
  [13668] = 12960,
  [13669] = 12892,
  [13670] = 13670,
  [13671] = 12908,
  [13672] = 13195,
  [13673] = 12877,
  [13674] = 13674,
  [13675] = 12878,
  [13676] = 12879,
  [13677] = 12881,
  [13678] = 12893,
  [13679] = 13004,
  [13680] = 12883,
  [13681] = 13681,
  [13682] = 12887,
  [13683] = 12961,
  [13684] = 12916,
  [13685] = 13219,
  [13686] = 12884,
  [13687] = 13179,
  [13688] = 12963,
  [13689] = 12964,
  [13690] = 12945,
  [13691] = 13015,
  [13692] = 13196,
  [13693] = 13693,
  [13694] = 13176,
  [13695] = 13660,
  [13696] = 12984,
  [13697] = 13697,
  [13698] = 13698,
  [13699] = 13016,
  [13700] = 12886,
  [13701] = 12965,
  [13702] = 11536,
  [13703] = 13703,
  [13704] = 13704,
  [13705] = 13705,
  [13706] = 13017,
  [13707] = 12894,
  [13708] = 12888,
  [13709] = 12882,
  [13710] = 12890,
  [13711] = 13650,
  [13712] = 12891,
  [13713] = 12892,
  [13714] = 13112,
  [13715] = 13106,
  [13716] = 13229,
  [13717] = 13231,
  [13718] = 13660,
  [13719] = 12893,
  [13720] = 13287,
  [13721] = 13196,
  [13722] = 13670,
  [13723] = 13183,
  [13724] = 13724,
  [13725] = 13725,
  [13726] = 12893,
  [13727] = 12966,
  [13728] = 13444,
  [13729] = 13135,
  [13730] = 13018,
  [13731] = 12894,
  [13732] = 13670,
  [13733] = 13014,
  [13734] = 13650,
  [13735] = 12877,
  [13736] = 13106,
  [13737] = 13229,
  [13738] = 13231,
  [13739] = 13660,
  [13740] = 13287,
  [13741] = 12896,
  [13742] = 13176,
  [13743] = 12967,
  [13744] = 13744,
  [13745] = 13670,
  [13746] = 13015,
  [13747] = 13747,
  [13748] = 13748,
  [13749] = 13749,
  [13750] = 13750,
  [13751] = 12904,
  [13752] = 12900,
  [13753] = 13753,
  [13754] = 12906,
  [13755] = 13755,
  [13756] = 12927,
  [13757] = 13016,
  [13758] = 13017,
  [13759] = 13018,
  [13760] = 13133,
  [13761] = 13020,
  [13762] = 13650,
  [13763] = 12907,
  [13764] = 13764,
  [13765] = 13106,
  [13766] = 13229,
  [13767] = 13231,
  [13768] = 13660,
  [13769] = 13287,
  [13770] = 12878,
  [13771] = 13670,
  [13772] = 13183,
  [13773] = 12906,
  [13774] = 13774,
  [13775] = 12908,
  [13776] = 13776,
  [13777] = 12896,
  [13778] = 13139,
  [13779] = 13650,
  [13780] = 13780,
  [13781] = 13106,
  [13782] = 13229,
  [13783] = 13231,
  [13784] = 13660,
  [13785] = 13785,
  [13786] = 13287,
  [13787] = 13787,
  [13788] = 13134,
  [13789] = 13670,
  [13790] = 12970,
  [13791] = 12920,
  [13792] = 12879,
  [13793] = 12882,
  [13794] = 13794,
  [13795] = 13287,
  [13796] = 12998,
  [13797] = 12999,
  [13798] = 13798,
  [13799] = 13287,
  [13800] = 13800,
  [13801] = 13000,
  [13802] = 13100,
  [13803] = 13020,
  [13804] = 13596,
  [13805] = 13805,
  [13806] = 13806,
  [13807] = 13807,
  [13808] = 13093,
  [13809] = 13001,
  [13810] = 13810,
  [13811] = 13389,
  [13812] = 13003,
  [13813] = 13813,
  [13814] = 12899,
  [13815] = 13815,
  [13816] = 13004,
  [13817] = 13183,
  [13818] = 13818,
  [13819] = 12918,
  [13820] = 12881,
  [13821] = 12919,
  [13822] = 13822,
  [13823] = 13823,
  [13824] = 13176,
  [13825] = 12925,
  [13826] = 13826,
  [13827] = 13005,
  [13828] = 13021,
  [13829] = 13038,
  [13830] = 13830,
  [13831] = 13088,
  [13832] = 12904,
  [13833] = 13833,
  [13834] = 12888,
  [13835] = 12921,
  [13836] = 13014,
  [13837] = 13015,
  [13838] = 12920,
  [13839] = 13016,
  [13840] = 12922,
  [13841] = 13176,
  [13842] = 13183,
  [13843] = 13843,
  [13844] = 13017,
  [13845] = 13018,
  [13846] = 12895,
  [13847] = 13020,
  [13848] = 12898,
  [13849] = 12902,
  [13850] = 12897,
  [13851] = 12915,
  [13852] = 13444,
  [13853] = 13853,
  [13854] = 13854,
  [13855] = 12917,
  [13856] = 13856,
  [13857] = 12900,
  [13858] = 13858,
  [13859] = 12927,
  [13860] = 12902,
  [13861] = 13861,
  [13862] = 12881,
  [13863] = 12983,
  [13864] = 12928,
  [13865] = 12944,
  [13866] = 12945,
  [13867] = 12948,
  [13868] = 12949,
  [13869] = 12950,
  [13870] = 12952,
  [13871] = 12921,
  [13872] = 13872,
  [13873] = 12960,
  [13874] = 12961,
  [13875] = 12963,
  [13876] = 13876,
  [13877] = 13021,
  [13878] = 12964,
  [13879] = 12965,
  [13880] = 12966,
  [13881] = 12967,
  [13882] = 12970,
  [13883] = 13883,
  [13884] = 12978,
  [13885] = 12979,
  [13886] = 12980,
  [13887] = 12981,
  [13888] = 13888,
  [13889] = 12982,
  [13890] = 12983,
  [13891] = 12887,
  [13892] = 12890,
  [13893] = 12916,
  [13894] = 12922,
  [13895] = 12891,
  [13896] = 12998,
  [13897] = 12999,
  [13898] = 12892,
  [13899] = 13000,
  [13900] = 13001,
  [13901] = 13003,
  [13902] = 13004,
  [13903] = 13005,
  [13904] = 12899,
  [13905] = 12918,
  [13906] = 13014,
  [13907] = 12919,
  [13908] = 13015,
  [13909] = 13016,
  [13910] = 13017,
  [13911] = 12925,
  [13912] = 12893,
  [13913] = 13018,
  [13914] = 13020,
  [13915] = 13915,
  [13916] = 13916,
  [13917] = 13287,
  [13918] = 13021,
  [13919] = 13287,
  [13920] = 13287,
  [13921] = 13287,
  [13922] = 13287,
  [13923] = 13287,
  [13924] = 13287,
  [13925] = 13596,
  [13926] = 12899,
  [13927] = 13120,
  [13928] = 13389,
  [13929] = 12918,
  [13930] = 12919,
  [13931] = 12925,
  [13932] = 12931,
  [13933] = 13596,
  [13934] = 13038,
  [13935] = 13043,
  [13936] = 13389,
  [13937] = 12906,
  [13938] = 12929,
  [13939] = 12930,
  [13940] = 13596,
  [13941] = 12922,
  [13942] = 13942,
  [13943] = 13389,
  [13944] = 13780,
  [13945] = 13389,
  [13946] = 12902,
  [13947] = 13947,
  [13948] = 13389,
  [13949] = 12933,
  [13950] = 13389,
  [13951] = 12934,
  [13952] = 13389,
  [13953] = 12891,
  [13954] = 13389,
  [13955] = 13955,
  [13956] = 13389,
  [13957] = 12935,
  [13958] = 13389,
  [13959] = 13959,
  [13960] = 13960,
  [13961] = 13389,
  [13962] = 13372,
  [13963] = 13963,
  [13964] = 12931,
  [13965] = 13389,
  [13966] = 13389,
  [13967] = 13967,
  [13968] = 12921,
  [13969] = 13650,
  [13970] = 13106,
  [13971] = 13229,
  [13972] = 13231,
  [13973] = 13660,
  [13974] = 13389,
  [13975] = 12922,
  [13976] = 13487,
  [13977] = 13670,
  [13978] = 12895,
  [13979] = 12898,
  [13980] = 13650,
  [13981] = 12877,
  [13982] = 12907,
  [13983] = 12878,
  [13984] = 12879,
  [13985] = 12952,
  [13986] = 12897,
  [13987] = 12881,
  [13988] = 12892,
  [13989] = 12883,
  [13990] = 12884,
  [13991] = 12883,
  [13992] = 12927,
  [13993] = 12928,
  [13994] = 13994,
  [13995] = 13038,
  [13996] = 12886,
  [13997] = 12929,
  [13998] = 13487,
  [13999] = 12930,
  [14000] = 13487,
  [14001] = 13487,
  [14002] = 13487,
  [14003] = 13487,
  [14004] = 13179,
  [14005] = 13596,
  [14006] = 12884,
  [14007] = 14007,
  [14008] = 12928,
  [14009] = 14009,
  [14010] = 12888,
  [14011] = 14011,
  [14012] = 12915,
  [14013] = 12890,
  [14014] = 12891,
  [14015] = 12892,
  [14016] = 12978,
  [14017] = 12893,
  [14018] = 14018,
  [14019] = 12933,
  [14020] = 13287,
  [14021] = 12934,
  [14022] = 12935,
  [14023] = 13176,
  [14024] = 14024,
  [14025] = 13183,
  [14026] = 12894,
  [14027] = 12908,
  [14028] = 14028,
  [14029] = 14029,
  [14030] = 14030,
  [14031] = 14031,
  [14032] = 14032,
  [14033] = 14033,
  [14034] = 14034,
  [14035] = 14035,
  [14036] = 14036,
  [14037] = 14037,
  [14038] = 14038,
  [14039] = 14039,
  [14040] = 14040,
  [14041] = 14041,
  [14042] = 14042,
  [14043] = 14043,
  [14044] = 14044,
  [14045] = 14045,
  [14046] = 14046,
  [14047] = 14047,
  [14048] = 14048,
  [14049] = 14049,
  [14050] = 14050,
  [14051] = 14051,
  [14052] = 14038,
  [14053] = 14053,
  [14054] = 14054,
  [14055] = 14043,
  [14056] = 14050,
  [14057] = 14053,
  [14058] = 14030,
  [14059] = 14059,
  [14060] = 14060,
  [14061] = 14061,
  [14062] = 14062,
  [14063] = 14063,
  [14064] = 14064,
  [14065] = 14065,
  [14066] = 14066,
  [14067] = 14067,
  [14068] = 14068,
  [14069] = 14029,
  [14070] = 14045,
  [14071] = 14071,
  [14072] = 14072,
  [14073] = 14073,
  [14074] = 14074,
  [14075] = 14071,
  [14076] = 14076,
  [14077] = 14077,
  [14078] = 14078,
  [14079] = 14079,
  [14080] = 14032,
  [14081] = 14081,
  [14082] = 14082,
  [14083] = 14083,
  [14084] = 14084,
  [14085] = 14085,
  [14086] = 14033,
  [14087] = 14087,
  [14088] = 14088,
  [14089] = 14079,
  [14090] = 14038,
  [14091] = 14091,
  [14092] = 14092,
  [14093] = 14093,
  [14094] = 14094,
  [14095] = 14095,
  [14096] = 14035,
  [14097] = 14050,
  [14098] = 14060,
  [14099] = 14053,
  [14100] = 14100,
  [14101] = 14065,
  [14102] = 14102,
  [14103] = 14103,
  [14104] = 14066,
  [14105] = 14105,
  [14106] = 14106,
  [14107] = 14107,
  [14108] = 14108,
  [14109] = 14032,
  [14110] = 14110,
  [14111] = 14111,
  [14112] = 14036,
  [14113] = 14037,
  [14114] = 14114,
  [14115] = 14076,
  [14116] = 14040,
  [14117] = 14028,
  [14118] = 14118,
  [14119] = 14119,
  [14120] = 14120,
  [14121] = 14121,
  [14122] = 14114,
  [14123] = 14123,
  [14124] = 14033,
  [14125] = 14042,
  [14126] = 14038,
  [14127] = 14127,
  [14128] = 14128,
  [14129] = 14035,
  [14130] = 14050,
  [14131] = 14053,
  [14132] = 12222,
  [14133] = 14110,
  [14134] = 14127,
  [14135] = 14061,
  [14136] = 14136,
  [14137] = 14128,
  [14138] = 14138,
  [14139] = 14034,
  [14140] = 14044,
  [14141] = 14061,
  [14142] = 14074,
  [14143] = 14064,
  [14144] = 14087,
  [14145] = 14106,
  [14146] = 14146,
  [14147] = 14034,
  [14148] = 14148,
  [14149] = 14061,
  [14150] = 14150,
  [14151] = 14047,
  [14152] = 14062,
  [14153] = 14114,
  [14154] = 14154,
  [14155] = 14084,
  [14156] = 14111,
  [14157] = 14157,
  [14158] = 14062,
  [14159] = 14159,
  [14160] = 14065,
  [14161] = 14161,
  [14162] = 14162,
  [14163] = 14061,
  [14164] = 14066,
  [14165] = 14092,
  [14166] = 14093,
  [14167] = 14094,
  [14168] = 14029,
  [14169] = 14169,
  [14170] = 14170,
  [14171] = 14169,
  [14172] = 14172,
  [14173] = 14173,
  [14174] = 14043,
  [14175] = 14175,
  [14176] = 14045,
  [14177] = 14177,
  [14178] = 14105,
  [14179] = 14179,
  [14180] = 14180,
  [14181] = 14181,
  [14182] = 14031,
  [14183] = 14031,
  [14184] = 14036,
  [14185] = 14037,
  [14186] = 14186,
  [14187] = 14187,
  [14188] = 14188,
  [14189] = 14040,
  [14190] = 14190,
  [14191] = 14062,
  [14192] = 14192,
  [14193] = 14071,
  [14194] = 14044,
  [14195] = 14181,
  [14196] = 14196,
  [14197] = 14197,
  [14198] = 14198,
  [14199] = 14199,
  [14200] = 14200,
  [14201] = 14201,
  [14202] = 14074,
  [14203] = 14203,
  [14204] = 14204,
  [14205] = 14205,
  [14206] = 14206,
  [14207] = 14207,
  [14208] = 14208,
  [14209] = 14064,
  [14210] = 14210,
  [14211] = 14060,
  [14212] = 14212,
  [14213] = 14087,
  [14214] = 14214,
  [14215] = 14215,
  [14216] = 14216,
  [14217] = 14079,
  [14218] = 14218,
  [14219] = 14219,
  [14220] = 14220,
  [14221] = 14106,
  [14222] = 14222,
  [14223] = 14046,
  [14224] = 14224,
  [14225] = 14225,
  [14226] = 14118,
  [14227] = 14187,
  [14228] = 14084,
  [14229] = 14088,
  [14230] = 14230,
  [14231] = 14231,
  [14232] = 14033,
  [14233] = 14035,
  [14234] = 14234,
  [14235] = 14102,
  [14236] = 14236,
  [14237] = 14237,
  [14238] = 14238,
  [14239] = 14102,
  [14240] = 14240,
  [14241] = 14186,
  [14242] = 14146,
  [14243] = 14243,
  [14244] = 14110,
  [14245] = 14245,
  [14246] = 14246,
  [14247] = 14247,
  [14248] = 14248,
  [14249] = 14249,
  [14250] = 14224,
  [14251] = 14251,
  [14252] = 14252,
  [14253] = 14253,
  [14254] = 14254,
  [14255] = 14111,
  [14256] = 14049,
  [14257] = 14257,
  [14258] = 14114,
  [14259] = 14259,
  [14260] = 14031,
  [14261] = 14261,
  [14262] = 14262,
  [14263] = 14263,
  [14264] = 14264,
  [14265] = 14188,
  [14266] = 14266,
  [14267] = 14267,
  [14268] = 14268,
  [14269] = 14159,
  [14270] = 14054,
  [14271] = 14271,
  [14272] = 14119,
  [14273] = 14273,
  [14274] = 14092,
  [14275] = 14093,
  [14276] = 14094,
  [14277] = 14118,
  [14278] = 14088,
  [14279] = 14279,
  [14280] = 14030,
  [14281] = 14281,
  [14282] = 14282,
  [14283] = 14283,
  [14284] = 14284,
  [14285] = 14031,
  [14286] = 14286,
  [14287] = 14287,
  [14288] = 14100,
  [14289] = 14205,
  [14290] = 14119,
  [14291] = 14291,
  [14292] = 14292,
  [14293] = 14293,
  [14294] = 14294,
  [14295] = 14295,
  [14296] = 14296,
  [14297] = 14297,
  [14298] = 14298,
  [14299] = 14123,
  [14300] = 14201,
  [14301] = 14074,
  [14302] = 14179,
  [14303] = 14065,
  [14304] = 14304,
  [14305] = 14123,
  [14306] = 14306,
  [14307] = 14196,
  [14308] = 13744,
  [14309] = 14309,
  [14310] = 14310,
  [14311] = 14311,
  [14312] = 14312,
  [14313] = 14028,
  [14314] = 14188,
  [14315] = 14315,
  [14316] = 14316,
  [14317] = 14208,
  [14318] = 14105,
  [14319] = 14161,
  [14320] = 14320,
  [14321] = 14321,
  [14322] = 14220,
  [14323] = 14212,
  [14324] = 14324,
  [14325] = 14088,
  [14326] = 14066,
  [14327] = 14031,
  [14328] = 14328,
  [14329] = 14067,
  [14330] = 14330,
  [14331] = 14240,
  [14332] = 14146,
  [14333] = 14333,
  [14334] = 14334,
  [14335] = 14286,
  [14336] = 14114,
  [14337] = 14337,
  [14338] = 14036,
  [14339] = 14037,
  [14340] = 14214,
  [14341] = 14088,
  [14342] = 14197,
  [14343] = 14040,
  [14344] = 14088,
  [14345] = 14088,
  [14346] = 14068,
  [14347] = 14347,
  [14348] = 14348,
  [14349] = 14138,
  [14350] = 14279,
  [14351] = 14351,
  [14352] = 14352,
  [14353] = 14353,
  [14354] = 14032,
  [14355] = 14240,
  [14356] = 14356,
  [14357] = 14357,
  [14358] = 14358,
  [14359] = 14359,
  [14360] = 14146,
  [14361] = 14361,
  [14362] = 14362,
  [14363] = 14363,
  [14364] = 14364,
  [14365] = 14238,
  [14366] = 14366,
  [14367] = 14084,
  [14368] = 14110,
  [14369] = 14369,
  [14370] = 14370,
  [14371] = 14371,
  [14372] = 14031,
  [14373] = 14373,
  [14374] = 14111,
  [14375] = 13311,
  [14376] = 14376,
  [14377] = 14377,
  [14378] = 14378,
  [14379] = 14379,
  [14380] = 14064,
  [14381] = 14087,
  [14382] = 14072,
  [14383] = 14081,
  [14384] = 14033,
  [14385] = 14385,
  [14386] = 14048,
  [14387] = 14114,
  [14388] = 14106,
  [14389] = 14389,
  [14390] = 14029,
  [14391] = 14045,
  [14392] = 14392,
  [14393] = 14054,
  [14394] = 14394,
  [14395] = 14088,
  [14396] = 14114,
  [14397] = 14088,
  [14398] = 14114,
  [14399] = 14088,
  [14400] = 14114,
  [14401] = 14281,
  [14402] = 14286,
  [14403] = 14403,
  [14404] = 14287,
  [14405] = 13061,
  [14406] = 14043,
  [14407] = 14222,
  [14408] = 14114,
  [14409] = 14292,
  [14410] = 14293,
  [14411] = 14038,
  [14412] = 14412,
  [14413] = 14297,
  [14414] = 14224,
  [14415] = 14050,
  [14416] = 14416,
  [14417] = 14053,
  [14418] = 14230,
  [14419] = 14212,
  [14420] = 14114,
  [14421] = 14196,
  [14422] = 14422,
  [14423] = 14309,
  [14424] = 14424,
  [14425] = 14312,
  [14426] = 14028,
  [14427] = 14114,
  [14428] = 12912,
  [14429] = 14429,
  [14430] = 14430,
  [14431] = 14247,
  [14432] = 14328,
  [14433] = 14433,
  [14434] = 14248,
  [14435] = 14337,
  [14436] = 14214,
  [14437] = 14437,
  [14438] = 14127,
  [14439] = 14128,
  [14440] = 14440,
  [14441] = 14441,
  [14442] = 14442,
  [14443] = 14071,
  [14444] = 14279,
  [14445] = 14351,
  [14446] = 14200,
  [14447] = 14034,
  [14448] = 14061,
  [14449] = 14062,
  [14450] = 14076,
  [14451] = 14361,
  [14452] = 14362,
  [14453] = 14363,
  [14454] = 14294,
  [14455] = 14373,
  [14456] = 14456,
  [14457] = 14457,
  [14458] = 14118,
  [14459] = 14088,
  [14460] = 14114,
  [14461] = 14088,
  [14462] = 14114,
  [14463] = 14281,
  [14464] = 14286,
  [14465] = 14287,
  [14466] = 14466,
  [14467] = 14292,
  [14468] = 14293,
  [14469] = 14181,
  [14470] = 14470,
  [14471] = 14297,
  [14472] = 14472,
  [14473] = 14215,
  [14474] = 14187,
  [14475] = 14088,
  [14476] = 14476,
  [14477] = 14477,
  [14478] = 14196,
  [14479] = 14188,
  [14480] = 14162,
  [14481] = 14119,
  [14482] = 14309,
  [14483] = 14312,
  [14484] = 14028,
  [14485] = 14093,
  [14486] = 14486,
  [14487] = 14186,
  [14488] = 14088,
  [14489] = 14218,
  [14490] = 14060,
  [14491] = 14328,
  [14492] = 14201,
  [14493] = 14074,
  [14494] = 14494,
  [14495] = 14123,
  [14496] = 14279,
  [14497] = 14351,
  [14498] = 14051,
  [14499] = 14499,
  [14500] = 14500,
  [14501] = 14361,
  [14502] = 14362,
  [14503] = 14363,
  [14504] = 14504,
  [14505] = 14505,
  [14506] = 14236,
  [14507] = 14373,
  [14508] = 14114,
  [14509] = 14094,
  [14510] = 14281,
  [14511] = 14084,
  [14512] = 14092,
  [14513] = 14286,
  [14514] = 14093,
  [14515] = 14287,
  [14516] = 14094,
  [14517] = 14416,
  [14518] = 14247,
  [14519] = 14292,
  [14520] = 14293,
  [14521] = 14248,
  [14522] = 14208,
  [14523] = 14523,
  [14524] = 14297,
  [14525] = 14525,
  [14526] = 14526,
  [14527] = 14059,
  [14528] = 14528,
  [14529] = 14267,
  [14530] = 959,
  [14531] = 14196,
  [14532] = 14072,
  [14533] = 14309,
  [14534] = 14312,
  [14535] = 14028,
  [14536] = 14092,
  [14537] = 14093,
  [14538] = 14094,
  [14539] = 14328,
  [14540] = 14212,
  [14541] = 14230,
  [14542] = 14035,
  [14543] = 14543,
  [14544] = 14544,
  [14545] = 14279,
  [14546] = 14351,
  [14547] = 14547,
  [14548] = 14219,
  [14549] = 14315,
  [14550] = 14550,
  [14551] = 14361,
  [14552] = 14362,
  [14553] = 14363,
  [14554] = 14373,
  [14555] = 14555,
  [14556] = 14556,
  [14557] = 14084,
  [14558] = 14286,
  [14559] = 14287,
  [14560] = 14560,
  [14561] = 14292,
  [14562] = 14293,
  [14563] = 14072,
  [14564] = 14297,
  [14565] = 14361,
  [14566] = 14102,
  [14567] = 14214,
  [14568] = 14294,
  [14569] = 14296,
  [14570] = 14196,
  [14571] = 14571,
  [14572] = 14088,
  [14573] = 14573,
  [14574] = 14312,
  [14575] = 14028,
  [14576] = 14222,
  [14577] = 14362,
  [14578] = 14159,
  [14579] = 14224,
  [14580] = 14315,
  [14581] = 14328,
  [14582] = 14105,
  [14583] = 14363,
  [14584] = 14584,
  [14585] = 14585,
  [14586] = 14105,
  [14587] = 14351,
  [14588] = 14320,
  [14589] = 14362,
  [14590] = 14363,
  [14591] = 14591,
  [14592] = 14169,
  [14593] = 14222,
  [14594] = 14373,
  [14595] = 14247,
  [14596] = 14596,
  [14597] = 14597,
  [14598] = 14292,
  [14599] = 14293,
  [14600] = 14196,
  [14601] = 14224,
  [14602] = 14312,
  [14603] = 14028,
  [14604] = 14088,
  [14605] = 14328,
  [14606] = 14036,
  [14607] = 14297,
  [14608] = 14351,
  [14609] = 14049,
  [14610] = 14362,
  [14611] = 14363,
  [14612] = 14373,
  [14613] = 14613,
  [14614] = 14072,
  [14615] = 14292,
  [14616] = 14293,
  [14617] = 14196,
  [14618] = 14312,
  [14619] = 14028,
  [14620] = 13128,
  [14621] = 14328,
  [14622] = 14337,
  [14623] = 14351,
  [14624] = 14362,
  [14625] = 14363,
  [14626] = 14373,
  [14627] = 14036,
  [14628] = 14544,
  [14629] = 14037,
  [14630] = 14312,
  [14631] = 14028,
  [14632] = 14312,
  [14633] = 14028,
  [14634] = 14312,
  [14635] = 14028,
  [14636] = 14042,
  [14637] = 14028,
  [14638] = 14312,
  [14639] = 14138,
  [14640] = 14312,
  [14641] = 14028,
  [14642] = 14312,
  [14643] = 14028,
  [14644] = 14230,
  [14645] = 14645,
  [14646] = 14646,
  [14647] = 14647,
  [14648] = 14648,
  [14649] = 14649,
  [14650] = 14650,
  [14651] = 14040,
  [14652] = 14114,
  [14653] = 14294,
  [14654] = 14296,
  [14655] = 14312,
  [14656] = 14028,
  [14657] = 14657,
  [14658] = 14161,
  [14659] = 14049,
  [14660] = 14660,
  [14661] = 14296,
  [14662] = 14662,
  [14663] = 14197,
  [14664] = 14081,
  [14665] = 14110,
  [14666] = 14136,
  [14667] = 14065,
  [14668] = 14424,
  [14669] = 14088,
  [14670] = 14081,
  [14671] = 14240,
  [14672] = 14672,
  [14673] = 14673,
  [14674] = 14138,
  [14675] = 14675,
  [14676] = 14676,
  [14677] = 14677,
  [14678] = 14678,
  [14679] = 14373,
  [14680] = 14038,
  [14681] = 14248,
  [14682] = 14066,
  [14683] = 14146,
  [14684] = 14230,
  [14685] = 14685,
  [14686] = 14114,
  [14687] = 14050,
  [14688] = 14688,
  [14689] = 14689,
  [14690] = 14200,
  [14691] = 14053,
  [14692] = 14692,
  [14693] = 14693,
  [14694] = 14694,
  [14695] = 14111,
  [14696] = 14179,
  [14697] = 14031,
  [14698] = 14215,
  [14699] = 14038,
  [14700] = 14240,
  [14701] = 14114,
  [14702] = 14324,
  [14703] = 14320,
  [14704] = 14031,
  [14705] = 14103,
  [14706] = 14706,
  [14707] = 14707,
  [14708] = 14162,
  [14709] = 14088,
  [14710] = 14218,
  [14711] = 14711,
  [14712] = 14712,
  [14713] = 14067,
  [14714] = 14287,
  [14715] = 14715,
  [14716] = 14079,
  [14717] = 14717,
  [14718] = 14718,
  [14719] = 14068,
  [14720] = 14720,
  [14721] = 14721,
  [14722] = 14044,
  [14723] = 14723,
  [14724] = 14064,
  [14725] = 14031,
  [14726] = 14726,
  [14727] = 14050,
  [14728] = 14087,
  [14729] = 14729,
  [14730] = 14106,
  [14731] = 14731,
  [14732] = 14732,
  [14733] = 14078,
  [14734] = 14103,
  [14735] = 14051,
  [14736] = 14736,
  [14737] = 14236,
  [14738] = 14078,
  [14739] = 14127,
  [14740] = 14378,
  [14741] = 14128,
  [14742] = 14494,
  [14743] = 14743,
  [14744] = 14111,
  [14745] = 14544,
  [14746] = 14746,
  [14747] = 14114,
  [14748] = 14034,
  [14749] = 14061,
  [14750] = 14315,
  [14751] = 14105,
  [14752] = 14752,
  [14753] = 14320,
  [14754] = 14179,
  [14755] = 14161,
  [14756] = 14756,
  [14757] = 14049,
  [14758] = 14169,
  [14759] = 14759,
  [14760] = 14179,
  [14761] = 14761,
  [14762] = 14037,
  [14763] = 1014,
  [14764] = 14764,
  [14765] = 14765,
  [14766] = 14486,
  [14767] = 14416,
  [14768] = 14162,
  [14769] = 14103,
  [14770] = 960,
  [14771] = 14162,
  [14772] = 14772,
  [14773] = 14159,
  [14774] = 14110,
  [14775] = 14775,
  [14776] = 14776,
  [14777] = 14103,
  [14778] = 14186,
  [14779] = 14267,
  [14780] = 14072,
  [14781] = 14781,
  [14782] = 14031,
  [14783] = 14783,
  [14784] = 14784,
  [14785] = 14785,
  [14786] = 14786,
  [14787] = 14238,
  [14788] = 14054,
  [14789] = 14761,
  [14790] = 14197,
  [14791] = 14200,
  [14792] = 14792,
  [14793] = 14215,
  [14794] = 14218,
  [14795] = 14201,
  [14796] = 14074,
  [14797] = 14236,
  [14798] = 14088,
  [14799] = 1008,
  [14800] = 14800,
  [14801] = 14088,
  [14802] = 14802,
  [14803] = 14726,
  [14804] = 14804,
  [14805] = 14805,
  [14806] = 14088,
  [14807] = 14205,
  [14808] = 14264,
  [14809] = 14205,
  [14810] = 14046,
  [14811] = 14042,
  [14812] = 14812,
  [14813] = 14088,
  [14814] = 14059,
  [14815] = 14079,
  [14816] = 14042,
  [14817] = 14030,
  [14818] = 14032,
  [14819] = 14033,
  [14820] = 14035,
  [14821] = 14416,
  [14822] = 14822,
  [14823] = 14114,
  [14824] = 14824,
  [14825] = 14078,
  [14826] = 14030,
  [14827] = 14065,
  [14828] = 14076,
  [14829] = 14114,
  [14830] = 14043,
  [14831] = 14337,
  [14832] = 14062,
  [14833] = 14036,
  [14834] = 14088,
  [14835] = 14065,
  [14836] = 14066,
  [14837] = 14136,
  [14838] = 14067,
  [14839] = 14068,
  [14840] = 14029,
  [14841] = 14045,
  [14842] = 14071,
  [14843] = 14037,
  [14844] = 14084,
  [14845] = 14845,
  [14846] = 14378,
  [14847] = 14378,
  [14848] = 14494,
  [14849] = 14309,
  [14850] = 14060,
  [14851] = 14544,
  [14852] = 14053,
  [14853] = 14102,
  [14854] = 14118,
  [14855] = 14292,
  [14856] = 14856,
  [14857] = 14247,
  [14858] = 14110,
  [14859] = 14111,
  [14860] = 14860,
  [14861] = 14861,
  [14862] = 14862,
  [14863] = 14076,
  [14864] = 14248,
  [14865] = 14181,
  [14866] = 14118,
  [14867] = 14267,
  [14868] = 14119,
  [14869] = 14123,
  [14870] = 14066,
  [14871] = 14187,
  [14872] = 14119,
  [14873] = 14188,
  [14874] = 14046,
  [14875] = 14293,
  [14876] = 14088,
  [14877] = 14092,
  [14878] = 14093,
  [14879] = 14879,
  [14880] = 14136,
  [14881] = 14094,
  [14882] = 14138,
  [14883] = 14114,
  [14884] = 14044,
  [14885] = 14064,
  [14886] = 14087,
  [14887] = 14040,
  [14888] = 14123,
  [14889] = 14106,
  [14890] = 14648,
  [14891] = 14114,
  [14892] = 14046,
  [14893] = 14161,
  [14894] = 14049,
  [14895] = 14895,
  [14896] = 14114,
  [14897] = 14494,
  [14898] = 14898,
  [14899] = 14169,
  [14900] = 14179,
  [14901] = 14901,
  [14902] = 14294,
  [14903] = 14296,
  [14904] = 14904,
  [14905] = 14088,
  [14906] = 14238,
  [14907] = 14054,
  [14908] = 14114,
  [14909] = 14238,
  [14910] = 14486,
  [14911] = 14186,
  [14912] = 14181,
  [14913] = 14646,
  [14914] = 14088,
  [14915] = 14648,
  [14916] = 14187,
  [14917] = 14188,
  [14918] = 14650,
  [14919] = 14315,
  [14920] = 14105,
  [14921] = 14320,
  [14922] = 14088,
  [14923] = 14127,
  [14924] = 14416,
  [14925] = 14162,
  [14926] = 14378,
  [14927] = 14494,
  [14928] = 14544,
  [14929] = 14929,
  [14930] = 14181,
  [14931] = 14208,
  [14932] = 14646,
  [14933] = 14215,
  [14934] = 14648,
  [14935] = 14212,
  [14936] = 14214,
  [14937] = 14650,
  [14938] = 14103,
  [14939] = 14114,
  [14940] = 14222,
  [14941] = 14224,
  [14942] = 14078,
  [14943] = 14230,
  [14944] = 14029,
  [14945] = 14128,
  [14946] = 14337,
  [14947] = 14036,
  [14948] = 14948,
  [14949] = 14240,
  [14950] = 14646,
  [14951] = 14037,
  [14952] = 14648,
  [14953] = 14146,
  [14954] = 14114,
  [14955] = 14650,
  [14956] = 14956,
  [14957] = 14957,
  [14958] = 14040,
  [14959] = 14045,
  [14960] = 14648,
  [14961] = 14071,
  [14962] = 14088,
  [14963] = 14650,
  [14964] = 14031,
  [14965] = 14114,
  [14966] = 14966,
  [14967] = 14059,
  [14968] = 14648,
  [14969] = 14650,
  [14970] = 14088,
  [14971] = 14971,
  [14972] = 14114,
  [14973] = 14650,
  [14974] = 14351,
  [14975] = 14092,
  [14976] = 14650,
  [14977] = 14038,
  [14978] = 14978,
  [14979] = 956,
  [14980] = 14159,
  [14981] = 14050,
  [14982] = 14053,
  [14983] = 14088,
  [14984] = 14267,
  [14985] = 14544,
  [14986] = 14218,
  [14987] = 14040,
  [14988] = 14114,
  [14989] = 14061,
  [14990] = 14088,
  [14991] = 14486,
  [14992] = 14992,
  [14993] = 14032,
  [14994] = 14236,
  [14995] = 14995,
  [14996] = 14996,
  [14997] = 14072,
  [14998] = 14998,
  [14999] = 14321,
  [15000] = 14031,
  [15001] = 13128,
  [15002] = 15002,
  [15003] = 15003,
  [15004] = 14238,
  [15005] = 14316,
  [15006] = 14186,
  [15007] = 14114,
  [15008] = 15008,
  [15009] = 14059,
  [15010] = 14049,
  [15011] = 14222,
  [15012] = 14179,
  [15013] = 14074,
  [15014] = 14054,
  [15015] = 15015,
  [15016] = 14054,
  [15017] = 14996,
  [15018] = 14197,
  [15019] = 14079,
  [15020] = 14208,
  [15021] = 14200,
  [15022] = 14215,
  [15023] = 14218,
  [15024] = 14236,
  [15025] = 14136,
  [15026] = 15026,
  [15027] = 15027,
  [15028] = 14088,
  [15029] = 14212,
  [15030] = 14238,
  [15031] = 15031,
  [15032] = 14238,
  [15033] = 14054,
  [15034] = 14201,
  [15035] = 14650,
  [15036] = 14214,
  [15037] = 14161,
  [15038] = 15038,
  [15039] = 14084,
  [15040] = 14059,
  [15041] = 14079,
  [15042] = 14088,
  [15043] = 14065,
  [15044] = 14267,
  [15045] = 14066,
  [15046] = 14646,
  [15047] = 14110,
  [15048] = 12422,
  [15049] = 14111,
  [15050] = 15050,
  [15051] = 14321,
  [15052] = 15052,
  [15053] = 15053,
  [15054] = 14996,
  [15055] = 14321,
  [15056] = 14247,
  [15057] = 14248,
  [15058] = 14996,
  [15059] = 14072,
  [15060] = 14321,
  [15061] = 14240,
  [15062] = 14205,
  [15063] = 14996,
  [15064] = 14146,
  [15065] = 14088,
  [15066] = 14996,
  [15067] = 15067,
  [15068] = 15068,
  [15069] = 14067,
  [15070] = 15070,
  [15071] = 14031,
  [15072] = 14092,
  [15073] = 14312,
  [15074] = 14093,
  [15075] = 14102,
  [15076] = 14049,
  [15077] = 14094,
  [15078] = 14081,
  [15079] = 14046,
  [15080] = 14138,
  [15081] = 14179,
  [15082] = 15082,
  [15083] = 15083,
  [15084] = 14114,
  [15085] = 15085,
  [15086] = 14294,
  [15087] = 14114,
  [15088] = 14074,
  [15089] = 14296,
  [15090] = 14114,
  [15091] = 15091,
  [15092] = 14328,
  [15093] = 14208,
  [15094] = 14068,
  [15095] = 15095,
  [15096] = 14059,
  [15097] = 14079,
  [15098] = 14187,
  [15099] = 14059,
  [15100] = 14281,
  [15101] = 15101,
  [15102] = 15102,
  [15103] = 14650,
  [15104] = 14486,
  [15105] = 14105,
  [15106] = 14320,
  [15107] = 14312,
  [15108] = 15108,
  [15109] = 15109,
  [15110] = 15110,
  [15111] = 15111,
  [15112] = 15112,
  [15113] = 15113,
  [15114] = 15114,
  [15115] = 15115,
  [15116] = 15116,
  [15117] = 15117,
  [15118] = 15118,
  [15119] = 15119,
  [15120] = 15120,
  [15121] = 15121,
  [15122] = 15122,
  [15123] = 15123,
  [15124] = 15124,
  [15125] = 15118,
  [15126] = 15126,
  [15127] = 15127,
  [15128] = 15128,
  [15129] = 15129,
  [15130] = 15130,
  [15131] = 15116,
  [15132] = 15132,
  [15133] = 15133,
  [15134] = 103,
  [15135] = 15135,
  [15136] = 15136,
  [15137] = 15137,
  [15138] = 15138,
  [15139] = 15139,
  [15140] = 15140,
  [15141] = 15141,
  [15142] = 15142,
  [15143] = 15143,
  [15144] = 15144,
  [15145] = 15145,
  [15146] = 15146,
  [15147] = 15147,
  [15148] = 15148,
  [15149] = 15149,
  [15150] = 15150,
  [15151] = 15151,
  [15152] = 15152,
  [15153] = 15153,
  [15154] = 15154,
  [15155] = 15155,
  [15156] = 15156,
  [15157] = 15157,
  [15158] = 15158,
  [15159] = 15159,
  [15160] = 15160,
  [15161] = 15161,
  [15162] = 15162,
  [15163] = 15163,
  [15164] = 15164,
  [15165] = 15165,
  [15166] = 15166,
  [15167] = 15167,
  [15168] = 15168,
  [15169] = 15169,
  [15170] = 15170,
  [15171] = 15171,
  [15172] = 15172,
  [15173] = 15173,
  [15174] = 15174,
  [15175] = 15175,
  [15176] = 15113,
  [15177] = 15177,
  [15178] = 15178,
  [15179] = 15179,
  [15180] = 15180,
  [15181] = 15118,
  [15182] = 15182,
  [15183] = 15183,
  [15184] = 15184,
  [15185] = 15185,
  [15186] = 15186,
  [15187] = 15187,
  [15188] = 15188,
  [15189] = 15189,
  [15190] = 15150,
  [15191] = 15191,
  [15192] = 15192,
  [15193] = 15193,
  [15194] = 15194,
  [15195] = 15195,
  [15196] = 15196,
  [15197] = 15197,
  [15198] = 15198,
  [15199] = 15199,
  [15200] = 15200,
  [15201] = 15201,
  [15202] = 15202,
  [15203] = 15203,
  [15204] = 15204,
  [15205] = 15205,
  [15206] = 15206,
  [15207] = 15207,
  [15208] = 15208,
  [15209] = 15209,
  [15210] = 15210,
  [15211] = 15211,
  [15212] = 15212,
  [15213] = 15213,
  [15214] = 15214,
  [15215] = 15215,
  [15216] = 15216,
  [15217] = 15217,
  [15218] = 15218,
  [15219] = 15219,
  [15220] = 15220,
  [15221] = 15221,
  [15222] = 15222,
  [15223] = 15223,
  [15224] = 15224,
  [15225] = 15112,
  [15226] = 15226,
  [15227] = 15227,
  [15228] = 15228,
  [15229] = 15229,
  [15230] = 15230,
  [15231] = 15231,
  [15232] = 15109,
  [15233] = 15233,
  [15234] = 15234,
  [15235] = 15235,
  [15236] = 15133,
  [15237] = 15237,
  [15238] = 15127,
  [15239] = 15135,
  [15240] = 15137,
  [15241] = 15177,
  [15242] = 15242,
  [15243] = 15179,
  [15244] = 15191,
  [15245] = 15231,
  [15246] = 15233,
  [15247] = 15247,
  [15248] = 15248,
  [15249] = 15226,
  [15250] = 15138,
  [15251] = 15136,
  [15252] = 15252,
  [15253] = 15253,
  [15254] = 15254,
  [15255] = 15255,
  [15256] = 15118,
  [15257] = 15257,
  [15258] = 15258,
  [15259] = 15259,
  [15260] = 15260,
  [15261] = 15261,
  [15262] = 15133,
  [15263] = 15263,
  [15264] = 15264,
  [15265] = 15265,
  [15266] = 15266,
  [15267] = 15267,
  [15268] = 15268,
  [15269] = 15269,
  [15270] = 15150,
  [15271] = 15271,
  [15272] = 15193,
  [15273] = 15273,
  [15274] = 15154,
  [15275] = 15155,
  [15276] = 15227,
  [15277] = 15157,
  [15278] = 15278,
  [15279] = 15279,
  [15280] = 15280,
  [15281] = 15281,
  [15282] = 15282,
  [15283] = 15149,
  [15284] = 15284,
  [15285] = 15166,
  [15286] = 15167,
  [15287] = 15168,
  [15288] = 15169,
  [15289] = 15170,
  [15290] = 15290,
  [15291] = 15172,
  [15292] = 15228,
  [15293] = 15174,
  [15294] = 15294,
  [15295] = 15295,
  [15296] = 15193,
  [15297] = 15297,
  [15298] = 15298,
  [15299] = 15299,
  [15300] = 15182,
  [15301] = 15183,
  [15302] = 15184,
  [15303] = 15185,
  [15304] = 15304,
  [15305] = 15187,
  [15306] = 15188,
  [15307] = 15189,
  [15308] = 15308,
  [15309] = 15309,
  [15310] = 15310,
  [15311] = 15253,
  [15312] = 15312,
  [15313] = 15194,
  [15314] = 15195,
  [15315] = 15196,
  [15316] = 15316,
  [15317] = 15198,
  [15318] = 15199,
  [15319] = 15319,
  [15320] = 15320,
  [15321] = 15201,
  [15322] = 15202,
  [15323] = 15203,
  [15324] = 15204,
  [15325] = 15205,
  [15326] = 15326,
  [15327] = 15207,
  [15328] = 15208,
  [15329] = 15209,
  [15330] = 15210,
  [15331] = 15211,
  [15332] = 15212,
  [15333] = 15213,
  [15334] = 15214,
  [15335] = 15215,
  [15336] = 15216,
  [15337] = 15217,
  [15338] = 15233,
  [15339] = 15339,
  [15340] = 15124,
  [15341] = 15341,
  [15342] = 15342,
  [15343] = 15343,
  [15344] = 15344,
  [15345] = 15345,
  [15346] = 15346,
  [15347] = 15219,
  [15348] = 15348,
  [15349] = 11506,
  [15350] = 15350,
  [15351] = 15113,
  [15352] = 15144,
  [15353] = 15154,
  [15354] = 15354,
  [15355] = 15320,
  [15356] = 15356,
  [15357] = 15154,
  [15358] = 15155,
  [15359] = 15359,
  [15360] = 15157,
  [15361] = 15361,
  [15362] = 15226,
  [15363] = 15363,
  [15364] = 15364,
  [15365] = 15365,
  [15366] = 15228,
  [15367] = 15367,
  [15368] = 15368,
  [15369] = 15369,
  [15370] = 15370,
  [15371] = 15371,
  [15372] = 15372,
  [15373] = 15373,
  [15374] = 15374,
  [15375] = 15375,
  [15376] = 15376,
  [15377] = 15109,
  [15378] = 15378,
  [15379] = 15379,
  [15380] = 15126,
  [15381] = 15381,
  [15382] = 15153,
  [15383] = 15160,
  [15384] = 15339,
  [15385] = 15173,
  [15386] = 15386,
  [15387] = 15312,
  [15388] = 15229,
  [15389] = 15118,
  [15390] = 15390,
  [15391] = 15391,
  [15392] = 15392,
  [15393] = 15133,
  [15394] = 15394,
  [15395] = 15395,
  [15396] = 15166,
  [15397] = 15178,
  [15398] = 15398,
  [15399] = 15167,
  [15400] = 15400,
  [15401] = 15401,
  [15402] = 15168,
  [15403] = 15169,
  [15404] = 15170,
  [15405] = 15109,
  [15406] = 15172,
  [15407] = 15407,
  [15408] = 15174,
  [15409] = 15409,
  [15410] = 15178,
  [15411] = 15411,
  [15412] = 15412,
  [15413] = 15413,
  [15414] = 15414,
  [15415] = 15415,
  [15416] = 15416,
  [15417] = 15417,
  [15418] = 15418,
  [15419] = 15118,
  [15420] = 15420,
  [15421] = 15221,
  [15422] = 15422,
  [15423] = 15423,
  [15424] = 15424,
  [15425] = 15346,
  [15426] = 15426,
  [15427] = 15427,
  [15428] = 15428,
  [15429] = 15429,
  [15430] = 15430,
  [15431] = 15118,
  [15432] = 15432,
  [15433] = 15420,
  [15434] = 15434,
  [15435] = 15435,
  [15436] = 15182,
  [15437] = 15437,
  [15438] = 15183,
  [15439] = 15439,
  [15440] = 15184,
  [15441] = 15441,
  [15442] = 15442,
  [15443] = 15185,
  [15444] = 15444,
  [15445] = 15187,
  [15446] = 15188,
  [15447] = 15189,
  [15448] = 15448,
  [15449] = 15439,
  [15450] = 15448,
  [15451] = 15451,
  [15452] = 15452,
  [15453] = 15453,
  [15454] = 15454,
  [15455] = 15455,
  [15456] = 15456,
  [15457] = 15457,
  [15458] = 15458,
  [15459] = 15459,
  [15460] = 15460,
  [15461] = 15461,
  [15462] = 15194,
  [15463] = 15463,
  [15464] = 15195,
  [15465] = 15196,
  [15466] = 15452,
  [15467] = 15198,
  [15468] = 15199,
  [15469] = 15224,
  [15470] = 15470,
  [15471] = 15471,
  [15472] = 15472,
  [15473] = 15108,
  [15474] = 15129,
  [15475] = 15475,
  [15476] = 15124,
  [15477] = 15222,
  [15478] = 15254,
  [15479] = 15479,
  [15480] = 15480,
  [15481] = 15316,
  [15482] = 15201,
  [15483] = 15202,
  [15484] = 15203,
  [15485] = 15204,
  [15486] = 15205,
  [15487] = 15133,
  [15488] = 15488,
  [15489] = 15179,
  [15490] = 15490,
  [15491] = 15491,
  [15492] = 15492,
  [15493] = 15207,
  [15494] = 15208,
  [15495] = 15209,
  [15496] = 15210,
  [15497] = 15497,
  [15498] = 15211,
  [15499] = 15212,
  [15500] = 15500,
  [15501] = 15501,
  [15502] = 15502,
  [15503] = 15503,
  [15504] = 15149,
  [15505] = 15213,
  [15506] = 15506,
  [15507] = 15214,
  [15508] = 15215,
  [15509] = 15216,
  [15510] = 15217,
  [15511] = 15511,
  [15512] = 15512,
  [15513] = 15115,
  [15514] = 15451,
  [15515] = 15515,
  [15516] = 15219,
  [15517] = 15517,
  [15518] = 15518,
  [15519] = 15138,
  [15520] = 15344,
  [15521] = 15479,
  [15522] = 15158,
  [15523] = 15523,
  [15524] = 15524,
  [15525] = 15525,
  [15526] = 15526,
  [15527] = 15527,
  [15528] = 15200,
  [15529] = 15273,
  [15530] = 15126,
  [15531] = 15278,
  [15532] = 15532,
  [15533] = 15532,
  [15534] = 15226,
  [15535] = 15280,
  [15536] = 15536,
  [15537] = 15281,
  [15538] = 15141,
  [15539] = 15142,
  [15540] = 15540,
  [15541] = 15541,
  [15542] = 15542,
  [15543] = 15228,
  [15544] = 15290,
  [15545] = 15545,
  [15546] = 15453,
  [15547] = 15547,
  [15548] = 15548,
  [15549] = 15109,
  [15550] = 15257,
  [15551] = 15344,
  [15552] = 15118,
  [15553] = 15264,
  [15554] = 15259,
  [15555] = 15113,
  [15556] = 15133,
  [15557] = 15109,
  [15558] = 15224,
  [15559] = 15559,
  [15560] = 15560,
  [15561] = 15561,
  [15562] = 15271,
  [15563] = 15156,
  [15564] = 15128,
  [15565] = 15265,
  [15566] = 15298,
  [15567] = 15567,
  [15568] = 15370,
  [15569] = 15430,
  [15570] = 15570,
  [15571] = 15523,
  [15572] = 15316,
  [15573] = 15319,
  [15574] = 15574,
  [15575] = 15575,
  [15576] = 15576,
  [15577] = 15577,
  [15578] = 15578,
  [15579] = 15109,
  [15580] = 15299,
  [15581] = 15581,
  [15582] = 15582,
  [15583] = 15116,
  [15584] = 15121,
  [15585] = 15273,
  [15586] = 15126,
  [15587] = 15587,
  [15588] = 15588,
  [15589] = 15589,
  [15590] = 15590,
  [15591] = 15124,
  [15592] = 15592,
  [15593] = 15309,
  [15594] = 15594,
  [15595] = 15595,
  [15596] = 15254,
  [15597] = 15597,
  [15598] = 15598,
  [15599] = 15144,
  [15600] = 15600,
  [15601] = 15601,
  [15602] = 15602,
  [15603] = 15603,
  [15604] = 15575,
  [15605] = 15158,
  [15606] = 15178,
  [15607] = 15607,
  [15608] = 15201,
  [15609] = 15202,
  [15610] = 15133,
  [15611] = 15253,
  [15612] = 15219,
  [15613] = 15570,
  [15614] = 15603,
  [15615] = 15230,
  [15616] = 15178,
  [15617] = 15540,
  [15618] = 13704,
  [15619] = 15153,
  [15620] = 15203,
  [15621] = 15621,
  [15622] = 15234,
  [15623] = 15312,
  [15624] = 15348,
  [15625] = 15376,
  [15626] = 15461,
  [15627] = 15257,
  [15628] = 15160,
  [15629] = 15162,
  [15630] = 15173,
  [15631] = 15390,
  [15632] = 15264,
  [15633] = 15271,
  [15634] = 15298,
  [15635] = 15299,
  [15636] = 15309,
  [15637] = 15197,
  [15638] = 15457,
  [15639] = 15595,
  [15640] = 15602,
  [15641] = 15641,
  [15642] = 15226,
  [15643] = 15643,
  [15644] = 15463,
  [15645] = 15545,
  [15646] = 15646,
  [15647] = 15118,
  [15648] = 15648,
  [15649] = 15649,
  [15650] = 102,
  [15651] = 15219,
  [15652] = 15219,
  [15653] = 15219,
  [15654] = 15420,
  [15655] = 15204,
  [15656] = 15205,
  [15657] = 15150,
  [15658] = 15658,
  [15659] = 15193,
  [15660] = 15660,
  [15661] = 15661,
  [15662] = 15138,
  [15663] = 15141,
  [15664] = 15142,
  [15665] = 15235,
  [15666] = 15666,
  [15667] = 15454,
  [15668] = 15226,
  [15669] = 15228,
  [15670] = 15670,
  [15671] = 15219,
  [15672] = 15455,
  [15673] = 15576,
  [15674] = 15219,
  [15675] = 15237,
  [15676] = 15156,
  [15677] = 15677,
  [15678] = 15265,
  [15679] = 15370,
  [15680] = 15430,
  [15681] = 15681,
  [15682] = 15641,
  [15683] = 15523,
  [15684] = 15575,
  [15685] = 15158,
  [15686] = 15576,
  [15687] = 15578,
  [15688] = 15582,
  [15689] = 15689,
  [15690] = 15690,
  [15691] = 15121,
  [15692] = 15588,
  [15693] = 15109,
  [15694] = 15694,
  [15695] = 15367,
  [15696] = 15696,
  [15697] = 15197,
  [15698] = 15182,
  [15699] = 15699,
  [15700] = 15218,
  [15701] = 15220,
  [15702] = 15112,
  [15703] = 15592,
  [15704] = 15115,
  [15705] = 15227,
  [15706] = 15603,
  [15707] = 15229,
  [15708] = 15230,
  [15709] = 15234,
  [15710] = 15235,
  [15711] = 15320,
  [15712] = 15712,
  [15713] = 15136,
  [15714] = 15154,
  [15715] = 15124,
  [15716] = 15118,
  [15717] = 15155,
  [15718] = 15237,
  [15719] = 15127,
  [15720] = 15135,
  [15721] = 15137,
  [15722] = 15157,
  [15723] = 15177,
  [15724] = 15412,
  [15725] = 15444,
  [15726] = 15179,
  [15727] = 15191,
  [15728] = 15457,
  [15729] = 15231,
  [15730] = 15512,
  [15731] = 15731,
  [15732] = 15547,
  [15733] = 15233,
  [15734] = 15463,
  [15735] = 15273,
  [15736] = 15226,
  [15737] = 15278,
  [15738] = 15364,
  [15739] = 15191,
  [15740] = 15488,
  [15741] = 15280,
  [15742] = 15281,
  [15743] = 15490,
  [15744] = 15365,
  [15745] = 15290,
  [15746] = 15595,
  [15747] = 15367,
  [15748] = 15369,
  [15749] = 15133,
  [15750] = 15750,
  [15751] = 15231,
  [15752] = 15752,
  [15753] = 15316,
  [15754] = 15319,
  [15755] = 15253,
  [15756] = 15371,
  [15757] = 15373,
  [15758] = 15375,
  [15759] = 15197,
  [15760] = 15218,
  [15761] = 15175,
  [15762] = 15681,
  [15763] = 15763,
  [15764] = 15228,
  [15765] = 15220,
  [15766] = 15112,
  [15767] = 15491,
  [15768] = 15227,
  [15769] = 15769,
  [15770] = 15229,
  [15771] = 15230,
  [15772] = 15234,
  [15773] = 15235,
  [15774] = 15237,
  [15775] = 15775,
  [15776] = 15127,
  [15777] = 15602,
  [15778] = 15226,
  [15779] = 15779,
  [15780] = 15780,
  [15781] = 15135,
  [15782] = 15113,
  [15783] = 15115,
  [15784] = 15784,
  [15785] = 15126,
  [15786] = 15137,
  [15787] = 15779,
  [15788] = 15339,
  [15789] = 15320,
  [15790] = 15177,
  [15791] = 15791,
  [15792] = 15154,
  [15793] = 15155,
  [15794] = 15149,
  [15795] = 15157,
  [15796] = 15796,
  [15797] = 15200,
  [15798] = 15364,
  [15799] = 15179,
  [15800] = 15592,
  [15801] = 15801,
  [15802] = 15191,
  [15803] = 15603,
  [15804] = 15133,
  [15805] = 15365,
  [15806] = 15109,
  [15807] = 15367,
  [15808] = 15661,
  [15809] = 15231,
  [15810] = 15369,
  [15811] = 15811,
  [15812] = 15371,
  [15813] = 15373,
  [15814] = 15375,
  [15815] = 15259,
  [15816] = 15457,
  [15817] = 15578,
  [15818] = 15348,
  [15819] = 15339,
  [15820] = 15820,
  [15821] = 15821,
  [15822] = 15463,
  [15823] = 15155,
  [15824] = 15824,
  [15825] = 15825,
  [15826] = 15826,
  [15827] = 15233,
  [15828] = 15828,
  [15829] = 117,
  [15830] = 15175,
  [15831] = 15831,
  [15832] = 15376,
  [15833] = 15166,
  [15834] = 15834,
  [15835] = 15826,
  [15836] = 15167,
  [15837] = 15457,
  [15838] = 15401,
  [15839] = 15168,
  [15840] = 15169,
  [15841] = 15170,
  [15842] = 15312,
  [15843] = 15348,
  [15844] = 15376,
  [15845] = 15461,
  [15846] = 15257,
  [15847] = 15264,
  [15848] = 15848,
  [15849] = 15172,
  [15850] = 15271,
  [15851] = 15298,
  [15852] = 15299,
  [15853] = 15309,
  [15854] = 15595,
  [15855] = 15602,
  [15856] = 15856,
  [15857] = 15174,
  [15858] = 15409,
  [15859] = 15859,
  [15860] = 15411,
  [15861] = 15861,
  [15862] = 15413,
  [15863] = 15414,
  [15864] = 15415,
  [15865] = 15416,
  [15866] = 15166,
  [15867] = 15417,
  [15868] = 15418,
  [15869] = 15869,
  [15870] = 15870,
  [15871] = 15461,
  [15872] = 15459,
  [15873] = 15219,
  [15874] = 15253,
  [15875] = 15661,
  [15876] = 15876,
  [15877] = 15221,
  [15878] = 15878,
  [15879] = 15879,
  [15880] = 15880,
  [15881] = 15167,
  [15882] = 15592,
  [15883] = 15883,
  [15884] = 15884,
  [15885] = 15219,
  [15886] = 15603,
  [15887] = 15887,
  [15888] = 15401,
  [15889] = 15681,
  [15890] = 15183,
  [15891] = 15641,
  [15892] = 15892,
  [15893] = 15257,
  [15894] = 15894,
  [15895] = 15166,
  [15896] = 15219,
  [15897] = 15182,
  [15898] = 15183,
  [15899] = 15167,
  [15900] = 15168,
  [15901] = 15184,
  [15902] = 15185,
  [15903] = 15401,
  [15904] = 15904,
  [15905] = 15187,
  [15906] = 15188,
  [15907] = 15189,
  [15908] = 15168,
  [15909] = 15439,
  [15910] = 15169,
  [15911] = 15448,
  [15912] = 15451,
  [15913] = 15453,
  [15914] = 15454,
  [15915] = 15170,
  [15916] = 15455,
  [15917] = 15172,
  [15918] = 15278,
  [15919] = 15169,
  [15920] = 15170,
  [15921] = 15458,
  [15922] = 15459,
  [15923] = 15174,
  [15924] = 15136,
  [15925] = 15925,
  [15926] = 15926,
  [15927] = 15194,
  [15928] = 15928,
  [15929] = 15195,
  [15930] = 15930,
  [15931] = 15196,
  [15932] = 15412,
  [15933] = 15172,
  [15934] = 15444,
  [15935] = 15512,
  [15936] = 15547,
  [15937] = 15198,
  [15938] = 15492,
  [15939] = 15939,
  [15940] = 15199,
  [15941] = 15470,
  [15942] = 15471,
  [15943] = 15472,
  [15944] = 15108,
  [15945] = 15129,
  [15946] = 15175,
  [15947] = 15947,
  [15948] = 15948,
  [15949] = 15226,
  [15950] = 15280,
  [15951] = 15951,
  [15952] = 15115,
  [15953] = 15222,
  [15954] = 15479,
  [15955] = 15174,
  [15956] = 15956,
  [15957] = 15201,
  [15958] = 15202,
  [15959] = 15203,
  [15960] = 15204,
  [15961] = 15205,
  [15962] = 15488,
  [15963] = 15490,
  [15964] = 15491,
  [15965] = 15965,
  [15966] = 15492,
  [15967] = 15967,
  [15968] = 15461,
  [15969] = 15208,
  [15970] = 15970,
  [15971] = 15209,
  [15972] = 15210,
  [15973] = 15175,
  [15974] = 15211,
  [15975] = 15212,
  [15976] = 15500,
  [15977] = 15977,
  [15978] = 15501,
  [15979] = 15213,
  [15980] = 15214,
  [15981] = 15215,
  [15982] = 15216,
  [15983] = 15217,
  [15984] = 15984,
  [15985] = 15409,
  [15986] = 15411,
  [15987] = 15987,
  [15988] = 15219,
  [15989] = 15264,
  [15990] = 15271,
  [15991] = 15991,
  [15992] = 15413,
  [15993] = 15414,
  [15994] = 15994,
  [15995] = 15415,
  [15996] = 15416,
  [15997] = 15997,
  [15998] = 15144,
  [15999] = 15417,
  [16000] = 15298,
  [16001] = 15418,
  [16002] = 16002,
  [16003] = 15299,
  [16004] = 15228,
  [16005] = 15127,
  [16006] = 16006,
  [16007] = 15226,
  [16008] = 15228,
  [16009] = 16009,
  [16010] = 15178,
  [16011] = 16011,
  [16012] = 15540,
  [16013] = 15221,
  [16014] = 16014,
  [16015] = 15268,
  [16016] = 15452,
  [16017] = 15369,
  [16018] = 16018,
  [16019] = 15135,
  [16020] = 15309,
  [16021] = 15109,
  [16022] = 15228,
  [16023] = 16023,
  [16024] = 16024,
  [16025] = 16025,
  [16026] = 16026,
  [16027] = 16027,
  [16028] = 15118,
  [16029] = 15226,
  [16030] = 16030,
  [16031] = 15116,
  [16032] = 15175,
  [16033] = 16033,
  [16034] = 15371,
  [16035] = 15661,
  [16036] = 11415,
  [16037] = 15666,
  [16038] = 16038,
  [16039] = 16039,
  [16040] = 15184,
  [16041] = 15113,
  [16042] = 16042,
  [16043] = 16043,
  [16044] = 15661,
  [16045] = 16045,
  [16046] = 15409,
  [16047] = 15452,
  [16048] = 16048,
  [16049] = 15226,
  [16050] = 15218,
  [16051] = 15126,
  [16052] = 15532,
  [16053] = 16053,
  [16054] = 15281,
  [16055] = 16055,
  [16056] = 15116,
  [16057] = 15182,
  [16058] = 15595,
  [16059] = 15183,
  [16060] = 15220,
  [16061] = 15184,
  [16062] = 16062,
  [16063] = 15602,
  [16064] = 15137,
  [16065] = 15290,
  [16066] = 16066,
  [16067] = 15344,
  [16068] = 15185,
  [16069] = 15109,
  [16070] = 15297,
  [16071] = 16071,
  [16072] = 5297,
  [16073] = 16073,
  [16074] = 16074,
  [16075] = 15187,
  [16076] = 15344,
  [16077] = 15153,
  [16078] = 15160,
  [16079] = 16079,
  [16080] = 16080,
  [16081] = 15188,
  [16082] = 15109,
  [16083] = 16083,
  [16084] = 15189,
  [16085] = 15162,
  [16086] = 15173,
  [16087] = 16087,
  [16088] = 16088,
  [16089] = 16089,
  [16090] = 16090,
  [16091] = 16091,
  [16092] = 16092,
  [16093] = 16093,
  [16094] = 15439,
  [16095] = 16095,
  [16096] = 15779,
  [16097] = 15779,
  [16098] = 15411,
  [16099] = 16099,
  [16100] = 15448,
  [16101] = 15150,
  [16102] = 15413,
  [16103] = 15779,
  [16104] = 15451,
  [16105] = 16105,
  [16106] = 16106,
  [16107] = 15193,
  [16108] = 15390,
  [16109] = 15453,
  [16110] = 15454,
  [16111] = 15455,
  [16112] = 15681,
  [16113] = 15670,
  [16114] = 15224,
  [16115] = 15414,
  [16116] = 15458,
  [16117] = 15207,
  [16118] = 15208,
  [16119] = 15209,
  [16120] = 15373,
  [16121] = 15219,
  [16122] = 15210,
  [16123] = 15211,
  [16124] = 15153,
  [16125] = 15212,
  [16126] = 15415,
  [16127] = 15224,
  [16128] = 16128,
  [16129] = 15160,
  [16130] = 16130,
  [16131] = 15540,
  [16132] = 15532,
  [16133] = 15185,
  [16134] = 15254,
  [16135] = 15459,
  [16136] = 15177,
  [16137] = 16137,
  [16138] = 15162,
  [16139] = 15364,
  [16140] = 15228,
  [16141] = 15173,
  [16142] = 16014,
  [16143] = 15500,
  [16144] = 15226,
  [16145] = 16145,
  [16146] = 16146,
  [16147] = 15194,
  [16148] = 15195,
  [16149] = 15196,
  [16150] = 15390,
  [16151] = 15228,
  [16152] = 15198,
  [16153] = 16153,
  [16154] = 15199,
  [16155] = 15470,
  [16156] = 15471,
  [16157] = 15511,
  [16158] = 15472,
  [16159] = 15108,
  [16160] = 15501,
  [16161] = 15365,
  [16162] = 15129,
  [16163] = 15197,
  [16164] = 15222,
  [16165] = 16165,
  [16166] = 15545,
  [16167] = 16167,
  [16168] = 15109,
  [16169] = 15641,
  [16170] = 16170,
  [16171] = 15178,
  [16172] = 16172,
  [16173] = 15118,
  [16174] = 15479,
  [16175] = 16175,
  [16176] = 15273,
  [16177] = 16177,
  [16178] = 15278,
  [16179] = 15133,
  [16180] = 15280,
  [16181] = 15281,
  [16182] = 15109,
  [16183] = 15290,
  [16184] = 15144,
  [16185] = 15201,
  [16186] = 15202,
  [16187] = 15203,
  [16188] = 15228,
  [16189] = 15316,
  [16190] = 15319,
  [16191] = 15204,
  [16192] = 15205,
  [16193] = 15488,
  [16194] = 15490,
  [16195] = 15491,
  [16196] = 15492,
  [16197] = 15157,
  [16198] = 15412,
  [16199] = 15156,
  [16200] = 15265,
  [16201] = 15370,
  [16202] = 15430,
  [16203] = 15416,
  [16204] = 16204,
  [16205] = 15417,
  [16206] = 15112,
  [16207] = 15207,
  [16208] = 15208,
  [16209] = 15224,
  [16210] = 15209,
  [16211] = 16211,
  [16212] = 16212,
  [16213] = 15210,
  [16214] = 16214,
  [16215] = 15320,
  [16216] = 15154,
  [16217] = 15155,
  [16218] = 15157,
  [16219] = 15211,
  [16220] = 15364,
  [16221] = 15365,
  [16222] = 15212,
  [16223] = 15367,
  [16224] = 15369,
  [16225] = 15500,
  [16226] = 15371,
  [16227] = 15373,
  [16228] = 15375,
  [16229] = 15501,
  [16230] = 15523,
  [16231] = 15575,
  [16232] = 15339,
  [16233] = 16233,
  [16234] = 15576,
  [16235] = 15578,
  [16236] = 15213,
  [16237] = 15214,
  [16238] = 15215,
  [16239] = 16239,
  [16240] = 15166,
  [16241] = 15216,
  [16242] = 15167,
  [16243] = 16243,
  [16244] = 15401,
  [16245] = 15168,
  [16246] = 15169,
  [16247] = 15170,
  [16248] = 15172,
  [16249] = 15582,
  [16250] = 15174,
  [16251] = 15409,
  [16252] = 15411,
  [16253] = 16253,
  [16254] = 16254,
  [16255] = 12333,
  [16256] = 15413,
  [16257] = 15414,
  [16258] = 15415,
  [16259] = 15416,
  [16260] = 15417,
  [16261] = 15418,
  [16262] = 15217,
  [16263] = 15187,
  [16264] = 15221,
  [16265] = 15188,
  [16266] = 16266,
  [16267] = 15228,
  [16268] = 15224,
  [16269] = 15227,
  [16270] = 15218,
  [16271] = 16271,
  [16272] = 16272,
  [16273] = 15182,
  [16274] = 15183,
  [16275] = 15133,
  [16276] = 15184,
  [16277] = 15185,
  [16278] = 15219,
  [16279] = 15187,
  [16280] = 15188,
  [16281] = 15189,
  [16282] = 15121,
  [16283] = 15439,
  [16284] = 15448,
  [16285] = 15451,
  [16286] = 15213,
  [16287] = 15453,
  [16288] = 15214,
  [16289] = 15215,
  [16290] = 15216,
  [16291] = 15454,
  [16292] = 15455,
  [16293] = 15444,
  [16294] = 16294,
  [16295] = 16295,
  [16296] = 15458,
  [16297] = 15459,
  [16298] = 16298,
  [16299] = 15194,
  [16300] = 15195,
  [16301] = 15196,
  [16302] = 16302,
  [16303] = 15198,
  [16304] = 15199,
  [16305] = 16305,
  [16306] = 15470,
  [16307] = 15471,
  [16308] = 15472,
  [16309] = 16309,
  [16310] = 15129,
  [16311] = 15588,
  [16312] = 15222,
  [16313] = 15479,
  [16314] = 16314,
  [16315] = 16315,
  [16316] = 15592,
  [16317] = 15201,
  [16318] = 16318,
  [16319] = 15202,
  [16320] = 15203,
  [16321] = 15204,
  [16322] = 15205,
  [16323] = 15488,
  [16324] = 15490,
  [16325] = 15491,
  [16326] = 15492,
  [16327] = 15207,
  [16328] = 15208,
  [16329] = 15209,
  [16330] = 15210,
  [16331] = 15211,
  [16332] = 16332,
  [16333] = 15212,
  [16334] = 15500,
  [16335] = 15501,
  [16336] = 15213,
  [16337] = 15214,
  [16338] = 15215,
  [16339] = 16339,
  [16340] = 15216,
  [16341] = 15217,
  [16342] = 15582,
  [16343] = 16343,
  [16344] = 16344,
  [16345] = 16345,
  [16346] = 16090,
  [16347] = 15967,
  [16348] = 15138,
  [16349] = 15194,
  [16350] = 15226,
  [16351] = 15228,
  [16352] = 15133,
  [16353] = 15124,
  [16354] = 15109,
  [16355] = 15200,
  [16356] = 15689,
  [16357] = 16357,
  [16358] = 16358,
  [16359] = 16359,
  [16360] = 16014,
  [16361] = 15268,
  [16362] = 15458,
  [16363] = 15512,
  [16364] = 16364,
  [16365] = 15116,
  [16366] = 15195,
  [16367] = 15196,
  [16368] = 15690,
  [16369] = 16369,
  [16370] = 15198,
  [16371] = 15199,
  [16372] = 16372,
  [16373] = 16373,
  [16374] = 16025,
  [16375] = 16375,
  [16376] = 15229,
  [16377] = 16377,
  [16378] = 15189,
  [16379] = 16379,
  [16380] = 15930,
  [16381] = 16381,
  [16382] = 16382,
  [16383] = 16014,
  [16384] = 15268,
  [16385] = 15150,
  [16386] = 15144,
  [16387] = 15193,
  [16388] = 12455,
  [16389] = 16389,
  [16390] = 16390,
  [16391] = 15319,
  [16392] = 16392,
  [16393] = 16393,
  [16394] = 15200,
  [16395] = 16395,
  [16396] = 15344,
  [16397] = 16397,
  [16398] = 15109,
  [16399] = 12421,
  [16400] = 16400,
  [16401] = 16401,
  [16402] = 15149,
  [16403] = 16403,
  [16404] = 16014,
  [16405] = 15268,
  [16406] = 16406,
  [16407] = 15178,
  [16408] = 15452,
  [16409] = 15420,
  [16410] = 15136,
  [16411] = 16411,
  [16412] = 16412,
  [16413] = 15118,
  [16414] = 15420,
  [16415] = 16415,
  [16416] = 16416,
  [16417] = 16417,
  [16418] = 15230,
  [16419] = 16014,
  [16420] = 15268,
  [16421] = 15681,
  [16422] = 16422,
  [16423] = 16423,
  [16424] = 15641,
  [16425] = 15452,
  [16426] = 16006,
  [16427] = 15278,
  [16428] = 16428,
  [16429] = 16014,
  [16430] = 15268,
  [16431] = 15280,
  [16432] = 15375,
  [16433] = 15281,
  [16434] = 16434,
  [16435] = 15290,
  [16436] = 16014,
  [16437] = 15268,
  [16438] = 16438,
  [16439] = 15463,
  [16440] = 15681,
  [16441] = 16441,
  [16442] = 15418,
  [16443] = 16014,
  [16444] = 15268,
  [16445] = 15121,
  [16446] = 15153,
  [16447] = 15224,
  [16448] = 15588,
  [16449] = 15160,
  [16450] = 15412,
  [16451] = 15254,
  [16452] = 16452,
  [16453] = 11625,
  [16454] = 15444,
  [16455] = 16455,
  [16456] = 16456,
  [16457] = 15154,
  [16458] = 15155,
  [16459] = 16459,
  [16460] = 15157,
  [16461] = 15779,
  [16462] = 15133,
  [16463] = 15641,
  [16464] = 16464,
  [16465] = 15162,
  [16466] = 15367,
  [16467] = 15369,
  [16468] = 15141,
  [16469] = 16469,
  [16470] = 15173,
  [16471] = 15371,
  [16472] = 15373,
  [16473] = 15375,
  [16474] = 16014,
  [16475] = 15268,
  [16476] = 16476,
  [16477] = 15142,
  [16478] = 15512,
  [16479] = 16479,
  [16480] = 15339,
  [16481] = 15390,
  [16482] = 16482,
  [16483] = 15547,
  [16484] = 15547,
  [16485] = 16485,
  [16486] = 15166,
  [16487] = 15167,
  [16488] = 15168,
  [16489] = 15169,
  [16490] = 15170,
  [16491] = 15217,
  [16492] = 15259,
  [16493] = 15234,
  [16494] = 15172,
  [16495] = 16495,
  [16496] = 15174,
  [16497] = 15411,
  [16498] = 16498,
  [16499] = 15413,
  [16500] = 15414,
  [16501] = 15415,
  [16502] = 15416,
  [16503] = 15417,
  [16504] = 15418,
  [16505] = 16505,
  [16506] = 16506,
  [16507] = 16507,
  [16508] = 15233,
  [16509] = 16509,
  [16510] = 15221,
  [16511] = 15228,
  [16512] = 16512,
  [16513] = 15235,
  [16514] = 15532,
  [16515] = 16515,
  [16516] = 16516,
  [16517] = 16517,
  [16518] = 15182,
  [16519] = 15183,
  [16520] = 15540,
  [16521] = 15184,
  [16522] = 15185,
  [16523] = 15219,
  [16524] = 15187,
  [16525] = 15545,
  [16526] = 16526,
  [16527] = 15188,
  [16528] = 15189,
  [16529] = 15545,
  [16530] = 16530,
  [16531] = 16531,
  [16532] = 15439,
  [16533] = 15448,
  [16534] = 15451,
  [16535] = 15453,
  [16536] = 15156,
  [16537] = 15265,
  [16538] = 15370,
  [16539] = 15430,
  [16540] = 15523,
  [16541] = 15575,
  [16542] = 15576,
  [16543] = 15578,
  [16544] = 15582,
  [16545] = 15454,
  [16546] = 15121,
  [16547] = 15455,
  [16548] = 15588,
  [16549] = 15540,
  [16550] = 15124,
  [16551] = 15470,
  [16552] = 15458,
  [16553] = 15459,
  [16554] = 15471,
  [16555] = 16555,
  [16556] = 16556,
  [16557] = 15194,
  [16558] = 15195,
  [16559] = 15196,
  [16560] = 16560,
  [16561] = 15198,
  [16562] = 15199,
  [16563] = 15470,
  [16564] = 15471,
  [16565] = 15472,
  [16566] = 15108,
  [16567] = 15129,
  [16568] = 15220,
  [16569] = 16506,
  [16570] = 15222,
  [16571] = 15479,
  [16572] = 16572,
  [16573] = 15201,
  [16574] = 15202,
  [16575] = 16575,
  [16576] = 15144,
  [16577] = 16577,
  [16578] = 16578,
  [16579] = 15203,
  [16580] = 15204,
  [16581] = 15205,
  [16582] = 16088,
  [16583] = 15488,
  [16584] = 15490,
  [16585] = 16585,
  [16586] = 15491,
  [16587] = 15153,
  [16588] = 15160,
  [16589] = 15162,
  [16590] = 15173,
  [16591] = 15492,
  [16592] = 15390,
  [16593] = 15149,
  [16594] = 15207,
  [16595] = 15208,
  [16596] = 15209,
  [16597] = 15210,
  [16598] = 15211,
  [16599] = 15212,
  [16600] = 15500,
  [16601] = 15501,
  [16602] = 15213,
  [16603] = 15214,
  [16604] = 15215,
  [16605] = 15138,
  [16606] = 15141,
  [16607] = 15142,
  [16608] = 15216,
  [16609] = 15217,
  [16610] = 16610,
  [16611] = 16611,
  [16612] = 16612,
  [16613] = 15237,
  [16614] = 15226,
  [16615] = 15472,
  [16616] = 16616,
  [16617] = 15108,
  [16618] = 16618,
  [16619] = 16619,
  [16620] = 15312,
  [16621] = 15348,
  [16622] = 15376,
  [16623] = 16623,
  [16624] = 15259,
  [16625] = 15158,
  [16626] = 15228,
  [16627] = 15226,
  [16628] = 16628,
  [16629] = 16629,
  [16630] = 15207,
  [16631] = 16631,
  [16632] = 16632,
  [16633] = 16633,
  [16634] = 16634,
  [16635] = 16635,
  [16636] = 16636,
  [16637] = 16637,
  [16638] = 16638,
  [16639] = 16639,
  [16640] = 16640,
  [16641] = 16641,
  [16642] = 16642,
  [16643] = 16643,
  [16644] = 16644,
  [16645] = 16645,
  [16646] = 16646,
  [16647] = 16647,
  [16648] = 16648,
  [16649] = 16649,
  [16650] = 16650,
  [16651] = 16651,
  [16652] = 16652,
  [16653] = 16653,
  [16654] = 16654,
  [16655] = 16655,
  [16656] = 16656,
  [16657] = 16657,
  [16658] = 16658,
  [16659] = 16659,
  [16660] = 16660,
  [16661] = 16661,
  [16662] = 16662,
  [16663] = 16663,
  [16664] = 16664,
  [16665] = 16665,
  [16666] = 16666,
  [16667] = 16667,
  [16668] = 16668,
  [16669] = 16669,
  [16670] = 16670,
  [16671] = 16671,
  [16672] = 16672,
  [16673] = 16663,
  [16674] = 16674,
  [16675] = 16675,
  [16676] = 16676,
  [16677] = 16677,
  [16678] = 16678,
  [16679] = 16667,
  [16680] = 16680,
  [16681] = 16681,
  [16682] = 16682,
  [16683] = 16683,
  [16684] = 16684,
  [16685] = 16685,
  [16686] = 16686,
  [16687] = 16687,
  [16688] = 16688,
  [16689] = 16642,
  [16690] = 16631,
  [16691] = 16691,
  [16692] = 16692,
  [16693] = 16693,
  [16694] = 16694,
  [16695] = 16695,
  [16696] = 16645,
  [16697] = 16697,
  [16698] = 16698,
  [16699] = 16671,
  [16700] = 16700,
  [16701] = 16701,
  [16702] = 16702,
  [16703] = 16698,
  [16704] = 16704,
  [16705] = 16705,
  [16706] = 16706,
  [16707] = 16707,
  [16708] = 16708,
  [16709] = 16709,
  [16710] = 16710,
  [16711] = 16711,
  [16712] = 16712,
  [16713] = 16713,
  [16714] = 16714,
  [16715] = 16715,
  [16716] = 16716,
  [16717] = 16650,
  [16718] = 16718,
  [16719] = 16719,
  [16720] = 16720,
  [16721] = 16716,
  [16722] = 16722,
  [16723] = 16723,
  [16724] = 16724,
  [16725] = 16725,
  [16726] = 16632,
  [16727] = 16727,
  [16728] = 16636,
  [16729] = 16729,
  [16730] = 16643,
  [16731] = 16645,
  [16732] = 16646,
  [16733] = 16733,
  [16734] = 16649,
  [16735] = 16719,
  [16736] = 16736,
  [16737] = 16655,
  [16738] = 16738,
  [16739] = 16739,
  [16740] = 16740,
  [16741] = 16724,
  [16742] = 16742,
  [16743] = 16743,
  [16744] = 16744,
  [16745] = 16662,
  [16746] = 16739,
  [16747] = 16665,
  [16748] = 16668,
  [16749] = 16749,
  [16750] = 16750,
  [16751] = 16751,
  [16752] = 16650,
  [16753] = 16653,
  [16754] = 16754,
  [16755] = 16755,
  [16756] = 16756,
  [16757] = 16646,
  [16758] = 16678,
  [16759] = 16642,
  [16760] = 16650,
  [16761] = 16667,
  [16762] = 16669,
  [16763] = 16763,
  [16764] = 16633,
  [16765] = 16765,
  [16766] = 16683,
  [16767] = 16685,
  [16768] = 16712,
  [16769] = 16686,
  [16770] = 16688,
  [16771] = 16695,
  [16772] = 16772,
  [16773] = 16773,
  [16774] = 16631,
  [16775] = 16775,
  [16776] = 16776,
  [16777] = 16777,
  [16778] = 16643,
  [16779] = 16704,
  [16780] = 16650,
  [16781] = 16653,
  [16782] = 16782,
  [16783] = 16716,
  [16784] = 16716,
  [16785] = 16633,
  [16786] = 16653,
  [16787] = 16707,
  [16788] = 16708,
  [16789] = 16789,
  [16790] = 16713,
  [16791] = 16791,
  [16792] = 16714,
  [16793] = 16715,
  [16794] = 16720,
  [16795] = 16795,
  [16796] = 16636,
  [16797] = 16654,
  [16798] = 16798,
  [16799] = 16643,
  [16800] = 16645,
  [16801] = 16646,
  [16802] = 16649,
  [16803] = 16724,
  [16804] = 16804,
  [16805] = 16739,
  [16806] = 16739,
  [16807] = 16807,
  [16808] = 16662,
  [16809] = 16665,
  [16810] = 16650,
  [16811] = 16668,
  [16812] = 16653,
  [16813] = 16813,
  [16814] = 16814,
  [16815] = 16815,
  [16816] = 16678,
  [16817] = 16669,
  [16818] = 16667,
  [16819] = 16819,
  [16820] = 16820,
  [16821] = 16821,
  [16822] = 16683,
  [16823] = 16823,
  [16824] = 16685,
  [16825] = 16686,
  [16826] = 16688,
  [16827] = 16695,
  [16828] = 16828,
  [16829] = 16829,
  [16830] = 16830,
  [16831] = 16669,
  [16832] = 16631,
  [16833] = 16804,
  [16834] = 16719,
  [16835] = 16724,
  [16836] = 16836,
  [16837] = 16650,
  [16838] = 16838,
  [16839] = 16683,
  [16840] = 16636,
  [16841] = 16643,
  [16842] = 16842,
  [16843] = 16843,
  [16844] = 16724,
  [16845] = 16683,
  [16846] = 16665,
  [16847] = 16687,
  [16848] = 16650,
  [16849] = 16849,
  [16850] = 16850,
  [16851] = 16851,
  [16852] = 16688,
  [16853] = 16853,
  [16854] = 16705,
  [16855] = 16685,
  [16856] = 16856,
  [16857] = 16724,
  [16858] = 16650,
  [16859] = 16773,
  [16860] = 16860,
  [16861] = 16861,
  [16862] = 16695,
  [16863] = 16863,
  [16864] = 16686,
  [16865] = 16865,
  [16866] = 14543,
  [16867] = 16867,
  [16868] = 16868,
  [16869] = 16869,
  [16870] = 16724,
  [16871] = 16636,
  [16872] = 16643,
  [16873] = 16650,
  [16874] = 16874,
  [16875] = 16669,
  [16876] = 16876,
  [16877] = 16665,
  [16878] = 16878,
  [16879] = 16879,
  [16880] = 16880,
  [16881] = 16881,
  [16882] = 16882,
  [16883] = 16724,
  [16884] = 16884,
  [16885] = 16650,
  [16886] = 16886,
  [16887] = 16671,
  [16888] = 16888,
  [16889] = 16889,
  [16890] = 16890,
  [16891] = 16891,
  [16892] = 16724,
  [16893] = 16704,
  [16894] = 16894,
  [16895] = 16836,
  [16896] = 16650,
  [16897] = 16643,
  [16898] = 16665,
  [16899] = 16671,
  [16900] = 16643,
  [16901] = 16901,
  [16902] = 16902,
  [16903] = 16903,
  [16904] = 16904,
  [16905] = 16665,
  [16906] = 16724,
  [16907] = 16643,
  [16908] = 16908,
  [16909] = 16909,
  [16910] = 16910,
  [16911] = 16665,
  [16912] = 16650,
  [16913] = 16913,
  [16914] = 16643,
  [16915] = 16915,
  [16916] = 16724,
  [16917] = 16773,
  [16918] = 16665,
  [16919] = 16919,
  [16920] = 16920,
  [16921] = 16921,
  [16922] = 16683,
  [16923] = 16643,
  [16924] = 16924,
  [16925] = 16925,
  [16926] = 16729,
  [16927] = 16927,
  [16928] = 16665,
  [16929] = 16929,
  [16930] = 16930,
  [16931] = 16931,
  [16932] = 16932,
  [16933] = 16933,
  [16934] = 16643,
  [16935] = 16935,
  [16936] = 16665,
  [16937] = 16937,
  [16938] = 16938,
  [16939] = 16643,
  [16940] = 16739,
  [16941] = 16941,
  [16942] = 16942,
  [16943] = 16943,
  [16944] = 16944,
  [16945] = 16665,
  [16946] = 16643,
  [16947] = 16947,
  [16948] = 16643,
  [16949] = 16949,
  [16950] = 16643,
  [16951] = 16951,
  [16952] = 16643,
  [16953] = 16953,
  [16954] = 16643,
  [16955] = 16643,
  [16956] = 16716,
  [16957] = 16643,
  [16958] = 16643,
  [16959] = 16643,
  [16960] = 16643,
  [16961] = 16961,
  [16962] = 16962,
  [16963] = 16963,
  [16964] = 16964,
  [16965] = 16965,
  [16966] = 16966,
  [16967] = 16659,
  [16968] = 16968,
  [16969] = 16969,
  [16970] = 16970,
  [16971] = 16971,
  [16972] = 16705,
  [16973] = 16973,
  [16974] = 16698,
  [16975] = 16707,
  [16976] = 16708,
  [16977] = 16633,
  [16978] = 16978,
  [16979] = 16979,
  [16980] = 16980,
  [16981] = 16981,
  [16982] = 16982,
  [16983] = 16713,
  [16984] = 16984,
  [16985] = 16985,
  [16986] = 16986,
  [16987] = 16842,
  [16988] = 16988,
  [16989] = 16989,
  [16990] = 16990,
  [16991] = 16712,
  [16992] = 16894,
  [16993] = 16993,
  [16994] = 16714,
  [16995] = 16715,
  [16996] = 16720,
  [16997] = 16716,
  [16998] = 16998,
  [16999] = 16999,
  [17000] = 16720,
  [17001] = 17001,
  [17002] = 17002,
  [17003] = 17003,
  [17004] = 16653,
  [17005] = 17005,
  [17006] = 16719,
  [17007] = 16632,
  [17008] = 16688,
  [17009] = 16642,
  [17010] = 16636,
  [17011] = 17011,
  [17012] = 17012,
  [17013] = 17013,
  [17014] = 16773,
  [17015] = 17015,
  [17016] = 17016,
  [17017] = 17017,
  [17018] = 16654,
  [17019] = 17019,
  [17020] = 17020,
  [17021] = 16979,
  [17022] = 17022,
  [17023] = 16643,
  [17024] = 17024,
  [17025] = 16645,
  [17026] = 16633,
  [17027] = 16646,
  [17028] = 16649,
  [17029] = 16643,
  [17030] = 16643,
  [17031] = 16643,
  [17032] = 17032,
  [17033] = 16654,
  [17034] = 16963,
  [17035] = 16964,
  [17036] = 16965,
  [17037] = 16966,
  [17038] = 17038,
  [17039] = 16650,
  [17040] = 16655,
  [17041] = 17041,
  [17042] = 16695,
  [17043] = 16969,
  [17044] = 16970,
  [17045] = 16714,
  [17046] = 16631,
  [17047] = 16720,
  [17048] = 16842,
  [17049] = 16653,
  [17050] = 16894,
  [17051] = 17051,
  [17052] = 16662,
  [17053] = 17053,
  [17054] = 16665,
  [17055] = 16687,
  [17056] = 16715,
  [17057] = 17057,
  [17058] = 16643,
  [17059] = 16643,
  [17060] = 16668,
  [17061] = 16963,
  [17062] = 16964,
  [17063] = 16965,
  [17064] = 16966,
  [17065] = 16804,
  [17066] = 16969,
  [17067] = 16970,
  [17068] = 16724,
  [17069] = 16643,
  [17070] = 16979,
  [17071] = 16704,
  [17072] = 16842,
  [17073] = 16894,
  [17074] = 16678,
  [17075] = 16667,
  [17076] = 17076,
  [17077] = 17077,
  [17078] = 17078,
  [17079] = 16724,
  [17080] = 16963,
  [17081] = 16964,
  [17082] = 16965,
  [17083] = 16966,
  [17084] = 16669,
  [17085] = 16650,
  [17086] = 16669,
  [17087] = 16688,
  [17088] = 16969,
  [17089] = 16729,
  [17090] = 16970,
  [17091] = 16685,
  [17092] = 17092,
  [17093] = 16649,
  [17094] = 17094,
  [17095] = 16979,
  [17096] = 16686,
  [17097] = 16842,
  [17098] = 16648,
  [17099] = 16739,
  [17100] = 17100,
  [17101] = 16894,
  [17102] = 17102,
  [17103] = 17103,
  [17104] = 16962,
  [17105] = 17105,
  [17106] = 16698,
  [17107] = 16836,
  [17108] = 16965,
  [17109] = 17109,
  [17110] = 16642,
  [17111] = 17111,
  [17112] = 17112,
  [17113] = 16724,
  [17114] = 17114,
  [17115] = 17115,
  [17116] = 17116,
  [17117] = 17117,
  [17118] = 16683,
  [17119] = 16650,
  [17120] = 17120,
  [17121] = 17121,
  [17122] = 16965,
  [17123] = 16653,
  [17124] = 17124,
  [17125] = 17125,
  [17126] = 16804,
  [17127] = 16687,
  [17128] = 17128,
  [17129] = 17129,
  [17130] = 16708,
  [17131] = 16713,
  [17132] = 16688,
  [17133] = 17133,
  [17134] = 16715,
  [17135] = 17135,
  [17136] = 16720,
  [17137] = 16707,
  [17138] = 17138,
  [17139] = 17139,
  [17140] = 17140,
  [17141] = 17141,
  [17142] = 17142,
  [17143] = 16669,
  [17144] = 17144,
  [17145] = 16712,
  [17146] = 16645,
  [17147] = 16646,
  [17148] = 16649,
  [17149] = 17149,
  [17150] = 16636,
  [17151] = 17151,
  [17152] = 17152,
  [17153] = 16671,
  [17154] = 16662,
  [17155] = 17155,
  [17156] = 16654,
  [17157] = 16643,
  [17158] = 17158,
  [17159] = 16668,
  [17160] = 16695,
  [17161] = 17161,
  [17162] = 16836,
  [17163] = 17163,
  [17164] = 17164,
  [17165] = 17165,
  [17166] = 17166,
  [17167] = 17167,
  [17168] = 17168,
  [17169] = 17169,
  [17170] = 17170,
  [17171] = 17171,
  [17172] = 17172,
  [17173] = 17173,
  [17174] = 17174,
  [17175] = 17175,
  [17176] = 17176,
  [17177] = 17177,
  [17178] = 17178,
  [17179] = 16655,
  [17180] = 17180,
  [17181] = 17181,
  [17182] = 17182,
  [17183] = 17183,
  [17184] = 17184,
  [17185] = 16668,
  [17186] = 17186,
  [17187] = 17187,
  [17188] = 16804,
  [17189] = 17189,
  [17190] = 17190,
  [17191] = 16665,
  [17192] = 17192,
  [17193] = 17193,
  [17194] = 17194,
  [17195] = 17195,
  [17196] = 17196,
  [17197] = 17197,
  [17198] = 16836,
  [17199] = 16683,
  [17200] = 17200,
  [17201] = 17201,
  [17202] = 17202,
  [17203] = 16966,
  [17204] = 17204,
  [17205] = 16708,
  [17206] = 16705,
  [17207] = 17207,
  [17208] = 16707,
  [17209] = 16708,
  [17210] = 16695,
  [17211] = 16687,
  [17212] = 16688,
  [17213] = 17213,
  [17214] = 16713,
  [17215] = 17215,
  [17216] = 17216,
  [17217] = 17217,
  [17218] = 17218,
  [17219] = 17219,
  [17220] = 17220,
  [17221] = 17221,
  [17222] = 17222,
  [17223] = 16714,
  [17224] = 16715,
  [17225] = 17225,
  [17226] = 16632,
  [17227] = 16695,
  [17228] = 17228,
  [17229] = 16720,
  [17230] = 17230,
  [17231] = 17231,
  [17232] = 17232,
  [17233] = 16632,
  [17234] = 16636,
  [17235] = 17235,
  [17236] = 17236,
  [17237] = 17237,
  [17238] = 17238,
  [17239] = 16671,
  [17240] = 17240,
  [17241] = 17241,
  [17242] = 17242,
  [17243] = 17243,
  [17244] = 17244,
  [17245] = 17245,
  [17246] = 17246,
  [17247] = 17247,
  [17248] = 16671,
  [17249] = 16643,
  [17250] = 17250,
  [17251] = 16645,
  [17252] = 16646,
  [17253] = 17253,
  [17254] = 17254,
  [17255] = 16649,
  [17256] = 17256,
  [17257] = 17257,
  [17258] = 17258,
  [17259] = 17259,
  [17260] = 17260,
  [17261] = 17261,
  [17262] = 17262,
  [17263] = 17263,
  [17264] = 16655,
  [17265] = 17265,
  [17266] = 16704,
  [17267] = 17267,
  [17268] = 16969,
  [17269] = 17269,
  [17270] = 17270,
  [17271] = 16719,
  [17272] = 16662,
  [17273] = 17273,
  [17274] = 16665,
  [17275] = 17275,
  [17276] = 17276,
  [17277] = 17277,
  [17278] = 16668,
  [17279] = 17279,
  [17280] = 17280,
  [17281] = 17281,
  [17282] = 17282,
  [17283] = 16724,
  [17284] = 17284,
  [17285] = 17285,
  [17286] = 17286,
  [17287] = 16678,
  [17288] = 17288,
  [17289] = 17289,
  [17290] = 16667,
  [17291] = 17291,
  [17292] = 17292,
  [17293] = 16716,
  [17294] = 17294,
  [17295] = 17295,
  [17296] = 16719,
  [17297] = 17297,
  [17298] = 16678,
  [17299] = 17299,
  [17300] = 17300,
  [17301] = 16685,
  [17302] = 16686,
  [17303] = 16698,
  [17304] = 17304,
  [17305] = 16729,
  [17306] = 17306,
  [17307] = 17307,
  [17308] = 17308,
  [17309] = 16773,
  [17310] = 17310,
  [17311] = 17311,
  [17312] = 17312,
  [17313] = 16964,
  [17314] = 17314,
  [17315] = 16631,
  [17316] = 17316,
  [17317] = 17317,
  [17318] = 16643,
  [17319] = 16712,
  [17320] = 17320,
  [17321] = 17321,
  [17322] = 16671,
  [17323] = 17323,
  [17324] = 16716,
  [17325] = 17325,
  [17326] = 17326,
  [17327] = 16671,
  [17328] = 16687,
  [17329] = 17329,
  [17330] = 16970,
  [17331] = 16636,
  [17332] = 16636,
  [17333] = 16719,
  [17334] = 16636,
  [17335] = 16636,
  [17336] = 16636,
  [17337] = 16636,
  [17338] = 16636,
  [17339] = 16739,
  [17340] = 17340,
  [17341] = 16713,
  [17342] = 17342,
  [17343] = 16705,
  [17344] = 17344,
  [17345] = 16707,
  [17346] = 16708,
  [17347] = 17347,
  [17348] = 17348,
  [17349] = 16963,
  [17350] = 16964,
  [17351] = 17351,
  [17352] = 17352,
  [17353] = 16965,
  [17354] = 16713,
  [17355] = 16724,
  [17356] = 17356,
  [17357] = 16773,
  [17358] = 17358,
  [17359] = 17359,
  [17360] = 16714,
  [17361] = 16715,
  [17362] = 16729,
  [17363] = 16636,
  [17364] = 16643,
  [17365] = 17365,
  [17366] = 16739,
  [17367] = 16979,
  [17368] = 17368,
  [17369] = 17369,
  [17370] = 17370,
  [17371] = 17371,
  [17372] = 17372,
  [17373] = 17373,
  [17374] = 17374,
  [17375] = 17375,
  [17376] = 17376,
  [17377] = 17377,
  [17378] = 17378,
  [17379] = 17379,
  [17380] = 17380,
  [17381] = 17381,
  [17382] = 17382,
  [17383] = 17383,
  [17384] = 17384,
  [17385] = 17385,
  [17386] = 17386,
  [17387] = 17387,
  [17388] = 17388,
  [17389] = 17389,
  [17390] = 17390,
  [17391] = 17391,
  [17392] = 17392,
  [17393] = 17393,
  [17394] = 17394,
  [17395] = 17395,
  [17396] = 17396,
  [17397] = 17397,
  [17398] = 17398,
  [17399] = 17399,
  [17400] = 17400,
  [17401] = 17401,
  [17402] = 17402,
  [17403] = 17403,
  [17404] = 17404,
  [17405] = 17405,
  [17406] = 17406,
  [17407] = 17407,
  [17408] = 17408,
  [17409] = 17409,
  [17410] = 17410,
  [17411] = 17389,
  [17412] = 17412,
  [17413] = 17413,
  [17414] = 17414,
  [17415] = 17415,
  [17416] = 17416,
  [17417] = 17417,
  [17418] = 17418,
  [17419] = 17419,
  [17420] = 17420,
  [17421] = 17421,
  [17422] = 17422,
  [17423] = 17423,
  [17424] = 17424,
  [17425] = 17425,
  [17426] = 17426,
  [17427] = 17427,
  [17428] = 17428,
  [17429] = 17429,
  [17430] = 17430,
  [17431] = 17431,
  [17432] = 17432,
  [17433] = 17433,
  [17434] = 17434,
  [17435] = 17435,
  [17436] = 17436,
  [17437] = 17437,
  [17438] = 17438,
  [17439] = 17439,
  [17440] = 17440,
  [17441] = 17441,
  [17442] = 17442,
  [17443] = 17426,
  [17444] = 17442,
  [17445] = 17442,
  [17446] = 17446,
  [17447] = 17447,
  [17448] = 17448,
  [17449] = 17449,
  [17450] = 17450,
  [17451] = 17451,
  [17452] = 17452,
  [17453] = 17453,
  [17454] = 17454,
  [17455] = 17455,
  [17456] = 17456,
  [17457] = 17457,
  [17458] = 17458,
  [17459] = 17375,
  [17460] = 17460,
  [17461] = 17389,
  [17462] = 17450,
  [17463] = 17451,
  [17464] = 17409,
  [17465] = 17410,
  [17466] = 17419,
  [17467] = 17420,
  [17468] = 17424,
  [17469] = 17428,
  [17470] = 17453,
  [17471] = 17471,
  [17472] = 17472,
  [17473] = 17452,
  [17474] = 17454,
  [17475] = 17475,
  [17476] = 17472,
  [17477] = 17477,
  [17478] = 17475,
  [17479] = 17477,
  [17480] = 17480,
  [17481] = 17480,
  [17482] = 17482,
  [17483] = 17483,
  [17484] = 17484,
  [17485] = 17485,
  [17486] = 17486,
  [17487] = 17487,
  [17488] = 17488,
  [17489] = 17489,
  [17490] = 17490,
  [17491] = 17491,
  [17492] = 17492,
  [17493] = 17493,
  [17494] = 17494,
  [17495] = 17495,
  [17496] = 17496,
  [17497] = 17497,
  [17498] = 17498,
  [17499] = 17499,
  [17500] = 17500,
  [17501] = 17501,
  [17502] = 17502,
  [17503] = 17503,
  [17504] = 17504,
  [17505] = 17505,
  [17506] = 17506,
  [17507] = 17507,
  [17508] = 17508,
  [17509] = 17509,
  [17510] = 17510,
  [17511] = 17511,
  [17512] = 17512,
  [17513] = 17513,
  [17514] = 17514,
  [17515] = 17515,
  [17516] = 17516,
  [17517] = 17517,
  [17518] = 17518,
  [17519] = 17519,
  [17520] = 17415,
  [17521] = 17521,
  [17522] = 17421,
  [17523] = 17523,
  [17524] = 17482,
  [17525] = 17416,
  [17526] = 17526,
  [17527] = 17527,
  [17528] = 17528,
  [17529] = 17396,
  [17530] = 17455,
  [17531] = 17531,
  [17532] = 17456,
  [17533] = 17533,
  [17534] = 17393,
  [17535] = 17535,
  [17536] = 17536,
  [17537] = 17537,
  [17538] = 17538,
  [17539] = 17539,
  [17540] = 17540,
  [17541] = 17541,
  [17542] = 17542,
  [17543] = 17543,
  [17544] = 17544,
  [17545] = 17545,
  [17546] = 17546,
  [17547] = 17547,
  [17548] = 17413,
  [17549] = 17549,
  [17550] = 17550,
  [17551] = 17551,
  [17552] = 17552,
  [17553] = 17553,
  [17554] = 17554,
  [17555] = 17555,
  [17556] = 17556,
  [17557] = 17427,
  [17558] = 17558,
  [17559] = 17374,
  [17560] = 17560,
  [17561] = 17376,
  [17562] = 17562,
  [17563] = 17563,
  [17564] = 17564,
  [17565] = 17565,
  [17566] = 17399,
  [17567] = 17567,
  [17568] = 17568,
  [17569] = 17400,
  [17570] = 17408,
  [17571] = 17393,
  [17572] = 17572,
  [17573] = 17573,
  [17574] = 17413,
  [17575] = 17457,
  [17576] = 17375,
  [17577] = 17577,
  [17578] = 17578,
  [17579] = 17394,
  [17580] = 17580,
  [17581] = 17439,
  [17582] = 17397,
  [17583] = 17518,
  [17584] = 17584,
  [17585] = 17409,
  [17586] = 17455,
  [17587] = 17456,
  [17588] = 17588,
  [17589] = 17589,
  [17590] = 17482,
  [17591] = 17591,
  [17592] = 17454,
  [17593] = 17472,
  [17594] = 17368,
  [17595] = 17475,
  [17596] = 17477,
  [17597] = 17421,
  [17598] = 17480,
  [17599] = 17599,
  [17600] = 17600,
  [17601] = 17601,
  [17602] = 17602,
  [17603] = 17603,
  [17604] = 17604,
  [17605] = 17605,
  [17606] = 17606,
  [17607] = 17607,
  [17608] = 17608,
  [17609] = 17547,
  [17610] = 17547,
  [17611] = 17611,
  [17612] = 17482,
  [17613] = 17613,
  [17614] = 17538,
  [17615] = 17611,
  [17616] = 17417,
  [17617] = 17547,
  [17618] = 17618,
  [17619] = 17619,
  [17620] = 17551,
  [17621] = 17621,
  [17622] = 17380,
  [17623] = 17381,
  [17624] = 17382,
  [17625] = 17625,
  [17626] = 17384,
  [17627] = 17627,
  [17628] = 17628,
  [17629] = 17629,
  [17630] = 17374,
  [17631] = 17631,
  [17632] = 17632,
  [17633] = 17633,
  [17634] = 17376,
  [17635] = 17635,
  [17636] = 17636,
  [17637] = 17637,
  [17638] = 17426,
  [17639] = 17639,
  [17640] = 17399,
  [17641] = 17641,
  [17642] = 17552,
  [17643] = 17643,
  [17644] = 17408,
  [17645] = 17645,
  [17646] = 17646,
  [17647] = 17413,
  [17648] = 17648,
  [17649] = 17649,
  [17650] = 17650,
  [17651] = 17629,
  [17652] = 17588,
  [17653] = 17498,
  [17654] = 17654,
  [17655] = 17439,
  [17656] = 17483,
  [17657] = 17483,
  [17658] = 17658,
  [17659] = 17441,
  [17660] = 17455,
  [17661] = 17456,
  [17662] = 17662,
  [17663] = 17501,
  [17664] = 17482,
  [17665] = 17488,
  [17666] = 17489,
  [17667] = 17490,
  [17668] = 17668,
  [17669] = 17389,
  [17670] = 17491,
  [17671] = 17493,
  [17672] = 17421,
  [17673] = 17442,
  [17674] = 17674,
  [17675] = 17675,
  [17676] = 17676,
  [17677] = 17677,
  [17678] = 17678,
  [17679] = 17502,
  [17680] = 17421,
  [17681] = 17504,
  [17682] = 17682,
  [17683] = 17683,
  [17684] = 17505,
  [17685] = 17547,
  [17686] = 17686,
  [17687] = 17687,
  [17688] = 17498,
  [17689] = 17551,
  [17690] = 17501,
  [17691] = 17508,
  [17692] = 17692,
  [17693] = 17450,
  [17694] = 17506,
  [17695] = 17695,
  [17696] = 17374,
  [17697] = 17482,
  [17698] = 17451,
  [17699] = 17376,
  [17700] = 17452,
  [17701] = 17507,
  [17702] = 17496,
  [17703] = 17497,
  [17704] = 17399,
  [17705] = 17499,
  [17706] = 17408,
  [17707] = 17531,
  [17708] = 17708,
  [17709] = 17500,
  [17710] = 17413,
  [17711] = 17711,
  [17712] = 17712,
  [17713] = 17713,
  [17714] = 17381,
  [17715] = 17715,
  [17716] = 17488,
  [17717] = 17439,
  [17718] = 17552,
  [17719] = 17489,
  [17720] = 17720,
  [17721] = 17721,
  [17722] = 17508,
  [17723] = 17455,
  [17724] = 17456,
  [17725] = 17725,
  [17726] = 17567,
  [17727] = 17490,
  [17728] = 17482,
  [17729] = 17491,
  [17730] = 17730,
  [17731] = 17731,
  [17732] = 17493,
  [17733] = 17733,
  [17734] = 17421,
  [17735] = 17735,
  [17736] = 17736,
  [17737] = 17510,
  [17738] = 17511,
  [17739] = 17512,
  [17740] = 17513,
  [17741] = 17605,
  [17742] = 17555,
  [17743] = 17743,
  [17744] = 17744,
  [17745] = 17745,
  [17746] = 17746,
  [17747] = 17747,
  [17748] = 17547,
  [17749] = 17749,
  [17750] = 17514,
  [17751] = 17551,
  [17752] = 17450,
  [17753] = 17515,
  [17754] = 17516,
  [17755] = 17374,
  [17756] = 17605,
  [17757] = 17606,
  [17758] = 17674,
  [17759] = 17376,
  [17760] = 17760,
  [17761] = 17761,
  [17762] = 17762,
  [17763] = 17763,
  [17764] = 17764,
  [17765] = 17399,
  [17766] = 17517,
  [17767] = 17538,
  [17768] = 17408,
  [17769] = 17769,
  [17770] = 17494,
  [17771] = 17384,
  [17772] = 17772,
  [17773] = 17413,
  [17774] = 17774,
  [17775] = 17775,
  [17776] = 17776,
  [17777] = 17777,
  [17778] = 17430,
  [17779] = 17439,
  [17780] = 17780,
  [17781] = 17781,
  [17782] = 17523,
  [17783] = 17455,
  [17784] = 17784,
  [17785] = 17456,
  [17786] = 17434,
  [17787] = 17781,
  [17788] = 17482,
  [17789] = 17789,
  [17790] = 17451,
  [17791] = 17527,
  [17792] = 17792,
  [17793] = 17793,
  [17794] = 17421,
  [17795] = 17795,
  [17796] = 17683,
  [17797] = 17797,
  [17798] = 17798,
  [17799] = 17799,
  [17800] = 17800,
  [17801] = 17455,
  [17802] = 17802,
  [17803] = 17441,
  [17804] = 17551,
  [17805] = 17397,
  [17806] = 17456,
  [17807] = 17533,
  [17808] = 17535,
  [17809] = 17800,
  [17810] = 17547,
  [17811] = 17811,
  [17812] = 17812,
  [17813] = 17389,
  [17814] = 17382,
  [17815] = 17551,
  [17816] = 17415,
  [17817] = 17551,
  [17818] = 17818,
  [17819] = 17374,
  [17820] = 17820,
  [17821] = 17376,
  [17822] = 17822,
  [17823] = 17823,
  [17824] = 17369,
  [17825] = 17825,
  [17826] = 17399,
  [17827] = 17827,
  [17828] = 17408,
  [17829] = 17829,
  [17830] = 17413,
  [17831] = 17498,
  [17832] = 17832,
  [17833] = 17508,
  [17834] = 17834,
  [17835] = 17835,
  [17836] = 17764,
  [17837] = 17837,
  [17838] = 17439,
  [17839] = 17839,
  [17840] = 17531,
  [17841] = 17496,
  [17842] = 17842,
  [17843] = 17455,
  [17844] = 17456,
  [17845] = 17497,
  [17846] = 17846,
  [17847] = 17482,
  [17848] = 17848,
  [17849] = 17531,
  [17850] = 17421,
  [17851] = 17625,
  [17852] = 17852,
  [17853] = 17438,
  [17854] = 17854,
  [17855] = 17855,
  [17856] = 17371,
  [17857] = 17857,
  [17858] = 17858,
  [17859] = 17547,
  [17860] = 17552,
  [17861] = 17499,
  [17862] = 17862,
  [17863] = 17551,
  [17864] = 17536,
  [17865] = 17865,
  [17866] = 17866,
  [17867] = 17374,
  [17868] = 17567,
  [17869] = 17564,
  [17870] = 17376,
  [17871] = 17871,
  [17872] = 17537,
  [17873] = 17500,
  [17874] = 17650,
  [17875] = 17399,
  [17876] = 17876,
  [17877] = 17408,
  [17878] = 17452,
  [17879] = 17413,
  [17880] = 17562,
  [17881] = 17818,
  [17882] = 17882,
  [17883] = 17605,
  [17884] = 17606,
  [17885] = 17885,
  [17886] = 17886,
  [17887] = 17887,
  [17888] = 17384,
  [17889] = 17889,
  [17890] = 17439,
  [17891] = 17891,
  [17892] = 17892,
  [17893] = 17565,
  [17894] = 17455,
  [17895] = 17456,
  [17896] = 17896,
  [17897] = 17897,
  [17898] = 17482,
  [17899] = 17899,
  [17900] = 17900,
  [17901] = 17901,
  [17902] = 17421,
  [17903] = 17903,
  [17904] = 17904,
  [17905] = 17905,
  [17906] = 17876,
  [17907] = 17457,
  [17908] = 17375,
  [17909] = 17380,
  [17910] = 17605,
  [17911] = 17547,
  [17912] = 17912,
  [17913] = 17913,
  [17914] = 17384,
  [17915] = 17915,
  [17916] = 17916,
  [17917] = 17725,
  [17918] = 17918,
  [17919] = 17369,
  [17920] = 17645,
  [17921] = 17921,
  [17922] = 17922,
  [17923] = 17551,
  [17924] = 17924,
  [17925] = 17827,
  [17926] = 17926,
  [17927] = 17409,
  [17928] = 17374,
  [17929] = 17871,
  [17930] = 17376,
  [17931] = 17931,
  [17932] = 17932,
  [17933] = 17416,
  [17934] = 17934,
  [17935] = 17935,
  [17936] = 17605,
  [17937] = 17937,
  [17938] = 17510,
  [17939] = 17384,
  [17940] = 17399,
  [17941] = 17552,
  [17942] = 17942,
  [17943] = 17408,
  [17944] = 17511,
  [17945] = 17413,
  [17946] = 17946,
  [17947] = 17374,
  [17948] = 17454,
  [17949] = 17512,
  [17950] = 17555,
  [17951] = 17513,
  [17952] = 17439,
  [17953] = 17953,
  [17954] = 17376,
  [17955] = 17648,
  [17956] = 17472,
  [17957] = 17385,
  [17958] = 17455,
  [17959] = 17456,
  [17960] = 17605,
  [17961] = 17475,
  [17962] = 17560,
  [17963] = 17384,
  [17964] = 17477,
  [17965] = 17482,
  [17966] = 17480,
  [17967] = 17421,
  [17968] = 17968,
  [17969] = 17521,
  [17970] = 17970,
  [17971] = 17746,
  [17972] = 17381,
  [17973] = 17973,
  [17974] = 17974,
  [17975] = 17619,
  [17976] = 17399,
  [17977] = 17514,
  [17978] = 17515,
  [17979] = 17979,
  [17980] = 17516,
  [17981] = 17981,
  [17982] = 17982,
  [17983] = 17421,
  [17984] = 17605,
  [17985] = 17405,
  [17986] = 17760,
  [17987] = 17384,
  [17988] = 17988,
  [17989] = 17567,
  [17990] = 17568,
  [17991] = 17991,
  [17992] = 17992,
  [17993] = 17413,
  [17994] = 17994,
  [17995] = 17407,
  [17996] = 17712,
  [17997] = 17382,
  [17998] = 17517,
  [17999] = 17772,
  [18000] = 18000,
  [18001] = 18001,
  [18002] = 17421,
  [18003] = 18003,
  [18004] = 17775,
  [18005] = 17777,
  [18006] = 17417,
  [18007] = 17605,
  [18008] = 17482,
  [18009] = 18009,
  [18010] = 17384,
  [18011] = 18011,
  [18012] = 17600,
  [18013] = 18013,
  [18014] = 17578,
  [18015] = 18015,
  [18016] = 17538,
  [18017] = 18017,
  [18018] = 18018,
  [18019] = 18019,
  [18020] = 18020,
  [18021] = 17625,
  [18022] = 18022,
  [18023] = 17852,
  [18024] = 18024,
  [18025] = 17421,
  [18026] = 18026,
  [18027] = 17408,
  [18028] = 17935,
  [18029] = 17605,
  [18030] = 18030,
  [18031] = 18031,
  [18032] = 18032,
  [18033] = 17584,
  [18034] = 17421,
  [18035] = 17422,
  [18036] = 17371,
  [18037] = 18037,
  [18038] = 18038,
  [18039] = 18039,
  [18040] = 17421,
  [18041] = 18041,
  [18042] = 17713,
  [18043] = 18043,
  [18044] = 17388,
  [18045] = 18045,
  [18046] = 17384,
  [18047] = 18047,
  [18048] = 17421,
  [18049] = 18049,
  [18050] = 17605,
  [18051] = 18051,
  [18052] = 18052,
  [18053] = 17605,
  [18054] = 18054,
  [18055] = 18055,
  [18056] = 17605,
  [18057] = 17564,
  [18058] = 18058,
  [18059] = 18059,
  [18060] = 18060,
  [18061] = 17439,
  [18062] = 17650,
  [18063] = 18063,
  [18064] = 17421,
  [18065] = 17528,
  [18066] = 18066,
  [18067] = 18067,
  [18068] = 18068,
  [18069] = 18069,
  [18070] = 18070,
  [18071] = 18071,
  [18072] = 17421,
  [18073] = 18073,
  [18074] = 18054,
  [18075] = 18075,
  [18076] = 18076,
  [18077] = 18077,
  [18078] = 17421,
  [18079] = 17421,
  [18080] = 17421,
  [18081] = 17747,
  [18082] = 17421,
  [18083] = 17421,
  [18084] = 17421,
  [18085] = 18085,
  [18086] = 17421,
  [18087] = 17421,
  [18088] = 17421,
  [18089] = 17372,
  [18090] = 18090,
  [18091] = 18091,
  [18092] = 17747,
  [18093] = 17421,
  [18094] = 18094,
  [18095] = 17421,
  [18096] = 17421,
  [18097] = 17421,
  [18098] = 17421,
  [18099] = 17421,
  [18100] = 17764,
  [18101] = 17605,
  [18102] = 18102,
  [18103] = 18103,
  [18104] = 18104,
  [18105] = 17494,
  [18106] = 18106,
  [18107] = 18107,
  [18108] = 18108,
  [18109] = 18109,
  [18110] = 18110,
  [18111] = 17934,
  [18112] = 18112,
  [18113] = 18113,
  [18114] = 17645,
  [18115] = 18115,
  [18116] = 18116,
  [18117] = 18117,
  [18118] = 17994,
  [18119] = 18119,
  [18120] = 18120,
  [18121] = 17421,
  [18122] = 18122,
  [18123] = 18123,
  [18124] = 18124,
  [18125] = 18125,
  [18126] = 18126,
  [18127] = 18127,
  [18128] = 18128,
  [18129] = 18129,
  [18130] = 17764,
  [18131] = 18131,
  [18132] = 17924,
  [18133] = 17494,
  [18134] = 18134,
  [18135] = 17648,
  [18136] = 18136,
  [18137] = 18137,
  [18138] = 18138,
  [18139] = 18139,
  [18140] = 18140,
  [18141] = 17588,
  [18142] = 18068,
  [18143] = 17654,
  [18144] = 18144,
  [18145] = 18145,
  [18146] = 17730,
  [18147] = 18147,
  [18148] = 18148,
  [18149] = 18149,
  [18150] = 18150,
  [18151] = 18151,
  [18152] = 18152,
  [18153] = 18153,
  [18154] = 18154,
  [18155] = 18155,
  [18156] = 18156,
  [18157] = 17380,
  [18158] = 17381,
  [18159] = 17382,
  [18160] = 18160,
  [18161] = 17384,
  [18162] = 18162,
  [18163] = 18163,
  [18164] = 18164,
  [18165] = 17483,
  [18166] = 18166,
  [18167] = 18045,
  [18168] = 17775,
  [18169] = 17994,
  [18170] = 18170,
  [18171] = 18171,
  [18172] = 18172,
  [18173] = 17413,
  [18174] = 18174,
  [18175] = 18175,
  [18176] = 18176,
  [18177] = 18177,
  [18178] = 18178,
  [18179] = 18179,
  [18180] = 18180,
  [18181] = 18181,
  [18182] = 18182,
  [18183] = 18183,
  [18184] = 18184,
  [18185] = 18076,
  [18186] = 18186,
  [18187] = 18187,
  [18188] = 18188,
  [18189] = 17713,
  [18190] = 18190,
  [18191] = 18191,
  [18192] = 18192,
  [18193] = 17713,
  [18194] = 18194,
  [18195] = 18195,
  [18196] = 17528,
  [18197] = 18054,
  [18198] = 18198,
  [18199] = 18199,
  [18200] = 18200,
  [18201] = 18201,
  [18202] = 17393,
  [18203] = 17368,
  [18204] = 17795,
  [18205] = 17776,
  [18206] = 18181,
  [18207] = 18207,
  [18208] = 17544,
  [18209] = 18209,
  [18210] = 17528,
  [18211] = 17834,
  [18212] = 17629,
  [18213] = 18213,
  [18214] = 18214,
  [18215] = 17781,
  [18216] = 18216,
  [18217] = 18217,
  [18218] = 18218,
  [18219] = 18149,
  [18220] = 18220,
  [18221] = 18221,
  [18222] = 18222,
  [18223] = 18223,
  [18224] = 18224,
  [18225] = 17654,
  [18226] = 18226,
  [18227] = 18227,
  [18228] = 18134,
  [18229] = 17654,
  [18230] = 18230,
  [18231] = 17560,
  [18232] = 17953,
  [18233] = 18233,
  [18234] = 17713,
  [18235] = 17605,
  [18236] = 17606,
  [18237] = 17528,
  [18238] = 17871,
  [18239] = 17414,
  [18240] = 17650,
  [18241] = 18241,
  [18242] = 18242,
  [18243] = 17605,
  [18244] = 18244,
  [18245] = 18245,
  [18246] = 18246,
  [18247] = 17494,
  [18248] = 17606,
  [18249] = 18249,
  [18250] = 18172,
  [18251] = 17866,
  [18252] = 17832,
  [18253] = 17488,
  [18254] = 17489,
  [18255] = 18201,
  [18256] = 17422,
  [18257] = 17736,
  [18258] = 17490,
  [18259] = 17491,
  [18260] = 17485,
  [18261] = 18261,
  [18262] = 17832,
  [18263] = 18263,
  [18264] = 18264,
  [18265] = 18265,
  [18266] = 17493,
  [18267] = 18267,
  [18268] = 18268,
  [18269] = 18269,
  [18270] = 18270,
  [18271] = 18271,
  [18272] = 17591,
  [18273] = 18116,
  [18274] = 18274,
  [18275] = 18275,
  [18276] = 17832,
  [18277] = 17935,
  [18278] = 17415,
  [18279] = 18279,
  [18280] = 18032,
  [18281] = 18281,
  [18282] = 18282,
  [18283] = 17416,
  [18284] = 18116,
  [18285] = 18285,
  [18286] = 18286,
  [18287] = 18287,
  [18288] = 18288,
  [18289] = 17749,
  [18290] = 17370,
  [18291] = 17379,
  [18292] = 18292,
  [18293] = 18293,
  [18294] = 18294,
  [18295] = 18295,
  [18296] = 18296,
  [18297] = 17374,
  [18298] = 18298,
  [18299] = 18299,
  [18300] = 17413,
  [18301] = 17486,
  [18302] = 17521,
  [18303] = 17486,
  [18304] = 17521,
  [18305] = 18305,
  [18306] = 17395,
  [18307] = 17483,
  [18308] = 17518,
  [18309] = 17400,
  [18310] = 17588,
  [18311] = 18311,
  [18312] = 17600,
  [18313] = 18313,
  [18314] = 17376,
  [18315] = 17876,
  [18316] = 17503,
  [18317] = 17498,
  [18318] = 18318,
  [18319] = 18319,
  [18320] = 17982,
  [18321] = 18321,
  [18322] = 18170,
  [18323] = 17798,
  [18324] = 17799,
  [18325] = 18294,
  [18326] = 18171,
  [18327] = 17683,
  [18328] = 18032,
  [18329] = 18287,
  [18330] = 18242,
  [18331] = 17632,
  [18332] = 18332,
  [18333] = 17565,
  [18334] = 17591,
  [18335] = 17588,
  [18336] = 18214,
  [18337] = 18337,
  [18338] = 18338,
  [18339] = 18223,
  [18340] = 17385,
  [18341] = 18341,
  [18342] = 17769,
  [18343] = 18343,
  [18344] = 18344,
  [18345] = 18116,
  [18346] = 18346,
  [18347] = 18051,
  [18348] = 18348,
  [18349] = 17380,
  [18350] = 18350,
  [18351] = 18351,
  [18352] = 18352,
  [18353] = 17648,
  [18354] = 18265,
  [18355] = 17381,
  [18356] = 18356,
  [18357] = 18357,
  [18358] = 18358,
  [18359] = 18359,
  [18360] = 17404,
  [18361] = 18361,
  [18362] = 18362,
  [18363] = 18069,
  [18364] = 17382,
  [18365] = 18365,
  [18366] = 18366,
  [18367] = 17488,
  [18368] = 18188,
  [18369] = 18188,
  [18370] = 18288,
  [18371] = 18371,
  [18372] = 17384,
  [18373] = 18373,
  [18374] = 18374,
  [18375] = 18375,
  [18376] = 18376,
  [18377] = 17386,
  [18378] = 18356,
  [18379] = 17370,
  [18380] = 17388,
  [18381] = 17395,
  [18382] = 17489,
  [18383] = 18383,
  [18384] = 17399,
  [18385] = 18385,
  [18386] = 17544,
  [18387] = 18387,
  [18388] = 17560,
  [18389] = 17496,
  [18390] = 17749,
  [18391] = 17631,
  [18392] = 18357,
  [18393] = 18393,
  [18394] = 18285,
  [18395] = 18395,
  [18396] = 17394,
  [18397] = 18294,
  [18398] = 18071,
  [18399] = 18399,
  [18400] = 17497,
  [18401] = 17418,
  [18402] = 17503,
  [18403] = 18069,
  [18404] = 18404,
  [18405] = 17632,
  [18406] = 18292,
  [18407] = 18407,
  [18408] = 17499,
  [18409] = 17379,
  [18410] = 18085,
  [18411] = 17500,
  [18412] = 18412,
  [18413] = 18413,
  [18414] = 17503,
  [18415] = 17982,
  [18416] = 17632,
  [18417] = 18417,
  [18418] = 17405,
  [18419] = 18094,
  [18420] = 17404,
  [18421] = 18421,
  [18422] = 18422,
  [18423] = 17519,
  [18424] = 17404,
  [18425] = 17490,
  [18426] = 17605,
  [18427] = 18102,
  [18428] = 17491,
  [18429] = 18429,
  [18430] = 18430,
  [18431] = 17430,
  [18432] = 17713,
  [18433] = 17493,
  [18434] = 18058,
  [18435] = 18112,
  [18436] = 17434,
  [18437] = 17392,
  [18438] = 17591,
  [18439] = 18439,
  [18440] = 17991,
  [18441] = 17725,
  [18442] = 18120,
  [18443] = 17720,
  [18444] = 17446,
  [18445] = 18123,
  [18446] = 18124,
  [18447] = 18125,
  [18448] = 18126,
  [18449] = 18127,
  [18450] = 18128,
  [18451] = 18129,
  [18452] = 17992,
  [18453] = 17924,
  [18454] = 17440,
  [18455] = 18137,
  [18456] = 18456,
  [18457] = 18136,
  [18458] = 18137,
  [18459] = 18138,
  [18460] = 17374,
  [18461] = 18145,
  [18462] = 17730,
  [18463] = 18463,
  [18464] = 18464,
  [18465] = 17519,
  [18466] = 18466,
  [18467] = 18151,
  [18468] = 18153,
  [18469] = 18469,
  [18470] = 18156,
  [18471] = 17380,
  [18472] = 17381,
  [18473] = 17382,
  [18474] = 17384,
  [18475] = 18162,
  [18476] = 18476,
  [18477] = 18477,
  [18478] = 17540,
  [18479] = 18045,
  [18480] = 18170,
  [18481] = 18171,
  [18482] = 17545,
  [18483] = 17376,
  [18484] = 18484,
  [18485] = 18176,
  [18486] = 18179,
  [18487] = 18180,
  [18488] = 18182,
  [18489] = 18183,
  [18490] = 18184,
  [18491] = 18491,
  [18492] = 17953,
  [18493] = 18191,
  [18494] = 18192,
  [18495] = 18495,
  [18496] = 18200,
  [18497] = 18052,
  [18498] = 17368,
  [18499] = 18499,
  [18500] = 17776,
  [18501] = 17540,
  [18502] = 17545,
  [18503] = 17852,
  [18504] = 17380,
  [18505] = 17427,
  [18506] = 17385,
  [18507] = 17393,
  [18508] = 18217,
  [18509] = 18218,
  [18510] = 18149,
  [18511] = 18511,
  [18512] = 17397,
  [18513] = 18227,
  [18514] = 18514,
  [18515] = 18233,
  [18516] = 18516,
  [18517] = 17414,
  [18518] = 18242,
  [18519] = 17381,
  [18520] = 18244,
  [18521] = 18245,
  [18522] = 18246,
  [18523] = 18249,
  [18524] = 17510,
  [18525] = 17503,
  [18526] = 17631,
  [18527] = 18051,
  [18528] = 17606,
  [18529] = 17511,
  [18530] = 17736,
  [18531] = 17382,
  [18532] = 18261,
  [18533] = 18264,
  [18534] = 17512,
  [18535] = 18269,
  [18536] = 18275,
  [18537] = 18281,
  [18538] = 18287,
  [18539] = 18285,
  [18540] = 18540,
  [18541] = 17547,
  [18542] = 17611,
  [18543] = 17513,
  [18544] = 17540,
  [18545] = 18545,
  [18546] = 18292,
  [18547] = 18295,
  [18548] = 18299,
  [18549] = 18549,
  [18550] = 17439,
  [18551] = 18551,
  [18552] = 17629,
  [18553] = 17384,
  [18554] = 17446,
  [18555] = 18318,
  [18556] = 18319,
  [18557] = 18557,
  [18558] = 18214,
  [18559] = 17372,
  [18560] = 18338,
  [18561] = 18561,
  [18562] = 17746,
  [18563] = 18563,
  [18564] = 17769,
  [18565] = 18265,
  [18566] = 17407,
  [18567] = 18356,
  [18568] = 18357,
  [18569] = 18569,
  [18570] = 18359,
  [18571] = 18365,
  [18572] = 18572,
  [18573] = 18573,
  [18574] = 17712,
  [18575] = 18575,
  [18576] = 17386,
  [18577] = 18540,
  [18578] = 17674,
  [18579] = 18579,
  [18580] = 18580,
  [18581] = 17781,
  [18582] = 18582,
  [18583] = 18583,
  [18584] = 17431,
  [18585] = 17749,
  [18586] = 17388,
  [18587] = 17432,
  [18588] = 17800,
  [18589] = 18071,
  [18590] = 18590,
  [18591] = 18591,
  [18592] = 17551,
  [18593] = 18593,
  [18594] = 18594,
  [18595] = 18595,
  [18596] = 18596,
  [18597] = 17439,
  [18598] = 17437,
  [18599] = 17818,
  [18600] = 18600,
  [18601] = 18085,
  [18602] = 18602,
  [18603] = 17369,
  [18604] = 18604,
  [18605] = 17393,
  [18606] = 17547,
  [18607] = 17611,
  [18608] = 18540,
  [18609] = 17827,
  [18610] = 18610,
  [18611] = 17438,
  [18612] = 18612,
  [18613] = 18613,
  [18614] = 17396,
  [18615] = 17605,
  [18616] = 18102,
  [18617] = 18102,
  [18618] = 18618,
  [18619] = 17605,
  [18620] = 18620,
  [18621] = 18020,
  [18622] = 17374,
  [18623] = 18112,
  [18624] = 18624,
  [18625] = 17376,
  [18626] = 17400,
  [18627] = 17441,
  [18628] = 17625,
  [18629] = 17852,
  [18630] = 18120,
  [18631] = 17421,
  [18632] = 18632,
  [18633] = 18123,
  [18634] = 18124,
  [18635] = 18125,
  [18636] = 18126,
  [18637] = 18127,
  [18638] = 18128,
  [18639] = 18129,
  [18640] = 17394,
  [18641] = 17924,
  [18642] = 18054,
  [18643] = 18643,
  [18644] = 18644,
  [18645] = 18136,
  [18646] = 18137,
  [18647] = 18138,
  [18648] = 17399,
  [18649] = 18145,
  [18650] = 17730,
  [18651] = 17371,
  [18652] = 18652,
  [18653] = 17514,
  [18654] = 18654,
  [18655] = 18151,
  [18656] = 18153,
  [18657] = 17515,
  [18658] = 18156,
  [18659] = 18162,
  [18660] = 18660,
  [18661] = 17501,
  [18662] = 17564,
  [18663] = 18045,
  [18664] = 18170,
  [18665] = 18171,
  [18666] = 17629,
  [18667] = 17486,
  [18668] = 17650,
  [18669] = 18176,
  [18670] = 18179,
  [18671] = 18180,
  [18672] = 18182,
  [18673] = 18183,
  [18674] = 18184,
  [18675] = 18675,
  [18676] = 17516,
  [18677] = 18191,
  [18678] = 18192,
  [18679] = 18295,
  [18680] = 18200,
  [18681] = 17368,
  [18682] = 17521,
  [18683] = 17776,
  [18684] = 17372,
  [18685] = 18685,
  [18686] = 18686,
  [18687] = 17760,
  [18688] = 17417,
  [18689] = 17519,
  [18690] = 18690,
  [18691] = 18217,
  [18692] = 18218,
  [18693] = 18149,
  [18694] = 18694,
  [18695] = 18695,
  [18696] = 18227,
  [18697] = 18697,
  [18698] = 18233,
  [18699] = 18699,
  [18700] = 17414,
  [18701] = 18242,
  [18702] = 17747,
  [18703] = 18244,
  [18704] = 18245,
  [18705] = 18246,
  [18706] = 18249,
  [18707] = 17606,
  [18708] = 17426,
  [18709] = 18709,
  [18710] = 17442,
  [18711] = 17384,
  [18712] = 17518,
  [18713] = 17736,
  [18714] = 18714,
  [18715] = 18261,
  [18716] = 18264,
  [18717] = 17781,
  [18718] = 18269,
  [18719] = 18275,
  [18720] = 18281,
  [18721] = 17517,
  [18722] = 18285,
  [18723] = 17389,
  [18724] = 17772,
  [18725] = 17441,
  [18726] = 17450,
  [18727] = 18727,
  [18728] = 17871,
  [18729] = 18292,
  [18730] = 18295,
  [18731] = 18299,
  [18732] = 17451,
  [18733] = 17452,
  [18734] = 17935,
  [18735] = 18735,
  [18736] = 18736,
  [18737] = 17410,
  [18738] = 18318,
  [18739] = 18319,
  [18740] = 17419,
  [18741] = 18214,
  [18742] = 17374,
  [18743] = 18338,
  [18744] = 17420,
  [18745] = 17588,
  [18746] = 17775,
  [18747] = 17769,
  [18748] = 18265,
  [18749] = 17424,
  [18750] = 18356,
  [18751] = 18357,
  [18752] = 17376,
  [18753] = 18359,
  [18754] = 18365,
  [18755] = 17428,
  [18756] = 17383,
  [18757] = 18071,
  [18758] = 17385,
  [18759] = 18759,
  [18760] = 17436,
  [18761] = 17777,
  [18762] = 18762,
  [18763] = 18763,
  [18764] = 18764,
  [18765] = 18765,
  [18766] = 18052,
  [18767] = 18767,
  [18768] = 17453,
  [18769] = 18085,
  [18770] = 17408,
  [18771] = 18771,
  [18772] = 18772,
  [18773] = 17551,
  [18774] = 17426,
  [18775] = 17600,
  [18776] = 17528,
  [18777] = 17458,
  [18778] = 17523,
  [18779] = 18779,
  [18780] = 17399,
  [18781] = 17523,
  [18782] = 18782,
  [18783] = 18102,
  [18784] = 17527,
  [18785] = 18785,
  [18786] = 18058,
  [18787] = 17457,
  [18788] = 18294,
  [18789] = 17540,
  [18790] = 18112,
  [18791] = 17455,
  [18792] = 17405,
  [18793] = 17632,
  [18794] = 17567,
  [18795] = 17991,
  [18796] = 17992,
  [18797] = 18120,
  [18798] = 17369,
  [18799] = 17442,
  [18800] = 18123,
  [18801] = 18124,
  [18802] = 18125,
  [18803] = 18126,
  [18804] = 18127,
  [18805] = 18128,
  [18806] = 18129,
  [18807] = 17545,
  [18808] = 17924,
  [18809] = 17407,
  [18810] = 17531,
  [18811] = 17712,
  [18812] = 18136,
  [18813] = 18137,
  [18814] = 18138,
  [18815] = 17456,
  [18816] = 18145,
  [18817] = 17730,
  [18818] = 17533,
  [18819] = 17535,
  [18820] = 17371,
  [18821] = 17422,
  [18822] = 18151,
  [18823] = 18153,
  [18824] = 18156,
  [18825] = 18162,
  [18826] = 17545,
  [18827] = 18827,
  [18828] = 18199,
  [18829] = 18045,
  [18830] = 18170,
  [18831] = 18171,
  [18832] = 17374,
  [18833] = 17418,
  [18834] = 18834,
  [18835] = 18176,
  [18836] = 18179,
  [18837] = 18180,
  [18838] = 18182,
  [18839] = 18183,
  [18840] = 18184,
  [18841] = 17394,
  [18842] = 18842,
  [18843] = 18191,
  [18844] = 18192,
  [18845] = 18845,
  [18846] = 18200,
  [18847] = 17934,
  [18848] = 17376,
  [18849] = 17776,
  [18850] = 17408,
  [18851] = 18851,
  [18852] = 17427,
  [18853] = 17498,
  [18854] = 17385,
  [18855] = 17422,
  [18856] = 18217,
  [18857] = 18218,
  [18858] = 18149,
  [18859] = 18407,
  [18860] = 18176,
  [18861] = 18227,
  [18862] = 17501,
  [18863] = 18233,
  [18864] = 17414,
  [18865] = 18242,
  [18866] = 18866,
  [18867] = 18244,
  [18868] = 18245,
  [18869] = 18246,
  [18870] = 18249,
  [18871] = 17502,
  [18872] = 17502,
  [18873] = 17934,
  [18874] = 17504,
  [18875] = 17505,
  [18876] = 17375,
  [18877] = 17736,
  [18878] = 17506,
  [18879] = 18261,
  [18880] = 18264,
  [18881] = 18881,
  [18882] = 18269,
  [18883] = 18275,
  [18884] = 18281,
  [18885] = 18885,
  [18886] = 18285,
  [18887] = 17934,
  [18888] = 17393,
  [18889] = 17507,
  [18890] = 18890,
  [18891] = 18891,
  [18892] = 17413,
  [18893] = 18292,
  [18894] = 18295,
  [18895] = 18299,
  [18896] = 18896,
  [18897] = 18188,
  [18898] = 18898,
  [18899] = 17720,
  [18900] = 18900,
  [18901] = 18318,
  [18902] = 18319,
  [18903] = 17508,
  [18904] = 18214,
  [18905] = 17408,
  [18906] = 18338,
  [18907] = 18907,
  [18908] = 18223,
  [18909] = 18909,
  [18910] = 17769,
  [18911] = 18265,
  [18912] = 17562,
  [18913] = 18356,
  [18914] = 18357,
  [18915] = 18915,
  [18916] = 18359,
  [18917] = 18365,
  [18918] = 18918,
  [18919] = 18071,
  [18920] = 18179,
  [18921] = 18921,
  [18922] = 18922,
  [18923] = 18923,
  [18924] = 17485,
  [18925] = 17565,
  [18926] = 18085,
  [18927] = 18927,
  [18928] = 17415,
  [18929] = 17416,
  [18930] = 17399,
  [18931] = 18224,
  [18932] = 17504,
  [18933] = 17505,
  [18934] = 18102,
  [18935] = 18935,
  [18936] = 18299,
  [18937] = 17397,
  [18938] = 17631,
  [18939] = 17798,
  [18940] = 17982,
  [18941] = 17531,
  [18942] = 18942,
  [18943] = 17527,
  [18944] = 18032,
  [18945] = 18123,
  [18946] = 18124,
  [18947] = 18125,
  [18948] = 18126,
  [18949] = 18127,
  [18950] = 18128,
  [18951] = 18129,
  [18952] = 17924,
  [18953] = 17457,
  [18954] = 18954,
  [18955] = 17536,
  [18956] = 18136,
  [18957] = 18137,
  [18958] = 18138,
  [18959] = 18145,
  [18960] = 17375,
  [18961] = 17537,
  [18962] = 17413,
  [18963] = 18963,
  [18964] = 18151,
  [18965] = 18153,
  [18966] = 18156,
  [18967] = 18162,
  [18968] = 18968,
  [18969] = 17409,
  [18970] = 17799,
  [18971] = 18045,
  [18972] = 18188,
  [18973] = 17876,
  [18974] = 18176,
  [18975] = 18182,
  [18976] = 18183,
  [18977] = 18223,
  [18978] = 18192,
  [18979] = 17454,
  [18980] = 18200,
  [18981] = 17776,
  [18982] = 17472,
  [18983] = 18184,
  [18984] = 17475,
  [18985] = 17477,
  [18986] = 17480,
  [18987] = 18987,
  [18988] = 18217,
  [18989] = 18218,
  [18990] = 18149,
  [18991] = 18991,
  [18992] = 17528,
  [18993] = 18227,
  [18994] = 17568,
  [18995] = 18242,
  [18996] = 18244,
  [18997] = 18245,
  [18998] = 18246,
  [18999] = 18249,
  [19000] = 17418,
  [19001] = 18540,
  [19002] = 18407,
  [19003] = 17405,
  [19004] = 17446,
  [19005] = 19005,
  [19006] = 18261,
  [19007] = 18264,
  [19008] = 17552,
  [19009] = 18269,
  [19010] = 18275,
  [19011] = 19011,
  [19012] = 18285,
  [19013] = 18318,
  [19014] = 17555,
  [19015] = 19015,
  [19016] = 19016,
  [19017] = 17407,
  [19018] = 18295,
  [19019] = 18299,
  [19020] = 17683,
  [19021] = 17380,
  [19022] = 17408,
  [19023] = 18429,
  [19024] = 17430,
  [19025] = 18319,
  [19026] = 17434,
  [19027] = 18214,
  [19028] = 18338,
  [19029] = 17392,
  [19030] = 17482,
  [19031] = 18156,
  [19032] = 17769,
  [19033] = 18265,
  [19034] = 18356,
  [19035] = 18357,
  [19036] = 18359,
  [19037] = 18359,
  [19038] = 18365,
  [19039] = 17538,
  [19040] = 18085,
  [19041] = 19041,
  [19042] = 19042,
  [19043] = 17381,
  [19044] = 18102,
  [19045] = 17506,
  [19046] = 19046,
  [19047] = 18123,
  [19048] = 18124,
  [19049] = 18125,
  [19050] = 18126,
  [19051] = 18127,
  [19052] = 18128,
  [19053] = 18129,
  [19054] = 17924,
  [19055] = 19055,
  [19056] = 19056,
  [19057] = 17547,
  [19058] = 18136,
  [19059] = 18137,
  [19060] = 18138,
  [19061] = 18145,
  [19062] = 17567,
  [19063] = 18183,
  [19064] = 17568,
  [19065] = 18192,
  [19066] = 17953,
  [19067] = 18200,
  [19068] = 17776,
  [19069] = 18242,
  [19070] = 18244,
  [19071] = 18245,
  [19072] = 18246,
  [19073] = 18249,
  [19074] = 17611,
  [19075] = 17450,
  [19076] = 19076,
  [19077] = 18285,
  [19078] = 19078,
  [19079] = 18051,
  [19080] = 19080,
  [19081] = 17422,
  [19082] = 18214,
  [19083] = 18338,
  [19084] = 19084,
  [19085] = 17439,
  [19086] = 18265,
  [19087] = 18356,
  [19088] = 18357,
  [19089] = 18244,
  [19090] = 18365,
  [19091] = 17372,
  [19092] = 18085,
  [19093] = 19093,
  [19094] = 19094,
  [19095] = 18102,
  [19096] = 19096,
  [19097] = 18772,
  [19098] = 18123,
  [19099] = 18124,
  [19100] = 18125,
  [19101] = 18126,
  [19102] = 18127,
  [19103] = 18128,
  [19104] = 18129,
  [19105] = 17924,
  [19106] = 17645,
  [19107] = 17578,
  [19108] = 17648,
  [19109] = 18136,
  [19110] = 18137,
  [19111] = 18138,
  [19112] = 18145,
  [19113] = 17629,
  [19114] = 19114,
  [19115] = 18192,
  [19116] = 19116,
  [19117] = 18200,
  [19118] = 17776,
  [19119] = 18244,
  [19120] = 18245,
  [19121] = 18246,
  [19122] = 18249,
  [19123] = 19123,
  [19124] = 19124,
  [19125] = 18285,
  [19126] = 19126,
  [19127] = 17483,
  [19128] = 19128,
  [19129] = 19129,
  [19130] = 18214,
  [19131] = 18338,
  [19132] = 17584,
  [19133] = 19133,
  [19134] = 18265,
  [19135] = 18356,
  [19136] = 18357,
  [19137] = 19137,
  [19138] = 18365,
  [19139] = 18102,
  [19140] = 18123,
  [19141] = 18124,
  [19142] = 18125,
  [19143] = 18126,
  [19144] = 17924,
  [19145] = 19145,
  [19146] = 17396,
  [19147] = 18136,
  [19148] = 18138,
  [19149] = 18200,
  [19150] = 18246,
  [19151] = 18102,
  [19152] = 18123,
  [19153] = 18124,
  [19154] = 18125,
  [19155] = 18126,
  [19156] = 17924,
  [19157] = 18223,
  [19158] = 17400,
  [19159] = 18136,
  [19160] = 18138,
  [19161] = 18200,
  [19162] = 18246,
  [19163] = 18123,
  [19164] = 18124,
  [19165] = 18125,
  [19166] = 18126,
  [19167] = 17924,
  [19168] = 19168,
  [19169] = 17488,
  [19170] = 18136,
  [19171] = 18138,
  [19172] = 18200,
  [19173] = 18246,
  [19174] = 18123,
  [19175] = 18124,
  [19176] = 18125,
  [19177] = 18126,
  [19178] = 17924,
  [19179] = 19179,
  [19180] = 17489,
  [19181] = 18136,
  [19182] = 18138,
  [19183] = 18200,
  [19184] = 18246,
  [19185] = 18123,
  [19186] = 18124,
  [19187] = 18125,
  [19188] = 18126,
  [19189] = 17924,
  [19190] = 17490,
  [19191] = 17491,
  [19192] = 18136,
  [19193] = 18138,
  [19194] = 18200,
  [19195] = 18246,
  [19196] = 18123,
  [19197] = 18124,
  [19198] = 18125,
  [19199] = 18126,
  [19200] = 17924,
  [19201] = 17493,
  [19202] = 19202,
  [19203] = 18136,
  [19204] = 18138,
  [19205] = 18200,
  [19206] = 18246,
  [19207] = 18123,
  [19208] = 18124,
  [19209] = 18125,
  [19210] = 18126,
  [19211] = 17924,
  [19212] = 17417,
  [19213] = 19213,
  [19214] = 18136,
  [19215] = 18138,
  [19216] = 18200,
  [19217] = 18246,
  [19218] = 19218,
  [19219] = 17842,
  [19220] = 19220,
  [19221] = 19221,
  [19222] = 17426,
  [19223] = 19223,
  [19224] = 17442,
  [19225] = 17431,
  [19226] = 19226,
  [19227] = 17674,
  [19228] = 17432,
  [19229] = 18094,
  [19230] = 17451,
  [19231] = 19231,
  [19232] = 19232,
  [19233] = 19233,
  [19234] = 17763,
  [19235] = 18102,
  [19236] = 17528,
  [19237] = 19237,
  [19238] = 17413,
  [19239] = 18429,
  [19240] = 17429,
  [19241] = 17901,
  [19242] = 17415,
  [19243] = 17416,
  [19244] = 17455,
  [19245] = 17456,
  [19246] = 19246,
  [19247] = 18123,
  [19248] = 18124,
  [19249] = 18125,
  [19250] = 18126,
  [19251] = 19251,
  [19252] = 17450,
  [19253] = 19253,
  [19254] = 17924,
  [19255] = 17451,
  [19256] = 17452,
  [19257] = 18136,
  [19258] = 17823,
  [19259] = 18138,
  [19260] = 19260,
  [19261] = 17683,
  [19262] = 19262,
  [19263] = 17533,
  [19264] = 19231,
  [19265] = 19265,
  [19266] = 17452,
  [19267] = 18319,
  [19268] = 17535,
  [19269] = 17431,
  [19270] = 19270,
  [19271] = 17486,
  [19272] = 17437,
  [19273] = 19273,
  [19274] = 17418,
  [19275] = 19275,
  [19276] = 18134,
  [19277] = 17523,
  [19278] = 17446,
  [19279] = 17438,
  [19280] = 19280,
  [19281] = 17432,
  [19282] = 17527,
  [19283] = 17485,
  [19284] = 17377,
  [19285] = 18032,
  [19286] = 17388,
  [19287] = 17654,
  [19288] = 17415,
  [19289] = 17394,
  [19290] = 18922,
  [19291] = 19042,
  [19292] = 17536,
  [19293] = 17382,
  [19294] = 17430,
  [19295] = 19145,
  [19296] = 19179,
  [19297] = 19297,
  [19298] = 19298,
  [19299] = 19299,
  [19300] = 17455,
  [19301] = 18200,
  [19302] = 17456,
  [19303] = 18020,
  [19304] = 18085,
  [19305] = 17441,
  [19306] = 17533,
  [19307] = 19307,
  [19308] = 17409,
  [19309] = 17535,
  [19310] = 19310,
  [19311] = 17537,
  [19312] = 18245,
  [19313] = 17496,
  [19314] = 19314,
  [19315] = 19315,
  [19316] = 17434,
  [19317] = 17497,
  [19318] = 17499,
  [19319] = 19319,
  [19320] = 19320,
  [19321] = 17500,
  [19322] = 17416,
  [19323] = 17588,
  [19324] = 17777,
  [19325] = 19325,
  [19326] = 19326,
  [19327] = 17436,
  [19328] = 17393,
  [19329] = 17781,
  [19330] = 17458,
  [19331] = 19331,
  [19332] = 17764,
  [19333] = 19333,
  [19334] = 19334,
  [19335] = 17432,
  [19336] = 19336,
  [19337] = 17973,
  [19338] = 17437,
  [19339] = 19339,
  [19340] = 18675,
  [19341] = 18104,
  [19342] = 19342,
  [19343] = 17507,
  [19344] = 19344,
  [19345] = 17725,
  [19346] = 17439,
  [19347] = 18246,
  [19348] = 19348,
  [19349] = 19349,
  [19350] = 19350,
  [19351] = 17562,
  [19352] = 19352,
  [19353] = 19353,
  [19354] = 19354,
  [19355] = 18200,
  [19356] = 19356,
  [19357] = 19357,
  [19358] = 17565,
  [19359] = 17380,
  [19360] = 19360,
  [19361] = 17792,
  [19362] = 17426,
  [19363] = 17453,
  [19364] = 19364,
  [19365] = 18697,
  [19366] = 17419,
  [19367] = 17420,
  [19368] = 17442,
  [19369] = 17424,
  [19370] = 17428,
  [19371] = 19371,
  [19372] = 19372,
  [19373] = 19373,
  [19374] = 19374,
  [19375] = 17396,
  [19376] = 19376,
  [19377] = 19377,
  [19378] = 19372,
  [19379] = 17519,
  [19380] = 18762,
  [19381] = 19381,
  [19382] = 18282,
  [19383] = 19383,
  [19384] = 19384,
  [19385] = 19385,
  [19386] = 17523,
  [19387] = 17437,
  [19388] = 17450,
  [19389] = 17457,
  [19390] = 18736,
  [19391] = 17504,
  [19392] = 17505,
  [19393] = 17506,
  [19394] = 17507,
  [19395] = 19395,
  [19396] = 19396,
  [19397] = 19397,
  [19398] = 19398,
  [19399] = 17451,
  [19400] = 19400,
  [19401] = 19401,
  [19402] = 19402,
  [19403] = 17452,
  [19404] = 19275,
  [19405] = 17537,
  [19406] = 17375,
  [19407] = 18070,
  [19408] = 17389,
  [19409] = 19409,
  [19410] = 19410,
  [19411] = 17455,
  [19412] = 17784,
  [19413] = 19413,
  [19414] = 19414,
  [19415] = 18180,
  [19416] = 19416,
  [19417] = 17456,
  [19418] = 17410,
  [19419] = 19419,
  [19420] = 17409,
  [19421] = 17419,
  [19422] = 17420,
  [19423] = 17424,
  [19424] = 17510,
  [19425] = 19425,
  [19426] = 17511,
  [19427] = 17428,
  [19428] = 18058,
  [19429] = 17454,
  [19430] = 18172,
  [19431] = 19431,
  [19432] = 17472,
  [19433] = 17475,
  [19434] = 17477,
  [19435] = 19435,
  [19436] = 17480,
  [19437] = 17512,
  [19438] = 19438,
  [19439] = 17513,
  [19440] = 19440,
  [19441] = 17438,
  [19442] = 19442,
  [19443] = 17547,
  [19444] = 17562,
  [19445] = 17533,
  [19446] = 19297,
  [19447] = 19447,
  [19448] = 19448,
  [19449] = 17453,
  [19450] = 17457,
  [19451] = 19451,
  [19452] = 17458,
  [19453] = 17375,
  [19454] = 17496,
  [19455] = 19455,
  [19456] = 17497,
  [19457] = 17982,
  [19458] = 19458,
  [19459] = 18112,
  [19460] = 17482,
  [19461] = 17746,
  [19462] = 17499,
  [19463] = 17538,
  [19464] = 19464,
  [19465] = 17611,
  [19466] = 19466,
  [19467] = 19467,
  [19468] = 18365,
  [19469] = 17514,
  [19470] = 17500,
  [19471] = 17409,
  [19472] = 17515,
  [19473] = 17516,
  [19474] = 19474,
  [19475] = 19475,
  [19476] = 18261,
  [19477] = 19477,
  [19478] = 17760,
  [19479] = 19479,
  [19480] = 18032,
  [19481] = 17527,
  [19482] = 17645,
  [19483] = 17648,
  [19484] = 19484,
  [19485] = 17517,
  [19486] = 17772,
  [19487] = 17483,
  [19488] = 17454,
  [19489] = 18223,
  [19490] = 17775,
  [19491] = 17777,
  [19492] = 17629,
  [19493] = 17488,
  [19494] = 17472,
  [19495] = 19495,
  [19496] = 17489,
  [19497] = 17490,
  [19498] = 17475,
  [19499] = 17477,
  [19500] = 19500,
  [19501] = 19501,
  [19502] = 17491,
  [19503] = 17493,
  [19504] = 17565,
  [19505] = 19505,
  [19506] = 19506,
  [19507] = 19507,
  [19508] = 17725,
  [19509] = 17480,
  [19510] = 19510,
  [19511] = 19511,
  [19512] = 17578,
  [19513] = 19513,
  [19514] = 19514,
  [19515] = 19515,
  [19516] = 19516,
  [19517] = 17410,
  [19518] = 17482,
  [19519] = 17483,
  [19520] = 17781,
  [19521] = 17683,
  [19522] = 18138,
  [19523] = 17455,
  [19524] = 18181,
  [19525] = 19525,
  [19526] = 19526,
  [19527] = 19527,
  [19528] = 17674,
  [19529] = 17456,
  [19530] = 17517,
  [19531] = 18429,
  [19532] = 17419,
  [19533] = 19533,
  [19534] = 19534,
  [19535] = 19535,
  [19536] = 17488,
  [19537] = 17605,
  [19538] = 17606,
  [19539] = 17533,
  [19540] = 17528,
  [19541] = 17496,
  [19542] = 17489,
  [19543] = 17497,
  [19544] = 17499,
  [19545] = 17490,
  [19546] = 17500,
  [19547] = 17491,
  [19548] = 17493,
  [19549] = 17384,
  [19550] = 17498,
  [19551] = 17385,
  [19552] = 17800,
  [19553] = 18136,
  [19554] = 19554,
  [19555] = 17551,
  [19556] = 19556,
  [19557] = 19557,
  [19558] = 17426,
  [19559] = 17442,
  [19560] = 19560,
  [19561] = 17876,
  [19562] = 17457,
  [19563] = 17375,
  [19564] = 19564,
  [19565] = 17483,
  [19566] = 17430,
  [19567] = 17725,
  [19568] = 19568,
  [19569] = 19569,
  [19570] = 17371,
  [19571] = 19571,
  [19572] = 17400,
  [19573] = 18288,
  [19574] = 19574,
  [19575] = 19575,
  [19576] = 19576,
  [19577] = 19577,
  [19578] = 17501,
  [19579] = 17385,
  [19580] = 17510,
  [19581] = 17511,
  [19582] = 18287,
  [19583] = 18191,
  [19584] = 17512,
  [19585] = 17513,
  [19586] = 17426,
  [19587] = 17442,
  [19588] = 17502,
  [19589] = 17457,
  [19590] = 17375,
  [19591] = 19591,
  [19592] = 17483,
  [19593] = 18182,
  [19594] = 17746,
  [19595] = 18094,
  [19596] = 17496,
  [19597] = 17504,
  [19598] = 17514,
  [19599] = 19599,
  [19600] = 19600,
  [19601] = 19601,
  [19602] = 19602,
  [19603] = 19603,
  [19604] = 17515,
  [19605] = 19605,
  [19606] = 19606,
  [19607] = 17385,
  [19608] = 17505,
  [19609] = 17516,
  [19610] = 17395,
  [19611] = 17818,
  [19612] = 17760,
  [19613] = 19613,
  [19614] = 17426,
  [19615] = 17442,
  [19616] = 19616,
  [19617] = 17457,
  [19618] = 17375,
  [19619] = 19619,
  [19620] = 17483,
  [19621] = 19621,
  [19622] = 17517,
  [19623] = 19623,
  [19624] = 17506,
  [19625] = 17772,
  [19626] = 19626,
  [19627] = 17507,
  [19628] = 17775,
  [19629] = 19629,
  [19630] = 17777,
  [19631] = 18246,
  [19632] = 19632,
  [19633] = 17369,
  [19634] = 17385,
  [19635] = 17497,
  [19636] = 18122,
  [19637] = 17827,
  [19638] = 19638,
  [19639] = 17499,
  [19640] = 19640,
  [19641] = 17426,
  [19642] = 17442,
  [19643] = 19643,
  [19644] = 17457,
  [19645] = 17375,
  [19646] = 17591,
  [19647] = 17483,
  [19648] = 17500,
  [19649] = 18281,
  [19650] = 19650,
  [19651] = 19651,
  [19652] = 19652,
  [19653] = 17720,
  [19654] = 17508,
  [19655] = 19655,
  [19656] = 18020,
  [19657] = 19657,
  [19658] = 17385,
  [19659] = 17510,
  [19660] = 17380,
  [19661] = 17511,
  [19662] = 17381,
  [19663] = 18145,
  [19664] = 17512,
  [19665] = 17426,
  [19666] = 17442,
  [19667] = 17441,
  [19668] = 17457,
  [19669] = 17375,
  [19670] = 17513,
  [19671] = 17483,
  [19672] = 18218,
  [19673] = 17382,
  [19674] = 19674,
  [19675] = 19675,
  [19676] = 17514,
  [19677] = 17515,
  [19678] = 17384,
  [19679] = 17516,
  [19680] = 18264,
  [19681] = 17625,
  [19682] = 17385,
  [19683] = 17386,
  [19684] = 17517,
  [19685] = 17388,
  [19686] = 17381,
  [19687] = 17852,
  [19688] = 19688,
  [19689] = 17426,
  [19690] = 17442,
  [19691] = 17405,
  [19692] = 17457,
  [19693] = 17375,
  [19694] = 17535,
  [19695] = 17483,
  [19696] = 19696,
  [19697] = 17371,
  [19698] = 17434,
  [19699] = 17385,
  [19700] = 17392,
  [19701] = 17394,
  [19702] = 19702,
  [19703] = 17677,
  [19704] = 19704,
  [19705] = 19705,
  [19706] = 17426,
  [19707] = 17442,
  [19708] = 19708,
  [19709] = 17457,
  [19710] = 17375,
  [19711] = 17382,
  [19712] = 17483,
  [19713] = 19713,
  [19714] = 19714,
  [19715] = 19715,
  [19716] = 17564,
  [19717] = 17418,
  [19718] = 18172,
  [19719] = 19719,
  [19720] = 19720,
  [19721] = 17510,
  [19722] = 19348,
  [19723] = 18188,
  [19724] = 19724,
  [19725] = 18190,
  [19726] = 17508,
  [19727] = 18201,
  [19728] = 17511,
  [19729] = 19729,
  [19730] = 17531,
  [19731] = 17512,
  [19732] = 18058,
  [19733] = 17513,
  [19734] = 19734,
  [19735] = 19735,
  [19736] = 19736,
  [19737] = 17437,
  [19738] = 19738,
  [19739] = 17370,
  [19740] = 17508,
  [19741] = 18249,
  [19742] = 19742,
  [19743] = 17781,
  [19744] = 19744,
  [19745] = 17418,
  [19746] = 17650,
  [19747] = 17430,
  [19748] = 19748,
  [19749] = 17682,
  [19750] = 19750,
  [19751] = 18227,
  [19752] = 19752,
  [19753] = 19704,
  [19754] = 17508,
  [19755] = 19755,
  [19756] = 18120,
  [19757] = 19757,
  [19758] = 17395,
  [19759] = 18407,
  [19760] = 17772,
  [19761] = 19761,
  [19762] = 17536,
  [19763] = 19763,
  [19764] = 17537,
  [19765] = 17386,
  [19766] = 17631,
  [19767] = 17379,
  [19768] = 17508,
  [19769] = 19769,
  [19770] = 19770,
  [19771] = 5533,
  [19772] = 5534,
  [19773] = 17746,
  [19774] = 19774,
  [19775] = 19775,
  [19776] = 17800,
  [19777] = 19777,
  [19778] = 18540,
  [19779] = 19779,
  [19780] = 19780,
  [19781] = 17584,
  [19782] = 17508,
  [19783] = 19783,
  [19784] = 17544,
  [19785] = 19785,
  [19786] = 19786,
  [19787] = 19787,
  [19788] = 19788,
  [19789] = 19789,
  [19790] = 19715,
  [19791] = 17551,
  [19792] = 19792,
  [19793] = 17798,
  [19794] = 19794,
  [19795] = 19795,
  [19796] = 17508,
  [19797] = 17871,
  [19798] = 19798,
  [19799] = 18123,
  [19800] = 18124,
  [19801] = 19801,
  [19802] = 18125,
  [19803] = 19803,
  [19804] = 19804,
  [19805] = 19805,
  [19806] = 19806,
  [19807] = 19807,
  [19808] = 17935,
  [19809] = 17832,
  [19810] = 17508,
  [19811] = 17953,
  [19812] = 17686,
  [19813] = 17431,
  [19814] = 18127,
  [19815] = 18128,
  [19816] = 18129,
  [19817] = 17432,
  [19818] = 18137,
  [19819] = 17421,
  [19820] = 17374,
  [19821] = 18244,
  [19822] = 18245,
  [19823] = 18282,
  [19824] = 18214,
  [19825] = 18265,
  [19826] = 18127,
  [19827] = 18128,
  [19828] = 18129,
  [19829] = 17994,
  [19830] = 18137,
  [19831] = 19831,
  [19832] = 18244,
  [19833] = 18245,
  [19834] = 18214,
  [19835] = 18265,
  [19836] = 18127,
  [19837] = 18128,
  [19838] = 18129,
  [19839] = 19839,
  [19840] = 18137,
  [19841] = 17799,
  [19842] = 18244,
  [19843] = 18245,
  [19844] = 18214,
  [19845] = 18265,
  [19846] = 18127,
  [19847] = 18128,
  [19848] = 18129,
  [19849] = 17376,
  [19850] = 18137,
  [19851] = 19851,
  [19852] = 18244,
  [19853] = 18245,
  [19854] = 18214,
  [19855] = 18265,
  [19856] = 18127,
  [19857] = 18128,
  [19858] = 18129,
  [19859] = 19859,
  [19860] = 18137,
  [19861] = 19861,
  [19862] = 18244,
  [19863] = 18245,
  [19864] = 18214,
  [19865] = 18265,
  [19866] = 18127,
  [19867] = 18128,
  [19868] = 18129,
  [19869] = 19869,
  [19870] = 18137,
  [19871] = 18126,
  [19872] = 18244,
  [19873] = 18245,
  [19874] = 18214,
  [19875] = 18265,
  [19876] = 18127,
  [19877] = 18128,
  [19878] = 18129,
  [19879] = 17437,
  [19880] = 18137,
  [19881] = 19881,
  [19882] = 18244,
  [19883] = 18245,
  [19884] = 18214,
  [19885] = 18265,
  [19886] = 17385,
  [19887] = 17764,
  [19888] = 17438,
  [19889] = 17494,
  [19890] = 19890,
  [19891] = 19891,
  [19892] = 17421,
  [19893] = 18094,
  [19894] = 17764,
  [19895] = 17494,
  [19896] = 19896,
  [19897] = 19233,
  [19898] = 17763,
  [19899] = 18102,
  [19900] = 18020,
  [19901] = 17429,
  [19902] = 17901,
  [19903] = 17441,
  [19904] = 18675,
  [19905] = 19905,
  [19906] = 19251,
  [19907] = 19907,
  [19908] = 17823,
  [19909] = 18891,
  [19910] = 19231,
  [19911] = 18233,
  [19912] = 18069,
  [19913] = 17377,
  [19914] = 18922,
  [19915] = 19042,
  [19916] = 19297,
  [19917] = 19299,
  [19918] = 18429,
  [19919] = 19919,
  [19920] = 17430,
  [19921] = 19331,
  [19922] = 19334,
  [19923] = 18127,
  [19924] = 19348,
  [19925] = 19925,
  [19926] = 18697,
  [19927] = 19372,
  [19928] = 18282,
  [19929] = 18736,
  [19930] = 19930,
  [19931] = 18675,
  [19932] = 19275,
  [19933] = 17991,
  [19934] = 19934,
  [19935] = 17784,
  [19936] = 19936,
  [19937] = 17552,
  [19938] = 17399,
  [19939] = 17420,
  [19940] = 19940,
  [19941] = 18269,
  [19942] = 18131,
  [19943] = 17713,
  [19944] = 18094,
  [19945] = 18054,
  [19946] = 17434,
  [19947] = 18201,
  [19948] = 19233,
  [19949] = 17763,
  [19950] = 18102,
  [19951] = 17528,
  [19952] = 17429,
  [19953] = 17901,
  [19954] = 17555,
  [19955] = 17392,
  [19956] = 19554,
  [19957] = 19251,
  [19958] = 19958,
  [19959] = 17823,
  [19960] = 19960,
  [19961] = 19231,
  [19962] = 17713,
  [19963] = 17654,
  [19964] = 17377,
  [19965] = 18922,
  [19966] = 19042,
  [19967] = 19297,
  [19968] = 19299,
  [19969] = 17389,
  [19970] = 17528,
  [19971] = 19971,
  [19972] = 19331,
  [19973] = 19334,
  [19974] = 19348,
  [19975] = 19975,
  [19976] = 18697,
  [19977] = 19372,
  [19978] = 18282,
  [19979] = 18736,
  [19980] = 19980,
  [19981] = 19981,
  [19982] = 19275,
  [19983] = 19983,
  [19984] = 19984,
  [19985] = 17784,
  [19986] = 19986,
  [19987] = 19987,
  [19988] = 18172,
  [19989] = 19989,
  [19990] = 17421,
  [19991] = 17832,
  [19992] = 17410,
  [19993] = 17419,
  [19994] = 18094,
  [19995] = 17420,
  [19996] = 17424,
  [19997] = 17428,
  [19998] = 19233,
  [19999] = 17763,
  [20000] = 17747,
  [20001] = 17429,
  [20002] = 17901,
  [20003] = 20003,
  [20004] = 18128,
  [20005] = 17436,
  [20006] = 19251,
  [20007] = 20007,
  [20008] = 17823,
  [20009] = 17764,
  [20010] = 19231,
  [20011] = 20011,
  [20012] = 17453,
  [20013] = 17377,
  [20014] = 18922,
  [20015] = 19297,
  [20016] = 19299,
  [20017] = 17388,
  [20018] = 20018,
  [20019] = 18116,
  [20020] = 19331,
  [20021] = 19334,
  [20022] = 19348,
  [20023] = 20023,
  [20024] = 18697,
  [20025] = 19372,
  [20026] = 18736,
  [20027] = 20027,
  [20028] = 20028,
  [20029] = 19275,
  [20030] = 18772,
  [20031] = 20031,
  [20032] = 17784,
  [20033] = 20033,
  [20034] = 17458,
  [20035] = 17494,
  [20036] = 20036,
  [20037] = 18094,
  [20038] = 20038,
  [20039] = 20039,
  [20040] = 17654,
  [20041] = 17763,
  [20042] = 20042,
  [20043] = 17901,
  [20044] = 20044,
  [20045] = 19251,
  [20046] = 17823,
  [20047] = 17486,
  [20048] = 17521,
  [20049] = 17377,
  [20050] = 19299,
  [20051] = 18763,
  [20052] = 20052,
  [20053] = 20053,
  [20054] = 19331,
  [20055] = 19334,
  [20056] = 19348,
  [20057] = 20057,
  [20058] = 18697,
  [20059] = 19372,
  [20060] = 18736,
  [20061] = 20061,
  [20062] = 19275,
  [20063] = 20063,
  [20064] = 17784,
  [20065] = 20065,
  [20066] = 17588,
  [20067] = 18094,
  [20068] = 20068,
  [20069] = 17405,
  [20070] = 17832,
  [20071] = 17901,
  [20072] = 20072,
  [20073] = 19251,
  [20074] = 17823,
  [20075] = 17798,
  [20076] = 19299,
  [20077] = 17799,
  [20078] = 20078,
  [20079] = 18129,
  [20080] = 19331,
  [20081] = 19348,
  [20082] = 20082,
  [20083] = 20083,
  [20084] = 17567,
  [20085] = 18094,
  [20086] = 20086,
  [20087] = 20087,
  [20088] = 20088,
  [20089] = 17901,
  [20090] = 19251,
  [20091] = 17823,
  [20092] = 17991,
  [20093] = 17568,
  [20094] = 17540,
  [20095] = 20095,
  [20096] = 19348,
  [20097] = 20097,
  [20098] = 20098,
  [20099] = 18338,
  [20100] = 17992,
  [20101] = 18116,
  [20102] = 18116,
  [20103] = 17823,
  [20104] = 17498,
  [20105] = 20105,
  [20106] = 17545,
  [20107] = 18051,
  [20108] = 17823,
  [20109] = 17501,
  [20110] = 17502,
  [20111] = 17953,
  [20112] = 17486,
  [20113] = 17823,
  [20114] = 17504,
  [20115] = 17505,
  [20116] = 20116,
  [20117] = 20117,
  [20118] = 17823,
  [20119] = 17506,
  [20120] = 17507,
  [20121] = 20121,
  [20122] = 17994,
  [20123] = 17823,
  [20124] = 20124,
  [20125] = 17521,
  [20126] = 17720,
  [20127] = 17508,
  [20128] = 17823,
  [20129] = 20129,
  [20130] = 17432,
  [20131] = 18134,
  [20132] = 17407,
  [20133] = 17823,
  [20134] = 17713,
  [20135] = 18069,
  [20136] = 20136,
  [20137] = 17818,
  [20138] = 18054,
  [20139] = 17712,
  [20140] = 17578,
  [20141] = 20141,
  [20142] = 17528,
  [20143] = 20143,
  [20144] = 20144,
  [20145] = 20145,
  [20146] = 17544,
  [20147] = 18151,
  [20148] = 17460,
  [20149] = 18066,
  [20150] = 19251,
  [20151] = 17560,
  [20152] = 17588,
  [20153] = 17514,
  [20154] = 17544,
  [20155] = 17749,
  [20156] = 17503,
  [20157] = 20157,
  [20158] = 17632,
  [20159] = 20159,
  [20160] = 17531,
  [20161] = 17515,
  [20162] = 18343,
  [20163] = 20163,
  [20164] = 19763,
  [20165] = 19331,
  [20166] = 20166,
  [20167] = 20167,
  [20168] = 17584,
  [20169] = 18134,
  [20170] = 17536,
  [20171] = 17516,
  [20172] = 17537,
  [20173] = 18045,
  [20174] = 17654,
  [20175] = 18176,
  [20176] = 17876,
  [20177] = 18180,
  [20178] = 19801,
  [20179] = 19213,
  [20180] = 19357,
  [20181] = 17992,
  [20182] = 18149,
  [20183] = 18069,
  [20184] = 17369,
  [20185] = 18051,
  [20186] = 18227,
  [20187] = 20187,
  [20188] = 18172,
  [20189] = 17414,
  [20190] = 17519,
  [20191] = 17385,
  [20192] = 20192,
  [20193] = 18675,
  [20194] = 18201,
  [20195] = 17560,
  [20196] = 20196,
  [20197] = 17540,
  [20198] = 17545,
  [20199] = 17552,
  [20200] = 18264,
  [20201] = 20201,
  [20202] = 18269,
  [20203] = 18275,
  [20204] = 17832,
  [20205] = 18762,
  [20206] = 18763,
  [20207] = 17555,
  [20208] = 20192,
  [20209] = 20209,
  [20210] = 18299,
  [20211] = 19376,
  [20212] = 17426,
  [20213] = 17442,
  [20214] = 17393,
  [20215] = 17876,
  [20216] = 17457,
  [20217] = 17375,
  [20218] = 17454,
  [20219] = 17886,
  [20220] = 17483,
  [20221] = 19246,
  [20222] = 17472,
  [20223] = 17426,
  [20224] = 18116,
  [20225] = 20225,
  [20226] = 17547,
  [20227] = 17611,
  [20228] = 20228,
  [20229] = 17431,
  [20230] = 17408,
  [20231] = 18288,
  [20232] = 17475,
  [20233] = 20233,
  [20234] = 20234,
  [20235] = 17567,
  [20236] = 17568,
  [20237] = 17439,
  [20238] = 17519,
  [20239] = 17629,
  [20240] = 17370,
  [20241] = 17379,
  [20242] = 18069,
  [20243] = 18181,
  [20244] = 17386,
  [20245] = 17418,
  [20246] = 17674,
  [20247] = 17760,
  [20248] = 17578,
  [20249] = 17503,
  [20250] = 20250,
  [20251] = 17781,
  [20252] = 20252,
  [20253] = 20253,
  [20254] = 17477,
  [20255] = 17800,
  [20256] = 17584,
  [20257] = 20257,
  [20258] = 18762,
  [20259] = 18763,
  [20260] = 17876,
  [20261] = 17551,
  [20262] = 17486,
  [20263] = 17372,
  [20264] = 17876,
  [20265] = 17521,
  [20266] = 18140,
  [20267] = 18241,
  [20268] = 17876,
  [20269] = 20269,
  [20270] = 17480,
  [20271] = 17632,
  [20272] = 17519,
  [20273] = 18407,
  [20274] = 17518,
  [20275] = 18217,
  [20276] = 17369,
  [20277] = 17588,
  [20278] = 17393,
  [20279] = 17781,
  [20280] = 19145,
  [20281] = 19179,
  [20282] = 18282,
  [20283] = 18282,
  [20284] = 18282,
  [20285] = 17460,
  [20286] = 18066,
  [20287] = 17588,
  [20288] = 20288,
  [20289] = 18343,
  [20290] = 19763,
  [20291] = 18192,
  [20292] = 17827,
  [20293] = 19801,
  [20294] = 19213,
  [20295] = 19357,
  [20296] = 17749,
  [20297] = 17827,
  [20298] = 20192,
  [20299] = 19376,
  [20300] = 17460,
  [20301] = 18066,
  [20302] = 20302,
  [20303] = 18183,
  [20304] = 18343,
  [20305] = 19763,
  [20306] = 17600,
  [20307] = 17508,
  [20308] = 19213,
  [20309] = 19357,
  [20310] = 17422,
  [20311] = 20311,
  [20312] = 20192,
  [20313] = 19376,
  [20314] = 17460,
  [20315] = 18066,
  [20316] = 20316,
  [20317] = 20317,
  [20318] = 18343,
  [20319] = 19763,
  [20320] = 20320,
  [20321] = 18294,
  [20322] = 19213,
  [20323] = 19357,
  [20324] = 20324,
  [20325] = 20325,
  [20326] = 20192,
  [20327] = 19376,
  [20328] = 17460,
  [20329] = 18343,
  [20330] = 19763,
  [20331] = 17434,
  [20332] = 17625,
  [20333] = 19213,
  [20334] = 19357,
  [20335] = 17371,
  [20336] = 17485,
  [20337] = 20192,
  [20338] = 19376,
  [20339] = 17460,
  [20340] = 18343,
  [20341] = 19763,
  [20342] = 18282,
  [20343] = 20343,
  [20344] = 19213,
  [20345] = 19357,
  [20346] = 20346,
  [20347] = 20192,
  [20348] = 19376,
  [20349] = 17460,
  [20350] = 18343,
  [20351] = 19763,
  [20352] = 20352,
  [20353] = 19213,
  [20354] = 19357,
  [20355] = 20192,
  [20356] = 19376,
  [20357] = 18343,
  [20358] = 20192,
  [20359] = 19376,
  [20360] = 18343,
  [20361] = 20192,
  [20362] = 19376,
  [20363] = 18343,
  [20364] = 20192,
  [20365] = 19376,
  [20366] = 18343,
  [20367] = 20192,
  [20368] = 19376,
  [20369] = 18343,
  [20370] = 20192,
  [20371] = 19376,
  [20372] = 18343,
  [20373] = 20192,
  [20374] = 19376,
  [20375] = 18343,
  [20376] = 20192,
  [20377] = 19376,
  [20378] = 17540,
  [20379] = 17545,
  [20380] = 17798,
  [20381] = 17799,
  [20382] = 17812,
  [20383] = 18162,
  [20384] = 17407,
  [20385] = 17374,
  [20386] = 17415,
  [20387] = 17393,
  [20388] = 19297,
  [20389] = 19414,
  [20390] = 17376,
  [20391] = 17547,
  [20392] = 20392,
  [20393] = 19801,
  [20394] = 17385,
  [20395] = 19638,
  [20396] = 17605,
  [20397] = 19334,
  [20398] = 17606,
  [20399] = 20399,
  [20400] = 18288,
  [20401] = 17503,
  [20402] = 18545,
  [20403] = 20403,
  [20404] = 20228,
  [20405] = 20405,
  [20406] = 17427,
  [20407] = 20407,
  [20408] = 20408,
  [20409] = 17508,
  [20410] = 18181,
  [20411] = 20411,
  [20412] = 17889,
  [20413] = 17416,
  [20414] = 20414,
  [20415] = 17399,
  [20416] = 17781,
  [20417] = 17439,
  [20418] = 17551,
  [20419] = 17424,
  [20420] = 19414,
  [20421] = 19801,
  [20422] = 18545,
  [20423] = 20228,
  [20424] = 20424,
  [20425] = 17605,
  [20426] = 19414,
  [20427] = 19801,
  [20428] = 18545,
  [20429] = 20228,
  [20430] = 17606,
  [20431] = 20431,
  [20432] = 19414,
  [20433] = 19801,
  [20434] = 18545,
  [20435] = 20228,
  [20436] = 20436,
  [20437] = 20437,
  [20438] = 19414,
  [20439] = 19801,
  [20440] = 18545,
  [20441] = 20228,
  [20442] = 17405,
  [20443] = 20443,
  [20444] = 19801,
  [20445] = 18545,
  [20446] = 20228,
  [20447] = 20447,
  [20448] = 18545,
  [20449] = 20228,
  [20450] = 18545,
  [20451] = 20228,
  [20452] = 18545,
  [20453] = 20228,
  [20454] = 18545,
  [20455] = 20228,
  [20456] = 18545,
  [20457] = 20228,
  [20458] = 18545,
  [20459] = 20228,
  [20460] = 18545,
  [20461] = 20228,
  [20462] = 18545,
  [20463] = 20228,
  [20464] = 19137,
  [20465] = 18896,
  [20466] = 17632,
  [20467] = 18102,
  [20468] = 18127,
  [20469] = 18128,
  [20470] = 18129,
  [20471] = 20471,
  [20472] = 20472,
  [20473] = 18137,
  [20474] = 18287,
  [20475] = 19145,
  [20476] = 19179,
  [20477] = 20477,
  [20478] = 20478,
  [20479] = 18244,
  [20480] = 18245,
  [20481] = 18282,
  [20482] = 19126,
  [20483] = 18214,
  [20484] = 18265,
  [20485] = 19137,
  [20486] = 18896,
  [20487] = 17407,
  [20488] = 20488,
  [20489] = 19137,
  [20490] = 18153,
  [20491] = 20491,
  [20492] = 19137,
  [20493] = 19299,
  [20494] = 20494,
  [20495] = 19137,
  [20496] = 20496,
  [20497] = 17428,
  [20498] = 19137,
  [20499] = 20499,
  [20500] = 20500,
  [20501] = 19233,
  [20502] = 17408,
  [20503] = 20503,
  [20504] = 20504,
  [20505] = 20505,
  [20506] = 17404,
  [20507] = 20507,
  [20508] = 17457,
  [20509] = 17422,
  [20510] = 18896,
  [20511] = 17823,
  [20512] = 20512,
  [20513] = 20513,
  [20514] = 18287,
  [20515] = 20515,
  [20516] = 17934,
  [20517] = 18069,
  [20518] = 18896,
  [20519] = 18896,
  [20520] = 18896,
  [20521] = 18896,
  [20522] = 18896,
  [20523] = 18343,
  [20524] = 19801,
  [20525] = 18031,
  [20526] = 20192,
  [20527] = 19376,
  [20528] = 18071,
  [20529] = 18545,
  [20530] = 20228,
  [20531] = 18896,
  [20532] = 18275,
  [20533] = 17399,
};

static TSCharacterRange sym_edge_symbol_character_set_1[] = {
  {'*', '*'}, {'F', 'F'}, {'N', 'N'}, {'P', 'P'}, {'R', 'R'}, {'f', 'f'}, {'n', 'n'}, {'p', 'p'},
  {'r', 'r'},
};

static TSCharacterRange sym_hex_number_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {'0', '9'}, {'?', '?'}, {'A', 'F'}, {'X', 'X'}, {'Z', 'Z'}, {'a', 'f'},
  {'x', 'x'}, {'z', 'z'},
};

static TSCharacterRange sym_hex_number_character_set_2[] = {
  {'0', '9'}, {'?', '?'}, {'A', 'F'}, {'X', 'X'}, {'Z', 'Z'}, {'_', '_'}, {'a', 'f'}, {'x', 'x'},
  {'z', 'z'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(374);
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 447,
        '$', 481,
        '%', 497,
        '&', 621,
        '\'', 646,
        '(', 406,
        ')', 408,
        '*', 474,
        '+', 488,
        ',', 409,
        '-', 541,
        '.', 450,
        '/', 435,
        '0', 457,
        '1', 460,
        '2', 462,
        ':', 444,
        ';', 441,
        '<', 382,
        '=', 412,
        '>', 391,
        '?', 616,
        '@', 572,
        'P', 555,
        '[', 466,
        '\\', 678,
        ']', 468,
        '^', 629,
        '`', 420,
        '{', 451,
        '|', 625,
        '}', 452,
        '~', 597,
        0x2013, 492,
        'B', 553,
        'b', 553,
        'X', 551,
        'x', 551,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (lookahead == 'F' ||
          lookahead == 'N' ||
          lookahead == 'R' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'p' ||
          lookahead == 'r') ADVANCE(556);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(645);
      if (lookahead != 0) ADVANCE(644);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(417);
      if (lookahead == '/') ADVANCE(66);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(83);
      if (lookahead == '/') ADVANCE(376);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(379);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(380);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(83);
      if (lookahead == '/') ADVANCE(385);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(388);
      if (lookahead != 0 &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(389);
      END_STATE();
    case 5:
      if (lookahead == '\r') ADVANCE(403);
      if (lookahead != 0) ADVANCE(402);
      END_STATE();
    case 6:
      if (lookahead == '\r') ADVANCE(401);
      if (lookahead == '*') ADVANCE(395);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 447,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 88,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '@', 573,
        '[', 68,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 626,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 56,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 647,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 442,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 69,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 597,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 445,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 647,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 597,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 445,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 647,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '@', 573,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 597,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '#', 448,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 647,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 546,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '@', 571,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 597,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 88,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '/', 434,
        '0', 664,
        ':', 86,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 73,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 522,
        '"', 375,
        '$', 481,
        '%', 496,
        '&', 620,
        '\'', 88,
        '(', 405,
        '*', 475,
        '+', 487,
        '-', 543,
        '/', 434,
        '0', 664,
        ':', 442,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 628,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 105,
        '#', 447,
        '$', 226,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        '1', 663,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 465,
        '\\', 678,
        '^', 630,
        '|', 626,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(664);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 105,
        '#', 447,
        '%', 497,
        '&', 621,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 476,
        '+', 489,
        ',', 409,
        '-', 545,
        '.', 449,
        '/', 435,
        ':', 443,
        '<', 382,
        '=', 411,
        '>', 391,
        '?', 616,
        '[', 465,
        '^', 629,
        '|', 625,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 105,
        '#', 447,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 465,
        '^', 630,
        '|', 626,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 105,
        '#', 447,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 465,
        '\\', 678,
        '^', 630,
        '|', 626,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '$', 315,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 466,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '%', 497,
        '&', 621,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 476,
        '+', 489,
        ',', 409,
        '-', 545,
        '.', 449,
        '/', 435,
        ':', 443,
        '<', 382,
        '=', 412,
        '>', 391,
        '?', 616,
        '[', 466,
        '^', 629,
        '|', 627,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 466,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '%', 496,
        '&', 620,
        '\'', 649,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        '0', 666,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 466,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(662);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '%', 496,
        '&', 623,
        '\'', 648,
        ')', 408,
        '*', 475,
        '+', 490,
        ',', 409,
        '-', 548,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        ']', 468,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 200,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        '0', 99,
        '1', 94,
        ':', 85,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 200,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 490,
        ',', 409,
        '-', 548,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 420,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 200,
        '%', 496,
        '&', 620,
        '\'', 649,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        '0', 666,
        ':', 85,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(662);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 200,
        '%', 496,
        '&', 623,
        '(', 65,
        '*', 473,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 100,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(665);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 315,
        '%', 496,
        '&', 623,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 477,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '$', 315,
        '%', 496,
        '&', 623,
        '\'', 648,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 497,
        '&', 621,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 476,
        '+', 489,
        ',', 409,
        '-', 545,
        '.', 449,
        '/', 435,
        ':', 443,
        '<', 382,
        '=', 412,
        '>', 391,
        '?', 616,
        '[', 467,
        '^', 629,
        '|', 627,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 497,
        '&', 621,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 476,
        '+', 489,
        ',', 409,
        '-', 545,
        '.', 449,
        '/', 435,
        ':', 443,
        '<', 382,
        '=', 411,
        '>', 391,
        '?', 616,
        '[', 464,
        '^', 629,
        '|', 627,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(30);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 467,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(31);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 486,
        ',', 409,
        '-', 547,
        '.', 449,
        '/', 434,
        ':', 443,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 467,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        '*', 475,
        '+', 487,
        '-', 543,
        '.', 449,
        '/', 434,
        ':', 443,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        ']', 468,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 443,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 467,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 405,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 85,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '^', 630,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 37:
      ADVANCE_MAP(
        '!', 105,
        '#', 445,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 405,
        '*', 475,
        '+', 490,
        '-', 548,
        '.', 449,
        '/', 434,
        ':', 443,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        ']', 468,
        '^', 630,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(37);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        '!', 105,
        '#', 448,
        '$', 310,
        '%', 497,
        '&', 621,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 476,
        '+', 489,
        ',', 409,
        '-', 544,
        '.', 449,
        '/', 435,
        ':', 443,
        ';', 441,
        '<', 382,
        '=', 411,
        '>', 391,
        '?', 616,
        '@', 571,
        '[', 464,
        '\\', 678,
        '^', 629,
        '{', 451,
        '|', 627,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(38);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 39:
      ADVANCE_MAP(
        '!', 105,
        '#', 448,
        '$', 310,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        '*', 475,
        '+', 487,
        '-', 542,
        '.', 449,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '@', 571,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(39);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 40:
      ADVANCE_MAP(
        '!', 105,
        '#', 55,
        '%', 496,
        '&', 620,
        '(', 405,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        ':', 86,
        ';', 441,
        '<', 383,
        '=', 108,
        '>', 392,
        '?', 616,
        '[', 69,
        ']', 468,
        '^', 630,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(40);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 41:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '#', 446,
        '$', 481,
        '&', 619,
        '\'', 647,
        '(', 405,
        ')', 408,
        '*', 472,
        '+', 486,
        ',', 409,
        '-', 540,
        '.', 449,
        '/', 66,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 102,
        '=', 410,
        '>', 123,
        '@', 571,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '}', 452,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 42:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '#', 56,
        '$', 481,
        '&', 619,
        '\'', 88,
        '(', 406,
        ')', 408,
        '+', 486,
        ',', 409,
        '-', 540,
        '.', 450,
        '/', 66,
        '0', 664,
        ':', 86,
        '<', 381,
        '@', 570,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '}', 452,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(42);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 43:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '#', 445,
        '$', 481,
        '&', 619,
        '\'', 88,
        '(', 405,
        ')', 408,
        '*', 114,
        '+', 485,
        ',', 409,
        '-', 539,
        '.', 450,
        '/', 66,
        '0', 664,
        ':', 442,
        ';', 441,
        '=', 115,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '}', 452,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(43);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 44:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '#', 448,
        '$', 481,
        '&', 619,
        '\'', 88,
        '(', 406,
        '+', 486,
        '-', 546,
        '.', 450,
        '/', 66,
        '0', 664,
        ';', 441,
        '@', 571,
        '[', 464,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(44);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '#', 59,
        '$', 481,
        '&', 619,
        '\'', 88,
        '(', 405,
        '+', 486,
        '-', 540,
        '/', 66,
        '0', 664,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '$', 481,
        '&', 619,
        '\'', 87,
        '(', 406,
        '+', 486,
        '-', 540,
        '/', 66,
        '0', 458,
        '1', 461,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(46);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 47:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '$', 482,
        '&', 619,
        '\'', 89,
        '(', 405,
        '*', 472,
        '+', 485,
        '-', 539,
        '/', 66,
        '0', 664,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '$', 345,
        '&', 619,
        '\'', 89,
        '(', 406,
        '+', 485,
        '-', 539,
        '.', 449,
        '/', 66,
        '0', 664,
        '[', 464,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '!', 521,
        '"', 375,
        '$', 345,
        '&', 622,
        '\'', 88,
        '(', 405,
        ')', 408,
        '*', 114,
        '+', 485,
        ',', 409,
        '-', 539,
        '.', 450,
        '/', 66,
        '0', 664,
        ':', 442,
        '=', 115,
        '?', 616,
        '[', 464,
        '\\', 678,
        '^', 630,
        '`', 419,
        '{', 451,
        '|', 624,
        '~', 597,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '!', 113,
        '"', 375,
        '#', 448,
        '$', 481,
        '%', 496,
        '\'', 88,
        '(', 406,
        '*', 475,
        '+', 486,
        '-', 77,
        '.', 449,
        '/', 434,
        '0', 664,
        ':', 443,
        ';', 441,
        '<', 384,
        '=', 413,
        '>', 390,
        '@', 571,
        '[', 464,
        '\\', 678,
        '`', 419,
        '{', 451,
        0x2013, 493,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(50);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(661);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 51:
      if (lookahead == '"') ADVANCE(375);
      if (lookahead == '/') ADVANCE(639);
      if (lookahead == '\\') ADVANCE(1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(642);
      if (lookahead != 0) ADVANCE(643);
      END_STATE();
    case 52:
      if (lookahead == '"') ADVANCE(484);
      if (lookahead == '-') ADVANCE(126);
      END_STATE();
    case 53:
      if (lookahead == '"') ADVANCE(483);
      END_STATE();
    case 54:
      ADVANCE_MAP(
        '#', 447,
        '(', 405,
        ')', 408,
        ',', 409,
        '.', 449,
        '/', 66,
        ':', 443,
        ';', 441,
        '=', 410,
        '[', 464,
        '\\', 678,
        '|', 80,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(54);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 55:
      if (lookahead == '#') ADVANCE(509);
      END_STATE();
    case 56:
      if (lookahead == '#') ADVANCE(509);
      if (lookahead == '0') ADVANCE(580);
      END_STATE();
    case 57:
      if (lookahead == '#') ADVANCE(506);
      END_STATE();
    case 58:
      if (lookahead == '#') ADVANCE(507);
      END_STATE();
    case 59:
      if (lookahead == '#') ADVANCE(508);
      END_STATE();
    case 60:
      if (lookahead == '&') ADVANCE(578);
      END_STATE();
    case 61:
      if (lookahead == '&') ADVANCE(60);
      if (lookahead == '=') ADVANCE(562);
      END_STATE();
    case 62:
      if (lookahead == '\'') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(62);
      END_STATE();
    case 63:
      if (lookahead == '(') ADVANCE(405);
      if (lookahead == '/') ADVANCE(66);
      if (lookahead == ':') ADVANCE(442);
      if (lookahead == 'e') ADVANCE(287);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'B' ||
          lookahead == 'X' ||
          lookahead == 'b' ||
          lookahead == 'x') ADVANCE(552);
      if (set_contains(sym_edge_symbol_character_set_1, 9, lookahead)) ADVANCE(554);
      END_STATE();
    case 64:
      if (lookahead == ')') ADVANCE(671);
      if (lookahead == ':') ADVANCE(101);
      if (lookahead == '=') ADVANCE(559);
      if (lookahead == '>') ADVANCE(581);
      END_STATE();
    case 65:
      if (lookahead == '*') ADVANCE(670);
      END_STATE();
    case 66:
      if (lookahead == '*') ADVANCE(71);
      if (lookahead == '/') ADVANCE(676);
      END_STATE();
    case 67:
      if (lookahead == '*') ADVANCE(71);
      if (lookahead == '/') ADVANCE(676);
      if (lookahead == '=') ADVANCE(560);
      END_STATE();
    case 68:
      if (lookahead == '*') ADVANCE(513);
      if (lookahead == '+') ADVANCE(130);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '=') ADVANCE(516);
      END_STATE();
    case 69:
      if (lookahead == '*') ADVANCE(513);
      if (lookahead == '+') ADVANCE(130);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '=') ADVANCE(516);
      if (lookahead == 0x2013) ADVANCE(119);
      END_STATE();
    case 70:
      if (lookahead == '*') ADVANCE(70);
      if (lookahead == '/') ADVANCE(672);
      if (lookahead != 0) ADVANCE(71);
      END_STATE();
    case 71:
      if (lookahead == '*') ADVANCE(70);
      if (lookahead != 0) ADVANCE(71);
      END_STATE();
    case 72:
      if (lookahead == '*') ADVANCE(478);
      END_STATE();
    case 73:
      if (lookahead == '*') ADVANCE(512);
      if (lookahead == '=') ADVANCE(516);
      if (lookahead == 0x2013) ADVANCE(119);
      END_STATE();
    case 74:
      if (lookahead == '*') ADVANCE(131);
      if (lookahead == '+') ADVANCE(132);
      END_STATE();
    case 75:
      if (lookahead == '+') ADVANCE(491);
      if (lookahead == '=') ADVANCE(557);
      END_STATE();
    case 76:
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '=') ADVANCE(558);
      END_STATE();
    case 77:
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '>') ADVANCE(576);
      END_STATE();
    case 78:
      if (lookahead == '-') ADVANCE(539);
      if (lookahead == '/') ADVANCE(66);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == 'X' ||
          lookahead == 'x') ADVANCE(550);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(78);
      END_STATE();
    case 79:
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '=') ADVANCE(564);
      END_STATE();
    case 80:
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '=') ADVANCE(121);
      END_STATE();
    case 81:
      if (lookahead == '/') ADVANCE(66);
      if (lookahead == 'P') ADVANCE(690);
      if (lookahead == '[') ADVANCE(464);
      if (lookahead == '\\') ADVANCE(678);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(81);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 82:
      if (lookahead == '/') ADVANCE(66);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(82);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(677);
      END_STATE();
    case 83:
      if (lookahead == '/') ADVANCE(66);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(83);
      END_STATE();
    case 84:
      if (lookahead == '/') ADVANCE(66);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(84);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(394);
      END_STATE();
    case 85:
      if (lookahead == '/') ADVANCE(470);
      if (lookahead == ':') ADVANCE(471);
      if (lookahead == '=') ADVANCE(469);
      END_STATE();
    case 86:
      if (lookahead == '/') ADVANCE(470);
      if (lookahead == '=') ADVANCE(469);
      END_STATE();
    case 87:
      ADVANCE_MAP(
        '0', 667,
        '1', 668,
        'B', 95,
        'b', 96,
        '{', 579,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
        'X', 669,
        'Z', 669,
        'x', 669,
        'z', 669,
      );
      END_STATE();
    case 88:
      ADVANCE_MAP(
        '0', 667,
        '1', 668,
        '{', 579,
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
        'X', 669,
        'Z', 669,
        'x', 669,
        'z', 669,
      );
      END_STATE();
    case 89:
      ADVANCE_MAP(
        '0', 667,
        '1', 668,
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
        'X', 669,
        'Z', 669,
        'x', 669,
        'z', 669,
      );
      END_STATE();
    case 90:
      if (lookahead == '0') ADVANCE(604);
      if (lookahead == '1') ADVANCE(606);
      END_STATE();
    case 91:
      if (lookahead == '0') ADVANCE(600);
      if (lookahead == '1') ADVANCE(602);
      END_STATE();
    case 92:
      if (lookahead == '0') ADVANCE(533);
      if (lookahead == '1') ADVANCE(535);
      if (lookahead == 'X') ADVANCE(538);
      if (lookahead == 'x') ADVANCE(537);
      END_STATE();
    case 93:
      if (lookahead == '0') ADVANCE(527);
      if (lookahead == '1') ADVANCE(529);
      if (lookahead == 'X') ADVANCE(532);
      if (lookahead == 'x') ADVANCE(531);
      END_STATE();
    case 94:
      if (lookahead == '0') ADVANCE(595);
      if (lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(596);
      END_STATE();
    case 95:
      if (lookahead == '0') ADVANCE(605);
      if (lookahead == '1') ADVANCE(607);
      if (lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(365);
      END_STATE();
    case 96:
      if (lookahead == '0') ADVANCE(601);
      if (lookahead == '1') ADVANCE(603);
      if (lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(365);
      END_STATE();
    case 97:
      if (lookahead == '0') ADVANCE(534);
      if (lookahead == '1') ADVANCE(536);
      if (lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(365);
      END_STATE();
    case 98:
      if (lookahead == '0') ADVANCE(528);
      if (lookahead == '1') ADVANCE(530);
      if (lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(365);
      END_STATE();
    case 99:
      if (lookahead == '1') ADVANCE(594);
      if (lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(596);
      END_STATE();
    case 100:
      if (lookahead == ':') ADVANCE(471);
      END_STATE();
    case 101:
      if (lookahead == ':') ADVANCE(72);
      END_STATE();
    case 102:
      if (lookahead == '<') ADVANCE(611);
      END_STATE();
    case 103:
      if (lookahead == '<') ADVANCE(104);
      if (lookahead == '=') ADVANCE(502);
      END_STATE();
    case 104:
      if (lookahead == '<') ADVANCE(111);
      if (lookahead == '=') ADVANCE(566);
      END_STATE();
    case 105:
      if (lookahead == '=') ADVANCE(501);
      END_STATE();
    case 106:
      if (lookahead == '=') ADVANCE(561);
      END_STATE();
    case 107:
      if (lookahead == '=') ADVANCE(499);
      END_STATE();
    case 108:
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(519);
      END_STATE();
    case 109:
      if (lookahead == '=') ADVANCE(565);
      END_STATE();
    case 110:
      if (lookahead == '=') ADVANCE(567);
      if (lookahead == '>') ADVANCE(112);
      END_STATE();
    case 111:
      if (lookahead == '=') ADVANCE(568);
      END_STATE();
    case 112:
      if (lookahead == '=') ADVANCE(569);
      END_STATE();
    case 113:
      if (lookahead == '=') ADVANCE(500);
      END_STATE();
    case 114:
      if (lookahead == '>') ADVANCE(581);
      END_STATE();
    case 115:
      if (lookahead == '>') ADVANCE(519);
      END_STATE();
    case 116:
      if (lookahead == '>') ADVANCE(463);
      END_STATE();
    case 117:
      if (lookahead == '>') ADVANCE(637);
      END_STATE();
    case 118:
      if (lookahead == '>') ADVANCE(517);
      END_STATE();
    case 119:
      if (lookahead == '>') ADVANCE(520);
      END_STATE();
    case 120:
      if (lookahead == '>') ADVANCE(504);
      END_STATE();
    case 121:
      if (lookahead == '>') ADVANCE(505);
      END_STATE();
    case 122:
      if (lookahead == '>') ADVANCE(110);
      END_STATE();
    case 123:
      if (lookahead == '>') ADVANCE(608);
      END_STATE();
    case 124:
      if (lookahead == 'B') ADVANCE(92);
      if (lookahead == 'b') ADVANCE(93);
      END_STATE();
    case 125:
      ADVANCE_MAP(
        'B', 97,
        'b', 98,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
      );
      END_STATE();
    case 126:
      if (lookahead == 'C') ADVANCE(53);
      END_STATE();
    case 127:
      if (lookahead == 'D') ADVANCE(129);
      END_STATE();
    case 128:
      if (lookahead == 'I') ADVANCE(52);
      END_STATE();
    case 129:
      if (lookahead == 'P') ADVANCE(128);
      END_STATE();
    case 130:
      if (lookahead == ']') ADVANCE(515);
      END_STATE();
    case 131:
      if (lookahead == ']') ADVANCE(510);
      END_STATE();
    case 132:
      if (lookahead == ']') ADVANCE(511);
      END_STATE();
    case 133:
      if (lookahead == '^') ADVANCE(632);
      END_STATE();
    case 134:
      if (lookahead == '_') ADVANCE(247);
      if (lookahead == 'c') ADVANCE(218);
      if (lookahead == 'i') ADVANCE(222);
      END_STATE();
    case 135:
      if (lookahead == '_') ADVANCE(162);
      END_STATE();
    case 136:
      if (lookahead == '_') ADVANCE(285);
      END_STATE();
    case 137:
      if (lookahead == '_') ADVANCE(172);
      END_STATE();
    case 138:
      if (lookahead == '_') ADVANCE(250);
      END_STATE();
    case 139:
      if (lookahead == 'a') ADVANCE(149);
      END_STATE();
    case 140:
      if (lookahead == 'a') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(281);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(319);
      END_STATE();
    case 142:
      if (lookahead == 'a') ADVANCE(340);
      END_STATE();
    case 143:
      if (lookahead == 'a') ADVANCE(265);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(254);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(277);
      END_STATE();
    case 146:
      if (lookahead == 'a') ADVANCE(255);
      END_STATE();
    case 147:
      if (lookahead == 'a') ADVANCE(259);
      END_STATE();
    case 148:
      if (lookahead == 'a') ADVANCE(261);
      END_STATE();
    case 149:
      if (lookahead == 'b') ADVANCE(266);
      END_STATE();
    case 150:
      if (lookahead == 'c') ADVANCE(234);
      END_STATE();
    case 151:
      if (lookahead == 'c') ADVANCE(303);
      if (lookahead == 'm') ADVANCE(295);
      END_STATE();
    case 152:
      if (lookahead == 'c') ADVANCE(297);
      if (lookahead == 'd') ADVANCE(206);
      END_STATE();
    case 153:
      if (lookahead == 'c') ADVANCE(143);
      END_STATE();
    case 154:
      if (lookahead == 'c') ADVANCE(258);
      END_STATE();
    case 155:
      if (lookahead == 'c') ADVANCE(339);
      END_STATE();
    case 156:
      if (lookahead == 'c') ADVANCE(341);
      END_STATE();
    case 157:
      if (lookahead == 'c') ADVANCE(306);
      END_STATE();
    case 158:
      if (lookahead == 'd') ADVANCE(134);
      END_STATE();
    case 159:
      if (lookahead == 'd') ADVANCE(583);
      END_STATE();
    case 160:
      if (lookahead == 'd') ADVANCE(591);
      END_STATE();
    case 161:
      if (lookahead == 'd') ADVANCE(584);
      END_STATE();
    case 162:
      if (lookahead == 'd') ADVANCE(312);
      END_STATE();
    case 163:
      if (lookahead == 'd') ADVANCE(135);
      END_STATE();
    case 164:
      if (lookahead == 'd') ADVANCE(323);
      END_STATE();
    case 165:
      if (lookahead == 'd') ADVANCE(324);
      END_STATE();
    case 166:
      if (lookahead == 'd') ADVANCE(202);
      if (lookahead == 'n') ADVANCE(169);
      END_STATE();
    case 167:
      if (lookahead == 'd') ADVANCE(334);
      END_STATE();
    case 168:
      if (lookahead == 'd') ADVANCE(338);
      END_STATE();
    case 169:
      if (lookahead == 'd') ADVANCE(207);
      END_STATE();
    case 170:
      if (lookahead == 'd') ADVANCE(208);
      END_STATE();
    case 171:
      if (lookahead == 'd') ADVANCE(183);
      END_STATE();
    case 172:
      if (lookahead == 'd') ADVANCE(320);
      END_STATE();
    case 173:
      if (lookahead == 'd') ADVANCE(137);
      END_STATE();
    case 174:
      if (lookahead == 'd') ADVANCE(215);
      END_STATE();
    case 175:
      if (lookahead == 'e') ADVANCE(232);
      END_STATE();
    case 176:
      if (lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 177:
      if (lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 178:
      if (lookahead == 'e') ADVANCE(307);
      END_STATE();
    case 179:
      if (lookahead == 'e') ADVANCE(428);
      if (lookahead == 'i') ADVANCE(221);
      END_STATE();
    case 180:
      if (lookahead == 'e') ADVANCE(438);
      END_STATE();
    case 181:
      if (lookahead == 'e') ADVANCE(415);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(357);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(393);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(433);
      END_STATE();
    case 185:
      if (lookahead == 'e') ADVANCE(430);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(431);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(436);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(437);
      END_STATE();
    case 189:
      if (lookahead == 'e') ADVANCE(429);
      END_STATE();
    case 190:
      if (lookahead == 'e') ADVANCE(151);
      END_STATE();
    case 191:
      if (lookahead == 'e') ADVANCE(593);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(526);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(329);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(326);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(270);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(352);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(325);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(353);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(316);
      if (lookahead == 'f') ADVANCE(142);
      if (lookahead == 'i') ADVANCE(280);
      if (lookahead == 'r') ADVANCE(296);
      if (lookahead == 'u') ADVANCE(278);
      if (lookahead == 'w') ADVANCE(141);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(316);
      if (lookahead == 'f') ADVANCE(142);
      if (lookahead == 'i') ADVANCE(280);
      if (lookahead == 'u') ADVANCE(278);
      if (lookahead == 'w') ADVANCE(141);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(335);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(163);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 205:
      if (lookahead == 'e') ADVANCE(354);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(224);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(225);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(228);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(314);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(337);
      if (lookahead == 'k') ADVANCE(196);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(317);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(148);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(328);
      END_STATE();
    case 214:
      if (lookahead == 'e') ADVANCE(173);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(229);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(360);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(269);
      END_STATE();
    case 219:
      if (lookahead == 'f') ADVANCE(166);
      if (lookahead == 'n') ADVANCE(154);
      END_STATE();
    case 220:
      if (lookahead == 'f') ADVANCE(140);
      END_STATE();
    case 221:
      if (lookahead == 'f') ADVANCE(423);
      END_STATE();
    case 222:
      if (lookahead == 'f') ADVANCE(427);
      END_STATE();
    case 223:
      if (lookahead == 'f') ADVANCE(421);
      END_STATE();
    case 224:
      if (lookahead == 'f') ADVANCE(424);
      END_STATE();
    case 225:
      if (lookahead == 'f') ADVANCE(422);
      END_STATE();
    case 226:
      ADVANCE_MAP(
        'f', 347,
        'h', 302,
        'n', 298,
        'p', 211,
        'r', 190,
        's', 210,
        't', 243,
        'u', 278,
        'w', 239,
      );
      END_STATE();
    case 227:
      if (lookahead == 'f') ADVANCE(294);
      END_STATE();
    case 228:
      if (lookahead == 'f') ADVANCE(245);
      END_STATE();
    case 229:
      if (lookahead == 'f') ADVANCE(246);
      END_STATE();
    case 230:
      if (lookahead == 'g') ADVANCE(455);
      END_STATE();
    case 231:
      if (lookahead == 'g') ADVANCE(191);
      END_STATE();
    case 232:
      if (lookahead == 'g') ADVANCE(238);
      END_STATE();
    case 233:
      if (lookahead == 'h') ADVANCE(592);
      END_STATE();
    case 234:
      if (lookahead == 'h') ADVANCE(145);
      END_STATE();
    case 235:
      if (lookahead == 'i') ADVANCE(271);
      END_STATE();
    case 236:
      if (lookahead == 'i') ADVANCE(348);
      END_STATE();
    case 237:
      if (lookahead == 'i') ADVANCE(279);
      END_STATE();
    case 238:
      if (lookahead == 'i') ADVANCE(274);
      END_STATE();
    case 239:
      if (lookahead == 'i') ADVANCE(167);
      END_STATE();
    case 240:
      if (lookahead == 'i') ADVANCE(331);
      END_STATE();
    case 241:
      if (lookahead == 'i') ADVANCE(275);
      END_STATE();
    case 242:
      if (lookahead == 'i') ADVANCE(301);
      END_STATE();
    case 243:
      if (lookahead == 'i') ADVANCE(272);
      END_STATE();
    case 244:
      if (lookahead == 'i') ADVANCE(349);
      END_STATE();
    case 245:
      if (lookahead == 'i') ADVANCE(284);
      END_STATE();
    case 246:
      if (lookahead == 'i') ADVANCE(286);
      END_STATE();
    case 247:
      if (lookahead == 'k') ADVANCE(182);
      END_STATE();
    case 248:
      if (lookahead == 'k') ADVANCE(198);
      END_STATE();
    case 249:
      if (lookahead == 'k') ADVANCE(205);
      END_STATE();
    case 250:
      if (lookahead == 'k') ADVANCE(216);
      END_STATE();
    case 251:
      if (lookahead == 'l') ADVANCE(322);
      if (lookahead == 'n') ADVANCE(158);
      END_STATE();
    case 252:
      if (lookahead == 'l') ADVANCE(425);
      END_STATE();
    case 253:
      if (lookahead == 'l') ADVANCE(426);
      END_STATE();
    case 254:
      if (lookahead == 'l') ADVANCE(453);
      END_STATE();
    case 255:
      if (lookahead == 'l') ADVANCE(586);
      END_STATE();
    case 256:
      if (lookahead == 'l') ADVANCE(267);
      END_STATE();
    case 257:
      if (lookahead == 'l') ADVANCE(332);
      END_STATE();
    case 258:
      if (lookahead == 'l') ADVANCE(346);
      END_STATE();
    case 259:
      if (lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 260:
      if (lookahead == 'l') ADVANCE(327);
      END_STATE();
    case 261:
      if (lookahead == 'l') ADVANCE(253);
      END_STATE();
    case 262:
      if (lookahead == 'l') ADVANCE(159);
      END_STATE();
    case 263:
      if (lookahead == 'l') ADVANCE(260);
      END_STATE();
    case 264:
      if (lookahead == 'l') ADVANCE(161);
      END_STATE();
    case 265:
      if (lookahead == 'l') ADVANCE(184);
      END_STATE();
    case 266:
      if (lookahead == 'l') ADVANCE(192);
      END_STATE();
    case 267:
      if (lookahead == 'l') ADVANCE(170);
      END_STATE();
    case 268:
      if (lookahead == 'l') ADVANCE(174);
      END_STATE();
    case 269:
      if (lookahead == 'l') ADVANCE(268);
      END_STATE();
    case 270:
      if (lookahead == 'm') ADVANCE(587);
      END_STATE();
    case 271:
      if (lookahead == 'm') ADVANCE(197);
      END_STATE();
    case 272:
      if (lookahead == 'm') ADVANCE(213);
      END_STATE();
    case 273:
      if (lookahead == 'n') ADVANCE(152);
      END_STATE();
    case 274:
      if (lookahead == 'n') ADVANCE(138);
      END_STATE();
    case 275:
      if (lookahead == 'n') ADVANCE(230);
      END_STATE();
    case 276:
      if (lookahead == 'n') ADVANCE(157);
      END_STATE();
    case 277:
      if (lookahead == 'n') ADVANCE(231);
      END_STATE();
    case 278:
      if (lookahead == 'n') ADVANCE(240);
      END_STATE();
    case 279:
      if (lookahead == 'n') ADVANCE(180);
      END_STATE();
    case 280:
      if (lookahead == 'n') ADVANCE(227);
      END_STATE();
    case 281:
      if (lookahead == 'n') ADVANCE(181);
      END_STATE();
    case 282:
      if (lookahead == 'n') ADVANCE(204);
      END_STATE();
    case 283:
      if (lookahead == 'n') ADVANCE(212);
      END_STATE();
    case 284:
      if (lookahead == 'n') ADVANCE(185);
      END_STATE();
    case 285:
      if (lookahead == 'n') ADVANCE(201);
      END_STATE();
    case 286:
      if (lookahead == 'n') ADVANCE(186);
      END_STATE();
    case 287:
      if (lookahead == 'n') ADVANCE(168);
      END_STATE();
    case 288:
      if (lookahead == 'n') ADVANCE(241);
      END_STATE();
    case 289:
      if (lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 290:
      if (lookahead == 'n') ADVANCE(217);
      END_STATE();
    case 291:
      if (lookahead == 'n') ADVANCE(290);
      END_STATE();
    case 292:
      if (lookahead == 'o') ADVANCE(342);
      END_STATE();
    case 293:
      if (lookahead == 'o') ADVANCE(313);
      END_STATE();
    case 294:
      if (lookahead == 'o') ADVANCE(456);
      END_STATE();
    case 295:
      if (lookahead == 'o') ADVANCE(351);
      END_STATE();
    case 296:
      if (lookahead == 'o') ADVANCE(300);
      END_STATE();
    case 297:
      if (lookahead == 'o') ADVANCE(289);
      END_STATE();
    case 298:
      if (lookahead == 'o') ADVANCE(150);
      END_STATE();
    case 299:
      if (lookahead == 'o') ADVANCE(311);
      END_STATE();
    case 300:
      if (lookahead == 'o') ADVANCE(330);
      END_STATE();
    case 301:
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 302:
      if (lookahead == 'o') ADVANCE(262);
      END_STATE();
    case 303:
      if (lookahead == 'o') ADVANCE(350);
      if (lookahead == 'r') ADVANCE(195);
      END_STATE();
    case 304:
      if (lookahead == 'o') ADVANCE(264);
      END_STATE();
    case 305:
      if (lookahead == 'o') ADVANCE(321);
      END_STATE();
    case 306:
      if (lookahead == 'o') ADVANCE(291);
      END_STATE();
    case 307:
      if (lookahead == 'p') ADVANCE(479);
      END_STATE();
    case 308:
      if (lookahead == 'p') ADVANCE(582);
      END_STATE();
    case 309:
      if (lookahead == 'p') ADVANCE(187);
      END_STATE();
    case 310:
      if (lookahead == 'r') ADVANCE(702);
      if (lookahead == 'u') ADVANCE(700);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 311:
      if (lookahead == 'r') ADVANCE(454);
      END_STATE();
    case 312:
      if (lookahead == 'r') ADVANCE(236);
      END_STATE();
    case 313:
      if (lookahead == 'r') ADVANCE(164);
      END_STATE();
    case 314:
      if (lookahead == 'r') ADVANCE(358);
      END_STATE();
    case 315:
      if (lookahead == 'r') ADVANCE(296);
      if (lookahead == 'u') ADVANCE(278);
      END_STATE();
    case 316:
      if (lookahead == 'r') ADVANCE(318);
      END_STATE();
    case 317:
      if (lookahead == 'r') ADVANCE(242);
      END_STATE();
    case 318:
      if (lookahead == 'r') ADVANCE(299);
      END_STATE();
    case 319:
      if (lookahead == 'r') ADVANCE(288);
      END_STATE();
    case 320:
      if (lookahead == 'r') ADVANCE(244);
      END_STATE();
    case 321:
      if (lookahead == 'r') ADVANCE(165);
      END_STATE();
    case 322:
      if (lookahead == 's') ADVANCE(179);
      END_STATE();
    case 323:
      if (lookahead == 's') ADVANCE(432);
      END_STATE();
    case 324:
      if (lookahead == 's') ADVANCE(439);
      END_STATE();
    case 325:
      if (lookahead == 's') ADVANCE(153);
      END_STATE();
    case 326:
      if (lookahead == 's') ADVANCE(193);
      END_STATE();
    case 327:
      if (lookahead == 's') ADVANCE(248);
      END_STATE();
    case 328:
      if (lookahead == 's') ADVANCE(249);
      END_STATE();
    case 329:
      if (lookahead == 't') ADVANCE(147);
      END_STATE();
    case 330:
      if (lookahead == 't') ADVANCE(684);
      END_STATE();
    case 331:
      if (lookahead == 't') ADVANCE(686);
      END_STATE();
    case 332:
      if (lookahead == 't') ADVANCE(136);
      END_STATE();
    case 333:
      if (lookahead == 't') ADVANCE(359);
      END_STATE();
    case 334:
      if (lookahead == 't') ADVANCE(233);
      END_STATE();
    case 335:
      if (lookahead == 't') ADVANCE(333);
      END_STATE();
    case 336:
      if (lookahead == 't') ADVANCE(178);
      END_STATE();
    case 337:
      if (lookahead == 't') ADVANCE(343);
      END_STATE();
    case 338:
      if (lookahead == 't') ADVANCE(139);
      END_STATE();
    case 339:
      if (lookahead == 't') ADVANCE(203);
      END_STATE();
    case 340:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 341:
      if (lookahead == 't') ADVANCE(214);
      END_STATE();
    case 342:
      if (lookahead == 'u') ADVANCE(276);
      END_STATE();
    case 343:
      if (lookahead == 'u') ADVANCE(308);
      END_STATE();
    case 344:
      if (lookahead == 'u') ADVANCE(257);
      END_STATE();
    case 345:
      if (lookahead == 'u') ADVANCE(278);
      END_STATE();
    case 346:
      if (lookahead == 'u') ADVANCE(171);
      END_STATE();
    case 347:
      if (lookahead == 'u') ADVANCE(263);
      END_STATE();
    case 348:
      if (lookahead == 'v') ADVANCE(188);
      END_STATE();
    case 349:
      if (lookahead == 'v') ADVANCE(189);
      END_STATE();
    case 350:
      if (lookahead == 'v') ADVANCE(209);
      END_STATE();
    case 351:
      if (lookahead == 'v') ADVANCE(146);
      END_STATE();
    case 352:
      if (lookahead == 'w') ADVANCE(588);
      END_STATE();
    case 353:
      if (lookahead == 'w') ADVANCE(590);
      END_STATE();
    case 354:
      if (lookahead == 'w') ADVANCE(589);
      END_STATE();
    case 355:
      if (lookahead == 'w') ADVANCE(293);
      END_STATE();
    case 356:
      if (lookahead == 'w') ADVANCE(305);
      END_STATE();
    case 357:
      if (lookahead == 'y') ADVANCE(355);
      END_STATE();
    case 358:
      if (lookahead == 'y') ADVANCE(585);
      END_STATE();
    case 359:
      if (lookahead == 'y') ADVANCE(309);
      END_STATE();
    case 360:
      if (lookahead == 'y') ADVANCE(356);
      END_STATE();
    case 361:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(369);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(658);
      END_STATE();
    case 362:
      ADVANCE_MAP(
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
      );
      END_STATE();
    case 363:
      ADVANCE_MAP(
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
      );
      END_STATE();
    case 364:
      if (lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(654);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(364);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(653);
      END_STATE();
    case 365:
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(365);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 366:
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(366);
      if (set_contains(sym_hex_number_character_set_1, 10, lookahead)) ADVANCE(657);
      END_STATE();
    case 367:
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(367);
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(656);
      END_STATE();
    case 368:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(659);
      END_STATE();
    case 369:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(658);
      END_STATE();
    case 370:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(660);
      END_STATE();
    case 371:
      if (eof) ADVANCE(374);
      ADVANCE_MAP(
        '!', 105,
        '"', 127,
        '#', 446,
        '$', 199,
        '%', 496,
        '&', 620,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 450,
        '/', 434,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '@', 572,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 420,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
        0x2013, 116,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(371);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(666);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 372:
      if (eof) ADVANCE(374);
      ADVANCE_MAP(
        '!', 105,
        '#', 446,
        '$', 200,
        '%', 496,
        '&', 623,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 475,
        '+', 485,
        ',', 409,
        '-', 549,
        '.', 449,
        '/', 434,
        '0', 457,
        '1', 459,
        '2', 462,
        ':', 443,
        ';', 441,
        '<', 383,
        '=', 107,
        '>', 392,
        '?', 616,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 630,
        '`', 420,
        '{', 451,
        '|', 628,
        '}', 452,
        '~', 133,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(372);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 373:
      if (eof) ADVANCE(374);
      ADVANCE_MAP(
        '"', 127,
        '#', 447,
        '$', 199,
        '%', 106,
        '&', 61,
        '\'', 648,
        '(', 406,
        ')', 408,
        '*', 64,
        '+', 75,
        ',', 409,
        '-', 76,
        '.', 449,
        '/', 67,
        '1', 663,
        ':', 443,
        ';', 441,
        '<', 103,
        '=', 414,
        '>', 122,
        '?', 616,
        '@', 570,
        '[', 464,
        '\\', 678,
        ']', 468,
        '^', 109,
        '`', 420,
        '{', 451,
        '|', 79,
        '}', 452,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(373);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(664);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(aux_sym_double_quoted_string_token1);
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(380);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(380);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(aux_sym_double_quoted_string_token1);
      if (lookahead == '*') ADVANCE(377);
      if (lookahead == '/') ADVANCE(380);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(378);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(aux_sym_double_quoted_string_token1);
      if (lookahead == '*') ADVANCE(377);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(378);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(aux_sym_double_quoted_string_token1);
      if (lookahead == '/') ADVANCE(376);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(379);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(380);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(aux_sym_double_quoted_string_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(380);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(117);
      if (lookahead == '<') ADVANCE(612);
      if (lookahead == '=') ADVANCE(502);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(117);
      if (lookahead == '<') ADVANCE(613);
      if (lookahead == '=') ADVANCE(502);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(502);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_standard_token1);
      if (lookahead == '*') ADVANCE(387);
      if (lookahead == '/') ADVANCE(389);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(389);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_standard_token1);
      if (lookahead == '*') ADVANCE(386);
      if (lookahead == '/') ADVANCE(389);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(387);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_standard_token1);
      if (lookahead == '*') ADVANCE(386);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(387);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_standard_token1);
      if (lookahead == '/') ADVANCE(385);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(388);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(389);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_standard_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '>' &&
          lookahead != '\\') ADVANCE(389);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(503);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(503);
      if (lookahead == '>') ADVANCE(609);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(503);
      if (lookahead == '>') ADVANCE(610);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(aux_sym_include_compiler_directive_token1);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(sym_default_text);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(394);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\n') ADVANCE(71);
      if (lookahead == '*') ADVANCE(395);
      if (lookahead == '/') ADVANCE(402);
      if (lookahead == '\\') ADVANCE(6);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\n') ADVANCE(71);
      if (lookahead == '*') ADVANCE(395);
      if (lookahead == '\\') ADVANCE(6);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\n') ADVANCE(416);
      if (lookahead == '(') ADVANCE(407);
      if (lookahead == '/') ADVANCE(400);
      if (lookahead == '\\') ADVANCE(5);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(397);
      if (lookahead != 0) ADVANCE(402);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\n') ADVANCE(402);
      if (lookahead == '\\') ADVANCE(673);
      if (lookahead != 0) ADVANCE(404);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\n') ADVANCE(418);
      if (lookahead == '/') ADVANCE(400);
      if (lookahead == '\\') ADVANCE(5);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(399);
      if (lookahead != 0) ADVANCE(402);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '*') ADVANCE(396);
      if (lookahead == '/') ADVANCE(404);
      if (lookahead == '\\') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(402);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '*') ADVANCE(395);
      if (lookahead == '\\') ADVANCE(6);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\\') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(402);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\\') ADVANCE(5);
      if (lookahead != 0) ADVANCE(402);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(sym_macro_text);
      if (lookahead == '\\') ADVANCE(673);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(404);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '*') ADVANCE(670);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '\\') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(402);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(499);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(499);
      if (lookahead == '>') ADVANCE(519);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(498);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(519);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(aux_sym_text_macro_definition_token1);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(416);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(397);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(417);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(418);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(399);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      ADVANCE_MAP(
        'b', 175,
        'c', 176,
        'd', 177,
        'e', 251,
        'i', 219,
        'l', 237,
        'n', 292,
        'r', 194,
        't', 235,
        'u', 273,
      );
      END_STATE();
    case 421:
      ACCEPT_TOKEN(aux_sym_id_directive_token1);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(aux_sym_id_directive_token2);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(aux_sym_id_directive_token3);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(aux_sym_id_directive_token4);
      if (lookahead == 'i') ADVANCE(283);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(aux_sym_zero_directive_token1);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(aux_sym_zero_directive_token2);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(aux_sym_zero_directive_token3);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(aux_sym_zero_directive_token4);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(aux_sym_zero_directive_token5);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(aux_sym_zero_directive_token6);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(aux_sym_zero_directive_token7);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(aux_sym_zero_directive_token8);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(aux_sym_timescale_compiler_directive_token1);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(71);
      if (lookahead == '/') ADVANCE(676);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(71);
      if (lookahead == '/') ADVANCE(676);
      if (lookahead == '=') ADVANCE(560);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(aux_sym_default_nettype_compiler_directive_token1);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(aux_sym_unconnected_drive_token1);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(aux_sym_line_compiler_directive_token1);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(aux_sym_begin_keywords_token1);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(471);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(471);
      if (lookahead == '=') ADVANCE(469);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '#') ADVANCE(509);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '#') ADVANCE(509);
      if (lookahead == '-') ADVANCE(57);
      if (lookahead == '=') ADVANCE(58);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '#') ADVANCE(508);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '*') ADVANCE(440);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_DOLLARfatal);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_DOLLARerror);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_DOLLARwarning);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_DOLLARinfo);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_0);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_0);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(664);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_1);
      if (lookahead == '\'') ADVANCE(124);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_1);
      if (lookahead == '\'') ADVANCE(124);
      if (lookahead == 's') ADVANCE(336);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_1);
      if (lookahead == '\'') ADVANCE(125);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(661);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_2);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_u2013_GT);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '*') ADVANCE(513);
      if (lookahead == '+') ADVANCE(130);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '=') ADVANCE(516);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '*') ADVANCE(513);
      if (lookahead == '+') ADVANCE(130);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '=') ADVANCE(516);
      if (lookahead == 0x2013) ADVANCE(119);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '*') ADVANCE(512);
      if (lookahead == '=') ADVANCE(516);
      if (lookahead == 0x2013) ADVANCE(119);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_COLON_SLASH);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == ')') ADVANCE(671);
      if (lookahead == '*') ADVANCE(495);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == ')') ADVANCE(671);
      if (lookahead == '*') ADVANCE(495);
      if (lookahead == '=') ADVANCE(559);
      if (lookahead == '>') ADVANCE(581);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(495);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(495);
      if (lookahead == '=') ADVANCE(559);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(495);
      if (lookahead == '>') ADVANCE(581);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_STAR_COLON_COLON_STAR);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_1step);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_PATHPULSE_DOLLAR_EQ);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == 'r') ADVANCE(702);
      if (lookahead == 'u') ADVANCE(700);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == 'u') ADVANCE(278);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_DQUOTEDPI_DASHC_DQUOTE);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_DQUOTEDPI_DQUOTE);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(491);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(491);
      if (lookahead == ':') ADVANCE(614);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(491);
      if (lookahead == ':') ADVANCE(614);
      if (lookahead == '=') ADVANCE(557);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(491);
      if (lookahead == '=') ADVANCE(557);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == ':') ADVANCE(614);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_u2013);
      if (lookahead == '>') ADVANCE(463);
      if (lookahead == 0x2013) ADVANCE(494);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_u2013);
      if (lookahead == 0x2013) ADVANCE(494);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_u2013u2013);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(561);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      if (lookahead == '=') ADVANCE(598);
      if (lookahead == '?') ADVANCE(617);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      if (lookahead == '=') ADVANCE(599);
      if (lookahead == '?') ADVANCE(618);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_PIPE_DASH_GT);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ_GT);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_POUND_DASH_POUND);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_POUND_EQ_POUND);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_POUND_POUND);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_POUND_POUND);
      if (lookahead == '[') ADVANCE(74);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_POUND_POUND_LBRACK_STAR_RBRACK);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_LBRACK_STAR);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_LBRACK_STAR);
      if (lookahead == ']') ADVANCE(514);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_LBRACK_STAR_RBRACK);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_LBRACK_PLUS_RBRACK);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_LBRACK_EQ);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_LBRACK_DASH_GT);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_AT_AT);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_LBRACKu2013_GT);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(501);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      if (lookahead == '&') ADVANCE(578);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_endtable);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEb0);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEb0);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEb1);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEb1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEbx);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEbX);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEB0);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEB0);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEB1);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEB1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEBx);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_1_SQUOTEBX);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == ':') ADVANCE(615);
      if (lookahead == '=') ADVANCE(558);
      if (lookahead == '>') ADVANCE(576);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == ':') ADVANCE(615);
      if (lookahead == '>') ADVANCE(576);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == ':') ADVANCE(615);
      if (lookahead == '>') ADVANCE(575);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '=') ADVANCE(558);
      if (lookahead == '>') ADVANCE(576);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '=') ADVANCE(558);
      if (lookahead == '>') ADVANCE(575);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '>') ADVANCE(576);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(652);
      if (lookahead == '>') ADVANCE(575);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == ':') ADVANCE(615);
      if (lookahead == '>') ADVANCE(575);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(575);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_output_symbol);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_output_symbol);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_level_symbol);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_level_symbol);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_edge_symbol);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_edge_symbol);
      if (lookahead == 'A') ADVANCE(696);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_edge_symbol);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      if (lookahead == '>') ADVANCE(505);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_LT_LT_LT_EQ);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '*') ADVANCE(574);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '*') ADVANCE(574);
      if (lookahead == '@') ADVANCE(518);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '@') ADVANCE(518);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_AT_STAR);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (lookahead == '>') ADVANCE(577);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_DASH_GT_GT);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_AMP_AMP_AMP);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_SQUOTE_LBRACE);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_POUND0);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_STAR_GT);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_DOLLARsetup);
      if (lookahead == 'h') ADVANCE(304);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_DOLLARhold);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_DOLLARsetuphold);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_DOLLARrecovery);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_DOLLARremoval);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_DOLLARrecrem);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_DOLLARskew);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_DOLLARtimeskew);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_DOLLARfullskew);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_DOLLARperiod);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_DOLLARwidth);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_DOLLARnochange);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_01);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_10);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(aux_sym_edge_descriptor_token2);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '&') ADVANCE(650);
      if (lookahead == '^') ADVANCE(632);
      if (lookahead == '|') ADVANCE(651);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_EQ_EQ_EQ);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_BANG_EQ_EQ);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_SQUOTEb0);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_SQUOTEb0);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_SQUOTEb1);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_SQUOTEb1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_SQUOTEB0);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_SQUOTEB0);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_SQUOTEB1);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_SQUOTEB1);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(567);
      if (lookahead == '>') ADVANCE(634);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(633);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '<') ADVANCE(636);
      if (lookahead == '=') ADVANCE(566);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '<') ADVANCE(635);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_PLUS_COLON);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_DASH_COLON);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(anon_sym_EQ_EQ_QMARK);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_BANG_EQ_QMARK);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(524);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(524);
      if (lookahead == '=') ADVANCE(562);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(60);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(523);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '=') ADVANCE(564);
      if (lookahead == '|') ADVANCE(525);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '=') ADVANCE(121);
      if (lookahead == '|') ADVANCE(525);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(563);
      if (lookahead == '|') ADVANCE(525);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(525);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(565);
      if (lookahead == '~') ADVANCE(631);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '~') ADVANCE(631);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_CARET_TILDE);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_TILDE_CARET);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(569);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(anon_sym_LT_LT_LT);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym_LT_LT_LT);
      if (lookahead == '=') ADVANCE(568);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym_LT_DASH_GT);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '\n') ADVANCE(643);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(676);
      if (lookahead != 0) ADVANCE(638);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(641);
      if (lookahead == '/') ADVANCE(638);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(643);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(640);
      if (lookahead == '/') ADVANCE(643);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(71);
      if (lookahead != 0) ADVANCE(641);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(640);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(71);
      if (lookahead != 0) ADVANCE(641);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(639);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(642);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(643);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(643);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(aux_sym_string_literal_token3);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      ADVANCE_MAP(
        '0', 667,
        '1', 668,
        'B', 90,
        'b', 91,
        '{', 579,
        'X', 669,
        'Z', 669,
        'x', 669,
        'z', 669,
      );
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      ADVANCE_MAP(
        '0', 667,
        '1', 668,
        '{', 579,
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
        'X', 669,
        'Z', 669,
        'x', 669,
        'z', 669,
      );
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '{') ADVANCE(579);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      ADVANCE_MAP(
        '{', 579,
        'B', 365,
        'b', 365,
        'D', 364,
        'd', 364,
        'H', 366,
        'h', 366,
        'O', 367,
        'o', 367,
        'S', 362,
        's', 362,
      );
      END_STATE();
    case 650:
      ACCEPT_TOKEN(anon_sym_TILDE_AMP);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(anon_sym_TILDE_PIPE);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(aux_sym_decimal_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(653);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(aux_sym_decimal_number_token2);
      if (lookahead == '_') ADVANCE(654);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_binary_number);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(655);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_octal_number);
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == '?' ||
          lookahead == 'X' ||
          lookahead == 'Z' ||
          lookahead == '_' ||
          lookahead == 'x' ||
          lookahead == 'z') ADVANCE(656);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_hex_number);
      if (set_contains(sym_hex_number_character_set_2, 9, lookahead)) ADVANCE(657);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(aux_sym_real_number_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(658);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_fixed_point_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(659);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym_fixed_point_number);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(660);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (lookahead == '\'') ADVANCE(363);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(661);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (lookahead == '\'') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(662);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == 's') ADVANCE(336);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(664);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(664);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (lookahead == '.') ADVANCE(370);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(665);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(sym_unsigned_number);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(666);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym_SQUOTE0);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_SQUOTE1);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(aux_sym_unbased_unsized_literal_token1);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(anon_sym_LPAREN_STAR);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym_STAR_RPAREN);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(402);
      if (lookahead == '\r') ADVANCE(398);
      if (lookahead != 0) ADVANCE(404);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(676);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(674);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(683);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(676);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym_c_identifier);
      if (lookahead == '$') ADVANCE(698);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(677);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(aux_sym_escaped_identifier_token1);
      if (lookahead == '*') ADVANCE(681);
      if (lookahead == '/') ADVANCE(674);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(683);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(aux_sym_escaped_identifier_token1);
      if (lookahead == '*') ADVANCE(680);
      if (lookahead == '/') ADVANCE(675);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(71);
      if (lookahead != 0) ADVANCE(681);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(aux_sym_escaped_identifier_token1);
      if (lookahead == '*') ADVANCE(680);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(71);
      if (lookahead != 0) ADVANCE(681);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(aux_sym_escaped_identifier_token1);
      if (lookahead == '/') ADVANCE(679);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(683);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(aux_sym_escaped_identifier_token1);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(683);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(anon_sym_DOLLARroot);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(anon_sym_DOLLARroot);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym_DOLLARunit);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(anon_sym_DOLLARunit);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == '$') ADVANCE(689);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == '=') ADVANCE(480);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'A') ADVANCE(696);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'E') ADVANCE(688);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'H') ADVANCE(694);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'L') ADVANCE(695);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'P') ADVANCE(697);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'S') ADVANCE(691);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'T') ADVANCE(692);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == 'U') ADVANCE(693);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(sym_simple_identifier);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(698);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 'i') ADVANCE(704);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 'n') ADVANCE(699);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 'o') ADVANCE(703);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 'o') ADVANCE(701);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 't') ADVANCE(685);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == 't') ADVANCE(687);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym_system_tf_identifier);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(705);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'g', 7,
        'h', 8,
        'i', 9,
        'j', 10,
        'l', 11,
        'm', 12,
        'n', 13,
        'o', 14,
        'p', 15,
        'r', 16,
        's', 17,
        't', 18,
        'u', 19,
        'v', 20,
        'w', 21,
        'x', 22,
        'X', 23,
        'Z', 23,
        'z', 23,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'c') ADVANCE(24);
      if (lookahead == 'l') ADVANCE(25);
      if (lookahead == 'n') ADVANCE(26);
      if (lookahead == 's') ADVANCE(27);
      if (lookahead == 'u') ADVANCE(28);
      END_STATE();
    case 2:
      if (lookahead == 'e') ADVANCE(29);
      if (lookahead == 'i') ADVANCE(30);
      if (lookahead == 'r') ADVANCE(31);
      if (lookahead == 'u') ADVANCE(32);
      if (lookahead == 'y') ADVANCE(33);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(34);
      if (lookahead == 'h') ADVANCE(35);
      if (lookahead == 'l') ADVANCE(36);
      if (lookahead == 'm') ADVANCE(37);
      if (lookahead == 'o') ADVANCE(38);
      if (lookahead == 'r') ADVANCE(39);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(40);
      if (lookahead == 'i') ADVANCE(41);
      if (lookahead == 'o') ADVANCE(42);
      END_STATE();
    case 5:
      if (lookahead == 'd') ADVANCE(43);
      if (lookahead == 'l') ADVANCE(44);
      if (lookahead == 'n') ADVANCE(45);
      if (lookahead == 'v') ADVANCE(46);
      if (lookahead == 'x') ADVANCE(47);
      END_STATE();
    case 6:
      if (lookahead == 'i') ADVANCE(48);
      if (lookahead == 'o') ADVANCE(49);
      if (lookahead == 's') ADVANCE(50);
      if (lookahead == 'u') ADVANCE(51);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(52);
      if (lookahead == 'l') ADVANCE(53);
      END_STATE();
    case 8:
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 9:
      if (lookahead == 'f') ADVANCE(55);
      if (lookahead == 'g') ADVANCE(56);
      if (lookahead == 'l') ADVANCE(57);
      if (lookahead == 'm') ADVANCE(58);
      if (lookahead == 'n') ADVANCE(59);
      END_STATE();
    case 10:
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(61);
      if (lookahead == 'e') ADVANCE(62);
      if (lookahead == 'o') ADVANCE(63);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(64);
      if (lookahead == 'e') ADVANCE(65);
      if (lookahead == 'o') ADVANCE(66);
      if (lookahead == 's') ADVANCE(67);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(68);
      if (lookahead == 'e') ADVANCE(69);
      if (lookahead == 'm') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(71);
      if (lookahead == 's') ADVANCE(72);
      if (lookahead == 'u') ADVANCE(73);
      END_STATE();
    case 14:
      if (lookahead == 'p') ADVANCE(74);
      if (lookahead == 'r') ADVANCE(75);
      if (lookahead == 'u') ADVANCE(76);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(77);
      if (lookahead == 'm') ADVANCE(78);
      if (lookahead == 'o') ADVANCE(79);
      if (lookahead == 'r') ADVANCE(80);
      if (lookahead == 's') ADVANCE(81);
      if (lookahead == 'u') ADVANCE(82);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(83);
      if (lookahead == 'c') ADVANCE(84);
      if (lookahead == 'e') ADVANCE(85);
      if (lookahead == 'n') ADVANCE(86);
      if (lookahead == 'p') ADVANCE(87);
      if (lookahead == 't') ADVANCE(88);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_s);
      ADVANCE_MAP(
        '_', 89,
        'a', 90,
        'c', 91,
        'e', 92,
        'h', 93,
        'i', 94,
        'm', 95,
        'o', 96,
        'p', 97,
        't', 98,
        'u', 99,
        'y', 100,
      );
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(101);
      if (lookahead == 'h') ADVANCE(102);
      if (lookahead == 'i') ADVANCE(103);
      if (lookahead == 'r') ADVANCE(104);
      if (lookahead == 'y') ADVANCE(105);
      END_STATE();
    case 19:
      if (lookahead == 'n') ADVANCE(106);
      if (lookahead == 's') ADVANCE(107);
      if (lookahead == 'w') ADVANCE(108);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(109);
      if (lookahead == 'e') ADVANCE(110);
      if (lookahead == 'i') ADVANCE(111);
      if (lookahead == 'o') ADVANCE(112);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(113);
      if (lookahead == 'e') ADVANCE(114);
      if (lookahead == 'h') ADVANCE(115);
      if (lookahead == 'i') ADVANCE(116);
      if (lookahead == 'o') ADVANCE(117);
      END_STATE();
    case 22:
      if (lookahead == 'n') ADVANCE(118);
      if (lookahead == 'o') ADVANCE(119);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(120);
      END_STATE();
    case 23:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(120);
      END_STATE();
    case 24:
      if (lookahead == 'c') ADVANCE(121);
      END_STATE();
    case 25:
      if (lookahead == 'i') ADVANCE(122);
      if (lookahead == 'w') ADVANCE(123);
      END_STATE();
    case 26:
      if (lookahead == 'd') ADVANCE(124);
      END_STATE();
    case 27:
      if (lookahead == 's') ADVANCE(125);
      END_STATE();
    case 28:
      if (lookahead == 't') ADVANCE(126);
      END_STATE();
    case 29:
      if (lookahead == 'f') ADVANCE(127);
      if (lookahead == 'g') ADVANCE(128);
      END_STATE();
    case 30:
      if (lookahead == 'n') ADVANCE(129);
      if (lookahead == 't') ADVANCE(130);
      END_STATE();
    case 31:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 32:
      if (lookahead == 'f') ADVANCE(132);
      END_STATE();
    case 33:
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 34:
      if (lookahead == 's') ADVANCE(134);
      END_STATE();
    case 35:
      if (lookahead == 'a') ADVANCE(135);
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 36:
      if (lookahead == 'a') ADVANCE(137);
      if (lookahead == 'o') ADVANCE(138);
      END_STATE();
    case 37:
      if (lookahead == 'o') ADVANCE(139);
      END_STATE();
    case 38:
      if (lookahead == 'n') ADVANCE(140);
      if (lookahead == 'v') ADVANCE(141);
      END_STATE();
    case 39:
      if (lookahead == 'o') ADVANCE(142);
      END_STATE();
    case 40:
      if (lookahead == 'a') ADVANCE(143);
      if (lookahead == 'f') ADVANCE(144);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(145);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 43:
      if (lookahead == 'g') ADVANCE(146);
      END_STATE();
    case 44:
      if (lookahead == 's') ADVANCE(147);
      END_STATE();
    case 45:
      if (lookahead == 'd') ADVANCE(148);
      if (lookahead == 'u') ADVANCE(149);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(150);
      END_STATE();
    case 47:
      if (lookahead == 'p') ADVANCE(151);
      if (lookahead == 't') ADVANCE(152);
      END_STATE();
    case 48:
      if (lookahead == 'n') ADVANCE(153);
      if (lookahead == 'r') ADVANCE(154);
      END_STATE();
    case 49:
      if (lookahead == 'r') ADVANCE(155);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_fs);
      END_STATE();
    case 51:
      if (lookahead == 'n') ADVANCE(156);
      END_STATE();
    case 52:
      if (lookahead == 'n') ADVANCE(157);
      END_STATE();
    case 53:
      if (lookahead == 'o') ADVANCE(158);
      END_STATE();
    case 54:
      if (lookahead == 'g') ADVANCE(159);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_if);
      if (lookahead == 'f') ADVANCE(160);
      if (lookahead == 'n') ADVANCE(161);
      END_STATE();
    case 56:
      if (lookahead == 'n') ADVANCE(162);
      END_STATE();
    case 57:
      if (lookahead == 'l') ADVANCE(163);
      END_STATE();
    case 58:
      if (lookahead == 'p') ADVANCE(164);
      END_STATE();
    case 59:
      if (lookahead == 'i') ADVANCE(165);
      if (lookahead == 'o') ADVANCE(166);
      if (lookahead == 'p') ADVANCE(167);
      if (lookahead == 's') ADVANCE(168);
      if (lookahead == 't') ADVANCE(169);
      END_STATE();
    case 60:
      if (lookahead == 'i') ADVANCE(170);
      END_STATE();
    case 61:
      if (lookahead == 'r') ADVANCE(171);
      END_STATE();
    case 62:
      if (lookahead == 't') ADVANCE(172);
      END_STATE();
    case 63:
      if (lookahead == 'c') ADVANCE(173);
      if (lookahead == 'g') ADVANCE(174);
      if (lookahead == 'n') ADVANCE(175);
      END_STATE();
    case 64:
      if (lookahead == 'c') ADVANCE(176);
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 65:
      if (lookahead == 'd') ADVANCE(178);
      END_STATE();
    case 66:
      if (lookahead == 'd') ADVANCE(179);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_ms);
      END_STATE();
    case 68:
      if (lookahead == 'n') ADVANCE(180);
      END_STATE();
    case 69:
      if (lookahead == 'g') ADVANCE(181);
      if (lookahead == 't') ADVANCE(182);
      if (lookahead == 'w') ADVANCE(183);
      if (lookahead == 'x') ADVANCE(184);
      END_STATE();
    case 70:
      if (lookahead == 'o') ADVANCE(185);
      END_STATE();
    case 71:
      if (lookahead == 'n') ADVANCE(186);
      if (lookahead == 'r') ADVANCE(187);
      if (lookahead == 's') ADVANCE(188);
      if (lookahead == 't') ADVANCE(189);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_ns);
      END_STATE();
    case 73:
      if (lookahead == 'l') ADVANCE(190);
      END_STATE();
    case 74:
      if (lookahead == 't') ADVANCE(191);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_or);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 77:
      if (lookahead == 'c') ADVANCE(193);
      if (lookahead == 'r') ADVANCE(194);
      END_STATE();
    case 78:
      if (lookahead == 'o') ADVANCE(195);
      END_STATE();
    case 79:
      if (lookahead == 's') ADVANCE(196);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(197);
      if (lookahead == 'o') ADVANCE(198);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_ps);
      END_STATE();
    case 82:
      if (lookahead == 'l') ADVANCE(199);
      if (lookahead == 'r') ADVANCE(200);
      END_STATE();
    case 83:
      if (lookahead == 'n') ADVANCE(201);
      END_STATE();
    case 84:
      if (lookahead == 'm') ADVANCE(202);
      END_STATE();
    case 85:
      ADVANCE_MAP(
        'a', 203,
        'f', 204,
        'g', 205,
        'j', 206,
        'l', 207,
        'p', 208,
        's', 209,
        't', 210,
      );
      END_STATE();
    case 86:
      if (lookahead == 'm') ADVANCE(211);
      END_STATE();
    case 87:
      if (lookahead == 'm') ADVANCE(212);
      END_STATE();
    case 88:
      if (lookahead == 'r') ADVANCE(213);
      END_STATE();
    case 89:
      if (lookahead == 'a') ADVANCE(214);
      if (lookahead == 'e') ADVANCE(215);
      if (lookahead == 'n') ADVANCE(216);
      if (lookahead == 'u') ADVANCE(217);
      END_STATE();
    case 90:
      if (lookahead == 'm') ADVANCE(218);
      END_STATE();
    case 91:
      if (lookahead == 'a') ADVANCE(219);
      END_STATE();
    case 92:
      if (lookahead == 'q') ADVANCE(220);
      END_STATE();
    case 93:
      if (lookahead == 'o') ADVANCE(221);
      END_STATE();
    case 94:
      if (lookahead == 'g') ADVANCE(222);
      END_STATE();
    case 95:
      if (lookahead == 'a') ADVANCE(223);
      END_STATE();
    case 96:
      if (lookahead == 'f') ADVANCE(224);
      if (lookahead == 'l') ADVANCE(225);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(226);
      END_STATE();
    case 98:
      if (lookahead == 'a') ADVANCE(227);
      if (lookahead == 'd') ADVANCE(228);
      if (lookahead == 'r') ADVANCE(229);
      END_STATE();
    case 99:
      if (lookahead == 'p') ADVANCE(230);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(231);
      END_STATE();
    case 101:
      if (lookahead == 'b') ADVANCE(232);
      if (lookahead == 'g') ADVANCE(233);
      if (lookahead == 's') ADVANCE(234);
      END_STATE();
    case 102:
      if (lookahead == 'i') ADVANCE(235);
      if (lookahead == 'r') ADVANCE(236);
      END_STATE();
    case 103:
      if (lookahead == 'm') ADVANCE(237);
      END_STATE();
    case 104:
      if (lookahead == 'a') ADVANCE(238);
      if (lookahead == 'i') ADVANCE(239);
      END_STATE();
    case 105:
      if (lookahead == 'p') ADVANCE(240);
      END_STATE();
    case 106:
      if (lookahead == 'i') ADVANCE(241);
      if (lookahead == 's') ADVANCE(242);
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_us);
      END_STATE();
    case 108:
      if (lookahead == 'i') ADVANCE(244);
      END_STATE();
    case 109:
      if (lookahead == 'r') ADVANCE(245);
      END_STATE();
    case 110:
      if (lookahead == 'c') ADVANCE(246);
      END_STATE();
    case 111:
      if (lookahead == 'r') ADVANCE(247);
      END_STATE();
    case 112:
      if (lookahead == 'i') ADVANCE(248);
      END_STATE();
    case 113:
      if (lookahead == 'i') ADVANCE(249);
      if (lookahead == 'n') ADVANCE(250);
      END_STATE();
    case 114:
      if (lookahead == 'a') ADVANCE(251);
      END_STATE();
    case 115:
      if (lookahead == 'i') ADVANCE(252);
      END_STATE();
    case 116:
      if (lookahead == 'l') ADVANCE(253);
      if (lookahead == 'r') ADVANCE(254);
      if (lookahead == 't') ADVANCE(255);
      END_STATE();
    case 117:
      if (lookahead == 'r') ADVANCE(256);
      END_STATE();
    case 118:
      if (lookahead == 'o') ADVANCE(257);
      END_STATE();
    case 119:
      if (lookahead == 'r') ADVANCE(258);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym_edge_descriptor_token1);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(259);
      END_STATE();
    case 122:
      if (lookahead == 'a') ADVANCE(260);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(261);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 125:
      if (lookahead == 'e') ADVANCE(262);
      if (lookahead == 'i') ADVANCE(263);
      if (lookahead == 'u') ADVANCE(264);
      END_STATE();
    case 126:
      if (lookahead == 'o') ADVANCE(265);
      END_STATE();
    case 127:
      if (lookahead == 'o') ADVANCE(266);
      END_STATE();
    case 128:
      if (lookahead == 'i') ADVANCE(267);
      END_STATE();
    case 129:
      if (lookahead == 'd') ADVANCE(268);
      if (lookahead == 's') ADVANCE(269);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_bit);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(270);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_buf);
      if (lookahead == 'i') ADVANCE(271);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(272);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(273);
      END_STATE();
    case 135:
      if (lookahead == 'n') ADVANCE(274);
      END_STATE();
    case 136:
      if (lookahead == 'c') ADVANCE(275);
      END_STATE();
    case 137:
      if (lookahead == 's') ADVANCE(276);
      END_STATE();
    case 138:
      if (lookahead == 'c') ADVANCE(277);
      END_STATE();
    case 139:
      if (lookahead == 's') ADVANCE(278);
      END_STATE();
    case 140:
      if (lookahead == 's') ADVANCE(279);
      if (lookahead == 't') ADVANCE(280);
      END_STATE();
    case 141:
      if (lookahead == 'e') ADVANCE(281);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(282);
      END_STATE();
    case 143:
      if (lookahead == 's') ADVANCE(283);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(284);
      if (lookahead == 'p') ADVANCE(285);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(286);
      if (lookahead == 't') ADVANCE(287);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(288);
      END_STATE();
    case 147:
      if (lookahead == 'e') ADVANCE(289);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_end);
      ADVANCE_MAP(
        'c', 290,
        'f', 291,
        'g', 292,
        'i', 293,
        'm', 294,
        'p', 295,
        's', 296,
        't', 297,
      );
      END_STATE();
    case 149:
      if (lookahead == 'm') ADVANCE(298);
      END_STATE();
    case 150:
      if (lookahead == 'n') ADVANCE(299);
      END_STATE();
    case 151:
      if (lookahead == 'e') ADVANCE(300);
      if (lookahead == 'o') ADVANCE(301);
      END_STATE();
    case 152:
      if (lookahead == 'e') ADVANCE(302);
      END_STATE();
    case 153:
      if (lookahead == 'a') ADVANCE(303);
      END_STATE();
    case 154:
      if (lookahead == 's') ADVANCE(304);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'c') ADVANCE(305);
      if (lookahead == 'e') ADVANCE(306);
      if (lookahead == 'k') ADVANCE(307);
      END_STATE();
    case 156:
      if (lookahead == 'c') ADVANCE(308);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(309);
      if (lookahead == 'v') ADVANCE(310);
      END_STATE();
    case 158:
      if (lookahead == 'b') ADVANCE(311);
      END_STATE();
    case 159:
      if (lookahead == 'h') ADVANCE(312);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_iff);
      END_STATE();
    case 161:
      if (lookahead == 'o') ADVANCE(313);
      END_STATE();
    case 162:
      if (lookahead == 'o') ADVANCE(314);
      END_STATE();
    case 163:
      if (lookahead == 'e') ADVANCE(315);
      END_STATE();
    case 164:
      if (lookahead == 'l') ADVANCE(316);
      if (lookahead == 'o') ADVANCE(317);
      END_STATE();
    case 165:
      if (lookahead == 't') ADVANCE(318);
      END_STATE();
    case 166:
      if (lookahead == 'u') ADVANCE(319);
      END_STATE();
    case 167:
      if (lookahead == 'u') ADVANCE(320);
      END_STATE();
    case 168:
      if (lookahead == 'i') ADVANCE(321);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == 'e') ADVANCE(322);
      END_STATE();
    case 170:
      if (lookahead == 'n') ADVANCE(323);
      END_STATE();
    case 171:
      if (lookahead == 'g') ADVANCE(324);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 173:
      if (lookahead == 'a') ADVANCE(325);
      END_STATE();
    case 174:
      if (lookahead == 'i') ADVANCE(326);
      END_STATE();
    case 175:
      if (lookahead == 'g') ADVANCE(327);
      END_STATE();
    case 176:
      if (lookahead == 'r') ADVANCE(328);
      END_STATE();
    case 177:
      if (lookahead == 'c') ADVANCE(329);
      END_STATE();
    case 178:
      if (lookahead == 'i') ADVANCE(330);
      END_STATE();
    case 179:
      if (lookahead == 'p') ADVANCE(331);
      if (lookahead == 'u') ADVANCE(332);
      END_STATE();
    case 180:
      if (lookahead == 'd') ADVANCE(333);
      END_STATE();
    case 181:
      if (lookahead == 'e') ADVANCE(334);
      END_STATE();
    case 182:
      if (lookahead == 't') ADVANCE(335);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 184:
      if (lookahead == 't') ADVANCE(336);
      END_STATE();
    case 185:
      if (lookahead == 's') ADVANCE(337);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(338);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_nor);
      END_STATE();
    case 188:
      if (lookahead == 'h') ADVANCE(339);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == 'i') ADVANCE(340);
      END_STATE();
    case 190:
      if (lookahead == 'l') ADVANCE(341);
      END_STATE();
    case 191:
      if (lookahead == 'i') ADVANCE(342);
      END_STATE();
    case 192:
      if (lookahead == 'p') ADVANCE(343);
      END_STATE();
    case 193:
      if (lookahead == 'k') ADVANCE(344);
      END_STATE();
    case 194:
      if (lookahead == 'a') ADVANCE(345);
      END_STATE();
    case 195:
      if (lookahead == 's') ADVANCE(346);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(347);
      END_STATE();
    case 197:
      if (lookahead == 'm') ADVANCE(348);
      if (lookahead == 'o') ADVANCE(349);
      END_STATE();
    case 198:
      if (lookahead == 'g') ADVANCE(350);
      if (lookahead == 'p') ADVANCE(351);
      if (lookahead == 't') ADVANCE(352);
      END_STATE();
    case 199:
      if (lookahead == 'l') ADVANCE(353);
      if (lookahead == 's') ADVANCE(354);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(355);
      END_STATE();
    case 201:
      if (lookahead == 'd') ADVANCE(356);
      END_STATE();
    case 202:
      if (lookahead == 'o') ADVANCE(357);
      END_STATE();
    case 203:
      if (lookahead == 'l') ADVANCE(358);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_ref);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_reg);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(359);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(360);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(361);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(362);
      END_STATE();
    case 210:
      if (lookahead == 'u') ADVANCE(363);
      END_STATE();
    case 211:
      if (lookahead == 'o') ADVANCE(364);
      END_STATE();
    case 212:
      if (lookahead == 'o') ADVANCE(365);
      END_STATE();
    case 213:
      if (lookahead == 'a') ADVANCE(366);
      END_STATE();
    case 214:
      if (lookahead == 'l') ADVANCE(367);
      END_STATE();
    case 215:
      if (lookahead == 'v') ADVANCE(368);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(369);
      END_STATE();
    case 217:
      if (lookahead == 'n') ADVANCE(370);
      END_STATE();
    case 218:
      if (lookahead == 'p') ADVANCE(371);
      END_STATE();
    case 219:
      if (lookahead == 'l') ADVANCE(372);
      END_STATE();
    case 220:
      if (lookahead == 'u') ADVANCE(373);
      END_STATE();
    case 221:
      if (lookahead == 'r') ADVANCE(374);
      if (lookahead == 'w') ADVANCE(375);
      END_STATE();
    case 222:
      if (lookahead == 'n') ADVANCE(376);
      END_STATE();
    case 223:
      if (lookahead == 'l') ADVANCE(377);
      END_STATE();
    case 224:
      if (lookahead == 't') ADVANCE(378);
      END_STATE();
    case 225:
      if (lookahead == 'v') ADVANCE(379);
      END_STATE();
    case 226:
      if (lookahead == 'c') ADVANCE(380);
      END_STATE();
    case 227:
      if (lookahead == 't') ADVANCE(381);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_std);
      END_STATE();
    case 229:
      if (lookahead == 'i') ADVANCE(382);
      if (lookahead == 'o') ADVANCE(383);
      if (lookahead == 'u') ADVANCE(384);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(385);
      if (lookahead == 'p') ADVANCE(386);
      END_STATE();
    case 231:
      if (lookahead == 'c') ADVANCE(387);
      END_STATE();
    case 232:
      if (lookahead == 'l') ADVANCE(388);
      END_STATE();
    case 233:
      if (lookahead == 'g') ADVANCE(389);
      END_STATE();
    case 234:
      if (lookahead == 'k') ADVANCE(390);
      END_STATE();
    case 235:
      if (lookahead == 's') ADVANCE(391);
      END_STATE();
    case 236:
      if (lookahead == 'o') ADVANCE(392);
      END_STATE();
    case 237:
      if (lookahead == 'e') ADVANCE(393);
      END_STATE();
    case 238:
      if (lookahead == 'n') ADVANCE(394);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_tri);
      if (lookahead == '0') ADVANCE(395);
      if (lookahead == '1') ADVANCE(396);
      if (lookahead == 'a') ADVANCE(397);
      if (lookahead == 'o') ADVANCE(398);
      if (lookahead == 'r') ADVANCE(399);
      END_STATE();
    case 240:
      if (lookahead == 'e') ADVANCE(400);
      END_STATE();
    case 241:
      if (lookahead == 'o') ADVANCE(401);
      if (lookahead == 'q') ADVANCE(402);
      END_STATE();
    case 242:
      if (lookahead == 'i') ADVANCE(403);
      END_STATE();
    case 243:
      if (lookahead == 'i') ADVANCE(404);
      if (lookahead == 'y') ADVANCE(405);
      END_STATE();
    case 244:
      if (lookahead == 'r') ADVANCE(406);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 246:
      if (lookahead == 't') ADVANCE(407);
      END_STATE();
    case 247:
      if (lookahead == 't') ADVANCE(408);
      END_STATE();
    case 248:
      if (lookahead == 'd') ADVANCE(409);
      END_STATE();
    case 249:
      if (lookahead == 't') ADVANCE(410);
      END_STATE();
    case 250:
      if (lookahead == 'd') ADVANCE(411);
      END_STATE();
    case 251:
      if (lookahead == 'k') ADVANCE(412);
      END_STATE();
    case 252:
      if (lookahead == 'l') ADVANCE(413);
      END_STATE();
    case 253:
      if (lookahead == 'd') ADVANCE(414);
      END_STATE();
    case 254:
      if (lookahead == 'e') ADVANCE(415);
      END_STATE();
    case 255:
      if (lookahead == 'h') ADVANCE(416);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_wor);
      END_STATE();
    case 257:
      if (lookahead == 'r') ADVANCE(417);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_xor);
      END_STATE();
    case 259:
      if (lookahead == 'p') ADVANCE(418);
      END_STATE();
    case 260:
      if (lookahead == 's') ADVANCE(419);
      END_STATE();
    case 261:
      if (lookahead == 'y') ADVANCE(420);
      END_STATE();
    case 262:
      if (lookahead == 'r') ADVANCE(421);
      END_STATE();
    case 263:
      if (lookahead == 'g') ADVANCE(422);
      END_STATE();
    case 264:
      if (lookahead == 'm') ADVANCE(423);
      END_STATE();
    case 265:
      if (lookahead == 'm') ADVANCE(424);
      END_STATE();
    case 266:
      if (lookahead == 'r') ADVANCE(425);
      END_STATE();
    case 267:
      if (lookahead == 'n') ADVANCE(426);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_bind);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_bins);
      if (lookahead == 'o') ADVANCE(427);
      END_STATE();
    case 270:
      if (lookahead == 'k') ADVANCE(428);
      END_STATE();
    case 271:
      if (lookahead == 'f') ADVANCE(429);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_byte);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_case);
      if (lookahead == 'x') ADVANCE(430);
      if (lookahead == 'z') ADVANCE(431);
      END_STATE();
    case 274:
      if (lookahead == 'd') ADVANCE(432);
      END_STATE();
    case 275:
      if (lookahead == 'k') ADVANCE(433);
      END_STATE();
    case 276:
      if (lookahead == 's') ADVANCE(434);
      END_STATE();
    case 277:
      if (lookahead == 'k') ADVANCE(435);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_cmos);
      END_STATE();
    case 279:
      if (lookahead == 't') ADVANCE(436);
      END_STATE();
    case 280:
      if (lookahead == 'e') ADVANCE(437);
      if (lookahead == 'i') ADVANCE(438);
      END_STATE();
    case 281:
      if (lookahead == 'r') ADVANCE(439);
      END_STATE();
    case 282:
      if (lookahead == 's') ADVANCE(440);
      END_STATE();
    case 283:
      if (lookahead == 's') ADVANCE(441);
      END_STATE();
    case 284:
      if (lookahead == 'u') ADVANCE(442);
      END_STATE();
    case 285:
      if (lookahead == 'a') ADVANCE(443);
      END_STATE();
    case 286:
      if (lookahead == 'b') ADVANCE(444);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_dist);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_edge);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 290:
      if (lookahead == 'a') ADVANCE(445);
      if (lookahead == 'h') ADVANCE(446);
      if (lookahead == 'l') ADVANCE(447);
      END_STATE();
    case 291:
      if (lookahead == 'u') ADVANCE(448);
      END_STATE();
    case 292:
      if (lookahead == 'e') ADVANCE(449);
      if (lookahead == 'r') ADVANCE(450);
      END_STATE();
    case 293:
      if (lookahead == 'n') ADVANCE(451);
      END_STATE();
    case 294:
      if (lookahead == 'o') ADVANCE(452);
      END_STATE();
    case 295:
      if (lookahead == 'a') ADVANCE(453);
      if (lookahead == 'r') ADVANCE(454);
      END_STATE();
    case 296:
      if (lookahead == 'e') ADVANCE(455);
      if (lookahead == 'p') ADVANCE(456);
      END_STATE();
    case 297:
      if (lookahead == 'a') ADVANCE(457);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 299:
      if (lookahead == 't') ADVANCE(458);
      END_STATE();
    case 300:
      if (lookahead == 'c') ADVANCE(459);
      END_STATE();
    case 301:
      if (lookahead == 'r') ADVANCE(460);
      END_STATE();
    case 302:
      if (lookahead == 'n') ADVANCE(461);
      if (lookahead == 'r') ADVANCE(462);
      END_STATE();
    case 303:
      if (lookahead == 'l') ADVANCE(463);
      END_STATE();
    case 304:
      if (lookahead == 't') ADVANCE(464);
      END_STATE();
    case 305:
      if (lookahead == 'e') ADVANCE(465);
      END_STATE();
    case 306:
      if (lookahead == 'a') ADVANCE(466);
      if (lookahead == 'v') ADVANCE(467);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_fork);
      if (lookahead == 'j') ADVANCE(468);
      END_STATE();
    case 308:
      if (lookahead == 't') ADVANCE(469);
      END_STATE();
    case 309:
      if (lookahead == 'r') ADVANCE(470);
      END_STATE();
    case 310:
      if (lookahead == 'a') ADVANCE(471);
      END_STATE();
    case 311:
      if (lookahead == 'a') ADVANCE(472);
      END_STATE();
    case 312:
      if (lookahead == 'z') ADVANCE(473);
      END_STATE();
    case 313:
      if (lookahead == 'n') ADVANCE(474);
      END_STATE();
    case 314:
      if (lookahead == 'r') ADVANCE(475);
      END_STATE();
    case 315:
      if (lookahead == 'g') ADVANCE(476);
      END_STATE();
    case 316:
      if (lookahead == 'e') ADVANCE(477);
      if (lookahead == 'i') ADVANCE(478);
      END_STATE();
    case 317:
      if (lookahead == 'r') ADVANCE(479);
      END_STATE();
    case 318:
      if (lookahead == 'i') ADVANCE(480);
      END_STATE();
    case 319:
      if (lookahead == 't') ADVANCE(481);
      END_STATE();
    case 320:
      if (lookahead == 't') ADVANCE(482);
      END_STATE();
    case 321:
      if (lookahead == 'd') ADVANCE(483);
      END_STATE();
    case 322:
      if (lookahead == 'g') ADVANCE(484);
      if (lookahead == 'r') ADVANCE(485);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_join);
      if (lookahead == '_') ADVANCE(486);
      END_STATE();
    case 324:
      if (lookahead == 'e') ADVANCE(487);
      END_STATE();
    case 325:
      if (lookahead == 'l') ADVANCE(488);
      END_STATE();
    case 326:
      if (lookahead == 'c') ADVANCE(489);
      END_STATE();
    case 327:
      if (lookahead == 'i') ADVANCE(490);
      END_STATE();
    case 328:
      if (lookahead == 'o') ADVANCE(491);
      END_STATE();
    case 329:
      if (lookahead == 'h') ADVANCE(492);
      END_STATE();
    case 330:
      if (lookahead == 'u') ADVANCE(493);
      END_STATE();
    case 331:
      if (lookahead == 'o') ADVANCE(494);
      END_STATE();
    case 332:
      if (lookahead == 'l') ADVANCE(495);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_nand);
      END_STATE();
    case 334:
      if (lookahead == 'd') ADVANCE(496);
      END_STATE();
    case 335:
      if (lookahead == 'y') ADVANCE(497);
      END_STATE();
    case 336:
      if (lookahead == 't') ADVANCE(498);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_nmos);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_none);
      END_STATE();
    case 339:
      if (lookahead == 'o') ADVANCE(499);
      END_STATE();
    case 340:
      if (lookahead == 'f') ADVANCE(500);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_null);
      END_STATE();
    case 342:
      if (lookahead == 'o') ADVANCE(501);
      END_STATE();
    case 343:
      if (lookahead == 'u') ADVANCE(502);
      END_STATE();
    case 344:
      if (lookahead == 'a') ADVANCE(503);
      if (lookahead == 'e') ADVANCE(504);
      END_STATE();
    case 345:
      if (lookahead == 'm') ADVANCE(505);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_pmos);
      END_STATE();
    case 347:
      if (lookahead == 'd') ADVANCE(506);
      END_STATE();
    case 348:
      if (lookahead == 'i') ADVANCE(507);
      END_STATE();
    case 349:
      if (lookahead == 'r') ADVANCE(508);
      END_STATE();
    case 350:
      if (lookahead == 'r') ADVANCE(509);
      END_STATE();
    case 351:
      if (lookahead == 'e') ADVANCE(510);
      END_STATE();
    case 352:
      if (lookahead == 'e') ADVANCE(511);
      END_STATE();
    case 353:
      if (lookahead == '0') ADVANCE(512);
      if (lookahead == '1') ADVANCE(513);
      if (lookahead == 'd') ADVANCE(514);
      if (lookahead == 'u') ADVANCE(515);
      END_STATE();
    case 354:
      if (lookahead == 'e') ADVANCE(516);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(anon_sym_pure);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_rand);
      if (lookahead == 'c') ADVANCE(517);
      if (lookahead == 'o') ADVANCE(518);
      END_STATE();
    case 357:
      if (lookahead == 's') ADVANCE(519);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_real);
      if (lookahead == 't') ADVANCE(520);
      END_STATE();
    case 359:
      if (lookahead == 'c') ADVANCE(521);
      END_STATE();
    case 360:
      if (lookahead == 'a') ADVANCE(522);
      END_STATE();
    case 361:
      if (lookahead == 'a') ADVANCE(523);
      END_STATE();
    case 362:
      if (lookahead == 'r') ADVANCE(524);
      END_STATE();
    case 363:
      if (lookahead == 'r') ADVANCE(525);
      END_STATE();
    case 364:
      if (lookahead == 's') ADVANCE(526);
      END_STATE();
    case 365:
      if (lookahead == 's') ADVANCE(527);
      END_STATE();
    case 366:
      if (lookahead == 'n') ADVANCE(528);
      END_STATE();
    case 367:
      if (lookahead == 'w') ADVANCE(529);
      END_STATE();
    case 368:
      if (lookahead == 'e') ADVANCE(530);
      END_STATE();
    case 369:
      if (lookahead == 'x') ADVANCE(531);
      END_STATE();
    case 370:
      if (lookahead == 't') ADVANCE(532);
      END_STATE();
    case 371:
      if (lookahead == 'l') ADVANCE(533);
      END_STATE();
    case 372:
      if (lookahead == 'a') ADVANCE(534);
      END_STATE();
    case 373:
      if (lookahead == 'e') ADVANCE(535);
      END_STATE();
    case 374:
      if (lookahead == 't') ADVANCE(536);
      END_STATE();
    case 375:
      if (lookahead == 'c') ADVANCE(537);
      END_STATE();
    case 376:
      if (lookahead == 'e') ADVANCE(538);
      END_STATE();
    case 377:
      if (lookahead == 'l') ADVANCE(539);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_soft);
      END_STATE();
    case 379:
      if (lookahead == 'e') ADVANCE(540);
      END_STATE();
    case 380:
      if (lookahead == 'i') ADVANCE(541);
      if (lookahead == 'p') ADVANCE(542);
      END_STATE();
    case 381:
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 382:
      if (lookahead == 'n') ADVANCE(544);
      END_STATE();
    case 383:
      if (lookahead == 'n') ADVANCE(545);
      END_STATE();
    case 384:
      if (lookahead == 'c') ADVANCE(546);
      END_STATE();
    case 385:
      if (lookahead == 'r') ADVANCE(547);
      END_STATE();
    case 386:
      if (lookahead == 'l') ADVANCE(548);
      END_STATE();
    case 387:
      if (lookahead == '_') ADVANCE(549);
      END_STATE();
    case 388:
      if (lookahead == 'e') ADVANCE(550);
      END_STATE();
    case 389:
      if (lookahead == 'e') ADVANCE(551);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_task);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_this);
      END_STATE();
    case 392:
      if (lookahead == 'u') ADVANCE(552);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_time);
      if (lookahead == 'p') ADVANCE(553);
      if (lookahead == 'u') ADVANCE(554);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_tran);
      if (lookahead == 'i') ADVANCE(555);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_tri0);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_tri1);
      END_STATE();
    case 397:
      if (lookahead == 'n') ADVANCE(556);
      END_STATE();
    case 398:
      if (lookahead == 'r') ADVANCE(557);
      END_STATE();
    case 399:
      if (lookahead == 'e') ADVANCE(558);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_type);
      if (lookahead == '_') ADVANCE(559);
      if (lookahead == 'd') ADVANCE(560);
      END_STATE();
    case 401:
      if (lookahead == 'n') ADVANCE(561);
      END_STATE();
    case 402:
      if (lookahead == 'u') ADVANCE(562);
      END_STATE();
    case 403:
      if (lookahead == 'g') ADVANCE(563);
      END_STATE();
    case 404:
      if (lookahead == 'l') ADVANCE(564);
      END_STATE();
    case 405:
      if (lookahead == 'p') ADVANCE(565);
      END_STATE();
    case 406:
      if (lookahead == 'e') ADVANCE(566);
      END_STATE();
    case 407:
      if (lookahead == 'o') ADVANCE(567);
      END_STATE();
    case 408:
      if (lookahead == 'u') ADVANCE(568);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_wait);
      if (lookahead == '_') ADVANCE(569);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_wand);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_weak);
      if (lookahead == '0') ADVANCE(570);
      if (lookahead == '1') ADVANCE(571);
      END_STATE();
    case 413:
      if (lookahead == 'e') ADVANCE(572);
      END_STATE();
    case 414:
      if (lookahead == 'c') ADVANCE(573);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_wire);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_with);
      if (lookahead == 'i') ADVANCE(574);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_xnor);
      END_STATE();
    case 418:
      if (lookahead == 't') ADVANCE(575);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_alias);
      END_STATE();
    case 420:
      if (lookahead == 's') ADVANCE(576);
      END_STATE();
    case 421:
      if (lookahead == 't') ADVANCE(577);
      END_STATE();
    case 422:
      if (lookahead == 'n') ADVANCE(578);
      END_STATE();
    case 423:
      if (lookahead == 'e') ADVANCE(579);
      END_STATE();
    case 424:
      if (lookahead == 'a') ADVANCE(580);
      END_STATE();
    case 425:
      if (lookahead == 'e') ADVANCE(581);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_begin);
      END_STATE();
    case 427:
      if (lookahead == 'f') ADVANCE(582);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 429:
      if (lookahead == '0') ADVANCE(583);
      if (lookahead == '1') ADVANCE(584);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_casex);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_casez);
      END_STATE();
    case 432:
      if (lookahead == 'l') ADVANCE(585);
      END_STATE();
    case 433:
      if (lookahead == 'e') ADVANCE(586);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 435:
      if (lookahead == 'i') ADVANCE(587);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_const);
      if (lookahead == 'r') ADVANCE(588);
      END_STATE();
    case 437:
      if (lookahead == 'x') ADVANCE(589);
      END_STATE();
    case 438:
      if (lookahead == 'n') ADVANCE(590);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_cover);
      if (lookahead == 'g') ADVANCE(591);
      if (lookahead == 'p') ADVANCE(592);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_cross);
      END_STATE();
    case 441:
      if (lookahead == 'i') ADVANCE(593);
      END_STATE();
    case 442:
      if (lookahead == 'l') ADVANCE(594);
      END_STATE();
    case 443:
      if (lookahead == 'r') ADVANCE(595);
      END_STATE();
    case 444:
      if (lookahead == 'l') ADVANCE(596);
      END_STATE();
    case 445:
      if (lookahead == 's') ADVANCE(597);
      END_STATE();
    case 446:
      if (lookahead == 'e') ADVANCE(598);
      END_STATE();
    case 447:
      if (lookahead == 'a') ADVANCE(599);
      if (lookahead == 'o') ADVANCE(600);
      END_STATE();
    case 448:
      if (lookahead == 'n') ADVANCE(601);
      END_STATE();
    case 449:
      if (lookahead == 'n') ADVANCE(602);
      END_STATE();
    case 450:
      if (lookahead == 'o') ADVANCE(603);
      END_STATE();
    case 451:
      if (lookahead == 't') ADVANCE(604);
      END_STATE();
    case 452:
      if (lookahead == 'd') ADVANCE(605);
      END_STATE();
    case 453:
      if (lookahead == 'c') ADVANCE(606);
      END_STATE();
    case 454:
      if (lookahead == 'i') ADVANCE(607);
      if (lookahead == 'o') ADVANCE(608);
      END_STATE();
    case 455:
      if (lookahead == 'q') ADVANCE(609);
      END_STATE();
    case 456:
      if (lookahead == 'e') ADVANCE(610);
      END_STATE();
    case 457:
      if (lookahead == 's') ADVANCE(611);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_event);
      if (lookahead == 'u') ADVANCE(612);
      END_STATE();
    case 459:
      if (lookahead == 't') ADVANCE(613);
      END_STATE();
    case 460:
      if (lookahead == 't') ADVANCE(614);
      END_STATE();
    case 461:
      if (lookahead == 'd') ADVANCE(615);
      END_STATE();
    case 462:
      if (lookahead == 'n') ADVANCE(616);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_final);
      END_STATE();
    case 464:
      if (lookahead == '_') ADVANCE(617);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_force);
      END_STATE();
    case 466:
      if (lookahead == 'c') ADVANCE(618);
      END_STATE();
    case 467:
      if (lookahead == 'e') ADVANCE(619);
      END_STATE();
    case 468:
      if (lookahead == 'o') ADVANCE(620);
      END_STATE();
    case 469:
      if (lookahead == 'i') ADVANCE(621);
      END_STATE();
    case 470:
      if (lookahead == 'a') ADVANCE(622);
      END_STATE();
    case 471:
      if (lookahead == 'r') ADVANCE(623);
      END_STATE();
    case 472:
      if (lookahead == 'l') ADVANCE(624);
      END_STATE();
    case 473:
      if (lookahead == '0') ADVANCE(625);
      if (lookahead == '1') ADVANCE(626);
      END_STATE();
    case 474:
      if (lookahead == 'e') ADVANCE(627);
      END_STATE();
    case 475:
      if (lookahead == 'e') ADVANCE(628);
      END_STATE();
    case 476:
      if (lookahead == 'a') ADVANCE(629);
      END_STATE();
    case 477:
      if (lookahead == 'm') ADVANCE(630);
      END_STATE();
    case 478:
      if (lookahead == 'e') ADVANCE(631);
      END_STATE();
    case 479:
      if (lookahead == 't') ADVANCE(632);
      END_STATE();
    case 480:
      if (lookahead == 'a') ADVANCE(633);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_inout);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_input);
      END_STATE();
    case 483:
      if (lookahead == 'e') ADVANCE(634);
      END_STATE();
    case 484:
      if (lookahead == 'e') ADVANCE(635);
      END_STATE();
    case 485:
      if (lookahead == 'c') ADVANCE(636);
      if (lookahead == 'f') ADVANCE(637);
      if (lookahead == 's') ADVANCE(638);
      END_STATE();
    case 486:
      if (lookahead == 'a') ADVANCE(639);
      if (lookahead == 'n') ADVANCE(640);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_large);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_local);
      if (lookahead == 'p') ADVANCE(641);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_logic);
      END_STATE();
    case 490:
      if (lookahead == 'n') ADVANCE(642);
      END_STATE();
    case 491:
      if (lookahead == 'm') ADVANCE(643);
      END_STATE();
    case 492:
      if (lookahead == 'e') ADVANCE(644);
      END_STATE();
    case 493:
      if (lookahead == 'm') ADVANCE(645);
      END_STATE();
    case 494:
      if (lookahead == 'r') ADVANCE(646);
      END_STATE();
    case 495:
      if (lookahead == 'e') ADVANCE(647);
      END_STATE();
    case 496:
      if (lookahead == 'g') ADVANCE(648);
      END_STATE();
    case 497:
      if (lookahead == 'p') ADVANCE(649);
      END_STATE();
    case 498:
      if (lookahead == 'i') ADVANCE(650);
      END_STATE();
    case 499:
      if (lookahead == 'w') ADVANCE(651);
      END_STATE();
    case 500:
      if (lookahead == '0') ADVANCE(652);
      if (lookahead == '1') ADVANCE(653);
      END_STATE();
    case 501:
      if (lookahead == 'n') ADVANCE(654);
      END_STATE();
    case 502:
      if (lookahead == 't') ADVANCE(655);
      END_STATE();
    case 503:
      if (lookahead == 'g') ADVANCE(656);
      END_STATE();
    case 504:
      if (lookahead == 'd') ADVANCE(657);
      END_STATE();
    case 505:
      if (lookahead == 'e') ADVANCE(658);
      END_STATE();
    case 506:
      if (lookahead == 'g') ADVANCE(659);
      END_STATE();
    case 507:
      if (lookahead == 't') ADVANCE(660);
      END_STATE();
    case 508:
      if (lookahead == 'i') ADVANCE(661);
      END_STATE();
    case 509:
      if (lookahead == 'a') ADVANCE(662);
      END_STATE();
    case 510:
      if (lookahead == 'r') ADVANCE(663);
      END_STATE();
    case 511:
      if (lookahead == 'c') ADVANCE(664);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_pull0);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_pull1);
      END_STATE();
    case 514:
      if (lookahead == 'o') ADVANCE(665);
      END_STATE();
    case 515:
      if (lookahead == 'p') ADVANCE(666);
      END_STATE();
    case 516:
      if (lookahead == 's') ADVANCE(667);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym_randc);
      if (lookahead == 'a') ADVANCE(668);
      END_STATE();
    case 518:
      if (lookahead == 'm') ADVANCE(669);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(anon_sym_rcmos);
      END_STATE();
    case 520:
      if (lookahead == 'i') ADVANCE(670);
      END_STATE();
    case 521:
      if (lookahead == 't') ADVANCE(671);
      END_STATE();
    case 522:
      if (lookahead == 's') ADVANCE(672);
      END_STATE();
    case 523:
      if (lookahead == 't') ADVANCE(673);
      END_STATE();
    case 524:
      if (lookahead == 'i') ADVANCE(674);
      END_STATE();
    case 525:
      if (lookahead == 'n') ADVANCE(675);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_rnmos);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_rpmos);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_rtran);
      if (lookahead == 'i') ADVANCE(676);
      END_STATE();
    case 529:
      if (lookahead == 'a') ADVANCE(677);
      END_STATE();
    case 530:
      if (lookahead == 'n') ADVANCE(678);
      END_STATE();
    case 531:
      if (lookahead == 't') ADVANCE(679);
      END_STATE();
    case 532:
      if (lookahead == 'i') ADVANCE(680);
      END_STATE();
    case 533:
      if (lookahead == 'e') ADVANCE(681);
      END_STATE();
    case 534:
      if (lookahead == 'r') ADVANCE(682);
      END_STATE();
    case 535:
      if (lookahead == 'n') ADVANCE(683);
      END_STATE();
    case 536:
      if (lookahead == 'i') ADVANCE(684);
      if (lookahead == 'r') ADVANCE(685);
      END_STATE();
    case 537:
      if (lookahead == 'a') ADVANCE(686);
      END_STATE();
    case 538:
      if (lookahead == 'd') ADVANCE(687);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_small);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_solve);
      END_STATE();
    case 541:
      if (lookahead == 'f') ADVANCE(688);
      END_STATE();
    case 542:
      if (lookahead == 'a') ADVANCE(689);
      END_STATE();
    case 543:
      if (lookahead == 'c') ADVANCE(690);
      END_STATE();
    case 544:
      if (lookahead == 'g') ADVANCE(691);
      END_STATE();
    case 545:
      if (lookahead == 'g') ADVANCE(692);
      END_STATE();
    case 546:
      if (lookahead == 't') ADVANCE(693);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_super);
      END_STATE();
    case 548:
      if (lookahead == 'y') ADVANCE(694);
      END_STATE();
    case 549:
      if (lookahead == 'a') ADVANCE(695);
      if (lookahead == 'r') ADVANCE(696);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_table);
      END_STATE();
    case 551:
      if (lookahead == 'd') ADVANCE(697);
      END_STATE();
    case 552:
      if (lookahead == 'g') ADVANCE(698);
      END_STATE();
    case 553:
      if (lookahead == 'r') ADVANCE(699);
      END_STATE();
    case 554:
      if (lookahead == 'n') ADVANCE(700);
      END_STATE();
    case 555:
      if (lookahead == 'f') ADVANCE(701);
      END_STATE();
    case 556:
      if (lookahead == 'd') ADVANCE(702);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_trior);
      END_STATE();
    case 558:
      if (lookahead == 'g') ADVANCE(703);
      END_STATE();
    case 559:
      if (lookahead == 'o') ADVANCE(704);
      END_STATE();
    case 560:
      if (lookahead == 'e') ADVANCE(705);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 562:
      if (lookahead == 'e') ADVANCE(706);
      END_STATE();
    case 563:
      if (lookahead == 'n') ADVANCE(707);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_until);
      if (lookahead == '_') ADVANCE(708);
      END_STATE();
    case 565:
      if (lookahead == 'e') ADVANCE(709);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_uwire);
      END_STATE();
    case 567:
      if (lookahead == 'r') ADVANCE(710);
      END_STATE();
    case 568:
      if (lookahead == 'a') ADVANCE(711);
      END_STATE();
    case 569:
      if (lookahead == 'o') ADVANCE(712);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_weak0);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_weak1);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 573:
      if (lookahead == 'a') ADVANCE(713);
      END_STATE();
    case 574:
      if (lookahead == 'n') ADVANCE(714);
      END_STATE();
    case 575:
      if (lookahead == '_') ADVANCE(715);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_always);
      if (lookahead == '_') ADVANCE(716);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_assign);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_assume);
      END_STATE();
    case 580:
      if (lookahead == 't') ADVANCE(717);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_before);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_binsof);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_bufif0);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_bufif1);
      END_STATE();
    case 585:
      if (lookahead == 'e') ADVANCE(718);
      END_STATE();
    case 586:
      if (lookahead == 'r') ADVANCE(719);
      END_STATE();
    case 587:
      if (lookahead == 'n') ADVANCE(720);
      END_STATE();
    case 588:
      if (lookahead == 'a') ADVANCE(721);
      END_STATE();
    case 589:
      if (lookahead == 't') ADVANCE(722);
      END_STATE();
    case 590:
      if (lookahead == 'u') ADVANCE(723);
      END_STATE();
    case 591:
      if (lookahead == 'r') ADVANCE(724);
      END_STATE();
    case 592:
      if (lookahead == 'o') ADVANCE(725);
      END_STATE();
    case 593:
      if (lookahead == 'g') ADVANCE(726);
      END_STATE();
    case 594:
      if (lookahead == 't') ADVANCE(727);
      END_STATE();
    case 595:
      if (lookahead == 'a') ADVANCE(728);
      END_STATE();
    case 596:
      if (lookahead == 'e') ADVANCE(729);
      END_STATE();
    case 597:
      if (lookahead == 'e') ADVANCE(730);
      END_STATE();
    case 598:
      if (lookahead == 'c') ADVANCE(731);
      END_STATE();
    case 599:
      if (lookahead == 's') ADVANCE(732);
      END_STATE();
    case 600:
      if (lookahead == 'c') ADVANCE(733);
      END_STATE();
    case 601:
      if (lookahead == 'c') ADVANCE(734);
      END_STATE();
    case 602:
      if (lookahead == 'e') ADVANCE(735);
      END_STATE();
    case 603:
      if (lookahead == 'u') ADVANCE(736);
      END_STATE();
    case 604:
      if (lookahead == 'e') ADVANCE(737);
      END_STATE();
    case 605:
      if (lookahead == 'u') ADVANCE(738);
      END_STATE();
    case 606:
      if (lookahead == 'k') ADVANCE(739);
      END_STATE();
    case 607:
      if (lookahead == 'm') ADVANCE(740);
      END_STATE();
    case 608:
      if (lookahead == 'g') ADVANCE(741);
      if (lookahead == 'p') ADVANCE(742);
      END_STATE();
    case 609:
      if (lookahead == 'u') ADVANCE(743);
      END_STATE();
    case 610:
      if (lookahead == 'c') ADVANCE(744);
      END_STATE();
    case 611:
      if (lookahead == 'k') ADVANCE(745);
      END_STATE();
    case 612:
      if (lookahead == 'a') ADVANCE(746);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_expect);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 615:
      if (lookahead == 's') ADVANCE(747);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_extern);
      END_STATE();
    case 617:
      if (lookahead == 'm') ADVANCE(748);
      END_STATE();
    case 618:
      if (lookahead == 'h') ADVANCE(749);
      END_STATE();
    case 619:
      if (lookahead == 'r') ADVANCE(750);
      END_STATE();
    case 620:
      if (lookahead == 'i') ADVANCE(751);
      END_STATE();
    case 621:
      if (lookahead == 'o') ADVANCE(752);
      END_STATE();
    case 622:
      if (lookahead == 't') ADVANCE(753);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_genvar);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_highz0);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_highz1);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_ifnone);
      END_STATE();
    case 628:
      if (lookahead == '_') ADVANCE(754);
      END_STATE();
    case 629:
      if (lookahead == 'l') ADVANCE(755);
      END_STATE();
    case 630:
      if (lookahead == 'e') ADVANCE(756);
      END_STATE();
    case 631:
      if (lookahead == 's') ADVANCE(757);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 633:
      if (lookahead == 'l') ADVANCE(758);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_inside);
      END_STATE();
    case 635:
      if (lookahead == 'r') ADVANCE(759);
      END_STATE();
    case 636:
      if (lookahead == 'o') ADVANCE(760);
      END_STATE();
    case 637:
      if (lookahead == 'a') ADVANCE(761);
      END_STATE();
    case 638:
      if (lookahead == 'e') ADVANCE(762);
      END_STATE();
    case 639:
      if (lookahead == 'n') ADVANCE(763);
      END_STATE();
    case 640:
      if (lookahead == 'o') ADVANCE(764);
      END_STATE();
    case 641:
      if (lookahead == 'a') ADVANCE(765);
      END_STATE();
    case 642:
      if (lookahead == 't') ADVANCE(766);
      END_STATE();
    case 643:
      if (lookahead == 'o') ADVANCE(767);
      END_STATE();
    case 644:
      if (lookahead == 's') ADVANCE(768);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_medium);
      END_STATE();
    case 646:
      if (lookahead == 't') ADVANCE(769);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 648:
      if (lookahead == 'e') ADVANCE(770);
      END_STATE();
    case 649:
      if (lookahead == 'e') ADVANCE(771);
      END_STATE();
    case 650:
      if (lookahead == 'm') ADVANCE(772);
      END_STATE();
    case 651:
      if (lookahead == 'c') ADVANCE(773);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_notif0);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_notif1);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(anon_sym_option);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(anon_sym_output);
      END_STATE();
    case 656:
      if (lookahead == 'e') ADVANCE(774);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(anon_sym_packed);
      END_STATE();
    case 658:
      if (lookahead == 't') ADVANCE(775);
      END_STATE();
    case 659:
      if (lookahead == 'e') ADVANCE(776);
      END_STATE();
    case 660:
      if (lookahead == 'i') ADVANCE(777);
      END_STATE();
    case 661:
      if (lookahead == 't') ADVANCE(778);
      END_STATE();
    case 662:
      if (lookahead == 'm') ADVANCE(779);
      END_STATE();
    case 663:
      if (lookahead == 't') ADVANCE(780);
      END_STATE();
    case 664:
      if (lookahead == 't') ADVANCE(781);
      END_STATE();
    case 665:
      if (lookahead == 'w') ADVANCE(782);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym_pullup);
      END_STATE();
    case 667:
      if (lookahead == 't') ADVANCE(783);
      END_STATE();
    case 668:
      if (lookahead == 's') ADVANCE(784);
      END_STATE();
    case 669:
      if (lookahead == 'i') ADVANCE(785);
      END_STATE();
    case 670:
      if (lookahead == 'm') ADVANCE(786);
      END_STATE();
    case 671:
      if (lookahead == '_') ADVANCE(787);
      END_STATE();
    case 672:
      if (lookahead == 'e') ADVANCE(788);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_repeat);
      END_STATE();
    case 674:
      if (lookahead == 'c') ADVANCE(789);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 676:
      if (lookahead == 'f') ADVANCE(790);
      END_STATE();
    case 677:
      if (lookahead == 'y') ADVANCE(791);
      END_STATE();
    case 678:
      if (lookahead == 't') ADVANCE(792);
      END_STATE();
    case 679:
      if (lookahead == 't') ADVANCE(793);
      END_STATE();
    case 680:
      if (lookahead == 'l') ADVANCE(794);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(anon_sym_sample);
      END_STATE();
    case 682:
      if (lookahead == 'e') ADVANCE(795);
      END_STATE();
    case 683:
      if (lookahead == 'c') ADVANCE(796);
      END_STATE();
    case 684:
      if (lookahead == 'n') ADVANCE(797);
      END_STATE();
    case 685:
      if (lookahead == 'e') ADVANCE(798);
      END_STATE();
    case 686:
      if (lookahead == 'n') ADVANCE(799);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(anon_sym_signed);
      END_STATE();
    case 688:
      if (lookahead == 'y') ADVANCE(800);
      END_STATE();
    case 689:
      if (lookahead == 'r') ADVANCE(801);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(anon_sym_strong);
      if (lookahead == '0') ADVANCE(802);
      if (lookahead == '1') ADVANCE(803);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 694:
      if (lookahead == '0') ADVANCE(804);
      if (lookahead == '1') ADVANCE(805);
      END_STATE();
    case 695:
      if (lookahead == 'c') ADVANCE(806);
      END_STATE();
    case 696:
      if (lookahead == 'e') ADVANCE(807);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(anon_sym_tagged);
      END_STATE();
    case 698:
      if (lookahead == 'h') ADVANCE(808);
      END_STATE();
    case 699:
      if (lookahead == 'e') ADVANCE(809);
      END_STATE();
    case 700:
      if (lookahead == 'i') ADVANCE(810);
      END_STATE();
    case 701:
      if (lookahead == '0') ADVANCE(811);
      if (lookahead == '1') ADVANCE(812);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(anon_sym_triand);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(anon_sym_trireg);
      END_STATE();
    case 704:
      if (lookahead == 'p') ADVANCE(813);
      END_STATE();
    case 705:
      if (lookahead == 'f') ADVANCE(814);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_unique);
      if (lookahead == '0') ADVANCE(815);
      END_STATE();
    case 707:
      if (lookahead == 'e') ADVANCE(816);
      END_STATE();
    case 708:
      if (lookahead == 'w') ADVANCE(817);
      END_STATE();
    case 709:
      if (lookahead == 'd') ADVANCE(818);
      END_STATE();
    case 710:
      if (lookahead == 'e') ADVANCE(819);
      END_STATE();
    case 711:
      if (lookahead == 'l') ADVANCE(820);
      END_STATE();
    case 712:
      if (lookahead == 'r') ADVANCE(821);
      END_STATE();
    case 713:
      if (lookahead == 'r') ADVANCE(822);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(anon_sym_within);
      END_STATE();
    case 715:
      if (lookahead == 'o') ADVANCE(823);
      END_STATE();
    case 716:
      if (lookahead == 'c') ADVANCE(824);
      if (lookahead == 'f') ADVANCE(825);
      if (lookahead == 'l') ADVANCE(826);
      END_STATE();
    case 717:
      if (lookahead == 'i') ADVANCE(827);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(anon_sym_chandle);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(anon_sym_checker);
      END_STATE();
    case 720:
      if (lookahead == 'g') ADVANCE(828);
      END_STATE();
    case 721:
      if (lookahead == 'i') ADVANCE(829);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(anon_sym_context);
      END_STATE();
    case 723:
      if (lookahead == 'e') ADVANCE(830);
      END_STATE();
    case 724:
      if (lookahead == 'o') ADVANCE(831);
      END_STATE();
    case 725:
      if (lookahead == 'i') ADVANCE(832);
      END_STATE();
    case 726:
      if (lookahead == 'n') ADVANCE(833);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 728:
      if (lookahead == 'm') ADVANCE(834);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(anon_sym_disable);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(anon_sym_endcase);
      END_STATE();
    case 731:
      if (lookahead == 'k') ADVANCE(835);
      END_STATE();
    case 732:
      if (lookahead == 's') ADVANCE(836);
      END_STATE();
    case 733:
      if (lookahead == 'k') ADVANCE(837);
      END_STATE();
    case 734:
      if (lookahead == 't') ADVANCE(838);
      END_STATE();
    case 735:
      if (lookahead == 'r') ADVANCE(839);
      END_STATE();
    case 736:
      if (lookahead == 'p') ADVANCE(840);
      END_STATE();
    case 737:
      if (lookahead == 'r') ADVANCE(841);
      END_STATE();
    case 738:
      if (lookahead == 'l') ADVANCE(842);
      END_STATE();
    case 739:
      if (lookahead == 'a') ADVANCE(843);
      END_STATE();
    case 740:
      if (lookahead == 'i') ADVANCE(844);
      END_STATE();
    case 741:
      if (lookahead == 'r') ADVANCE(845);
      END_STATE();
    case 742:
      if (lookahead == 'e') ADVANCE(846);
      END_STATE();
    case 743:
      if (lookahead == 'e') ADVANCE(847);
      END_STATE();
    case 744:
      if (lookahead == 'i') ADVANCE(848);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(anon_sym_endtask);
      END_STATE();
    case 746:
      if (lookahead == 'l') ADVANCE(849);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 748:
      if (lookahead == 'a') ADVANCE(850);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(anon_sym_foreach);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(anon_sym_forever);
      END_STATE();
    case 751:
      if (lookahead == 'n') ADVANCE(851);
      END_STATE();
    case 752:
      if (lookahead == 'n') ADVANCE(852);
      END_STATE();
    case 753:
      if (lookahead == 'e') ADVANCE(853);
      END_STATE();
    case 754:
      if (lookahead == 'b') ADVANCE(854);
      END_STATE();
    case 755:
      if (lookahead == '_') ADVANCE(855);
      END_STATE();
    case 756:
      if (lookahead == 'n') ADVANCE(856);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(anon_sym_implies);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(anon_sym_initial);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(anon_sym_integer);
      END_STATE();
    case 760:
      if (lookahead == 'n') ADVANCE(857);
      END_STATE();
    case 761:
      if (lookahead == 'c') ADVANCE(858);
      END_STATE();
    case 762:
      if (lookahead == 'c') ADVANCE(859);
      END_STATE();
    case 763:
      if (lookahead == 'y') ADVANCE(860);
      END_STATE();
    case 764:
      if (lookahead == 'n') ADVANCE(861);
      END_STATE();
    case 765:
      if (lookahead == 'r') ADVANCE(862);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(anon_sym_longint);
      END_STATE();
    case 767:
      if (lookahead == 'd') ADVANCE(863);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(anon_sym_matches);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(anon_sym_modport);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(anon_sym_negedge);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(anon_sym_nettype);
      END_STATE();
    case 772:
      if (lookahead == 'e') ADVANCE(864);
      END_STATE();
    case 773:
      if (lookahead == 'a') ADVANCE(865);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 775:
      if (lookahead == 'e') ADVANCE(866);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(anon_sym_posedge);
      END_STATE();
    case 777:
      if (lookahead == 'v') ADVANCE(867);
      END_STATE();
    case 778:
      if (lookahead == 'y') ADVANCE(868);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(anon_sym_program);
      END_STATE();
    case 780:
      if (lookahead == 'y') ADVANCE(869);
      END_STATE();
    case 781:
      if (lookahead == 'e') ADVANCE(870);
      END_STATE();
    case 782:
      if (lookahead == 'n') ADVANCE(871);
      END_STATE();
    case 783:
      if (lookahead == 'y') ADVANCE(872);
      END_STATE();
    case 784:
      if (lookahead == 'e') ADVANCE(873);
      END_STATE();
    case 785:
      if (lookahead == 'z') ADVANCE(874);
      END_STATE();
    case 786:
      if (lookahead == 'e') ADVANCE(875);
      END_STATE();
    case 787:
      if (lookahead == 'o') ADVANCE(876);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(anon_sym_release);
      END_STATE();
    case 789:
      if (lookahead == 't') ADVANCE(877);
      END_STATE();
    case 790:
      if (lookahead == '0') ADVANCE(878);
      if (lookahead == '1') ADVANCE(879);
      END_STATE();
    case 791:
      if (lookahead == 's') ADVANCE(880);
      END_STATE();
    case 792:
      if (lookahead == 'u') ADVANCE(881);
      END_STATE();
    case 793:
      if (lookahead == 'i') ADVANCE(882);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(anon_sym_s_until);
      if (lookahead == '_') ADVANCE(883);
      END_STATE();
    case 795:
      if (lookahead == 'd') ADVANCE(884);
      END_STATE();
    case 796:
      if (lookahead == 'e') ADVANCE(885);
      END_STATE();
    case 797:
      if (lookahead == 't') ADVANCE(886);
      END_STATE();
    case 798:
      if (lookahead == 'a') ADVANCE(887);
      END_STATE();
    case 799:
      if (lookahead == 'c') ADVANCE(888);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(anon_sym_specify);
      END_STATE();
    case 801:
      if (lookahead == 'a') ADVANCE(889);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(anon_sym_strong0);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(anon_sym_strong1);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(anon_sym_supply0);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(anon_sym_supply1);
      END_STATE();
    case 806:
      if (lookahead == 'c') ADVANCE(890);
      END_STATE();
    case 807:
      if (lookahead == 'j') ADVANCE(891);
      END_STATE();
    case 808:
      if (lookahead == 'o') ADVANCE(892);
      END_STATE();
    case 809:
      if (lookahead == 'c') ADVANCE(893);
      END_STATE();
    case 810:
      if (lookahead == 't') ADVANCE(894);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(anon_sym_tranif0);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(anon_sym_tranif1);
      END_STATE();
    case 813:
      if (lookahead == 't') ADVANCE(895);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(anon_sym_typedef);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(anon_sym_unique0);
      END_STATE();
    case 816:
      if (lookahead == 'd') ADVANCE(896);
      END_STATE();
    case 817:
      if (lookahead == 'i') ADVANCE(897);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(anon_sym_untyped);
      END_STATE();
    case 819:
      if (lookahead == 'd') ADVANCE(898);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(anon_sym_virtual);
      END_STATE();
    case 821:
      if (lookahead == 'd') ADVANCE(899);
      END_STATE();
    case 822:
      if (lookahead == 'd') ADVANCE(900);
      END_STATE();
    case 823:
      if (lookahead == 'n') ADVANCE(901);
      END_STATE();
    case 824:
      if (lookahead == 'o') ADVANCE(902);
      END_STATE();
    case 825:
      if (lookahead == 'f') ADVANCE(903);
      END_STATE();
    case 826:
      if (lookahead == 'a') ADVANCE(904);
      END_STATE();
    case 827:
      if (lookahead == 'c') ADVANCE(905);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(anon_sym_clocking);
      END_STATE();
    case 829:
      if (lookahead == 'n') ADVANCE(906);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 831:
      if (lookahead == 'u') ADVANCE(907);
      END_STATE();
    case 832:
      if (lookahead == 'n') ADVANCE(908);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(anon_sym_deassign);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(anon_sym_defparam);
      END_STATE();
    case 835:
      if (lookahead == 'e') ADVANCE(909);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(anon_sym_endclass);
      END_STATE();
    case 837:
      if (lookahead == 'i') ADVANCE(910);
      END_STATE();
    case 838:
      if (lookahead == 'i') ADVANCE(911);
      END_STATE();
    case 839:
      if (lookahead == 'a') ADVANCE(912);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(anon_sym_endgroup);
      END_STATE();
    case 841:
      if (lookahead == 'f') ADVANCE(913);
      END_STATE();
    case 842:
      if (lookahead == 'e') ADVANCE(914);
      END_STATE();
    case 843:
      if (lookahead == 'g') ADVANCE(915);
      END_STATE();
    case 844:
      if (lookahead == 't') ADVANCE(916);
      END_STATE();
    case 845:
      if (lookahead == 'a') ADVANCE(917);
      END_STATE();
    case 846:
      if (lookahead == 'r') ADVANCE(918);
      END_STATE();
    case 847:
      if (lookahead == 'n') ADVANCE(919);
      END_STATE();
    case 848:
      if (lookahead == 'f') ADVANCE(920);
      END_STATE();
    case 849:
      if (lookahead == 'l') ADVANCE(921);
      END_STATE();
    case 850:
      if (lookahead == 't') ADVANCE(922);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(anon_sym_forkjoin);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(anon_sym_generate);
      END_STATE();
    case 854:
      if (lookahead == 'i') ADVANCE(923);
      END_STATE();
    case 855:
      if (lookahead == 'b') ADVANCE(924);
      END_STATE();
    case 856:
      if (lookahead == 't') ADVANCE(925);
      END_STATE();
    case 857:
      if (lookahead == 'n') ADVANCE(926);
      END_STATE();
    case 858:
      if (lookahead == 'e') ADVANCE(927);
      END_STATE();
    case 859:
      if (lookahead == 't') ADVANCE(928);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(anon_sym_join_any);
      END_STATE();
    case 861:
      if (lookahead == 'e') ADVANCE(929);
      END_STATE();
    case 862:
      if (lookahead == 'a') ADVANCE(930);
      END_STATE();
    case 863:
      if (lookahead == 'u') ADVANCE(931);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(anon_sym_nexttime);
      END_STATE();
    case 865:
      if (lookahead == 'n') ADVANCE(932);
      END_STATE();
    case 866:
      if (lookahead == 'r') ADVANCE(933);
      END_STATE();
    case 867:
      if (lookahead == 'e') ADVANCE(934);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(anon_sym_priority);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(anon_sym_property);
      END_STATE();
    case 870:
      if (lookahead == 'd') ADVANCE(935);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(anon_sym_pulldown);
      END_STATE();
    case 872:
      if (lookahead == 'l') ADVANCE(936);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(anon_sym_randcase);
      END_STATE();
    case 874:
      if (lookahead == 'e') ADVANCE(937);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(anon_sym_realtime);
      END_STATE();
    case 876:
      if (lookahead == 'n') ADVANCE(938);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(anon_sym_restrict);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(anon_sym_rtranif0);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(anon_sym_rtranif1);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(anon_sym_s_always);
      END_STATE();
    case 881:
      if (lookahead == 'a') ADVANCE(939);
      END_STATE();
    case 882:
      if (lookahead == 'm') ADVANCE(940);
      END_STATE();
    case 883:
      if (lookahead == 'w') ADVANCE(941);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(anon_sym_scalared);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(anon_sym_sequence);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(anon_sym_shortint);
      END_STATE();
    case 887:
      if (lookahead == 'l') ADVANCE(942);
      END_STATE();
    case 888:
      if (lookahead == 'e') ADVANCE(943);
      END_STATE();
    case 889:
      if (lookahead == 'm') ADVANCE(944);
      END_STATE();
    case 890:
      if (lookahead == 'e') ADVANCE(945);
      END_STATE();
    case 891:
      if (lookahead == 'e') ADVANCE(946);
      END_STATE();
    case 892:
      if (lookahead == 'u') ADVANCE(947);
      END_STATE();
    case 893:
      if (lookahead == 'i') ADVANCE(948);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(anon_sym_timeunit);
      END_STATE();
    case 895:
      if (lookahead == 'i') ADVANCE(949);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 897:
      if (lookahead == 't') ADVANCE(950);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(anon_sym_vectored);
      END_STATE();
    case 899:
      if (lookahead == 'e') ADVANCE(951);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(anon_sym_wildcard);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(anon_sym_accept_on);
      END_STATE();
    case 902:
      if (lookahead == 'm') ADVANCE(952);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(anon_sym_always_ff);
      END_STATE();
    case 904:
      if (lookahead == 't') ADVANCE(953);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(anon_sym_automatic);
      END_STATE();
    case 906:
      if (lookahead == 't') ADVANCE(954);
      END_STATE();
    case 907:
      if (lookahead == 'p') ADVANCE(955);
      END_STATE();
    case 908:
      if (lookahead == 't') ADVANCE(956);
      END_STATE();
    case 909:
      if (lookahead == 'r') ADVANCE(957);
      END_STATE();
    case 910:
      if (lookahead == 'n') ADVANCE(958);
      END_STATE();
    case 911:
      if (lookahead == 'o') ADVANCE(959);
      END_STATE();
    case 912:
      if (lookahead == 't') ADVANCE(960);
      END_STATE();
    case 913:
      if (lookahead == 'a') ADVANCE(961);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(anon_sym_endmodule);
      END_STATE();
    case 915:
      if (lookahead == 'e') ADVANCE(962);
      END_STATE();
    case 916:
      if (lookahead == 'i') ADVANCE(963);
      END_STATE();
    case 917:
      if (lookahead == 'm') ADVANCE(964);
      END_STATE();
    case 918:
      if (lookahead == 't') ADVANCE(965);
      END_STATE();
    case 919:
      if (lookahead == 'c') ADVANCE(966);
      END_STATE();
    case 920:
      if (lookahead == 'y') ADVANCE(967);
      END_STATE();
    case 921:
      if (lookahead == 'y') ADVANCE(968);
      END_STATE();
    case 922:
      if (lookahead == 'c') ADVANCE(969);
      END_STATE();
    case 923:
      if (lookahead == 'n') ADVANCE(970);
      END_STATE();
    case 924:
      if (lookahead == 'i') ADVANCE(971);
      END_STATE();
    case 925:
      if (lookahead == 's') ADVANCE(972);
      END_STATE();
    case 926:
      if (lookahead == 'e') ADVANCE(973);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(anon_sym_intersect);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(anon_sym_join_none);
      END_STATE();
    case 930:
      if (lookahead == 'm') ADVANCE(974);
      END_STATE();
    case 931:
      if (lookahead == 'l') ADVANCE(975);
      END_STATE();
    case 932:
      if (lookahead == 'c') ADVANCE(976);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(anon_sym_parameter);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(anon_sym_primitive);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 936:
      if (lookahead == 'e') ADVANCE(977);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(anon_sym_randomize);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(anon_sym_reject_on);
      END_STATE();
    case 939:
      if (lookahead == 'l') ADVANCE(978);
      END_STATE();
    case 940:
      if (lookahead == 'e') ADVANCE(979);
      END_STATE();
    case 941:
      if (lookahead == 'i') ADVANCE(980);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(anon_sym_shortreal);
      END_STATE();
    case 943:
      if (lookahead == 'l') ADVANCE(981);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(anon_sym_specparam);
      END_STATE();
    case 945:
      if (lookahead == 'p') ADVANCE(982);
      END_STATE();
    case 946:
      if (lookahead == 'c') ADVANCE(983);
      END_STATE();
    case 947:
      if (lookahead == 't') ADVANCE(984);
      END_STATE();
    case 948:
      if (lookahead == 's') ADVANCE(985);
      END_STATE();
    case 949:
      if (lookahead == 'o') ADVANCE(986);
      END_STATE();
    case 950:
      if (lookahead == 'h') ADVANCE(987);
      END_STATE();
    case 951:
      if (lookahead == 'r') ADVANCE(988);
      END_STATE();
    case 952:
      if (lookahead == 'b') ADVANCE(989);
      END_STATE();
    case 953:
      if (lookahead == 'c') ADVANCE(990);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(anon_sym_constraint);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(anon_sym_covergroup);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(anon_sym_coverpoint);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(anon_sym_endchecker);
      END_STATE();
    case 958:
      if (lookahead == 'g') ADVANCE(991);
      END_STATE();
    case 959:
      if (lookahead == 'n') ADVANCE(992);
      END_STATE();
    case 960:
      if (lookahead == 'e') ADVANCE(993);
      END_STATE();
    case 961:
      if (lookahead == 'c') ADVANCE(994);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(anon_sym_endpackage);
      END_STATE();
    case 963:
      if (lookahead == 'v') ADVANCE(995);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(anon_sym_endprogram);
      END_STATE();
    case 965:
      if (lookahead == 'y') ADVANCE(996);
      END_STATE();
    case 966:
      if (lookahead == 'e') ADVANCE(997);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(anon_sym_endspecify);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(anon_sym_eventually);
      END_STATE();
    case 969:
      if (lookahead == 'h') ADVANCE(998);
      END_STATE();
    case 970:
      if (lookahead == 's') ADVANCE(999);
      END_STATE();
    case 971:
      if (lookahead == 'n') ADVANCE(1000);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 973:
      if (lookahead == 'c') ADVANCE(1001);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(anon_sym_localparam);
      END_STATE();
    case 975:
      if (lookahead == 'e') ADVANCE(1002);
      END_STATE();
    case 976:
      if (lookahead == 'e') ADVANCE(1003);
      END_STATE();
    case 977:
      if (lookahead == '_') ADVANCE(1004);
      END_STATE();
    case 978:
      if (lookahead == 'l') ADVANCE(1005);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(anon_sym_s_nexttime);
      END_STATE();
    case 980:
      if (lookahead == 't') ADVANCE(1006);
      END_STATE();
    case 981:
      if (lookahead == 'l') ADVANCE(1007);
      END_STATE();
    case 982:
      if (lookahead == 't') ADVANCE(1008);
      END_STATE();
    case 983:
      if (lookahead == 't') ADVANCE(1009);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(anon_sym_throughout);
      END_STATE();
    case 985:
      if (lookahead == 'i') ADVANCE(1010);
      END_STATE();
    case 986:
      if (lookahead == 'n') ADVANCE(1011);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(anon_sym_until_with);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(anon_sym_wait_order);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(anon_sym_always_comb);
      END_STATE();
    case 990:
      if (lookahead == 'h') ADVANCE(1012);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(anon_sym_endclocking);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(anon_sym_endgenerate);
      END_STATE();
    case 994:
      if (lookahead == 'e') ADVANCE(1013);
      END_STATE();
    case 995:
      if (lookahead == 'e') ADVANCE(1014);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(anon_sym_endproperty);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(anon_sym_endsequence);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(anon_sym_first_match);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(anon_sym_ignore_bins);
      END_STATE();
    case 1000:
      if (lookahead == 's') ADVANCE(1015);
      END_STATE();
    case 1001:
      if (lookahead == 't') ADVANCE(1016);
      END_STATE();
    case 1002:
      ACCEPT_TOKEN(anon_sym_macromodule);
      END_STATE();
    case 1003:
      if (lookahead == 'l') ADVANCE(1017);
      END_STATE();
    case 1004:
      if (lookahead == 'o') ADVANCE(1018);
      END_STATE();
    case 1005:
      if (lookahead == 'y') ADVANCE(1019);
      END_STATE();
    case 1006:
      if (lookahead == 'h') ADVANCE(1020);
      END_STATE();
    case 1007:
      if (lookahead == 'e') ADVANCE(1021);
      END_STATE();
    case 1008:
      if (lookahead == '_') ADVANCE(1022);
      END_STATE();
    case 1009:
      if (lookahead == '_') ADVANCE(1023);
      END_STATE();
    case 1010:
      if (lookahead == 'o') ADVANCE(1024);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(anon_sym_type_option);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(anon_sym_always_latch);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(anon_sym_endinterface);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(anon_sym_endprimitive);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(anon_sym_illegal_bins);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(anon_sym_interconnect);
      END_STATE();
    case 1017:
      if (lookahead == 'l') ADVANCE(1025);
      END_STATE();
    case 1018:
      if (lookahead == 'n') ADVANCE(1026);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(anon_sym_s_eventually);
      END_STATE();
    case 1020:
      ACCEPT_TOKEN(anon_sym_s_until_with);
      END_STATE();
    case 1021:
      if (lookahead == 'd') ADVANCE(1027);
      END_STATE();
    case 1022:
      if (lookahead == 'o') ADVANCE(1028);
      END_STATE();
    case 1023:
      if (lookahead == 'o') ADVANCE(1029);
      END_STATE();
    case 1024:
      if (lookahead == 'n') ADVANCE(1030);
      END_STATE();
    case 1025:
      if (lookahead == 'e') ADVANCE(1031);
      END_STATE();
    case 1026:
      if (lookahead == 'd') ADVANCE(1032);
      if (lookahead == 'e') ADVANCE(1033);
      END_STATE();
    case 1027:
      ACCEPT_TOKEN(anon_sym_showcancelled);
      END_STATE();
    case 1028:
      if (lookahead == 'n') ADVANCE(1034);
      END_STATE();
    case 1029:
      if (lookahead == 'n') ADVANCE(1035);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(anon_sym_timeprecision);
      END_STATE();
    case 1031:
      if (lookahead == 'd') ADVANCE(1036);
      END_STATE();
    case 1032:
      if (lookahead == 'e') ADVANCE(1037);
      END_STATE();
    case 1033:
      if (lookahead == 'v') ADVANCE(1038);
      END_STATE();
    case 1034:
      ACCEPT_TOKEN(anon_sym_sync_accept_on);
      END_STATE();
    case 1035:
      ACCEPT_TOKEN(anon_sym_sync_reject_on);
      END_STATE();
    case 1036:
      ACCEPT_TOKEN(anon_sym_noshowcancelled);
      END_STATE();
    case 1037:
      if (lookahead == 't') ADVANCE(1039);
      END_STATE();
    case 1038:
      if (lookahead == 'e') ADVANCE(1040);
      END_STATE();
    case 1039:
      if (lookahead == 'e') ADVANCE(1041);
      END_STATE();
    case 1040:
      if (lookahead == 'n') ADVANCE(1042);
      END_STATE();
    case 1041:
      if (lookahead == 'c') ADVANCE(1043);
      END_STATE();
    case 1042:
      if (lookahead == 't') ADVANCE(1044);
      END_STATE();
    case 1043:
      if (lookahead == 't') ADVANCE(1045);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(anon_sym_pulsestyle_onevent);
      END_STATE();
    case 1045:
      ACCEPT_TOKEN(anon_sym_pulsestyle_ondetect);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 371},
  [2] = {.lex_state = 371},
  [3] = {.lex_state = 371},
  [4] = {.lex_state = 371},
  [5] = {.lex_state = 371},
  [6] = {.lex_state = 371},
  [7] = {.lex_state = 371},
  [8] = {.lex_state = 371},
  [9] = {.lex_state = 371},
  [10] = {.lex_state = 371},
  [11] = {.lex_state = 371},
  [12] = {.lex_state = 371},
  [13] = {.lex_state = 371},
  [14] = {.lex_state = 371},
  [15] = {.lex_state = 371},
  [16] = {.lex_state = 371},
  [17] = {.lex_state = 371},
  [18] = {.lex_state = 371},
  [19] = {.lex_state = 371},
  [20] = {.lex_state = 371},
  [21] = {.lex_state = 371},
  [22] = {.lex_state = 371},
  [23] = {.lex_state = 371},
  [24] = {.lex_state = 371},
  [25] = {.lex_state = 371},
  [26] = {.lex_state = 371},
  [27] = {.lex_state = 371},
  [28] = {.lex_state = 371},
  [29] = {.lex_state = 371},
  [30] = {.lex_state = 371},
  [31] = {.lex_state = 371},
  [32] = {.lex_state = 371},
  [33] = {.lex_state = 371},
  [34] = {.lex_state = 371},
  [35] = {.lex_state = 371},
  [36] = {.lex_state = 371},
  [37] = {.lex_state = 371},
  [38] = {.lex_state = 371},
  [39] = {.lex_state = 371},
  [40] = {.lex_state = 371},
  [41] = {.lex_state = 371},
  [42] = {.lex_state = 371},
  [43] = {.lex_state = 371},
  [44] = {.lex_state = 371},
  [45] = {.lex_state = 371},
  [46] = {.lex_state = 371},
  [47] = {.lex_state = 371},
  [48] = {.lex_state = 371},
  [49] = {.lex_state = 371},
  [50] = {.lex_state = 371},
  [51] = {.lex_state = 371},
  [52] = {.lex_state = 371},
  [53] = {.lex_state = 371},
  [54] = {.lex_state = 371},
  [55] = {.lex_state = 371},
  [56] = {.lex_state = 371},
  [57] = {.lex_state = 371},
  [58] = {.lex_state = 371},
  [59] = {.lex_state = 371},
  [60] = {.lex_state = 371},
  [61] = {.lex_state = 371},
  [62] = {.lex_state = 371},
  [63] = {.lex_state = 371},
  [64] = {.lex_state = 371},
  [65] = {.lex_state = 371},
  [66] = {.lex_state = 371},
  [67] = {.lex_state = 371},
  [68] = {.lex_state = 371},
  [69] = {.lex_state = 371},
  [70] = {.lex_state = 371},
  [71] = {.lex_state = 371},
  [72] = {.lex_state = 371},
  [73] = {.lex_state = 371},
  [74] = {.lex_state = 371},
  [75] = {.lex_state = 371},
  [76] = {.lex_state = 371},
  [77] = {.lex_state = 371},
  [78] = {.lex_state = 371},
  [79] = {.lex_state = 371},
  [80] = {.lex_state = 371},
  [81] = {.lex_state = 371},
  [82] = {.lex_state = 371},
  [83] = {.lex_state = 371},
  [84] = {.lex_state = 371},
  [85] = {.lex_state = 371},
  [86] = {.lex_state = 371},
  [87] = {.lex_state = 371},
  [88] = {.lex_state = 371},
  [89] = {.lex_state = 371},
  [90] = {.lex_state = 371},
  [91] = {.lex_state = 371},
  [92] = {.lex_state = 371},
  [93] = {.lex_state = 371},
  [94] = {.lex_state = 371},
  [95] = {.lex_state = 371},
  [96] = {.lex_state = 371},
  [97] = {.lex_state = 371},
  [98] = {.lex_state = 371},
  [99] = {.lex_state = 371},
  [100] = {.lex_state = 371},
  [101] = {.lex_state = 371},
  [102] = {.lex_state = 373},
  [103] = {.lex_state = 373},
  [104] = {.lex_state = 371},
  [105] = {.lex_state = 371},
  [106] = {.lex_state = 371},
  [107] = {.lex_state = 371},
  [108] = {.lex_state = 371},
  [109] = {.lex_state = 371},
  [110] = {.lex_state = 371},
  [111] = {.lex_state = 371},
  [112] = {.lex_state = 371},
  [113] = {.lex_state = 371},
  [114] = {.lex_state = 371},
  [115] = {.lex_state = 371},
  [116] = {.lex_state = 371},
  [117] = {.lex_state = 372},
  [118] = {.lex_state = 50},
  [119] = {.lex_state = 50},
  [120] = {.lex_state = 50},
  [121] = {.lex_state = 50},
  [122] = {.lex_state = 50},
  [123] = {.lex_state = 50},
  [124] = {.lex_state = 50},
  [125] = {.lex_state = 50},
  [126] = {.lex_state = 50},
  [127] = {.lex_state = 50},
  [128] = {.lex_state = 50},
  [129] = {.lex_state = 50},
  [130] = {.lex_state = 50},
  [131] = {.lex_state = 50},
  [132] = {.lex_state = 50},
  [133] = {.lex_state = 50},
  [134] = {.lex_state = 50},
  [135] = {.lex_state = 50},
  [136] = {.lex_state = 50},
  [137] = {.lex_state = 50},
  [138] = {.lex_state = 50},
  [139] = {.lex_state = 50},
  [140] = {.lex_state = 50},
  [141] = {.lex_state = 50},
  [142] = {.lex_state = 50},
  [143] = {.lex_state = 50},
  [144] = {.lex_state = 50},
  [145] = {.lex_state = 50},
  [146] = {.lex_state = 50},
  [147] = {.lex_state = 50},
  [148] = {.lex_state = 50},
  [149] = {.lex_state = 50},
  [150] = {.lex_state = 50},
  [151] = {.lex_state = 50},
  [152] = {.lex_state = 50},
  [153] = {.lex_state = 50},
  [154] = {.lex_state = 50},
  [155] = {.lex_state = 50},
  [156] = {.lex_state = 50},
  [157] = {.lex_state = 50},
  [158] = {.lex_state = 50},
  [159] = {.lex_state = 50},
  [160] = {.lex_state = 50},
  [161] = {.lex_state = 50},
  [162] = {.lex_state = 50},
  [163] = {.lex_state = 50},
  [164] = {.lex_state = 50},
  [165] = {.lex_state = 50},
  [166] = {.lex_state = 50},
  [167] = {.lex_state = 50},
  [168] = {.lex_state = 50},
  [169] = {.lex_state = 50},
  [170] = {.lex_state = 50},
  [171] = {.lex_state = 50},
  [172] = {.lex_state = 50},
  [173] = {.lex_state = 50},
  [174] = {.lex_state = 50},
  [175] = {.lex_state = 50},
  [176] = {.lex_state = 50},
  [177] = {.lex_state = 50},
  [178] = {.lex_state = 50},
  [179] = {.lex_state = 50},
  [180] = {.lex_state = 50},
  [181] = {.lex_state = 50},
  [182] = {.lex_state = 50},
  [183] = {.lex_state = 50},
  [184] = {.lex_state = 50},
  [185] = {.lex_state = 50},
  [186] = {.lex_state = 50},
  [187] = {.lex_state = 50},
  [188] = {.lex_state = 50},
  [189] = {.lex_state = 50},
  [190] = {.lex_state = 50},
  [191] = {.lex_state = 50},
  [192] = {.lex_state = 50},
  [193] = {.lex_state = 50},
  [194] = {.lex_state = 50},
  [195] = {.lex_state = 371},
  [196] = {.lex_state = 50},
  [197] = {.lex_state = 50},
  [198] = {.lex_state = 50},
  [199] = {.lex_state = 371},
  [200] = {.lex_state = 371},
  [201] = {.lex_state = 50},
  [202] = {.lex_state = 50},
  [203] = {.lex_state = 50},
  [204] = {.lex_state = 50},
  [205] = {.lex_state = 50},
  [206] = {.lex_state = 50},
  [207] = {.lex_state = 50},
  [208] = {.lex_state = 50},
  [209] = {.lex_state = 50},
  [210] = {.lex_state = 50},
  [211] = {.lex_state = 50},
  [212] = {.lex_state = 50},
  [213] = {.lex_state = 50},
  [214] = {.lex_state = 50},
  [215] = {.lex_state = 50},
  [216] = {.lex_state = 371},
  [217] = {.lex_state = 371},
  [218] = {.lex_state = 50},
  [219] = {.lex_state = 50},
  [220] = {.lex_state = 50},
  [221] = {.lex_state = 50},
  [222] = {.lex_state = 50},
  [223] = {.lex_state = 50},
  [224] = {.lex_state = 50},
  [225] = {.lex_state = 50},
  [226] = {.lex_state = 50},
  [227] = {.lex_state = 50},
  [228] = {.lex_state = 50},
  [229] = {.lex_state = 50},
  [230] = {.lex_state = 50},
  [231] = {.lex_state = 50},
  [232] = {.lex_state = 50},
  [233] = {.lex_state = 50},
  [234] = {.lex_state = 50},
  [235] = {.lex_state = 50},
  [236] = {.lex_state = 50},
  [237] = {.lex_state = 50},
  [238] = {.lex_state = 50},
  [239] = {.lex_state = 50},
  [240] = {.lex_state = 50},
  [241] = {.lex_state = 50},
  [242] = {.lex_state = 50},
  [243] = {.lex_state = 50},
  [244] = {.lex_state = 50},
  [245] = {.lex_state = 50},
  [246] = {.lex_state = 50},
  [247] = {.lex_state = 50},
  [248] = {.lex_state = 50},
  [249] = {.lex_state = 50},
  [250] = {.lex_state = 50},
  [251] = {.lex_state = 50},
  [252] = {.lex_state = 50},
  [253] = {.lex_state = 50},
  [254] = {.lex_state = 50},
  [255] = {.lex_state = 50},
  [256] = {.lex_state = 50},
  [257] = {.lex_state = 50},
  [258] = {.lex_state = 50},
  [259] = {.lex_state = 50},
  [260] = {.lex_state = 50},
  [261] = {.lex_state = 50},
  [262] = {.lex_state = 50},
  [263] = {.lex_state = 50},
  [264] = {.lex_state = 50},
  [265] = {.lex_state = 50},
  [266] = {.lex_state = 50},
  [267] = {.lex_state = 7},
  [268] = {.lex_state = 50},
  [269] = {.lex_state = 50},
  [270] = {.lex_state = 50},
  [271] = {.lex_state = 50},
  [272] = {.lex_state = 50},
  [273] = {.lex_state = 50},
  [274] = {.lex_state = 50},
  [275] = {.lex_state = 50},
  [276] = {.lex_state = 50},
  [277] = {.lex_state = 50},
  [278] = {.lex_state = 50},
  [279] = {.lex_state = 50},
  [280] = {.lex_state = 50},
  [281] = {.lex_state = 50},
  [282] = {.lex_state = 50},
  [283] = {.lex_state = 50},
  [284] = {.lex_state = 50},
  [285] = {.lex_state = 50},
  [286] = {.lex_state = 50},
  [287] = {.lex_state = 50},
  [288] = {.lex_state = 50},
  [289] = {.lex_state = 50},
  [290] = {.lex_state = 50},
  [291] = {.lex_state = 50},
  [292] = {.lex_state = 50},
  [293] = {.lex_state = 50},
  [294] = {.lex_state = 50},
  [295] = {.lex_state = 50},
  [296] = {.lex_state = 50},
  [297] = {.lex_state = 50},
  [298] = {.lex_state = 50},
  [299] = {.lex_state = 50},
  [300] = {.lex_state = 50},
  [301] = {.lex_state = 50},
  [302] = {.lex_state = 50},
  [303] = {.lex_state = 50},
  [304] = {.lex_state = 50},
  [305] = {.lex_state = 50},
  [306] = {.lex_state = 50},
  [307] = {.lex_state = 50},
  [308] = {.lex_state = 50},
  [309] = {.lex_state = 50},
  [310] = {.lex_state = 50},
  [311] = {.lex_state = 50},
  [312] = {.lex_state = 50},
  [313] = {.lex_state = 50},
  [314] = {.lex_state = 50},
  [315] = {.lex_state = 50},
  [316] = {.lex_state = 50},
  [317] = {.lex_state = 50},
  [318] = {.lex_state = 50},
  [319] = {.lex_state = 50},
  [320] = {.lex_state = 50},
  [321] = {.lex_state = 50},
  [322] = {.lex_state = 50},
  [323] = {.lex_state = 50},
  [324] = {.lex_state = 50},
  [325] = {.lex_state = 50},
  [326] = {.lex_state = 50},
  [327] = {.lex_state = 50},
  [328] = {.lex_state = 50},
  [329] = {.lex_state = 50},
  [330] = {.lex_state = 50},
  [331] = {.lex_state = 50},
  [332] = {.lex_state = 50},
  [333] = {.lex_state = 50},
  [334] = {.lex_state = 50},
  [335] = {.lex_state = 50},
  [336] = {.lex_state = 50},
  [337] = {.lex_state = 50},
  [338] = {.lex_state = 50},
  [339] = {.lex_state = 50},
  [340] = {.lex_state = 50},
  [341] = {.lex_state = 50},
  [342] = {.lex_state = 50},
  [343] = {.lex_state = 50},
  [344] = {.lex_state = 50},
  [345] = {.lex_state = 50},
  [346] = {.lex_state = 50},
  [347] = {.lex_state = 50},
  [348] = {.lex_state = 50},
  [349] = {.lex_state = 50},
  [350] = {.lex_state = 50},
  [351] = {.lex_state = 50},
  [352] = {.lex_state = 50},
  [353] = {.lex_state = 50},
  [354] = {.lex_state = 50},
  [355] = {.lex_state = 50},
  [356] = {.lex_state = 50},
  [357] = {.lex_state = 50},
  [358] = {.lex_state = 50},
  [359] = {.lex_state = 50},
  [360] = {.lex_state = 50},
  [361] = {.lex_state = 50},
  [362] = {.lex_state = 50},
  [363] = {.lex_state = 50},
  [364] = {.lex_state = 50},
  [365] = {.lex_state = 50},
  [366] = {.lex_state = 50},
  [367] = {.lex_state = 50},
  [368] = {.lex_state = 50},
  [369] = {.lex_state = 50},
  [370] = {.lex_state = 50},
  [371] = {.lex_state = 50},
  [372] = {.lex_state = 50},
  [373] = {.lex_state = 50},
  [374] = {.lex_state = 50},
  [375] = {.lex_state = 50},
  [376] = {.lex_state = 50},
  [377] = {.lex_state = 50},
  [378] = {.lex_state = 50},
  [379] = {.lex_state = 50},
  [380] = {.lex_state = 50},
  [381] = {.lex_state = 50},
  [382] = {.lex_state = 50},
  [383] = {.lex_state = 50},
  [384] = {.lex_state = 50},
  [385] = {.lex_state = 50},
  [386] = {.lex_state = 50},
  [387] = {.lex_state = 50},
  [388] = {.lex_state = 50},
  [389] = {.lex_state = 50},
  [390] = {.lex_state = 50},
  [391] = {.lex_state = 50},
  [392] = {.lex_state = 50},
  [393] = {.lex_state = 50},
  [394] = {.lex_state = 50},
  [395] = {.lex_state = 50},
  [396] = {.lex_state = 50},
  [397] = {.lex_state = 50},
  [398] = {.lex_state = 50},
  [399] = {.lex_state = 50},
  [400] = {.lex_state = 50},
  [401] = {.lex_state = 50},
  [402] = {.lex_state = 50},
  [403] = {.lex_state = 50},
  [404] = {.lex_state = 50},
  [405] = {.lex_state = 50},
  [406] = {.lex_state = 50},
  [407] = {.lex_state = 50},
  [408] = {.lex_state = 50},
  [409] = {.lex_state = 50},
  [410] = {.lex_state = 50},
  [411] = {.lex_state = 50},
  [412] = {.lex_state = 50},
  [413] = {.lex_state = 50},
  [414] = {.lex_state = 50},
  [415] = {.lex_state = 50},
  [416] = {.lex_state = 50},
  [417] = {.lex_state = 50},
  [418] = {.lex_state = 50},
  [419] = {.lex_state = 50},
  [420] = {.lex_state = 50},
  [421] = {.lex_state = 50},
  [422] = {.lex_state = 50},
  [423] = {.lex_state = 50},
  [424] = {.lex_state = 50},
  [425] = {.lex_state = 50},
  [426] = {.lex_state = 50},
  [427] = {.lex_state = 50},
  [428] = {.lex_state = 50},
  [429] = {.lex_state = 50},
  [430] = {.lex_state = 50},
  [431] = {.lex_state = 50},
  [432] = {.lex_state = 50},
  [433] = {.lex_state = 50},
  [434] = {.lex_state = 50},
  [435] = {.lex_state = 50},
  [436] = {.lex_state = 50},
  [437] = {.lex_state = 50},
  [438] = {.lex_state = 50},
  [439] = {.lex_state = 50},
  [440] = {.lex_state = 50},
  [441] = {.lex_state = 50},
  [442] = {.lex_state = 50},
  [443] = {.lex_state = 50},
  [444] = {.lex_state = 50},
  [445] = {.lex_state = 50},
  [446] = {.lex_state = 50},
  [447] = {.lex_state = 50},
  [448] = {.lex_state = 50},
  [449] = {.lex_state = 50},
  [450] = {.lex_state = 50},
  [451] = {.lex_state = 50},
  [452] = {.lex_state = 50},
  [453] = {.lex_state = 50},
  [454] = {.lex_state = 50},
  [455] = {.lex_state = 50},
  [456] = {.lex_state = 50},
  [457] = {.lex_state = 50},
  [458] = {.lex_state = 50},
  [459] = {.lex_state = 50},
  [460] = {.lex_state = 50},
  [461] = {.lex_state = 50},
  [462] = {.lex_state = 50},
  [463] = {.lex_state = 50},
  [464] = {.lex_state = 50},
  [465] = {.lex_state = 50},
  [466] = {.lex_state = 50},
  [467] = {.lex_state = 50},
  [468] = {.lex_state = 50},
  [469] = {.lex_state = 50},
  [470] = {.lex_state = 50},
  [471] = {.lex_state = 50},
  [472] = {.lex_state = 50},
  [473] = {.lex_state = 50},
  [474] = {.lex_state = 50},
  [475] = {.lex_state = 50},
  [476] = {.lex_state = 50},
  [477] = {.lex_state = 50},
  [478] = {.lex_state = 50},
  [479] = {.lex_state = 50},
  [480] = {.lex_state = 50},
  [481] = {.lex_state = 50},
  [482] = {.lex_state = 50},
  [483] = {.lex_state = 50},
  [484] = {.lex_state = 50},
  [485] = {.lex_state = 50},
  [486] = {.lex_state = 50},
  [487] = {.lex_state = 50},
  [488] = {.lex_state = 50},
  [489] = {.lex_state = 50},
  [490] = {.lex_state = 50},
  [491] = {.lex_state = 50},
  [492] = {.lex_state = 50},
  [493] = {.lex_state = 50},
  [494] = {.lex_state = 50},
  [495] = {.lex_state = 50},
  [496] = {.lex_state = 50},
  [497] = {.lex_state = 50},
  [498] = {.lex_state = 50},
  [499] = {.lex_state = 50},
  [500] = {.lex_state = 50},
  [501] = {.lex_state = 50},
  [502] = {.lex_state = 50},
  [503] = {.lex_state = 50},
  [504] = {.lex_state = 50},
  [505] = {.lex_state = 371},
  [506] = {.lex_state = 50},
  [507] = {.lex_state = 50},
  [508] = {.lex_state = 50},
  [509] = {.lex_state = 50},
  [510] = {.lex_state = 50},
  [511] = {.lex_state = 50},
  [512] = {.lex_state = 50},
  [513] = {.lex_state = 50},
  [514] = {.lex_state = 50},
  [515] = {.lex_state = 50},
  [516] = {.lex_state = 50},
  [517] = {.lex_state = 50},
  [518] = {.lex_state = 50},
  [519] = {.lex_state = 50},
  [520] = {.lex_state = 50},
  [521] = {.lex_state = 50},
  [522] = {.lex_state = 50},
  [523] = {.lex_state = 50},
  [524] = {.lex_state = 50},
  [525] = {.lex_state = 50},
  [526] = {.lex_state = 50},
  [527] = {.lex_state = 50},
  [528] = {.lex_state = 50},
  [529] = {.lex_state = 50},
  [530] = {.lex_state = 50},
  [531] = {.lex_state = 50},
  [532] = {.lex_state = 50},
  [533] = {.lex_state = 50},
  [534] = {.lex_state = 50},
  [535] = {.lex_state = 50},
  [536] = {.lex_state = 50},
  [537] = {.lex_state = 50},
  [538] = {.lex_state = 50},
  [539] = {.lex_state = 50},
  [540] = {.lex_state = 50},
  [541] = {.lex_state = 50},
  [542] = {.lex_state = 50},
  [543] = {.lex_state = 50},
  [544] = {.lex_state = 50},
  [545] = {.lex_state = 50},
  [546] = {.lex_state = 50},
  [547] = {.lex_state = 50},
  [548] = {.lex_state = 371},
  [549] = {.lex_state = 371},
  [550] = {.lex_state = 42},
  [551] = {.lex_state = 42},
  [552] = {.lex_state = 42},
  [553] = {.lex_state = 42},
  [554] = {.lex_state = 42},
  [555] = {.lex_state = 8},
  [556] = {.lex_state = 371},
  [557] = {.lex_state = 371},
  [558] = {.lex_state = 371},
  [559] = {.lex_state = 371},
  [560] = {.lex_state = 371},
  [561] = {.lex_state = 371},
  [562] = {.lex_state = 371},
  [563] = {.lex_state = 371},
  [564] = {.lex_state = 371},
  [565] = {.lex_state = 371},
  [566] = {.lex_state = 371},
  [567] = {.lex_state = 371},
  [568] = {.lex_state = 371},
  [569] = {.lex_state = 371},
  [570] = {.lex_state = 42},
  [571] = {.lex_state = 25},
  [572] = {.lex_state = 25},
  [573] = {.lex_state = 42},
  [574] = {.lex_state = 42},
  [575] = {.lex_state = 42},
  [576] = {.lex_state = 42},
  [577] = {.lex_state = 42},
  [578] = {.lex_state = 42},
  [579] = {.lex_state = 42},
  [580] = {.lex_state = 42},
  [581] = {.lex_state = 42},
  [582] = {.lex_state = 42},
  [583] = {.lex_state = 42},
  [584] = {.lex_state = 42},
  [585] = {.lex_state = 42},
  [586] = {.lex_state = 42},
  [587] = {.lex_state = 42},
  [588] = {.lex_state = 42},
  [589] = {.lex_state = 42},
  [590] = {.lex_state = 42},
  [591] = {.lex_state = 42},
  [592] = {.lex_state = 42},
  [593] = {.lex_state = 42},
  [594] = {.lex_state = 42},
  [595] = {.lex_state = 42},
  [596] = {.lex_state = 42},
  [597] = {.lex_state = 42},
  [598] = {.lex_state = 42},
  [599] = {.lex_state = 42},
  [600] = {.lex_state = 42},
  [601] = {.lex_state = 42},
  [602] = {.lex_state = 42},
  [603] = {.lex_state = 42},
  [604] = {.lex_state = 42},
  [605] = {.lex_state = 42},
  [606] = {.lex_state = 42},
  [607] = {.lex_state = 42},
  [608] = {.lex_state = 42},
  [609] = {.lex_state = 42},
  [610] = {.lex_state = 41},
  [611] = {.lex_state = 41},
  [612] = {.lex_state = 41},
  [613] = {.lex_state = 41},
  [614] = {.lex_state = 41},
  [615] = {.lex_state = 41},
  [616] = {.lex_state = 41},
  [617] = {.lex_state = 41},
  [618] = {.lex_state = 41},
  [619] = {.lex_state = 41},
  [620] = {.lex_state = 41},
  [621] = {.lex_state = 41},
  [622] = {.lex_state = 41},
  [623] = {.lex_state = 41},
  [624] = {.lex_state = 41},
  [625] = {.lex_state = 41},
  [626] = {.lex_state = 41},
  [627] = {.lex_state = 41},
  [628] = {.lex_state = 41},
  [629] = {.lex_state = 41},
  [630] = {.lex_state = 41},
  [631] = {.lex_state = 41},
  [632] = {.lex_state = 41},
  [633] = {.lex_state = 41},
  [634] = {.lex_state = 41},
  [635] = {.lex_state = 41},
  [636] = {.lex_state = 41},
  [637] = {.lex_state = 41},
  [638] = {.lex_state = 41},
  [639] = {.lex_state = 41},
  [640] = {.lex_state = 42},
  [641] = {.lex_state = 42},
  [642] = {.lex_state = 371},
  [643] = {.lex_state = 371},
  [644] = {.lex_state = 371},
  [645] = {.lex_state = 371},
  [646] = {.lex_state = 371},
  [647] = {.lex_state = 8},
  [648] = {.lex_state = 371},
  [649] = {.lex_state = 371},
  [650] = {.lex_state = 371},
  [651] = {.lex_state = 371},
  [652] = {.lex_state = 371},
  [653] = {.lex_state = 371},
  [654] = {.lex_state = 371},
  [655] = {.lex_state = 371},
  [656] = {.lex_state = 23},
  [657] = {.lex_state = 371},
  [658] = {.lex_state = 371},
  [659] = {.lex_state = 371},
  [660] = {.lex_state = 371},
  [661] = {.lex_state = 371},
  [662] = {.lex_state = 371},
  [663] = {.lex_state = 371},
  [664] = {.lex_state = 371},
  [665] = {.lex_state = 371},
  [666] = {.lex_state = 371},
  [667] = {.lex_state = 371},
  [668] = {.lex_state = 371},
  [669] = {.lex_state = 371},
  [670] = {.lex_state = 371},
  [671] = {.lex_state = 371},
  [672] = {.lex_state = 371},
  [673] = {.lex_state = 371},
  [674] = {.lex_state = 371},
  [675] = {.lex_state = 371},
  [676] = {.lex_state = 23},
  [677] = {.lex_state = 371},
  [678] = {.lex_state = 371},
  [679] = {.lex_state = 371},
  [680] = {.lex_state = 371},
  [681] = {.lex_state = 371},
  [682] = {.lex_state = 371},
  [683] = {.lex_state = 371},
  [684] = {.lex_state = 371},
  [685] = {.lex_state = 371},
  [686] = {.lex_state = 371},
  [687] = {.lex_state = 371},
  [688] = {.lex_state = 371},
  [689] = {.lex_state = 371},
  [690] = {.lex_state = 371},
  [691] = {.lex_state = 371},
  [692] = {.lex_state = 371},
  [693] = {.lex_state = 371},
  [694] = {.lex_state = 371},
  [695] = {.lex_state = 371},
  [696] = {.lex_state = 371},
  [697] = {.lex_state = 371},
  [698] = {.lex_state = 371},
  [699] = {.lex_state = 371},
  [700] = {.lex_state = 371},
  [701] = {.lex_state = 371},
  [702] = {.lex_state = 371},
  [703] = {.lex_state = 371},
  [704] = {.lex_state = 371},
  [705] = {.lex_state = 371},
  [706] = {.lex_state = 371},
  [707] = {.lex_state = 371},
  [708] = {.lex_state = 371},
  [709] = {.lex_state = 371},
  [710] = {.lex_state = 371},
  [711] = {.lex_state = 371},
  [712] = {.lex_state = 371},
  [713] = {.lex_state = 371},
  [714] = {.lex_state = 371},
  [715] = {.lex_state = 371},
  [716] = {.lex_state = 371},
  [717] = {.lex_state = 371},
  [718] = {.lex_state = 371},
  [719] = {.lex_state = 371},
  [720] = {.lex_state = 371},
  [721] = {.lex_state = 371},
  [722] = {.lex_state = 371},
  [723] = {.lex_state = 371},
  [724] = {.lex_state = 371},
  [725] = {.lex_state = 371},
  [726] = {.lex_state = 371},
  [727] = {.lex_state = 371},
  [728] = {.lex_state = 371},
  [729] = {.lex_state = 371},
  [730] = {.lex_state = 371},
  [731] = {.lex_state = 371},
  [732] = {.lex_state = 371},
  [733] = {.lex_state = 371},
  [734] = {.lex_state = 371},
  [735] = {.lex_state = 371},
  [736] = {.lex_state = 371},
  [737] = {.lex_state = 371},
  [738] = {.lex_state = 371},
  [739] = {.lex_state = 371},
  [740] = {.lex_state = 371},
  [741] = {.lex_state = 371},
  [742] = {.lex_state = 371},
  [743] = {.lex_state = 371},
  [744] = {.lex_state = 371},
  [745] = {.lex_state = 371},
  [746] = {.lex_state = 371},
  [747] = {.lex_state = 371},
  [748] = {.lex_state = 371},
  [749] = {.lex_state = 371},
  [750] = {.lex_state = 371},
  [751] = {.lex_state = 371},
  [752] = {.lex_state = 371},
  [753] = {.lex_state = 371},
  [754] = {.lex_state = 371},
  [755] = {.lex_state = 371},
  [756] = {.lex_state = 371},
  [757] = {.lex_state = 371},
  [758] = {.lex_state = 371},
  [759] = {.lex_state = 371},
  [760] = {.lex_state = 371},
  [761] = {.lex_state = 371},
  [762] = {.lex_state = 371},
  [763] = {.lex_state = 371},
  [764] = {.lex_state = 371},
  [765] = {.lex_state = 371},
  [766] = {.lex_state = 371},
  [767] = {.lex_state = 371},
  [768] = {.lex_state = 371},
  [769] = {.lex_state = 371},
  [770] = {.lex_state = 371},
  [771] = {.lex_state = 371},
  [772] = {.lex_state = 371},
  [773] = {.lex_state = 371},
  [774] = {.lex_state = 41},
  [775] = {.lex_state = 371},
  [776] = {.lex_state = 371},
  [777] = {.lex_state = 371},
  [778] = {.lex_state = 371},
  [779] = {.lex_state = 371},
  [780] = {.lex_state = 371},
  [781] = {.lex_state = 371},
  [782] = {.lex_state = 371},
  [783] = {.lex_state = 371},
  [784] = {.lex_state = 371},
  [785] = {.lex_state = 371},
  [786] = {.lex_state = 371},
  [787] = {.lex_state = 371},
  [788] = {.lex_state = 371},
  [789] = {.lex_state = 371},
  [790] = {.lex_state = 371},
  [791] = {.lex_state = 371},
  [792] = {.lex_state = 371},
  [793] = {.lex_state = 371},
  [794] = {.lex_state = 371},
  [795] = {.lex_state = 371},
  [796] = {.lex_state = 371},
  [797] = {.lex_state = 371},
  [798] = {.lex_state = 371},
  [799] = {.lex_state = 371},
  [800] = {.lex_state = 371},
  [801] = {.lex_state = 371},
  [802] = {.lex_state = 371},
  [803] = {.lex_state = 371},
  [804] = {.lex_state = 371},
  [805] = {.lex_state = 371},
  [806] = {.lex_state = 371},
  [807] = {.lex_state = 371},
  [808] = {.lex_state = 371},
  [809] = {.lex_state = 371},
  [810] = {.lex_state = 371},
  [811] = {.lex_state = 371},
  [812] = {.lex_state = 371},
  [813] = {.lex_state = 371},
  [814] = {.lex_state = 371},
  [815] = {.lex_state = 371},
  [816] = {.lex_state = 371},
  [817] = {.lex_state = 371},
  [818] = {.lex_state = 371},
  [819] = {.lex_state = 371},
  [820] = {.lex_state = 371},
  [821] = {.lex_state = 371},
  [822] = {.lex_state = 8},
  [823] = {.lex_state = 371},
  [824] = {.lex_state = 371},
  [825] = {.lex_state = 371},
  [826] = {.lex_state = 371},
  [827] = {.lex_state = 371},
  [828] = {.lex_state = 371},
  [829] = {.lex_state = 371},
  [830] = {.lex_state = 371},
  [831] = {.lex_state = 371},
  [832] = {.lex_state = 371},
  [833] = {.lex_state = 371},
  [834] = {.lex_state = 371},
  [835] = {.lex_state = 371},
  [836] = {.lex_state = 371},
  [837] = {.lex_state = 371},
  [838] = {.lex_state = 371},
  [839] = {.lex_state = 371},
  [840] = {.lex_state = 371},
  [841] = {.lex_state = 371},
  [842] = {.lex_state = 371},
  [843] = {.lex_state = 371},
  [844] = {.lex_state = 371},
  [845] = {.lex_state = 371},
  [846] = {.lex_state = 371},
  [847] = {.lex_state = 371},
  [848] = {.lex_state = 371},
  [849] = {.lex_state = 371},
  [850] = {.lex_state = 371},
  [851] = {.lex_state = 371},
  [852] = {.lex_state = 371},
  [853] = {.lex_state = 371},
  [854] = {.lex_state = 371},
  [855] = {.lex_state = 371},
  [856] = {.lex_state = 371},
  [857] = {.lex_state = 371},
  [858] = {.lex_state = 371},
  [859] = {.lex_state = 371},
  [860] = {.lex_state = 41},
  [861] = {.lex_state = 41},
  [862] = {.lex_state = 371},
  [863] = {.lex_state = 371},
  [864] = {.lex_state = 371},
  [865] = {.lex_state = 371},
  [866] = {.lex_state = 371},
  [867] = {.lex_state = 371},
  [868] = {.lex_state = 371},
  [869] = {.lex_state = 371},
  [870] = {.lex_state = 371},
  [871] = {.lex_state = 371},
  [872] = {.lex_state = 371},
  [873] = {.lex_state = 371},
  [874] = {.lex_state = 371},
  [875] = {.lex_state = 41},
  [876] = {.lex_state = 41},
  [877] = {.lex_state = 41},
  [878] = {.lex_state = 371},
  [879] = {.lex_state = 371},
  [880] = {.lex_state = 371},
  [881] = {.lex_state = 371},
  [882] = {.lex_state = 371},
  [883] = {.lex_state = 371},
  [884] = {.lex_state = 371},
  [885] = {.lex_state = 371},
  [886] = {.lex_state = 371},
  [887] = {.lex_state = 371},
  [888] = {.lex_state = 371},
  [889] = {.lex_state = 371},
  [890] = {.lex_state = 371},
  [891] = {.lex_state = 41},
  [892] = {.lex_state = 41},
  [893] = {.lex_state = 371},
  [894] = {.lex_state = 41},
  [895] = {.lex_state = 371},
  [896] = {.lex_state = 371},
  [897] = {.lex_state = 371},
  [898] = {.lex_state = 41},
  [899] = {.lex_state = 41},
  [900] = {.lex_state = 371},
  [901] = {.lex_state = 41},
  [902] = {.lex_state = 371},
  [903] = {.lex_state = 41},
  [904] = {.lex_state = 41},
  [905] = {.lex_state = 41},
  [906] = {.lex_state = 41},
  [907] = {.lex_state = 41},
  [908] = {.lex_state = 41},
  [909] = {.lex_state = 41},
  [910] = {.lex_state = 41},
  [911] = {.lex_state = 41},
  [912] = {.lex_state = 41},
  [913] = {.lex_state = 41},
  [914] = {.lex_state = 41},
  [915] = {.lex_state = 41},
  [916] = {.lex_state = 41},
  [917] = {.lex_state = 41},
  [918] = {.lex_state = 41},
  [919] = {.lex_state = 41},
  [920] = {.lex_state = 41},
  [921] = {.lex_state = 41},
  [922] = {.lex_state = 41},
  [923] = {.lex_state = 41},
  [924] = {.lex_state = 41},
  [925] = {.lex_state = 41},
  [926] = {.lex_state = 41},
  [927] = {.lex_state = 41},
  [928] = {.lex_state = 41},
  [929] = {.lex_state = 371},
  [930] = {.lex_state = 41},
  [931] = {.lex_state = 41},
  [932] = {.lex_state = 41},
  [933] = {.lex_state = 41},
  [934] = {.lex_state = 41},
  [935] = {.lex_state = 41},
  [936] = {.lex_state = 371},
  [937] = {.lex_state = 371},
  [938] = {.lex_state = 371},
  [939] = {.lex_state = 371},
  [940] = {.lex_state = 371},
  [941] = {.lex_state = 371},
  [942] = {.lex_state = 8},
  [943] = {.lex_state = 8},
  [944] = {.lex_state = 41},
  [945] = {.lex_state = 41},
  [946] = {.lex_state = 371},
  [947] = {.lex_state = 41},
  [948] = {.lex_state = 41},
  [949] = {.lex_state = 41},
  [950] = {.lex_state = 41},
  [951] = {.lex_state = 371},
  [952] = {.lex_state = 371},
  [953] = {.lex_state = 41},
  [954] = {.lex_state = 41},
  [955] = {.lex_state = 41},
  [956] = {.lex_state = 371},
  [957] = {.lex_state = 371},
  [958] = {.lex_state = 371},
  [959] = {.lex_state = 371},
  [960] = {.lex_state = 371},
  [961] = {.lex_state = 41},
  [962] = {.lex_state = 41},
  [963] = {.lex_state = 41},
  [964] = {.lex_state = 41},
  [965] = {.lex_state = 41},
  [966] = {.lex_state = 41},
  [967] = {.lex_state = 371},
  [968] = {.lex_state = 41},
  [969] = {.lex_state = 41},
  [970] = {.lex_state = 41},
  [971] = {.lex_state = 371},
  [972] = {.lex_state = 371},
  [973] = {.lex_state = 371},
  [974] = {.lex_state = 371},
  [975] = {.lex_state = 371},
  [976] = {.lex_state = 371},
  [977] = {.lex_state = 371},
  [978] = {.lex_state = 371},
  [979] = {.lex_state = 371},
  [980] = {.lex_state = 371},
  [981] = {.lex_state = 371},
  [982] = {.lex_state = 371},
  [983] = {.lex_state = 371},
  [984] = {.lex_state = 371},
  [985] = {.lex_state = 371},
  [986] = {.lex_state = 371},
  [987] = {.lex_state = 371},
  [988] = {.lex_state = 371},
  [989] = {.lex_state = 371},
  [990] = {.lex_state = 371},
  [991] = {.lex_state = 371},
  [992] = {.lex_state = 371},
  [993] = {.lex_state = 371},
  [994] = {.lex_state = 371},
  [995] = {.lex_state = 371},
  [996] = {.lex_state = 371},
  [997] = {.lex_state = 26},
  [998] = {.lex_state = 371},
  [999] = {.lex_state = 371},
  [1000] = {.lex_state = 26},
  [1001] = {.lex_state = 371},
  [1002] = {.lex_state = 371},
  [1003] = {.lex_state = 371},
  [1004] = {.lex_state = 371},
  [1005] = {.lex_state = 371},
  [1006] = {.lex_state = 371},
  [1007] = {.lex_state = 371},
  [1008] = {.lex_state = 371},
  [1009] = {.lex_state = 371},
  [1010] = {.lex_state = 371},
  [1011] = {.lex_state = 8},
  [1012] = {.lex_state = 371},
  [1013] = {.lex_state = 371},
  [1014] = {.lex_state = 371},
  [1015] = {.lex_state = 371},
  [1016] = {.lex_state = 371},
  [1017] = {.lex_state = 371},
  [1018] = {.lex_state = 371},
  [1019] = {.lex_state = 371},
  [1020] = {.lex_state = 371},
  [1021] = {.lex_state = 371},
  [1022] = {.lex_state = 371},
  [1023] = {.lex_state = 371},
  [1024] = {.lex_state = 371},
  [1025] = {.lex_state = 371},
  [1026] = {.lex_state = 371},
  [1027] = {.lex_state = 371},
  [1028] = {.lex_state = 371},
  [1029] = {.lex_state = 371},
  [1030] = {.lex_state = 371},
  [1031] = {.lex_state = 371},
  [1032] = {.lex_state = 371},
  [1033] = {.lex_state = 371},
  [1034] = {.lex_state = 371},
  [1035] = {.lex_state = 371},
  [1036] = {.lex_state = 371},
  [1037] = {.lex_state = 371},
  [1038] = {.lex_state = 371},
  [1039] = {.lex_state = 371},
  [1040] = {.lex_state = 371},
  [1041] = {.lex_state = 371},
  [1042] = {.lex_state = 371},
  [1043] = {.lex_state = 371},
  [1044] = {.lex_state = 371},
  [1045] = {.lex_state = 371},
  [1046] = {.lex_state = 371},
  [1047] = {.lex_state = 371},
  [1048] = {.lex_state = 371},
  [1049] = {.lex_state = 371},
  [1050] = {.lex_state = 371},
  [1051] = {.lex_state = 371},
  [1052] = {.lex_state = 371},
  [1053] = {.lex_state = 371},
  [1054] = {.lex_state = 371},
  [1055] = {.lex_state = 371},
  [1056] = {.lex_state = 371},
  [1057] = {.lex_state = 371},
  [1058] = {.lex_state = 371},
  [1059] = {.lex_state = 13},
  [1060] = {.lex_state = 371},
  [1061] = {.lex_state = 371},
  [1062] = {.lex_state = 371},
  [1063] = {.lex_state = 371},
  [1064] = {.lex_state = 371},
  [1065] = {.lex_state = 371},
  [1066] = {.lex_state = 371},
  [1067] = {.lex_state = 371},
  [1068] = {.lex_state = 12},
  [1069] = {.lex_state = 371},
  [1070] = {.lex_state = 371},
  [1071] = {.lex_state = 371},
  [1072] = {.lex_state = 371},
  [1073] = {.lex_state = 371},
  [1074] = {.lex_state = 371},
  [1075] = {.lex_state = 371},
  [1076] = {.lex_state = 371},
  [1077] = {.lex_state = 371},
  [1078] = {.lex_state = 371},
  [1079] = {.lex_state = 371},
  [1080] = {.lex_state = 371},
  [1081] = {.lex_state = 371},
  [1082] = {.lex_state = 371},
  [1083] = {.lex_state = 371},
  [1084] = {.lex_state = 371},
  [1085] = {.lex_state = 371},
  [1086] = {.lex_state = 371},
  [1087] = {.lex_state = 371},
  [1088] = {.lex_state = 371},
  [1089] = {.lex_state = 371},
  [1090] = {.lex_state = 371},
  [1091] = {.lex_state = 371},
  [1092] = {.lex_state = 371},
  [1093] = {.lex_state = 371},
  [1094] = {.lex_state = 371},
  [1095] = {.lex_state = 371},
  [1096] = {.lex_state = 371},
  [1097] = {.lex_state = 371},
  [1098] = {.lex_state = 371},
  [1099] = {.lex_state = 371},
  [1100] = {.lex_state = 371},
  [1101] = {.lex_state = 371},
  [1102] = {.lex_state = 371},
  [1103] = {.lex_state = 371},
  [1104] = {.lex_state = 371},
  [1105] = {.lex_state = 371},
  [1106] = {.lex_state = 371},
  [1107] = {.lex_state = 371},
  [1108] = {.lex_state = 371},
  [1109] = {.lex_state = 371},
  [1110] = {.lex_state = 371},
  [1111] = {.lex_state = 371},
  [1112] = {.lex_state = 371},
  [1113] = {.lex_state = 371},
  [1114] = {.lex_state = 371},
  [1115] = {.lex_state = 371},
  [1116] = {.lex_state = 371},
  [1117] = {.lex_state = 371},
  [1118] = {.lex_state = 371},
  [1119] = {.lex_state = 371},
  [1120] = {.lex_state = 371},
  [1121] = {.lex_state = 371},
  [1122] = {.lex_state = 371},
  [1123] = {.lex_state = 371},
  [1124] = {.lex_state = 371},
  [1125] = {.lex_state = 371},
  [1126] = {.lex_state = 371},
  [1127] = {.lex_state = 371},
  [1128] = {.lex_state = 371},
  [1129] = {.lex_state = 371},
  [1130] = {.lex_state = 371},
  [1131] = {.lex_state = 371},
  [1132] = {.lex_state = 371},
  [1133] = {.lex_state = 371},
  [1134] = {.lex_state = 371},
  [1135] = {.lex_state = 371},
  [1136] = {.lex_state = 371},
  [1137] = {.lex_state = 371},
  [1138] = {.lex_state = 371},
  [1139] = {.lex_state = 371},
  [1140] = {.lex_state = 371},
  [1141] = {.lex_state = 371},
  [1142] = {.lex_state = 371},
  [1143] = {.lex_state = 371},
  [1144] = {.lex_state = 371},
  [1145] = {.lex_state = 371},
  [1146] = {.lex_state = 371},
  [1147] = {.lex_state = 371},
  [1148] = {.lex_state = 371},
  [1149] = {.lex_state = 371},
  [1150] = {.lex_state = 371},
  [1151] = {.lex_state = 371},
  [1152] = {.lex_state = 8},
  [1153] = {.lex_state = 371},
  [1154] = {.lex_state = 371},
  [1155] = {.lex_state = 371},
  [1156] = {.lex_state = 371},
  [1157] = {.lex_state = 371},
  [1158] = {.lex_state = 371},
  [1159] = {.lex_state = 371},
  [1160] = {.lex_state = 371},
  [1161] = {.lex_state = 371},
  [1162] = {.lex_state = 371},
  [1163] = {.lex_state = 371},
  [1164] = {.lex_state = 371},
  [1165] = {.lex_state = 371},
  [1166] = {.lex_state = 371},
  [1167] = {.lex_state = 371},
  [1168] = {.lex_state = 371},
  [1169] = {.lex_state = 371},
  [1170] = {.lex_state = 371},
  [1171] = {.lex_state = 371},
  [1172] = {.lex_state = 371},
  [1173] = {.lex_state = 371},
  [1174] = {.lex_state = 371},
  [1175] = {.lex_state = 371},
  [1176] = {.lex_state = 371},
  [1177] = {.lex_state = 371},
  [1178] = {.lex_state = 371},
  [1179] = {.lex_state = 371},
  [1180] = {.lex_state = 8},
  [1181] = {.lex_state = 371},
  [1182] = {.lex_state = 371},
  [1183] = {.lex_state = 371},
  [1184] = {.lex_state = 371},
  [1185] = {.lex_state = 371},
  [1186] = {.lex_state = 371},
  [1187] = {.lex_state = 371},
  [1188] = {.lex_state = 371},
  [1189] = {.lex_state = 8},
  [1190] = {.lex_state = 371},
  [1191] = {.lex_state = 371},
  [1192] = {.lex_state = 371},
  [1193] = {.lex_state = 371},
  [1194] = {.lex_state = 371},
  [1195] = {.lex_state = 371},
  [1196] = {.lex_state = 371},
  [1197] = {.lex_state = 41},
  [1198] = {.lex_state = 371},
  [1199] = {.lex_state = 371},
  [1200] = {.lex_state = 371},
  [1201] = {.lex_state = 371},
  [1202] = {.lex_state = 371},
  [1203] = {.lex_state = 371},
  [1204] = {.lex_state = 371},
  [1205] = {.lex_state = 371},
  [1206] = {.lex_state = 371},
  [1207] = {.lex_state = 371},
  [1208] = {.lex_state = 371},
  [1209] = {.lex_state = 371},
  [1210] = {.lex_state = 371},
  [1211] = {.lex_state = 371},
  [1212] = {.lex_state = 371},
  [1213] = {.lex_state = 371},
  [1214] = {.lex_state = 371},
  [1215] = {.lex_state = 371},
  [1216] = {.lex_state = 371},
  [1217] = {.lex_state = 371},
  [1218] = {.lex_state = 371},
  [1219] = {.lex_state = 371},
  [1220] = {.lex_state = 371},
  [1221] = {.lex_state = 8},
  [1222] = {.lex_state = 371},
  [1223] = {.lex_state = 371},
  [1224] = {.lex_state = 371},
  [1225] = {.lex_state = 371},
  [1226] = {.lex_state = 371},
  [1227] = {.lex_state = 371},
  [1228] = {.lex_state = 371},
  [1229] = {.lex_state = 371},
  [1230] = {.lex_state = 371},
  [1231] = {.lex_state = 371},
  [1232] = {.lex_state = 371},
  [1233] = {.lex_state = 371},
  [1234] = {.lex_state = 371},
  [1235] = {.lex_state = 371},
  [1236] = {.lex_state = 371},
  [1237] = {.lex_state = 371},
  [1238] = {.lex_state = 371},
  [1239] = {.lex_state = 371},
  [1240] = {.lex_state = 371},
  [1241] = {.lex_state = 371},
  [1242] = {.lex_state = 371},
  [1243] = {.lex_state = 371},
  [1244] = {.lex_state = 371},
  [1245] = {.lex_state = 371},
  [1246] = {.lex_state = 371},
  [1247] = {.lex_state = 371},
  [1248] = {.lex_state = 371},
  [1249] = {.lex_state = 371},
  [1250] = {.lex_state = 371},
  [1251] = {.lex_state = 371},
  [1252] = {.lex_state = 371},
  [1253] = {.lex_state = 371},
  [1254] = {.lex_state = 371},
  [1255] = {.lex_state = 371},
  [1256] = {.lex_state = 371},
  [1257] = {.lex_state = 371},
  [1258] = {.lex_state = 371},
  [1259] = {.lex_state = 371},
  [1260] = {.lex_state = 371},
  [1261] = {.lex_state = 371},
  [1262] = {.lex_state = 371},
  [1263] = {.lex_state = 371},
  [1264] = {.lex_state = 371},
  [1265] = {.lex_state = 371},
  [1266] = {.lex_state = 371},
  [1267] = {.lex_state = 371},
  [1268] = {.lex_state = 371},
  [1269] = {.lex_state = 371},
  [1270] = {.lex_state = 371},
  [1271] = {.lex_state = 371},
  [1272] = {.lex_state = 371},
  [1273] = {.lex_state = 371},
  [1274] = {.lex_state = 371},
  [1275] = {.lex_state = 371},
  [1276] = {.lex_state = 371},
  [1277] = {.lex_state = 371},
  [1278] = {.lex_state = 371},
  [1279] = {.lex_state = 371},
  [1280] = {.lex_state = 371},
  [1281] = {.lex_state = 371},
  [1282] = {.lex_state = 371},
  [1283] = {.lex_state = 371},
  [1284] = {.lex_state = 371},
  [1285] = {.lex_state = 371},
  [1286] = {.lex_state = 8},
  [1287] = {.lex_state = 371},
  [1288] = {.lex_state = 371},
  [1289] = {.lex_state = 371},
  [1290] = {.lex_state = 41},
  [1291] = {.lex_state = 41},
  [1292] = {.lex_state = 41},
  [1293] = {.lex_state = 41},
  [1294] = {.lex_state = 41},
  [1295] = {.lex_state = 41},
  [1296] = {.lex_state = 41},
  [1297] = {.lex_state = 41},
  [1298] = {.lex_state = 41},
  [1299] = {.lex_state = 41},
  [1300] = {.lex_state = 41},
  [1301] = {.lex_state = 41},
  [1302] = {.lex_state = 41},
  [1303] = {.lex_state = 41},
  [1304] = {.lex_state = 41},
  [1305] = {.lex_state = 41},
  [1306] = {.lex_state = 41},
  [1307] = {.lex_state = 41},
  [1308] = {.lex_state = 41},
  [1309] = {.lex_state = 41},
  [1310] = {.lex_state = 41},
  [1311] = {.lex_state = 41},
  [1312] = {.lex_state = 41},
  [1313] = {.lex_state = 41},
  [1314] = {.lex_state = 41},
  [1315] = {.lex_state = 41},
  [1316] = {.lex_state = 41},
  [1317] = {.lex_state = 41},
  [1318] = {.lex_state = 41},
  [1319] = {.lex_state = 41},
  [1320] = {.lex_state = 41},
  [1321] = {.lex_state = 41},
  [1322] = {.lex_state = 41},
  [1323] = {.lex_state = 41},
  [1324] = {.lex_state = 41},
  [1325] = {.lex_state = 41},
  [1326] = {.lex_state = 41},
  [1327] = {.lex_state = 41},
  [1328] = {.lex_state = 41},
  [1329] = {.lex_state = 41},
  [1330] = {.lex_state = 41},
  [1331] = {.lex_state = 41},
  [1332] = {.lex_state = 41},
  [1333] = {.lex_state = 41},
  [1334] = {.lex_state = 41},
  [1335] = {.lex_state = 41},
  [1336] = {.lex_state = 41},
  [1337] = {.lex_state = 41},
  [1338] = {.lex_state = 41},
  [1339] = {.lex_state = 41},
  [1340] = {.lex_state = 41},
  [1341] = {.lex_state = 41},
  [1342] = {.lex_state = 41},
  [1343] = {.lex_state = 41},
  [1344] = {.lex_state = 41},
  [1345] = {.lex_state = 41},
  [1346] = {.lex_state = 41},
  [1347] = {.lex_state = 41},
  [1348] = {.lex_state = 41},
  [1349] = {.lex_state = 41},
  [1350] = {.lex_state = 41},
  [1351] = {.lex_state = 41},
  [1352] = {.lex_state = 41},
  [1353] = {.lex_state = 41},
  [1354] = {.lex_state = 41},
  [1355] = {.lex_state = 41},
  [1356] = {.lex_state = 41},
  [1357] = {.lex_state = 41},
  [1358] = {.lex_state = 41},
  [1359] = {.lex_state = 41},
  [1360] = {.lex_state = 41},
  [1361] = {.lex_state = 41},
  [1362] = {.lex_state = 41},
  [1363] = {.lex_state = 41},
  [1364] = {.lex_state = 41},
  [1365] = {.lex_state = 41},
  [1366] = {.lex_state = 41},
  [1367] = {.lex_state = 41},
  [1368] = {.lex_state = 41},
  [1369] = {.lex_state = 41},
  [1370] = {.lex_state = 41},
  [1371] = {.lex_state = 41},
  [1372] = {.lex_state = 41},
  [1373] = {.lex_state = 371},
  [1374] = {.lex_state = 41},
  [1375] = {.lex_state = 371},
  [1376] = {.lex_state = 41},
  [1377] = {.lex_state = 41},
  [1378] = {.lex_state = 41},
  [1379] = {.lex_state = 41},
  [1380] = {.lex_state = 371},
  [1381] = {.lex_state = 41},
  [1382] = {.lex_state = 41},
  [1383] = {.lex_state = 41},
  [1384] = {.lex_state = 41},
  [1385] = {.lex_state = 41},
  [1386] = {.lex_state = 41},
  [1387] = {.lex_state = 41},
  [1388] = {.lex_state = 371},
  [1389] = {.lex_state = 41},
  [1390] = {.lex_state = 371},
  [1391] = {.lex_state = 41},
  [1392] = {.lex_state = 41},
  [1393] = {.lex_state = 41},
  [1394] = {.lex_state = 41},
  [1395] = {.lex_state = 41},
  [1396] = {.lex_state = 41},
  [1397] = {.lex_state = 371},
  [1398] = {.lex_state = 41},
  [1399] = {.lex_state = 41},
  [1400] = {.lex_state = 41},
  [1401] = {.lex_state = 41},
  [1402] = {.lex_state = 41},
  [1403] = {.lex_state = 41},
  [1404] = {.lex_state = 41},
  [1405] = {.lex_state = 41},
  [1406] = {.lex_state = 41},
  [1407] = {.lex_state = 41},
  [1408] = {.lex_state = 41},
  [1409] = {.lex_state = 41},
  [1410] = {.lex_state = 41},
  [1411] = {.lex_state = 41},
  [1412] = {.lex_state = 41},
  [1413] = {.lex_state = 41},
  [1414] = {.lex_state = 41},
  [1415] = {.lex_state = 41},
  [1416] = {.lex_state = 41},
  [1417] = {.lex_state = 41},
  [1418] = {.lex_state = 41},
  [1419] = {.lex_state = 41},
  [1420] = {.lex_state = 41},
  [1421] = {.lex_state = 41},
  [1422] = {.lex_state = 41},
  [1423] = {.lex_state = 41},
  [1424] = {.lex_state = 41},
  [1425] = {.lex_state = 11},
  [1426] = {.lex_state = 11},
  [1427] = {.lex_state = 41},
  [1428] = {.lex_state = 41},
  [1429] = {.lex_state = 41},
  [1430] = {.lex_state = 41},
  [1431] = {.lex_state = 41},
  [1432] = {.lex_state = 41},
  [1433] = {.lex_state = 41},
  [1434] = {.lex_state = 41},
  [1435] = {.lex_state = 41},
  [1436] = {.lex_state = 41},
  [1437] = {.lex_state = 41},
  [1438] = {.lex_state = 41},
  [1439] = {.lex_state = 41},
  [1440] = {.lex_state = 41},
  [1441] = {.lex_state = 41},
  [1442] = {.lex_state = 41},
  [1443] = {.lex_state = 41},
  [1444] = {.lex_state = 41},
  [1445] = {.lex_state = 41},
  [1446] = {.lex_state = 41},
  [1447] = {.lex_state = 41},
  [1448] = {.lex_state = 41},
  [1449] = {.lex_state = 41},
  [1450] = {.lex_state = 41},
  [1451] = {.lex_state = 41},
  [1452] = {.lex_state = 41},
  [1453] = {.lex_state = 41},
  [1454] = {.lex_state = 41},
  [1455] = {.lex_state = 41},
  [1456] = {.lex_state = 41},
  [1457] = {.lex_state = 41},
  [1458] = {.lex_state = 41},
  [1459] = {.lex_state = 41},
  [1460] = {.lex_state = 38},
  [1461] = {.lex_state = 38},
  [1462] = {.lex_state = 41},
  [1463] = {.lex_state = 41},
  [1464] = {.lex_state = 41},
  [1465] = {.lex_state = 371},
  [1466] = {.lex_state = 41},
  [1467] = {.lex_state = 41},
  [1468] = {.lex_state = 41},
  [1469] = {.lex_state = 41},
  [1470] = {.lex_state = 41},
  [1471] = {.lex_state = 41},
  [1472] = {.lex_state = 41},
  [1473] = {.lex_state = 41},
  [1474] = {.lex_state = 41},
  [1475] = {.lex_state = 41},
  [1476] = {.lex_state = 41},
  [1477] = {.lex_state = 41},
  [1478] = {.lex_state = 41},
  [1479] = {.lex_state = 41},
  [1480] = {.lex_state = 41},
  [1481] = {.lex_state = 41},
  [1482] = {.lex_state = 41},
  [1483] = {.lex_state = 46},
  [1484] = {.lex_state = 46},
  [1485] = {.lex_state = 41},
  [1486] = {.lex_state = 41},
  [1487] = {.lex_state = 41},
  [1488] = {.lex_state = 41},
  [1489] = {.lex_state = 41},
  [1490] = {.lex_state = 41},
  [1491] = {.lex_state = 41},
  [1492] = {.lex_state = 41},
  [1493] = {.lex_state = 41},
  [1494] = {.lex_state = 41},
  [1495] = {.lex_state = 41},
  [1496] = {.lex_state = 41},
  [1497] = {.lex_state = 41},
  [1498] = {.lex_state = 41},
  [1499] = {.lex_state = 41},
  [1500] = {.lex_state = 41},
  [1501] = {.lex_state = 371},
  [1502] = {.lex_state = 41},
  [1503] = {.lex_state = 41},
  [1504] = {.lex_state = 41},
  [1505] = {.lex_state = 41},
  [1506] = {.lex_state = 41},
  [1507] = {.lex_state = 41},
  [1508] = {.lex_state = 41},
  [1509] = {.lex_state = 41},
  [1510] = {.lex_state = 41},
  [1511] = {.lex_state = 41},
  [1512] = {.lex_state = 41},
  [1513] = {.lex_state = 41},
  [1514] = {.lex_state = 41},
  [1515] = {.lex_state = 41},
  [1516] = {.lex_state = 41},
  [1517] = {.lex_state = 41},
  [1518] = {.lex_state = 41},
  [1519] = {.lex_state = 41},
  [1520] = {.lex_state = 41},
  [1521] = {.lex_state = 41},
  [1522] = {.lex_state = 41},
  [1523] = {.lex_state = 41},
  [1524] = {.lex_state = 41},
  [1525] = {.lex_state = 41},
  [1526] = {.lex_state = 41},
  [1527] = {.lex_state = 41},
  [1528] = {.lex_state = 41},
  [1529] = {.lex_state = 41},
  [1530] = {.lex_state = 41},
  [1531] = {.lex_state = 41},
  [1532] = {.lex_state = 41},
  [1533] = {.lex_state = 41},
  [1534] = {.lex_state = 41},
  [1535] = {.lex_state = 41},
  [1536] = {.lex_state = 41},
  [1537] = {.lex_state = 41},
  [1538] = {.lex_state = 41},
  [1539] = {.lex_state = 41},
  [1540] = {.lex_state = 41},
  [1541] = {.lex_state = 41},
  [1542] = {.lex_state = 41},
  [1543] = {.lex_state = 41},
  [1544] = {.lex_state = 41},
  [1545] = {.lex_state = 41},
  [1546] = {.lex_state = 41},
  [1547] = {.lex_state = 41},
  [1548] = {.lex_state = 41},
  [1549] = {.lex_state = 41},
  [1550] = {.lex_state = 41},
  [1551] = {.lex_state = 41},
  [1552] = {.lex_state = 41},
  [1553] = {.lex_state = 371},
  [1554] = {.lex_state = 41},
  [1555] = {.lex_state = 371},
  [1556] = {.lex_state = 41},
  [1557] = {.lex_state = 41},
  [1558] = {.lex_state = 41},
  [1559] = {.lex_state = 41},
  [1560] = {.lex_state = 41},
  [1561] = {.lex_state = 41},
  [1562] = {.lex_state = 41},
  [1563] = {.lex_state = 41},
  [1564] = {.lex_state = 41},
  [1565] = {.lex_state = 41},
  [1566] = {.lex_state = 41},
  [1567] = {.lex_state = 41},
  [1568] = {.lex_state = 41},
  [1569] = {.lex_state = 41},
  [1570] = {.lex_state = 41},
  [1571] = {.lex_state = 41},
  [1572] = {.lex_state = 371},
  [1573] = {.lex_state = 371},
  [1574] = {.lex_state = 371},
  [1575] = {.lex_state = 41},
  [1576] = {.lex_state = 41},
  [1577] = {.lex_state = 41},
  [1578] = {.lex_state = 371},
  [1579] = {.lex_state = 41},
  [1580] = {.lex_state = 371},
  [1581] = {.lex_state = 371},
  [1582] = {.lex_state = 41},
  [1583] = {.lex_state = 371},
  [1584] = {.lex_state = 371},
  [1585] = {.lex_state = 41},
  [1586] = {.lex_state = 41},
  [1587] = {.lex_state = 41},
  [1588] = {.lex_state = 41},
  [1589] = {.lex_state = 41},
  [1590] = {.lex_state = 41},
  [1591] = {.lex_state = 371},
  [1592] = {.lex_state = 371},
  [1593] = {.lex_state = 42},
  [1594] = {.lex_state = 371},
  [1595] = {.lex_state = 371},
  [1596] = {.lex_state = 371},
  [1597] = {.lex_state = 41},
  [1598] = {.lex_state = 41},
  [1599] = {.lex_state = 41},
  [1600] = {.lex_state = 41},
  [1601] = {.lex_state = 41},
  [1602] = {.lex_state = 41},
  [1603] = {.lex_state = 41},
  [1604] = {.lex_state = 41},
  [1605] = {.lex_state = 41},
  [1606] = {.lex_state = 371},
  [1607] = {.lex_state = 41},
  [1608] = {.lex_state = 371},
  [1609] = {.lex_state = 41},
  [1610] = {.lex_state = 371},
  [1611] = {.lex_state = 41},
  [1612] = {.lex_state = 41},
  [1613] = {.lex_state = 41},
  [1614] = {.lex_state = 41},
  [1615] = {.lex_state = 41},
  [1616] = {.lex_state = 41},
  [1617] = {.lex_state = 41},
  [1618] = {.lex_state = 41},
  [1619] = {.lex_state = 371},
  [1620] = {.lex_state = 41},
  [1621] = {.lex_state = 41},
  [1622] = {.lex_state = 41},
  [1623] = {.lex_state = 41},
  [1624] = {.lex_state = 41},
  [1625] = {.lex_state = 41},
  [1626] = {.lex_state = 41},
  [1627] = {.lex_state = 41},
  [1628] = {.lex_state = 41},
  [1629] = {.lex_state = 41},
  [1630] = {.lex_state = 41},
  [1631] = {.lex_state = 41},
  [1632] = {.lex_state = 41},
  [1633] = {.lex_state = 371},
  [1634] = {.lex_state = 41},
  [1635] = {.lex_state = 41},
  [1636] = {.lex_state = 371},
  [1637] = {.lex_state = 41},
  [1638] = {.lex_state = 41},
  [1639] = {.lex_state = 371},
  [1640] = {.lex_state = 41},
  [1641] = {.lex_state = 371},
  [1642] = {.lex_state = 41},
  [1643] = {.lex_state = 371},
  [1644] = {.lex_state = 371},
  [1645] = {.lex_state = 41},
  [1646] = {.lex_state = 41},
  [1647] = {.lex_state = 41},
  [1648] = {.lex_state = 41},
  [1649] = {.lex_state = 371},
  [1650] = {.lex_state = 371},
  [1651] = {.lex_state = 41},
  [1652] = {.lex_state = 41},
  [1653] = {.lex_state = 41},
  [1654] = {.lex_state = 371},
  [1655] = {.lex_state = 371},
  [1656] = {.lex_state = 371},
  [1657] = {.lex_state = 41},
  [1658] = {.lex_state = 371},
  [1659] = {.lex_state = 41},
  [1660] = {.lex_state = 41},
  [1661] = {.lex_state = 41},
  [1662] = {.lex_state = 41},
  [1663] = {.lex_state = 41},
  [1664] = {.lex_state = 41},
  [1665] = {.lex_state = 41},
  [1666] = {.lex_state = 41},
  [1667] = {.lex_state = 41},
  [1668] = {.lex_state = 41},
  [1669] = {.lex_state = 41},
  [1670] = {.lex_state = 41},
  [1671] = {.lex_state = 41},
  [1672] = {.lex_state = 41},
  [1673] = {.lex_state = 41},
  [1674] = {.lex_state = 41},
  [1675] = {.lex_state = 41},
  [1676] = {.lex_state = 41},
  [1677] = {.lex_state = 41},
  [1678] = {.lex_state = 41},
  [1679] = {.lex_state = 41},
  [1680] = {.lex_state = 41},
  [1681] = {.lex_state = 41},
  [1682] = {.lex_state = 41},
  [1683] = {.lex_state = 41},
  [1684] = {.lex_state = 41},
  [1685] = {.lex_state = 41},
  [1686] = {.lex_state = 41},
  [1687] = {.lex_state = 41},
  [1688] = {.lex_state = 41},
  [1689] = {.lex_state = 41},
  [1690] = {.lex_state = 41},
  [1691] = {.lex_state = 41},
  [1692] = {.lex_state = 41},
  [1693] = {.lex_state = 371},
  [1694] = {.lex_state = 371},
  [1695] = {.lex_state = 371},
  [1696] = {.lex_state = 371},
  [1697] = {.lex_state = 371},
  [1698] = {.lex_state = 371},
  [1699] = {.lex_state = 371},
  [1700] = {.lex_state = 371},
  [1701] = {.lex_state = 371},
  [1702] = {.lex_state = 41},
  [1703] = {.lex_state = 371},
  [1704] = {.lex_state = 371},
  [1705] = {.lex_state = 371},
  [1706] = {.lex_state = 371},
  [1707] = {.lex_state = 371},
  [1708] = {.lex_state = 371},
  [1709] = {.lex_state = 371},
  [1710] = {.lex_state = 371},
  [1711] = {.lex_state = 371},
  [1712] = {.lex_state = 371},
  [1713] = {.lex_state = 371},
  [1714] = {.lex_state = 371},
  [1715] = {.lex_state = 371},
  [1716] = {.lex_state = 371},
  [1717] = {.lex_state = 371},
  [1718] = {.lex_state = 371},
  [1719] = {.lex_state = 371},
  [1720] = {.lex_state = 371},
  [1721] = {.lex_state = 371},
  [1722] = {.lex_state = 371},
  [1723] = {.lex_state = 41},
  [1724] = {.lex_state = 371},
  [1725] = {.lex_state = 371},
  [1726] = {.lex_state = 371},
  [1727] = {.lex_state = 371},
  [1728] = {.lex_state = 371},
  [1729] = {.lex_state = 371},
  [1730] = {.lex_state = 371},
  [1731] = {.lex_state = 371},
  [1732] = {.lex_state = 371},
  [1733] = {.lex_state = 41},
  [1734] = {.lex_state = 371},
  [1735] = {.lex_state = 371},
  [1736] = {.lex_state = 371},
  [1737] = {.lex_state = 371},
  [1738] = {.lex_state = 371},
  [1739] = {.lex_state = 371},
  [1740] = {.lex_state = 41},
  [1741] = {.lex_state = 371},
  [1742] = {.lex_state = 41},
  [1743] = {.lex_state = 41},
  [1744] = {.lex_state = 41},
  [1745] = {.lex_state = 41},
  [1746] = {.lex_state = 41},
  [1747] = {.lex_state = 41},
  [1748] = {.lex_state = 371},
  [1749] = {.lex_state = 371},
  [1750] = {.lex_state = 371},
  [1751] = {.lex_state = 371},
  [1752] = {.lex_state = 371},
  [1753] = {.lex_state = 371},
  [1754] = {.lex_state = 371},
  [1755] = {.lex_state = 371},
  [1756] = {.lex_state = 371},
  [1757] = {.lex_state = 41},
  [1758] = {.lex_state = 371},
  [1759] = {.lex_state = 41},
  [1760] = {.lex_state = 371},
  [1761] = {.lex_state = 371},
  [1762] = {.lex_state = 371},
  [1763] = {.lex_state = 371},
  [1764] = {.lex_state = 371},
  [1765] = {.lex_state = 371},
  [1766] = {.lex_state = 41},
  [1767] = {.lex_state = 371},
  [1768] = {.lex_state = 371},
  [1769] = {.lex_state = 371},
  [1770] = {.lex_state = 371},
  [1771] = {.lex_state = 41},
  [1772] = {.lex_state = 41},
  [1773] = {.lex_state = 371},
  [1774] = {.lex_state = 371},
  [1775] = {.lex_state = 41},
  [1776] = {.lex_state = 41},
  [1777] = {.lex_state = 41},
  [1778] = {.lex_state = 371},
  [1779] = {.lex_state = 371},
  [1780] = {.lex_state = 371},
  [1781] = {.lex_state = 371},
  [1782] = {.lex_state = 371},
  [1783] = {.lex_state = 371},
  [1784] = {.lex_state = 371},
  [1785] = {.lex_state = 41},
  [1786] = {.lex_state = 371},
  [1787] = {.lex_state = 371},
  [1788] = {.lex_state = 371},
  [1789] = {.lex_state = 371},
  [1790] = {.lex_state = 371},
  [1791] = {.lex_state = 371},
  [1792] = {.lex_state = 371},
  [1793] = {.lex_state = 371},
  [1794] = {.lex_state = 41},
  [1795] = {.lex_state = 371},
  [1796] = {.lex_state = 371},
  [1797] = {.lex_state = 41},
  [1798] = {.lex_state = 41},
  [1799] = {.lex_state = 371},
  [1800] = {.lex_state = 41},
  [1801] = {.lex_state = 41},
  [1802] = {.lex_state = 371},
  [1803] = {.lex_state = 371},
  [1804] = {.lex_state = 371},
  [1805] = {.lex_state = 371},
  [1806] = {.lex_state = 371},
  [1807] = {.lex_state = 371},
  [1808] = {.lex_state = 371},
  [1809] = {.lex_state = 371},
  [1810] = {.lex_state = 371},
  [1811] = {.lex_state = 371},
  [1812] = {.lex_state = 371},
  [1813] = {.lex_state = 371},
  [1814] = {.lex_state = 371},
  [1815] = {.lex_state = 371},
  [1816] = {.lex_state = 371},
  [1817] = {.lex_state = 371},
  [1818] = {.lex_state = 371},
  [1819] = {.lex_state = 371},
  [1820] = {.lex_state = 41},
  [1821] = {.lex_state = 41},
  [1822] = {.lex_state = 371},
  [1823] = {.lex_state = 371},
  [1824] = {.lex_state = 41},
  [1825] = {.lex_state = 41},
  [1826] = {.lex_state = 371},
  [1827] = {.lex_state = 371},
  [1828] = {.lex_state = 371},
  [1829] = {.lex_state = 371},
  [1830] = {.lex_state = 41},
  [1831] = {.lex_state = 371},
  [1832] = {.lex_state = 371},
  [1833] = {.lex_state = 371},
  [1834] = {.lex_state = 371},
  [1835] = {.lex_state = 371},
  [1836] = {.lex_state = 371},
  [1837] = {.lex_state = 371},
  [1838] = {.lex_state = 371},
  [1839] = {.lex_state = 371},
  [1840] = {.lex_state = 371},
  [1841] = {.lex_state = 371},
  [1842] = {.lex_state = 371},
  [1843] = {.lex_state = 371},
  [1844] = {.lex_state = 371},
  [1845] = {.lex_state = 371},
  [1846] = {.lex_state = 371},
  [1847] = {.lex_state = 41},
  [1848] = {.lex_state = 41},
  [1849] = {.lex_state = 371},
  [1850] = {.lex_state = 371},
  [1851] = {.lex_state = 41},
  [1852] = {.lex_state = 41},
  [1853] = {.lex_state = 371},
  [1854] = {.lex_state = 371},
  [1855] = {.lex_state = 371},
  [1856] = {.lex_state = 371},
  [1857] = {.lex_state = 371},
  [1858] = {.lex_state = 371},
  [1859] = {.lex_state = 371},
  [1860] = {.lex_state = 41},
  [1861] = {.lex_state = 41},
  [1862] = {.lex_state = 41},
  [1863] = {.lex_state = 41},
  [1864] = {.lex_state = 371},
  [1865] = {.lex_state = 371},
  [1866] = {.lex_state = 371},
  [1867] = {.lex_state = 371},
  [1868] = {.lex_state = 371},
  [1869] = {.lex_state = 41},
  [1870] = {.lex_state = 41},
  [1871] = {.lex_state = 371},
  [1872] = {.lex_state = 371},
  [1873] = {.lex_state = 41},
  [1874] = {.lex_state = 371},
  [1875] = {.lex_state = 371},
  [1876] = {.lex_state = 371},
  [1877] = {.lex_state = 371},
  [1878] = {.lex_state = 371},
  [1879] = {.lex_state = 371},
  [1880] = {.lex_state = 41},
  [1881] = {.lex_state = 41},
  [1882] = {.lex_state = 41},
  [1883] = {.lex_state = 371},
  [1884] = {.lex_state = 371},
  [1885] = {.lex_state = 371},
  [1886] = {.lex_state = 41},
  [1887] = {.lex_state = 371},
  [1888] = {.lex_state = 371},
  [1889] = {.lex_state = 41},
  [1890] = {.lex_state = 371},
  [1891] = {.lex_state = 41},
  [1892] = {.lex_state = 41},
  [1893] = {.lex_state = 41},
  [1894] = {.lex_state = 41},
  [1895] = {.lex_state = 371},
  [1896] = {.lex_state = 371},
  [1897] = {.lex_state = 371},
  [1898] = {.lex_state = 371},
  [1899] = {.lex_state = 371},
  [1900] = {.lex_state = 371},
  [1901] = {.lex_state = 371},
  [1902] = {.lex_state = 371},
  [1903] = {.lex_state = 371},
  [1904] = {.lex_state = 371},
  [1905] = {.lex_state = 371},
  [1906] = {.lex_state = 371},
  [1907] = {.lex_state = 371},
  [1908] = {.lex_state = 371},
  [1909] = {.lex_state = 371},
  [1910] = {.lex_state = 371},
  [1911] = {.lex_state = 371},
  [1912] = {.lex_state = 371},
  [1913] = {.lex_state = 371},
  [1914] = {.lex_state = 371},
  [1915] = {.lex_state = 371},
  [1916] = {.lex_state = 371},
  [1917] = {.lex_state = 371},
  [1918] = {.lex_state = 371},
  [1919] = {.lex_state = 371},
  [1920] = {.lex_state = 371},
  [1921] = {.lex_state = 371},
  [1922] = {.lex_state = 371},
  [1923] = {.lex_state = 371},
  [1924] = {.lex_state = 371},
  [1925] = {.lex_state = 371},
  [1926] = {.lex_state = 371},
  [1927] = {.lex_state = 371},
  [1928] = {.lex_state = 371},
  [1929] = {.lex_state = 371},
  [1930] = {.lex_state = 371},
  [1931] = {.lex_state = 371},
  [1932] = {.lex_state = 371},
  [1933] = {.lex_state = 371},
  [1934] = {.lex_state = 371},
  [1935] = {.lex_state = 371},
  [1936] = {.lex_state = 371},
  [1937] = {.lex_state = 371},
  [1938] = {.lex_state = 371},
  [1939] = {.lex_state = 371},
  [1940] = {.lex_state = 371},
  [1941] = {.lex_state = 371},
  [1942] = {.lex_state = 371},
  [1943] = {.lex_state = 371},
  [1944] = {.lex_state = 371},
  [1945] = {.lex_state = 371},
  [1946] = {.lex_state = 371},
  [1947] = {.lex_state = 371},
  [1948] = {.lex_state = 371},
  [1949] = {.lex_state = 371},
  [1950] = {.lex_state = 371},
  [1951] = {.lex_state = 371},
  [1952] = {.lex_state = 371},
  [1953] = {.lex_state = 371},
  [1954] = {.lex_state = 371},
  [1955] = {.lex_state = 371},
  [1956] = {.lex_state = 371},
  [1957] = {.lex_state = 371},
  [1958] = {.lex_state = 371},
  [1959] = {.lex_state = 371},
  [1960] = {.lex_state = 371},
  [1961] = {.lex_state = 371},
  [1962] = {.lex_state = 371},
  [1963] = {.lex_state = 371},
  [1964] = {.lex_state = 41},
  [1965] = {.lex_state = 371},
  [1966] = {.lex_state = 41},
  [1967] = {.lex_state = 371},
  [1968] = {.lex_state = 371},
  [1969] = {.lex_state = 371},
  [1970] = {.lex_state = 371},
  [1971] = {.lex_state = 371},
  [1972] = {.lex_state = 371},
  [1973] = {.lex_state = 371},
  [1974] = {.lex_state = 371},
  [1975] = {.lex_state = 371},
  [1976] = {.lex_state = 371},
  [1977] = {.lex_state = 371},
  [1978] = {.lex_state = 371},
  [1979] = {.lex_state = 371},
  [1980] = {.lex_state = 371},
  [1981] = {.lex_state = 41},
  [1982] = {.lex_state = 371},
  [1983] = {.lex_state = 371},
  [1984] = {.lex_state = 371},
  [1985] = {.lex_state = 371},
  [1986] = {.lex_state = 41},
  [1987] = {.lex_state = 371},
  [1988] = {.lex_state = 371},
  [1989] = {.lex_state = 371},
  [1990] = {.lex_state = 371},
  [1991] = {.lex_state = 371},
  [1992] = {.lex_state = 371},
  [1993] = {.lex_state = 371},
  [1994] = {.lex_state = 371},
  [1995] = {.lex_state = 371},
  [1996] = {.lex_state = 371},
  [1997] = {.lex_state = 371},
  [1998] = {.lex_state = 371},
  [1999] = {.lex_state = 371},
  [2000] = {.lex_state = 371},
  [2001] = {.lex_state = 371},
  [2002] = {.lex_state = 371},
  [2003] = {.lex_state = 371},
  [2004] = {.lex_state = 371},
  [2005] = {.lex_state = 371},
  [2006] = {.lex_state = 371},
  [2007] = {.lex_state = 371},
  [2008] = {.lex_state = 371},
  [2009] = {.lex_state = 41},
  [2010] = {.lex_state = 371},
  [2011] = {.lex_state = 371},
  [2012] = {.lex_state = 371},
  [2013] = {.lex_state = 371},
  [2014] = {.lex_state = 371},
  [2015] = {.lex_state = 371},
  [2016] = {.lex_state = 371},
  [2017] = {.lex_state = 371},
  [2018] = {.lex_state = 50},
  [2019] = {.lex_state = 371},
  [2020] = {.lex_state = 371},
  [2021] = {.lex_state = 371},
  [2022] = {.lex_state = 371},
  [2023] = {.lex_state = 371},
  [2024] = {.lex_state = 371},
  [2025] = {.lex_state = 371},
  [2026] = {.lex_state = 371},
  [2027] = {.lex_state = 371},
  [2028] = {.lex_state = 371},
  [2029] = {.lex_state = 371},
  [2030] = {.lex_state = 371},
  [2031] = {.lex_state = 371},
  [2032] = {.lex_state = 371},
  [2033] = {.lex_state = 371},
  [2034] = {.lex_state = 371},
  [2035] = {.lex_state = 371},
  [2036] = {.lex_state = 371},
  [2037] = {.lex_state = 371},
  [2038] = {.lex_state = 41},
  [2039] = {.lex_state = 50},
  [2040] = {.lex_state = 50},
  [2041] = {.lex_state = 50},
  [2042] = {.lex_state = 50},
  [2043] = {.lex_state = 50},
  [2044] = {.lex_state = 41},
  [2045] = {.lex_state = 41},
  [2046] = {.lex_state = 41},
  [2047] = {.lex_state = 41},
  [2048] = {.lex_state = 41},
  [2049] = {.lex_state = 50},
  [2050] = {.lex_state = 50},
  [2051] = {.lex_state = 41},
  [2052] = {.lex_state = 41},
  [2053] = {.lex_state = 50},
  [2054] = {.lex_state = 50},
  [2055] = {.lex_state = 41},
  [2056] = {.lex_state = 41},
  [2057] = {.lex_state = 50},
  [2058] = {.lex_state = 41},
  [2059] = {.lex_state = 41},
  [2060] = {.lex_state = 50},
  [2061] = {.lex_state = 41},
  [2062] = {.lex_state = 41},
  [2063] = {.lex_state = 50},
  [2064] = {.lex_state = 41},
  [2065] = {.lex_state = 50},
  [2066] = {.lex_state = 41},
  [2067] = {.lex_state = 41},
  [2068] = {.lex_state = 41},
  [2069] = {.lex_state = 41},
  [2070] = {.lex_state = 41},
  [2071] = {.lex_state = 41},
  [2072] = {.lex_state = 41},
  [2073] = {.lex_state = 41},
  [2074] = {.lex_state = 41},
  [2075] = {.lex_state = 50},
  [2076] = {.lex_state = 50},
  [2077] = {.lex_state = 41},
  [2078] = {.lex_state = 50},
  [2079] = {.lex_state = 50},
  [2080] = {.lex_state = 41},
  [2081] = {.lex_state = 41},
  [2082] = {.lex_state = 50},
  [2083] = {.lex_state = 41},
  [2084] = {.lex_state = 50},
  [2085] = {.lex_state = 41},
  [2086] = {.lex_state = 50},
  [2087] = {.lex_state = 50},
  [2088] = {.lex_state = 41},
  [2089] = {.lex_state = 50},
  [2090] = {.lex_state = 50},
  [2091] = {.lex_state = 41},
  [2092] = {.lex_state = 50},
  [2093] = {.lex_state = 41},
  [2094] = {.lex_state = 41},
  [2095] = {.lex_state = 50},
  [2096] = {.lex_state = 41},
  [2097] = {.lex_state = 50},
  [2098] = {.lex_state = 50},
  [2099] = {.lex_state = 41},
  [2100] = {.lex_state = 41},
  [2101] = {.lex_state = 50},
  [2102] = {.lex_state = 50},
  [2103] = {.lex_state = 50},
  [2104] = {.lex_state = 41},
  [2105] = {.lex_state = 50},
  [2106] = {.lex_state = 50},
  [2107] = {.lex_state = 41},
  [2108] = {.lex_state = 50},
  [2109] = {.lex_state = 41},
  [2110] = {.lex_state = 41},
  [2111] = {.lex_state = 41},
  [2112] = {.lex_state = 41},
  [2113] = {.lex_state = 41},
  [2114] = {.lex_state = 41},
  [2115] = {.lex_state = 41},
  [2116] = {.lex_state = 41},
  [2117] = {.lex_state = 41},
  [2118] = {.lex_state = 41},
  [2119] = {.lex_state = 41},
  [2120] = {.lex_state = 41},
  [2121] = {.lex_state = 41},
  [2122] = {.lex_state = 41},
  [2123] = {.lex_state = 41},
  [2124] = {.lex_state = 41},
  [2125] = {.lex_state = 41},
  [2126] = {.lex_state = 41},
  [2127] = {.lex_state = 41},
  [2128] = {.lex_state = 41},
  [2129] = {.lex_state = 41},
  [2130] = {.lex_state = 41},
  [2131] = {.lex_state = 41},
  [2132] = {.lex_state = 41},
  [2133] = {.lex_state = 41},
  [2134] = {.lex_state = 41},
  [2135] = {.lex_state = 41},
  [2136] = {.lex_state = 41},
  [2137] = {.lex_state = 41},
  [2138] = {.lex_state = 41},
  [2139] = {.lex_state = 41},
  [2140] = {.lex_state = 41},
  [2141] = {.lex_state = 41},
  [2142] = {.lex_state = 41},
  [2143] = {.lex_state = 41},
  [2144] = {.lex_state = 41},
  [2145] = {.lex_state = 41},
  [2146] = {.lex_state = 41},
  [2147] = {.lex_state = 41},
  [2148] = {.lex_state = 41},
  [2149] = {.lex_state = 41},
  [2150] = {.lex_state = 41},
  [2151] = {.lex_state = 41},
  [2152] = {.lex_state = 41},
  [2153] = {.lex_state = 41},
  [2154] = {.lex_state = 41},
  [2155] = {.lex_state = 41},
  [2156] = {.lex_state = 41},
  [2157] = {.lex_state = 41},
  [2158] = {.lex_state = 41},
  [2159] = {.lex_state = 41},
  [2160] = {.lex_state = 41},
  [2161] = {.lex_state = 41},
  [2162] = {.lex_state = 41},
  [2163] = {.lex_state = 41},
  [2164] = {.lex_state = 41},
  [2165] = {.lex_state = 41},
  [2166] = {.lex_state = 41},
  [2167] = {.lex_state = 41},
  [2168] = {.lex_state = 41},
  [2169] = {.lex_state = 41},
  [2170] = {.lex_state = 41},
  [2171] = {.lex_state = 41},
  [2172] = {.lex_state = 41},
  [2173] = {.lex_state = 41},
  [2174] = {.lex_state = 41},
  [2175] = {.lex_state = 41},
  [2176] = {.lex_state = 41},
  [2177] = {.lex_state = 41},
  [2178] = {.lex_state = 41},
  [2179] = {.lex_state = 41},
  [2180] = {.lex_state = 41},
  [2181] = {.lex_state = 41},
  [2182] = {.lex_state = 41},
  [2183] = {.lex_state = 41},
  [2184] = {.lex_state = 41},
  [2185] = {.lex_state = 41},
  [2186] = {.lex_state = 41},
  [2187] = {.lex_state = 41},
  [2188] = {.lex_state = 42},
  [2189] = {.lex_state = 41},
  [2190] = {.lex_state = 41},
  [2191] = {.lex_state = 41},
  [2192] = {.lex_state = 41},
  [2193] = {.lex_state = 41},
  [2194] = {.lex_state = 41},
  [2195] = {.lex_state = 41},
  [2196] = {.lex_state = 41},
  [2197] = {.lex_state = 41},
  [2198] = {.lex_state = 50},
  [2199] = {.lex_state = 50},
  [2200] = {.lex_state = 50},
  [2201] = {.lex_state = 50},
  [2202] = {.lex_state = 41},
  [2203] = {.lex_state = 50},
  [2204] = {.lex_state = 50},
  [2205] = {.lex_state = 41},
  [2206] = {.lex_state = 41},
  [2207] = {.lex_state = 41},
  [2208] = {.lex_state = 50},
  [2209] = {.lex_state = 50},
  [2210] = {.lex_state = 50},
  [2211] = {.lex_state = 41},
  [2212] = {.lex_state = 50},
  [2213] = {.lex_state = 50},
  [2214] = {.lex_state = 50},
  [2215] = {.lex_state = 50},
  [2216] = {.lex_state = 50},
  [2217] = {.lex_state = 50},
  [2218] = {.lex_state = 50},
  [2219] = {.lex_state = 41},
  [2220] = {.lex_state = 50},
  [2221] = {.lex_state = 41},
  [2222] = {.lex_state = 50},
  [2223] = {.lex_state = 50},
  [2224] = {.lex_state = 50},
  [2225] = {.lex_state = 50},
  [2226] = {.lex_state = 41},
  [2227] = {.lex_state = 50},
  [2228] = {.lex_state = 50},
  [2229] = {.lex_state = 50},
  [2230] = {.lex_state = 50},
  [2231] = {.lex_state = 41},
  [2232] = {.lex_state = 50},
  [2233] = {.lex_state = 41},
  [2234] = {.lex_state = 50},
  [2235] = {.lex_state = 50},
  [2236] = {.lex_state = 41},
  [2237] = {.lex_state = 50},
  [2238] = {.lex_state = 50},
  [2239] = {.lex_state = 50},
  [2240] = {.lex_state = 41},
  [2241] = {.lex_state = 41},
  [2242] = {.lex_state = 50},
  [2243] = {.lex_state = 50},
  [2244] = {.lex_state = 50},
  [2245] = {.lex_state = 50},
  [2246] = {.lex_state = 50},
  [2247] = {.lex_state = 41},
  [2248] = {.lex_state = 50},
  [2249] = {.lex_state = 50},
  [2250] = {.lex_state = 50},
  [2251] = {.lex_state = 50},
  [2252] = {.lex_state = 41},
  [2253] = {.lex_state = 50},
  [2254] = {.lex_state = 50},
  [2255] = {.lex_state = 50},
  [2256] = {.lex_state = 50},
  [2257] = {.lex_state = 41},
  [2258] = {.lex_state = 50},
  [2259] = {.lex_state = 50},
  [2260] = {.lex_state = 50},
  [2261] = {.lex_state = 50},
  [2262] = {.lex_state = 50},
  [2263] = {.lex_state = 50},
  [2264] = {.lex_state = 50},
  [2265] = {.lex_state = 50},
  [2266] = {.lex_state = 50},
  [2267] = {.lex_state = 50},
  [2268] = {.lex_state = 50},
  [2269] = {.lex_state = 50},
  [2270] = {.lex_state = 50},
  [2271] = {.lex_state = 50},
  [2272] = {.lex_state = 50},
  [2273] = {.lex_state = 50},
  [2274] = {.lex_state = 50},
  [2275] = {.lex_state = 41},
  [2276] = {.lex_state = 50},
  [2277] = {.lex_state = 50},
  [2278] = {.lex_state = 50},
  [2279] = {.lex_state = 50},
  [2280] = {.lex_state = 50},
  [2281] = {.lex_state = 50},
  [2282] = {.lex_state = 41},
  [2283] = {.lex_state = 50},
  [2284] = {.lex_state = 50},
  [2285] = {.lex_state = 50},
  [2286] = {.lex_state = 50},
  [2287] = {.lex_state = 50},
  [2288] = {.lex_state = 41},
  [2289] = {.lex_state = 41},
  [2290] = {.lex_state = 50},
  [2291] = {.lex_state = 50},
  [2292] = {.lex_state = 42},
  [2293] = {.lex_state = 50},
  [2294] = {.lex_state = 50},
  [2295] = {.lex_state = 50},
  [2296] = {.lex_state = 50},
  [2297] = {.lex_state = 41},
  [2298] = {.lex_state = 41},
  [2299] = {.lex_state = 50},
  [2300] = {.lex_state = 50},
  [2301] = {.lex_state = 50},
  [2302] = {.lex_state = 50},
  [2303] = {.lex_state = 50},
  [2304] = {.lex_state = 41},
  [2305] = {.lex_state = 41},
  [2306] = {.lex_state = 41},
  [2307] = {.lex_state = 41},
  [2308] = {.lex_state = 50},
  [2309] = {.lex_state = 50},
  [2310] = {.lex_state = 50},
  [2311] = {.lex_state = 41},
  [2312] = {.lex_state = 50},
  [2313] = {.lex_state = 50},
  [2314] = {.lex_state = 41},
  [2315] = {.lex_state = 50},
  [2316] = {.lex_state = 50},
  [2317] = {.lex_state = 50},
  [2318] = {.lex_state = 50},
  [2319] = {.lex_state = 50},
  [2320] = {.lex_state = 50},
  [2321] = {.lex_state = 50},
  [2322] = {.lex_state = 50},
  [2323] = {.lex_state = 50},
  [2324] = {.lex_state = 50},
  [2325] = {.lex_state = 50},
  [2326] = {.lex_state = 50},
  [2327] = {.lex_state = 50},
  [2328] = {.lex_state = 373},
  [2329] = {.lex_state = 41},
  [2330] = {.lex_state = 50},
  [2331] = {.lex_state = 50},
  [2332] = {.lex_state = 50},
  [2333] = {.lex_state = 50},
  [2334] = {.lex_state = 41},
  [2335] = {.lex_state = 50},
  [2336] = {.lex_state = 50},
  [2337] = {.lex_state = 41},
  [2338] = {.lex_state = 50},
  [2339] = {.lex_state = 41},
  [2340] = {.lex_state = 50},
  [2341] = {.lex_state = 50},
  [2342] = {.lex_state = 50},
  [2343] = {.lex_state = 50},
  [2344] = {.lex_state = 50},
  [2345] = {.lex_state = 50},
  [2346] = {.lex_state = 50},
  [2347] = {.lex_state = 50},
  [2348] = {.lex_state = 50},
  [2349] = {.lex_state = 50},
  [2350] = {.lex_state = 50},
  [2351] = {.lex_state = 50},
  [2352] = {.lex_state = 50},
  [2353] = {.lex_state = 50},
  [2354] = {.lex_state = 50},
  [2355] = {.lex_state = 50},
  [2356] = {.lex_state = 50},
  [2357] = {.lex_state = 50},
  [2358] = {.lex_state = 50},
  [2359] = {.lex_state = 50},
  [2360] = {.lex_state = 50},
  [2361] = {.lex_state = 50},
  [2362] = {.lex_state = 50},
  [2363] = {.lex_state = 50},
  [2364] = {.lex_state = 50},
  [2365] = {.lex_state = 50},
  [2366] = {.lex_state = 50},
  [2367] = {.lex_state = 41},
  [2368] = {.lex_state = 50},
  [2369] = {.lex_state = 50},
  [2370] = {.lex_state = 50},
  [2371] = {.lex_state = 50},
  [2372] = {.lex_state = 41},
  [2373] = {.lex_state = 50},
  [2374] = {.lex_state = 50},
  [2375] = {.lex_state = 50},
  [2376] = {.lex_state = 41},
  [2377] = {.lex_state = 50},
  [2378] = {.lex_state = 50},
  [2379] = {.lex_state = 50},
  [2380] = {.lex_state = 50},
  [2381] = {.lex_state = 50},
  [2382] = {.lex_state = 50},
  [2383] = {.lex_state = 50},
  [2384] = {.lex_state = 50},
  [2385] = {.lex_state = 50},
  [2386] = {.lex_state = 50},
  [2387] = {.lex_state = 41},
  [2388] = {.lex_state = 50},
  [2389] = {.lex_state = 50},
  [2390] = {.lex_state = 50},
  [2391] = {.lex_state = 50},
  [2392] = {.lex_state = 50},
  [2393] = {.lex_state = 50},
  [2394] = {.lex_state = 50},
  [2395] = {.lex_state = 50},
  [2396] = {.lex_state = 50},
  [2397] = {.lex_state = 50},
  [2398] = {.lex_state = 50},
  [2399] = {.lex_state = 50},
  [2400] = {.lex_state = 50},
  [2401] = {.lex_state = 50},
  [2402] = {.lex_state = 50},
  [2403] = {.lex_state = 50},
  [2404] = {.lex_state = 50},
  [2405] = {.lex_state = 50},
  [2406] = {.lex_state = 41},
  [2407] = {.lex_state = 50},
  [2408] = {.lex_state = 50},
  [2409] = {.lex_state = 50},
  [2410] = {.lex_state = 50},
  [2411] = {.lex_state = 41},
  [2412] = {.lex_state = 41},
  [2413] = {.lex_state = 50},
  [2414] = {.lex_state = 50},
  [2415] = {.lex_state = 50},
  [2416] = {.lex_state = 41},
  [2417] = {.lex_state = 50},
  [2418] = {.lex_state = 50},
  [2419] = {.lex_state = 50},
  [2420] = {.lex_state = 50},
  [2421] = {.lex_state = 50},
  [2422] = {.lex_state = 50},
  [2423] = {.lex_state = 50},
  [2424] = {.lex_state = 50},
  [2425] = {.lex_state = 50},
  [2426] = {.lex_state = 50},
  [2427] = {.lex_state = 50},
  [2428] = {.lex_state = 50},
  [2429] = {.lex_state = 50},
  [2430] = {.lex_state = 50},
  [2431] = {.lex_state = 50},
  [2432] = {.lex_state = 50},
  [2433] = {.lex_state = 50},
  [2434] = {.lex_state = 50},
  [2435] = {.lex_state = 50},
  [2436] = {.lex_state = 50},
  [2437] = {.lex_state = 50},
  [2438] = {.lex_state = 50},
  [2439] = {.lex_state = 50},
  [2440] = {.lex_state = 50},
  [2441] = {.lex_state = 50},
  [2442] = {.lex_state = 50},
  [2443] = {.lex_state = 50},
  [2444] = {.lex_state = 50},
  [2445] = {.lex_state = 41},
  [2446] = {.lex_state = 41},
  [2447] = {.lex_state = 41},
  [2448] = {.lex_state = 41},
  [2449] = {.lex_state = 41},
  [2450] = {.lex_state = 41},
  [2451] = {.lex_state = 41},
  [2452] = {.lex_state = 41},
  [2453] = {.lex_state = 41},
  [2454] = {.lex_state = 41},
  [2455] = {.lex_state = 41},
  [2456] = {.lex_state = 41},
  [2457] = {.lex_state = 41},
  [2458] = {.lex_state = 41},
  [2459] = {.lex_state = 41},
  [2460] = {.lex_state = 41},
  [2461] = {.lex_state = 41},
  [2462] = {.lex_state = 41},
  [2463] = {.lex_state = 41},
  [2464] = {.lex_state = 41},
  [2465] = {.lex_state = 41},
  [2466] = {.lex_state = 41},
  [2467] = {.lex_state = 41},
  [2468] = {.lex_state = 41},
  [2469] = {.lex_state = 41},
  [2470] = {.lex_state = 41},
  [2471] = {.lex_state = 41},
  [2472] = {.lex_state = 41},
  [2473] = {.lex_state = 41},
  [2474] = {.lex_state = 41},
  [2475] = {.lex_state = 41},
  [2476] = {.lex_state = 41},
  [2477] = {.lex_state = 41},
  [2478] = {.lex_state = 50},
  [2479] = {.lex_state = 41},
  [2480] = {.lex_state = 41},
  [2481] = {.lex_state = 41},
  [2482] = {.lex_state = 41},
  [2483] = {.lex_state = 41},
  [2484] = {.lex_state = 41},
  [2485] = {.lex_state = 41},
  [2486] = {.lex_state = 41},
  [2487] = {.lex_state = 41},
  [2488] = {.lex_state = 41},
  [2489] = {.lex_state = 41},
  [2490] = {.lex_state = 41},
  [2491] = {.lex_state = 41},
  [2492] = {.lex_state = 41},
  [2493] = {.lex_state = 41},
  [2494] = {.lex_state = 41},
  [2495] = {.lex_state = 41},
  [2496] = {.lex_state = 41},
  [2497] = {.lex_state = 41},
  [2498] = {.lex_state = 50},
  [2499] = {.lex_state = 41},
  [2500] = {.lex_state = 41},
  [2501] = {.lex_state = 41},
  [2502] = {.lex_state = 41},
  [2503] = {.lex_state = 41},
  [2504] = {.lex_state = 41},
  [2505] = {.lex_state = 41},
  [2506] = {.lex_state = 41},
  [2507] = {.lex_state = 41},
  [2508] = {.lex_state = 41},
  [2509] = {.lex_state = 41},
  [2510] = {.lex_state = 41},
  [2511] = {.lex_state = 41},
  [2512] = {.lex_state = 41},
  [2513] = {.lex_state = 41},
  [2514] = {.lex_state = 41},
  [2515] = {.lex_state = 41},
  [2516] = {.lex_state = 41},
  [2517] = {.lex_state = 41},
  [2518] = {.lex_state = 41},
  [2519] = {.lex_state = 41},
  [2520] = {.lex_state = 41},
  [2521] = {.lex_state = 41},
  [2522] = {.lex_state = 41},
  [2523] = {.lex_state = 41},
  [2524] = {.lex_state = 41},
  [2525] = {.lex_state = 41},
  [2526] = {.lex_state = 41},
  [2527] = {.lex_state = 41},
  [2528] = {.lex_state = 41},
  [2529] = {.lex_state = 41},
  [2530] = {.lex_state = 41},
  [2531] = {.lex_state = 41},
  [2532] = {.lex_state = 41},
  [2533] = {.lex_state = 41},
  [2534] = {.lex_state = 41},
  [2535] = {.lex_state = 41},
  [2536] = {.lex_state = 41},
  [2537] = {.lex_state = 41},
  [2538] = {.lex_state = 41},
  [2539] = {.lex_state = 41},
  [2540] = {.lex_state = 41},
  [2541] = {.lex_state = 41},
  [2542] = {.lex_state = 41},
  [2543] = {.lex_state = 41},
  [2544] = {.lex_state = 41},
  [2545] = {.lex_state = 41},
  [2546] = {.lex_state = 41},
  [2547] = {.lex_state = 41},
  [2548] = {.lex_state = 41},
  [2549] = {.lex_state = 41},
  [2550] = {.lex_state = 41},
  [2551] = {.lex_state = 41},
  [2552] = {.lex_state = 41},
  [2553] = {.lex_state = 41},
  [2554] = {.lex_state = 41},
  [2555] = {.lex_state = 41},
  [2556] = {.lex_state = 41},
  [2557] = {.lex_state = 41},
  [2558] = {.lex_state = 50},
  [2559] = {.lex_state = 50},
  [2560] = {.lex_state = 50},
  [2561] = {.lex_state = 50},
  [2562] = {.lex_state = 50},
  [2563] = {.lex_state = 50},
  [2564] = {.lex_state = 50},
  [2565] = {.lex_state = 50},
  [2566] = {.lex_state = 50},
  [2567] = {.lex_state = 50},
  [2568] = {.lex_state = 50},
  [2569] = {.lex_state = 50},
  [2570] = {.lex_state = 50},
  [2571] = {.lex_state = 50},
  [2572] = {.lex_state = 50},
  [2573] = {.lex_state = 50},
  [2574] = {.lex_state = 50},
  [2575] = {.lex_state = 50},
  [2576] = {.lex_state = 50},
  [2577] = {.lex_state = 50},
  [2578] = {.lex_state = 50},
  [2579] = {.lex_state = 50},
  [2580] = {.lex_state = 50},
  [2581] = {.lex_state = 50},
  [2582] = {.lex_state = 50},
  [2583] = {.lex_state = 50},
  [2584] = {.lex_state = 50},
  [2585] = {.lex_state = 50},
  [2586] = {.lex_state = 50},
  [2587] = {.lex_state = 50},
  [2588] = {.lex_state = 50},
  [2589] = {.lex_state = 50},
  [2590] = {.lex_state = 50},
  [2591] = {.lex_state = 50},
  [2592] = {.lex_state = 41},
  [2593] = {.lex_state = 50},
  [2594] = {.lex_state = 50},
  [2595] = {.lex_state = 50},
  [2596] = {.lex_state = 42},
  [2597] = {.lex_state = 42},
  [2598] = {.lex_state = 42},
  [2599] = {.lex_state = 42},
  [2600] = {.lex_state = 42},
  [2601] = {.lex_state = 42},
  [2602] = {.lex_state = 42},
  [2603] = {.lex_state = 42},
  [2604] = {.lex_state = 42},
  [2605] = {.lex_state = 42},
  [2606] = {.lex_state = 42},
  [2607] = {.lex_state = 42},
  [2608] = {.lex_state = 41},
  [2609] = {.lex_state = 50},
  [2610] = {.lex_state = 50},
  [2611] = {.lex_state = 50},
  [2612] = {.lex_state = 50},
  [2613] = {.lex_state = 50},
  [2614] = {.lex_state = 50},
  [2615] = {.lex_state = 41},
  [2616] = {.lex_state = 50},
  [2617] = {.lex_state = 42},
  [2618] = {.lex_state = 50},
  [2619] = {.lex_state = 41},
  [2620] = {.lex_state = 42},
  [2621] = {.lex_state = 41},
  [2622] = {.lex_state = 42},
  [2623] = {.lex_state = 42},
  [2624] = {.lex_state = 42},
  [2625] = {.lex_state = 42},
  [2626] = {.lex_state = 42},
  [2627] = {.lex_state = 42},
  [2628] = {.lex_state = 42},
  [2629] = {.lex_state = 42},
  [2630] = {.lex_state = 42},
  [2631] = {.lex_state = 42},
  [2632] = {.lex_state = 42},
  [2633] = {.lex_state = 42},
  [2634] = {.lex_state = 42},
  [2635] = {.lex_state = 41},
  [2636] = {.lex_state = 42},
  [2637] = {.lex_state = 50},
  [2638] = {.lex_state = 50},
  [2639] = {.lex_state = 371},
  [2640] = {.lex_state = 41},
  [2641] = {.lex_state = 50},
  [2642] = {.lex_state = 41},
  [2643] = {.lex_state = 42},
  [2644] = {.lex_state = 41},
  [2645] = {.lex_state = 42},
  [2646] = {.lex_state = 42},
  [2647] = {.lex_state = 42},
  [2648] = {.lex_state = 42},
  [2649] = {.lex_state = 42},
  [2650] = {.lex_state = 42},
  [2651] = {.lex_state = 42},
  [2652] = {.lex_state = 50},
  [2653] = {.lex_state = 42},
  [2654] = {.lex_state = 50},
  [2655] = {.lex_state = 42},
  [2656] = {.lex_state = 50},
  [2657] = {.lex_state = 41},
  [2658] = {.lex_state = 50},
  [2659] = {.lex_state = 41},
  [2660] = {.lex_state = 42},
  [2661] = {.lex_state = 42},
  [2662] = {.lex_state = 50},
  [2663] = {.lex_state = 42},
  [2664] = {.lex_state = 42},
  [2665] = {.lex_state = 42},
  [2666] = {.lex_state = 42},
  [2667] = {.lex_state = 42},
  [2668] = {.lex_state = 42},
  [2669] = {.lex_state = 42},
  [2670] = {.lex_state = 42},
  [2671] = {.lex_state = 50},
  [2672] = {.lex_state = 42},
  [2673] = {.lex_state = 50},
  [2674] = {.lex_state = 42},
  [2675] = {.lex_state = 50},
  [2676] = {.lex_state = 42},
  [2677] = {.lex_state = 42},
  [2678] = {.lex_state = 42},
  [2679] = {.lex_state = 42},
  [2680] = {.lex_state = 42},
  [2681] = {.lex_state = 42},
  [2682] = {.lex_state = 42},
  [2683] = {.lex_state = 42},
  [2684] = {.lex_state = 41},
  [2685] = {.lex_state = 42},
  [2686] = {.lex_state = 50},
  [2687] = {.lex_state = 50},
  [2688] = {.lex_state = 50},
  [2689] = {.lex_state = 50},
  [2690] = {.lex_state = 50},
  [2691] = {.lex_state = 50},
  [2692] = {.lex_state = 41},
  [2693] = {.lex_state = 42},
  [2694] = {.lex_state = 50},
  [2695] = {.lex_state = 50},
  [2696] = {.lex_state = 50},
  [2697] = {.lex_state = 50},
  [2698] = {.lex_state = 50},
  [2699] = {.lex_state = 50},
  [2700] = {.lex_state = 42},
  [2701] = {.lex_state = 50},
  [2702] = {.lex_state = 42},
  [2703] = {.lex_state = 42},
  [2704] = {.lex_state = 42},
  [2705] = {.lex_state = 42},
  [2706] = {.lex_state = 42},
  [2707] = {.lex_state = 50},
  [2708] = {.lex_state = 42},
  [2709] = {.lex_state = 42},
  [2710] = {.lex_state = 42},
  [2711] = {.lex_state = 42},
  [2712] = {.lex_state = 42},
  [2713] = {.lex_state = 42},
  [2714] = {.lex_state = 42},
  [2715] = {.lex_state = 50},
  [2716] = {.lex_state = 50},
  [2717] = {.lex_state = 50},
  [2718] = {.lex_state = 50},
  [2719] = {.lex_state = 42},
  [2720] = {.lex_state = 41},
  [2721] = {.lex_state = 42},
  [2722] = {.lex_state = 41},
  [2723] = {.lex_state = 42},
  [2724] = {.lex_state = 42},
  [2725] = {.lex_state = 42},
  [2726] = {.lex_state = 50},
  [2727] = {.lex_state = 50},
  [2728] = {.lex_state = 41},
  [2729] = {.lex_state = 42},
  [2730] = {.lex_state = 42},
  [2731] = {.lex_state = 42},
  [2732] = {.lex_state = 42},
  [2733] = {.lex_state = 42},
  [2734] = {.lex_state = 42},
  [2735] = {.lex_state = 42},
  [2736] = {.lex_state = 42},
  [2737] = {.lex_state = 42},
  [2738] = {.lex_state = 42},
  [2739] = {.lex_state = 42},
  [2740] = {.lex_state = 42},
  [2741] = {.lex_state = 50},
  [2742] = {.lex_state = 42},
  [2743] = {.lex_state = 42},
  [2744] = {.lex_state = 42},
  [2745] = {.lex_state = 41},
  [2746] = {.lex_state = 50},
  [2747] = {.lex_state = 41},
  [2748] = {.lex_state = 41},
  [2749] = {.lex_state = 42},
  [2750] = {.lex_state = 42},
  [2751] = {.lex_state = 42},
  [2752] = {.lex_state = 42},
  [2753] = {.lex_state = 42},
  [2754] = {.lex_state = 50},
  [2755] = {.lex_state = 50},
  [2756] = {.lex_state = 50},
  [2757] = {.lex_state = 41},
  [2758] = {.lex_state = 42},
  [2759] = {.lex_state = 50},
  [2760] = {.lex_state = 50},
  [2761] = {.lex_state = 50},
  [2762] = {.lex_state = 50},
  [2763] = {.lex_state = 42},
  [2764] = {.lex_state = 50},
  [2765] = {.lex_state = 42},
  [2766] = {.lex_state = 42},
  [2767] = {.lex_state = 50},
  [2768] = {.lex_state = 42},
  [2769] = {.lex_state = 42},
  [2770] = {.lex_state = 42},
  [2771] = {.lex_state = 50},
  [2772] = {.lex_state = 42},
  [2773] = {.lex_state = 42},
  [2774] = {.lex_state = 42},
  [2775] = {.lex_state = 42},
  [2776] = {.lex_state = 42},
  [2777] = {.lex_state = 42},
  [2778] = {.lex_state = 50},
  [2779] = {.lex_state = 50},
  [2780] = {.lex_state = 50},
  [2781] = {.lex_state = 50},
  [2782] = {.lex_state = 42},
  [2783] = {.lex_state = 50},
  [2784] = {.lex_state = 50},
  [2785] = {.lex_state = 50},
  [2786] = {.lex_state = 41},
  [2787] = {.lex_state = 42},
  [2788] = {.lex_state = 42},
  [2789] = {.lex_state = 42},
  [2790] = {.lex_state = 50},
  [2791] = {.lex_state = 50},
  [2792] = {.lex_state = 42},
  [2793] = {.lex_state = 42},
  [2794] = {.lex_state = 42},
  [2795] = {.lex_state = 42},
  [2796] = {.lex_state = 42},
  [2797] = {.lex_state = 50},
  [2798] = {.lex_state = 42},
  [2799] = {.lex_state = 42},
  [2800] = {.lex_state = 42},
  [2801] = {.lex_state = 42},
  [2802] = {.lex_state = 42},
  [2803] = {.lex_state = 42},
  [2804] = {.lex_state = 41},
  [2805] = {.lex_state = 50},
  [2806] = {.lex_state = 50},
  [2807] = {.lex_state = 50},
  [2808] = {.lex_state = 50},
  [2809] = {.lex_state = 50},
  [2810] = {.lex_state = 41},
  [2811] = {.lex_state = 41},
  [2812] = {.lex_state = 42},
  [2813] = {.lex_state = 42},
  [2814] = {.lex_state = 42},
  [2815] = {.lex_state = 50},
  [2816] = {.lex_state = 50},
  [2817] = {.lex_state = 41},
  [2818] = {.lex_state = 50},
  [2819] = {.lex_state = 50},
  [2820] = {.lex_state = 50},
  [2821] = {.lex_state = 50},
  [2822] = {.lex_state = 50},
  [2823] = {.lex_state = 41},
  [2824] = {.lex_state = 50},
  [2825] = {.lex_state = 50},
  [2826] = {.lex_state = 50},
  [2827] = {.lex_state = 50},
  [2828] = {.lex_state = 50},
  [2829] = {.lex_state = 50},
  [2830] = {.lex_state = 50},
  [2831] = {.lex_state = 41},
  [2832] = {.lex_state = 41},
  [2833] = {.lex_state = 42},
  [2834] = {.lex_state = 50},
  [2835] = {.lex_state = 41},
  [2836] = {.lex_state = 42},
  [2837] = {.lex_state = 50},
  [2838] = {.lex_state = 50},
  [2839] = {.lex_state = 50},
  [2840] = {.lex_state = 41},
  [2841] = {.lex_state = 42},
  [2842] = {.lex_state = 42},
  [2843] = {.lex_state = 42},
  [2844] = {.lex_state = 42},
  [2845] = {.lex_state = 42},
  [2846] = {.lex_state = 50},
  [2847] = {.lex_state = 50},
  [2848] = {.lex_state = 41},
  [2849] = {.lex_state = 50},
  [2850] = {.lex_state = 42},
  [2851] = {.lex_state = 42},
  [2852] = {.lex_state = 42},
  [2853] = {.lex_state = 42},
  [2854] = {.lex_state = 42},
  [2855] = {.lex_state = 42},
  [2856] = {.lex_state = 50},
  [2857] = {.lex_state = 50},
  [2858] = {.lex_state = 50},
  [2859] = {.lex_state = 42},
  [2860] = {.lex_state = 42},
  [2861] = {.lex_state = 42},
  [2862] = {.lex_state = 42},
  [2863] = {.lex_state = 42},
  [2864] = {.lex_state = 50},
  [2865] = {.lex_state = 50},
  [2866] = {.lex_state = 50},
  [2867] = {.lex_state = 42},
  [2868] = {.lex_state = 42},
  [2869] = {.lex_state = 50},
  [2870] = {.lex_state = 41},
  [2871] = {.lex_state = 50},
  [2872] = {.lex_state = 42},
  [2873] = {.lex_state = 42},
  [2874] = {.lex_state = 50},
  [2875] = {.lex_state = 42},
  [2876] = {.lex_state = 50},
  [2877] = {.lex_state = 42},
  [2878] = {.lex_state = 41},
  [2879] = {.lex_state = 42},
  [2880] = {.lex_state = 50},
  [2881] = {.lex_state = 50},
  [2882] = {.lex_state = 50},
  [2883] = {.lex_state = 50},
  [2884] = {.lex_state = 41},
  [2885] = {.lex_state = 50},
  [2886] = {.lex_state = 41},
  [2887] = {.lex_state = 42},
  [2888] = {.lex_state = 42},
  [2889] = {.lex_state = 42},
  [2890] = {.lex_state = 50},
  [2891] = {.lex_state = 50},
  [2892] = {.lex_state = 41},
  [2893] = {.lex_state = 50},
  [2894] = {.lex_state = 50},
  [2895] = {.lex_state = 50},
  [2896] = {.lex_state = 50},
  [2897] = {.lex_state = 41},
  [2898] = {.lex_state = 50},
  [2899] = {.lex_state = 50},
  [2900] = {.lex_state = 41},
  [2901] = {.lex_state = 50},
  [2902] = {.lex_state = 50},
  [2903] = {.lex_state = 50},
  [2904] = {.lex_state = 50},
  [2905] = {.lex_state = 50},
  [2906] = {.lex_state = 50},
  [2907] = {.lex_state = 41},
  [2908] = {.lex_state = 50},
  [2909] = {.lex_state = 50},
  [2910] = {.lex_state = 50},
  [2911] = {.lex_state = 50},
  [2912] = {.lex_state = 50},
  [2913] = {.lex_state = 50},
  [2914] = {.lex_state = 50},
  [2915] = {.lex_state = 50},
  [2916] = {.lex_state = 50},
  [2917] = {.lex_state = 50},
  [2918] = {.lex_state = 50},
  [2919] = {.lex_state = 50},
  [2920] = {.lex_state = 50},
  [2921] = {.lex_state = 50},
  [2922] = {.lex_state = 50},
  [2923] = {.lex_state = 50},
  [2924] = {.lex_state = 50},
  [2925] = {.lex_state = 50},
  [2926] = {.lex_state = 41},
  [2927] = {.lex_state = 41},
  [2928] = {.lex_state = 42},
  [2929] = {.lex_state = 42},
  [2930] = {.lex_state = 50},
  [2931] = {.lex_state = 50},
  [2932] = {.lex_state = 50},
  [2933] = {.lex_state = 42},
  [2934] = {.lex_state = 50},
  [2935] = {.lex_state = 50},
  [2936] = {.lex_state = 50},
  [2937] = {.lex_state = 50},
  [2938] = {.lex_state = 50},
  [2939] = {.lex_state = 50},
  [2940] = {.lex_state = 41},
  [2941] = {.lex_state = 50},
  [2942] = {.lex_state = 50},
  [2943] = {.lex_state = 50},
  [2944] = {.lex_state = 50},
  [2945] = {.lex_state = 50},
  [2946] = {.lex_state = 50},
  [2947] = {.lex_state = 50},
  [2948] = {.lex_state = 41},
  [2949] = {.lex_state = 50},
  [2950] = {.lex_state = 41},
  [2951] = {.lex_state = 50},
  [2952] = {.lex_state = 41},
  [2953] = {.lex_state = 50},
  [2954] = {.lex_state = 50},
  [2955] = {.lex_state = 42},
  [2956] = {.lex_state = 50},
  [2957] = {.lex_state = 50},
  [2958] = {.lex_state = 50},
  [2959] = {.lex_state = 50},
  [2960] = {.lex_state = 50},
  [2961] = {.lex_state = 50},
  [2962] = {.lex_state = 41},
  [2963] = {.lex_state = 50},
  [2964] = {.lex_state = 41},
  [2965] = {.lex_state = 42},
  [2966] = {.lex_state = 50},
  [2967] = {.lex_state = 50},
  [2968] = {.lex_state = 50},
  [2969] = {.lex_state = 50},
  [2970] = {.lex_state = 50},
  [2971] = {.lex_state = 50},
  [2972] = {.lex_state = 50},
  [2973] = {.lex_state = 50},
  [2974] = {.lex_state = 50},
  [2975] = {.lex_state = 50},
  [2976] = {.lex_state = 50},
  [2977] = {.lex_state = 50},
  [2978] = {.lex_state = 42},
  [2979] = {.lex_state = 42},
  [2980] = {.lex_state = 50},
  [2981] = {.lex_state = 50},
  [2982] = {.lex_state = 50},
  [2983] = {.lex_state = 50},
  [2984] = {.lex_state = 42},
  [2985] = {.lex_state = 42},
  [2986] = {.lex_state = 50},
  [2987] = {.lex_state = 50},
  [2988] = {.lex_state = 50},
  [2989] = {.lex_state = 50},
  [2990] = {.lex_state = 42},
  [2991] = {.lex_state = 50},
  [2992] = {.lex_state = 50},
  [2993] = {.lex_state = 50},
  [2994] = {.lex_state = 50},
  [2995] = {.lex_state = 50},
  [2996] = {.lex_state = 41},
  [2997] = {.lex_state = 50},
  [2998] = {.lex_state = 50},
  [2999] = {.lex_state = 42},
  [3000] = {.lex_state = 42},
  [3001] = {.lex_state = 42},
  [3002] = {.lex_state = 42},
  [3003] = {.lex_state = 42},
  [3004] = {.lex_state = 42},
  [3005] = {.lex_state = 50},
  [3006] = {.lex_state = 50},
  [3007] = {.lex_state = 41},
  [3008] = {.lex_state = 42},
  [3009] = {.lex_state = 42},
  [3010] = {.lex_state = 42},
  [3011] = {.lex_state = 42},
  [3012] = {.lex_state = 42},
  [3013] = {.lex_state = 50},
  [3014] = {.lex_state = 42},
  [3015] = {.lex_state = 42},
  [3016] = {.lex_state = 42},
  [3017] = {.lex_state = 50},
  [3018] = {.lex_state = 41},
  [3019] = {.lex_state = 42},
  [3020] = {.lex_state = 42},
  [3021] = {.lex_state = 42},
  [3022] = {.lex_state = 42},
  [3023] = {.lex_state = 42},
  [3024] = {.lex_state = 42},
  [3025] = {.lex_state = 42},
  [3026] = {.lex_state = 42},
  [3027] = {.lex_state = 42},
  [3028] = {.lex_state = 42},
  [3029] = {.lex_state = 42},
  [3030] = {.lex_state = 42},
  [3031] = {.lex_state = 42},
  [3032] = {.lex_state = 42},
  [3033] = {.lex_state = 42},
  [3034] = {.lex_state = 42},
  [3035] = {.lex_state = 42},
  [3036] = {.lex_state = 42},
  [3037] = {.lex_state = 42},
  [3038] = {.lex_state = 42},
  [3039] = {.lex_state = 42},
  [3040] = {.lex_state = 42},
  [3041] = {.lex_state = 42},
  [3042] = {.lex_state = 42},
  [3043] = {.lex_state = 42},
  [3044] = {.lex_state = 42},
  [3045] = {.lex_state = 42},
  [3046] = {.lex_state = 42},
  [3047] = {.lex_state = 42},
  [3048] = {.lex_state = 42},
  [3049] = {.lex_state = 42},
  [3050] = {.lex_state = 42},
  [3051] = {.lex_state = 42},
  [3052] = {.lex_state = 42},
  [3053] = {.lex_state = 42},
  [3054] = {.lex_state = 42},
  [3055] = {.lex_state = 42},
  [3056] = {.lex_state = 42},
  [3057] = {.lex_state = 42},
  [3058] = {.lex_state = 42},
  [3059] = {.lex_state = 42},
  [3060] = {.lex_state = 42},
  [3061] = {.lex_state = 42},
  [3062] = {.lex_state = 42},
  [3063] = {.lex_state = 42},
  [3064] = {.lex_state = 42},
  [3065] = {.lex_state = 42},
  [3066] = {.lex_state = 42},
  [3067] = {.lex_state = 42},
  [3068] = {.lex_state = 42},
  [3069] = {.lex_state = 42},
  [3070] = {.lex_state = 42},
  [3071] = {.lex_state = 42},
  [3072] = {.lex_state = 42},
  [3073] = {.lex_state = 42},
  [3074] = {.lex_state = 42},
  [3075] = {.lex_state = 42},
  [3076] = {.lex_state = 42},
  [3077] = {.lex_state = 42},
  [3078] = {.lex_state = 42},
  [3079] = {.lex_state = 42},
  [3080] = {.lex_state = 42},
  [3081] = {.lex_state = 50},
  [3082] = {.lex_state = 50},
  [3083] = {.lex_state = 50},
  [3084] = {.lex_state = 42},
  [3085] = {.lex_state = 42},
  [3086] = {.lex_state = 42},
  [3087] = {.lex_state = 42},
  [3088] = {.lex_state = 42},
  [3089] = {.lex_state = 42},
  [3090] = {.lex_state = 42},
  [3091] = {.lex_state = 42},
  [3092] = {.lex_state = 42},
  [3093] = {.lex_state = 42},
  [3094] = {.lex_state = 42},
  [3095] = {.lex_state = 42},
  [3096] = {.lex_state = 42},
  [3097] = {.lex_state = 42},
  [3098] = {.lex_state = 42},
  [3099] = {.lex_state = 42},
  [3100] = {.lex_state = 42},
  [3101] = {.lex_state = 42},
  [3102] = {.lex_state = 42},
  [3103] = {.lex_state = 42},
  [3104] = {.lex_state = 50},
  [3105] = {.lex_state = 50},
  [3106] = {.lex_state = 50},
  [3107] = {.lex_state = 42},
  [3108] = {.lex_state = 50},
  [3109] = {.lex_state = 50},
  [3110] = {.lex_state = 50},
  [3111] = {.lex_state = 42},
  [3112] = {.lex_state = 41},
  [3113] = {.lex_state = 50},
  [3114] = {.lex_state = 50},
  [3115] = {.lex_state = 50},
  [3116] = {.lex_state = 50},
  [3117] = {.lex_state = 50},
  [3118] = {.lex_state = 50},
  [3119] = {.lex_state = 50},
  [3120] = {.lex_state = 50},
  [3121] = {.lex_state = 42},
  [3122] = {.lex_state = 50},
  [3123] = {.lex_state = 50},
  [3124] = {.lex_state = 50},
  [3125] = {.lex_state = 42},
  [3126] = {.lex_state = 50},
  [3127] = {.lex_state = 42},
  [3128] = {.lex_state = 50},
  [3129] = {.lex_state = 50},
  [3130] = {.lex_state = 50},
  [3131] = {.lex_state = 42},
  [3132] = {.lex_state = 50},
  [3133] = {.lex_state = 50},
  [3134] = {.lex_state = 50},
  [3135] = {.lex_state = 50},
  [3136] = {.lex_state = 42},
  [3137] = {.lex_state = 50},
  [3138] = {.lex_state = 42},
  [3139] = {.lex_state = 50},
  [3140] = {.lex_state = 50},
  [3141] = {.lex_state = 50},
  [3142] = {.lex_state = 50},
  [3143] = {.lex_state = 50},
  [3144] = {.lex_state = 50},
  [3145] = {.lex_state = 42},
  [3146] = {.lex_state = 50},
  [3147] = {.lex_state = 42},
  [3148] = {.lex_state = 50},
  [3149] = {.lex_state = 50},
  [3150] = {.lex_state = 50},
  [3151] = {.lex_state = 50},
  [3152] = {.lex_state = 42},
  [3153] = {.lex_state = 50},
  [3154] = {.lex_state = 42},
  [3155] = {.lex_state = 50},
  [3156] = {.lex_state = 50},
  [3157] = {.lex_state = 50},
  [3158] = {.lex_state = 50},
  [3159] = {.lex_state = 42},
  [3160] = {.lex_state = 50},
  [3161] = {.lex_state = 42},
  [3162] = {.lex_state = 50},
  [3163] = {.lex_state = 50},
  [3164] = {.lex_state = 50},
  [3165] = {.lex_state = 42},
  [3166] = {.lex_state = 50},
  [3167] = {.lex_state = 42},
  [3168] = {.lex_state = 50},
  [3169] = {.lex_state = 50},
  [3170] = {.lex_state = 50},
  [3171] = {.lex_state = 42},
  [3172] = {.lex_state = 50},
  [3173] = {.lex_state = 50},
  [3174] = {.lex_state = 50},
  [3175] = {.lex_state = 50},
  [3176] = {.lex_state = 50},
  [3177] = {.lex_state = 50},
  [3178] = {.lex_state = 50},
  [3179] = {.lex_state = 50},
  [3180] = {.lex_state = 50},
  [3181] = {.lex_state = 42},
  [3182] = {.lex_state = 42},
  [3183] = {.lex_state = 42},
  [3184] = {.lex_state = 42},
  [3185] = {.lex_state = 42},
  [3186] = {.lex_state = 42},
  [3187] = {.lex_state = 42},
  [3188] = {.lex_state = 42},
  [3189] = {.lex_state = 42},
  [3190] = {.lex_state = 42},
  [3191] = {.lex_state = 42},
  [3192] = {.lex_state = 42},
  [3193] = {.lex_state = 42},
  [3194] = {.lex_state = 42},
  [3195] = {.lex_state = 42},
  [3196] = {.lex_state = 42},
  [3197] = {.lex_state = 42},
  [3198] = {.lex_state = 42},
  [3199] = {.lex_state = 42},
  [3200] = {.lex_state = 42},
  [3201] = {.lex_state = 42},
  [3202] = {.lex_state = 42},
  [3203] = {.lex_state = 42},
  [3204] = {.lex_state = 42},
  [3205] = {.lex_state = 42},
  [3206] = {.lex_state = 50},
  [3207] = {.lex_state = 42},
  [3208] = {.lex_state = 42},
  [3209] = {.lex_state = 42},
  [3210] = {.lex_state = 42},
  [3211] = {.lex_state = 42},
  [3212] = {.lex_state = 42},
  [3213] = {.lex_state = 42},
  [3214] = {.lex_state = 42},
  [3215] = {.lex_state = 42},
  [3216] = {.lex_state = 42},
  [3217] = {.lex_state = 50},
  [3218] = {.lex_state = 42},
  [3219] = {.lex_state = 42},
  [3220] = {.lex_state = 42},
  [3221] = {.lex_state = 50},
  [3222] = {.lex_state = 42},
  [3223] = {.lex_state = 50},
  [3224] = {.lex_state = 50},
  [3225] = {.lex_state = 50},
  [3226] = {.lex_state = 50},
  [3227] = {.lex_state = 50},
  [3228] = {.lex_state = 42},
  [3229] = {.lex_state = 50},
  [3230] = {.lex_state = 42},
  [3231] = {.lex_state = 50},
  [3232] = {.lex_state = 42},
  [3233] = {.lex_state = 42},
  [3234] = {.lex_state = 42},
  [3235] = {.lex_state = 50},
  [3236] = {.lex_state = 42},
  [3237] = {.lex_state = 50},
  [3238] = {.lex_state = 42},
  [3239] = {.lex_state = 50},
  [3240] = {.lex_state = 42},
  [3241] = {.lex_state = 42},
  [3242] = {.lex_state = 50},
  [3243] = {.lex_state = 42},
  [3244] = {.lex_state = 42},
  [3245] = {.lex_state = 42},
  [3246] = {.lex_state = 50},
  [3247] = {.lex_state = 50},
  [3248] = {.lex_state = 50},
  [3249] = {.lex_state = 50},
  [3250] = {.lex_state = 50},
  [3251] = {.lex_state = 42},
  [3252] = {.lex_state = 50},
  [3253] = {.lex_state = 50},
  [3254] = {.lex_state = 50},
  [3255] = {.lex_state = 50},
  [3256] = {.lex_state = 50},
  [3257] = {.lex_state = 42},
  [3258] = {.lex_state = 42},
  [3259] = {.lex_state = 42},
  [3260] = {.lex_state = 42},
  [3261] = {.lex_state = 50},
  [3262] = {.lex_state = 50},
  [3263] = {.lex_state = 50},
  [3264] = {.lex_state = 50},
  [3265] = {.lex_state = 42},
  [3266] = {.lex_state = 50},
  [3267] = {.lex_state = 42},
  [3268] = {.lex_state = 42},
  [3269] = {.lex_state = 42},
  [3270] = {.lex_state = 42},
  [3271] = {.lex_state = 42},
  [3272] = {.lex_state = 42},
  [3273] = {.lex_state = 42},
  [3274] = {.lex_state = 42},
  [3275] = {.lex_state = 42},
  [3276] = {.lex_state = 42},
  [3277] = {.lex_state = 42},
  [3278] = {.lex_state = 42},
  [3279] = {.lex_state = 42},
  [3280] = {.lex_state = 42},
  [3281] = {.lex_state = 42},
  [3282] = {.lex_state = 42},
  [3283] = {.lex_state = 42},
  [3284] = {.lex_state = 42},
  [3285] = {.lex_state = 42},
  [3286] = {.lex_state = 42},
  [3287] = {.lex_state = 42},
  [3288] = {.lex_state = 42},
  [3289] = {.lex_state = 42},
  [3290] = {.lex_state = 42},
  [3291] = {.lex_state = 41},
  [3292] = {.lex_state = 42},
  [3293] = {.lex_state = 50},
  [3294] = {.lex_state = 50},
  [3295] = {.lex_state = 50},
  [3296] = {.lex_state = 42},
  [3297] = {.lex_state = 42},
  [3298] = {.lex_state = 42},
  [3299] = {.lex_state = 41},
  [3300] = {.lex_state = 41},
  [3301] = {.lex_state = 41},
  [3302] = {.lex_state = 50},
  [3303] = {.lex_state = 41},
  [3304] = {.lex_state = 41},
  [3305] = {.lex_state = 41},
  [3306] = {.lex_state = 41},
  [3307] = {.lex_state = 41},
  [3308] = {.lex_state = 41},
  [3309] = {.lex_state = 41},
  [3310] = {.lex_state = 41},
  [3311] = {.lex_state = 41},
  [3312] = {.lex_state = 41},
  [3313] = {.lex_state = 373},
  [3314] = {.lex_state = 45},
  [3315] = {.lex_state = 41},
  [3316] = {.lex_state = 373},
  [3317] = {.lex_state = 41},
  [3318] = {.lex_state = 41},
  [3319] = {.lex_state = 41},
  [3320] = {.lex_state = 50},
  [3321] = {.lex_state = 41},
  [3322] = {.lex_state = 50},
  [3323] = {.lex_state = 41},
  [3324] = {.lex_state = 41},
  [3325] = {.lex_state = 41},
  [3326] = {.lex_state = 41},
  [3327] = {.lex_state = 50},
  [3328] = {.lex_state = 41},
  [3329] = {.lex_state = 41},
  [3330] = {.lex_state = 41},
  [3331] = {.lex_state = 41},
  [3332] = {.lex_state = 41},
  [3333] = {.lex_state = 41},
  [3334] = {.lex_state = 50},
  [3335] = {.lex_state = 50},
  [3336] = {.lex_state = 50},
  [3337] = {.lex_state = 50},
  [3338] = {.lex_state = 50},
  [3339] = {.lex_state = 50},
  [3340] = {.lex_state = 50},
  [3341] = {.lex_state = 50},
  [3342] = {.lex_state = 50},
  [3343] = {.lex_state = 41},
  [3344] = {.lex_state = 50},
  [3345] = {.lex_state = 41},
  [3346] = {.lex_state = 50},
  [3347] = {.lex_state = 50},
  [3348] = {.lex_state = 50},
  [3349] = {.lex_state = 50},
  [3350] = {.lex_state = 50},
  [3351] = {.lex_state = 41},
  [3352] = {.lex_state = 50},
  [3353] = {.lex_state = 50},
  [3354] = {.lex_state = 41},
  [3355] = {.lex_state = 41},
  [3356] = {.lex_state = 50},
  [3357] = {.lex_state = 41},
  [3358] = {.lex_state = 50},
  [3359] = {.lex_state = 50},
  [3360] = {.lex_state = 50},
  [3361] = {.lex_state = 41},
  [3362] = {.lex_state = 41},
  [3363] = {.lex_state = 41},
  [3364] = {.lex_state = 41},
  [3365] = {.lex_state = 41},
  [3366] = {.lex_state = 41},
  [3367] = {.lex_state = 41},
  [3368] = {.lex_state = 41},
  [3369] = {.lex_state = 41},
  [3370] = {.lex_state = 50},
  [3371] = {.lex_state = 41},
  [3372] = {.lex_state = 41},
  [3373] = {.lex_state = 50},
  [3374] = {.lex_state = 41},
  [3375] = {.lex_state = 50},
  [3376] = {.lex_state = 50},
  [3377] = {.lex_state = 50},
  [3378] = {.lex_state = 50},
  [3379] = {.lex_state = 50},
  [3380] = {.lex_state = 50},
  [3381] = {.lex_state = 50},
  [3382] = {.lex_state = 41},
  [3383] = {.lex_state = 41},
  [3384] = {.lex_state = 41},
  [3385] = {.lex_state = 50},
  [3386] = {.lex_state = 50},
  [3387] = {.lex_state = 50},
  [3388] = {.lex_state = 50},
  [3389] = {.lex_state = 41},
  [3390] = {.lex_state = 50},
  [3391] = {.lex_state = 50},
  [3392] = {.lex_state = 50},
  [3393] = {.lex_state = 50},
  [3394] = {.lex_state = 50},
  [3395] = {.lex_state = 50},
  [3396] = {.lex_state = 50},
  [3397] = {.lex_state = 50},
  [3398] = {.lex_state = 50},
  [3399] = {.lex_state = 50},
  [3400] = {.lex_state = 50},
  [3401] = {.lex_state = 41},
  [3402] = {.lex_state = 41},
  [3403] = {.lex_state = 41},
  [3404] = {.lex_state = 50},
  [3405] = {.lex_state = 50},
  [3406] = {.lex_state = 50},
  [3407] = {.lex_state = 50},
  [3408] = {.lex_state = 50},
  [3409] = {.lex_state = 50},
  [3410] = {.lex_state = 50},
  [3411] = {.lex_state = 41},
  [3412] = {.lex_state = 41},
  [3413] = {.lex_state = 41},
  [3414] = {.lex_state = 50},
  [3415] = {.lex_state = 50},
  [3416] = {.lex_state = 50},
  [3417] = {.lex_state = 50},
  [3418] = {.lex_state = 50},
  [3419] = {.lex_state = 41},
  [3420] = {.lex_state = 50},
  [3421] = {.lex_state = 50},
  [3422] = {.lex_state = 50},
  [3423] = {.lex_state = 50},
  [3424] = {.lex_state = 50},
  [3425] = {.lex_state = 50},
  [3426] = {.lex_state = 50},
  [3427] = {.lex_state = 50},
  [3428] = {.lex_state = 50},
  [3429] = {.lex_state = 50},
  [3430] = {.lex_state = 41},
  [3431] = {.lex_state = 50},
  [3432] = {.lex_state = 41},
  [3433] = {.lex_state = 50},
  [3434] = {.lex_state = 41},
  [3435] = {.lex_state = 41},
  [3436] = {.lex_state = 41},
  [3437] = {.lex_state = 50},
  [3438] = {.lex_state = 50},
  [3439] = {.lex_state = 41},
  [3440] = {.lex_state = 41},
  [3441] = {.lex_state = 41},
  [3442] = {.lex_state = 41},
  [3443] = {.lex_state = 41},
  [3444] = {.lex_state = 50},
  [3445] = {.lex_state = 371},
  [3446] = {.lex_state = 41},
  [3447] = {.lex_state = 50},
  [3448] = {.lex_state = 50},
  [3449] = {.lex_state = 50},
  [3450] = {.lex_state = 50},
  [3451] = {.lex_state = 50},
  [3452] = {.lex_state = 50},
  [3453] = {.lex_state = 50},
  [3454] = {.lex_state = 50},
  [3455] = {.lex_state = 50},
  [3456] = {.lex_state = 50},
  [3457] = {.lex_state = 41},
  [3458] = {.lex_state = 41},
  [3459] = {.lex_state = 50},
  [3460] = {.lex_state = 41},
  [3461] = {.lex_state = 41},
  [3462] = {.lex_state = 41},
  [3463] = {.lex_state = 41},
  [3464] = {.lex_state = 41},
  [3465] = {.lex_state = 41},
  [3466] = {.lex_state = 41},
  [3467] = {.lex_state = 50},
  [3468] = {.lex_state = 50},
  [3469] = {.lex_state = 50},
  [3470] = {.lex_state = 50},
  [3471] = {.lex_state = 50},
  [3472] = {.lex_state = 50},
  [3473] = {.lex_state = 50},
  [3474] = {.lex_state = 50},
  [3475] = {.lex_state = 50},
  [3476] = {.lex_state = 50},
  [3477] = {.lex_state = 50},
  [3478] = {.lex_state = 41},
  [3479] = {.lex_state = 50},
  [3480] = {.lex_state = 50},
  [3481] = {.lex_state = 50},
  [3482] = {.lex_state = 50},
  [3483] = {.lex_state = 50},
  [3484] = {.lex_state = 50},
  [3485] = {.lex_state = 41},
  [3486] = {.lex_state = 50},
  [3487] = {.lex_state = 41},
  [3488] = {.lex_state = 41},
  [3489] = {.lex_state = 50},
  [3490] = {.lex_state = 50},
  [3491] = {.lex_state = 41},
  [3492] = {.lex_state = 41},
  [3493] = {.lex_state = 41},
  [3494] = {.lex_state = 50},
  [3495] = {.lex_state = 50},
  [3496] = {.lex_state = 50},
  [3497] = {.lex_state = 50},
  [3498] = {.lex_state = 50},
  [3499] = {.lex_state = 50},
  [3500] = {.lex_state = 50},
  [3501] = {.lex_state = 50},
  [3502] = {.lex_state = 50},
  [3503] = {.lex_state = 50},
  [3504] = {.lex_state = 50},
  [3505] = {.lex_state = 50},
  [3506] = {.lex_state = 50},
  [3507] = {.lex_state = 50},
  [3508] = {.lex_state = 50},
  [3509] = {.lex_state = 50},
  [3510] = {.lex_state = 50},
  [3511] = {.lex_state = 50},
  [3512] = {.lex_state = 41},
  [3513] = {.lex_state = 50},
  [3514] = {.lex_state = 50},
  [3515] = {.lex_state = 41},
  [3516] = {.lex_state = 41},
  [3517] = {.lex_state = 50},
  [3518] = {.lex_state = 50},
  [3519] = {.lex_state = 41},
  [3520] = {.lex_state = 41},
  [3521] = {.lex_state = 41},
  [3522] = {.lex_state = 50},
  [3523] = {.lex_state = 41},
  [3524] = {.lex_state = 41},
  [3525] = {.lex_state = 41},
  [3526] = {.lex_state = 50},
  [3527] = {.lex_state = 41},
  [3528] = {.lex_state = 41},
  [3529] = {.lex_state = 50},
  [3530] = {.lex_state = 50},
  [3531] = {.lex_state = 50},
  [3532] = {.lex_state = 41},
  [3533] = {.lex_state = 50},
  [3534] = {.lex_state = 41},
  [3535] = {.lex_state = 41},
  [3536] = {.lex_state = 50},
  [3537] = {.lex_state = 50},
  [3538] = {.lex_state = 41},
  [3539] = {.lex_state = 41},
  [3540] = {.lex_state = 50},
  [3541] = {.lex_state = 41},
  [3542] = {.lex_state = 41},
  [3543] = {.lex_state = 41},
  [3544] = {.lex_state = 50},
  [3545] = {.lex_state = 50},
  [3546] = {.lex_state = 50},
  [3547] = {.lex_state = 41},
  [3548] = {.lex_state = 50},
  [3549] = {.lex_state = 50},
  [3550] = {.lex_state = 50},
  [3551] = {.lex_state = 50},
  [3552] = {.lex_state = 41},
  [3553] = {.lex_state = 41},
  [3554] = {.lex_state = 41},
  [3555] = {.lex_state = 50},
  [3556] = {.lex_state = 50},
  [3557] = {.lex_state = 41},
  [3558] = {.lex_state = 41},
  [3559] = {.lex_state = 41},
  [3560] = {.lex_state = 41},
  [3561] = {.lex_state = 41},
  [3562] = {.lex_state = 50},
  [3563] = {.lex_state = 50},
  [3564] = {.lex_state = 50},
  [3565] = {.lex_state = 41},
  [3566] = {.lex_state = 50},
  [3567] = {.lex_state = 41},
  [3568] = {.lex_state = 50},
  [3569] = {.lex_state = 41},
  [3570] = {.lex_state = 50},
  [3571] = {.lex_state = 50},
  [3572] = {.lex_state = 371},
  [3573] = {.lex_state = 41},
  [3574] = {.lex_state = 50},
  [3575] = {.lex_state = 42},
  [3576] = {.lex_state = 50},
  [3577] = {.lex_state = 50},
  [3578] = {.lex_state = 41},
  [3579] = {.lex_state = 41},
  [3580] = {.lex_state = 41},
  [3581] = {.lex_state = 41},
  [3582] = {.lex_state = 50},
  [3583] = {.lex_state = 50},
  [3584] = {.lex_state = 41},
  [3585] = {.lex_state = 41},
  [3586] = {.lex_state = 41},
  [3587] = {.lex_state = 41},
  [3588] = {.lex_state = 41},
  [3589] = {.lex_state = 50},
  [3590] = {.lex_state = 50},
  [3591] = {.lex_state = 41},
  [3592] = {.lex_state = 41},
  [3593] = {.lex_state = 50},
  [3594] = {.lex_state = 50},
  [3595] = {.lex_state = 50},
  [3596] = {.lex_state = 50},
  [3597] = {.lex_state = 50},
  [3598] = {.lex_state = 41},
  [3599] = {.lex_state = 50},
  [3600] = {.lex_state = 41},
  [3601] = {.lex_state = 50},
  [3602] = {.lex_state = 41},
  [3603] = {.lex_state = 41},
  [3604] = {.lex_state = 41},
  [3605] = {.lex_state = 50},
  [3606] = {.lex_state = 41},
  [3607] = {.lex_state = 50},
  [3608] = {.lex_state = 50},
  [3609] = {.lex_state = 50},
  [3610] = {.lex_state = 41},
  [3611] = {.lex_state = 50},
  [3612] = {.lex_state = 50},
  [3613] = {.lex_state = 50},
  [3614] = {.lex_state = 50},
  [3615] = {.lex_state = 41},
  [3616] = {.lex_state = 41},
  [3617] = {.lex_state = 41},
  [3618] = {.lex_state = 50},
  [3619] = {.lex_state = 50},
  [3620] = {.lex_state = 41},
  [3621] = {.lex_state = 41},
  [3622] = {.lex_state = 41},
  [3623] = {.lex_state = 41},
  [3624] = {.lex_state = 41},
  [3625] = {.lex_state = 41},
  [3626] = {.lex_state = 41},
  [3627] = {.lex_state = 50},
  [3628] = {.lex_state = 50},
  [3629] = {.lex_state = 41},
  [3630] = {.lex_state = 41},
  [3631] = {.lex_state = 50},
  [3632] = {.lex_state = 50},
  [3633] = {.lex_state = 41},
  [3634] = {.lex_state = 50},
  [3635] = {.lex_state = 50},
  [3636] = {.lex_state = 50},
  [3637] = {.lex_state = 41},
  [3638] = {.lex_state = 41},
  [3639] = {.lex_state = 41},
  [3640] = {.lex_state = 41},
  [3641] = {.lex_state = 41},
  [3642] = {.lex_state = 41},
  [3643] = {.lex_state = 41},
  [3644] = {.lex_state = 50},
  [3645] = {.lex_state = 50},
  [3646] = {.lex_state = 50},
  [3647] = {.lex_state = 50},
  [3648] = {.lex_state = 50},
  [3649] = {.lex_state = 50},
  [3650] = {.lex_state = 50},
  [3651] = {.lex_state = 50},
  [3652] = {.lex_state = 50},
  [3653] = {.lex_state = 41},
  [3654] = {.lex_state = 50},
  [3655] = {.lex_state = 50},
  [3656] = {.lex_state = 41},
  [3657] = {.lex_state = 50},
  [3658] = {.lex_state = 41},
  [3659] = {.lex_state = 50},
  [3660] = {.lex_state = 50},
  [3661] = {.lex_state = 50},
  [3662] = {.lex_state = 50},
  [3663] = {.lex_state = 50},
  [3664] = {.lex_state = 50},
  [3665] = {.lex_state = 50},
  [3666] = {.lex_state = 50},
  [3667] = {.lex_state = 50},
  [3668] = {.lex_state = 50},
  [3669] = {.lex_state = 50},
  [3670] = {.lex_state = 50},
  [3671] = {.lex_state = 50},
  [3672] = {.lex_state = 50},
  [3673] = {.lex_state = 50},
  [3674] = {.lex_state = 50},
  [3675] = {.lex_state = 50},
  [3676] = {.lex_state = 50},
  [3677] = {.lex_state = 50},
  [3678] = {.lex_state = 50},
  [3679] = {.lex_state = 50},
  [3680] = {.lex_state = 50},
  [3681] = {.lex_state = 50},
  [3682] = {.lex_state = 50},
  [3683] = {.lex_state = 50},
  [3684] = {.lex_state = 50},
  [3685] = {.lex_state = 50},
  [3686] = {.lex_state = 50},
  [3687] = {.lex_state = 50},
  [3688] = {.lex_state = 50},
  [3689] = {.lex_state = 50},
  [3690] = {.lex_state = 50},
  [3691] = {.lex_state = 50},
  [3692] = {.lex_state = 50},
  [3693] = {.lex_state = 50},
  [3694] = {.lex_state = 50},
  [3695] = {.lex_state = 50},
  [3696] = {.lex_state = 50},
  [3697] = {.lex_state = 50},
  [3698] = {.lex_state = 50},
  [3699] = {.lex_state = 50},
  [3700] = {.lex_state = 50},
  [3701] = {.lex_state = 50},
  [3702] = {.lex_state = 50},
  [3703] = {.lex_state = 50},
  [3704] = {.lex_state = 50},
  [3705] = {.lex_state = 50},
  [3706] = {.lex_state = 50},
  [3707] = {.lex_state = 50},
  [3708] = {.lex_state = 50},
  [3709] = {.lex_state = 50},
  [3710] = {.lex_state = 50},
  [3711] = {.lex_state = 50},
  [3712] = {.lex_state = 50},
  [3713] = {.lex_state = 50},
  [3714] = {.lex_state = 50},
  [3715] = {.lex_state = 50},
  [3716] = {.lex_state = 50},
  [3717] = {.lex_state = 50},
  [3718] = {.lex_state = 50},
  [3719] = {.lex_state = 50},
  [3720] = {.lex_state = 50},
  [3721] = {.lex_state = 50},
  [3722] = {.lex_state = 50},
  [3723] = {.lex_state = 50},
  [3724] = {.lex_state = 50},
  [3725] = {.lex_state = 50},
  [3726] = {.lex_state = 50},
  [3727] = {.lex_state = 50},
  [3728] = {.lex_state = 50},
  [3729] = {.lex_state = 50},
  [3730] = {.lex_state = 50},
  [3731] = {.lex_state = 50},
  [3732] = {.lex_state = 50},
  [3733] = {.lex_state = 50},
  [3734] = {.lex_state = 50},
  [3735] = {.lex_state = 50},
  [3736] = {.lex_state = 50},
  [3737] = {.lex_state = 50},
  [3738] = {.lex_state = 50},
  [3739] = {.lex_state = 50},
  [3740] = {.lex_state = 50},
  [3741] = {.lex_state = 50},
  [3742] = {.lex_state = 50},
  [3743] = {.lex_state = 50},
  [3744] = {.lex_state = 50},
  [3745] = {.lex_state = 50},
  [3746] = {.lex_state = 50},
  [3747] = {.lex_state = 50},
  [3748] = {.lex_state = 50},
  [3749] = {.lex_state = 50},
  [3750] = {.lex_state = 50},
  [3751] = {.lex_state = 50},
  [3752] = {.lex_state = 50},
  [3753] = {.lex_state = 50},
  [3754] = {.lex_state = 50},
  [3755] = {.lex_state = 50},
  [3756] = {.lex_state = 50},
  [3757] = {.lex_state = 50},
  [3758] = {.lex_state = 50},
  [3759] = {.lex_state = 50},
  [3760] = {.lex_state = 50},
  [3761] = {.lex_state = 50},
  [3762] = {.lex_state = 50},
  [3763] = {.lex_state = 50},
  [3764] = {.lex_state = 50},
  [3765] = {.lex_state = 50},
  [3766] = {.lex_state = 50},
  [3767] = {.lex_state = 50},
  [3768] = {.lex_state = 50},
  [3769] = {.lex_state = 50},
  [3770] = {.lex_state = 50},
  [3771] = {.lex_state = 50},
  [3772] = {.lex_state = 50},
  [3773] = {.lex_state = 50},
  [3774] = {.lex_state = 50},
  [3775] = {.lex_state = 50},
  [3776] = {.lex_state = 50},
  [3777] = {.lex_state = 50},
  [3778] = {.lex_state = 50},
  [3779] = {.lex_state = 50},
  [3780] = {.lex_state = 41},
  [3781] = {.lex_state = 41},
  [3782] = {.lex_state = 41},
  [3783] = {.lex_state = 41},
  [3784] = {.lex_state = 41},
  [3785] = {.lex_state = 41},
  [3786] = {.lex_state = 41},
  [3787] = {.lex_state = 41},
  [3788] = {.lex_state = 50},
  [3789] = {.lex_state = 50},
  [3790] = {.lex_state = 41},
  [3791] = {.lex_state = 41},
  [3792] = {.lex_state = 50},
  [3793] = {.lex_state = 41},
  [3794] = {.lex_state = 41},
  [3795] = {.lex_state = 41},
  [3796] = {.lex_state = 41},
  [3797] = {.lex_state = 41},
  [3798] = {.lex_state = 41},
  [3799] = {.lex_state = 41},
  [3800] = {.lex_state = 41},
  [3801] = {.lex_state = 41},
  [3802] = {.lex_state = 41},
  [3803] = {.lex_state = 41},
  [3804] = {.lex_state = 41},
  [3805] = {.lex_state = 41},
  [3806] = {.lex_state = 41},
  [3807] = {.lex_state = 41},
  [3808] = {.lex_state = 41},
  [3809] = {.lex_state = 41},
  [3810] = {.lex_state = 41},
  [3811] = {.lex_state = 41},
  [3812] = {.lex_state = 41},
  [3813] = {.lex_state = 41},
  [3814] = {.lex_state = 41},
  [3815] = {.lex_state = 41},
  [3816] = {.lex_state = 41},
  [3817] = {.lex_state = 41},
  [3818] = {.lex_state = 41},
  [3819] = {.lex_state = 41},
  [3820] = {.lex_state = 41},
  [3821] = {.lex_state = 41},
  [3822] = {.lex_state = 41},
  [3823] = {.lex_state = 41},
  [3824] = {.lex_state = 41},
  [3825] = {.lex_state = 41},
  [3826] = {.lex_state = 41},
  [3827] = {.lex_state = 41},
  [3828] = {.lex_state = 41},
  [3829] = {.lex_state = 41},
  [3830] = {.lex_state = 41},
  [3831] = {.lex_state = 41},
  [3832] = {.lex_state = 41},
  [3833] = {.lex_state = 41},
  [3834] = {.lex_state = 41},
  [3835] = {.lex_state = 41},
  [3836] = {.lex_state = 50},
  [3837] = {.lex_state = 50},
  [3838] = {.lex_state = 50},
  [3839] = {.lex_state = 41},
  [3840] = {.lex_state = 50},
  [3841] = {.lex_state = 41},
  [3842] = {.lex_state = 41},
  [3843] = {.lex_state = 41},
  [3844] = {.lex_state = 41},
  [3845] = {.lex_state = 41},
  [3846] = {.lex_state = 50},
  [3847] = {.lex_state = 50},
  [3848] = {.lex_state = 50},
  [3849] = {.lex_state = 50},
  [3850] = {.lex_state = 50},
  [3851] = {.lex_state = 50},
  [3852] = {.lex_state = 50},
  [3853] = {.lex_state = 41},
  [3854] = {.lex_state = 41},
  [3855] = {.lex_state = 41},
  [3856] = {.lex_state = 41},
  [3857] = {.lex_state = 41},
  [3858] = {.lex_state = 41},
  [3859] = {.lex_state = 41},
  [3860] = {.lex_state = 41},
  [3861] = {.lex_state = 41},
  [3862] = {.lex_state = 41},
  [3863] = {.lex_state = 41},
  [3864] = {.lex_state = 41},
  [3865] = {.lex_state = 41},
  [3866] = {.lex_state = 41},
  [3867] = {.lex_state = 41},
  [3868] = {.lex_state = 41},
  [3869] = {.lex_state = 41},
  [3870] = {.lex_state = 41},
  [3871] = {.lex_state = 41},
  [3872] = {.lex_state = 41},
  [3873] = {.lex_state = 41},
  [3874] = {.lex_state = 41},
  [3875] = {.lex_state = 41},
  [3876] = {.lex_state = 41},
  [3877] = {.lex_state = 41},
  [3878] = {.lex_state = 41},
  [3879] = {.lex_state = 41},
  [3880] = {.lex_state = 41},
  [3881] = {.lex_state = 41},
  [3882] = {.lex_state = 41},
  [3883] = {.lex_state = 41},
  [3884] = {.lex_state = 41},
  [3885] = {.lex_state = 41},
  [3886] = {.lex_state = 41},
  [3887] = {.lex_state = 41},
  [3888] = {.lex_state = 41},
  [3889] = {.lex_state = 41},
  [3890] = {.lex_state = 41},
  [3891] = {.lex_state = 41},
  [3892] = {.lex_state = 41},
  [3893] = {.lex_state = 41},
  [3894] = {.lex_state = 41},
  [3895] = {.lex_state = 41},
  [3896] = {.lex_state = 41},
  [3897] = {.lex_state = 41},
  [3898] = {.lex_state = 41},
  [3899] = {.lex_state = 41},
  [3900] = {.lex_state = 41},
  [3901] = {.lex_state = 41},
  [3902] = {.lex_state = 41},
  [3903] = {.lex_state = 41},
  [3904] = {.lex_state = 41},
  [3905] = {.lex_state = 41},
  [3906] = {.lex_state = 41},
  [3907] = {.lex_state = 41},
  [3908] = {.lex_state = 41},
  [3909] = {.lex_state = 41},
  [3910] = {.lex_state = 41},
  [3911] = {.lex_state = 41},
  [3912] = {.lex_state = 41},
  [3913] = {.lex_state = 41},
  [3914] = {.lex_state = 41},
  [3915] = {.lex_state = 41},
  [3916] = {.lex_state = 41},
  [3917] = {.lex_state = 41},
  [3918] = {.lex_state = 41},
  [3919] = {.lex_state = 41},
  [3920] = {.lex_state = 41},
  [3921] = {.lex_state = 41},
  [3922] = {.lex_state = 41},
  [3923] = {.lex_state = 41},
  [3924] = {.lex_state = 41},
  [3925] = {.lex_state = 50},
  [3926] = {.lex_state = 41},
  [3927] = {.lex_state = 41},
  [3928] = {.lex_state = 41},
  [3929] = {.lex_state = 41},
  [3930] = {.lex_state = 41},
  [3931] = {.lex_state = 41},
  [3932] = {.lex_state = 41},
  [3933] = {.lex_state = 41},
  [3934] = {.lex_state = 41},
  [3935] = {.lex_state = 41},
  [3936] = {.lex_state = 41},
  [3937] = {.lex_state = 41},
  [3938] = {.lex_state = 41},
  [3939] = {.lex_state = 41},
  [3940] = {.lex_state = 41},
  [3941] = {.lex_state = 41},
  [3942] = {.lex_state = 41},
  [3943] = {.lex_state = 41},
  [3944] = {.lex_state = 41},
  [3945] = {.lex_state = 41},
  [3946] = {.lex_state = 41},
  [3947] = {.lex_state = 41},
  [3948] = {.lex_state = 41},
  [3949] = {.lex_state = 41},
  [3950] = {.lex_state = 41},
  [3951] = {.lex_state = 41},
  [3952] = {.lex_state = 41},
  [3953] = {.lex_state = 41},
  [3954] = {.lex_state = 41},
  [3955] = {.lex_state = 41},
  [3956] = {.lex_state = 41},
  [3957] = {.lex_state = 41},
  [3958] = {.lex_state = 41},
  [3959] = {.lex_state = 41},
  [3960] = {.lex_state = 41},
  [3961] = {.lex_state = 41},
  [3962] = {.lex_state = 41},
  [3963] = {.lex_state = 41},
  [3964] = {.lex_state = 41},
  [3965] = {.lex_state = 41},
  [3966] = {.lex_state = 41},
  [3967] = {.lex_state = 41},
  [3968] = {.lex_state = 41},
  [3969] = {.lex_state = 41},
  [3970] = {.lex_state = 41},
  [3971] = {.lex_state = 41},
  [3972] = {.lex_state = 41},
  [3973] = {.lex_state = 41},
  [3974] = {.lex_state = 50},
  [3975] = {.lex_state = 41},
  [3976] = {.lex_state = 41},
  [3977] = {.lex_state = 41},
  [3978] = {.lex_state = 41},
  [3979] = {.lex_state = 41},
  [3980] = {.lex_state = 41},
  [3981] = {.lex_state = 41},
  [3982] = {.lex_state = 41},
  [3983] = {.lex_state = 41},
  [3984] = {.lex_state = 41},
  [3985] = {.lex_state = 41},
  [3986] = {.lex_state = 41},
  [3987] = {.lex_state = 41},
  [3988] = {.lex_state = 41},
  [3989] = {.lex_state = 41},
  [3990] = {.lex_state = 41},
  [3991] = {.lex_state = 41},
  [3992] = {.lex_state = 41},
  [3993] = {.lex_state = 41},
  [3994] = {.lex_state = 41},
  [3995] = {.lex_state = 41},
  [3996] = {.lex_state = 41},
  [3997] = {.lex_state = 41},
  [3998] = {.lex_state = 41},
  [3999] = {.lex_state = 41},
  [4000] = {.lex_state = 41},
  [4001] = {.lex_state = 41},
  [4002] = {.lex_state = 41},
  [4003] = {.lex_state = 41},
  [4004] = {.lex_state = 41},
  [4005] = {.lex_state = 41},
  [4006] = {.lex_state = 41},
  [4007] = {.lex_state = 41},
  [4008] = {.lex_state = 41},
  [4009] = {.lex_state = 41},
  [4010] = {.lex_state = 41},
  [4011] = {.lex_state = 41},
  [4012] = {.lex_state = 41},
  [4013] = {.lex_state = 41},
  [4014] = {.lex_state = 41},
  [4015] = {.lex_state = 41},
  [4016] = {.lex_state = 41},
  [4017] = {.lex_state = 41},
  [4018] = {.lex_state = 41},
  [4019] = {.lex_state = 41},
  [4020] = {.lex_state = 41},
  [4021] = {.lex_state = 41},
  [4022] = {.lex_state = 41},
  [4023] = {.lex_state = 41},
  [4024] = {.lex_state = 41},
  [4025] = {.lex_state = 41},
  [4026] = {.lex_state = 50},
  [4027] = {.lex_state = 41},
  [4028] = {.lex_state = 41},
  [4029] = {.lex_state = 41},
  [4030] = {.lex_state = 41},
  [4031] = {.lex_state = 41},
  [4032] = {.lex_state = 41},
  [4033] = {.lex_state = 41},
  [4034] = {.lex_state = 41},
  [4035] = {.lex_state = 41},
  [4036] = {.lex_state = 41},
  [4037] = {.lex_state = 41},
  [4038] = {.lex_state = 41},
  [4039] = {.lex_state = 41},
  [4040] = {.lex_state = 50},
  [4041] = {.lex_state = 41},
  [4042] = {.lex_state = 41},
  [4043] = {.lex_state = 41},
  [4044] = {.lex_state = 41},
  [4045] = {.lex_state = 41},
  [4046] = {.lex_state = 41},
  [4047] = {.lex_state = 41},
  [4048] = {.lex_state = 41},
  [4049] = {.lex_state = 41},
  [4050] = {.lex_state = 41},
  [4051] = {.lex_state = 41},
  [4052] = {.lex_state = 41},
  [4053] = {.lex_state = 41},
  [4054] = {.lex_state = 41},
  [4055] = {.lex_state = 41},
  [4056] = {.lex_state = 41},
  [4057] = {.lex_state = 41},
  [4058] = {.lex_state = 41},
  [4059] = {.lex_state = 41},
  [4060] = {.lex_state = 41},
  [4061] = {.lex_state = 41},
  [4062] = {.lex_state = 41},
  [4063] = {.lex_state = 41},
  [4064] = {.lex_state = 41},
  [4065] = {.lex_state = 41},
  [4066] = {.lex_state = 41},
  [4067] = {.lex_state = 41},
  [4068] = {.lex_state = 41},
  [4069] = {.lex_state = 41},
  [4070] = {.lex_state = 41},
  [4071] = {.lex_state = 41},
  [4072] = {.lex_state = 41},
  [4073] = {.lex_state = 41},
  [4074] = {.lex_state = 41},
  [4075] = {.lex_state = 41},
  [4076] = {.lex_state = 41},
  [4077] = {.lex_state = 41},
  [4078] = {.lex_state = 41},
  [4079] = {.lex_state = 41},
  [4080] = {.lex_state = 41},
  [4081] = {.lex_state = 41},
  [4082] = {.lex_state = 41},
  [4083] = {.lex_state = 41},
  [4084] = {.lex_state = 41},
  [4085] = {.lex_state = 41},
  [4086] = {.lex_state = 41},
  [4087] = {.lex_state = 41},
  [4088] = {.lex_state = 41},
  [4089] = {.lex_state = 41},
  [4090] = {.lex_state = 41},
  [4091] = {.lex_state = 41},
  [4092] = {.lex_state = 41},
  [4093] = {.lex_state = 41},
  [4094] = {.lex_state = 41},
  [4095] = {.lex_state = 41},
  [4096] = {.lex_state = 41},
  [4097] = {.lex_state = 41},
  [4098] = {.lex_state = 41},
  [4099] = {.lex_state = 41},
  [4100] = {.lex_state = 41},
  [4101] = {.lex_state = 41},
  [4102] = {.lex_state = 41},
  [4103] = {.lex_state = 41},
  [4104] = {.lex_state = 41},
  [4105] = {.lex_state = 41},
  [4106] = {.lex_state = 41},
  [4107] = {.lex_state = 41},
  [4108] = {.lex_state = 41},
  [4109] = {.lex_state = 41},
  [4110] = {.lex_state = 41},
  [4111] = {.lex_state = 41},
  [4112] = {.lex_state = 41},
  [4113] = {.lex_state = 41},
  [4114] = {.lex_state = 41},
  [4115] = {.lex_state = 41},
  [4116] = {.lex_state = 41},
  [4117] = {.lex_state = 41},
  [4118] = {.lex_state = 41},
  [4119] = {.lex_state = 41},
  [4120] = {.lex_state = 41},
  [4121] = {.lex_state = 41},
  [4122] = {.lex_state = 41},
  [4123] = {.lex_state = 41},
  [4124] = {.lex_state = 41},
  [4125] = {.lex_state = 41},
  [4126] = {.lex_state = 41},
  [4127] = {.lex_state = 41},
  [4128] = {.lex_state = 41},
  [4129] = {.lex_state = 41},
  [4130] = {.lex_state = 41},
  [4131] = {.lex_state = 41},
  [4132] = {.lex_state = 41},
  [4133] = {.lex_state = 41},
  [4134] = {.lex_state = 41},
  [4135] = {.lex_state = 41},
  [4136] = {.lex_state = 41},
  [4137] = {.lex_state = 41},
  [4138] = {.lex_state = 41},
  [4139] = {.lex_state = 41},
  [4140] = {.lex_state = 41},
  [4141] = {.lex_state = 41},
  [4142] = {.lex_state = 41},
  [4143] = {.lex_state = 41},
  [4144] = {.lex_state = 41},
  [4145] = {.lex_state = 41},
  [4146] = {.lex_state = 41},
  [4147] = {.lex_state = 41},
  [4148] = {.lex_state = 41},
  [4149] = {.lex_state = 41},
  [4150] = {.lex_state = 41},
  [4151] = {.lex_state = 41},
  [4152] = {.lex_state = 41},
  [4153] = {.lex_state = 41},
  [4154] = {.lex_state = 41},
  [4155] = {.lex_state = 41},
  [4156] = {.lex_state = 50},
  [4157] = {.lex_state = 41},
  [4158] = {.lex_state = 41},
  [4159] = {.lex_state = 41},
  [4160] = {.lex_state = 41},
  [4161] = {.lex_state = 41},
  [4162] = {.lex_state = 41},
  [4163] = {.lex_state = 41},
  [4164] = {.lex_state = 41},
  [4165] = {.lex_state = 41},
  [4166] = {.lex_state = 41},
  [4167] = {.lex_state = 41},
  [4168] = {.lex_state = 41},
  [4169] = {.lex_state = 41},
  [4170] = {.lex_state = 41},
  [4171] = {.lex_state = 41},
  [4172] = {.lex_state = 371},
  [4173] = {.lex_state = 41},
  [4174] = {.lex_state = 50},
  [4175] = {.lex_state = 41},
  [4176] = {.lex_state = 41},
  [4177] = {.lex_state = 41},
  [4178] = {.lex_state = 50},
  [4179] = {.lex_state = 41},
  [4180] = {.lex_state = 41},
  [4181] = {.lex_state = 41},
  [4182] = {.lex_state = 50},
  [4183] = {.lex_state = 41},
  [4184] = {.lex_state = 50},
  [4185] = {.lex_state = 41},
  [4186] = {.lex_state = 41},
  [4187] = {.lex_state = 41},
  [4188] = {.lex_state = 41},
  [4189] = {.lex_state = 41},
  [4190] = {.lex_state = 41},
  [4191] = {.lex_state = 41},
  [4192] = {.lex_state = 41},
  [4193] = {.lex_state = 41},
  [4194] = {.lex_state = 41},
  [4195] = {.lex_state = 41},
  [4196] = {.lex_state = 41},
  [4197] = {.lex_state = 41},
  [4198] = {.lex_state = 41},
  [4199] = {.lex_state = 41},
  [4200] = {.lex_state = 41},
  [4201] = {.lex_state = 41},
  [4202] = {.lex_state = 41},
  [4203] = {.lex_state = 41},
  [4204] = {.lex_state = 41},
  [4205] = {.lex_state = 41},
  [4206] = {.lex_state = 41},
  [4207] = {.lex_state = 41},
  [4208] = {.lex_state = 41},
  [4209] = {.lex_state = 41},
  [4210] = {.lex_state = 41},
  [4211] = {.lex_state = 41},
  [4212] = {.lex_state = 41},
  [4213] = {.lex_state = 41},
  [4214] = {.lex_state = 41},
  [4215] = {.lex_state = 41},
  [4216] = {.lex_state = 41},
  [4217] = {.lex_state = 41},
  [4218] = {.lex_state = 41},
  [4219] = {.lex_state = 41},
  [4220] = {.lex_state = 41},
  [4221] = {.lex_state = 41},
  [4222] = {.lex_state = 50},
  [4223] = {.lex_state = 41},
  [4224] = {.lex_state = 41},
  [4225] = {.lex_state = 41},
  [4226] = {.lex_state = 50},
  [4227] = {.lex_state = 50},
  [4228] = {.lex_state = 50},
  [4229] = {.lex_state = 50},
  [4230] = {.lex_state = 50},
  [4231] = {.lex_state = 50},
  [4232] = {.lex_state = 50},
  [4233] = {.lex_state = 50},
  [4234] = {.lex_state = 50},
  [4235] = {.lex_state = 50},
  [4236] = {.lex_state = 50},
  [4237] = {.lex_state = 50},
  [4238] = {.lex_state = 50},
  [4239] = {.lex_state = 50},
  [4240] = {.lex_state = 50},
  [4241] = {.lex_state = 50},
  [4242] = {.lex_state = 50},
  [4243] = {.lex_state = 50},
  [4244] = {.lex_state = 50},
  [4245] = {.lex_state = 50},
  [4246] = {.lex_state = 50},
  [4247] = {.lex_state = 50},
  [4248] = {.lex_state = 50},
  [4249] = {.lex_state = 50},
  [4250] = {.lex_state = 50},
  [4251] = {.lex_state = 50},
  [4252] = {.lex_state = 50},
  [4253] = {.lex_state = 50},
  [4254] = {.lex_state = 50},
  [4255] = {.lex_state = 50},
  [4256] = {.lex_state = 50},
  [4257] = {.lex_state = 50},
  [4258] = {.lex_state = 50},
  [4259] = {.lex_state = 50},
  [4260] = {.lex_state = 50},
  [4261] = {.lex_state = 50},
  [4262] = {.lex_state = 50},
  [4263] = {.lex_state = 50},
  [4264] = {.lex_state = 50},
  [4265] = {.lex_state = 50},
  [4266] = {.lex_state = 50},
  [4267] = {.lex_state = 50},
  [4268] = {.lex_state = 50},
  [4269] = {.lex_state = 50},
  [4270] = {.lex_state = 50},
  [4271] = {.lex_state = 50},
  [4272] = {.lex_state = 50},
  [4273] = {.lex_state = 50},
  [4274] = {.lex_state = 50},
  [4275] = {.lex_state = 50},
  [4276] = {.lex_state = 50},
  [4277] = {.lex_state = 50},
  [4278] = {.lex_state = 50},
  [4279] = {.lex_state = 50},
  [4280] = {.lex_state = 50},
  [4281] = {.lex_state = 50},
  [4282] = {.lex_state = 50},
  [4283] = {.lex_state = 50},
  [4284] = {.lex_state = 50},
  [4285] = {.lex_state = 50},
  [4286] = {.lex_state = 50},
  [4287] = {.lex_state = 50},
  [4288] = {.lex_state = 50},
  [4289] = {.lex_state = 50},
  [4290] = {.lex_state = 50},
  [4291] = {.lex_state = 50},
  [4292] = {.lex_state = 50},
  [4293] = {.lex_state = 50},
  [4294] = {.lex_state = 50},
  [4295] = {.lex_state = 50},
  [4296] = {.lex_state = 50},
  [4297] = {.lex_state = 50},
  [4298] = {.lex_state = 50},
  [4299] = {.lex_state = 50},
  [4300] = {.lex_state = 50},
  [4301] = {.lex_state = 50},
  [4302] = {.lex_state = 50},
  [4303] = {.lex_state = 50},
  [4304] = {.lex_state = 50},
  [4305] = {.lex_state = 50},
  [4306] = {.lex_state = 50},
  [4307] = {.lex_state = 50},
  [4308] = {.lex_state = 50},
  [4309] = {.lex_state = 50},
  [4310] = {.lex_state = 50},
  [4311] = {.lex_state = 50},
  [4312] = {.lex_state = 50},
  [4313] = {.lex_state = 371},
  [4314] = {.lex_state = 50},
  [4315] = {.lex_state = 50},
  [4316] = {.lex_state = 50},
  [4317] = {.lex_state = 50},
  [4318] = {.lex_state = 50},
  [4319] = {.lex_state = 50},
  [4320] = {.lex_state = 50},
  [4321] = {.lex_state = 50},
  [4322] = {.lex_state = 50},
  [4323] = {.lex_state = 371},
  [4324] = {.lex_state = 50},
  [4325] = {.lex_state = 50},
  [4326] = {.lex_state = 50},
  [4327] = {.lex_state = 50},
  [4328] = {.lex_state = 50},
  [4329] = {.lex_state = 50},
  [4330] = {.lex_state = 50},
  [4331] = {.lex_state = 50},
  [4332] = {.lex_state = 50},
  [4333] = {.lex_state = 50},
  [4334] = {.lex_state = 50},
  [4335] = {.lex_state = 50},
  [4336] = {.lex_state = 371},
  [4337] = {.lex_state = 371},
  [4338] = {.lex_state = 371},
  [4339] = {.lex_state = 371},
  [4340] = {.lex_state = 371},
  [4341] = {.lex_state = 371},
  [4342] = {.lex_state = 371},
  [4343] = {.lex_state = 371},
  [4344] = {.lex_state = 371},
  [4345] = {.lex_state = 371},
  [4346] = {.lex_state = 371},
  [4347] = {.lex_state = 371},
  [4348] = {.lex_state = 371},
  [4349] = {.lex_state = 371},
  [4350] = {.lex_state = 371},
  [4351] = {.lex_state = 371},
  [4352] = {.lex_state = 371},
  [4353] = {.lex_state = 371},
  [4354] = {.lex_state = 371},
  [4355] = {.lex_state = 371},
  [4356] = {.lex_state = 371},
  [4357] = {.lex_state = 371},
  [4358] = {.lex_state = 371},
  [4359] = {.lex_state = 371},
  [4360] = {.lex_state = 371},
  [4361] = {.lex_state = 371},
  [4362] = {.lex_state = 371},
  [4363] = {.lex_state = 371},
  [4364] = {.lex_state = 371},
  [4365] = {.lex_state = 371},
  [4366] = {.lex_state = 371},
  [4367] = {.lex_state = 371},
  [4368] = {.lex_state = 371},
  [4369] = {.lex_state = 371},
  [4370] = {.lex_state = 371},
  [4371] = {.lex_state = 371},
  [4372] = {.lex_state = 371},
  [4373] = {.lex_state = 371},
  [4374] = {.lex_state = 371},
  [4375] = {.lex_state = 371},
  [4376] = {.lex_state = 371},
  [4377] = {.lex_state = 371},
  [4378] = {.lex_state = 371},
  [4379] = {.lex_state = 371},
  [4380] = {.lex_state = 371},
  [4381] = {.lex_state = 371},
  [4382] = {.lex_state = 371},
  [4383] = {.lex_state = 371},
  [4384] = {.lex_state = 371},
  [4385] = {.lex_state = 371},
  [4386] = {.lex_state = 371},
  [4387] = {.lex_state = 371},
  [4388] = {.lex_state = 371},
  [4389] = {.lex_state = 371},
  [4390] = {.lex_state = 371},
  [4391] = {.lex_state = 371},
  [4392] = {.lex_state = 371},
  [4393] = {.lex_state = 371},
  [4394] = {.lex_state = 371},
  [4395] = {.lex_state = 371},
  [4396] = {.lex_state = 371},
  [4397] = {.lex_state = 371},
  [4398] = {.lex_state = 371},
  [4399] = {.lex_state = 371},
  [4400] = {.lex_state = 371},
  [4401] = {.lex_state = 371},
  [4402] = {.lex_state = 371},
  [4403] = {.lex_state = 371},
  [4404] = {.lex_state = 371},
  [4405] = {.lex_state = 371},
  [4406] = {.lex_state = 371},
  [4407] = {.lex_state = 371},
  [4408] = {.lex_state = 371},
  [4409] = {.lex_state = 371},
  [4410] = {.lex_state = 371},
  [4411] = {.lex_state = 371},
  [4412] = {.lex_state = 371},
  [4413] = {.lex_state = 371},
  [4414] = {.lex_state = 371},
  [4415] = {.lex_state = 371},
  [4416] = {.lex_state = 371},
  [4417] = {.lex_state = 371},
  [4418] = {.lex_state = 371},
  [4419] = {.lex_state = 371},
  [4420] = {.lex_state = 371},
  [4421] = {.lex_state = 371},
  [4422] = {.lex_state = 371},
  [4423] = {.lex_state = 371},
  [4424] = {.lex_state = 371},
  [4425] = {.lex_state = 371},
  [4426] = {.lex_state = 371},
  [4427] = {.lex_state = 371},
  [4428] = {.lex_state = 371},
  [4429] = {.lex_state = 371},
  [4430] = {.lex_state = 371},
  [4431] = {.lex_state = 371},
  [4432] = {.lex_state = 371},
  [4433] = {.lex_state = 371},
  [4434] = {.lex_state = 371},
  [4435] = {.lex_state = 371},
  [4436] = {.lex_state = 371},
  [4437] = {.lex_state = 371},
  [4438] = {.lex_state = 371},
  [4439] = {.lex_state = 371},
  [4440] = {.lex_state = 371},
  [4441] = {.lex_state = 371},
  [4442] = {.lex_state = 371},
  [4443] = {.lex_state = 371},
  [4444] = {.lex_state = 371},
  [4445] = {.lex_state = 371},
  [4446] = {.lex_state = 371},
  [4447] = {.lex_state = 371},
  [4448] = {.lex_state = 371},
  [4449] = {.lex_state = 371},
  [4450] = {.lex_state = 371},
  [4451] = {.lex_state = 371},
  [4452] = {.lex_state = 371},
  [4453] = {.lex_state = 371},
  [4454] = {.lex_state = 371},
  [4455] = {.lex_state = 371},
  [4456] = {.lex_state = 371},
  [4457] = {.lex_state = 371},
  [4458] = {.lex_state = 371},
  [4459] = {.lex_state = 371},
  [4460] = {.lex_state = 371},
  [4461] = {.lex_state = 371},
  [4462] = {.lex_state = 371},
  [4463] = {.lex_state = 371},
  [4464] = {.lex_state = 371},
  [4465] = {.lex_state = 371},
  [4466] = {.lex_state = 371},
  [4467] = {.lex_state = 371},
  [4468] = {.lex_state = 371},
  [4469] = {.lex_state = 371},
  [4470] = {.lex_state = 371},
  [4471] = {.lex_state = 371},
  [4472] = {.lex_state = 371},
  [4473] = {.lex_state = 371},
  [4474] = {.lex_state = 371},
  [4475] = {.lex_state = 371},
  [4476] = {.lex_state = 371},
  [4477] = {.lex_state = 371},
  [4478] = {.lex_state = 371},
  [4479] = {.lex_state = 371},
  [4480] = {.lex_state = 371},
  [4481] = {.lex_state = 371},
  [4482] = {.lex_state = 371},
  [4483] = {.lex_state = 371},
  [4484] = {.lex_state = 371},
  [4485] = {.lex_state = 371},
  [4486] = {.lex_state = 371},
  [4487] = {.lex_state = 371},
  [4488] = {.lex_state = 371},
  [4489] = {.lex_state = 371},
  [4490] = {.lex_state = 371},
  [4491] = {.lex_state = 371},
  [4492] = {.lex_state = 371},
  [4493] = {.lex_state = 371},
  [4494] = {.lex_state = 371},
  [4495] = {.lex_state = 371},
  [4496] = {.lex_state = 371},
  [4497] = {.lex_state = 371},
  [4498] = {.lex_state = 371},
  [4499] = {.lex_state = 371},
  [4500] = {.lex_state = 371},
  [4501] = {.lex_state = 371},
  [4502] = {.lex_state = 371},
  [4503] = {.lex_state = 371},
  [4504] = {.lex_state = 371},
  [4505] = {.lex_state = 371},
  [4506] = {.lex_state = 371},
  [4507] = {.lex_state = 371},
  [4508] = {.lex_state = 371},
  [4509] = {.lex_state = 371},
  [4510] = {.lex_state = 371},
  [4511] = {.lex_state = 371},
  [4512] = {.lex_state = 371},
  [4513] = {.lex_state = 371},
  [4514] = {.lex_state = 371},
  [4515] = {.lex_state = 371},
  [4516] = {.lex_state = 371},
  [4517] = {.lex_state = 371},
  [4518] = {.lex_state = 371},
  [4519] = {.lex_state = 371},
  [4520] = {.lex_state = 371},
  [4521] = {.lex_state = 371},
  [4522] = {.lex_state = 371},
  [4523] = {.lex_state = 371},
  [4524] = {.lex_state = 371},
  [4525] = {.lex_state = 371},
  [4526] = {.lex_state = 371},
  [4527] = {.lex_state = 371},
  [4528] = {.lex_state = 371},
  [4529] = {.lex_state = 371},
  [4530] = {.lex_state = 371},
  [4531] = {.lex_state = 371},
  [4532] = {.lex_state = 371},
  [4533] = {.lex_state = 371},
  [4534] = {.lex_state = 371},
  [4535] = {.lex_state = 371},
  [4536] = {.lex_state = 371},
  [4537] = {.lex_state = 371},
  [4538] = {.lex_state = 371},
  [4539] = {.lex_state = 371},
  [4540] = {.lex_state = 371},
  [4541] = {.lex_state = 371},
  [4542] = {.lex_state = 371},
  [4543] = {.lex_state = 371},
  [4544] = {.lex_state = 371},
  [4545] = {.lex_state = 371},
  [4546] = {.lex_state = 371},
  [4547] = {.lex_state = 371},
  [4548] = {.lex_state = 371},
  [4549] = {.lex_state = 371},
  [4550] = {.lex_state = 371},
  [4551] = {.lex_state = 371},
  [4552] = {.lex_state = 371},
  [4553] = {.lex_state = 371},
  [4554] = {.lex_state = 371},
  [4555] = {.lex_state = 371},
  [4556] = {.lex_state = 371},
  [4557] = {.lex_state = 371},
  [4558] = {.lex_state = 371},
  [4559] = {.lex_state = 371},
  [4560] = {.lex_state = 371},
  [4561] = {.lex_state = 371},
  [4562] = {.lex_state = 371},
  [4563] = {.lex_state = 371},
  [4564] = {.lex_state = 371},
  [4565] = {.lex_state = 371},
  [4566] = {.lex_state = 371},
  [4567] = {.lex_state = 371},
  [4568] = {.lex_state = 371},
  [4569] = {.lex_state = 371},
  [4570] = {.lex_state = 371},
  [4571] = {.lex_state = 371},
  [4572] = {.lex_state = 371},
  [4573] = {.lex_state = 371},
  [4574] = {.lex_state = 371},
  [4575] = {.lex_state = 371},
  [4576] = {.lex_state = 371},
  [4577] = {.lex_state = 371},
  [4578] = {.lex_state = 371},
  [4579] = {.lex_state = 371},
  [4580] = {.lex_state = 371},
  [4581] = {.lex_state = 371},
  [4582] = {.lex_state = 371},
  [4583] = {.lex_state = 371},
  [4584] = {.lex_state = 371},
  [4585] = {.lex_state = 371},
  [4586] = {.lex_state = 371},
  [4587] = {.lex_state = 371},
  [4588] = {.lex_state = 371},
  [4589] = {.lex_state = 371},
  [4590] = {.lex_state = 371},
  [4591] = {.lex_state = 371},
  [4592] = {.lex_state = 371},
  [4593] = {.lex_state = 371},
  [4594] = {.lex_state = 371},
  [4595] = {.lex_state = 371},
  [4596] = {.lex_state = 371},
  [4597] = {.lex_state = 371},
  [4598] = {.lex_state = 371},
  [4599] = {.lex_state = 371},
  [4600] = {.lex_state = 371},
  [4601] = {.lex_state = 371},
  [4602] = {.lex_state = 371},
  [4603] = {.lex_state = 371},
  [4604] = {.lex_state = 371},
  [4605] = {.lex_state = 371},
  [4606] = {.lex_state = 371},
  [4607] = {.lex_state = 371},
  [4608] = {.lex_state = 371},
  [4609] = {.lex_state = 371},
  [4610] = {.lex_state = 371},
  [4611] = {.lex_state = 371},
  [4612] = {.lex_state = 371},
  [4613] = {.lex_state = 371},
  [4614] = {.lex_state = 371},
  [4615] = {.lex_state = 371},
  [4616] = {.lex_state = 371},
  [4617] = {.lex_state = 371},
  [4618] = {.lex_state = 371},
  [4619] = {.lex_state = 371},
  [4620] = {.lex_state = 371},
  [4621] = {.lex_state = 371},
  [4622] = {.lex_state = 371},
  [4623] = {.lex_state = 371},
  [4624] = {.lex_state = 371},
  [4625] = {.lex_state = 371},
  [4626] = {.lex_state = 371},
  [4627] = {.lex_state = 371},
  [4628] = {.lex_state = 371},
  [4629] = {.lex_state = 371},
  [4630] = {.lex_state = 371},
  [4631] = {.lex_state = 371},
  [4632] = {.lex_state = 371},
  [4633] = {.lex_state = 371},
  [4634] = {.lex_state = 371},
  [4635] = {.lex_state = 371},
  [4636] = {.lex_state = 371},
  [4637] = {.lex_state = 371},
  [4638] = {.lex_state = 371},
  [4639] = {.lex_state = 371},
  [4640] = {.lex_state = 371},
  [4641] = {.lex_state = 371},
  [4642] = {.lex_state = 371},
  [4643] = {.lex_state = 371},
  [4644] = {.lex_state = 371},
  [4645] = {.lex_state = 371},
  [4646] = {.lex_state = 371},
  [4647] = {.lex_state = 371},
  [4648] = {.lex_state = 371},
  [4649] = {.lex_state = 371},
  [4650] = {.lex_state = 371},
  [4651] = {.lex_state = 371},
  [4652] = {.lex_state = 371},
  [4653] = {.lex_state = 371},
  [4654] = {.lex_state = 371},
  [4655] = {.lex_state = 371},
  [4656] = {.lex_state = 371},
  [4657] = {.lex_state = 371},
  [4658] = {.lex_state = 371},
  [4659] = {.lex_state = 371},
  [4660] = {.lex_state = 371},
  [4661] = {.lex_state = 371},
  [4662] = {.lex_state = 371},
  [4663] = {.lex_state = 371},
  [4664] = {.lex_state = 371},
  [4665] = {.lex_state = 371},
  [4666] = {.lex_state = 371},
  [4667] = {.lex_state = 371},
  [4668] = {.lex_state = 371},
  [4669] = {.lex_state = 371},
  [4670] = {.lex_state = 371},
  [4671] = {.lex_state = 371},
  [4672] = {.lex_state = 371},
  [4673] = {.lex_state = 371},
  [4674] = {.lex_state = 371},
  [4675] = {.lex_state = 371},
  [4676] = {.lex_state = 371},
  [4677] = {.lex_state = 371},
  [4678] = {.lex_state = 371},
  [4679] = {.lex_state = 371},
  [4680] = {.lex_state = 371},
  [4681] = {.lex_state = 371},
  [4682] = {.lex_state = 371},
  [4683] = {.lex_state = 371},
  [4684] = {.lex_state = 371},
  [4685] = {.lex_state = 371},
  [4686] = {.lex_state = 371},
  [4687] = {.lex_state = 371},
  [4688] = {.lex_state = 371},
  [4689] = {.lex_state = 371},
  [4690] = {.lex_state = 371},
  [4691] = {.lex_state = 371},
  [4692] = {.lex_state = 371},
  [4693] = {.lex_state = 371},
  [4694] = {.lex_state = 371},
  [4695] = {.lex_state = 371},
  [4696] = {.lex_state = 371},
  [4697] = {.lex_state = 371},
  [4698] = {.lex_state = 371},
  [4699] = {.lex_state = 371},
  [4700] = {.lex_state = 371},
  [4701] = {.lex_state = 371},
  [4702] = {.lex_state = 371},
  [4703] = {.lex_state = 371},
  [4704] = {.lex_state = 371},
  [4705] = {.lex_state = 371},
  [4706] = {.lex_state = 371},
  [4707] = {.lex_state = 371},
  [4708] = {.lex_state = 371},
  [4709] = {.lex_state = 371},
  [4710] = {.lex_state = 371},
  [4711] = {.lex_state = 371},
  [4712] = {.lex_state = 371},
  [4713] = {.lex_state = 371},
  [4714] = {.lex_state = 371},
  [4715] = {.lex_state = 371},
  [4716] = {.lex_state = 371},
  [4717] = {.lex_state = 371},
  [4718] = {.lex_state = 371},
  [4719] = {.lex_state = 371},
  [4720] = {.lex_state = 371},
  [4721] = {.lex_state = 371},
  [4722] = {.lex_state = 371},
  [4723] = {.lex_state = 371},
  [4724] = {.lex_state = 371},
  [4725] = {.lex_state = 371},
  [4726] = {.lex_state = 371},
  [4727] = {.lex_state = 371},
  [4728] = {.lex_state = 371},
  [4729] = {.lex_state = 371},
  [4730] = {.lex_state = 371},
  [4731] = {.lex_state = 371},
  [4732] = {.lex_state = 371},
  [4733] = {.lex_state = 44},
  [4734] = {.lex_state = 371},
  [4735] = {.lex_state = 371},
  [4736] = {.lex_state = 371},
  [4737] = {.lex_state = 371},
  [4738] = {.lex_state = 371},
  [4739] = {.lex_state = 371},
  [4740] = {.lex_state = 371},
  [4741] = {.lex_state = 371},
  [4742] = {.lex_state = 371},
  [4743] = {.lex_state = 371},
  [4744] = {.lex_state = 371},
  [4745] = {.lex_state = 371},
  [4746] = {.lex_state = 371},
  [4747] = {.lex_state = 371},
  [4748] = {.lex_state = 371},
  [4749] = {.lex_state = 371},
  [4750] = {.lex_state = 371},
  [4751] = {.lex_state = 371},
  [4752] = {.lex_state = 371},
  [4753] = {.lex_state = 371},
  [4754] = {.lex_state = 371},
  [4755] = {.lex_state = 371},
  [4756] = {.lex_state = 371},
  [4757] = {.lex_state = 371},
  [4758] = {.lex_state = 371},
  [4759] = {.lex_state = 371},
  [4760] = {.lex_state = 371},
  [4761] = {.lex_state = 371},
  [4762] = {.lex_state = 371},
  [4763] = {.lex_state = 371},
  [4764] = {.lex_state = 371},
  [4765] = {.lex_state = 371},
  [4766] = {.lex_state = 371},
  [4767] = {.lex_state = 371},
  [4768] = {.lex_state = 371},
  [4769] = {.lex_state = 371},
  [4770] = {.lex_state = 371},
  [4771] = {.lex_state = 371},
  [4772] = {.lex_state = 371},
  [4773] = {.lex_state = 371},
  [4774] = {.lex_state = 371},
  [4775] = {.lex_state = 371},
  [4776] = {.lex_state = 371},
  [4777] = {.lex_state = 371},
  [4778] = {.lex_state = 371},
  [4779] = {.lex_state = 371},
  [4780] = {.lex_state = 371},
  [4781] = {.lex_state = 371},
  [4782] = {.lex_state = 371},
  [4783] = {.lex_state = 371},
  [4784] = {.lex_state = 371},
  [4785] = {.lex_state = 371},
  [4786] = {.lex_state = 371},
  [4787] = {.lex_state = 371},
  [4788] = {.lex_state = 371},
  [4789] = {.lex_state = 371},
  [4790] = {.lex_state = 371},
  [4791] = {.lex_state = 371},
  [4792] = {.lex_state = 371},
  [4793] = {.lex_state = 371},
  [4794] = {.lex_state = 371},
  [4795] = {.lex_state = 371},
  [4796] = {.lex_state = 371},
  [4797] = {.lex_state = 371},
  [4798] = {.lex_state = 371},
  [4799] = {.lex_state = 371},
  [4800] = {.lex_state = 371},
  [4801] = {.lex_state = 371},
  [4802] = {.lex_state = 371},
  [4803] = {.lex_state = 371},
  [4804] = {.lex_state = 371},
  [4805] = {.lex_state = 371},
  [4806] = {.lex_state = 371},
  [4807] = {.lex_state = 371},
  [4808] = {.lex_state = 371},
  [4809] = {.lex_state = 371},
  [4810] = {.lex_state = 371},
  [4811] = {.lex_state = 371},
  [4812] = {.lex_state = 371},
  [4813] = {.lex_state = 371},
  [4814] = {.lex_state = 371},
  [4815] = {.lex_state = 371},
  [4816] = {.lex_state = 371},
  [4817] = {.lex_state = 371},
  [4818] = {.lex_state = 371},
  [4819] = {.lex_state = 371},
  [4820] = {.lex_state = 371},
  [4821] = {.lex_state = 371},
  [4822] = {.lex_state = 371},
  [4823] = {.lex_state = 371},
  [4824] = {.lex_state = 371},
  [4825] = {.lex_state = 371},
  [4826] = {.lex_state = 371},
  [4827] = {.lex_state = 371},
  [4828] = {.lex_state = 371},
  [4829] = {.lex_state = 371},
  [4830] = {.lex_state = 371},
  [4831] = {.lex_state = 371},
  [4832] = {.lex_state = 371},
  [4833] = {.lex_state = 371},
  [4834] = {.lex_state = 371},
  [4835] = {.lex_state = 371},
  [4836] = {.lex_state = 371},
  [4837] = {.lex_state = 371},
  [4838] = {.lex_state = 371},
  [4839] = {.lex_state = 371},
  [4840] = {.lex_state = 371},
  [4841] = {.lex_state = 371},
  [4842] = {.lex_state = 371},
  [4843] = {.lex_state = 371},
  [4844] = {.lex_state = 371},
  [4845] = {.lex_state = 371},
  [4846] = {.lex_state = 371},
  [4847] = {.lex_state = 371},
  [4848] = {.lex_state = 371},
  [4849] = {.lex_state = 371},
  [4850] = {.lex_state = 371},
  [4851] = {.lex_state = 371},
  [4852] = {.lex_state = 371},
  [4853] = {.lex_state = 371},
  [4854] = {.lex_state = 371},
  [4855] = {.lex_state = 371},
  [4856] = {.lex_state = 371},
  [4857] = {.lex_state = 371},
  [4858] = {.lex_state = 371},
  [4859] = {.lex_state = 371},
  [4860] = {.lex_state = 371},
  [4861] = {.lex_state = 371},
  [4862] = {.lex_state = 371},
  [4863] = {.lex_state = 371},
  [4864] = {.lex_state = 371},
  [4865] = {.lex_state = 371},
  [4866] = {.lex_state = 371},
  [4867] = {.lex_state = 371},
  [4868] = {.lex_state = 371},
  [4869] = {.lex_state = 371},
  [4870] = {.lex_state = 371},
  [4871] = {.lex_state = 371},
  [4872] = {.lex_state = 371},
  [4873] = {.lex_state = 371},
  [4874] = {.lex_state = 371},
  [4875] = {.lex_state = 371},
  [4876] = {.lex_state = 371},
  [4877] = {.lex_state = 371},
  [4878] = {.lex_state = 371},
  [4879] = {.lex_state = 371},
  [4880] = {.lex_state = 371},
  [4881] = {.lex_state = 371},
  [4882] = {.lex_state = 371},
  [4883] = {.lex_state = 371},
  [4884] = {.lex_state = 371},
  [4885] = {.lex_state = 371},
  [4886] = {.lex_state = 371},
  [4887] = {.lex_state = 371},
  [4888] = {.lex_state = 371},
  [4889] = {.lex_state = 371},
  [4890] = {.lex_state = 371},
  [4891] = {.lex_state = 371},
  [4892] = {.lex_state = 371},
  [4893] = {.lex_state = 371},
  [4894] = {.lex_state = 371},
  [4895] = {.lex_state = 371},
  [4896] = {.lex_state = 371},
  [4897] = {.lex_state = 371},
  [4898] = {.lex_state = 371},
  [4899] = {.lex_state = 371},
  [4900] = {.lex_state = 371},
  [4901] = {.lex_state = 371},
  [4902] = {.lex_state = 371},
  [4903] = {.lex_state = 371},
  [4904] = {.lex_state = 371},
  [4905] = {.lex_state = 371},
  [4906] = {.lex_state = 371},
  [4907] = {.lex_state = 371},
  [4908] = {.lex_state = 371},
  [4909] = {.lex_state = 371},
  [4910] = {.lex_state = 371},
  [4911] = {.lex_state = 371},
  [4912] = {.lex_state = 371},
  [4913] = {.lex_state = 371},
  [4914] = {.lex_state = 371},
  [4915] = {.lex_state = 371},
  [4916] = {.lex_state = 371},
  [4917] = {.lex_state = 371},
  [4918] = {.lex_state = 371},
  [4919] = {.lex_state = 371},
  [4920] = {.lex_state = 371},
  [4921] = {.lex_state = 371},
  [4922] = {.lex_state = 371},
  [4923] = {.lex_state = 371},
  [4924] = {.lex_state = 371},
  [4925] = {.lex_state = 371},
  [4926] = {.lex_state = 371},
  [4927] = {.lex_state = 371},
  [4928] = {.lex_state = 371},
  [4929] = {.lex_state = 371},
  [4930] = {.lex_state = 371},
  [4931] = {.lex_state = 371},
  [4932] = {.lex_state = 371},
  [4933] = {.lex_state = 371},
  [4934] = {.lex_state = 371},
  [4935] = {.lex_state = 371},
  [4936] = {.lex_state = 371},
  [4937] = {.lex_state = 371},
  [4938] = {.lex_state = 371},
  [4939] = {.lex_state = 371},
  [4940] = {.lex_state = 371},
  [4941] = {.lex_state = 371},
  [4942] = {.lex_state = 371},
  [4943] = {.lex_state = 371},
  [4944] = {.lex_state = 371},
  [4945] = {.lex_state = 371},
  [4946] = {.lex_state = 371},
  [4947] = {.lex_state = 371},
  [4948] = {.lex_state = 371},
  [4949] = {.lex_state = 371},
  [4950] = {.lex_state = 371},
  [4951] = {.lex_state = 371},
  [4952] = {.lex_state = 371},
  [4953] = {.lex_state = 371},
  [4954] = {.lex_state = 371},
  [4955] = {.lex_state = 371},
  [4956] = {.lex_state = 371},
  [4957] = {.lex_state = 371},
  [4958] = {.lex_state = 371},
  [4959] = {.lex_state = 371},
  [4960] = {.lex_state = 371},
  [4961] = {.lex_state = 371},
  [4962] = {.lex_state = 371},
  [4963] = {.lex_state = 371},
  [4964] = {.lex_state = 371},
  [4965] = {.lex_state = 371},
  [4966] = {.lex_state = 371},
  [4967] = {.lex_state = 371},
  [4968] = {.lex_state = 371},
  [4969] = {.lex_state = 371},
  [4970] = {.lex_state = 371},
  [4971] = {.lex_state = 371},
  [4972] = {.lex_state = 371},
  [4973] = {.lex_state = 371},
  [4974] = {.lex_state = 371},
  [4975] = {.lex_state = 371},
  [4976] = {.lex_state = 371},
  [4977] = {.lex_state = 371},
  [4978] = {.lex_state = 371},
  [4979] = {.lex_state = 371},
  [4980] = {.lex_state = 371},
  [4981] = {.lex_state = 371},
  [4982] = {.lex_state = 371},
  [4983] = {.lex_state = 371},
  [4984] = {.lex_state = 371},
  [4985] = {.lex_state = 371},
  [4986] = {.lex_state = 371},
  [4987] = {.lex_state = 371},
  [4988] = {.lex_state = 371},
  [4989] = {.lex_state = 371},
  [4990] = {.lex_state = 371},
  [4991] = {.lex_state = 371},
  [4992] = {.lex_state = 371},
  [4993] = {.lex_state = 371},
  [4994] = {.lex_state = 371},
  [4995] = {.lex_state = 371},
  [4996] = {.lex_state = 371},
  [4997] = {.lex_state = 371},
  [4998] = {.lex_state = 371},
  [4999] = {.lex_state = 371},
  [5000] = {.lex_state = 371},
  [5001] = {.lex_state = 371},
  [5002] = {.lex_state = 371},
  [5003] = {.lex_state = 371},
  [5004] = {.lex_state = 371},
  [5005] = {.lex_state = 371},
  [5006] = {.lex_state = 371},
  [5007] = {.lex_state = 371},
  [5008] = {.lex_state = 371},
  [5009] = {.lex_state = 371},
  [5010] = {.lex_state = 371},
  [5011] = {.lex_state = 371},
  [5012] = {.lex_state = 371},
  [5013] = {.lex_state = 371},
  [5014] = {.lex_state = 371},
  [5015] = {.lex_state = 371},
  [5016] = {.lex_state = 371},
  [5017] = {.lex_state = 371},
  [5018] = {.lex_state = 371},
  [5019] = {.lex_state = 371},
  [5020] = {.lex_state = 371},
  [5021] = {.lex_state = 371},
  [5022] = {.lex_state = 371},
  [5023] = {.lex_state = 371},
  [5024] = {.lex_state = 371},
  [5025] = {.lex_state = 371},
  [5026] = {.lex_state = 371},
  [5027] = {.lex_state = 371},
  [5028] = {.lex_state = 371},
  [5029] = {.lex_state = 371},
  [5030] = {.lex_state = 371},
  [5031] = {.lex_state = 371},
  [5032] = {.lex_state = 371},
  [5033] = {.lex_state = 371},
  [5034] = {.lex_state = 371},
  [5035] = {.lex_state = 371},
  [5036] = {.lex_state = 371},
  [5037] = {.lex_state = 371},
  [5038] = {.lex_state = 371},
  [5039] = {.lex_state = 371},
  [5040] = {.lex_state = 371},
  [5041] = {.lex_state = 371},
  [5042] = {.lex_state = 371},
  [5043] = {.lex_state = 371},
  [5044] = {.lex_state = 371},
  [5045] = {.lex_state = 371},
  [5046] = {.lex_state = 371},
  [5047] = {.lex_state = 371},
  [5048] = {.lex_state = 371},
  [5049] = {.lex_state = 371},
  [5050] = {.lex_state = 371},
  [5051] = {.lex_state = 371},
  [5052] = {.lex_state = 371},
  [5053] = {.lex_state = 371},
  [5054] = {.lex_state = 371},
  [5055] = {.lex_state = 371},
  [5056] = {.lex_state = 371},
  [5057] = {.lex_state = 371},
  [5058] = {.lex_state = 371},
  [5059] = {.lex_state = 371},
  [5060] = {.lex_state = 371},
  [5061] = {.lex_state = 371},
  [5062] = {.lex_state = 371},
  [5063] = {.lex_state = 371},
  [5064] = {.lex_state = 371},
  [5065] = {.lex_state = 371},
  [5066] = {.lex_state = 371},
  [5067] = {.lex_state = 371},
  [5068] = {.lex_state = 371},
  [5069] = {.lex_state = 371},
  [5070] = {.lex_state = 371},
  [5071] = {.lex_state = 371},
  [5072] = {.lex_state = 371},
  [5073] = {.lex_state = 371},
  [5074] = {.lex_state = 371},
  [5075] = {.lex_state = 371},
  [5076] = {.lex_state = 371},
  [5077] = {.lex_state = 371},
  [5078] = {.lex_state = 371},
  [5079] = {.lex_state = 371},
  [5080] = {.lex_state = 371},
  [5081] = {.lex_state = 371},
  [5082] = {.lex_state = 371},
  [5083] = {.lex_state = 371},
  [5084] = {.lex_state = 371},
  [5085] = {.lex_state = 371},
  [5086] = {.lex_state = 371},
  [5087] = {.lex_state = 371},
  [5088] = {.lex_state = 371},
  [5089] = {.lex_state = 371},
  [5090] = {.lex_state = 371},
  [5091] = {.lex_state = 371},
  [5092] = {.lex_state = 371},
  [5093] = {.lex_state = 371},
  [5094] = {.lex_state = 371},
  [5095] = {.lex_state = 371},
  [5096] = {.lex_state = 371},
  [5097] = {.lex_state = 371},
  [5098] = {.lex_state = 371},
  [5099] = {.lex_state = 371},
  [5100] = {.lex_state = 371},
  [5101] = {.lex_state = 371},
  [5102] = {.lex_state = 371},
  [5103] = {.lex_state = 371},
  [5104] = {.lex_state = 371},
  [5105] = {.lex_state = 371},
  [5106] = {.lex_state = 371},
  [5107] = {.lex_state = 371},
  [5108] = {.lex_state = 371},
  [5109] = {.lex_state = 371},
  [5110] = {.lex_state = 371},
  [5111] = {.lex_state = 371},
  [5112] = {.lex_state = 371},
  [5113] = {.lex_state = 371},
  [5114] = {.lex_state = 371},
  [5115] = {.lex_state = 371},
  [5116] = {.lex_state = 371},
  [5117] = {.lex_state = 371},
  [5118] = {.lex_state = 371},
  [5119] = {.lex_state = 371},
  [5120] = {.lex_state = 371},
  [5121] = {.lex_state = 371},
  [5122] = {.lex_state = 371},
  [5123] = {.lex_state = 371},
  [5124] = {.lex_state = 371},
  [5125] = {.lex_state = 371},
  [5126] = {.lex_state = 371},
  [5127] = {.lex_state = 371},
  [5128] = {.lex_state = 371},
  [5129] = {.lex_state = 371},
  [5130] = {.lex_state = 371},
  [5131] = {.lex_state = 371},
  [5132] = {.lex_state = 371},
  [5133] = {.lex_state = 371},
  [5134] = {.lex_state = 371},
  [5135] = {.lex_state = 371},
  [5136] = {.lex_state = 371},
  [5137] = {.lex_state = 371},
  [5138] = {.lex_state = 371},
  [5139] = {.lex_state = 371},
  [5140] = {.lex_state = 371},
  [5141] = {.lex_state = 371},
  [5142] = {.lex_state = 371},
  [5143] = {.lex_state = 371},
  [5144] = {.lex_state = 371},
  [5145] = {.lex_state = 371},
  [5146] = {.lex_state = 371},
  [5147] = {.lex_state = 371},
  [5148] = {.lex_state = 371},
  [5149] = {.lex_state = 371},
  [5150] = {.lex_state = 371},
  [5151] = {.lex_state = 371},
  [5152] = {.lex_state = 371},
  [5153] = {.lex_state = 371},
  [5154] = {.lex_state = 371},
  [5155] = {.lex_state = 371},
  [5156] = {.lex_state = 371},
  [5157] = {.lex_state = 371},
  [5158] = {.lex_state = 371},
  [5159] = {.lex_state = 371},
  [5160] = {.lex_state = 371},
  [5161] = {.lex_state = 371},
  [5162] = {.lex_state = 371},
  [5163] = {.lex_state = 371},
  [5164] = {.lex_state = 371},
  [5165] = {.lex_state = 371},
  [5166] = {.lex_state = 371},
  [5167] = {.lex_state = 371},
  [5168] = {.lex_state = 371},
  [5169] = {.lex_state = 371},
  [5170] = {.lex_state = 371},
  [5171] = {.lex_state = 371},
  [5172] = {.lex_state = 371},
  [5173] = {.lex_state = 371},
  [5174] = {.lex_state = 371},
  [5175] = {.lex_state = 371},
  [5176] = {.lex_state = 371},
  [5177] = {.lex_state = 371},
  [5178] = {.lex_state = 371},
  [5179] = {.lex_state = 371},
  [5180] = {.lex_state = 371},
  [5181] = {.lex_state = 371},
  [5182] = {.lex_state = 371},
  [5183] = {.lex_state = 371},
  [5184] = {.lex_state = 371},
  [5185] = {.lex_state = 371},
  [5186] = {.lex_state = 371},
  [5187] = {.lex_state = 371},
  [5188] = {.lex_state = 371},
  [5189] = {.lex_state = 371},
  [5190] = {.lex_state = 371},
  [5191] = {.lex_state = 371},
  [5192] = {.lex_state = 371},
  [5193] = {.lex_state = 371},
  [5194] = {.lex_state = 371},
  [5195] = {.lex_state = 371},
  [5196] = {.lex_state = 371},
  [5197] = {.lex_state = 371},
  [5198] = {.lex_state = 371},
  [5199] = {.lex_state = 371},
  [5200] = {.lex_state = 371},
  [5201] = {.lex_state = 371},
  [5202] = {.lex_state = 371},
  [5203] = {.lex_state = 371},
  [5204] = {.lex_state = 371},
  [5205] = {.lex_state = 371},
  [5206] = {.lex_state = 371},
  [5207] = {.lex_state = 371},
  [5208] = {.lex_state = 371},
  [5209] = {.lex_state = 371},
  [5210] = {.lex_state = 371},
  [5211] = {.lex_state = 371},
  [5212] = {.lex_state = 371},
  [5213] = {.lex_state = 371},
  [5214] = {.lex_state = 371},
  [5215] = {.lex_state = 371},
  [5216] = {.lex_state = 371},
  [5217] = {.lex_state = 371},
  [5218] = {.lex_state = 371},
  [5219] = {.lex_state = 371},
  [5220] = {.lex_state = 371},
  [5221] = {.lex_state = 7},
  [5222] = {.lex_state = 371},
  [5223] = {.lex_state = 7},
  [5224] = {.lex_state = 44},
  [5225] = {.lex_state = 44},
  [5226] = {.lex_state = 24},
  [5227] = {.lex_state = 24},
  [5228] = {.lex_state = 24},
  [5229] = {.lex_state = 43},
  [5230] = {.lex_state = 24},
  [5231] = {.lex_state = 24},
  [5232] = {.lex_state = 9},
  [5233] = {.lex_state = 24},
  [5234] = {.lex_state = 24},
  [5235] = {.lex_state = 9},
  [5236] = {.lex_state = 9},
  [5237] = {.lex_state = 9},
  [5238] = {.lex_state = 7},
  [5239] = {.lex_state = 7},
  [5240] = {.lex_state = 7},
  [5241] = {.lex_state = 10},
  [5242] = {.lex_state = 7},
  [5243] = {.lex_state = 7},
  [5244] = {.lex_state = 7},
  [5245] = {.lex_state = 7},
  [5246] = {.lex_state = 7},
  [5247] = {.lex_state = 7},
  [5248] = {.lex_state = 7},
  [5249] = {.lex_state = 7},
  [5250] = {.lex_state = 7},
  [5251] = {.lex_state = 7},
  [5252] = {.lex_state = 7},
  [5253] = {.lex_state = 7},
  [5254] = {.lex_state = 7},
  [5255] = {.lex_state = 7},
  [5256] = {.lex_state = 7},
  [5257] = {.lex_state = 7},
  [5258] = {.lex_state = 7},
  [5259] = {.lex_state = 7},
  [5260] = {.lex_state = 7},
  [5261] = {.lex_state = 10},
  [5262] = {.lex_state = 7},
  [5263] = {.lex_state = 7},
  [5264] = {.lex_state = 7},
  [5265] = {.lex_state = 7},
  [5266] = {.lex_state = 9},
  [5267] = {.lex_state = 7},
  [5268] = {.lex_state = 7},
  [5269] = {.lex_state = 7},
  [5270] = {.lex_state = 7},
  [5271] = {.lex_state = 7},
  [5272] = {.lex_state = 7},
  [5273] = {.lex_state = 7},
  [5274] = {.lex_state = 7},
  [5275] = {.lex_state = 7},
  [5276] = {.lex_state = 7},
  [5277] = {.lex_state = 7},
  [5278] = {.lex_state = 7},
  [5279] = {.lex_state = 7},
  [5280] = {.lex_state = 7},
  [5281] = {.lex_state = 7},
  [5282] = {.lex_state = 7},
  [5283] = {.lex_state = 7},
  [5284] = {.lex_state = 7},
  [5285] = {.lex_state = 7},
  [5286] = {.lex_state = 7},
  [5287] = {.lex_state = 7},
  [5288] = {.lex_state = 7},
  [5289] = {.lex_state = 8},
  [5290] = {.lex_state = 8},
  [5291] = {.lex_state = 9},
  [5292] = {.lex_state = 7},
  [5293] = {.lex_state = 7},
  [5294] = {.lex_state = 9},
  [5295] = {.lex_state = 10},
  [5296] = {.lex_state = 41},
  [5297] = {.lex_state = 9},
  [5298] = {.lex_state = 9},
  [5299] = {.lex_state = 39},
  [5300] = {.lex_state = 39},
  [5301] = {.lex_state = 10},
  [5302] = {.lex_state = 9},
  [5303] = {.lex_state = 9},
  [5304] = {.lex_state = 9},
  [5305] = {.lex_state = 9},
  [5306] = {.lex_state = 9},
  [5307] = {.lex_state = 10},
  [5308] = {.lex_state = 9},
  [5309] = {.lex_state = 9},
  [5310] = {.lex_state = 7},
  [5311] = {.lex_state = 9},
  [5312] = {.lex_state = 7},
  [5313] = {.lex_state = 7},
  [5314] = {.lex_state = 7},
  [5315] = {.lex_state = 9},
  [5316] = {.lex_state = 9},
  [5317] = {.lex_state = 50},
  [5318] = {.lex_state = 50},
  [5319] = {.lex_state = 50},
  [5320] = {.lex_state = 50},
  [5321] = {.lex_state = 50},
  [5322] = {.lex_state = 50},
  [5323] = {.lex_state = 50},
  [5324] = {.lex_state = 50},
  [5325] = {.lex_state = 50},
  [5326] = {.lex_state = 50},
  [5327] = {.lex_state = 50},
  [5328] = {.lex_state = 50},
  [5329] = {.lex_state = 50},
  [5330] = {.lex_state = 50},
  [5331] = {.lex_state = 50},
  [5332] = {.lex_state = 50},
  [5333] = {.lex_state = 50},
  [5334] = {.lex_state = 50},
  [5335] = {.lex_state = 50},
  [5336] = {.lex_state = 50},
  [5337] = {.lex_state = 50},
  [5338] = {.lex_state = 50},
  [5339] = {.lex_state = 50},
  [5340] = {.lex_state = 50},
  [5341] = {.lex_state = 50},
  [5342] = {.lex_state = 50},
  [5343] = {.lex_state = 50},
  [5344] = {.lex_state = 50},
  [5345] = {.lex_state = 50},
  [5346] = {.lex_state = 50},
  [5347] = {.lex_state = 50},
  [5348] = {.lex_state = 50},
  [5349] = {.lex_state = 50},
  [5350] = {.lex_state = 50},
  [5351] = {.lex_state = 50},
  [5352] = {.lex_state = 50},
  [5353] = {.lex_state = 50},
  [5354] = {.lex_state = 50},
  [5355] = {.lex_state = 50},
  [5356] = {.lex_state = 50},
  [5357] = {.lex_state = 50},
  [5358] = {.lex_state = 50},
  [5359] = {.lex_state = 50},
  [5360] = {.lex_state = 50},
  [5361] = {.lex_state = 50},
  [5362] = {.lex_state = 50},
  [5363] = {.lex_state = 9},
  [5364] = {.lex_state = 9},
  [5365] = {.lex_state = 9},
  [5366] = {.lex_state = 9},
  [5367] = {.lex_state = 8},
  [5368] = {.lex_state = 8},
  [5369] = {.lex_state = 8},
  [5370] = {.lex_state = 9},
  [5371] = {.lex_state = 9},
  [5372] = {.lex_state = 9},
  [5373] = {.lex_state = 10},
  [5374] = {.lex_state = 371},
  [5375] = {.lex_state = 10},
  [5376] = {.lex_state = 10},
  [5377] = {.lex_state = 371},
  [5378] = {.lex_state = 9},
  [5379] = {.lex_state = 10},
  [5380] = {.lex_state = 9},
  [5381] = {.lex_state = 371},
  [5382] = {.lex_state = 371},
  [5383] = {.lex_state = 10},
  [5384] = {.lex_state = 9},
  [5385] = {.lex_state = 371},
  [5386] = {.lex_state = 371},
  [5387] = {.lex_state = 9},
  [5388] = {.lex_state = 9},
  [5389] = {.lex_state = 9},
  [5390] = {.lex_state = 10},
  [5391] = {.lex_state = 10},
  [5392] = {.lex_state = 10},
  [5393] = {.lex_state = 10},
  [5394] = {.lex_state = 371},
  [5395] = {.lex_state = 9},
  [5396] = {.lex_state = 9},
  [5397] = {.lex_state = 15},
  [5398] = {.lex_state = 9},
  [5399] = {.lex_state = 9},
  [5400] = {.lex_state = 50},
  [5401] = {.lex_state = 50},
  [5402] = {.lex_state = 50},
  [5403] = {.lex_state = 50},
  [5404] = {.lex_state = 9},
  [5405] = {.lex_state = 50},
  [5406] = {.lex_state = 50},
  [5407] = {.lex_state = 9},
  [5408] = {.lex_state = 50},
  [5409] = {.lex_state = 9},
  [5410] = {.lex_state = 50},
  [5411] = {.lex_state = 50},
  [5412] = {.lex_state = 50},
  [5413] = {.lex_state = 50},
  [5414] = {.lex_state = 9},
  [5415] = {.lex_state = 50},
  [5416] = {.lex_state = 50},
  [5417] = {.lex_state = 9},
  [5418] = {.lex_state = 9},
  [5419] = {.lex_state = 12},
  [5420] = {.lex_state = 50},
  [5421] = {.lex_state = 50},
  [5422] = {.lex_state = 50},
  [5423] = {.lex_state = 50},
  [5424] = {.lex_state = 50},
  [5425] = {.lex_state = 12},
  [5426] = {.lex_state = 50},
  [5427] = {.lex_state = 9},
  [5428] = {.lex_state = 50},
  [5429] = {.lex_state = 9},
  [5430] = {.lex_state = 50},
  [5431] = {.lex_state = 50},
  [5432] = {.lex_state = 9},
  [5433] = {.lex_state = 9},
  [5434] = {.lex_state = 50},
  [5435] = {.lex_state = 50},
  [5436] = {.lex_state = 9},
  [5437] = {.lex_state = 9},
  [5438] = {.lex_state = 9},
  [5439] = {.lex_state = 371},
  [5440] = {.lex_state = 9},
  [5441] = {.lex_state = 371},
  [5442] = {.lex_state = 9},
  [5443] = {.lex_state = 9},
  [5444] = {.lex_state = 9},
  [5445] = {.lex_state = 371},
  [5446] = {.lex_state = 371},
  [5447] = {.lex_state = 9},
  [5448] = {.lex_state = 371},
  [5449] = {.lex_state = 371},
  [5450] = {.lex_state = 371},
  [5451] = {.lex_state = 371},
  [5452] = {.lex_state = 371},
  [5453] = {.lex_state = 371},
  [5454] = {.lex_state = 371},
  [5455] = {.lex_state = 371},
  [5456] = {.lex_state = 15},
  [5457] = {.lex_state = 371},
  [5458] = {.lex_state = 371},
  [5459] = {.lex_state = 371},
  [5460] = {.lex_state = 9},
  [5461] = {.lex_state = 9},
  [5462] = {.lex_state = 371},
  [5463] = {.lex_state = 9},
  [5464] = {.lex_state = 10},
  [5465] = {.lex_state = 371},
  [5466] = {.lex_state = 371},
  [5467] = {.lex_state = 371},
  [5468] = {.lex_state = 10},
  [5469] = {.lex_state = 371},
  [5470] = {.lex_state = 371},
  [5471] = {.lex_state = 371},
  [5472] = {.lex_state = 10},
  [5473] = {.lex_state = 371},
  [5474] = {.lex_state = 8},
  [5475] = {.lex_state = 8},
  [5476] = {.lex_state = 9},
  [5477] = {.lex_state = 9},
  [5478] = {.lex_state = 10},
  [5479] = {.lex_state = 50},
  [5480] = {.lex_state = 8},
  [5481] = {.lex_state = 9},
  [5482] = {.lex_state = 371},
  [5483] = {.lex_state = 9},
  [5484] = {.lex_state = 371},
  [5485] = {.lex_state = 9},
  [5486] = {.lex_state = 8},
  [5487] = {.lex_state = 371},
  [5488] = {.lex_state = 50},
  [5489] = {.lex_state = 371},
  [5490] = {.lex_state = 371},
  [5491] = {.lex_state = 371},
  [5492] = {.lex_state = 8},
  [5493] = {.lex_state = 371},
  [5494] = {.lex_state = 371},
  [5495] = {.lex_state = 9},
  [5496] = {.lex_state = 8},
  [5497] = {.lex_state = 8},
  [5498] = {.lex_state = 371},
  [5499] = {.lex_state = 371},
  [5500] = {.lex_state = 50},
  [5501] = {.lex_state = 371},
  [5502] = {.lex_state = 371},
  [5503] = {.lex_state = 50},
  [5504] = {.lex_state = 50},
  [5505] = {.lex_state = 371},
  [5506] = {.lex_state = 10},
  [5507] = {.lex_state = 371},
  [5508] = {.lex_state = 371},
  [5509] = {.lex_state = 10},
  [5510] = {.lex_state = 371},
  [5511] = {.lex_state = 371},
  [5512] = {.lex_state = 50},
  [5513] = {.lex_state = 8},
  [5514] = {.lex_state = 8},
  [5515] = {.lex_state = 10},
  [5516] = {.lex_state = 8},
  [5517] = {.lex_state = 10},
  [5518] = {.lex_state = 8},
  [5519] = {.lex_state = 10},
  [5520] = {.lex_state = 10},
  [5521] = {.lex_state = 9},
  [5522] = {.lex_state = 10},
  [5523] = {.lex_state = 8},
  [5524] = {.lex_state = 10},
  [5525] = {.lex_state = 10},
  [5526] = {.lex_state = 8},
  [5527] = {.lex_state = 8},
  [5528] = {.lex_state = 10},
  [5529] = {.lex_state = 10},
  [5530] = {.lex_state = 8},
  [5531] = {.lex_state = 8},
  [5532] = {.lex_state = 8},
  [5533] = {.lex_state = 8},
  [5534] = {.lex_state = 8},
  [5535] = {.lex_state = 8},
  [5536] = {.lex_state = 8},
  [5537] = {.lex_state = 8},
  [5538] = {.lex_state = 8},
  [5539] = {.lex_state = 8},
  [5540] = {.lex_state = 8},
  [5541] = {.lex_state = 10},
  [5542] = {.lex_state = 50},
  [5543] = {.lex_state = 8},
  [5544] = {.lex_state = 8},
  [5545] = {.lex_state = 8},
  [5546] = {.lex_state = 8},
  [5547] = {.lex_state = 8},
  [5548] = {.lex_state = 8},
  [5549] = {.lex_state = 8},
  [5550] = {.lex_state = 8},
  [5551] = {.lex_state = 8},
  [5552] = {.lex_state = 13},
  [5553] = {.lex_state = 8},
  [5554] = {.lex_state = 8},
  [5555] = {.lex_state = 8},
  [5556] = {.lex_state = 8},
  [5557] = {.lex_state = 8},
  [5558] = {.lex_state = 13},
  [5559] = {.lex_state = 8},
  [5560] = {.lex_state = 8},
  [5561] = {.lex_state = 8},
  [5562] = {.lex_state = 8},
  [5563] = {.lex_state = 8},
  [5564] = {.lex_state = 8},
  [5565] = {.lex_state = 8},
  [5566] = {.lex_state = 8},
  [5567] = {.lex_state = 8},
  [5568] = {.lex_state = 8},
  [5569] = {.lex_state = 8},
  [5570] = {.lex_state = 8},
  [5571] = {.lex_state = 8},
  [5572] = {.lex_state = 8},
  [5573] = {.lex_state = 8},
  [5574] = {.lex_state = 8},
  [5575] = {.lex_state = 8},
  [5576] = {.lex_state = 8},
  [5577] = {.lex_state = 8},
  [5578] = {.lex_state = 8},
  [5579] = {.lex_state = 8},
  [5580] = {.lex_state = 8},
  [5581] = {.lex_state = 8},
  [5582] = {.lex_state = 8},
  [5583] = {.lex_state = 8},
  [5584] = {.lex_state = 8},
  [5585] = {.lex_state = 8},
  [5586] = {.lex_state = 50},
  [5587] = {.lex_state = 8},
  [5588] = {.lex_state = 42},
  [5589] = {.lex_state = 8},
  [5590] = {.lex_state = 8},
  [5591] = {.lex_state = 8},
  [5592] = {.lex_state = 8},
  [5593] = {.lex_state = 8},
  [5594] = {.lex_state = 8},
  [5595] = {.lex_state = 8},
  [5596] = {.lex_state = 8},
  [5597] = {.lex_state = 8},
  [5598] = {.lex_state = 8},
  [5599] = {.lex_state = 8},
  [5600] = {.lex_state = 8},
  [5601] = {.lex_state = 8},
  [5602] = {.lex_state = 8},
  [5603] = {.lex_state = 8},
  [5604] = {.lex_state = 8},
  [5605] = {.lex_state = 8},
  [5606] = {.lex_state = 8},
  [5607] = {.lex_state = 8},
  [5608] = {.lex_state = 8},
  [5609] = {.lex_state = 8},
  [5610] = {.lex_state = 8},
  [5611] = {.lex_state = 8},
  [5612] = {.lex_state = 8},
  [5613] = {.lex_state = 8},
  [5614] = {.lex_state = 8},
  [5615] = {.lex_state = 8},
  [5616] = {.lex_state = 8},
  [5617] = {.lex_state = 8},
  [5618] = {.lex_state = 8},
  [5619] = {.lex_state = 8},
  [5620] = {.lex_state = 8},
  [5621] = {.lex_state = 8},
  [5622] = {.lex_state = 8},
  [5623] = {.lex_state = 8},
  [5624] = {.lex_state = 8},
  [5625] = {.lex_state = 8},
  [5626] = {.lex_state = 8},
  [5627] = {.lex_state = 8},
  [5628] = {.lex_state = 8},
  [5629] = {.lex_state = 8},
  [5630] = {.lex_state = 8},
  [5631] = {.lex_state = 8},
  [5632] = {.lex_state = 8},
  [5633] = {.lex_state = 8},
  [5634] = {.lex_state = 8},
  [5635] = {.lex_state = 8},
  [5636] = {.lex_state = 8},
  [5637] = {.lex_state = 8},
  [5638] = {.lex_state = 8},
  [5639] = {.lex_state = 8},
  [5640] = {.lex_state = 8},
  [5641] = {.lex_state = 8},
  [5642] = {.lex_state = 8},
  [5643] = {.lex_state = 371},
  [5644] = {.lex_state = 8},
  [5645] = {.lex_state = 8},
  [5646] = {.lex_state = 8},
  [5647] = {.lex_state = 371},
  [5648] = {.lex_state = 371},
  [5649] = {.lex_state = 15},
  [5650] = {.lex_state = 371},
  [5651] = {.lex_state = 8},
  [5652] = {.lex_state = 8},
  [5653] = {.lex_state = 8},
  [5654] = {.lex_state = 8},
  [5655] = {.lex_state = 8},
  [5656] = {.lex_state = 8},
  [5657] = {.lex_state = 8},
  [5658] = {.lex_state = 371},
  [5659] = {.lex_state = 8},
  [5660] = {.lex_state = 8},
  [5661] = {.lex_state = 8},
  [5662] = {.lex_state = 8},
  [5663] = {.lex_state = 8},
  [5664] = {.lex_state = 8},
  [5665] = {.lex_state = 8},
  [5666] = {.lex_state = 15},
  [5667] = {.lex_state = 8},
  [5668] = {.lex_state = 8},
  [5669] = {.lex_state = 15},
  [5670] = {.lex_state = 8},
  [5671] = {.lex_state = 8},
  [5672] = {.lex_state = 8},
  [5673] = {.lex_state = 23},
  [5674] = {.lex_state = 8},
  [5675] = {.lex_state = 8},
  [5676] = {.lex_state = 41},
  [5677] = {.lex_state = 8},
  [5678] = {.lex_state = 8},
  [5679] = {.lex_state = 8},
  [5680] = {.lex_state = 8},
  [5681] = {.lex_state = 8},
  [5682] = {.lex_state = 8},
  [5683] = {.lex_state = 8},
  [5684] = {.lex_state = 8},
  [5685] = {.lex_state = 8},
  [5686] = {.lex_state = 8},
  [5687] = {.lex_state = 8},
  [5688] = {.lex_state = 42},
  [5689] = {.lex_state = 42},
  [5690] = {.lex_state = 8},
  [5691] = {.lex_state = 8},
  [5692] = {.lex_state = 8},
  [5693] = {.lex_state = 8},
  [5694] = {.lex_state = 8},
  [5695] = {.lex_state = 8},
  [5696] = {.lex_state = 8},
  [5697] = {.lex_state = 8},
  [5698] = {.lex_state = 8},
  [5699] = {.lex_state = 8},
  [5700] = {.lex_state = 8},
  [5701] = {.lex_state = 8},
  [5702] = {.lex_state = 41},
  [5703] = {.lex_state = 8},
  [5704] = {.lex_state = 41},
  [5705] = {.lex_state = 50},
  [5706] = {.lex_state = 50},
  [5707] = {.lex_state = 50},
  [5708] = {.lex_state = 50},
  [5709] = {.lex_state = 50},
  [5710] = {.lex_state = 50},
  [5711] = {.lex_state = 8},
  [5712] = {.lex_state = 50},
  [5713] = {.lex_state = 50},
  [5714] = {.lex_state = 50},
  [5715] = {.lex_state = 50},
  [5716] = {.lex_state = 50},
  [5717] = {.lex_state = 50},
  [5718] = {.lex_state = 50},
  [5719] = {.lex_state = 50},
  [5720] = {.lex_state = 50},
  [5721] = {.lex_state = 50},
  [5722] = {.lex_state = 50},
  [5723] = {.lex_state = 17},
  [5724] = {.lex_state = 50},
  [5725] = {.lex_state = 50},
  [5726] = {.lex_state = 50},
  [5727] = {.lex_state = 50},
  [5728] = {.lex_state = 50},
  [5729] = {.lex_state = 50},
  [5730] = {.lex_state = 50},
  [5731] = {.lex_state = 41},
  [5732] = {.lex_state = 17},
  [5733] = {.lex_state = 23},
  [5734] = {.lex_state = 23},
  [5735] = {.lex_state = 19},
  [5736] = {.lex_state = 47},
  [5737] = {.lex_state = 17},
  [5738] = {.lex_state = 15},
  [5739] = {.lex_state = 15},
  [5740] = {.lex_state = 15},
  [5741] = {.lex_state = 371},
  [5742] = {.lex_state = 371},
  [5743] = {.lex_state = 371},
  [5744] = {.lex_state = 15},
  [5745] = {.lex_state = 15},
  [5746] = {.lex_state = 371},
  [5747] = {.lex_state = 17},
  [5748] = {.lex_state = 371},
  [5749] = {.lex_state = 16},
  [5750] = {.lex_state = 41},
  [5751] = {.lex_state = 371},
  [5752] = {.lex_state = 19},
  [5753] = {.lex_state = 17},
  [5754] = {.lex_state = 41},
  [5755] = {.lex_state = 47},
  [5756] = {.lex_state = 9},
  [5757] = {.lex_state = 47},
  [5758] = {.lex_state = 17},
  [5759] = {.lex_state = 47},
  [5760] = {.lex_state = 17},
  [5761] = {.lex_state = 17},
  [5762] = {.lex_state = 47},
  [5763] = {.lex_state = 15},
  [5764] = {.lex_state = 15},
  [5765] = {.lex_state = 16},
  [5766] = {.lex_state = 47},
  [5767] = {.lex_state = 15},
  [5768] = {.lex_state = 14},
  [5769] = {.lex_state = 15},
  [5770] = {.lex_state = 19},
  [5771] = {.lex_state = 19},
  [5772] = {.lex_state = 19},
  [5773] = {.lex_state = 17},
  [5774] = {.lex_state = 15},
  [5775] = {.lex_state = 17},
  [5776] = {.lex_state = 15},
  [5777] = {.lex_state = 15},
  [5778] = {.lex_state = 17},
  [5779] = {.lex_state = 15},
  [5780] = {.lex_state = 17},
  [5781] = {.lex_state = 17},
  [5782] = {.lex_state = 15},
  [5783] = {.lex_state = 15},
  [5784] = {.lex_state = 17},
  [5785] = {.lex_state = 17},
  [5786] = {.lex_state = 15},
  [5787] = {.lex_state = 17},
  [5788] = {.lex_state = 15},
  [5789] = {.lex_state = 15},
  [5790] = {.lex_state = 15},
  [5791] = {.lex_state = 15},
  [5792] = {.lex_state = 15},
  [5793] = {.lex_state = 15},
  [5794] = {.lex_state = 15},
  [5795] = {.lex_state = 15},
  [5796] = {.lex_state = 15},
  [5797] = {.lex_state = 15},
  [5798] = {.lex_state = 15},
  [5799] = {.lex_state = 48},
  [5800] = {.lex_state = 20},
  [5801] = {.lex_state = 16},
  [5802] = {.lex_state = 16},
  [5803] = {.lex_state = 16},
  [5804] = {.lex_state = 16},
  [5805] = {.lex_state = 14},
  [5806] = {.lex_state = 16},
  [5807] = {.lex_state = 371},
  [5808] = {.lex_state = 17},
  [5809] = {.lex_state = 17},
  [5810] = {.lex_state = 17},
  [5811] = {.lex_state = 371},
  [5812] = {.lex_state = 371},
  [5813] = {.lex_state = 29},
  [5814] = {.lex_state = 371},
  [5815] = {.lex_state = 17},
  [5816] = {.lex_state = 17},
  [5817] = {.lex_state = 20},
  [5818] = {.lex_state = 19},
  [5819] = {.lex_state = 17},
  [5820] = {.lex_state = 17},
  [5821] = {.lex_state = 17},
  [5822] = {.lex_state = 17},
  [5823] = {.lex_state = 17},
  [5824] = {.lex_state = 48},
  [5825] = {.lex_state = 48},
  [5826] = {.lex_state = 19},
  [5827] = {.lex_state = 17},
  [5828] = {.lex_state = 43},
  [5829] = {.lex_state = 19},
  [5830] = {.lex_state = 43},
  [5831] = {.lex_state = 43},
  [5832] = {.lex_state = 43},
  [5833] = {.lex_state = 19},
  [5834] = {.lex_state = 43},
  [5835] = {.lex_state = 43},
  [5836] = {.lex_state = 43},
  [5837] = {.lex_state = 43},
  [5838] = {.lex_state = 43},
  [5839] = {.lex_state = 43},
  [5840] = {.lex_state = 43},
  [5841] = {.lex_state = 20},
  [5842] = {.lex_state = 20},
  [5843] = {.lex_state = 43},
  [5844] = {.lex_state = 43},
  [5845] = {.lex_state = 43},
  [5846] = {.lex_state = 43},
  [5847] = {.lex_state = 43},
  [5848] = {.lex_state = 19},
  [5849] = {.lex_state = 29},
  [5850] = {.lex_state = 18},
  [5851] = {.lex_state = 16},
  [5852] = {.lex_state = 16},
  [5853] = {.lex_state = 16},
  [5854] = {.lex_state = 16},
  [5855] = {.lex_state = 18},
  [5856] = {.lex_state = 20},
  [5857] = {.lex_state = 41},
  [5858] = {.lex_state = 20},
  [5859] = {.lex_state = 16},
  [5860] = {.lex_state = 30},
  [5861] = {.lex_state = 16},
  [5862] = {.lex_state = 41},
  [5863] = {.lex_state = 16},
  [5864] = {.lex_state = 41},
  [5865] = {.lex_state = 41},
  [5866] = {.lex_state = 30},
  [5867] = {.lex_state = 16},
  [5868] = {.lex_state = 16},
  [5869] = {.lex_state = 16},
  [5870] = {.lex_state = 16},
  [5871] = {.lex_state = 16},
  [5872] = {.lex_state = 16},
  [5873] = {.lex_state = 371},
  [5874] = {.lex_state = 371},
  [5875] = {.lex_state = 371},
  [5876] = {.lex_state = 371},
  [5877] = {.lex_state = 371},
  [5878] = {.lex_state = 371},
  [5879] = {.lex_state = 371},
  [5880] = {.lex_state = 371},
  [5881] = {.lex_state = 371},
  [5882] = {.lex_state = 371},
  [5883] = {.lex_state = 371},
  [5884] = {.lex_state = 371},
  [5885] = {.lex_state = 371},
  [5886] = {.lex_state = 371},
  [5887] = {.lex_state = 371},
  [5888] = {.lex_state = 14},
  [5889] = {.lex_state = 14},
  [5890] = {.lex_state = 371},
  [5891] = {.lex_state = 30},
  [5892] = {.lex_state = 371},
  [5893] = {.lex_state = 371},
  [5894] = {.lex_state = 371},
  [5895] = {.lex_state = 371},
  [5896] = {.lex_state = 371},
  [5897] = {.lex_state = 371},
  [5898] = {.lex_state = 371},
  [5899] = {.lex_state = 371},
  [5900] = {.lex_state = 371},
  [5901] = {.lex_state = 371},
  [5902] = {.lex_state = 371},
  [5903] = {.lex_state = 371},
  [5904] = {.lex_state = 371},
  [5905] = {.lex_state = 16},
  [5906] = {.lex_state = 371},
  [5907] = {.lex_state = 17},
  [5908] = {.lex_state = 371},
  [5909] = {.lex_state = 371},
  [5910] = {.lex_state = 20},
  [5911] = {.lex_state = 371},
  [5912] = {.lex_state = 371},
  [5913] = {.lex_state = 371},
  [5914] = {.lex_state = 371},
  [5915] = {.lex_state = 371},
  [5916] = {.lex_state = 371},
  [5917] = {.lex_state = 17},
  [5918] = {.lex_state = 371},
  [5919] = {.lex_state = 371},
  [5920] = {.lex_state = 371},
  [5921] = {.lex_state = 371},
  [5922] = {.lex_state = 371},
  [5923] = {.lex_state = 371},
  [5924] = {.lex_state = 371},
  [5925] = {.lex_state = 19},
  [5926] = {.lex_state = 371},
  [5927] = {.lex_state = 18},
  [5928] = {.lex_state = 18},
  [5929] = {.lex_state = 371},
  [5930] = {.lex_state = 371},
  [5931] = {.lex_state = 371},
  [5932] = {.lex_state = 371},
  [5933] = {.lex_state = 371},
  [5934] = {.lex_state = 16},
  [5935] = {.lex_state = 16},
  [5936] = {.lex_state = 371},
  [5937] = {.lex_state = 18},
  [5938] = {.lex_state = 371},
  [5939] = {.lex_state = 371},
  [5940] = {.lex_state = 371},
  [5941] = {.lex_state = 371},
  [5942] = {.lex_state = 371},
  [5943] = {.lex_state = 371},
  [5944] = {.lex_state = 371},
  [5945] = {.lex_state = 371},
  [5946] = {.lex_state = 371},
  [5947] = {.lex_state = 371},
  [5948] = {.lex_state = 19},
  [5949] = {.lex_state = 41},
  [5950] = {.lex_state = 371},
  [5951] = {.lex_state = 371},
  [5952] = {.lex_state = 371},
  [5953] = {.lex_state = 371},
  [5954] = {.lex_state = 371},
  [5955] = {.lex_state = 371},
  [5956] = {.lex_state = 371},
  [5957] = {.lex_state = 371},
  [5958] = {.lex_state = 371},
  [5959] = {.lex_state = 371},
  [5960] = {.lex_state = 371},
  [5961] = {.lex_state = 371},
  [5962] = {.lex_state = 371},
  [5963] = {.lex_state = 371},
  [5964] = {.lex_state = 371},
  [5965] = {.lex_state = 371},
  [5966] = {.lex_state = 371},
  [5967] = {.lex_state = 371},
  [5968] = {.lex_state = 19},
  [5969] = {.lex_state = 371},
  [5970] = {.lex_state = 371},
  [5971] = {.lex_state = 371},
  [5972] = {.lex_state = 371},
  [5973] = {.lex_state = 371},
  [5974] = {.lex_state = 371},
  [5975] = {.lex_state = 371},
  [5976] = {.lex_state = 371},
  [5977] = {.lex_state = 371},
  [5978] = {.lex_state = 19},
  [5979] = {.lex_state = 19},
  [5980] = {.lex_state = 371},
  [5981] = {.lex_state = 371},
  [5982] = {.lex_state = 371},
  [5983] = {.lex_state = 371},
  [5984] = {.lex_state = 371},
  [5985] = {.lex_state = 371},
  [5986] = {.lex_state = 371},
  [5987] = {.lex_state = 371},
  [5988] = {.lex_state = 371},
  [5989] = {.lex_state = 19},
  [5990] = {.lex_state = 371},
  [5991] = {.lex_state = 371},
  [5992] = {.lex_state = 371},
  [5993] = {.lex_state = 19},
  [5994] = {.lex_state = 371},
  [5995] = {.lex_state = 19},
  [5996] = {.lex_state = 371},
  [5997] = {.lex_state = 371},
  [5998] = {.lex_state = 371},
  [5999] = {.lex_state = 371},
  [6000] = {.lex_state = 371},
  [6001] = {.lex_state = 371},
  [6002] = {.lex_state = 371},
  [6003] = {.lex_state = 371},
  [6004] = {.lex_state = 371},
  [6005] = {.lex_state = 371},
  [6006] = {.lex_state = 371},
  [6007] = {.lex_state = 371},
  [6008] = {.lex_state = 371},
  [6009] = {.lex_state = 371},
  [6010] = {.lex_state = 371},
  [6011] = {.lex_state = 371},
  [6012] = {.lex_state = 16},
  [6013] = {.lex_state = 371},
  [6014] = {.lex_state = 371},
  [6015] = {.lex_state = 371},
  [6016] = {.lex_state = 371},
  [6017] = {.lex_state = 371},
  [6018] = {.lex_state = 371},
  [6019] = {.lex_state = 371},
  [6020] = {.lex_state = 16},
  [6021] = {.lex_state = 371},
  [6022] = {.lex_state = 19},
  [6023] = {.lex_state = 16},
  [6024] = {.lex_state = 371},
  [6025] = {.lex_state = 371},
  [6026] = {.lex_state = 371},
  [6027] = {.lex_state = 371},
  [6028] = {.lex_state = 371},
  [6029] = {.lex_state = 371},
  [6030] = {.lex_state = 371},
  [6031] = {.lex_state = 371},
  [6032] = {.lex_state = 371},
  [6033] = {.lex_state = 371},
  [6034] = {.lex_state = 371},
  [6035] = {.lex_state = 371},
  [6036] = {.lex_state = 17},
  [6037] = {.lex_state = 19},
  [6038] = {.lex_state = 371},
  [6039] = {.lex_state = 371},
  [6040] = {.lex_state = 371},
  [6041] = {.lex_state = 371},
  [6042] = {.lex_state = 371},
  [6043] = {.lex_state = 16},
  [6044] = {.lex_state = 371},
  [6045] = {.lex_state = 371},
  [6046] = {.lex_state = 371},
  [6047] = {.lex_state = 17},
  [6048] = {.lex_state = 19},
  [6049] = {.lex_state = 19},
  [6050] = {.lex_state = 371},
  [6051] = {.lex_state = 371},
  [6052] = {.lex_state = 371},
  [6053] = {.lex_state = 371},
  [6054] = {.lex_state = 371},
  [6055] = {.lex_state = 16},
  [6056] = {.lex_state = 371},
  [6057] = {.lex_state = 371},
  [6058] = {.lex_state = 371},
  [6059] = {.lex_state = 371},
  [6060] = {.lex_state = 371},
  [6061] = {.lex_state = 371},
  [6062] = {.lex_state = 371},
  [6063] = {.lex_state = 371},
  [6064] = {.lex_state = 371},
  [6065] = {.lex_state = 371},
  [6066] = {.lex_state = 371},
  [6067] = {.lex_state = 371},
  [6068] = {.lex_state = 371},
  [6069] = {.lex_state = 371},
  [6070] = {.lex_state = 371},
  [6071] = {.lex_state = 371},
  [6072] = {.lex_state = 371},
  [6073] = {.lex_state = 371},
  [6074] = {.lex_state = 371},
  [6075] = {.lex_state = 371},
  [6076] = {.lex_state = 371},
  [6077] = {.lex_state = 371},
  [6078] = {.lex_state = 371},
  [6079] = {.lex_state = 371},
  [6080] = {.lex_state = 371},
  [6081] = {.lex_state = 371},
  [6082] = {.lex_state = 19},
  [6083] = {.lex_state = 371},
  [6084] = {.lex_state = 371},
  [6085] = {.lex_state = 371},
  [6086] = {.lex_state = 19},
  [6087] = {.lex_state = 16},
  [6088] = {.lex_state = 371},
  [6089] = {.lex_state = 371},
  [6090] = {.lex_state = 371},
  [6091] = {.lex_state = 371},
  [6092] = {.lex_state = 371},
  [6093] = {.lex_state = 371},
  [6094] = {.lex_state = 371},
  [6095] = {.lex_state = 371},
  [6096] = {.lex_state = 371},
  [6097] = {.lex_state = 371},
  [6098] = {.lex_state = 371},
  [6099] = {.lex_state = 371},
  [6100] = {.lex_state = 371},
  [6101] = {.lex_state = 371},
  [6102] = {.lex_state = 371},
  [6103] = {.lex_state = 371},
  [6104] = {.lex_state = 371},
  [6105] = {.lex_state = 19},
  [6106] = {.lex_state = 371},
  [6107] = {.lex_state = 371},
  [6108] = {.lex_state = 371},
  [6109] = {.lex_state = 371},
  [6110] = {.lex_state = 371},
  [6111] = {.lex_state = 19},
  [6112] = {.lex_state = 19},
  [6113] = {.lex_state = 371},
  [6114] = {.lex_state = 371},
  [6115] = {.lex_state = 16},
  [6116] = {.lex_state = 371},
  [6117] = {.lex_state = 371},
  [6118] = {.lex_state = 371},
  [6119] = {.lex_state = 371},
  [6120] = {.lex_state = 371},
  [6121] = {.lex_state = 371},
  [6122] = {.lex_state = 371},
  [6123] = {.lex_state = 371},
  [6124] = {.lex_state = 371},
  [6125] = {.lex_state = 16},
  [6126] = {.lex_state = 19},
  [6127] = {.lex_state = 371},
  [6128] = {.lex_state = 371},
  [6129] = {.lex_state = 371},
  [6130] = {.lex_state = 371},
  [6131] = {.lex_state = 371},
  [6132] = {.lex_state = 371},
  [6133] = {.lex_state = 29},
  [6134] = {.lex_state = 371},
  [6135] = {.lex_state = 371},
  [6136] = {.lex_state = 30},
  [6137] = {.lex_state = 371},
  [6138] = {.lex_state = 371},
  [6139] = {.lex_state = 371},
  [6140] = {.lex_state = 30},
  [6141] = {.lex_state = 371},
  [6142] = {.lex_state = 371},
  [6143] = {.lex_state = 17},
  [6144] = {.lex_state = 371},
  [6145] = {.lex_state = 371},
  [6146] = {.lex_state = 19},
  [6147] = {.lex_state = 371},
  [6148] = {.lex_state = 371},
  [6149] = {.lex_state = 371},
  [6150] = {.lex_state = 19},
  [6151] = {.lex_state = 371},
  [6152] = {.lex_state = 371},
  [6153] = {.lex_state = 371},
  [6154] = {.lex_state = 371},
  [6155] = {.lex_state = 371},
  [6156] = {.lex_state = 371},
  [6157] = {.lex_state = 371},
  [6158] = {.lex_state = 371},
  [6159] = {.lex_state = 371},
  [6160] = {.lex_state = 371},
  [6161] = {.lex_state = 371},
  [6162] = {.lex_state = 371},
  [6163] = {.lex_state = 371},
  [6164] = {.lex_state = 371},
  [6165] = {.lex_state = 371},
  [6166] = {.lex_state = 371},
  [6167] = {.lex_state = 371},
  [6168] = {.lex_state = 371},
  [6169] = {.lex_state = 371},
  [6170] = {.lex_state = 29},
  [6171] = {.lex_state = 371},
  [6172] = {.lex_state = 29},
  [6173] = {.lex_state = 371},
  [6174] = {.lex_state = 371},
  [6175] = {.lex_state = 17},
  [6176] = {.lex_state = 371},
  [6177] = {.lex_state = 371},
  [6178] = {.lex_state = 371},
  [6179] = {.lex_state = 371},
  [6180] = {.lex_state = 19},
  [6181] = {.lex_state = 371},
  [6182] = {.lex_state = 371},
  [6183] = {.lex_state = 20},
  [6184] = {.lex_state = 18},
  [6185] = {.lex_state = 18},
  [6186] = {.lex_state = 371},
  [6187] = {.lex_state = 371},
  [6188] = {.lex_state = 371},
  [6189] = {.lex_state = 371},
  [6190] = {.lex_state = 371},
  [6191] = {.lex_state = 371},
  [6192] = {.lex_state = 371},
  [6193] = {.lex_state = 371},
  [6194] = {.lex_state = 371},
  [6195] = {.lex_state = 371},
  [6196] = {.lex_state = 371},
  [6197] = {.lex_state = 371},
  [6198] = {.lex_state = 371},
  [6199] = {.lex_state = 371},
  [6200] = {.lex_state = 371},
  [6201] = {.lex_state = 371},
  [6202] = {.lex_state = 371},
  [6203] = {.lex_state = 371},
  [6204] = {.lex_state = 371},
  [6205] = {.lex_state = 371},
  [6206] = {.lex_state = 371},
  [6207] = {.lex_state = 371},
  [6208] = {.lex_state = 371},
  [6209] = {.lex_state = 371},
  [6210] = {.lex_state = 371},
  [6211] = {.lex_state = 371},
  [6212] = {.lex_state = 371},
  [6213] = {.lex_state = 21},
  [6214] = {.lex_state = 371},
  [6215] = {.lex_state = 371},
  [6216] = {.lex_state = 371},
  [6217] = {.lex_state = 371},
  [6218] = {.lex_state = 371},
  [6219] = {.lex_state = 371},
  [6220] = {.lex_state = 371},
  [6221] = {.lex_state = 371},
  [6222] = {.lex_state = 371},
  [6223] = {.lex_state = 371},
  [6224] = {.lex_state = 371},
  [6225] = {.lex_state = 371},
  [6226] = {.lex_state = 19},
  [6227] = {.lex_state = 371},
  [6228] = {.lex_state = 371},
  [6229] = {.lex_state = 371},
  [6230] = {.lex_state = 371},
  [6231] = {.lex_state = 371},
  [6232] = {.lex_state = 371},
  [6233] = {.lex_state = 371},
  [6234] = {.lex_state = 371},
  [6235] = {.lex_state = 371},
  [6236] = {.lex_state = 371},
  [6237] = {.lex_state = 371},
  [6238] = {.lex_state = 371},
  [6239] = {.lex_state = 371},
  [6240] = {.lex_state = 371},
  [6241] = {.lex_state = 371},
  [6242] = {.lex_state = 371},
  [6243] = {.lex_state = 371},
  [6244] = {.lex_state = 371},
  [6245] = {.lex_state = 371},
  [6246] = {.lex_state = 371},
  [6247] = {.lex_state = 371},
  [6248] = {.lex_state = 371},
  [6249] = {.lex_state = 371},
  [6250] = {.lex_state = 371},
  [6251] = {.lex_state = 371},
  [6252] = {.lex_state = 371},
  [6253] = {.lex_state = 17},
  [6254] = {.lex_state = 371},
  [6255] = {.lex_state = 17},
  [6256] = {.lex_state = 371},
  [6257] = {.lex_state = 371},
  [6258] = {.lex_state = 371},
  [6259] = {.lex_state = 371},
  [6260] = {.lex_state = 371},
  [6261] = {.lex_state = 371},
  [6262] = {.lex_state = 371},
  [6263] = {.lex_state = 371},
  [6264] = {.lex_state = 371},
  [6265] = {.lex_state = 371},
  [6266] = {.lex_state = 371},
  [6267] = {.lex_state = 371},
  [6268] = {.lex_state = 371},
  [6269] = {.lex_state = 371},
  [6270] = {.lex_state = 371},
  [6271] = {.lex_state = 371},
  [6272] = {.lex_state = 371},
  [6273] = {.lex_state = 16},
  [6274] = {.lex_state = 371},
  [6275] = {.lex_state = 20},
  [6276] = {.lex_state = 16},
  [6277] = {.lex_state = 371},
  [6278] = {.lex_state = 371},
  [6279] = {.lex_state = 371},
  [6280] = {.lex_state = 371},
  [6281] = {.lex_state = 371},
  [6282] = {.lex_state = 371},
  [6283] = {.lex_state = 371},
  [6284] = {.lex_state = 371},
  [6285] = {.lex_state = 371},
  [6286] = {.lex_state = 371},
  [6287] = {.lex_state = 371},
  [6288] = {.lex_state = 371},
  [6289] = {.lex_state = 371},
  [6290] = {.lex_state = 20},
  [6291] = {.lex_state = 371},
  [6292] = {.lex_state = 371},
  [6293] = {.lex_state = 371},
  [6294] = {.lex_state = 16},
  [6295] = {.lex_state = 17},
  [6296] = {.lex_state = 371},
  [6297] = {.lex_state = 371},
  [6298] = {.lex_state = 371},
  [6299] = {.lex_state = 371},
  [6300] = {.lex_state = 371},
  [6301] = {.lex_state = 371},
  [6302] = {.lex_state = 371},
  [6303] = {.lex_state = 371},
  [6304] = {.lex_state = 371},
  [6305] = {.lex_state = 371},
  [6306] = {.lex_state = 371},
  [6307] = {.lex_state = 371},
  [6308] = {.lex_state = 371},
  [6309] = {.lex_state = 371},
  [6310] = {.lex_state = 371},
  [6311] = {.lex_state = 371},
  [6312] = {.lex_state = 371},
  [6313] = {.lex_state = 371},
  [6314] = {.lex_state = 371},
  [6315] = {.lex_state = 371},
  [6316] = {.lex_state = 371},
  [6317] = {.lex_state = 371},
  [6318] = {.lex_state = 371},
  [6319] = {.lex_state = 371},
  [6320] = {.lex_state = 371},
  [6321] = {.lex_state = 371},
  [6322] = {.lex_state = 371},
  [6323] = {.lex_state = 371},
  [6324] = {.lex_state = 41},
  [6325] = {.lex_state = 371},
  [6326] = {.lex_state = 371},
  [6327] = {.lex_state = 371},
  [6328] = {.lex_state = 371},
  [6329] = {.lex_state = 371},
  [6330] = {.lex_state = 371},
  [6331] = {.lex_state = 371},
  [6332] = {.lex_state = 371},
  [6333] = {.lex_state = 371},
  [6334] = {.lex_state = 371},
  [6335] = {.lex_state = 371},
  [6336] = {.lex_state = 371},
  [6337] = {.lex_state = 371},
  [6338] = {.lex_state = 371},
  [6339] = {.lex_state = 371},
  [6340] = {.lex_state = 371},
  [6341] = {.lex_state = 371},
  [6342] = {.lex_state = 371},
  [6343] = {.lex_state = 371},
  [6344] = {.lex_state = 371},
  [6345] = {.lex_state = 371},
  [6346] = {.lex_state = 41},
  [6347] = {.lex_state = 371},
  [6348] = {.lex_state = 371},
  [6349] = {.lex_state = 371},
  [6350] = {.lex_state = 371},
  [6351] = {.lex_state = 371},
  [6352] = {.lex_state = 371},
  [6353] = {.lex_state = 371},
  [6354] = {.lex_state = 371},
  [6355] = {.lex_state = 371},
  [6356] = {.lex_state = 371},
  [6357] = {.lex_state = 371},
  [6358] = {.lex_state = 371},
  [6359] = {.lex_state = 371},
  [6360] = {.lex_state = 371},
  [6361] = {.lex_state = 371},
  [6362] = {.lex_state = 371},
  [6363] = {.lex_state = 371},
  [6364] = {.lex_state = 371},
  [6365] = {.lex_state = 371},
  [6366] = {.lex_state = 371},
  [6367] = {.lex_state = 371},
  [6368] = {.lex_state = 371},
  [6369] = {.lex_state = 371},
  [6370] = {.lex_state = 371},
  [6371] = {.lex_state = 371},
  [6372] = {.lex_state = 371},
  [6373] = {.lex_state = 371},
  [6374] = {.lex_state = 371},
  [6375] = {.lex_state = 371},
  [6376] = {.lex_state = 41},
  [6377] = {.lex_state = 371},
  [6378] = {.lex_state = 371},
  [6379] = {.lex_state = 41},
  [6380] = {.lex_state = 41},
  [6381] = {.lex_state = 41},
  [6382] = {.lex_state = 371},
  [6383] = {.lex_state = 371},
  [6384] = {.lex_state = 371},
  [6385] = {.lex_state = 41},
  [6386] = {.lex_state = 41},
  [6387] = {.lex_state = 371},
  [6388] = {.lex_state = 41},
  [6389] = {.lex_state = 371},
  [6390] = {.lex_state = 371},
  [6391] = {.lex_state = 371},
  [6392] = {.lex_state = 371},
  [6393] = {.lex_state = 371},
  [6394] = {.lex_state = 371},
  [6395] = {.lex_state = 371},
  [6396] = {.lex_state = 371},
  [6397] = {.lex_state = 371},
  [6398] = {.lex_state = 371},
  [6399] = {.lex_state = 371},
  [6400] = {.lex_state = 17},
  [6401] = {.lex_state = 371},
  [6402] = {.lex_state = 371},
  [6403] = {.lex_state = 371},
  [6404] = {.lex_state = 371},
  [6405] = {.lex_state = 371},
  [6406] = {.lex_state = 371},
  [6407] = {.lex_state = 371},
  [6408] = {.lex_state = 371},
  [6409] = {.lex_state = 371},
  [6410] = {.lex_state = 371},
  [6411] = {.lex_state = 371},
  [6412] = {.lex_state = 371},
  [6413] = {.lex_state = 17},
  [6414] = {.lex_state = 371},
  [6415] = {.lex_state = 371},
  [6416] = {.lex_state = 371},
  [6417] = {.lex_state = 371},
  [6418] = {.lex_state = 371},
  [6419] = {.lex_state = 371},
  [6420] = {.lex_state = 371},
  [6421] = {.lex_state = 371},
  [6422] = {.lex_state = 371},
  [6423] = {.lex_state = 371},
  [6424] = {.lex_state = 371},
  [6425] = {.lex_state = 371},
  [6426] = {.lex_state = 371},
  [6427] = {.lex_state = 371},
  [6428] = {.lex_state = 371},
  [6429] = {.lex_state = 371},
  [6430] = {.lex_state = 371},
  [6431] = {.lex_state = 371},
  [6432] = {.lex_state = 371},
  [6433] = {.lex_state = 371},
  [6434] = {.lex_state = 371},
  [6435] = {.lex_state = 371},
  [6436] = {.lex_state = 371},
  [6437] = {.lex_state = 371},
  [6438] = {.lex_state = 371},
  [6439] = {.lex_state = 371},
  [6440] = {.lex_state = 371},
  [6441] = {.lex_state = 371},
  [6442] = {.lex_state = 371},
  [6443] = {.lex_state = 371},
  [6444] = {.lex_state = 371},
  [6445] = {.lex_state = 371},
  [6446] = {.lex_state = 371},
  [6447] = {.lex_state = 371},
  [6448] = {.lex_state = 371},
  [6449] = {.lex_state = 371},
  [6450] = {.lex_state = 371},
  [6451] = {.lex_state = 371},
  [6452] = {.lex_state = 371},
  [6453] = {.lex_state = 371},
  [6454] = {.lex_state = 371},
  [6455] = {.lex_state = 371},
  [6456] = {.lex_state = 371},
  [6457] = {.lex_state = 371},
  [6458] = {.lex_state = 371},
  [6459] = {.lex_state = 371},
  [6460] = {.lex_state = 371},
  [6461] = {.lex_state = 371},
  [6462] = {.lex_state = 371},
  [6463] = {.lex_state = 371},
  [6464] = {.lex_state = 371},
  [6465] = {.lex_state = 371},
  [6466] = {.lex_state = 371},
  [6467] = {.lex_state = 371},
  [6468] = {.lex_state = 371},
  [6469] = {.lex_state = 371},
  [6470] = {.lex_state = 371},
  [6471] = {.lex_state = 371},
  [6472] = {.lex_state = 371},
  [6473] = {.lex_state = 371},
  [6474] = {.lex_state = 371},
  [6475] = {.lex_state = 371},
  [6476] = {.lex_state = 17},
  [6477] = {.lex_state = 371},
  [6478] = {.lex_state = 371},
  [6479] = {.lex_state = 371},
  [6480] = {.lex_state = 371},
  [6481] = {.lex_state = 371},
  [6482] = {.lex_state = 371},
  [6483] = {.lex_state = 371},
  [6484] = {.lex_state = 17},
  [6485] = {.lex_state = 371},
  [6486] = {.lex_state = 371},
  [6487] = {.lex_state = 371},
  [6488] = {.lex_state = 371},
  [6489] = {.lex_state = 17},
  [6490] = {.lex_state = 371},
  [6491] = {.lex_state = 371},
  [6492] = {.lex_state = 371},
  [6493] = {.lex_state = 371},
  [6494] = {.lex_state = 371},
  [6495] = {.lex_state = 371},
  [6496] = {.lex_state = 371},
  [6497] = {.lex_state = 371},
  [6498] = {.lex_state = 371},
  [6499] = {.lex_state = 371},
  [6500] = {.lex_state = 371},
  [6501] = {.lex_state = 371},
  [6502] = {.lex_state = 371},
  [6503] = {.lex_state = 371},
  [6504] = {.lex_state = 371},
  [6505] = {.lex_state = 371},
  [6506] = {.lex_state = 371},
  [6507] = {.lex_state = 371},
  [6508] = {.lex_state = 371},
  [6509] = {.lex_state = 371},
  [6510] = {.lex_state = 371},
  [6511] = {.lex_state = 17},
  [6512] = {.lex_state = 17},
  [6513] = {.lex_state = 371},
  [6514] = {.lex_state = 371},
  [6515] = {.lex_state = 371},
  [6516] = {.lex_state = 371},
  [6517] = {.lex_state = 371},
  [6518] = {.lex_state = 371},
  [6519] = {.lex_state = 371},
  [6520] = {.lex_state = 371},
  [6521] = {.lex_state = 371},
  [6522] = {.lex_state = 371},
  [6523] = {.lex_state = 371},
  [6524] = {.lex_state = 371},
  [6525] = {.lex_state = 371},
  [6526] = {.lex_state = 371},
  [6527] = {.lex_state = 371},
  [6528] = {.lex_state = 371},
  [6529] = {.lex_state = 371},
  [6530] = {.lex_state = 371},
  [6531] = {.lex_state = 371},
  [6532] = {.lex_state = 371},
  [6533] = {.lex_state = 371},
  [6534] = {.lex_state = 371},
  [6535] = {.lex_state = 371},
  [6536] = {.lex_state = 371},
  [6537] = {.lex_state = 17},
  [6538] = {.lex_state = 371},
  [6539] = {.lex_state = 17},
  [6540] = {.lex_state = 371},
  [6541] = {.lex_state = 371},
  [6542] = {.lex_state = 371},
  [6543] = {.lex_state = 371},
  [6544] = {.lex_state = 371},
  [6545] = {.lex_state = 371},
  [6546] = {.lex_state = 371},
  [6547] = {.lex_state = 16},
  [6548] = {.lex_state = 371},
  [6549] = {.lex_state = 371},
  [6550] = {.lex_state = 371},
  [6551] = {.lex_state = 371},
  [6552] = {.lex_state = 371},
  [6553] = {.lex_state = 371},
  [6554] = {.lex_state = 17},
  [6555] = {.lex_state = 17},
  [6556] = {.lex_state = 16},
  [6557] = {.lex_state = 371},
  [6558] = {.lex_state = 371},
  [6559] = {.lex_state = 371},
  [6560] = {.lex_state = 371},
  [6561] = {.lex_state = 371},
  [6562] = {.lex_state = 371},
  [6563] = {.lex_state = 371},
  [6564] = {.lex_state = 371},
  [6565] = {.lex_state = 17},
  [6566] = {.lex_state = 371},
  [6567] = {.lex_state = 371},
  [6568] = {.lex_state = 371},
  [6569] = {.lex_state = 371},
  [6570] = {.lex_state = 371},
  [6571] = {.lex_state = 371},
  [6572] = {.lex_state = 371},
  [6573] = {.lex_state = 371},
  [6574] = {.lex_state = 371},
  [6575] = {.lex_state = 371},
  [6576] = {.lex_state = 371},
  [6577] = {.lex_state = 371},
  [6578] = {.lex_state = 371},
  [6579] = {.lex_state = 371},
  [6580] = {.lex_state = 371},
  [6581] = {.lex_state = 371},
  [6582] = {.lex_state = 371},
  [6583] = {.lex_state = 371},
  [6584] = {.lex_state = 41},
  [6585] = {.lex_state = 371},
  [6586] = {.lex_state = 371},
  [6587] = {.lex_state = 371},
  [6588] = {.lex_state = 371},
  [6589] = {.lex_state = 371},
  [6590] = {.lex_state = 16},
  [6591] = {.lex_state = 371},
  [6592] = {.lex_state = 371},
  [6593] = {.lex_state = 371},
  [6594] = {.lex_state = 371},
  [6595] = {.lex_state = 371},
  [6596] = {.lex_state = 371},
  [6597] = {.lex_state = 41},
  [6598] = {.lex_state = 41},
  [6599] = {.lex_state = 371},
  [6600] = {.lex_state = 371},
  [6601] = {.lex_state = 16},
  [6602] = {.lex_state = 371},
  [6603] = {.lex_state = 17},
  [6604] = {.lex_state = 371},
  [6605] = {.lex_state = 371},
  [6606] = {.lex_state = 371},
  [6607] = {.lex_state = 371},
  [6608] = {.lex_state = 371},
  [6609] = {.lex_state = 371},
  [6610] = {.lex_state = 371},
  [6611] = {.lex_state = 371},
  [6612] = {.lex_state = 371},
  [6613] = {.lex_state = 371},
  [6614] = {.lex_state = 371},
  [6615] = {.lex_state = 16},
  [6616] = {.lex_state = 371},
  [6617] = {.lex_state = 371},
  [6618] = {.lex_state = 371},
  [6619] = {.lex_state = 20},
  [6620] = {.lex_state = 16},
  [6621] = {.lex_state = 41},
  [6622] = {.lex_state = 20},
  [6623] = {.lex_state = 41},
  [6624] = {.lex_state = 20},
  [6625] = {.lex_state = 371},
  [6626] = {.lex_state = 20},
  [6627] = {.lex_state = 41},
  [6628] = {.lex_state = 9},
  [6629] = {.lex_state = 41},
  [6630] = {.lex_state = 14},
  [6631] = {.lex_state = 371},
  [6632] = {.lex_state = 371},
  [6633] = {.lex_state = 21},
  [6634] = {.lex_state = 371},
  [6635] = {.lex_state = 41},
  [6636] = {.lex_state = 16},
  [6637] = {.lex_state = 16},
  [6638] = {.lex_state = 371},
  [6639] = {.lex_state = 16},
  [6640] = {.lex_state = 16},
  [6641] = {.lex_state = 50},
  [6642] = {.lex_state = 18},
  [6643] = {.lex_state = 371},
  [6644] = {.lex_state = 16},
  [6645] = {.lex_state = 16},
  [6646] = {.lex_state = 16},
  [6647] = {.lex_state = 18},
  [6648] = {.lex_state = 18},
  [6649] = {.lex_state = 16},
  [6650] = {.lex_state = 16},
  [6651] = {.lex_state = 50},
  [6652] = {.lex_state = 50},
  [6653] = {.lex_state = 16},
  [6654] = {.lex_state = 16},
  [6655] = {.lex_state = 50},
  [6656] = {.lex_state = 16},
  [6657] = {.lex_state = 16},
  [6658] = {.lex_state = 16},
  [6659] = {.lex_state = 16},
  [6660] = {.lex_state = 50},
  [6661] = {.lex_state = 16},
  [6662] = {.lex_state = 50},
  [6663] = {.lex_state = 16},
  [6664] = {.lex_state = 16},
  [6665] = {.lex_state = 16},
  [6666] = {.lex_state = 16},
  [6667] = {.lex_state = 16},
  [6668] = {.lex_state = 50},
  [6669] = {.lex_state = 18},
  [6670] = {.lex_state = 50},
  [6671] = {.lex_state = 50},
  [6672] = {.lex_state = 41},
  [6673] = {.lex_state = 16},
  [6674] = {.lex_state = 16},
  [6675] = {.lex_state = 50},
  [6676] = {.lex_state = 41},
  [6677] = {.lex_state = 16},
  [6678] = {.lex_state = 16},
  [6679] = {.lex_state = 16},
  [6680] = {.lex_state = 16},
  [6681] = {.lex_state = 16},
  [6682] = {.lex_state = 16},
  [6683] = {.lex_state = 16},
  [6684] = {.lex_state = 16},
  [6685] = {.lex_state = 41},
  [6686] = {.lex_state = 41},
  [6687] = {.lex_state = 41},
  [6688] = {.lex_state = 50},
  [6689] = {.lex_state = 50},
  [6690] = {.lex_state = 50},
  [6691] = {.lex_state = 16},
  [6692] = {.lex_state = 41},
  [6693] = {.lex_state = 16},
  [6694] = {.lex_state = 18},
  [6695] = {.lex_state = 18},
  [6696] = {.lex_state = 50},
  [6697] = {.lex_state = 16},
  [6698] = {.lex_state = 16},
  [6699] = {.lex_state = 50},
  [6700] = {.lex_state = 16},
  [6701] = {.lex_state = 50},
  [6702] = {.lex_state = 50},
  [6703] = {.lex_state = 16},
  [6704] = {.lex_state = 16},
  [6705] = {.lex_state = 16},
  [6706] = {.lex_state = 41},
  [6707] = {.lex_state = 50},
  [6708] = {.lex_state = 16},
  [6709] = {.lex_state = 16},
  [6710] = {.lex_state = 41},
  [6711] = {.lex_state = 50},
  [6712] = {.lex_state = 50},
  [6713] = {.lex_state = 16},
  [6714] = {.lex_state = 50},
  [6715] = {.lex_state = 50},
  [6716] = {.lex_state = 50},
  [6717] = {.lex_state = 50},
  [6718] = {.lex_state = 50},
  [6719] = {.lex_state = 50},
  [6720] = {.lex_state = 50},
  [6721] = {.lex_state = 16},
  [6722] = {.lex_state = 50},
  [6723] = {.lex_state = 50},
  [6724] = {.lex_state = 50},
  [6725] = {.lex_state = 50},
  [6726] = {.lex_state = 50},
  [6727] = {.lex_state = 16},
  [6728] = {.lex_state = 50},
  [6729] = {.lex_state = 16},
  [6730] = {.lex_state = 50},
  [6731] = {.lex_state = 16},
  [6732] = {.lex_state = 29},
  [6733] = {.lex_state = 16},
  [6734] = {.lex_state = 16},
  [6735] = {.lex_state = 16},
  [6736] = {.lex_state = 16},
  [6737] = {.lex_state = 16},
  [6738] = {.lex_state = 16},
  [6739] = {.lex_state = 50},
  [6740] = {.lex_state = 50},
  [6741] = {.lex_state = 16},
  [6742] = {.lex_state = 50},
  [6743] = {.lex_state = 16},
  [6744] = {.lex_state = 50},
  [6745] = {.lex_state = 16},
  [6746] = {.lex_state = 50},
  [6747] = {.lex_state = 50},
  [6748] = {.lex_state = 50},
  [6749] = {.lex_state = 41},
  [6750] = {.lex_state = 41},
  [6751] = {.lex_state = 30},
  [6752] = {.lex_state = 20},
  [6753] = {.lex_state = 16},
  [6754] = {.lex_state = 16},
  [6755] = {.lex_state = 16},
  [6756] = {.lex_state = 16},
  [6757] = {.lex_state = 16},
  [6758] = {.lex_state = 16},
  [6759] = {.lex_state = 41},
  [6760] = {.lex_state = 16},
  [6761] = {.lex_state = 20},
  [6762] = {.lex_state = 16},
  [6763] = {.lex_state = 41},
  [6764] = {.lex_state = 50},
  [6765] = {.lex_state = 16},
  [6766] = {.lex_state = 16},
  [6767] = {.lex_state = 50},
  [6768] = {.lex_state = 50},
  [6769] = {.lex_state = 50},
  [6770] = {.lex_state = 16},
  [6771] = {.lex_state = 30},
  [6772] = {.lex_state = 16},
  [6773] = {.lex_state = 50},
  [6774] = {.lex_state = 50},
  [6775] = {.lex_state = 16},
  [6776] = {.lex_state = 50},
  [6777] = {.lex_state = 50},
  [6778] = {.lex_state = 20},
  [6779] = {.lex_state = 16},
  [6780] = {.lex_state = 16},
  [6781] = {.lex_state = 16},
  [6782] = {.lex_state = 30},
  [6783] = {.lex_state = 50},
  [6784] = {.lex_state = 30},
  [6785] = {.lex_state = 50},
  [6786] = {.lex_state = 50},
  [6787] = {.lex_state = 30},
  [6788] = {.lex_state = 50},
  [6789] = {.lex_state = 16},
  [6790] = {.lex_state = 16},
  [6791] = {.lex_state = 50},
  [6792] = {.lex_state = 16},
  [6793] = {.lex_state = 50},
  [6794] = {.lex_state = 50},
  [6795] = {.lex_state = 50},
  [6796] = {.lex_state = 50},
  [6797] = {.lex_state = 16},
  [6798] = {.lex_state = 50},
  [6799] = {.lex_state = 50},
  [6800] = {.lex_state = 50},
  [6801] = {.lex_state = 50},
  [6802] = {.lex_state = 50},
  [6803] = {.lex_state = 50},
  [6804] = {.lex_state = 50},
  [6805] = {.lex_state = 50},
  [6806] = {.lex_state = 50},
  [6807] = {.lex_state = 50},
  [6808] = {.lex_state = 16},
  [6809] = {.lex_state = 50},
  [6810] = {.lex_state = 50},
  [6811] = {.lex_state = 50},
  [6812] = {.lex_state = 16},
  [6813] = {.lex_state = 16},
  [6814] = {.lex_state = 16},
  [6815] = {.lex_state = 41},
  [6816] = {.lex_state = 41},
  [6817] = {.lex_state = 16},
  [6818] = {.lex_state = 16},
  [6819] = {.lex_state = 16},
  [6820] = {.lex_state = 50},
  [6821] = {.lex_state = 20},
  [6822] = {.lex_state = 50},
  [6823] = {.lex_state = 41},
  [6824] = {.lex_state = 20},
  [6825] = {.lex_state = 41},
  [6826] = {.lex_state = 41},
  [6827] = {.lex_state = 41},
  [6828] = {.lex_state = 41},
  [6829] = {.lex_state = 16},
  [6830] = {.lex_state = 16},
  [6831] = {.lex_state = 50},
  [6832] = {.lex_state = 50},
  [6833] = {.lex_state = 16},
  [6834] = {.lex_state = 50},
  [6835] = {.lex_state = 50},
  [6836] = {.lex_state = 16},
  [6837] = {.lex_state = 16},
  [6838] = {.lex_state = 41},
  [6839] = {.lex_state = 41},
  [6840] = {.lex_state = 16},
  [6841] = {.lex_state = 29},
  [6842] = {.lex_state = 16},
  [6843] = {.lex_state = 16},
  [6844] = {.lex_state = 41},
  [6845] = {.lex_state = 41},
  [6846] = {.lex_state = 41},
  [6847] = {.lex_state = 16},
  [6848] = {.lex_state = 50},
  [6849] = {.lex_state = 41},
  [6850] = {.lex_state = 50},
  [6851] = {.lex_state = 41},
  [6852] = {.lex_state = 50},
  [6853] = {.lex_state = 371},
  [6854] = {.lex_state = 50},
  [6855] = {.lex_state = 41},
  [6856] = {.lex_state = 41},
  [6857] = {.lex_state = 41},
  [6858] = {.lex_state = 16},
  [6859] = {.lex_state = 16},
  [6860] = {.lex_state = 50},
  [6861] = {.lex_state = 50},
  [6862] = {.lex_state = 20},
  [6863] = {.lex_state = 50},
  [6864] = {.lex_state = 50},
  [6865] = {.lex_state = 50},
  [6866] = {.lex_state = 50},
  [6867] = {.lex_state = 50},
  [6868] = {.lex_state = 50},
  [6869] = {.lex_state = 50},
  [6870] = {.lex_state = 50},
  [6871] = {.lex_state = 16},
  [6872] = {.lex_state = 50},
  [6873] = {.lex_state = 50},
  [6874] = {.lex_state = 50},
  [6875] = {.lex_state = 16},
  [6876] = {.lex_state = 16},
  [6877] = {.lex_state = 41},
  [6878] = {.lex_state = 29},
  [6879] = {.lex_state = 41},
  [6880] = {.lex_state = 50},
  [6881] = {.lex_state = 50},
  [6882] = {.lex_state = 50},
  [6883] = {.lex_state = 41},
  [6884] = {.lex_state = 16},
  [6885] = {.lex_state = 41},
  [6886] = {.lex_state = 50},
  [6887] = {.lex_state = 50},
  [6888] = {.lex_state = 50},
  [6889] = {.lex_state = 50},
  [6890] = {.lex_state = 16},
  [6891] = {.lex_state = 16},
  [6892] = {.lex_state = 16},
  [6893] = {.lex_state = 16},
  [6894] = {.lex_state = 41},
  [6895] = {.lex_state = 41},
  [6896] = {.lex_state = 16},
  [6897] = {.lex_state = 20},
  [6898] = {.lex_state = 50},
  [6899] = {.lex_state = 50},
  [6900] = {.lex_state = 50},
  [6901] = {.lex_state = 50},
  [6902] = {.lex_state = 41},
  [6903] = {.lex_state = 41},
  [6904] = {.lex_state = 50},
  [6905] = {.lex_state = 50},
  [6906] = {.lex_state = 16},
  [6907] = {.lex_state = 20},
  [6908] = {.lex_state = 20},
  [6909] = {.lex_state = 20},
  [6910] = {.lex_state = 30},
  [6911] = {.lex_state = 16},
  [6912] = {.lex_state = 41},
  [6913] = {.lex_state = 41},
  [6914] = {.lex_state = 20},
  [6915] = {.lex_state = 50},
  [6916] = {.lex_state = 50},
  [6917] = {.lex_state = 50},
  [6918] = {.lex_state = 50},
  [6919] = {.lex_state = 41},
  [6920] = {.lex_state = 16},
  [6921] = {.lex_state = 41},
  [6922] = {.lex_state = 16},
  [6923] = {.lex_state = 16},
  [6924] = {.lex_state = 41},
  [6925] = {.lex_state = 41},
  [6926] = {.lex_state = 41},
  [6927] = {.lex_state = 16},
  [6928] = {.lex_state = 41},
  [6929] = {.lex_state = 41},
  [6930] = {.lex_state = 41},
  [6931] = {.lex_state = 41},
  [6932] = {.lex_state = 41},
  [6933] = {.lex_state = 16},
  [6934] = {.lex_state = 9},
  [6935] = {.lex_state = 41},
  [6936] = {.lex_state = 41},
  [6937] = {.lex_state = 41},
  [6938] = {.lex_state = 41},
  [6939] = {.lex_state = 41},
  [6940] = {.lex_state = 41},
  [6941] = {.lex_state = 41},
  [6942] = {.lex_state = 20},
  [6943] = {.lex_state = 41},
  [6944] = {.lex_state = 16},
  [6945] = {.lex_state = 371},
  [6946] = {.lex_state = 41},
  [6947] = {.lex_state = 41},
  [6948] = {.lex_state = 16},
  [6949] = {.lex_state = 16},
  [6950] = {.lex_state = 20},
  [6951] = {.lex_state = 41},
  [6952] = {.lex_state = 41},
  [6953] = {.lex_state = 41},
  [6954] = {.lex_state = 16},
  [6955] = {.lex_state = 16},
  [6956] = {.lex_state = 41},
  [6957] = {.lex_state = 41},
  [6958] = {.lex_state = 41},
  [6959] = {.lex_state = 41},
  [6960] = {.lex_state = 41},
  [6961] = {.lex_state = 41},
  [6962] = {.lex_state = 16},
  [6963] = {.lex_state = 41},
  [6964] = {.lex_state = 16},
  [6965] = {.lex_state = 371},
  [6966] = {.lex_state = 41},
  [6967] = {.lex_state = 41},
  [6968] = {.lex_state = 41},
  [6969] = {.lex_state = 41},
  [6970] = {.lex_state = 41},
  [6971] = {.lex_state = 16},
  [6972] = {.lex_state = 16},
  [6973] = {.lex_state = 41},
  [6974] = {.lex_state = 41},
  [6975] = {.lex_state = 16},
  [6976] = {.lex_state = 41},
  [6977] = {.lex_state = 41},
  [6978] = {.lex_state = 20},
  [6979] = {.lex_state = 41},
  [6980] = {.lex_state = 41},
  [6981] = {.lex_state = 41},
  [6982] = {.lex_state = 41},
  [6983] = {.lex_state = 20},
  [6984] = {.lex_state = 20},
  [6985] = {.lex_state = 41},
  [6986] = {.lex_state = 41},
  [6987] = {.lex_state = 41},
  [6988] = {.lex_state = 41},
  [6989] = {.lex_state = 41},
  [6990] = {.lex_state = 16},
  [6991] = {.lex_state = 41},
  [6992] = {.lex_state = 50},
  [6993] = {.lex_state = 20},
  [6994] = {.lex_state = 16},
  [6995] = {.lex_state = 41},
  [6996] = {.lex_state = 16},
  [6997] = {.lex_state = 16},
  [6998] = {.lex_state = 16},
  [6999] = {.lex_state = 16},
  [7000] = {.lex_state = 20},
  [7001] = {.lex_state = 41},
  [7002] = {.lex_state = 16},
  [7003] = {.lex_state = 41},
  [7004] = {.lex_state = 41},
  [7005] = {.lex_state = 16},
  [7006] = {.lex_state = 16},
  [7007] = {.lex_state = 16},
  [7008] = {.lex_state = 16},
  [7009] = {.lex_state = 16},
  [7010] = {.lex_state = 16},
  [7011] = {.lex_state = 41},
  [7012] = {.lex_state = 16},
  [7013] = {.lex_state = 16},
  [7014] = {.lex_state = 16},
  [7015] = {.lex_state = 16},
  [7016] = {.lex_state = 16},
  [7017] = {.lex_state = 41},
  [7018] = {.lex_state = 16},
  [7019] = {.lex_state = 16},
  [7020] = {.lex_state = 16},
  [7021] = {.lex_state = 16},
  [7022] = {.lex_state = 20},
  [7023] = {.lex_state = 20},
  [7024] = {.lex_state = 20},
  [7025] = {.lex_state = 29},
  [7026] = {.lex_state = 16},
  [7027] = {.lex_state = 29},
  [7028] = {.lex_state = 41},
  [7029] = {.lex_state = 41},
  [7030] = {.lex_state = 41},
  [7031] = {.lex_state = 41},
  [7032] = {.lex_state = 41},
  [7033] = {.lex_state = 41},
  [7034] = {.lex_state = 41},
  [7035] = {.lex_state = 41},
  [7036] = {.lex_state = 41},
  [7037] = {.lex_state = 41},
  [7038] = {.lex_state = 16},
  [7039] = {.lex_state = 16},
  [7040] = {.lex_state = 41},
  [7041] = {.lex_state = 41},
  [7042] = {.lex_state = 41},
  [7043] = {.lex_state = 41},
  [7044] = {.lex_state = 41},
  [7045] = {.lex_state = 41},
  [7046] = {.lex_state = 41},
  [7047] = {.lex_state = 41},
  [7048] = {.lex_state = 41},
  [7049] = {.lex_state = 41},
  [7050] = {.lex_state = 41},
  [7051] = {.lex_state = 41},
  [7052] = {.lex_state = 16},
  [7053] = {.lex_state = 16},
  [7054] = {.lex_state = 16},
  [7055] = {.lex_state = 41},
  [7056] = {.lex_state = 41},
  [7057] = {.lex_state = 41},
  [7058] = {.lex_state = 41},
  [7059] = {.lex_state = 41},
  [7060] = {.lex_state = 41},
  [7061] = {.lex_state = 41},
  [7062] = {.lex_state = 41},
  [7063] = {.lex_state = 41},
  [7064] = {.lex_state = 41},
  [7065] = {.lex_state = 18},
  [7066] = {.lex_state = 41},
  [7067] = {.lex_state = 41},
  [7068] = {.lex_state = 41},
  [7069] = {.lex_state = 18},
  [7070] = {.lex_state = 16},
  [7071] = {.lex_state = 16},
  [7072] = {.lex_state = 41},
  [7073] = {.lex_state = 41},
  [7074] = {.lex_state = 41},
  [7075] = {.lex_state = 41},
  [7076] = {.lex_state = 41},
  [7077] = {.lex_state = 41},
  [7078] = {.lex_state = 16},
  [7079] = {.lex_state = 41},
  [7080] = {.lex_state = 41},
  [7081] = {.lex_state = 20},
  [7082] = {.lex_state = 41},
  [7083] = {.lex_state = 41},
  [7084] = {.lex_state = 41},
  [7085] = {.lex_state = 41},
  [7086] = {.lex_state = 16},
  [7087] = {.lex_state = 43},
  [7088] = {.lex_state = 43},
  [7089] = {.lex_state = 50},
  [7090] = {.lex_state = 32},
  [7091] = {.lex_state = 41},
  [7092] = {.lex_state = 50},
  [7093] = {.lex_state = 41},
  [7094] = {.lex_state = 43},
  [7095] = {.lex_state = 18},
  [7096] = {.lex_state = 43},
  [7097] = {.lex_state = 18},
  [7098] = {.lex_state = 18},
  [7099] = {.lex_state = 43},
  [7100] = {.lex_state = 43},
  [7101] = {.lex_state = 43},
  [7102] = {.lex_state = 43},
  [7103] = {.lex_state = 18},
  [7104] = {.lex_state = 43},
  [7105] = {.lex_state = 41},
  [7106] = {.lex_state = 43},
  [7107] = {.lex_state = 43},
  [7108] = {.lex_state = 49},
  [7109] = {.lex_state = 33},
  [7110] = {.lex_state = 21},
  [7111] = {.lex_state = 50},
  [7112] = {.lex_state = 16},
  [7113] = {.lex_state = 16},
  [7114] = {.lex_state = 43},
  [7115] = {.lex_state = 371},
  [7116] = {.lex_state = 43},
  [7117] = {.lex_state = 18},
  [7118] = {.lex_state = 43},
  [7119] = {.lex_state = 43},
  [7120] = {.lex_state = 43},
  [7121] = {.lex_state = 43},
  [7122] = {.lex_state = 50},
  [7123] = {.lex_state = 41},
  [7124] = {.lex_state = 41},
  [7125] = {.lex_state = 18},
  [7126] = {.lex_state = 43},
  [7127] = {.lex_state = 50},
  [7128] = {.lex_state = 43},
  [7129] = {.lex_state = 9},
  [7130] = {.lex_state = 50},
  [7131] = {.lex_state = 43},
  [7132] = {.lex_state = 41},
  [7133] = {.lex_state = 43},
  [7134] = {.lex_state = 43},
  [7135] = {.lex_state = 50},
  [7136] = {.lex_state = 50},
  [7137] = {.lex_state = 43},
  [7138] = {.lex_state = 27},
  [7139] = {.lex_state = 18},
  [7140] = {.lex_state = 18},
  [7141] = {.lex_state = 18},
  [7142] = {.lex_state = 43},
  [7143] = {.lex_state = 43},
  [7144] = {.lex_state = 18},
  [7145] = {.lex_state = 50},
  [7146] = {.lex_state = 43},
  [7147] = {.lex_state = 18},
  [7148] = {.lex_state = 50},
  [7149] = {.lex_state = 18},
  [7150] = {.lex_state = 18},
  [7151] = {.lex_state = 18},
  [7152] = {.lex_state = 16},
  [7153] = {.lex_state = 43},
  [7154] = {.lex_state = 27},
  [7155] = {.lex_state = 41},
  [7156] = {.lex_state = 43},
  [7157] = {.lex_state = 371},
  [7158] = {.lex_state = 50},
  [7159] = {.lex_state = 43},
  [7160] = {.lex_state = 43},
  [7161] = {.lex_state = 43},
  [7162] = {.lex_state = 18},
  [7163] = {.lex_state = 18},
  [7164] = {.lex_state = 43},
  [7165] = {.lex_state = 41},
  [7166] = {.lex_state = 43},
  [7167] = {.lex_state = 41},
  [7168] = {.lex_state = 50},
  [7169] = {.lex_state = 25},
  [7170] = {.lex_state = 50},
  [7171] = {.lex_state = 50},
  [7172] = {.lex_state = 50},
  [7173] = {.lex_state = 18},
  [7174] = {.lex_state = 18},
  [7175] = {.lex_state = 18},
  [7176] = {.lex_state = 50},
  [7177] = {.lex_state = 50},
  [7178] = {.lex_state = 50},
  [7179] = {.lex_state = 18},
  [7180] = {.lex_state = 18},
  [7181] = {.lex_state = 50},
  [7182] = {.lex_state = 50},
  [7183] = {.lex_state = 18},
  [7184] = {.lex_state = 18},
  [7185] = {.lex_state = 18},
  [7186] = {.lex_state = 18},
  [7187] = {.lex_state = 18},
  [7188] = {.lex_state = 18},
  [7189] = {.lex_state = 18},
  [7190] = {.lex_state = 18},
  [7191] = {.lex_state = 18},
  [7192] = {.lex_state = 50},
  [7193] = {.lex_state = 18},
  [7194] = {.lex_state = 50},
  [7195] = {.lex_state = 16},
  [7196] = {.lex_state = 50},
  [7197] = {.lex_state = 50},
  [7198] = {.lex_state = 50},
  [7199] = {.lex_state = 50},
  [7200] = {.lex_state = 18},
  [7201] = {.lex_state = 18},
  [7202] = {.lex_state = 34},
  [7203] = {.lex_state = 50},
  [7204] = {.lex_state = 18},
  [7205] = {.lex_state = 18},
  [7206] = {.lex_state = 18},
  [7207] = {.lex_state = 18},
  [7208] = {.lex_state = 50},
  [7209] = {.lex_state = 18},
  [7210] = {.lex_state = 18},
  [7211] = {.lex_state = 50},
  [7212] = {.lex_state = 50},
  [7213] = {.lex_state = 50},
  [7214] = {.lex_state = 50},
  [7215] = {.lex_state = 50},
  [7216] = {.lex_state = 50},
  [7217] = {.lex_state = 50},
  [7218] = {.lex_state = 18},
  [7219] = {.lex_state = 50},
  [7220] = {.lex_state = 50},
  [7221] = {.lex_state = 50},
  [7222] = {.lex_state = 43},
  [7223] = {.lex_state = 18},
  [7224] = {.lex_state = 18},
  [7225] = {.lex_state = 18},
  [7226] = {.lex_state = 18},
  [7227] = {.lex_state = 29},
  [7228] = {.lex_state = 18},
  [7229] = {.lex_state = 50},
  [7230] = {.lex_state = 50},
  [7231] = {.lex_state = 18},
  [7232] = {.lex_state = 29},
  [7233] = {.lex_state = 41},
  [7234] = {.lex_state = 18},
  [7235] = {.lex_state = 18},
  [7236] = {.lex_state = 50},
  [7237] = {.lex_state = 50},
  [7238] = {.lex_state = 50},
  [7239] = {.lex_state = 50},
  [7240] = {.lex_state = 50},
  [7241] = {.lex_state = 50},
  [7242] = {.lex_state = 50},
  [7243] = {.lex_state = 50},
  [7244] = {.lex_state = 18},
  [7245] = {.lex_state = 50},
  [7246] = {.lex_state = 50},
  [7247] = {.lex_state = 18},
  [7248] = {.lex_state = 18},
  [7249] = {.lex_state = 18},
  [7250] = {.lex_state = 30},
  [7251] = {.lex_state = 18},
  [7252] = {.lex_state = 50},
  [7253] = {.lex_state = 50},
  [7254] = {.lex_state = 50},
  [7255] = {.lex_state = 50},
  [7256] = {.lex_state = 50},
  [7257] = {.lex_state = 50},
  [7258] = {.lex_state = 18},
  [7259] = {.lex_state = 18},
  [7260] = {.lex_state = 18},
  [7261] = {.lex_state = 50},
  [7262] = {.lex_state = 18},
  [7263] = {.lex_state = 50},
  [7264] = {.lex_state = 50},
  [7265] = {.lex_state = 18},
  [7266] = {.lex_state = 50},
  [7267] = {.lex_state = 50},
  [7268] = {.lex_state = 50},
  [7269] = {.lex_state = 50},
  [7270] = {.lex_state = 50},
  [7271] = {.lex_state = 18},
  [7272] = {.lex_state = 30},
  [7273] = {.lex_state = 50},
  [7274] = {.lex_state = 50},
  [7275] = {.lex_state = 50},
  [7276] = {.lex_state = 18},
  [7277] = {.lex_state = 50},
  [7278] = {.lex_state = 30},
  [7279] = {.lex_state = 30},
  [7280] = {.lex_state = 50},
  [7281] = {.lex_state = 50},
  [7282] = {.lex_state = 50},
  [7283] = {.lex_state = 50},
  [7284] = {.lex_state = 50},
  [7285] = {.lex_state = 18},
  [7286] = {.lex_state = 18},
  [7287] = {.lex_state = 50},
  [7288] = {.lex_state = 50},
  [7289] = {.lex_state = 50},
  [7290] = {.lex_state = 50},
  [7291] = {.lex_state = 50},
  [7292] = {.lex_state = 9},
  [7293] = {.lex_state = 18},
  [7294] = {.lex_state = 50},
  [7295] = {.lex_state = 50},
  [7296] = {.lex_state = 18},
  [7297] = {.lex_state = 18},
  [7298] = {.lex_state = 18},
  [7299] = {.lex_state = 50},
  [7300] = {.lex_state = 50},
  [7301] = {.lex_state = 50},
  [7302] = {.lex_state = 31},
  [7303] = {.lex_state = 50},
  [7304] = {.lex_state = 50},
  [7305] = {.lex_state = 50},
  [7306] = {.lex_state = 50},
  [7307] = {.lex_state = 50},
  [7308] = {.lex_state = 41},
  [7309] = {.lex_state = 50},
  [7310] = {.lex_state = 50},
  [7311] = {.lex_state = 18},
  [7312] = {.lex_state = 30},
  [7313] = {.lex_state = 18},
  [7314] = {.lex_state = 18},
  [7315] = {.lex_state = 18},
  [7316] = {.lex_state = 18},
  [7317] = {.lex_state = 18},
  [7318] = {.lex_state = 18},
  [7319] = {.lex_state = 18},
  [7320] = {.lex_state = 18},
  [7321] = {.lex_state = 18},
  [7322] = {.lex_state = 18},
  [7323] = {.lex_state = 18},
  [7324] = {.lex_state = 18},
  [7325] = {.lex_state = 16},
  [7326] = {.lex_state = 30},
  [7327] = {.lex_state = 16},
  [7328] = {.lex_state = 18},
  [7329] = {.lex_state = 18},
  [7330] = {.lex_state = 50},
  [7331] = {.lex_state = 18},
  [7332] = {.lex_state = 31},
  [7333] = {.lex_state = 18},
  [7334] = {.lex_state = 16},
  [7335] = {.lex_state = 18},
  [7336] = {.lex_state = 18},
  [7337] = {.lex_state = 50},
  [7338] = {.lex_state = 50},
  [7339] = {.lex_state = 50},
  [7340] = {.lex_state = 50},
  [7341] = {.lex_state = 50},
  [7342] = {.lex_state = 18},
  [7343] = {.lex_state = 50},
  [7344] = {.lex_state = 50},
  [7345] = {.lex_state = 50},
  [7346] = {.lex_state = 50},
  [7347] = {.lex_state = 50},
  [7348] = {.lex_state = 50},
  [7349] = {.lex_state = 50},
  [7350] = {.lex_state = 50},
  [7351] = {.lex_state = 50},
  [7352] = {.lex_state = 50},
  [7353] = {.lex_state = 50},
  [7354] = {.lex_state = 50},
  [7355] = {.lex_state = 50},
  [7356] = {.lex_state = 50},
  [7357] = {.lex_state = 18},
  [7358] = {.lex_state = 18},
  [7359] = {.lex_state = 18},
  [7360] = {.lex_state = 50},
  [7361] = {.lex_state = 18},
  [7362] = {.lex_state = 50},
  [7363] = {.lex_state = 50},
  [7364] = {.lex_state = 16},
  [7365] = {.lex_state = 18},
  [7366] = {.lex_state = 18},
  [7367] = {.lex_state = 18},
  [7368] = {.lex_state = 33},
  [7369] = {.lex_state = 41},
  [7370] = {.lex_state = 18},
  [7371] = {.lex_state = 41},
  [7372] = {.lex_state = 16},
  [7373] = {.lex_state = 16},
  [7374] = {.lex_state = 18},
  [7375] = {.lex_state = 9},
  [7376] = {.lex_state = 371},
  [7377] = {.lex_state = 16},
  [7378] = {.lex_state = 21},
  [7379] = {.lex_state = 16},
  [7380] = {.lex_state = 29},
  [7381] = {.lex_state = 33},
  [7382] = {.lex_state = 32},
  [7383] = {.lex_state = 41},
  [7384] = {.lex_state = 18},
  [7385] = {.lex_state = 18},
  [7386] = {.lex_state = 25},
  [7387] = {.lex_state = 41},
  [7388] = {.lex_state = 41},
  [7389] = {.lex_state = 33},
  [7390] = {.lex_state = 50},
  [7391] = {.lex_state = 41},
  [7392] = {.lex_state = 21},
  [7393] = {.lex_state = 9},
  [7394] = {.lex_state = 41},
  [7395] = {.lex_state = 18},
  [7396] = {.lex_state = 9},
  [7397] = {.lex_state = 33},
  [7398] = {.lex_state = 18},
  [7399] = {.lex_state = 18},
  [7400] = {.lex_state = 16},
  [7401] = {.lex_state = 9},
  [7402] = {.lex_state = 41},
  [7403] = {.lex_state = 18},
  [7404] = {.lex_state = 18},
  [7405] = {.lex_state = 18},
  [7406] = {.lex_state = 50},
  [7407] = {.lex_state = 18},
  [7408] = {.lex_state = 18},
  [7409] = {.lex_state = 20},
  [7410] = {.lex_state = 18},
  [7411] = {.lex_state = 50},
  [7412] = {.lex_state = 18},
  [7413] = {.lex_state = 50},
  [7414] = {.lex_state = 50},
  [7415] = {.lex_state = 25},
  [7416] = {.lex_state = 18},
  [7417] = {.lex_state = 18},
  [7418] = {.lex_state = 25},
  [7419] = {.lex_state = 33},
  [7420] = {.lex_state = 18},
  [7421] = {.lex_state = 29},
  [7422] = {.lex_state = 41},
  [7423] = {.lex_state = 20},
  [7424] = {.lex_state = 50},
  [7425] = {.lex_state = 371},
  [7426] = {.lex_state = 9},
  [7427] = {.lex_state = 41},
  [7428] = {.lex_state = 9},
  [7429] = {.lex_state = 41},
  [7430] = {.lex_state = 18},
  [7431] = {.lex_state = 18},
  [7432] = {.lex_state = 41},
  [7433] = {.lex_state = 41},
  [7434] = {.lex_state = 50},
  [7435] = {.lex_state = 25},
  [7436] = {.lex_state = 18},
  [7437] = {.lex_state = 18},
  [7438] = {.lex_state = 50},
  [7439] = {.lex_state = 18},
  [7440] = {.lex_state = 18},
  [7441] = {.lex_state = 50},
  [7442] = {.lex_state = 25},
  [7443] = {.lex_state = 18},
  [7444] = {.lex_state = 20},
  [7445] = {.lex_state = 50},
  [7446] = {.lex_state = 18},
  [7447] = {.lex_state = 50},
  [7448] = {.lex_state = 18},
  [7449] = {.lex_state = 50},
  [7450] = {.lex_state = 9},
  [7451] = {.lex_state = 18},
  [7452] = {.lex_state = 18},
  [7453] = {.lex_state = 25},
  [7454] = {.lex_state = 25},
  [7455] = {.lex_state = 20},
  [7456] = {.lex_state = 25},
  [7457] = {.lex_state = 43},
  [7458] = {.lex_state = 50},
  [7459] = {.lex_state = 50},
  [7460] = {.lex_state = 29},
  [7461] = {.lex_state = 18},
  [7462] = {.lex_state = 9},
  [7463] = {.lex_state = 50},
  [7464] = {.lex_state = 29},
  [7465] = {.lex_state = 43},
  [7466] = {.lex_state = 50},
  [7467] = {.lex_state = 50},
  [7468] = {.lex_state = 25},
  [7469] = {.lex_state = 25},
  [7470] = {.lex_state = 43},
  [7471] = {.lex_state = 29},
  [7472] = {.lex_state = 43},
  [7473] = {.lex_state = 29},
  [7474] = {.lex_state = 25},
  [7475] = {.lex_state = 25},
  [7476] = {.lex_state = 43},
  [7477] = {.lex_state = 43},
  [7478] = {.lex_state = 50},
  [7479] = {.lex_state = 25},
  [7480] = {.lex_state = 43},
  [7481] = {.lex_state = 371},
  [7482] = {.lex_state = 371},
  [7483] = {.lex_state = 371},
  [7484] = {.lex_state = 371},
  [7485] = {.lex_state = 371},
  [7486] = {.lex_state = 9},
  [7487] = {.lex_state = 371},
  [7488] = {.lex_state = 371},
  [7489] = {.lex_state = 371},
  [7490] = {.lex_state = 371},
  [7491] = {.lex_state = 371},
  [7492] = {.lex_state = 371},
  [7493] = {.lex_state = 371},
  [7494] = {.lex_state = 371},
  [7495] = {.lex_state = 43},
  [7496] = {.lex_state = 371},
  [7497] = {.lex_state = 371},
  [7498] = {.lex_state = 371},
  [7499] = {.lex_state = 371},
  [7500] = {.lex_state = 43},
  [7501] = {.lex_state = 371},
  [7502] = {.lex_state = 371},
  [7503] = {.lex_state = 371},
  [7504] = {.lex_state = 24},
  [7505] = {.lex_state = 371},
  [7506] = {.lex_state = 371},
  [7507] = {.lex_state = 371},
  [7508] = {.lex_state = 371},
  [7509] = {.lex_state = 24},
  [7510] = {.lex_state = 371},
  [7511] = {.lex_state = 371},
  [7512] = {.lex_state = 371},
  [7513] = {.lex_state = 371},
  [7514] = {.lex_state = 371},
  [7515] = {.lex_state = 371},
  [7516] = {.lex_state = 371},
  [7517] = {.lex_state = 371},
  [7518] = {.lex_state = 371},
  [7519] = {.lex_state = 371},
  [7520] = {.lex_state = 371},
  [7521] = {.lex_state = 371},
  [7522] = {.lex_state = 371},
  [7523] = {.lex_state = 371},
  [7524] = {.lex_state = 371},
  [7525] = {.lex_state = 371},
  [7526] = {.lex_state = 43},
  [7527] = {.lex_state = 371},
  [7528] = {.lex_state = 371},
  [7529] = {.lex_state = 24},
  [7530] = {.lex_state = 43},
  [7531] = {.lex_state = 371},
  [7532] = {.lex_state = 371},
  [7533] = {.lex_state = 371},
  [7534] = {.lex_state = 371},
  [7535] = {.lex_state = 43},
  [7536] = {.lex_state = 371},
  [7537] = {.lex_state = 20},
  [7538] = {.lex_state = 371},
  [7539] = {.lex_state = 371},
  [7540] = {.lex_state = 43},
  [7541] = {.lex_state = 43},
  [7542] = {.lex_state = 43},
  [7543] = {.lex_state = 43},
  [7544] = {.lex_state = 24},
  [7545] = {.lex_state = 371},
  [7546] = {.lex_state = 43},
  [7547] = {.lex_state = 371},
  [7548] = {.lex_state = 371},
  [7549] = {.lex_state = 371},
  [7550] = {.lex_state = 371},
  [7551] = {.lex_state = 371},
  [7552] = {.lex_state = 371},
  [7553] = {.lex_state = 371},
  [7554] = {.lex_state = 43},
  [7555] = {.lex_state = 43},
  [7556] = {.lex_state = 371},
  [7557] = {.lex_state = 371},
  [7558] = {.lex_state = 371},
  [7559] = {.lex_state = 43},
  [7560] = {.lex_state = 43},
  [7561] = {.lex_state = 371},
  [7562] = {.lex_state = 371},
  [7563] = {.lex_state = 371},
  [7564] = {.lex_state = 371},
  [7565] = {.lex_state = 371},
  [7566] = {.lex_state = 43},
  [7567] = {.lex_state = 371},
  [7568] = {.lex_state = 371},
  [7569] = {.lex_state = 371},
  [7570] = {.lex_state = 371},
  [7571] = {.lex_state = 371},
  [7572] = {.lex_state = 43},
  [7573] = {.lex_state = 25},
  [7574] = {.lex_state = 371},
  [7575] = {.lex_state = 43},
  [7576] = {.lex_state = 371},
  [7577] = {.lex_state = 371},
  [7578] = {.lex_state = 371},
  [7579] = {.lex_state = 371},
  [7580] = {.lex_state = 371},
  [7581] = {.lex_state = 371},
  [7582] = {.lex_state = 371},
  [7583] = {.lex_state = 371},
  [7584] = {.lex_state = 43},
  [7585] = {.lex_state = 371},
  [7586] = {.lex_state = 371},
  [7587] = {.lex_state = 371},
  [7588] = {.lex_state = 371},
  [7589] = {.lex_state = 371},
  [7590] = {.lex_state = 371},
  [7591] = {.lex_state = 371},
  [7592] = {.lex_state = 371},
  [7593] = {.lex_state = 371},
  [7594] = {.lex_state = 371},
  [7595] = {.lex_state = 43},
  [7596] = {.lex_state = 371},
  [7597] = {.lex_state = 371},
  [7598] = {.lex_state = 43},
  [7599] = {.lex_state = 43},
  [7600] = {.lex_state = 43},
  [7601] = {.lex_state = 43},
  [7602] = {.lex_state = 371},
  [7603] = {.lex_state = 371},
  [7604] = {.lex_state = 371},
  [7605] = {.lex_state = 371},
  [7606] = {.lex_state = 371},
  [7607] = {.lex_state = 371},
  [7608] = {.lex_state = 371},
  [7609] = {.lex_state = 43},
  [7610] = {.lex_state = 23},
  [7611] = {.lex_state = 371},
  [7612] = {.lex_state = 371},
  [7613] = {.lex_state = 371},
  [7614] = {.lex_state = 371},
  [7615] = {.lex_state = 371},
  [7616] = {.lex_state = 371},
  [7617] = {.lex_state = 43},
  [7618] = {.lex_state = 371},
  [7619] = {.lex_state = 371},
  [7620] = {.lex_state = 371},
  [7621] = {.lex_state = 50},
  [7622] = {.lex_state = 20},
  [7623] = {.lex_state = 20},
  [7624] = {.lex_state = 371},
  [7625] = {.lex_state = 371},
  [7626] = {.lex_state = 371},
  [7627] = {.lex_state = 371},
  [7628] = {.lex_state = 371},
  [7629] = {.lex_state = 43},
  [7630] = {.lex_state = 371},
  [7631] = {.lex_state = 371},
  [7632] = {.lex_state = 371},
  [7633] = {.lex_state = 371},
  [7634] = {.lex_state = 43},
  [7635] = {.lex_state = 371},
  [7636] = {.lex_state = 43},
  [7637] = {.lex_state = 34},
  [7638] = {.lex_state = 43},
  [7639] = {.lex_state = 371},
  [7640] = {.lex_state = 371},
  [7641] = {.lex_state = 371},
  [7642] = {.lex_state = 371},
  [7643] = {.lex_state = 43},
  [7644] = {.lex_state = 371},
  [7645] = {.lex_state = 371},
  [7646] = {.lex_state = 371},
  [7647] = {.lex_state = 371},
  [7648] = {.lex_state = 371},
  [7649] = {.lex_state = 371},
  [7650] = {.lex_state = 371},
  [7651] = {.lex_state = 371},
  [7652] = {.lex_state = 371},
  [7653] = {.lex_state = 371},
  [7654] = {.lex_state = 43},
  [7655] = {.lex_state = 371},
  [7656] = {.lex_state = 371},
  [7657] = {.lex_state = 371},
  [7658] = {.lex_state = 43},
  [7659] = {.lex_state = 371},
  [7660] = {.lex_state = 371},
  [7661] = {.lex_state = 371},
  [7662] = {.lex_state = 371},
  [7663] = {.lex_state = 371},
  [7664] = {.lex_state = 43},
  [7665] = {.lex_state = 371},
  [7666] = {.lex_state = 371},
  [7667] = {.lex_state = 371},
  [7668] = {.lex_state = 371},
  [7669] = {.lex_state = 20},
  [7670] = {.lex_state = 371},
  [7671] = {.lex_state = 371},
  [7672] = {.lex_state = 371},
  [7673] = {.lex_state = 371},
  [7674] = {.lex_state = 371},
  [7675] = {.lex_state = 43},
  [7676] = {.lex_state = 371},
  [7677] = {.lex_state = 371},
  [7678] = {.lex_state = 43},
  [7679] = {.lex_state = 371},
  [7680] = {.lex_state = 371},
  [7681] = {.lex_state = 371},
  [7682] = {.lex_state = 371},
  [7683] = {.lex_state = 371},
  [7684] = {.lex_state = 371},
  [7685] = {.lex_state = 43},
  [7686] = {.lex_state = 48},
  [7687] = {.lex_state = 48},
  [7688] = {.lex_state = 48},
  [7689] = {.lex_state = 48},
  [7690] = {.lex_state = 48},
  [7691] = {.lex_state = 48},
  [7692] = {.lex_state = 48},
  [7693] = {.lex_state = 48},
  [7694] = {.lex_state = 48},
  [7695] = {.lex_state = 48},
  [7696] = {.lex_state = 48},
  [7697] = {.lex_state = 43},
  [7698] = {.lex_state = 43},
  [7699] = {.lex_state = 48},
  [7700] = {.lex_state = 48},
  [7701] = {.lex_state = 48},
  [7702] = {.lex_state = 48},
  [7703] = {.lex_state = 48},
  [7704] = {.lex_state = 48},
  [7705] = {.lex_state = 48},
  [7706] = {.lex_state = 48},
  [7707] = {.lex_state = 48},
  [7708] = {.lex_state = 48},
  [7709] = {.lex_state = 48},
  [7710] = {.lex_state = 48},
  [7711] = {.lex_state = 43},
  [7712] = {.lex_state = 43},
  [7713] = {.lex_state = 9},
  [7714] = {.lex_state = 43},
  [7715] = {.lex_state = 43},
  [7716] = {.lex_state = 43},
  [7717] = {.lex_state = 48},
  [7718] = {.lex_state = 48},
  [7719] = {.lex_state = 48},
  [7720] = {.lex_state = 48},
  [7721] = {.lex_state = 48},
  [7722] = {.lex_state = 43},
  [7723] = {.lex_state = 48},
  [7724] = {.lex_state = 43},
  [7725] = {.lex_state = 48},
  [7726] = {.lex_state = 48},
  [7727] = {.lex_state = 48},
  [7728] = {.lex_state = 48},
  [7729] = {.lex_state = 48},
  [7730] = {.lex_state = 48},
  [7731] = {.lex_state = 25},
  [7732] = {.lex_state = 43},
  [7733] = {.lex_state = 43},
  [7734] = {.lex_state = 371},
  [7735] = {.lex_state = 43},
  [7736] = {.lex_state = 33},
  [7737] = {.lex_state = 9},
  [7738] = {.lex_state = 30},
  [7739] = {.lex_state = 48},
  [7740] = {.lex_state = 48},
  [7741] = {.lex_state = 48},
  [7742] = {.lex_state = 48},
  [7743] = {.lex_state = 48},
  [7744] = {.lex_state = 48},
  [7745] = {.lex_state = 48},
  [7746] = {.lex_state = 48},
  [7747] = {.lex_state = 48},
  [7748] = {.lex_state = 48},
  [7749] = {.lex_state = 48},
  [7750] = {.lex_state = 48},
  [7751] = {.lex_state = 48},
  [7752] = {.lex_state = 48},
  [7753] = {.lex_state = 48},
  [7754] = {.lex_state = 48},
  [7755] = {.lex_state = 48},
  [7756] = {.lex_state = 48},
  [7757] = {.lex_state = 48},
  [7758] = {.lex_state = 48},
  [7759] = {.lex_state = 48},
  [7760] = {.lex_state = 48},
  [7761] = {.lex_state = 48},
  [7762] = {.lex_state = 48},
  [7763] = {.lex_state = 48},
  [7764] = {.lex_state = 48},
  [7765] = {.lex_state = 48},
  [7766] = {.lex_state = 48},
  [7767] = {.lex_state = 48},
  [7768] = {.lex_state = 18},
  [7769] = {.lex_state = 48},
  [7770] = {.lex_state = 30},
  [7771] = {.lex_state = 30},
  [7772] = {.lex_state = 48},
  [7773] = {.lex_state = 48},
  [7774] = {.lex_state = 371},
  [7775] = {.lex_state = 48},
  [7776] = {.lex_state = 48},
  [7777] = {.lex_state = 48},
  [7778] = {.lex_state = 18},
  [7779] = {.lex_state = 25},
  [7780] = {.lex_state = 18},
  [7781] = {.lex_state = 28},
  [7782] = {.lex_state = 48},
  [7783] = {.lex_state = 48},
  [7784] = {.lex_state = 18},
  [7785] = {.lex_state = 48},
  [7786] = {.lex_state = 48},
  [7787] = {.lex_state = 48},
  [7788] = {.lex_state = 48},
  [7789] = {.lex_state = 48},
  [7790] = {.lex_state = 48},
  [7791] = {.lex_state = 48},
  [7792] = {.lex_state = 48},
  [7793] = {.lex_state = 48},
  [7794] = {.lex_state = 48},
  [7795] = {.lex_state = 48},
  [7796] = {.lex_state = 48},
  [7797] = {.lex_state = 18},
  [7798] = {.lex_state = 18},
  [7799] = {.lex_state = 30},
  [7800] = {.lex_state = 48},
  [7801] = {.lex_state = 28},
  [7802] = {.lex_state = 28},
  [7803] = {.lex_state = 18},
  [7804] = {.lex_state = 48},
  [7805] = {.lex_state = 18},
  [7806] = {.lex_state = 48},
  [7807] = {.lex_state = 48},
  [7808] = {.lex_state = 48},
  [7809] = {.lex_state = 33},
  [7810] = {.lex_state = 35},
  [7811] = {.lex_state = 25},
  [7812] = {.lex_state = 35},
  [7813] = {.lex_state = 48},
  [7814] = {.lex_state = 371},
  [7815] = {.lex_state = 48},
  [7816] = {.lex_state = 48},
  [7817] = {.lex_state = 48},
  [7818] = {.lex_state = 48},
  [7819] = {.lex_state = 30},
  [7820] = {.lex_state = 30},
  [7821] = {.lex_state = 33},
  [7822] = {.lex_state = 25},
  [7823] = {.lex_state = 9},
  [7824] = {.lex_state = 48},
  [7825] = {.lex_state = 48},
  [7826] = {.lex_state = 48},
  [7827] = {.lex_state = 48},
  [7828] = {.lex_state = 48},
  [7829] = {.lex_state = 43},
  [7830] = {.lex_state = 43},
  [7831] = {.lex_state = 48},
  [7832] = {.lex_state = 48},
  [7833] = {.lex_state = 33},
  [7834] = {.lex_state = 18},
  [7835] = {.lex_state = 48},
  [7836] = {.lex_state = 48},
  [7837] = {.lex_state = 48},
  [7838] = {.lex_state = 32},
  [7839] = {.lex_state = 18},
  [7840] = {.lex_state = 18},
  [7841] = {.lex_state = 43},
  [7842] = {.lex_state = 18},
  [7843] = {.lex_state = 43},
  [7844] = {.lex_state = 371},
  [7845] = {.lex_state = 43},
  [7846] = {.lex_state = 43},
  [7847] = {.lex_state = 43},
  [7848] = {.lex_state = 43},
  [7849] = {.lex_state = 30},
  [7850] = {.lex_state = 43},
  [7851] = {.lex_state = 43},
  [7852] = {.lex_state = 43},
  [7853] = {.lex_state = 371},
  [7854] = {.lex_state = 25},
  [7855] = {.lex_state = 371},
  [7856] = {.lex_state = 32},
  [7857] = {.lex_state = 43},
  [7858] = {.lex_state = 43},
  [7859] = {.lex_state = 25},
  [7860] = {.lex_state = 9},
  [7861] = {.lex_state = 43},
  [7862] = {.lex_state = 371},
  [7863] = {.lex_state = 9},
  [7864] = {.lex_state = 43},
  [7865] = {.lex_state = 18},
  [7866] = {.lex_state = 9},
  [7867] = {.lex_state = 25},
  [7868] = {.lex_state = 9},
  [7869] = {.lex_state = 34},
  [7870] = {.lex_state = 371},
  [7871] = {.lex_state = 371},
  [7872] = {.lex_state = 371},
  [7873] = {.lex_state = 43},
  [7874] = {.lex_state = 32},
  [7875] = {.lex_state = 18},
  [7876] = {.lex_state = 43},
  [7877] = {.lex_state = 43},
  [7878] = {.lex_state = 25},
  [7879] = {.lex_state = 18},
  [7880] = {.lex_state = 18},
  [7881] = {.lex_state = 30},
  [7882] = {.lex_state = 43},
  [7883] = {.lex_state = 43},
  [7884] = {.lex_state = 18},
  [7885] = {.lex_state = 43},
  [7886] = {.lex_state = 25},
  [7887] = {.lex_state = 43},
  [7888] = {.lex_state = 25},
  [7889] = {.lex_state = 43},
  [7890] = {.lex_state = 25},
  [7891] = {.lex_state = 18},
  [7892] = {.lex_state = 18},
  [7893] = {.lex_state = 30},
  [7894] = {.lex_state = 43},
  [7895] = {.lex_state = 18},
  [7896] = {.lex_state = 18},
  [7897] = {.lex_state = 18},
  [7898] = {.lex_state = 43},
  [7899] = {.lex_state = 43},
  [7900] = {.lex_state = 371},
  [7901] = {.lex_state = 43},
  [7902] = {.lex_state = 30},
  [7903] = {.lex_state = 18},
  [7904] = {.lex_state = 30},
  [7905] = {.lex_state = 30},
  [7906] = {.lex_state = 371},
  [7907] = {.lex_state = 43},
  [7908] = {.lex_state = 18},
  [7909] = {.lex_state = 47},
  [7910] = {.lex_state = 30},
  [7911] = {.lex_state = 43},
  [7912] = {.lex_state = 43},
  [7913] = {.lex_state = 43},
  [7914] = {.lex_state = 371},
  [7915] = {.lex_state = 18},
  [7916] = {.lex_state = 43},
  [7917] = {.lex_state = 43},
  [7918] = {.lex_state = 43},
  [7919] = {.lex_state = 43},
  [7920] = {.lex_state = 43},
  [7921] = {.lex_state = 18},
  [7922] = {.lex_state = 18},
  [7923] = {.lex_state = 43},
  [7924] = {.lex_state = 18},
  [7925] = {.lex_state = 18},
  [7926] = {.lex_state = 9},
  [7927] = {.lex_state = 43},
  [7928] = {.lex_state = 43},
  [7929] = {.lex_state = 43},
  [7930] = {.lex_state = 43},
  [7931] = {.lex_state = 43},
  [7932] = {.lex_state = 43},
  [7933] = {.lex_state = 43},
  [7934] = {.lex_state = 43},
  [7935] = {.lex_state = 43},
  [7936] = {.lex_state = 43},
  [7937] = {.lex_state = 43},
  [7938] = {.lex_state = 43},
  [7939] = {.lex_state = 43},
  [7940] = {.lex_state = 37},
  [7941] = {.lex_state = 43},
  [7942] = {.lex_state = 31},
  [7943] = {.lex_state = 40},
  [7944] = {.lex_state = 43},
  [7945] = {.lex_state = 43},
  [7946] = {.lex_state = 43},
  [7947] = {.lex_state = 19},
  [7948] = {.lex_state = 43},
  [7949] = {.lex_state = 43},
  [7950] = {.lex_state = 40},
  [7951] = {.lex_state = 36},
  [7952] = {.lex_state = 43},
  [7953] = {.lex_state = 43},
  [7954] = {.lex_state = 19},
  [7955] = {.lex_state = 19},
  [7956] = {.lex_state = 43},
  [7957] = {.lex_state = 43},
  [7958] = {.lex_state = 37},
  [7959] = {.lex_state = 43},
  [7960] = {.lex_state = 43},
  [7961] = {.lex_state = 43},
  [7962] = {.lex_state = 19},
  [7963] = {.lex_state = 43},
  [7964] = {.lex_state = 43},
  [7965] = {.lex_state = 43},
  [7966] = {.lex_state = 43},
  [7967] = {.lex_state = 34},
  [7968] = {.lex_state = 43},
  [7969] = {.lex_state = 43},
  [7970] = {.lex_state = 19},
  [7971] = {.lex_state = 43},
  [7972] = {.lex_state = 43},
  [7973] = {.lex_state = 43},
  [7974] = {.lex_state = 43},
  [7975] = {.lex_state = 31},
  [7976] = {.lex_state = 43},
  [7977] = {.lex_state = 43},
  [7978] = {.lex_state = 43},
  [7979] = {.lex_state = 371},
  [7980] = {.lex_state = 43},
  [7981] = {.lex_state = 19},
  [7982] = {.lex_state = 34},
  [7983] = {.lex_state = 43},
  [7984] = {.lex_state = 37},
  [7985] = {.lex_state = 18},
  [7986] = {.lex_state = 43},
  [7987] = {.lex_state = 43},
  [7988] = {.lex_state = 37},
  [7989] = {.lex_state = 43},
  [7990] = {.lex_state = 43},
  [7991] = {.lex_state = 43},
  [7992] = {.lex_state = 43},
  [7993] = {.lex_state = 43},
  [7994] = {.lex_state = 371},
  [7995] = {.lex_state = 19},
  [7996] = {.lex_state = 43},
  [7997] = {.lex_state = 43},
  [7998] = {.lex_state = 43},
  [7999] = {.lex_state = 43},
  [8000] = {.lex_state = 19},
  [8001] = {.lex_state = 43},
  [8002] = {.lex_state = 19},
  [8003] = {.lex_state = 371},
  [8004] = {.lex_state = 43},
  [8005] = {.lex_state = 43},
  [8006] = {.lex_state = 31},
  [8007] = {.lex_state = 18},
  [8008] = {.lex_state = 43},
  [8009] = {.lex_state = 40},
  [8010] = {.lex_state = 40},
  [8011] = {.lex_state = 43},
  [8012] = {.lex_state = 371},
  [8013] = {.lex_state = 43},
  [8014] = {.lex_state = 19},
  [8015] = {.lex_state = 43},
  [8016] = {.lex_state = 371},
  [8017] = {.lex_state = 43},
  [8018] = {.lex_state = 19},
  [8019] = {.lex_state = 371},
  [8020] = {.lex_state = 43},
  [8021] = {.lex_state = 31},
  [8022] = {.lex_state = 18},
  [8023] = {.lex_state = 43},
  [8024] = {.lex_state = 19},
  [8025] = {.lex_state = 19},
  [8026] = {.lex_state = 43},
  [8027] = {.lex_state = 43},
  [8028] = {.lex_state = 43},
  [8029] = {.lex_state = 43},
  [8030] = {.lex_state = 43},
  [8031] = {.lex_state = 43},
  [8032] = {.lex_state = 371},
  [8033] = {.lex_state = 43},
  [8034] = {.lex_state = 43},
  [8035] = {.lex_state = 18},
  [8036] = {.lex_state = 371},
  [8037] = {.lex_state = 43},
  [8038] = {.lex_state = 43},
  [8039] = {.lex_state = 43},
  [8040] = {.lex_state = 31},
  [8041] = {.lex_state = 19},
  [8042] = {.lex_state = 33},
  [8043] = {.lex_state = 34},
  [8044] = {.lex_state = 25},
  [8045] = {.lex_state = 372},
  [8046] = {.lex_state = 41},
  [8047] = {.lex_state = 34},
  [8048] = {.lex_state = 18},
  [8049] = {.lex_state = 18},
  [8050] = {.lex_state = 25},
  [8051] = {.lex_state = 41},
  [8052] = {.lex_state = 18},
  [8053] = {.lex_state = 18},
  [8054] = {.lex_state = 18},
  [8055] = {.lex_state = 18},
  [8056] = {.lex_state = 18},
  [8057] = {.lex_state = 18},
  [8058] = {.lex_state = 18},
  [8059] = {.lex_state = 18},
  [8060] = {.lex_state = 18},
  [8061] = {.lex_state = 18},
  [8062] = {.lex_state = 372},
  [8063] = {.lex_state = 41},
  [8064] = {.lex_state = 371},
  [8065] = {.lex_state = 371},
  [8066] = {.lex_state = 371},
  [8067] = {.lex_state = 18},
  [8068] = {.lex_state = 25},
  [8069] = {.lex_state = 25},
  [8070] = {.lex_state = 25},
  [8071] = {.lex_state = 25},
  [8072] = {.lex_state = 371},
  [8073] = {.lex_state = 371},
  [8074] = {.lex_state = 18},
  [8075] = {.lex_state = 18},
  [8076] = {.lex_state = 34},
  [8077] = {.lex_state = 18},
  [8078] = {.lex_state = 371},
  [8079] = {.lex_state = 18},
  [8080] = {.lex_state = 18},
  [8081] = {.lex_state = 371},
  [8082] = {.lex_state = 371},
  [8083] = {.lex_state = 18},
  [8084] = {.lex_state = 371},
  [8085] = {.lex_state = 25},
  [8086] = {.lex_state = 18},
  [8087] = {.lex_state = 371},
  [8088] = {.lex_state = 371},
  [8089] = {.lex_state = 18},
  [8090] = {.lex_state = 371},
  [8091] = {.lex_state = 34},
  [8092] = {.lex_state = 34},
  [8093] = {.lex_state = 18},
  [8094] = {.lex_state = 371},
  [8095] = {.lex_state = 18},
  [8096] = {.lex_state = 18},
  [8097] = {.lex_state = 18},
  [8098] = {.lex_state = 25},
  [8099] = {.lex_state = 371},
  [8100] = {.lex_state = 371},
  [8101] = {.lex_state = 18},
  [8102] = {.lex_state = 18},
  [8103] = {.lex_state = 371},
  [8104] = {.lex_state = 18},
  [8105] = {.lex_state = 371},
  [8106] = {.lex_state = 33},
  [8107] = {.lex_state = 41},
  [8108] = {.lex_state = 41},
  [8109] = {.lex_state = 371},
  [8110] = {.lex_state = 371},
  [8111] = {.lex_state = 33},
  [8112] = {.lex_state = 371},
  [8113] = {.lex_state = 371},
  [8114] = {.lex_state = 371},
  [8115] = {.lex_state = 371},
  [8116] = {.lex_state = 371},
  [8117] = {.lex_state = 371},
  [8118] = {.lex_state = 371},
  [8119] = {.lex_state = 371},
  [8120] = {.lex_state = 371},
  [8121] = {.lex_state = 371},
  [8122] = {.lex_state = 371},
  [8123] = {.lex_state = 25},
  [8124] = {.lex_state = 371},
  [8125] = {.lex_state = 40},
  [8126] = {.lex_state = 371},
  [8127] = {.lex_state = 32},
  [8128] = {.lex_state = 371},
  [8129] = {.lex_state = 372},
  [8130] = {.lex_state = 22},
  [8131] = {.lex_state = 23},
  [8132] = {.lex_state = 371},
  [8133] = {.lex_state = 371},
  [8134] = {.lex_state = 40},
  [8135] = {.lex_state = 40},
  [8136] = {.lex_state = 22},
  [8137] = {.lex_state = 371},
  [8138] = {.lex_state = 40},
  [8139] = {.lex_state = 25},
  [8140] = {.lex_state = 25},
  [8141] = {.lex_state = 25},
  [8142] = {.lex_state = 372},
  [8143] = {.lex_state = 25},
  [8144] = {.lex_state = 32},
  [8145] = {.lex_state = 371},
  [8146] = {.lex_state = 9},
  [8147] = {.lex_state = 28},
  [8148] = {.lex_state = 9},
  [8149] = {.lex_state = 371},
  [8150] = {.lex_state = 25},
  [8151] = {.lex_state = 32},
  [8152] = {.lex_state = 40},
  [8153] = {.lex_state = 371},
  [8154] = {.lex_state = 9},
  [8155] = {.lex_state = 371},
  [8156] = {.lex_state = 9},
  [8157] = {.lex_state = 371},
  [8158] = {.lex_state = 371},
  [8159] = {.lex_state = 371},
  [8160] = {.lex_state = 371},
  [8161] = {.lex_state = 18},
  [8162] = {.lex_state = 371},
  [8163] = {.lex_state = 371},
  [8164] = {.lex_state = 23},
  [8165] = {.lex_state = 9},
  [8166] = {.lex_state = 25},
  [8167] = {.lex_state = 371},
  [8168] = {.lex_state = 24},
  [8169] = {.lex_state = 9},
  [8170] = {.lex_state = 371},
  [8171] = {.lex_state = 23},
  [8172] = {.lex_state = 18},
  [8173] = {.lex_state = 23},
  [8174] = {.lex_state = 24},
  [8175] = {.lex_state = 371},
  [8176] = {.lex_state = 371},
  [8177] = {.lex_state = 25},
  [8178] = {.lex_state = 371},
  [8179] = {.lex_state = 371},
  [8180] = {.lex_state = 371},
  [8181] = {.lex_state = 371},
  [8182] = {.lex_state = 23},
  [8183] = {.lex_state = 25},
  [8184] = {.lex_state = 371},
  [8185] = {.lex_state = 371},
  [8186] = {.lex_state = 25},
  [8187] = {.lex_state = 371},
  [8188] = {.lex_state = 371},
  [8189] = {.lex_state = 18},
  [8190] = {.lex_state = 24},
  [8191] = {.lex_state = 24},
  [8192] = {.lex_state = 23},
  [8193] = {.lex_state = 371},
  [8194] = {.lex_state = 371},
  [8195] = {.lex_state = 371},
  [8196] = {.lex_state = 24},
  [8197] = {.lex_state = 18},
  [8198] = {.lex_state = 371},
  [8199] = {.lex_state = 371},
  [8200] = {.lex_state = 32},
  [8201] = {.lex_state = 32},
  [8202] = {.lex_state = 371},
  [8203] = {.lex_state = 23},
  [8204] = {.lex_state = 371},
  [8205] = {.lex_state = 371},
  [8206] = {.lex_state = 371},
  [8207] = {.lex_state = 9},
  [8208] = {.lex_state = 371},
  [8209] = {.lex_state = 18},
  [8210] = {.lex_state = 371},
  [8211] = {.lex_state = 371},
  [8212] = {.lex_state = 371},
  [8213] = {.lex_state = 9},
  [8214] = {.lex_state = 371},
  [8215] = {.lex_state = 9},
  [8216] = {.lex_state = 371},
  [8217] = {.lex_state = 371},
  [8218] = {.lex_state = 9},
  [8219] = {.lex_state = 371},
  [8220] = {.lex_state = 18},
  [8221] = {.lex_state = 9},
  [8222] = {.lex_state = 371},
  [8223] = {.lex_state = 371},
  [8224] = {.lex_state = 31},
  [8225] = {.lex_state = 31},
  [8226] = {.lex_state = 371},
  [8227] = {.lex_state = 371},
  [8228] = {.lex_state = 371},
  [8229] = {.lex_state = 371},
  [8230] = {.lex_state = 371},
  [8231] = {.lex_state = 371},
  [8232] = {.lex_state = 18},
  [8233] = {.lex_state = 50},
  [8234] = {.lex_state = 371},
  [8235] = {.lex_state = 371},
  [8236] = {.lex_state = 371},
  [8237] = {.lex_state = 371},
  [8238] = {.lex_state = 31},
  [8239] = {.lex_state = 371},
  [8240] = {.lex_state = 25},
  [8241] = {.lex_state = 33},
  [8242] = {.lex_state = 371},
  [8243] = {.lex_state = 31},
  [8244] = {.lex_state = 31},
  [8245] = {.lex_state = 371},
  [8246] = {.lex_state = 371},
  [8247] = {.lex_state = 371},
  [8248] = {.lex_state = 25},
  [8249] = {.lex_state = 372},
  [8250] = {.lex_state = 372},
  [8251] = {.lex_state = 31},
  [8252] = {.lex_state = 25},
  [8253] = {.lex_state = 372},
  [8254] = {.lex_state = 371},
  [8255] = {.lex_state = 31},
  [8256] = {.lex_state = 28},
  [8257] = {.lex_state = 371},
  [8258] = {.lex_state = 371},
  [8259] = {.lex_state = 371},
  [8260] = {.lex_state = 31},
  [8261] = {.lex_state = 371},
  [8262] = {.lex_state = 371},
  [8263] = {.lex_state = 371},
  [8264] = {.lex_state = 33},
  [8265] = {.lex_state = 371},
  [8266] = {.lex_state = 33},
  [8267] = {.lex_state = 31},
  [8268] = {.lex_state = 371},
  [8269] = {.lex_state = 371},
  [8270] = {.lex_state = 371},
  [8271] = {.lex_state = 31},
  [8272] = {.lex_state = 371},
  [8273] = {.lex_state = 371},
  [8274] = {.lex_state = 371},
  [8275] = {.lex_state = 371},
  [8276] = {.lex_state = 371},
  [8277] = {.lex_state = 371},
  [8278] = {.lex_state = 31},
  [8279] = {.lex_state = 371},
  [8280] = {.lex_state = 32},
  [8281] = {.lex_state = 373},
  [8282] = {.lex_state = 371},
  [8283] = {.lex_state = 14},
  [8284] = {.lex_state = 371},
  [8285] = {.lex_state = 371},
  [8286] = {.lex_state = 371},
  [8287] = {.lex_state = 372},
  [8288] = {.lex_state = 371},
  [8289] = {.lex_state = 371},
  [8290] = {.lex_state = 25},
  [8291] = {.lex_state = 371},
  [8292] = {.lex_state = 35},
  [8293] = {.lex_state = 35},
  [8294] = {.lex_state = 371},
  [8295] = {.lex_state = 372},
  [8296] = {.lex_state = 371},
  [8297] = {.lex_state = 9},
  [8298] = {.lex_state = 371},
  [8299] = {.lex_state = 373},
  [8300] = {.lex_state = 371},
  [8301] = {.lex_state = 372},
  [8302] = {.lex_state = 371},
  [8303] = {.lex_state = 371},
  [8304] = {.lex_state = 372},
  [8305] = {.lex_state = 371},
  [8306] = {.lex_state = 371},
  [8307] = {.lex_state = 18},
  [8308] = {.lex_state = 371},
  [8309] = {.lex_state = 18},
  [8310] = {.lex_state = 372},
  [8311] = {.lex_state = 371},
  [8312] = {.lex_state = 371},
  [8313] = {.lex_state = 372},
  [8314] = {.lex_state = 371},
  [8315] = {.lex_state = 25},
  [8316] = {.lex_state = 372},
  [8317] = {.lex_state = 371},
  [8318] = {.lex_state = 25},
  [8319] = {.lex_state = 372},
  [8320] = {.lex_state = 371},
  [8321] = {.lex_state = 371},
  [8322] = {.lex_state = 371},
  [8323] = {.lex_state = 371},
  [8324] = {.lex_state = 371},
  [8325] = {.lex_state = 372},
  [8326] = {.lex_state = 372},
  [8327] = {.lex_state = 32},
  [8328] = {.lex_state = 371},
  [8329] = {.lex_state = 14},
  [8330] = {.lex_state = 371},
  [8331] = {.lex_state = 371},
  [8332] = {.lex_state = 372},
  [8333] = {.lex_state = 372},
  [8334] = {.lex_state = 372},
  [8335] = {.lex_state = 372},
  [8336] = {.lex_state = 371},
  [8337] = {.lex_state = 371},
  [8338] = {.lex_state = 18},
  [8339] = {.lex_state = 14},
  [8340] = {.lex_state = 24},
  [8341] = {.lex_state = 371},
  [8342] = {.lex_state = 18},
  [8343] = {.lex_state = 18},
  [8344] = {.lex_state = 18},
  [8345] = {.lex_state = 23},
  [8346] = {.lex_state = 32},
  [8347] = {.lex_state = 23},
  [8348] = {.lex_state = 372},
  [8349] = {.lex_state = 32},
  [8350] = {.lex_state = 372},
  [8351] = {.lex_state = 50},
  [8352] = {.lex_state = 24},
  [8353] = {.lex_state = 371},
  [8354] = {.lex_state = 373},
  [8355] = {.lex_state = 371},
  [8356] = {.lex_state = 371},
  [8357] = {.lex_state = 373},
  [8358] = {.lex_state = 372},
  [8359] = {.lex_state = 371},
  [8360] = {.lex_state = 18},
  [8361] = {.lex_state = 18},
  [8362] = {.lex_state = 371},
  [8363] = {.lex_state = 372},
  [8364] = {.lex_state = 371},
  [8365] = {.lex_state = 371},
  [8366] = {.lex_state = 371},
  [8367] = {.lex_state = 18},
  [8368] = {.lex_state = 18},
  [8369] = {.lex_state = 18},
  [8370] = {.lex_state = 372},
  [8371] = {.lex_state = 371},
  [8372] = {.lex_state = 371},
  [8373] = {.lex_state = 18},
  [8374] = {.lex_state = 371},
  [8375] = {.lex_state = 371},
  [8376] = {.lex_state = 24},
  [8377] = {.lex_state = 371},
  [8378] = {.lex_state = 371},
  [8379] = {.lex_state = 24},
  [8380] = {.lex_state = 371},
  [8381] = {.lex_state = 371},
  [8382] = {.lex_state = 372},
  [8383] = {.lex_state = 23},
  [8384] = {.lex_state = 371},
  [8385] = {.lex_state = 371},
  [8386] = {.lex_state = 371},
  [8387] = {.lex_state = 24},
  [8388] = {.lex_state = 371},
  [8389] = {.lex_state = 371},
  [8390] = {.lex_state = 371},
  [8391] = {.lex_state = 371},
  [8392] = {.lex_state = 371},
  [8393] = {.lex_state = 23},
  [8394] = {.lex_state = 371},
  [8395] = {.lex_state = 371},
  [8396] = {.lex_state = 371},
  [8397] = {.lex_state = 371},
  [8398] = {.lex_state = 24},
  [8399] = {.lex_state = 371},
  [8400] = {.lex_state = 371},
  [8401] = {.lex_state = 24},
  [8402] = {.lex_state = 371},
  [8403] = {.lex_state = 23},
  [8404] = {.lex_state = 371},
  [8405] = {.lex_state = 371},
  [8406] = {.lex_state = 32},
  [8407] = {.lex_state = 371},
  [8408] = {.lex_state = 371},
  [8409] = {.lex_state = 371},
  [8410] = {.lex_state = 371},
  [8411] = {.lex_state = 24},
  [8412] = {.lex_state = 371},
  [8413] = {.lex_state = 371},
  [8414] = {.lex_state = 371},
  [8415] = {.lex_state = 23},
  [8416] = {.lex_state = 32},
  [8417] = {.lex_state = 23},
  [8418] = {.lex_state = 371},
  [8419] = {.lex_state = 371},
  [8420] = {.lex_state = 371},
  [8421] = {.lex_state = 32},
  [8422] = {.lex_state = 23},
  [8423] = {.lex_state = 372},
  [8424] = {.lex_state = 23},
  [8425] = {.lex_state = 23},
  [8426] = {.lex_state = 371},
  [8427] = {.lex_state = 24},
  [8428] = {.lex_state = 23},
  [8429] = {.lex_state = 371},
  [8430] = {.lex_state = 371},
  [8431] = {.lex_state = 371},
  [8432] = {.lex_state = 371},
  [8433] = {.lex_state = 371},
  [8434] = {.lex_state = 371},
  [8435] = {.lex_state = 371},
  [8436] = {.lex_state = 371},
  [8437] = {.lex_state = 371},
  [8438] = {.lex_state = 371},
  [8439] = {.lex_state = 32},
  [8440] = {.lex_state = 371},
  [8441] = {.lex_state = 371},
  [8442] = {.lex_state = 24},
  [8443] = {.lex_state = 24},
  [8444] = {.lex_state = 371},
  [8445] = {.lex_state = 371},
  [8446] = {.lex_state = 18},
  [8447] = {.lex_state = 371},
  [8448] = {.lex_state = 25},
  [8449] = {.lex_state = 25},
  [8450] = {.lex_state = 24},
  [8451] = {.lex_state = 371},
  [8452] = {.lex_state = 371},
  [8453] = {.lex_state = 43},
  [8454] = {.lex_state = 371},
  [8455] = {.lex_state = 37},
  [8456] = {.lex_state = 23},
  [8457] = {.lex_state = 37},
  [8458] = {.lex_state = 372},
  [8459] = {.lex_state = 23},
  [8460] = {.lex_state = 36},
  [8461] = {.lex_state = 36},
  [8462] = {.lex_state = 23},
  [8463] = {.lex_state = 23},
  [8464] = {.lex_state = 371},
  [8465] = {.lex_state = 24},
  [8466] = {.lex_state = 24},
  [8467] = {.lex_state = 23},
  [8468] = {.lex_state = 18},
  [8469] = {.lex_state = 371},
  [8470] = {.lex_state = 31},
  [8471] = {.lex_state = 18},
  [8472] = {.lex_state = 18},
  [8473] = {.lex_state = 371},
  [8474] = {.lex_state = 371},
  [8475] = {.lex_state = 371},
  [8476] = {.lex_state = 371},
  [8477] = {.lex_state = 33},
  [8478] = {.lex_state = 371},
  [8479] = {.lex_state = 18},
  [8480] = {.lex_state = 33},
  [8481] = {.lex_state = 23},
  [8482] = {.lex_state = 371},
  [8483] = {.lex_state = 23},
  [8484] = {.lex_state = 22},
  [8485] = {.lex_state = 40},
  [8486] = {.lex_state = 371},
  [8487] = {.lex_state = 371},
  [8488] = {.lex_state = 371},
  [8489] = {.lex_state = 371},
  [8490] = {.lex_state = 23},
  [8491] = {.lex_state = 31},
  [8492] = {.lex_state = 23},
  [8493] = {.lex_state = 23},
  [8494] = {.lex_state = 23},
  [8495] = {.lex_state = 31},
  [8496] = {.lex_state = 23},
  [8497] = {.lex_state = 23},
  [8498] = {.lex_state = 31},
  [8499] = {.lex_state = 371},
  [8500] = {.lex_state = 371},
  [8501] = {.lex_state = 371},
  [8502] = {.lex_state = 371},
  [8503] = {.lex_state = 23},
  [8504] = {.lex_state = 23},
  [8505] = {.lex_state = 43},
  [8506] = {.lex_state = 24},
  [8507] = {.lex_state = 50},
  [8508] = {.lex_state = 31},
  [8509] = {.lex_state = 22},
  [8510] = {.lex_state = 24},
  [8511] = {.lex_state = 33},
  [8512] = {.lex_state = 23},
  [8513] = {.lex_state = 24},
  [8514] = {.lex_state = 23},
  [8515] = {.lex_state = 50},
  [8516] = {.lex_state = 371},
  [8517] = {.lex_state = 50},
  [8518] = {.lex_state = 31},
  [8519] = {.lex_state = 33},
  [8520] = {.lex_state = 23},
  [8521] = {.lex_state = 50},
  [8522] = {.lex_state = 24},
  [8523] = {.lex_state = 371},
  [8524] = {.lex_state = 23},
  [8525] = {.lex_state = 24},
  [8526] = {.lex_state = 24},
  [8527] = {.lex_state = 24},
  [8528] = {.lex_state = 25},
  [8529] = {.lex_state = 371},
  [8530] = {.lex_state = 25},
  [8531] = {.lex_state = 372},
  [8532] = {.lex_state = 50},
  [8533] = {.lex_state = 371},
  [8534] = {.lex_state = 50},
  [8535] = {.lex_state = 371},
  [8536] = {.lex_state = 371},
  [8537] = {.lex_state = 371},
  [8538] = {.lex_state = 50},
  [8539] = {.lex_state = 50},
  [8540] = {.lex_state = 371},
  [8541] = {.lex_state = 43},
  [8542] = {.lex_state = 23},
  [8543] = {.lex_state = 23},
  [8544] = {.lex_state = 23},
  [8545] = {.lex_state = 23},
  [8546] = {.lex_state = 371},
  [8547] = {.lex_state = 23},
  [8548] = {.lex_state = 23},
  [8549] = {.lex_state = 371},
  [8550] = {.lex_state = 23},
  [8551] = {.lex_state = 23},
  [8552] = {.lex_state = 371},
  [8553] = {.lex_state = 23},
  [8554] = {.lex_state = 23},
  [8555] = {.lex_state = 371},
  [8556] = {.lex_state = 371},
  [8557] = {.lex_state = 23},
  [8558] = {.lex_state = 23},
  [8559] = {.lex_state = 23},
  [8560] = {.lex_state = 23},
  [8561] = {.lex_state = 371},
  [8562] = {.lex_state = 23},
  [8563] = {.lex_state = 23},
  [8564] = {.lex_state = 371},
  [8565] = {.lex_state = 23},
  [8566] = {.lex_state = 371},
  [8567] = {.lex_state = 31},
  [8568] = {.lex_state = 23},
  [8569] = {.lex_state = 31},
  [8570] = {.lex_state = 371},
  [8571] = {.lex_state = 23},
  [8572] = {.lex_state = 23},
  [8573] = {.lex_state = 371},
  [8574] = {.lex_state = 371},
  [8575] = {.lex_state = 371},
  [8576] = {.lex_state = 23},
  [8577] = {.lex_state = 371},
  [8578] = {.lex_state = 23},
  [8579] = {.lex_state = 33},
  [8580] = {.lex_state = 371},
  [8581] = {.lex_state = 33},
  [8582] = {.lex_state = 23},
  [8583] = {.lex_state = 23},
  [8584] = {.lex_state = 23},
  [8585] = {.lex_state = 23},
  [8586] = {.lex_state = 18},
  [8587] = {.lex_state = 23},
  [8588] = {.lex_state = 371},
  [8589] = {.lex_state = 23},
  [8590] = {.lex_state = 23},
  [8591] = {.lex_state = 23},
  [8592] = {.lex_state = 18},
  [8593] = {.lex_state = 23},
  [8594] = {.lex_state = 25},
  [8595] = {.lex_state = 23},
  [8596] = {.lex_state = 371},
  [8597] = {.lex_state = 23},
  [8598] = {.lex_state = 371},
  [8599] = {.lex_state = 25},
  [8600] = {.lex_state = 31},
  [8601] = {.lex_state = 31},
  [8602] = {.lex_state = 371},
  [8603] = {.lex_state = 23},
  [8604] = {.lex_state = 23},
  [8605] = {.lex_state = 371},
  [8606] = {.lex_state = 33},
  [8607] = {.lex_state = 31},
  [8608] = {.lex_state = 23},
  [8609] = {.lex_state = 23},
  [8610] = {.lex_state = 371},
  [8611] = {.lex_state = 23},
  [8612] = {.lex_state = 23},
  [8613] = {.lex_state = 23},
  [8614] = {.lex_state = 371},
  [8615] = {.lex_state = 371},
  [8616] = {.lex_state = 371},
  [8617] = {.lex_state = 371},
  [8618] = {.lex_state = 23},
  [8619] = {.lex_state = 23},
  [8620] = {.lex_state = 371},
  [8621] = {.lex_state = 23},
  [8622] = {.lex_state = 23},
  [8623] = {.lex_state = 371},
  [8624] = {.lex_state = 371},
  [8625] = {.lex_state = 371},
  [8626] = {.lex_state = 25},
  [8627] = {.lex_state = 23},
  [8628] = {.lex_state = 31},
  [8629] = {.lex_state = 371},
  [8630] = {.lex_state = 23},
  [8631] = {.lex_state = 23},
  [8632] = {.lex_state = 23},
  [8633] = {.lex_state = 23},
  [8634] = {.lex_state = 33},
  [8635] = {.lex_state = 23},
  [8636] = {.lex_state = 23},
  [8637] = {.lex_state = 23},
  [8638] = {.lex_state = 18},
  [8639] = {.lex_state = 23},
  [8640] = {.lex_state = 371},
  [8641] = {.lex_state = 371},
  [8642] = {.lex_state = 23},
  [8643] = {.lex_state = 23},
  [8644] = {.lex_state = 31},
  [8645] = {.lex_state = 31},
  [8646] = {.lex_state = 23},
  [8647] = {.lex_state = 23},
  [8648] = {.lex_state = 371},
  [8649] = {.lex_state = 25},
  [8650] = {.lex_state = 371},
  [8651] = {.lex_state = 23},
  [8652] = {.lex_state = 25},
  [8653] = {.lex_state = 31},
  [8654] = {.lex_state = 23},
  [8655] = {.lex_state = 31},
  [8656] = {.lex_state = 371},
  [8657] = {.lex_state = 23},
  [8658] = {.lex_state = 23},
  [8659] = {.lex_state = 23},
  [8660] = {.lex_state = 371},
  [8661] = {.lex_state = 24},
  [8662] = {.lex_state = 371},
  [8663] = {.lex_state = 25},
  [8664] = {.lex_state = 33},
  [8665] = {.lex_state = 25},
  [8666] = {.lex_state = 371},
  [8667] = {.lex_state = 24},
  [8668] = {.lex_state = 41},
  [8669] = {.lex_state = 23},
  [8670] = {.lex_state = 23},
  [8671] = {.lex_state = 33},
  [8672] = {.lex_state = 371},
  [8673] = {.lex_state = 25},
  [8674] = {.lex_state = 23},
  [8675] = {.lex_state = 23},
  [8676] = {.lex_state = 24},
  [8677] = {.lex_state = 23},
  [8678] = {.lex_state = 23},
  [8679] = {.lex_state = 371},
  [8680] = {.lex_state = 371},
  [8681] = {.lex_state = 23},
  [8682] = {.lex_state = 33},
  [8683] = {.lex_state = 25},
  [8684] = {.lex_state = 23},
  [8685] = {.lex_state = 371},
  [8686] = {.lex_state = 23},
  [8687] = {.lex_state = 23},
  [8688] = {.lex_state = 25},
  [8689] = {.lex_state = 23},
  [8690] = {.lex_state = 23},
  [8691] = {.lex_state = 33},
  [8692] = {.lex_state = 23},
  [8693] = {.lex_state = 25},
  [8694] = {.lex_state = 33},
  [8695] = {.lex_state = 24},
  [8696] = {.lex_state = 22},
  [8697] = {.lex_state = 25},
  [8698] = {.lex_state = 23},
  [8699] = {.lex_state = 24},
  [8700] = {.lex_state = 41},
  [8701] = {.lex_state = 33},
  [8702] = {.lex_state = 33},
  [8703] = {.lex_state = 371},
  [8704] = {.lex_state = 33},
  [8705] = {.lex_state = 23},
  [8706] = {.lex_state = 22},
  [8707] = {.lex_state = 25},
  [8708] = {.lex_state = 23},
  [8709] = {.lex_state = 371},
  [8710] = {.lex_state = 33},
  [8711] = {.lex_state = 23},
  [8712] = {.lex_state = 33},
  [8713] = {.lex_state = 371},
  [8714] = {.lex_state = 33},
  [8715] = {.lex_state = 371},
  [8716] = {.lex_state = 371},
  [8717] = {.lex_state = 23},
  [8718] = {.lex_state = 371},
  [8719] = {.lex_state = 371},
  [8720] = {.lex_state = 371},
  [8721] = {.lex_state = 23},
  [8722] = {.lex_state = 33},
  [8723] = {.lex_state = 371},
  [8724] = {.lex_state = 25},
  [8725] = {.lex_state = 25},
  [8726] = {.lex_state = 371},
  [8727] = {.lex_state = 23},
  [8728] = {.lex_state = 23},
  [8729] = {.lex_state = 43},
  [8730] = {.lex_state = 23},
  [8731] = {.lex_state = 25},
  [8732] = {.lex_state = 43},
  [8733] = {.lex_state = 22},
  [8734] = {.lex_state = 25},
  [8735] = {.lex_state = 24},
  [8736] = {.lex_state = 371},
  [8737] = {.lex_state = 41},
  [8738] = {.lex_state = 371},
  [8739] = {.lex_state = 371},
  [8740] = {.lex_state = 23},
  [8741] = {.lex_state = 23},
  [8742] = {.lex_state = 23},
  [8743] = {.lex_state = 33},
  [8744] = {.lex_state = 33},
  [8745] = {.lex_state = 24},
  [8746] = {.lex_state = 25},
  [8747] = {.lex_state = 23},
  [8748] = {.lex_state = 23},
  [8749] = {.lex_state = 371},
  [8750] = {.lex_state = 18},
  [8751] = {.lex_state = 18},
  [8752] = {.lex_state = 7},
  [8753] = {.lex_state = 372},
  [8754] = {.lex_state = 371},
  [8755] = {.lex_state = 23},
  [8756] = {.lex_state = 23},
  [8757] = {.lex_state = 18},
  [8758] = {.lex_state = 18},
  [8759] = {.lex_state = 18},
  [8760] = {.lex_state = 371},
  [8761] = {.lex_state = 371},
  [8762] = {.lex_state = 371},
  [8763] = {.lex_state = 371},
  [8764] = {.lex_state = 18},
  [8765] = {.lex_state = 372},
  [8766] = {.lex_state = 18},
  [8767] = {.lex_state = 18},
  [8768] = {.lex_state = 18},
  [8769] = {.lex_state = 18},
  [8770] = {.lex_state = 18},
  [8771] = {.lex_state = 7},
  [8772] = {.lex_state = 371},
  [8773] = {.lex_state = 18},
  [8774] = {.lex_state = 18},
  [8775] = {.lex_state = 18},
  [8776] = {.lex_state = 371},
  [8777] = {.lex_state = 371},
  [8778] = {.lex_state = 372},
  [8779] = {.lex_state = 7},
  [8780] = {.lex_state = 18},
  [8781] = {.lex_state = 18},
  [8782] = {.lex_state = 18},
  [8783] = {.lex_state = 18},
  [8784] = {.lex_state = 7},
  [8785] = {.lex_state = 372},
  [8786] = {.lex_state = 7},
  [8787] = {.lex_state = 18},
  [8788] = {.lex_state = 18},
  [8789] = {.lex_state = 24},
  [8790] = {.lex_state = 18},
  [8791] = {.lex_state = 18},
  [8792] = {.lex_state = 18},
  [8793] = {.lex_state = 371},
  [8794] = {.lex_state = 18},
  [8795] = {.lex_state = 371},
  [8796] = {.lex_state = 371},
  [8797] = {.lex_state = 371},
  [8798] = {.lex_state = 371},
  [8799] = {.lex_state = 371},
  [8800] = {.lex_state = 371},
  [8801] = {.lex_state = 371},
  [8802] = {.lex_state = 371},
  [8803] = {.lex_state = 371},
  [8804] = {.lex_state = 371},
  [8805] = {.lex_state = 371},
  [8806] = {.lex_state = 371},
  [8807] = {.lex_state = 371},
  [8808] = {.lex_state = 371},
  [8809] = {.lex_state = 371},
  [8810] = {.lex_state = 18},
  [8811] = {.lex_state = 371},
  [8812] = {.lex_state = 22},
  [8813] = {.lex_state = 371},
  [8814] = {.lex_state = 37},
  [8815] = {.lex_state = 24},
  [8816] = {.lex_state = 371},
  [8817] = {.lex_state = 371},
  [8818] = {.lex_state = 371},
  [8819] = {.lex_state = 371},
  [8820] = {.lex_state = 371},
  [8821] = {.lex_state = 371},
  [8822] = {.lex_state = 371},
  [8823] = {.lex_state = 18},
  [8824] = {.lex_state = 43},
  [8825] = {.lex_state = 24},
  [8826] = {.lex_state = 372},
  [8827] = {.lex_state = 371},
  [8828] = {.lex_state = 24},
  [8829] = {.lex_state = 24},
  [8830] = {.lex_state = 24},
  [8831] = {.lex_state = 43},
  [8832] = {.lex_state = 43},
  [8833] = {.lex_state = 24},
  [8834] = {.lex_state = 18},
  [8835] = {.lex_state = 23},
  [8836] = {.lex_state = 43},
  [8837] = {.lex_state = 18},
  [8838] = {.lex_state = 23},
  [8839] = {.lex_state = 18},
  [8840] = {.lex_state = 28},
  [8841] = {.lex_state = 28},
  [8842] = {.lex_state = 43},
  [8843] = {.lex_state = 23},
  [8844] = {.lex_state = 23},
  [8845] = {.lex_state = 18},
  [8846] = {.lex_state = 24},
  [8847] = {.lex_state = 24},
  [8848] = {.lex_state = 18},
  [8849] = {.lex_state = 24},
  [8850] = {.lex_state = 24},
  [8851] = {.lex_state = 23},
  [8852] = {.lex_state = 23},
  [8853] = {.lex_state = 18},
  [8854] = {.lex_state = 23},
  [8855] = {.lex_state = 23},
  [8856] = {.lex_state = 26},
  [8857] = {.lex_state = 23},
  [8858] = {.lex_state = 23},
  [8859] = {.lex_state = 49},
  [8860] = {.lex_state = 49},
  [8861] = {.lex_state = 26},
  [8862] = {.lex_state = 26},
  [8863] = {.lex_state = 24},
  [8864] = {.lex_state = 373},
  [8865] = {.lex_state = 18},
  [8866] = {.lex_state = 24},
  [8867] = {.lex_state = 23},
  [8868] = {.lex_state = 18},
  [8869] = {.lex_state = 18},
  [8870] = {.lex_state = 24},
  [8871] = {.lex_state = 21},
  [8872] = {.lex_state = 371},
  [8873] = {.lex_state = 43},
  [8874] = {.lex_state = 43},
  [8875] = {.lex_state = 24},
  [8876] = {.lex_state = 18},
  [8877] = {.lex_state = 18},
  [8878] = {.lex_state = 18},
  [8879] = {.lex_state = 18},
  [8880] = {.lex_state = 24},
  [8881] = {.lex_state = 24},
  [8882] = {.lex_state = 24},
  [8883] = {.lex_state = 22},
  [8884] = {.lex_state = 18},
  [8885] = {.lex_state = 18},
  [8886] = {.lex_state = 18},
  [8887] = {.lex_state = 18},
  [8888] = {.lex_state = 24},
  [8889] = {.lex_state = 18},
  [8890] = {.lex_state = 18},
  [8891] = {.lex_state = 18},
  [8892] = {.lex_state = 18},
  [8893] = {.lex_state = 18},
  [8894] = {.lex_state = 18},
  [8895] = {.lex_state = 371},
  [8896] = {.lex_state = 18},
  [8897] = {.lex_state = 24},
  [8898] = {.lex_state = 23},
  [8899] = {.lex_state = 24},
  [8900] = {.lex_state = 18},
  [8901] = {.lex_state = 24},
  [8902] = {.lex_state = 23},
  [8903] = {.lex_state = 43},
  [8904] = {.lex_state = 24},
  [8905] = {.lex_state = 24},
  [8906] = {.lex_state = 24},
  [8907] = {.lex_state = 23},
  [8908] = {.lex_state = 24},
  [8909] = {.lex_state = 24},
  [8910] = {.lex_state = 24},
  [8911] = {.lex_state = 373},
  [8912] = {.lex_state = 43},
  [8913] = {.lex_state = 24},
  [8914] = {.lex_state = 24},
  [8915] = {.lex_state = 24},
  [8916] = {.lex_state = 371},
  [8917] = {.lex_state = 23},
  [8918] = {.lex_state = 43},
  [8919] = {.lex_state = 24},
  [8920] = {.lex_state = 24},
  [8921] = {.lex_state = 43},
  [8922] = {.lex_state = 371},
  [8923] = {.lex_state = 24},
  [8924] = {.lex_state = 23},
  [8925] = {.lex_state = 371},
  [8926] = {.lex_state = 24},
  [8927] = {.lex_state = 23},
  [8928] = {.lex_state = 24},
  [8929] = {.lex_state = 372},
  [8930] = {.lex_state = 371},
  [8931] = {.lex_state = 24},
  [8932] = {.lex_state = 18},
  [8933] = {.lex_state = 371},
  [8934] = {.lex_state = 24},
  [8935] = {.lex_state = 371},
  [8936] = {.lex_state = 24},
  [8937] = {.lex_state = 43},
  [8938] = {.lex_state = 43},
  [8939] = {.lex_state = 371},
  [8940] = {.lex_state = 24},
  [8941] = {.lex_state = 43},
  [8942] = {.lex_state = 43},
  [8943] = {.lex_state = 24},
  [8944] = {.lex_state = 24},
  [8945] = {.lex_state = 43},
  [8946] = {.lex_state = 24},
  [8947] = {.lex_state = 24},
  [8948] = {.lex_state = 24},
  [8949] = {.lex_state = 43},
  [8950] = {.lex_state = 24},
  [8951] = {.lex_state = 24},
  [8952] = {.lex_state = 24},
  [8953] = {.lex_state = 24},
  [8954] = {.lex_state = 371},
  [8955] = {.lex_state = 43},
  [8956] = {.lex_state = 24},
  [8957] = {.lex_state = 371},
  [8958] = {.lex_state = 371},
  [8959] = {.lex_state = 43},
  [8960] = {.lex_state = 24},
  [8961] = {.lex_state = 24},
  [8962] = {.lex_state = 43},
  [8963] = {.lex_state = 24},
  [8964] = {.lex_state = 371},
  [8965] = {.lex_state = 43},
  [8966] = {.lex_state = 371},
  [8967] = {.lex_state = 371},
  [8968] = {.lex_state = 24},
  [8969] = {.lex_state = 371},
  [8970] = {.lex_state = 43},
  [8971] = {.lex_state = 371},
  [8972] = {.lex_state = 43},
  [8973] = {.lex_state = 43},
  [8974] = {.lex_state = 371},
  [8975] = {.lex_state = 371},
  [8976] = {.lex_state = 24},
  [8977] = {.lex_state = 43},
  [8978] = {.lex_state = 43},
  [8979] = {.lex_state = 24},
  [8980] = {.lex_state = 24},
  [8981] = {.lex_state = 24},
  [8982] = {.lex_state = 43},
  [8983] = {.lex_state = 43},
  [8984] = {.lex_state = 43},
  [8985] = {.lex_state = 43},
  [8986] = {.lex_state = 43},
  [8987] = {.lex_state = 43},
  [8988] = {.lex_state = 43},
  [8989] = {.lex_state = 43},
  [8990] = {.lex_state = 43},
  [8991] = {.lex_state = 43},
  [8992] = {.lex_state = 43},
  [8993] = {.lex_state = 43},
  [8994] = {.lex_state = 43},
  [8995] = {.lex_state = 24},
  [8996] = {.lex_state = 43},
  [8997] = {.lex_state = 43},
  [8998] = {.lex_state = 43},
  [8999] = {.lex_state = 24},
  [9000] = {.lex_state = 43},
  [9001] = {.lex_state = 24},
  [9002] = {.lex_state = 24},
  [9003] = {.lex_state = 24},
  [9004] = {.lex_state = 43},
  [9005] = {.lex_state = 22},
  [9006] = {.lex_state = 43},
  [9007] = {.lex_state = 43},
  [9008] = {.lex_state = 371},
  [9009] = {.lex_state = 371},
  [9010] = {.lex_state = 371},
  [9011] = {.lex_state = 371},
  [9012] = {.lex_state = 43},
  [9013] = {.lex_state = 371},
  [9014] = {.lex_state = 371},
  [9015] = {.lex_state = 371},
  [9016] = {.lex_state = 24},
  [9017] = {.lex_state = 371},
  [9018] = {.lex_state = 43},
  [9019] = {.lex_state = 371},
  [9020] = {.lex_state = 371},
  [9021] = {.lex_state = 24},
  [9022] = {.lex_state = 371},
  [9023] = {.lex_state = 371},
  [9024] = {.lex_state = 371},
  [9025] = {.lex_state = 43},
  [9026] = {.lex_state = 43},
  [9027] = {.lex_state = 24},
  [9028] = {.lex_state = 371},
  [9029] = {.lex_state = 371},
  [9030] = {.lex_state = 371},
  [9031] = {.lex_state = 371},
  [9032] = {.lex_state = 371},
  [9033] = {.lex_state = 371},
  [9034] = {.lex_state = 371},
  [9035] = {.lex_state = 371},
  [9036] = {.lex_state = 371},
  [9037] = {.lex_state = 371},
  [9038] = {.lex_state = 371},
  [9039] = {.lex_state = 24},
  [9040] = {.lex_state = 371},
  [9041] = {.lex_state = 43},
  [9042] = {.lex_state = 371},
  [9043] = {.lex_state = 371},
  [9044] = {.lex_state = 43},
  [9045] = {.lex_state = 371},
  [9046] = {.lex_state = 43},
  [9047] = {.lex_state = 371},
  [9048] = {.lex_state = 43},
  [9049] = {.lex_state = 43},
  [9050] = {.lex_state = 371},
  [9051] = {.lex_state = 43},
  [9052] = {.lex_state = 43},
  [9053] = {.lex_state = 24},
  [9054] = {.lex_state = 43},
  [9055] = {.lex_state = 24},
  [9056] = {.lex_state = 24},
  [9057] = {.lex_state = 24},
  [9058] = {.lex_state = 24},
  [9059] = {.lex_state = 43},
  [9060] = {.lex_state = 43},
  [9061] = {.lex_state = 24},
  [9062] = {.lex_state = 43},
  [9063] = {.lex_state = 24},
  [9064] = {.lex_state = 43},
  [9065] = {.lex_state = 24},
  [9066] = {.lex_state = 43},
  [9067] = {.lex_state = 43},
  [9068] = {.lex_state = 43},
  [9069] = {.lex_state = 43},
  [9070] = {.lex_state = 43},
  [9071] = {.lex_state = 43},
  [9072] = {.lex_state = 43},
  [9073] = {.lex_state = 43},
  [9074] = {.lex_state = 43},
  [9075] = {.lex_state = 371},
  [9076] = {.lex_state = 43},
  [9077] = {.lex_state = 43},
  [9078] = {.lex_state = 371},
  [9079] = {.lex_state = 43},
  [9080] = {.lex_state = 43},
  [9081] = {.lex_state = 43},
  [9082] = {.lex_state = 43},
  [9083] = {.lex_state = 24},
  [9084] = {.lex_state = 43},
  [9085] = {.lex_state = 43},
  [9086] = {.lex_state = 43},
  [9087] = {.lex_state = 43},
  [9088] = {.lex_state = 43},
  [9089] = {.lex_state = 24},
  [9090] = {.lex_state = 372},
  [9091] = {.lex_state = 43},
  [9092] = {.lex_state = 43},
  [9093] = {.lex_state = 43},
  [9094] = {.lex_state = 43},
  [9095] = {.lex_state = 24},
  [9096] = {.lex_state = 24},
  [9097] = {.lex_state = 43},
  [9098] = {.lex_state = 43},
  [9099] = {.lex_state = 43},
  [9100] = {.lex_state = 43},
  [9101] = {.lex_state = 24},
  [9102] = {.lex_state = 43},
  [9103] = {.lex_state = 24},
  [9104] = {.lex_state = 24},
  [9105] = {.lex_state = 43},
  [9106] = {.lex_state = 24},
  [9107] = {.lex_state = 24},
  [9108] = {.lex_state = 371},
  [9109] = {.lex_state = 371},
  [9110] = {.lex_state = 43},
  [9111] = {.lex_state = 24},
  [9112] = {.lex_state = 43},
  [9113] = {.lex_state = 24},
  [9114] = {.lex_state = 371},
  [9115] = {.lex_state = 371},
  [9116] = {.lex_state = 24},
  [9117] = {.lex_state = 26},
  [9118] = {.lex_state = 372},
  [9119] = {.lex_state = 43},
  [9120] = {.lex_state = 43},
  [9121] = {.lex_state = 43},
  [9122] = {.lex_state = 24},
  [9123] = {.lex_state = 43},
  [9124] = {.lex_state = 43},
  [9125] = {.lex_state = 372},
  [9126] = {.lex_state = 43},
  [9127] = {.lex_state = 43},
  [9128] = {.lex_state = 43},
  [9129] = {.lex_state = 43},
  [9130] = {.lex_state = 24},
  [9131] = {.lex_state = 24},
  [9132] = {.lex_state = 24},
  [9133] = {.lex_state = 24},
  [9134] = {.lex_state = 43},
  [9135] = {.lex_state = 24},
  [9136] = {.lex_state = 24},
  [9137] = {.lex_state = 24},
  [9138] = {.lex_state = 371},
  [9139] = {.lex_state = 24},
  [9140] = {.lex_state = 22},
  [9141] = {.lex_state = 43},
  [9142] = {.lex_state = 371},
  [9143] = {.lex_state = 371},
  [9144] = {.lex_state = 371},
  [9145] = {.lex_state = 43},
  [9146] = {.lex_state = 371},
  [9147] = {.lex_state = 43},
  [9148] = {.lex_state = 24},
  [9149] = {.lex_state = 24},
  [9150] = {.lex_state = 371},
  [9151] = {.lex_state = 24},
  [9152] = {.lex_state = 43},
  [9153] = {.lex_state = 24},
  [9154] = {.lex_state = 24},
  [9155] = {.lex_state = 24},
  [9156] = {.lex_state = 43},
  [9157] = {.lex_state = 371},
  [9158] = {.lex_state = 371},
  [9159] = {.lex_state = 372},
  [9160] = {.lex_state = 371},
  [9161] = {.lex_state = 371},
  [9162] = {.lex_state = 24},
  [9163] = {.lex_state = 372},
  [9164] = {.lex_state = 23},
  [9165] = {.lex_state = 24},
  [9166] = {.lex_state = 24},
  [9167] = {.lex_state = 372},
  [9168] = {.lex_state = 371},
  [9169] = {.lex_state = 23},
  [9170] = {.lex_state = 371},
  [9171] = {.lex_state = 24},
  [9172] = {.lex_state = 371},
  [9173] = {.lex_state = 23},
  [9174] = {.lex_state = 23},
  [9175] = {.lex_state = 24},
  [9176] = {.lex_state = 371},
  [9177] = {.lex_state = 373},
  [9178] = {.lex_state = 372},
  [9179] = {.lex_state = 372},
  [9180] = {.lex_state = 24},
  [9181] = {.lex_state = 371},
  [9182] = {.lex_state = 372},
  [9183] = {.lex_state = 371},
  [9184] = {.lex_state = 373},
  [9185] = {.lex_state = 373},
  [9186] = {.lex_state = 373},
  [9187] = {.lex_state = 24},
  [9188] = {.lex_state = 371},
  [9189] = {.lex_state = 43},
  [9190] = {.lex_state = 43},
  [9191] = {.lex_state = 371},
  [9192] = {.lex_state = 371},
  [9193] = {.lex_state = 24},
  [9194] = {.lex_state = 371},
  [9195] = {.lex_state = 373},
  [9196] = {.lex_state = 24},
  [9197] = {.lex_state = 24},
  [9198] = {.lex_state = 371},
  [9199] = {.lex_state = 24},
  [9200] = {.lex_state = 371},
  [9201] = {.lex_state = 373},
  [9202] = {.lex_state = 371},
  [9203] = {.lex_state = 23},
  [9204] = {.lex_state = 371},
  [9205] = {.lex_state = 371},
  [9206] = {.lex_state = 371},
  [9207] = {.lex_state = 371},
  [9208] = {.lex_state = 373},
  [9209] = {.lex_state = 371},
  [9210] = {.lex_state = 371},
  [9211] = {.lex_state = 371},
  [9212] = {.lex_state = 371},
  [9213] = {.lex_state = 24},
  [9214] = {.lex_state = 373},
  [9215] = {.lex_state = 372},
  [9216] = {.lex_state = 24},
  [9217] = {.lex_state = 371},
  [9218] = {.lex_state = 371},
  [9219] = {.lex_state = 373},
  [9220] = {.lex_state = 24},
  [9221] = {.lex_state = 371},
  [9222] = {.lex_state = 24},
  [9223] = {.lex_state = 372},
  [9224] = {.lex_state = 371},
  [9225] = {.lex_state = 373},
  [9226] = {.lex_state = 372},
  [9227] = {.lex_state = 373},
  [9228] = {.lex_state = 371},
  [9229] = {.lex_state = 24},
  [9230] = {.lex_state = 372},
  [9231] = {.lex_state = 372},
  [9232] = {.lex_state = 371},
  [9233] = {.lex_state = 371},
  [9234] = {.lex_state = 23},
  [9235] = {.lex_state = 371},
  [9236] = {.lex_state = 373},
  [9237] = {.lex_state = 371},
  [9238] = {.lex_state = 373},
  [9239] = {.lex_state = 24},
  [9240] = {.lex_state = 372},
  [9241] = {.lex_state = 372},
  [9242] = {.lex_state = 372},
  [9243] = {.lex_state = 22},
  [9244] = {.lex_state = 23},
  [9245] = {.lex_state = 24},
  [9246] = {.lex_state = 24},
  [9247] = {.lex_state = 372},
  [9248] = {.lex_state = 372},
  [9249] = {.lex_state = 24},
  [9250] = {.lex_state = 371},
  [9251] = {.lex_state = 24},
  [9252] = {.lex_state = 371},
  [9253] = {.lex_state = 371},
  [9254] = {.lex_state = 24},
  [9255] = {.lex_state = 371},
  [9256] = {.lex_state = 371},
  [9257] = {.lex_state = 24},
  [9258] = {.lex_state = 372},
  [9259] = {.lex_state = 372},
  [9260] = {.lex_state = 371},
  [9261] = {.lex_state = 372},
  [9262] = {.lex_state = 371},
  [9263] = {.lex_state = 371},
  [9264] = {.lex_state = 24},
  [9265] = {.lex_state = 371},
  [9266] = {.lex_state = 371},
  [9267] = {.lex_state = 372},
  [9268] = {.lex_state = 371},
  [9269] = {.lex_state = 371},
  [9270] = {.lex_state = 371},
  [9271] = {.lex_state = 371},
  [9272] = {.lex_state = 372},
  [9273] = {.lex_state = 371},
  [9274] = {.lex_state = 371},
  [9275] = {.lex_state = 371},
  [9276] = {.lex_state = 23},
  [9277] = {.lex_state = 23},
  [9278] = {.lex_state = 43},
  [9279] = {.lex_state = 371},
  [9280] = {.lex_state = 23},
  [9281] = {.lex_state = 24},
  [9282] = {.lex_state = 24},
  [9283] = {.lex_state = 24},
  [9284] = {.lex_state = 371},
  [9285] = {.lex_state = 24},
  [9286] = {.lex_state = 371},
  [9287] = {.lex_state = 373},
  [9288] = {.lex_state = 23},
  [9289] = {.lex_state = 371},
  [9290] = {.lex_state = 372},
  [9291] = {.lex_state = 371},
  [9292] = {.lex_state = 43},
  [9293] = {.lex_state = 23},
  [9294] = {.lex_state = 24},
  [9295] = {.lex_state = 371},
  [9296] = {.lex_state = 24},
  [9297] = {.lex_state = 372},
  [9298] = {.lex_state = 24},
  [9299] = {.lex_state = 372},
  [9300] = {.lex_state = 24},
  [9301] = {.lex_state = 24},
  [9302] = {.lex_state = 371},
  [9303] = {.lex_state = 371},
  [9304] = {.lex_state = 371},
  [9305] = {.lex_state = 373},
  [9306] = {.lex_state = 24},
  [9307] = {.lex_state = 371},
  [9308] = {.lex_state = 24},
  [9309] = {.lex_state = 23},
  [9310] = {.lex_state = 23},
  [9311] = {.lex_state = 372},
  [9312] = {.lex_state = 24},
  [9313] = {.lex_state = 23},
  [9314] = {.lex_state = 24},
  [9315] = {.lex_state = 23},
  [9316] = {.lex_state = 23},
  [9317] = {.lex_state = 371},
  [9318] = {.lex_state = 371},
  [9319] = {.lex_state = 24},
  [9320] = {.lex_state = 23},
  [9321] = {.lex_state = 24},
  [9322] = {.lex_state = 23},
  [9323] = {.lex_state = 373},
  [9324] = {.lex_state = 24},
  [9325] = {.lex_state = 24},
  [9326] = {.lex_state = 371},
  [9327] = {.lex_state = 371},
  [9328] = {.lex_state = 24},
  [9329] = {.lex_state = 371},
  [9330] = {.lex_state = 24},
  [9331] = {.lex_state = 371},
  [9332] = {.lex_state = 372},
  [9333] = {.lex_state = 371},
  [9334] = {.lex_state = 371},
  [9335] = {.lex_state = 371},
  [9336] = {.lex_state = 371},
  [9337] = {.lex_state = 371},
  [9338] = {.lex_state = 371},
  [9339] = {.lex_state = 23},
  [9340] = {.lex_state = 371},
  [9341] = {.lex_state = 371},
  [9342] = {.lex_state = 22},
  [9343] = {.lex_state = 43},
  [9344] = {.lex_state = 371},
  [9345] = {.lex_state = 24},
  [9346] = {.lex_state = 371},
  [9347] = {.lex_state = 23},
  [9348] = {.lex_state = 371},
  [9349] = {.lex_state = 371},
  [9350] = {.lex_state = 371},
  [9351] = {.lex_state = 371},
  [9352] = {.lex_state = 371},
  [9353] = {.lex_state = 371},
  [9354] = {.lex_state = 24},
  [9355] = {.lex_state = 371},
  [9356] = {.lex_state = 23},
  [9357] = {.lex_state = 371},
  [9358] = {.lex_state = 371},
  [9359] = {.lex_state = 371},
  [9360] = {.lex_state = 371},
  [9361] = {.lex_state = 371},
  [9362] = {.lex_state = 371},
  [9363] = {.lex_state = 371},
  [9364] = {.lex_state = 372},
  [9365] = {.lex_state = 23},
  [9366] = {.lex_state = 372},
  [9367] = {.lex_state = 371},
  [9368] = {.lex_state = 23},
  [9369] = {.lex_state = 23},
  [9370] = {.lex_state = 372},
  [9371] = {.lex_state = 372},
  [9372] = {.lex_state = 23},
  [9373] = {.lex_state = 371},
  [9374] = {.lex_state = 23},
  [9375] = {.lex_state = 24},
  [9376] = {.lex_state = 371},
  [9377] = {.lex_state = 24},
  [9378] = {.lex_state = 372},
  [9379] = {.lex_state = 372},
  [9380] = {.lex_state = 371},
  [9381] = {.lex_state = 24},
  [9382] = {.lex_state = 373},
  [9383] = {.lex_state = 371},
  [9384] = {.lex_state = 373},
  [9385] = {.lex_state = 24},
  [9386] = {.lex_state = 22},
  [9387] = {.lex_state = 24},
  [9388] = {.lex_state = 371},
  [9389] = {.lex_state = 24},
  [9390] = {.lex_state = 24},
  [9391] = {.lex_state = 371},
  [9392] = {.lex_state = 371},
  [9393] = {.lex_state = 371},
  [9394] = {.lex_state = 372},
  [9395] = {.lex_state = 371},
  [9396] = {.lex_state = 371},
  [9397] = {.lex_state = 371},
  [9398] = {.lex_state = 371},
  [9399] = {.lex_state = 371},
  [9400] = {.lex_state = 24},
  [9401] = {.lex_state = 371},
  [9402] = {.lex_state = 371},
  [9403] = {.lex_state = 371},
  [9404] = {.lex_state = 371},
  [9405] = {.lex_state = 371},
  [9406] = {.lex_state = 371},
  [9407] = {.lex_state = 371},
  [9408] = {.lex_state = 24},
  [9409] = {.lex_state = 371},
  [9410] = {.lex_state = 371},
  [9411] = {.lex_state = 371},
  [9412] = {.lex_state = 371},
  [9413] = {.lex_state = 371},
  [9414] = {.lex_state = 371},
  [9415] = {.lex_state = 371},
  [9416] = {.lex_state = 371},
  [9417] = {.lex_state = 371},
  [9418] = {.lex_state = 372},
  [9419] = {.lex_state = 371},
  [9420] = {.lex_state = 371},
  [9421] = {.lex_state = 371},
  [9422] = {.lex_state = 371},
  [9423] = {.lex_state = 371},
  [9424] = {.lex_state = 371},
  [9425] = {.lex_state = 371},
  [9426] = {.lex_state = 371},
  [9427] = {.lex_state = 371},
  [9428] = {.lex_state = 24},
  [9429] = {.lex_state = 371},
  [9430] = {.lex_state = 371},
  [9431] = {.lex_state = 371},
  [9432] = {.lex_state = 371},
  [9433] = {.lex_state = 371},
  [9434] = {.lex_state = 371},
  [9435] = {.lex_state = 371},
  [9436] = {.lex_state = 371},
  [9437] = {.lex_state = 371},
  [9438] = {.lex_state = 371},
  [9439] = {.lex_state = 371},
  [9440] = {.lex_state = 371},
  [9441] = {.lex_state = 22},
  [9442] = {.lex_state = 371},
  [9443] = {.lex_state = 371},
  [9444] = {.lex_state = 371},
  [9445] = {.lex_state = 373},
  [9446] = {.lex_state = 371},
  [9447] = {.lex_state = 371},
  [9448] = {.lex_state = 371},
  [9449] = {.lex_state = 373},
  [9450] = {.lex_state = 24},
  [9451] = {.lex_state = 371},
  [9452] = {.lex_state = 24},
  [9453] = {.lex_state = 371},
  [9454] = {.lex_state = 371},
  [9455] = {.lex_state = 24},
  [9456] = {.lex_state = 371},
  [9457] = {.lex_state = 371},
  [9458] = {.lex_state = 24},
  [9459] = {.lex_state = 371},
  [9460] = {.lex_state = 371},
  [9461] = {.lex_state = 371},
  [9462] = {.lex_state = 371},
  [9463] = {.lex_state = 371},
  [9464] = {.lex_state = 373},
  [9465] = {.lex_state = 371},
  [9466] = {.lex_state = 371},
  [9467] = {.lex_state = 24},
  [9468] = {.lex_state = 22},
  [9469] = {.lex_state = 371},
  [9470] = {.lex_state = 371},
  [9471] = {.lex_state = 371},
  [9472] = {.lex_state = 371},
  [9473] = {.lex_state = 371},
  [9474] = {.lex_state = 371},
  [9475] = {.lex_state = 371},
  [9476] = {.lex_state = 373},
  [9477] = {.lex_state = 371},
  [9478] = {.lex_state = 371},
  [9479] = {.lex_state = 371},
  [9480] = {.lex_state = 24},
  [9481] = {.lex_state = 24},
  [9482] = {.lex_state = 371},
  [9483] = {.lex_state = 371},
  [9484] = {.lex_state = 371},
  [9485] = {.lex_state = 371},
  [9486] = {.lex_state = 373},
  [9487] = {.lex_state = 371},
  [9488] = {.lex_state = 24},
  [9489] = {.lex_state = 371},
  [9490] = {.lex_state = 371},
  [9491] = {.lex_state = 371},
  [9492] = {.lex_state = 373},
  [9493] = {.lex_state = 24},
  [9494] = {.lex_state = 371},
  [9495] = {.lex_state = 371},
  [9496] = {.lex_state = 371},
  [9497] = {.lex_state = 371},
  [9498] = {.lex_state = 371},
  [9499] = {.lex_state = 373},
  [9500] = {.lex_state = 22},
  [9501] = {.lex_state = 371},
  [9502] = {.lex_state = 371},
  [9503] = {.lex_state = 373},
  [9504] = {.lex_state = 371},
  [9505] = {.lex_state = 371},
  [9506] = {.lex_state = 371},
  [9507] = {.lex_state = 371},
  [9508] = {.lex_state = 373},
  [9509] = {.lex_state = 371},
  [9510] = {.lex_state = 373},
  [9511] = {.lex_state = 371},
  [9512] = {.lex_state = 371},
  [9513] = {.lex_state = 373},
  [9514] = {.lex_state = 371},
  [9515] = {.lex_state = 371},
  [9516] = {.lex_state = 373},
  [9517] = {.lex_state = 371},
  [9518] = {.lex_state = 373},
  [9519] = {.lex_state = 371},
  [9520] = {.lex_state = 373},
  [9521] = {.lex_state = 371},
  [9522] = {.lex_state = 371},
  [9523] = {.lex_state = 371},
  [9524] = {.lex_state = 371},
  [9525] = {.lex_state = 371},
  [9526] = {.lex_state = 371},
  [9527] = {.lex_state = 371},
  [9528] = {.lex_state = 371},
  [9529] = {.lex_state = 371},
  [9530] = {.lex_state = 24},
  [9531] = {.lex_state = 371},
  [9532] = {.lex_state = 371},
  [9533] = {.lex_state = 371},
  [9534] = {.lex_state = 371},
  [9535] = {.lex_state = 371},
  [9536] = {.lex_state = 371},
  [9537] = {.lex_state = 371},
  [9538] = {.lex_state = 371},
  [9539] = {.lex_state = 22},
  [9540] = {.lex_state = 371},
  [9541] = {.lex_state = 371},
  [9542] = {.lex_state = 371},
  [9543] = {.lex_state = 371},
  [9544] = {.lex_state = 373},
  [9545] = {.lex_state = 22},
  [9546] = {.lex_state = 371},
  [9547] = {.lex_state = 371},
  [9548] = {.lex_state = 371},
  [9549] = {.lex_state = 24},
  [9550] = {.lex_state = 371},
  [9551] = {.lex_state = 371},
  [9552] = {.lex_state = 371},
  [9553] = {.lex_state = 371},
  [9554] = {.lex_state = 371},
  [9555] = {.lex_state = 371},
  [9556] = {.lex_state = 371},
  [9557] = {.lex_state = 24},
  [9558] = {.lex_state = 22},
  [9559] = {.lex_state = 371},
  [9560] = {.lex_state = 372},
  [9561] = {.lex_state = 22},
  [9562] = {.lex_state = 22},
  [9563] = {.lex_state = 371},
  [9564] = {.lex_state = 43},
  [9565] = {.lex_state = 43},
  [9566] = {.lex_state = 371},
  [9567] = {.lex_state = 43},
  [9568] = {.lex_state = 43},
  [9569] = {.lex_state = 43},
  [9570] = {.lex_state = 43},
  [9571] = {.lex_state = 371},
  [9572] = {.lex_state = 43},
  [9573] = {.lex_state = 43},
  [9574] = {.lex_state = 43},
  [9575] = {.lex_state = 371},
  [9576] = {.lex_state = 371},
  [9577] = {.lex_state = 371},
  [9578] = {.lex_state = 43},
  [9579] = {.lex_state = 43},
  [9580] = {.lex_state = 43},
  [9581] = {.lex_state = 43},
  [9582] = {.lex_state = 43},
  [9583] = {.lex_state = 371},
  [9584] = {.lex_state = 43},
  [9585] = {.lex_state = 43},
  [9586] = {.lex_state = 43},
  [9587] = {.lex_state = 43},
  [9588] = {.lex_state = 43},
  [9589] = {.lex_state = 43},
  [9590] = {.lex_state = 43},
  [9591] = {.lex_state = 43},
  [9592] = {.lex_state = 43},
  [9593] = {.lex_state = 43},
  [9594] = {.lex_state = 371},
  [9595] = {.lex_state = 371},
  [9596] = {.lex_state = 43},
  [9597] = {.lex_state = 22},
  [9598] = {.lex_state = 371},
  [9599] = {.lex_state = 43},
  [9600] = {.lex_state = 43},
  [9601] = {.lex_state = 43},
  [9602] = {.lex_state = 43},
  [9603] = {.lex_state = 43},
  [9604] = {.lex_state = 372},
  [9605] = {.lex_state = 43},
  [9606] = {.lex_state = 43},
  [9607] = {.lex_state = 43},
  [9608] = {.lex_state = 371},
  [9609] = {.lex_state = 43},
  [9610] = {.lex_state = 43},
  [9611] = {.lex_state = 372},
  [9612] = {.lex_state = 43},
  [9613] = {.lex_state = 372},
  [9614] = {.lex_state = 43},
  [9615] = {.lex_state = 43},
  [9616] = {.lex_state = 371},
  [9617] = {.lex_state = 43},
  [9618] = {.lex_state = 372},
  [9619] = {.lex_state = 43},
  [9620] = {.lex_state = 22},
  [9621] = {.lex_state = 372},
  [9622] = {.lex_state = 43},
  [9623] = {.lex_state = 43},
  [9624] = {.lex_state = 371},
  [9625] = {.lex_state = 26},
  [9626] = {.lex_state = 372},
  [9627] = {.lex_state = 371},
  [9628] = {.lex_state = 43},
  [9629] = {.lex_state = 43},
  [9630] = {.lex_state = 43},
  [9631] = {.lex_state = 43},
  [9632] = {.lex_state = 371},
  [9633] = {.lex_state = 43},
  [9634] = {.lex_state = 43},
  [9635] = {.lex_state = 43},
  [9636] = {.lex_state = 371},
  [9637] = {.lex_state = 43},
  [9638] = {.lex_state = 43},
  [9639] = {.lex_state = 371},
  [9640] = {.lex_state = 43},
  [9641] = {.lex_state = 43},
  [9642] = {.lex_state = 43},
  [9643] = {.lex_state = 371},
  [9644] = {.lex_state = 43},
  [9645] = {.lex_state = 371},
  [9646] = {.lex_state = 43},
  [9647] = {.lex_state = 43},
  [9648] = {.lex_state = 43},
  [9649] = {.lex_state = 43},
  [9650] = {.lex_state = 372},
  [9651] = {.lex_state = 22},
  [9652] = {.lex_state = 24},
  [9653] = {.lex_state = 371},
  [9654] = {.lex_state = 371},
  [9655] = {.lex_state = 371},
  [9656] = {.lex_state = 43},
  [9657] = {.lex_state = 371},
  [9658] = {.lex_state = 43},
  [9659] = {.lex_state = 43},
  [9660] = {.lex_state = 43},
  [9661] = {.lex_state = 43},
  [9662] = {.lex_state = 43},
  [9663] = {.lex_state = 43},
  [9664] = {.lex_state = 22},
  [9665] = {.lex_state = 371},
  [9666] = {.lex_state = 371},
  [9667] = {.lex_state = 43},
  [9668] = {.lex_state = 371},
  [9669] = {.lex_state = 371},
  [9670] = {.lex_state = 371},
  [9671] = {.lex_state = 43},
  [9672] = {.lex_state = 371},
  [9673] = {.lex_state = 43},
  [9674] = {.lex_state = 371},
  [9675] = {.lex_state = 372},
  [9676] = {.lex_state = 43},
  [9677] = {.lex_state = 43},
  [9678] = {.lex_state = 371},
  [9679] = {.lex_state = 371},
  [9680] = {.lex_state = 371},
  [9681] = {.lex_state = 371},
  [9682] = {.lex_state = 43},
  [9683] = {.lex_state = 43},
  [9684] = {.lex_state = 371},
  [9685] = {.lex_state = 372},
  [9686] = {.lex_state = 43},
  [9687] = {.lex_state = 22},
  [9688] = {.lex_state = 43},
  [9689] = {.lex_state = 43},
  [9690] = {.lex_state = 43},
  [9691] = {.lex_state = 371},
  [9692] = {.lex_state = 43},
  [9693] = {.lex_state = 43},
  [9694] = {.lex_state = 43},
  [9695] = {.lex_state = 371},
  [9696] = {.lex_state = 43},
  [9697] = {.lex_state = 43},
  [9698] = {.lex_state = 22},
  [9699] = {.lex_state = 22},
  [9700] = {.lex_state = 43},
  [9701] = {.lex_state = 43},
  [9702] = {.lex_state = 43},
  [9703] = {.lex_state = 371},
  [9704] = {.lex_state = 43},
  [9705] = {.lex_state = 43},
  [9706] = {.lex_state = 43},
  [9707] = {.lex_state = 371},
  [9708] = {.lex_state = 43},
  [9709] = {.lex_state = 371},
  [9710] = {.lex_state = 371},
  [9711] = {.lex_state = 43},
  [9712] = {.lex_state = 43},
  [9713] = {.lex_state = 43},
  [9714] = {.lex_state = 371},
  [9715] = {.lex_state = 43},
  [9716] = {.lex_state = 43},
  [9717] = {.lex_state = 371},
  [9718] = {.lex_state = 43},
  [9719] = {.lex_state = 43},
  [9720] = {.lex_state = 371},
  [9721] = {.lex_state = 371},
  [9722] = {.lex_state = 371},
  [9723] = {.lex_state = 43},
  [9724] = {.lex_state = 371},
  [9725] = {.lex_state = 43},
  [9726] = {.lex_state = 43},
  [9727] = {.lex_state = 371},
  [9728] = {.lex_state = 43},
  [9729] = {.lex_state = 43},
  [9730] = {.lex_state = 43},
  [9731] = {.lex_state = 371},
  [9732] = {.lex_state = 43},
  [9733] = {.lex_state = 43},
  [9734] = {.lex_state = 372},
  [9735] = {.lex_state = 43},
  [9736] = {.lex_state = 43},
  [9737] = {.lex_state = 43},
  [9738] = {.lex_state = 43},
  [9739] = {.lex_state = 43},
  [9740] = {.lex_state = 43},
  [9741] = {.lex_state = 43},
  [9742] = {.lex_state = 22},
  [9743] = {.lex_state = 22},
  [9744] = {.lex_state = 371},
  [9745] = {.lex_state = 43},
  [9746] = {.lex_state = 371},
  [9747] = {.lex_state = 43},
  [9748] = {.lex_state = 371},
  [9749] = {.lex_state = 371},
  [9750] = {.lex_state = 371},
  [9751] = {.lex_state = 371},
  [9752] = {.lex_state = 43},
  [9753] = {.lex_state = 371},
  [9754] = {.lex_state = 371},
  [9755] = {.lex_state = 371},
  [9756] = {.lex_state = 43},
  [9757] = {.lex_state = 22},
  [9758] = {.lex_state = 371},
  [9759] = {.lex_state = 371},
  [9760] = {.lex_state = 43},
  [9761] = {.lex_state = 371},
  [9762] = {.lex_state = 371},
  [9763] = {.lex_state = 371},
  [9764] = {.lex_state = 371},
  [9765] = {.lex_state = 43},
  [9766] = {.lex_state = 22},
  [9767] = {.lex_state = 371},
  [9768] = {.lex_state = 43},
  [9769] = {.lex_state = 371},
  [9770] = {.lex_state = 43},
  [9771] = {.lex_state = 43},
  [9772] = {.lex_state = 22},
  [9773] = {.lex_state = 43},
  [9774] = {.lex_state = 43},
  [9775] = {.lex_state = 43},
  [9776] = {.lex_state = 22},
  [9777] = {.lex_state = 43},
  [9778] = {.lex_state = 43},
  [9779] = {.lex_state = 43},
  [9780] = {.lex_state = 43},
  [9781] = {.lex_state = 371},
  [9782] = {.lex_state = 22},
  [9783] = {.lex_state = 371},
  [9784] = {.lex_state = 43},
  [9785] = {.lex_state = 43},
  [9786] = {.lex_state = 43},
  [9787] = {.lex_state = 43},
  [9788] = {.lex_state = 43},
  [9789] = {.lex_state = 43},
  [9790] = {.lex_state = 22},
  [9791] = {.lex_state = 22},
  [9792] = {.lex_state = 22},
  [9793] = {.lex_state = 22},
  [9794] = {.lex_state = 22},
  [9795] = {.lex_state = 22},
  [9796] = {.lex_state = 22},
  [9797] = {.lex_state = 22},
  [9798] = {.lex_state = 22},
  [9799] = {.lex_state = 22},
  [9800] = {.lex_state = 22},
  [9801] = {.lex_state = 22},
  [9802] = {.lex_state = 22},
  [9803] = {.lex_state = 22},
  [9804] = {.lex_state = 22},
  [9805] = {.lex_state = 371},
  [9806] = {.lex_state = 371},
  [9807] = {.lex_state = 43},
  [9808] = {.lex_state = 372},
  [9809] = {.lex_state = 371},
  [9810] = {.lex_state = 22},
  [9811] = {.lex_state = 22},
  [9812] = {.lex_state = 22},
  [9813] = {.lex_state = 22},
  [9814] = {.lex_state = 22},
  [9815] = {.lex_state = 22},
  [9816] = {.lex_state = 22},
  [9817] = {.lex_state = 22},
  [9818] = {.lex_state = 22},
  [9819] = {.lex_state = 22},
  [9820] = {.lex_state = 22},
  [9821] = {.lex_state = 22},
  [9822] = {.lex_state = 371},
  [9823] = {.lex_state = 371},
  [9824] = {.lex_state = 371},
  [9825] = {.lex_state = 371},
  [9826] = {.lex_state = 371},
  [9827] = {.lex_state = 371},
  [9828] = {.lex_state = 371},
  [9829] = {.lex_state = 371},
  [9830] = {.lex_state = 371},
  [9831] = {.lex_state = 371},
  [9832] = {.lex_state = 371},
  [9833] = {.lex_state = 371},
  [9834] = {.lex_state = 371},
  [9835] = {.lex_state = 371},
  [9836] = {.lex_state = 371},
  [9837] = {.lex_state = 22},
  [9838] = {.lex_state = 371},
  [9839] = {.lex_state = 371},
  [9840] = {.lex_state = 371},
  [9841] = {.lex_state = 43},
  [9842] = {.lex_state = 371},
  [9843] = {.lex_state = 22},
  [9844] = {.lex_state = 372},
  [9845] = {.lex_state = 22},
  [9846] = {.lex_state = 371},
  [9847] = {.lex_state = 371},
  [9848] = {.lex_state = 371},
  [9849] = {.lex_state = 22},
  [9850] = {.lex_state = 22},
  [9851] = {.lex_state = 372},
  [9852] = {.lex_state = 371},
  [9853] = {.lex_state = 371},
  [9854] = {.lex_state = 371},
  [9855] = {.lex_state = 371},
  [9856] = {.lex_state = 371},
  [9857] = {.lex_state = 371},
  [9858] = {.lex_state = 371},
  [9859] = {.lex_state = 371},
  [9860] = {.lex_state = 371},
  [9861] = {.lex_state = 371},
  [9862] = {.lex_state = 371},
  [9863] = {.lex_state = 371},
  [9864] = {.lex_state = 371},
  [9865] = {.lex_state = 371},
  [9866] = {.lex_state = 372},
  [9867] = {.lex_state = 371},
  [9868] = {.lex_state = 371},
  [9869] = {.lex_state = 43},
  [9870] = {.lex_state = 371},
  [9871] = {.lex_state = 371},
  [9872] = {.lex_state = 371},
  [9873] = {.lex_state = 371},
  [9874] = {.lex_state = 43},
  [9875] = {.lex_state = 371},
  [9876] = {.lex_state = 371},
  [9877] = {.lex_state = 371},
  [9878] = {.lex_state = 371},
  [9879] = {.lex_state = 43},
  [9880] = {.lex_state = 43},
  [9881] = {.lex_state = 43},
  [9882] = {.lex_state = 43},
  [9883] = {.lex_state = 22},
  [9884] = {.lex_state = 22},
  [9885] = {.lex_state = 22},
  [9886] = {.lex_state = 22},
  [9887] = {.lex_state = 22},
  [9888] = {.lex_state = 22},
  [9889] = {.lex_state = 22},
  [9890] = {.lex_state = 26},
  [9891] = {.lex_state = 371},
  [9892] = {.lex_state = 371},
  [9893] = {.lex_state = 22},
  [9894] = {.lex_state = 22},
  [9895] = {.lex_state = 371},
  [9896] = {.lex_state = 371},
  [9897] = {.lex_state = 43},
  [9898] = {.lex_state = 371},
  [9899] = {.lex_state = 371},
  [9900] = {.lex_state = 22},
  [9901] = {.lex_state = 371},
  [9902] = {.lex_state = 22},
  [9903] = {.lex_state = 371},
  [9904] = {.lex_state = 371},
  [9905] = {.lex_state = 371},
  [9906] = {.lex_state = 371},
  [9907] = {.lex_state = 371},
  [9908] = {.lex_state = 371},
  [9909] = {.lex_state = 371},
  [9910] = {.lex_state = 371},
  [9911] = {.lex_state = 371},
  [9912] = {.lex_state = 371},
  [9913] = {.lex_state = 371},
  [9914] = {.lex_state = 371},
  [9915] = {.lex_state = 371},
  [9916] = {.lex_state = 371},
  [9917] = {.lex_state = 371},
  [9918] = {.lex_state = 371},
  [9919] = {.lex_state = 371},
  [9920] = {.lex_state = 372},
  [9921] = {.lex_state = 371},
  [9922] = {.lex_state = 371},
  [9923] = {.lex_state = 22},
  [9924] = {.lex_state = 371},
  [9925] = {.lex_state = 371},
  [9926] = {.lex_state = 371},
  [9927] = {.lex_state = 371},
  [9928] = {.lex_state = 371},
  [9929] = {.lex_state = 22},
  [9930] = {.lex_state = 371},
  [9931] = {.lex_state = 371},
  [9932] = {.lex_state = 371},
  [9933] = {.lex_state = 371},
  [9934] = {.lex_state = 371},
  [9935] = {.lex_state = 371},
  [9936] = {.lex_state = 371},
  [9937] = {.lex_state = 371},
  [9938] = {.lex_state = 371},
  [9939] = {.lex_state = 371},
  [9940] = {.lex_state = 371},
  [9941] = {.lex_state = 371},
  [9942] = {.lex_state = 371},
  [9943] = {.lex_state = 371},
  [9944] = {.lex_state = 371},
  [9945] = {.lex_state = 41},
  [9946] = {.lex_state = 371},
  [9947] = {.lex_state = 371},
  [9948] = {.lex_state = 371},
  [9949] = {.lex_state = 22},
  [9950] = {.lex_state = 371},
  [9951] = {.lex_state = 371},
  [9952] = {.lex_state = 22},
  [9953] = {.lex_state = 371},
  [9954] = {.lex_state = 371},
  [9955] = {.lex_state = 371},
  [9956] = {.lex_state = 371},
  [9957] = {.lex_state = 22},
  [9958] = {.lex_state = 371},
  [9959] = {.lex_state = 371},
  [9960] = {.lex_state = 371},
  [9961] = {.lex_state = 371},
  [9962] = {.lex_state = 22},
  [9963] = {.lex_state = 371},
  [9964] = {.lex_state = 371},
  [9965] = {.lex_state = 371},
  [9966] = {.lex_state = 371},
  [9967] = {.lex_state = 371},
  [9968] = {.lex_state = 371},
  [9969] = {.lex_state = 371},
  [9970] = {.lex_state = 371},
  [9971] = {.lex_state = 371},
  [9972] = {.lex_state = 371},
  [9973] = {.lex_state = 371},
  [9974] = {.lex_state = 371},
  [9975] = {.lex_state = 43},
  [9976] = {.lex_state = 371},
  [9977] = {.lex_state = 371},
  [9978] = {.lex_state = 371},
  [9979] = {.lex_state = 371},
  [9980] = {.lex_state = 43},
  [9981] = {.lex_state = 371},
  [9982] = {.lex_state = 43},
  [9983] = {.lex_state = 22},
  [9984] = {.lex_state = 22},
  [9985] = {.lex_state = 371},
  [9986] = {.lex_state = 43},
  [9987] = {.lex_state = 371},
  [9988] = {.lex_state = 43},
  [9989] = {.lex_state = 43},
  [9990] = {.lex_state = 43},
  [9991] = {.lex_state = 43},
  [9992] = {.lex_state = 43},
  [9993] = {.lex_state = 43},
  [9994] = {.lex_state = 43},
  [9995] = {.lex_state = 371},
  [9996] = {.lex_state = 372},
  [9997] = {.lex_state = 43},
  [9998] = {.lex_state = 22},
  [9999] = {.lex_state = 43},
  [10000] = {.lex_state = 371},
  [10001] = {.lex_state = 371},
  [10002] = {.lex_state = 371},
  [10003] = {.lex_state = 371},
  [10004] = {.lex_state = 371},
  [10005] = {.lex_state = 371},
  [10006] = {.lex_state = 22},
  [10007] = {.lex_state = 371},
  [10008] = {.lex_state = 371},
  [10009] = {.lex_state = 371},
  [10010] = {.lex_state = 371},
  [10011] = {.lex_state = 371},
  [10012] = {.lex_state = 371},
  [10013] = {.lex_state = 43},
  [10014] = {.lex_state = 43},
  [10015] = {.lex_state = 371},
  [10016] = {.lex_state = 371},
  [10017] = {.lex_state = 43},
  [10018] = {.lex_state = 371},
  [10019] = {.lex_state = 371},
  [10020] = {.lex_state = 43},
  [10021] = {.lex_state = 371},
  [10022] = {.lex_state = 371},
  [10023] = {.lex_state = 371},
  [10024] = {.lex_state = 371},
  [10025] = {.lex_state = 371},
  [10026] = {.lex_state = 371},
  [10027] = {.lex_state = 43},
  [10028] = {.lex_state = 371},
  [10029] = {.lex_state = 43},
  [10030] = {.lex_state = 371},
  [10031] = {.lex_state = 371},
  [10032] = {.lex_state = 371},
  [10033] = {.lex_state = 43},
  [10034] = {.lex_state = 43},
  [10035] = {.lex_state = 43},
  [10036] = {.lex_state = 43},
  [10037] = {.lex_state = 43},
  [10038] = {.lex_state = 43},
  [10039] = {.lex_state = 43},
  [10040] = {.lex_state = 43},
  [10041] = {.lex_state = 371},
  [10042] = {.lex_state = 371},
  [10043] = {.lex_state = 371},
  [10044] = {.lex_state = 371},
  [10045] = {.lex_state = 371},
  [10046] = {.lex_state = 371},
  [10047] = {.lex_state = 371},
  [10048] = {.lex_state = 371},
  [10049] = {.lex_state = 371},
  [10050] = {.lex_state = 371},
  [10051] = {.lex_state = 371},
  [10052] = {.lex_state = 371},
  [10053] = {.lex_state = 371},
  [10054] = {.lex_state = 371},
  [10055] = {.lex_state = 371},
  [10056] = {.lex_state = 371},
  [10057] = {.lex_state = 43},
  [10058] = {.lex_state = 371},
  [10059] = {.lex_state = 43},
  [10060] = {.lex_state = 371},
  [10061] = {.lex_state = 371},
  [10062] = {.lex_state = 371},
  [10063] = {.lex_state = 371},
  [10064] = {.lex_state = 371},
  [10065] = {.lex_state = 371},
  [10066] = {.lex_state = 371},
  [10067] = {.lex_state = 371},
  [10068] = {.lex_state = 371},
  [10069] = {.lex_state = 43},
  [10070] = {.lex_state = 43},
  [10071] = {.lex_state = 371},
  [10072] = {.lex_state = 43},
  [10073] = {.lex_state = 43},
  [10074] = {.lex_state = 43},
  [10075] = {.lex_state = 371},
  [10076] = {.lex_state = 43},
  [10077] = {.lex_state = 371},
  [10078] = {.lex_state = 371},
  [10079] = {.lex_state = 371},
  [10080] = {.lex_state = 371},
  [10081] = {.lex_state = 371},
  [10082] = {.lex_state = 371},
  [10083] = {.lex_state = 371},
  [10084] = {.lex_state = 371},
  [10085] = {.lex_state = 371},
  [10086] = {.lex_state = 371},
  [10087] = {.lex_state = 43},
  [10088] = {.lex_state = 371},
  [10089] = {.lex_state = 371},
  [10090] = {.lex_state = 371},
  [10091] = {.lex_state = 371},
  [10092] = {.lex_state = 371},
  [10093] = {.lex_state = 371},
  [10094] = {.lex_state = 371},
  [10095] = {.lex_state = 371},
  [10096] = {.lex_state = 371},
  [10097] = {.lex_state = 371},
  [10098] = {.lex_state = 371},
  [10099] = {.lex_state = 371},
  [10100] = {.lex_state = 43},
  [10101] = {.lex_state = 371},
  [10102] = {.lex_state = 371},
  [10103] = {.lex_state = 371},
  [10104] = {.lex_state = 371},
  [10105] = {.lex_state = 371},
  [10106] = {.lex_state = 371},
  [10107] = {.lex_state = 371},
  [10108] = {.lex_state = 371},
  [10109] = {.lex_state = 43},
  [10110] = {.lex_state = 43},
  [10111] = {.lex_state = 43},
  [10112] = {.lex_state = 43},
  [10113] = {.lex_state = 43},
  [10114] = {.lex_state = 43},
  [10115] = {.lex_state = 43},
  [10116] = {.lex_state = 371},
  [10117] = {.lex_state = 43},
  [10118] = {.lex_state = 371},
  [10119] = {.lex_state = 371},
  [10120] = {.lex_state = 371},
  [10121] = {.lex_state = 371},
  [10122] = {.lex_state = 43},
  [10123] = {.lex_state = 43},
  [10124] = {.lex_state = 371},
  [10125] = {.lex_state = 371},
  [10126] = {.lex_state = 371},
  [10127] = {.lex_state = 371},
  [10128] = {.lex_state = 371},
  [10129] = {.lex_state = 43},
  [10130] = {.lex_state = 371},
  [10131] = {.lex_state = 43},
  [10132] = {.lex_state = 371},
  [10133] = {.lex_state = 43},
  [10134] = {.lex_state = 371},
  [10135] = {.lex_state = 372},
  [10136] = {.lex_state = 43},
  [10137] = {.lex_state = 371},
  [10138] = {.lex_state = 371},
  [10139] = {.lex_state = 43},
  [10140] = {.lex_state = 371},
  [10141] = {.lex_state = 371},
  [10142] = {.lex_state = 371},
  [10143] = {.lex_state = 371},
  [10144] = {.lex_state = 371},
  [10145] = {.lex_state = 371},
  [10146] = {.lex_state = 371},
  [10147] = {.lex_state = 371},
  [10148] = {.lex_state = 43},
  [10149] = {.lex_state = 43},
  [10150] = {.lex_state = 43},
  [10151] = {.lex_state = 371},
  [10152] = {.lex_state = 43},
  [10153] = {.lex_state = 43},
  [10154] = {.lex_state = 43},
  [10155] = {.lex_state = 43},
  [10156] = {.lex_state = 43},
  [10157] = {.lex_state = 43},
  [10158] = {.lex_state = 43},
  [10159] = {.lex_state = 371},
  [10160] = {.lex_state = 371},
  [10161] = {.lex_state = 371},
  [10162] = {.lex_state = 371},
  [10163] = {.lex_state = 371},
  [10164] = {.lex_state = 371},
  [10165] = {.lex_state = 371},
  [10166] = {.lex_state = 371},
  [10167] = {.lex_state = 43},
  [10168] = {.lex_state = 43},
  [10169] = {.lex_state = 43},
  [10170] = {.lex_state = 43},
  [10171] = {.lex_state = 43},
  [10172] = {.lex_state = 43},
  [10173] = {.lex_state = 43},
  [10174] = {.lex_state = 371},
  [10175] = {.lex_state = 371},
  [10176] = {.lex_state = 371},
  [10177] = {.lex_state = 371},
  [10178] = {.lex_state = 371},
  [10179] = {.lex_state = 371},
  [10180] = {.lex_state = 371},
  [10181] = {.lex_state = 371},
  [10182] = {.lex_state = 43},
  [10183] = {.lex_state = 43},
  [10184] = {.lex_state = 43},
  [10185] = {.lex_state = 371},
  [10186] = {.lex_state = 371},
  [10187] = {.lex_state = 371},
  [10188] = {.lex_state = 371},
  [10189] = {.lex_state = 371},
  [10190] = {.lex_state = 371},
  [10191] = {.lex_state = 371},
  [10192] = {.lex_state = 43},
  [10193] = {.lex_state = 371},
  [10194] = {.lex_state = 43},
  [10195] = {.lex_state = 43},
  [10196] = {.lex_state = 371},
  [10197] = {.lex_state = 371},
  [10198] = {.lex_state = 371},
  [10199] = {.lex_state = 43},
  [10200] = {.lex_state = 43},
  [10201] = {.lex_state = 43},
  [10202] = {.lex_state = 43},
  [10203] = {.lex_state = 43},
  [10204] = {.lex_state = 43},
  [10205] = {.lex_state = 43},
  [10206] = {.lex_state = 43},
  [10207] = {.lex_state = 43},
  [10208] = {.lex_state = 43},
  [10209] = {.lex_state = 43},
  [10210] = {.lex_state = 43},
  [10211] = {.lex_state = 43},
  [10212] = {.lex_state = 43},
  [10213] = {.lex_state = 371},
  [10214] = {.lex_state = 43},
  [10215] = {.lex_state = 371},
  [10216] = {.lex_state = 371},
  [10217] = {.lex_state = 43},
  [10218] = {.lex_state = 43},
  [10219] = {.lex_state = 371},
  [10220] = {.lex_state = 43},
  [10221] = {.lex_state = 43},
  [10222] = {.lex_state = 43},
  [10223] = {.lex_state = 43},
  [10224] = {.lex_state = 43},
  [10225] = {.lex_state = 43},
  [10226] = {.lex_state = 371},
  [10227] = {.lex_state = 371},
  [10228] = {.lex_state = 43},
  [10229] = {.lex_state = 43},
  [10230] = {.lex_state = 43},
  [10231] = {.lex_state = 371},
  [10232] = {.lex_state = 43},
  [10233] = {.lex_state = 43},
  [10234] = {.lex_state = 371},
  [10235] = {.lex_state = 43},
  [10236] = {.lex_state = 43},
  [10237] = {.lex_state = 43},
  [10238] = {.lex_state = 43},
  [10239] = {.lex_state = 43},
  [10240] = {.lex_state = 371},
  [10241] = {.lex_state = 43},
  [10242] = {.lex_state = 43},
  [10243] = {.lex_state = 43},
  [10244] = {.lex_state = 43},
  [10245] = {.lex_state = 371},
  [10246] = {.lex_state = 43},
  [10247] = {.lex_state = 43},
  [10248] = {.lex_state = 43},
  [10249] = {.lex_state = 43},
  [10250] = {.lex_state = 43},
  [10251] = {.lex_state = 43},
  [10252] = {.lex_state = 43},
  [10253] = {.lex_state = 371},
  [10254] = {.lex_state = 371},
  [10255] = {.lex_state = 43},
  [10256] = {.lex_state = 43},
  [10257] = {.lex_state = 43},
  [10258] = {.lex_state = 43},
  [10259] = {.lex_state = 371},
  [10260] = {.lex_state = 43},
  [10261] = {.lex_state = 43},
  [10262] = {.lex_state = 43},
  [10263] = {.lex_state = 43},
  [10264] = {.lex_state = 371},
  [10265] = {.lex_state = 43},
  [10266] = {.lex_state = 43},
  [10267] = {.lex_state = 43},
  [10268] = {.lex_state = 43},
  [10269] = {.lex_state = 43},
  [10270] = {.lex_state = 43},
  [10271] = {.lex_state = 43},
  [10272] = {.lex_state = 43},
  [10273] = {.lex_state = 371},
  [10274] = {.lex_state = 371},
  [10275] = {.lex_state = 43},
  [10276] = {.lex_state = 43},
  [10277] = {.lex_state = 371},
  [10278] = {.lex_state = 43},
  [10279] = {.lex_state = 43},
  [10280] = {.lex_state = 43},
  [10281] = {.lex_state = 371},
  [10282] = {.lex_state = 43},
  [10283] = {.lex_state = 43},
  [10284] = {.lex_state = 371},
  [10285] = {.lex_state = 43},
  [10286] = {.lex_state = 43},
  [10287] = {.lex_state = 43},
  [10288] = {.lex_state = 43},
  [10289] = {.lex_state = 43},
  [10290] = {.lex_state = 43},
  [10291] = {.lex_state = 43},
  [10292] = {.lex_state = 43},
  [10293] = {.lex_state = 43},
  [10294] = {.lex_state = 371},
  [10295] = {.lex_state = 371},
  [10296] = {.lex_state = 371},
  [10297] = {.lex_state = 43},
  [10298] = {.lex_state = 43},
  [10299] = {.lex_state = 371},
  [10300] = {.lex_state = 371},
  [10301] = {.lex_state = 371},
  [10302] = {.lex_state = 371},
  [10303] = {.lex_state = 371},
  [10304] = {.lex_state = 371},
  [10305] = {.lex_state = 371},
  [10306] = {.lex_state = 371},
  [10307] = {.lex_state = 371},
  [10308] = {.lex_state = 43},
  [10309] = {.lex_state = 371},
  [10310] = {.lex_state = 371},
  [10311] = {.lex_state = 371},
  [10312] = {.lex_state = 371},
  [10313] = {.lex_state = 43},
  [10314] = {.lex_state = 43},
  [10315] = {.lex_state = 371},
  [10316] = {.lex_state = 371},
  [10317] = {.lex_state = 371},
  [10318] = {.lex_state = 371},
  [10319] = {.lex_state = 371},
  [10320] = {.lex_state = 371},
  [10321] = {.lex_state = 371},
  [10322] = {.lex_state = 371},
  [10323] = {.lex_state = 371},
  [10324] = {.lex_state = 371},
  [10325] = {.lex_state = 371},
  [10326] = {.lex_state = 371},
  [10327] = {.lex_state = 371},
  [10328] = {.lex_state = 371},
  [10329] = {.lex_state = 371},
  [10330] = {.lex_state = 371},
  [10331] = {.lex_state = 371},
  [10332] = {.lex_state = 371},
  [10333] = {.lex_state = 43},
  [10334] = {.lex_state = 371},
  [10335] = {.lex_state = 371},
  [10336] = {.lex_state = 371},
  [10337] = {.lex_state = 371},
  [10338] = {.lex_state = 43},
  [10339] = {.lex_state = 371},
  [10340] = {.lex_state = 371},
  [10341] = {.lex_state = 371},
  [10342] = {.lex_state = 371},
  [10343] = {.lex_state = 371},
  [10344] = {.lex_state = 371},
  [10345] = {.lex_state = 371},
  [10346] = {.lex_state = 371},
  [10347] = {.lex_state = 371},
  [10348] = {.lex_state = 371},
  [10349] = {.lex_state = 371},
  [10350] = {.lex_state = 371},
  [10351] = {.lex_state = 43},
  [10352] = {.lex_state = 371},
  [10353] = {.lex_state = 371},
  [10354] = {.lex_state = 22},
  [10355] = {.lex_state = 43},
  [10356] = {.lex_state = 43},
  [10357] = {.lex_state = 371},
  [10358] = {.lex_state = 371},
  [10359] = {.lex_state = 371},
  [10360] = {.lex_state = 371},
  [10361] = {.lex_state = 43},
  [10362] = {.lex_state = 43},
  [10363] = {.lex_state = 43},
  [10364] = {.lex_state = 43},
  [10365] = {.lex_state = 43},
  [10366] = {.lex_state = 43},
  [10367] = {.lex_state = 43},
  [10368] = {.lex_state = 43},
  [10369] = {.lex_state = 43},
  [10370] = {.lex_state = 371},
  [10371] = {.lex_state = 371},
  [10372] = {.lex_state = 371},
  [10373] = {.lex_state = 371},
  [10374] = {.lex_state = 371},
  [10375] = {.lex_state = 371},
  [10376] = {.lex_state = 43},
  [10377] = {.lex_state = 43},
  [10378] = {.lex_state = 43},
  [10379] = {.lex_state = 43},
  [10380] = {.lex_state = 43},
  [10381] = {.lex_state = 43},
  [10382] = {.lex_state = 43},
  [10383] = {.lex_state = 371},
  [10384] = {.lex_state = 371},
  [10385] = {.lex_state = 371},
  [10386] = {.lex_state = 371},
  [10387] = {.lex_state = 371},
  [10388] = {.lex_state = 43},
  [10389] = {.lex_state = 371},
  [10390] = {.lex_state = 43},
  [10391] = {.lex_state = 371},
  [10392] = {.lex_state = 43},
  [10393] = {.lex_state = 371},
  [10394] = {.lex_state = 371},
  [10395] = {.lex_state = 43},
  [10396] = {.lex_state = 372},
  [10397] = {.lex_state = 371},
  [10398] = {.lex_state = 371},
  [10399] = {.lex_state = 371},
  [10400] = {.lex_state = 371},
  [10401] = {.lex_state = 43},
  [10402] = {.lex_state = 371},
  [10403] = {.lex_state = 43},
  [10404] = {.lex_state = 371},
  [10405] = {.lex_state = 26},
  [10406] = {.lex_state = 26},
  [10407] = {.lex_state = 371},
  [10408] = {.lex_state = 26},
  [10409] = {.lex_state = 26},
  [10410] = {.lex_state = 26},
  [10411] = {.lex_state = 43},
  [10412] = {.lex_state = 371},
  [10413] = {.lex_state = 26},
  [10414] = {.lex_state = 371},
  [10415] = {.lex_state = 372},
  [10416] = {.lex_state = 371},
  [10417] = {.lex_state = 372},
  [10418] = {.lex_state = 371},
  [10419] = {.lex_state = 371},
  [10420] = {.lex_state = 371},
  [10421] = {.lex_state = 43},
  [10422] = {.lex_state = 372},
  [10423] = {.lex_state = 371},
  [10424] = {.lex_state = 372},
  [10425] = {.lex_state = 371},
  [10426] = {.lex_state = 371},
  [10427] = {.lex_state = 371},
  [10428] = {.lex_state = 371},
  [10429] = {.lex_state = 371},
  [10430] = {.lex_state = 371},
  [10431] = {.lex_state = 371},
  [10432] = {.lex_state = 371},
  [10433] = {.lex_state = 371},
  [10434] = {.lex_state = 371},
  [10435] = {.lex_state = 371},
  [10436] = {.lex_state = 371},
  [10437] = {.lex_state = 371},
  [10438] = {.lex_state = 371},
  [10439] = {.lex_state = 371},
  [10440] = {.lex_state = 371},
  [10441] = {.lex_state = 371},
  [10442] = {.lex_state = 371},
  [10443] = {.lex_state = 371},
  [10444] = {.lex_state = 371},
  [10445] = {.lex_state = 371},
  [10446] = {.lex_state = 371},
  [10447] = {.lex_state = 371},
  [10448] = {.lex_state = 371},
  [10449] = {.lex_state = 371},
  [10450] = {.lex_state = 372},
  [10451] = {.lex_state = 26},
  [10452] = {.lex_state = 371},
  [10453] = {.lex_state = 26},
  [10454] = {.lex_state = 26},
  [10455] = {.lex_state = 26},
  [10456] = {.lex_state = 26},
  [10457] = {.lex_state = 26},
  [10458] = {.lex_state = 371},
  [10459] = {.lex_state = 26},
  [10460] = {.lex_state = 26},
  [10461] = {.lex_state = 26},
  [10462] = {.lex_state = 26},
  [10463] = {.lex_state = 26},
  [10464] = {.lex_state = 372},
  [10465] = {.lex_state = 372},
  [10466] = {.lex_state = 371},
  [10467] = {.lex_state = 371},
  [10468] = {.lex_state = 371},
  [10469] = {.lex_state = 371},
  [10470] = {.lex_state = 372},
  [10471] = {.lex_state = 371},
  [10472] = {.lex_state = 371},
  [10473] = {.lex_state = 26},
  [10474] = {.lex_state = 26},
  [10475] = {.lex_state = 26},
  [10476] = {.lex_state = 26},
  [10477] = {.lex_state = 26},
  [10478] = {.lex_state = 371},
  [10479] = {.lex_state = 26},
  [10480] = {.lex_state = 26},
  [10481] = {.lex_state = 371},
  [10482] = {.lex_state = 26},
  [10483] = {.lex_state = 372},
  [10484] = {.lex_state = 26},
  [10485] = {.lex_state = 26},
  [10486] = {.lex_state = 26},
  [10487] = {.lex_state = 371},
  [10488] = {.lex_state = 26},
  [10489] = {.lex_state = 371},
  [10490] = {.lex_state = 26},
  [10491] = {.lex_state = 26},
  [10492] = {.lex_state = 26},
  [10493] = {.lex_state = 26},
  [10494] = {.lex_state = 371},
  [10495] = {.lex_state = 26},
  [10496] = {.lex_state = 26},
  [10497] = {.lex_state = 26},
  [10498] = {.lex_state = 26},
  [10499] = {.lex_state = 26},
  [10500] = {.lex_state = 371},
  [10501] = {.lex_state = 372},
  [10502] = {.lex_state = 26},
  [10503] = {.lex_state = 372},
  [10504] = {.lex_state = 371},
  [10505] = {.lex_state = 26},
  [10506] = {.lex_state = 26},
  [10507] = {.lex_state = 371},
  [10508] = {.lex_state = 371},
  [10509] = {.lex_state = 372},
  [10510] = {.lex_state = 372},
  [10511] = {.lex_state = 371},
  [10512] = {.lex_state = 371},
  [10513] = {.lex_state = 371},
  [10514] = {.lex_state = 371},
  [10515] = {.lex_state = 371},
  [10516] = {.lex_state = 26},
  [10517] = {.lex_state = 372},
  [10518] = {.lex_state = 372},
  [10519] = {.lex_state = 371},
  [10520] = {.lex_state = 372},
  [10521] = {.lex_state = 371},
  [10522] = {.lex_state = 371},
  [10523] = {.lex_state = 372},
  [10524] = {.lex_state = 371},
  [10525] = {.lex_state = 372},
  [10526] = {.lex_state = 371},
  [10527] = {.lex_state = 373},
  [10528] = {.lex_state = 371},
  [10529] = {.lex_state = 26},
  [10530] = {.lex_state = 26},
  [10531] = {.lex_state = 26},
  [10532] = {.lex_state = 372},
  [10533] = {.lex_state = 371},
  [10534] = {.lex_state = 372},
  [10535] = {.lex_state = 371},
  [10536] = {.lex_state = 371},
  [10537] = {.lex_state = 372},
  [10538] = {.lex_state = 41},
  [10539] = {.lex_state = 371},
  [10540] = {.lex_state = 372},
  [10541] = {.lex_state = 371},
  [10542] = {.lex_state = 26},
  [10543] = {.lex_state = 371},
  [10544] = {.lex_state = 371},
  [10545] = {.lex_state = 371},
  [10546] = {.lex_state = 371},
  [10547] = {.lex_state = 371},
  [10548] = {.lex_state = 26},
  [10549] = {.lex_state = 372},
  [10550] = {.lex_state = 26},
  [10551] = {.lex_state = 371},
  [10552] = {.lex_state = 371},
  [10553] = {.lex_state = 371},
  [10554] = {.lex_state = 371},
  [10555] = {.lex_state = 371},
  [10556] = {.lex_state = 371},
  [10557] = {.lex_state = 26},
  [10558] = {.lex_state = 371},
  [10559] = {.lex_state = 372},
  [10560] = {.lex_state = 26},
  [10561] = {.lex_state = 26},
  [10562] = {.lex_state = 372},
  [10563] = {.lex_state = 371},
  [10564] = {.lex_state = 372},
  [10565] = {.lex_state = 371},
  [10566] = {.lex_state = 372},
  [10567] = {.lex_state = 372},
  [10568] = {.lex_state = 372},
  [10569] = {.lex_state = 372},
  [10570] = {.lex_state = 26},
  [10571] = {.lex_state = 26},
  [10572] = {.lex_state = 371},
  [10573] = {.lex_state = 26},
  [10574] = {.lex_state = 26},
  [10575] = {.lex_state = 372},
  [10576] = {.lex_state = 372},
  [10577] = {.lex_state = 43},
  [10578] = {.lex_state = 372},
  [10579] = {.lex_state = 372},
  [10580] = {.lex_state = 372},
  [10581] = {.lex_state = 372},
  [10582] = {.lex_state = 372},
  [10583] = {.lex_state = 371},
  [10584] = {.lex_state = 372},
  [10585] = {.lex_state = 372},
  [10586] = {.lex_state = 372},
  [10587] = {.lex_state = 372},
  [10588] = {.lex_state = 372},
  [10589] = {.lex_state = 372},
  [10590] = {.lex_state = 372},
  [10591] = {.lex_state = 372},
  [10592] = {.lex_state = 372},
  [10593] = {.lex_state = 372},
  [10594] = {.lex_state = 371},
  [10595] = {.lex_state = 372},
  [10596] = {.lex_state = 372},
  [10597] = {.lex_state = 372},
  [10598] = {.lex_state = 372},
  [10599] = {.lex_state = 372},
  [10600] = {.lex_state = 372},
  [10601] = {.lex_state = 372},
  [10602] = {.lex_state = 372},
  [10603] = {.lex_state = 371},
  [10604] = {.lex_state = 43},
  [10605] = {.lex_state = 372},
  [10606] = {.lex_state = 372},
  [10607] = {.lex_state = 372},
  [10608] = {.lex_state = 372},
  [10609] = {.lex_state = 372},
  [10610] = {.lex_state = 372},
  [10611] = {.lex_state = 371},
  [10612] = {.lex_state = 372},
  [10613] = {.lex_state = 372},
  [10614] = {.lex_state = 371},
  [10615] = {.lex_state = 372},
  [10616] = {.lex_state = 54},
  [10617] = {.lex_state = 54},
  [10618] = {.lex_state = 372},
  [10619] = {.lex_state = 372},
  [10620] = {.lex_state = 372},
  [10621] = {.lex_state = 7},
  [10622] = {.lex_state = 372},
  [10623] = {.lex_state = 372},
  [10624] = {.lex_state = 372},
  [10625] = {.lex_state = 372},
  [10626] = {.lex_state = 372},
  [10627] = {.lex_state = 371},
  [10628] = {.lex_state = 372},
  [10629] = {.lex_state = 372},
  [10630] = {.lex_state = 372},
  [10631] = {.lex_state = 371},
  [10632] = {.lex_state = 41},
  [10633] = {.lex_state = 41},
  [10634] = {.lex_state = 41},
  [10635] = {.lex_state = 7},
  [10636] = {.lex_state = 371},
  [10637] = {.lex_state = 373},
  [10638] = {.lex_state = 41},
  [10639] = {.lex_state = 373},
  [10640] = {.lex_state = 373},
  [10641] = {.lex_state = 371},
  [10642] = {.lex_state = 41},
  [10643] = {.lex_state = 7},
  [10644] = {.lex_state = 41},
  [10645] = {.lex_state = 41},
  [10646] = {.lex_state = 41},
  [10647] = {.lex_state = 41},
  [10648] = {.lex_state = 41},
  [10649] = {.lex_state = 41},
  [10650] = {.lex_state = 41},
  [10651] = {.lex_state = 41},
  [10652] = {.lex_state = 41},
  [10653] = {.lex_state = 41},
  [10654] = {.lex_state = 41},
  [10655] = {.lex_state = 41},
  [10656] = {.lex_state = 41},
  [10657] = {.lex_state = 41},
  [10658] = {.lex_state = 41},
  [10659] = {.lex_state = 41},
  [10660] = {.lex_state = 371},
  [10661] = {.lex_state = 371},
  [10662] = {.lex_state = 371},
  [10663] = {.lex_state = 371},
  [10664] = {.lex_state = 371},
  [10665] = {.lex_state = 371},
  [10666] = {.lex_state = 371},
  [10667] = {.lex_state = 371},
  [10668] = {.lex_state = 371},
  [10669] = {.lex_state = 371},
  [10670] = {.lex_state = 371},
  [10671] = {.lex_state = 371},
  [10672] = {.lex_state = 371},
  [10673] = {.lex_state = 371},
  [10674] = {.lex_state = 373},
  [10675] = {.lex_state = 371},
  [10676] = {.lex_state = 371},
  [10677] = {.lex_state = 371},
  [10678] = {.lex_state = 371},
  [10679] = {.lex_state = 371},
  [10680] = {.lex_state = 371},
  [10681] = {.lex_state = 7},
  [10682] = {.lex_state = 7},
  [10683] = {.lex_state = 7},
  [10684] = {.lex_state = 371},
  [10685] = {.lex_state = 373},
  [10686] = {.lex_state = 373},
  [10687] = {.lex_state = 371},
  [10688] = {.lex_state = 371},
  [10689] = {.lex_state = 7},
  [10690] = {.lex_state = 7},
  [10691] = {.lex_state = 371},
  [10692] = {.lex_state = 371},
  [10693] = {.lex_state = 371},
  [10694] = {.lex_state = 371},
  [10695] = {.lex_state = 371},
  [10696] = {.lex_state = 371},
  [10697] = {.lex_state = 373},
  [10698] = {.lex_state = 371},
  [10699] = {.lex_state = 7},
  [10700] = {.lex_state = 371},
  [10701] = {.lex_state = 7},
  [10702] = {.lex_state = 371},
  [10703] = {.lex_state = 371},
  [10704] = {.lex_state = 371},
  [10705] = {.lex_state = 371},
  [10706] = {.lex_state = 7},
  [10707] = {.lex_state = 371},
  [10708] = {.lex_state = 371},
  [10709] = {.lex_state = 371},
  [10710] = {.lex_state = 7},
  [10711] = {.lex_state = 7},
  [10712] = {.lex_state = 371},
  [10713] = {.lex_state = 371},
  [10714] = {.lex_state = 371},
  [10715] = {.lex_state = 371},
  [10716] = {.lex_state = 371},
  [10717] = {.lex_state = 371},
  [10718] = {.lex_state = 373},
  [10719] = {.lex_state = 371},
  [10720] = {.lex_state = 373},
  [10721] = {.lex_state = 371},
  [10722] = {.lex_state = 371},
  [10723] = {.lex_state = 371},
  [10724] = {.lex_state = 371},
  [10725] = {.lex_state = 371},
  [10726] = {.lex_state = 371},
  [10727] = {.lex_state = 371},
  [10728] = {.lex_state = 371},
  [10729] = {.lex_state = 373},
  [10730] = {.lex_state = 371},
  [10731] = {.lex_state = 371},
  [10732] = {.lex_state = 373},
  [10733] = {.lex_state = 371},
  [10734] = {.lex_state = 373},
  [10735] = {.lex_state = 371},
  [10736] = {.lex_state = 371},
  [10737] = {.lex_state = 371},
  [10738] = {.lex_state = 373},
  [10739] = {.lex_state = 371},
  [10740] = {.lex_state = 371},
  [10741] = {.lex_state = 373},
  [10742] = {.lex_state = 371},
  [10743] = {.lex_state = 371},
  [10744] = {.lex_state = 373},
  [10745] = {.lex_state = 371},
  [10746] = {.lex_state = 371},
  [10747] = {.lex_state = 371},
  [10748] = {.lex_state = 371},
  [10749] = {.lex_state = 371},
  [10750] = {.lex_state = 371},
  [10751] = {.lex_state = 371},
  [10752] = {.lex_state = 371},
  [10753] = {.lex_state = 371},
  [10754] = {.lex_state = 371},
  [10755] = {.lex_state = 373},
  [10756] = {.lex_state = 371},
  [10757] = {.lex_state = 371},
  [10758] = {.lex_state = 371},
  [10759] = {.lex_state = 373},
  [10760] = {.lex_state = 371},
  [10761] = {.lex_state = 371},
  [10762] = {.lex_state = 371},
  [10763] = {.lex_state = 371},
  [10764] = {.lex_state = 371},
  [10765] = {.lex_state = 50},
  [10766] = {.lex_state = 50},
  [10767] = {.lex_state = 50},
  [10768] = {.lex_state = 371},
  [10769] = {.lex_state = 373},
  [10770] = {.lex_state = 373},
  [10771] = {.lex_state = 373},
  [10772] = {.lex_state = 373},
  [10773] = {.lex_state = 373},
  [10774] = {.lex_state = 50},
  [10775] = {.lex_state = 373},
  [10776] = {.lex_state = 373},
  [10777] = {.lex_state = 373},
  [10778] = {.lex_state = 373},
  [10779] = {.lex_state = 373},
  [10780] = {.lex_state = 50},
  [10781] = {.lex_state = 373},
  [10782] = {.lex_state = 373},
  [10783] = {.lex_state = 373},
  [10784] = {.lex_state = 373},
  [10785] = {.lex_state = 371},
  [10786] = {.lex_state = 373},
  [10787] = {.lex_state = 373},
  [10788] = {.lex_state = 373},
  [10789] = {.lex_state = 373},
  [10790] = {.lex_state = 373},
  [10791] = {.lex_state = 373},
  [10792] = {.lex_state = 373},
  [10793] = {.lex_state = 373},
  [10794] = {.lex_state = 373},
  [10795] = {.lex_state = 373},
  [10796] = {.lex_state = 373},
  [10797] = {.lex_state = 373},
  [10798] = {.lex_state = 373},
  [10799] = {.lex_state = 373},
  [10800] = {.lex_state = 373},
  [10801] = {.lex_state = 373},
  [10802] = {.lex_state = 373},
  [10803] = {.lex_state = 373},
  [10804] = {.lex_state = 373},
  [10805] = {.lex_state = 373},
  [10806] = {.lex_state = 373},
  [10807] = {.lex_state = 373},
  [10808] = {.lex_state = 373},
  [10809] = {.lex_state = 373},
  [10810] = {.lex_state = 373},
  [10811] = {.lex_state = 373},
  [10812] = {.lex_state = 373},
  [10813] = {.lex_state = 373},
  [10814] = {.lex_state = 373},
  [10815] = {.lex_state = 373},
  [10816] = {.lex_state = 373},
  [10817] = {.lex_state = 371},
  [10818] = {.lex_state = 373},
  [10819] = {.lex_state = 373},
  [10820] = {.lex_state = 373},
  [10821] = {.lex_state = 373},
  [10822] = {.lex_state = 373},
  [10823] = {.lex_state = 373},
  [10824] = {.lex_state = 373},
  [10825] = {.lex_state = 373},
  [10826] = {.lex_state = 373},
  [10827] = {.lex_state = 373},
  [10828] = {.lex_state = 373},
  [10829] = {.lex_state = 371},
  [10830] = {.lex_state = 373},
  [10831] = {.lex_state = 373},
  [10832] = {.lex_state = 373},
  [10833] = {.lex_state = 373},
  [10834] = {.lex_state = 373},
  [10835] = {.lex_state = 373},
  [10836] = {.lex_state = 373},
  [10837] = {.lex_state = 373},
  [10838] = {.lex_state = 373},
  [10839] = {.lex_state = 373},
  [10840] = {.lex_state = 373},
  [10841] = {.lex_state = 14},
  [10842] = {.lex_state = 373},
  [10843] = {.lex_state = 14},
  [10844] = {.lex_state = 14},
  [10845] = {.lex_state = 14},
  [10846] = {.lex_state = 14},
  [10847] = {.lex_state = 371},
  [10848] = {.lex_state = 14},
  [10849] = {.lex_state = 14},
  [10850] = {.lex_state = 14},
  [10851] = {.lex_state = 14},
  [10852] = {.lex_state = 373},
  [10853] = {.lex_state = 14},
  [10854] = {.lex_state = 14},
  [10855] = {.lex_state = 373},
  [10856] = {.lex_state = 373},
  [10857] = {.lex_state = 373},
  [10858] = {.lex_state = 14},
  [10859] = {.lex_state = 373},
  [10860] = {.lex_state = 373},
  [10861] = {.lex_state = 373},
  [10862] = {.lex_state = 373},
  [10863] = {.lex_state = 14},
  [10864] = {.lex_state = 14},
  [10865] = {.lex_state = 373},
  [10866] = {.lex_state = 14},
  [10867] = {.lex_state = 14},
  [10868] = {.lex_state = 373},
  [10869] = {.lex_state = 373},
  [10870] = {.lex_state = 14},
  [10871] = {.lex_state = 371},
  [10872] = {.lex_state = 14},
  [10873] = {.lex_state = 14},
  [10874] = {.lex_state = 14},
  [10875] = {.lex_state = 14},
  [10876] = {.lex_state = 373},
  [10877] = {.lex_state = 14},
  [10878] = {.lex_state = 373},
  [10879] = {.lex_state = 14},
  [10880] = {.lex_state = 14},
  [10881] = {.lex_state = 14},
  [10882] = {.lex_state = 14},
  [10883] = {.lex_state = 373},
  [10884] = {.lex_state = 14},
  [10885] = {.lex_state = 14},
  [10886] = {.lex_state = 14},
  [10887] = {.lex_state = 14},
  [10888] = {.lex_state = 14},
  [10889] = {.lex_state = 14},
  [10890] = {.lex_state = 14},
  [10891] = {.lex_state = 14},
  [10892] = {.lex_state = 14},
  [10893] = {.lex_state = 14},
  [10894] = {.lex_state = 14},
  [10895] = {.lex_state = 14},
  [10896] = {.lex_state = 373},
  [10897] = {.lex_state = 14},
  [10898] = {.lex_state = 373},
  [10899] = {.lex_state = 14},
  [10900] = {.lex_state = 14},
  [10901] = {.lex_state = 14},
  [10902] = {.lex_state = 14},
  [10903] = {.lex_state = 14},
  [10904] = {.lex_state = 373},
  [10905] = {.lex_state = 14},
  [10906] = {.lex_state = 14},
  [10907] = {.lex_state = 373},
  [10908] = {.lex_state = 14},
  [10909] = {.lex_state = 373},
  [10910] = {.lex_state = 14},
  [10911] = {.lex_state = 14},
  [10912] = {.lex_state = 14},
  [10913] = {.lex_state = 373},
  [10914] = {.lex_state = 373},
  [10915] = {.lex_state = 373},
  [10916] = {.lex_state = 14},
  [10917] = {.lex_state = 371},
  [10918] = {.lex_state = 14},
  [10919] = {.lex_state = 14},
  [10920] = {.lex_state = 371},
  [10921] = {.lex_state = 14},
  [10922] = {.lex_state = 14},
  [10923] = {.lex_state = 14},
  [10924] = {.lex_state = 14},
  [10925] = {.lex_state = 14},
  [10926] = {.lex_state = 14},
  [10927] = {.lex_state = 14},
  [10928] = {.lex_state = 14},
  [10929] = {.lex_state = 14},
  [10930] = {.lex_state = 14},
  [10931] = {.lex_state = 14},
  [10932] = {.lex_state = 14},
  [10933] = {.lex_state = 373},
  [10934] = {.lex_state = 373},
  [10935] = {.lex_state = 373},
  [10936] = {.lex_state = 7},
  [10937] = {.lex_state = 373},
  [10938] = {.lex_state = 373},
  [10939] = {.lex_state = 373},
  [10940] = {.lex_state = 373},
  [10941] = {.lex_state = 373},
  [10942] = {.lex_state = 373},
  [10943] = {.lex_state = 371},
  [10944] = {.lex_state = 373},
  [10945] = {.lex_state = 373},
  [10946] = {.lex_state = 373},
  [10947] = {.lex_state = 371},
  [10948] = {.lex_state = 373},
  [10949] = {.lex_state = 371},
  [10950] = {.lex_state = 371},
  [10951] = {.lex_state = 373},
  [10952] = {.lex_state = 371},
  [10953] = {.lex_state = 371},
  [10954] = {.lex_state = 373},
  [10955] = {.lex_state = 371},
  [10956] = {.lex_state = 373},
  [10957] = {.lex_state = 371},
  [10958] = {.lex_state = 371},
  [10959] = {.lex_state = 7},
  [10960] = {.lex_state = 371},
  [10961] = {.lex_state = 371},
  [10962] = {.lex_state = 371},
  [10963] = {.lex_state = 371},
  [10964] = {.lex_state = 371},
  [10965] = {.lex_state = 371},
  [10966] = {.lex_state = 371},
  [10967] = {.lex_state = 373},
  [10968] = {.lex_state = 371},
  [10969] = {.lex_state = 373},
  [10970] = {.lex_state = 371},
  [10971] = {.lex_state = 371},
  [10972] = {.lex_state = 371},
  [10973] = {.lex_state = 371},
  [10974] = {.lex_state = 371},
  [10975] = {.lex_state = 371},
  [10976] = {.lex_state = 371},
  [10977] = {.lex_state = 371},
  [10978] = {.lex_state = 371},
  [10979] = {.lex_state = 373},
  [10980] = {.lex_state = 371},
  [10981] = {.lex_state = 371},
  [10982] = {.lex_state = 373},
  [10983] = {.lex_state = 371},
  [10984] = {.lex_state = 373},
  [10985] = {.lex_state = 373},
  [10986] = {.lex_state = 373},
  [10987] = {.lex_state = 373},
  [10988] = {.lex_state = 373},
  [10989] = {.lex_state = 373},
  [10990] = {.lex_state = 373},
  [10991] = {.lex_state = 371},
  [10992] = {.lex_state = 373},
  [10993] = {.lex_state = 373},
  [10994] = {.lex_state = 371},
  [10995] = {.lex_state = 371},
  [10996] = {.lex_state = 371},
  [10997] = {.lex_state = 371},
  [10998] = {.lex_state = 373},
  [10999] = {.lex_state = 373},
  [11000] = {.lex_state = 371},
  [11001] = {.lex_state = 373},
  [11002] = {.lex_state = 371},
  [11003] = {.lex_state = 371},
  [11004] = {.lex_state = 371},
  [11005] = {.lex_state = 371},
  [11006] = {.lex_state = 371},
  [11007] = {.lex_state = 371},
  [11008] = {.lex_state = 371},
  [11009] = {.lex_state = 373},
  [11010] = {.lex_state = 373},
  [11011] = {.lex_state = 371},
  [11012] = {.lex_state = 373},
  [11013] = {.lex_state = 371},
  [11014] = {.lex_state = 371},
  [11015] = {.lex_state = 373},
  [11016] = {.lex_state = 371},
  [11017] = {.lex_state = 371},
  [11018] = {.lex_state = 371},
  [11019] = {.lex_state = 371},
  [11020] = {.lex_state = 371},
  [11021] = {.lex_state = 373},
  [11022] = {.lex_state = 373},
  [11023] = {.lex_state = 371},
  [11024] = {.lex_state = 371},
  [11025] = {.lex_state = 371},
  [11026] = {.lex_state = 373},
  [11027] = {.lex_state = 373},
  [11028] = {.lex_state = 373},
  [11029] = {.lex_state = 373},
  [11030] = {.lex_state = 373},
  [11031] = {.lex_state = 371},
  [11032] = {.lex_state = 371},
  [11033] = {.lex_state = 371},
  [11034] = {.lex_state = 371},
  [11035] = {.lex_state = 371},
  [11036] = {.lex_state = 373},
  [11037] = {.lex_state = 373},
  [11038] = {.lex_state = 371},
  [11039] = {.lex_state = 373},
  [11040] = {.lex_state = 373},
  [11041] = {.lex_state = 373},
  [11042] = {.lex_state = 373},
  [11043] = {.lex_state = 373},
  [11044] = {.lex_state = 371},
  [11045] = {.lex_state = 371},
  [11046] = {.lex_state = 371},
  [11047] = {.lex_state = 7},
  [11048] = {.lex_state = 371},
  [11049] = {.lex_state = 371},
  [11050] = {.lex_state = 371},
  [11051] = {.lex_state = 371},
  [11052] = {.lex_state = 371},
  [11053] = {.lex_state = 373},
  [11054] = {.lex_state = 371},
  [11055] = {.lex_state = 373},
  [11056] = {.lex_state = 371},
  [11057] = {.lex_state = 373},
  [11058] = {.lex_state = 371},
  [11059] = {.lex_state = 373},
  [11060] = {.lex_state = 373},
  [11061] = {.lex_state = 371},
  [11062] = {.lex_state = 371},
  [11063] = {.lex_state = 371},
  [11064] = {.lex_state = 373},
  [11065] = {.lex_state = 371},
  [11066] = {.lex_state = 371},
  [11067] = {.lex_state = 371},
  [11068] = {.lex_state = 371},
  [11069] = {.lex_state = 373},
  [11070] = {.lex_state = 371},
  [11071] = {.lex_state = 371},
  [11072] = {.lex_state = 371},
  [11073] = {.lex_state = 371},
  [11074] = {.lex_state = 371},
  [11075] = {.lex_state = 371},
  [11076] = {.lex_state = 371},
  [11077] = {.lex_state = 371},
  [11078] = {.lex_state = 371},
  [11079] = {.lex_state = 371},
  [11080] = {.lex_state = 371},
  [11081] = {.lex_state = 371},
  [11082] = {.lex_state = 371},
  [11083] = {.lex_state = 371},
  [11084] = {.lex_state = 371},
  [11085] = {.lex_state = 371},
  [11086] = {.lex_state = 371},
  [11087] = {.lex_state = 371},
  [11088] = {.lex_state = 371},
  [11089] = {.lex_state = 371},
  [11090] = {.lex_state = 371},
  [11091] = {.lex_state = 371},
  [11092] = {.lex_state = 371},
  [11093] = {.lex_state = 371},
  [11094] = {.lex_state = 371},
  [11095] = {.lex_state = 371},
  [11096] = {.lex_state = 373},
  [11097] = {.lex_state = 371},
  [11098] = {.lex_state = 371},
  [11099] = {.lex_state = 371},
  [11100] = {.lex_state = 371},
  [11101] = {.lex_state = 371},
  [11102] = {.lex_state = 371},
  [11103] = {.lex_state = 371},
  [11104] = {.lex_state = 371},
  [11105] = {.lex_state = 371},
  [11106] = {.lex_state = 371},
  [11107] = {.lex_state = 371},
  [11108] = {.lex_state = 371},
  [11109] = {.lex_state = 371},
  [11110] = {.lex_state = 371},
  [11111] = {.lex_state = 371},
  [11112] = {.lex_state = 371},
  [11113] = {.lex_state = 371},
  [11114] = {.lex_state = 371},
  [11115] = {.lex_state = 371},
  [11116] = {.lex_state = 371},
  [11117] = {.lex_state = 371},
  [11118] = {.lex_state = 371},
  [11119] = {.lex_state = 371},
  [11120] = {.lex_state = 371},
  [11121] = {.lex_state = 371},
  [11122] = {.lex_state = 371},
  [11123] = {.lex_state = 41},
  [11124] = {.lex_state = 371},
  [11125] = {.lex_state = 371},
  [11126] = {.lex_state = 371},
  [11127] = {.lex_state = 371},
  [11128] = {.lex_state = 371},
  [11129] = {.lex_state = 371},
  [11130] = {.lex_state = 371},
  [11131] = {.lex_state = 371},
  [11132] = {.lex_state = 50},
  [11133] = {.lex_state = 371},
  [11134] = {.lex_state = 371},
  [11135] = {.lex_state = 371},
  [11136] = {.lex_state = 371},
  [11137] = {.lex_state = 371},
  [11138] = {.lex_state = 371},
  [11139] = {.lex_state = 371},
  [11140] = {.lex_state = 50},
  [11141] = {.lex_state = 50},
  [11142] = {.lex_state = 371},
  [11143] = {.lex_state = 371},
  [11144] = {.lex_state = 14},
  [11145] = {.lex_state = 371},
  [11146] = {.lex_state = 371},
  [11147] = {.lex_state = 371},
  [11148] = {.lex_state = 371},
  [11149] = {.lex_state = 7},
  [11150] = {.lex_state = 14},
  [11151] = {.lex_state = 7},
  [11152] = {.lex_state = 371},
  [11153] = {.lex_state = 371},
  [11154] = {.lex_state = 14},
  [11155] = {.lex_state = 14},
  [11156] = {.lex_state = 14},
  [11157] = {.lex_state = 14},
  [11158] = {.lex_state = 14},
  [11159] = {.lex_state = 371},
  [11160] = {.lex_state = 7},
  [11161] = {.lex_state = 373},
  [11162] = {.lex_state = 371},
  [11163] = {.lex_state = 373},
  [11164] = {.lex_state = 373},
  [11165] = {.lex_state = 373},
  [11166] = {.lex_state = 371},
  [11167] = {.lex_state = 371},
  [11168] = {.lex_state = 373},
  [11169] = {.lex_state = 371},
  [11170] = {.lex_state = 371},
  [11171] = {.lex_state = 371},
  [11172] = {.lex_state = 371},
  [11173] = {.lex_state = 371},
  [11174] = {.lex_state = 371},
  [11175] = {.lex_state = 371},
  [11176] = {.lex_state = 373},
  [11177] = {.lex_state = 371},
  [11178] = {.lex_state = 371},
  [11179] = {.lex_state = 371},
  [11180] = {.lex_state = 371},
  [11181] = {.lex_state = 371},
  [11182] = {.lex_state = 371},
  [11183] = {.lex_state = 371},
  [11184] = {.lex_state = 371},
  [11185] = {.lex_state = 371},
  [11186] = {.lex_state = 371},
  [11187] = {.lex_state = 371},
  [11188] = {.lex_state = 371},
  [11189] = {.lex_state = 371},
  [11190] = {.lex_state = 371},
  [11191] = {.lex_state = 371},
  [11192] = {.lex_state = 14},
  [11193] = {.lex_state = 373},
  [11194] = {.lex_state = 7},
  [11195] = {.lex_state = 371},
  [11196] = {.lex_state = 371},
  [11197] = {.lex_state = 14},
  [11198] = {.lex_state = 14},
  [11199] = {.lex_state = 371},
  [11200] = {.lex_state = 371},
  [11201] = {.lex_state = 371},
  [11202] = {.lex_state = 371},
  [11203] = {.lex_state = 373},
  [11204] = {.lex_state = 371},
  [11205] = {.lex_state = 371},
  [11206] = {.lex_state = 371},
  [11207] = {.lex_state = 371},
  [11208] = {.lex_state = 371},
  [11209] = {.lex_state = 373},
  [11210] = {.lex_state = 371},
  [11211] = {.lex_state = 371},
  [11212] = {.lex_state = 371},
  [11213] = {.lex_state = 371},
  [11214] = {.lex_state = 373},
  [11215] = {.lex_state = 373},
  [11216] = {.lex_state = 371},
  [11217] = {.lex_state = 371},
  [11218] = {.lex_state = 371},
  [11219] = {.lex_state = 41},
  [11220] = {.lex_state = 371},
  [11221] = {.lex_state = 373},
  [11222] = {.lex_state = 373},
  [11223] = {.lex_state = 373},
  [11224] = {.lex_state = 373},
  [11225] = {.lex_state = 371},
  [11226] = {.lex_state = 371},
  [11227] = {.lex_state = 373},
  [11228] = {.lex_state = 373},
  [11229] = {.lex_state = 371},
  [11230] = {.lex_state = 373},
  [11231] = {.lex_state = 373},
  [11232] = {.lex_state = 371},
  [11233] = {.lex_state = 41},
  [11234] = {.lex_state = 371},
  [11235] = {.lex_state = 371},
  [11236] = {.lex_state = 371},
  [11237] = {.lex_state = 371},
  [11238] = {.lex_state = 371},
  [11239] = {.lex_state = 371},
  [11240] = {.lex_state = 371},
  [11241] = {.lex_state = 371},
  [11242] = {.lex_state = 371},
  [11243] = {.lex_state = 371},
  [11244] = {.lex_state = 41},
  [11245] = {.lex_state = 41},
  [11246] = {.lex_state = 41},
  [11247] = {.lex_state = 371},
  [11248] = {.lex_state = 41},
  [11249] = {.lex_state = 371},
  [11250] = {.lex_state = 371},
  [11251] = {.lex_state = 371},
  [11252] = {.lex_state = 371},
  [11253] = {.lex_state = 371},
  [11254] = {.lex_state = 371},
  [11255] = {.lex_state = 371},
  [11256] = {.lex_state = 371},
  [11257] = {.lex_state = 371},
  [11258] = {.lex_state = 371},
  [11259] = {.lex_state = 41},
  [11260] = {.lex_state = 371},
  [11261] = {.lex_state = 371},
  [11262] = {.lex_state = 371},
  [11263] = {.lex_state = 371},
  [11264] = {.lex_state = 371},
  [11265] = {.lex_state = 371},
  [11266] = {.lex_state = 371},
  [11267] = {.lex_state = 371},
  [11268] = {.lex_state = 371},
  [11269] = {.lex_state = 371},
  [11270] = {.lex_state = 21},
  [11271] = {.lex_state = 7},
  [11272] = {.lex_state = 371},
  [11273] = {.lex_state = 371},
  [11274] = {.lex_state = 373},
  [11275] = {.lex_state = 371},
  [11276] = {.lex_state = 371},
  [11277] = {.lex_state = 371},
  [11278] = {.lex_state = 373},
  [11279] = {.lex_state = 371},
  [11280] = {.lex_state = 371},
  [11281] = {.lex_state = 371},
  [11282] = {.lex_state = 371},
  [11283] = {.lex_state = 371},
  [11284] = {.lex_state = 371},
  [11285] = {.lex_state = 371},
  [11286] = {.lex_state = 371},
  [11287] = {.lex_state = 371},
  [11288] = {.lex_state = 371},
  [11289] = {.lex_state = 371},
  [11290] = {.lex_state = 371},
  [11291] = {.lex_state = 371},
  [11292] = {.lex_state = 371},
  [11293] = {.lex_state = 371},
  [11294] = {.lex_state = 371},
  [11295] = {.lex_state = 21},
  [11296] = {.lex_state = 371},
  [11297] = {.lex_state = 371},
  [11298] = {.lex_state = 371},
  [11299] = {.lex_state = 371},
  [11300] = {.lex_state = 371},
  [11301] = {.lex_state = 371},
  [11302] = {.lex_state = 371},
  [11303] = {.lex_state = 371},
  [11304] = {.lex_state = 371},
  [11305] = {.lex_state = 371},
  [11306] = {.lex_state = 371},
  [11307] = {.lex_state = 371},
  [11308] = {.lex_state = 7},
  [11309] = {.lex_state = 371},
  [11310] = {.lex_state = 371},
  [11311] = {.lex_state = 371},
  [11312] = {.lex_state = 371},
  [11313] = {.lex_state = 371},
  [11314] = {.lex_state = 371},
  [11315] = {.lex_state = 371},
  [11316] = {.lex_state = 7},
  [11317] = {.lex_state = 371},
  [11318] = {.lex_state = 371},
  [11319] = {.lex_state = 371},
  [11320] = {.lex_state = 371},
  [11321] = {.lex_state = 371},
  [11322] = {.lex_state = 371},
  [11323] = {.lex_state = 371},
  [11324] = {.lex_state = 371},
  [11325] = {.lex_state = 371},
  [11326] = {.lex_state = 371},
  [11327] = {.lex_state = 371},
  [11328] = {.lex_state = 371},
  [11329] = {.lex_state = 371},
  [11330] = {.lex_state = 371},
  [11331] = {.lex_state = 371},
  [11332] = {.lex_state = 371},
  [11333] = {.lex_state = 371},
  [11334] = {.lex_state = 371},
  [11335] = {.lex_state = 371},
  [11336] = {.lex_state = 371},
  [11337] = {.lex_state = 371},
  [11338] = {.lex_state = 371},
  [11339] = {.lex_state = 371},
  [11340] = {.lex_state = 371},
  [11341] = {.lex_state = 371},
  [11342] = {.lex_state = 7},
  [11343] = {.lex_state = 371},
  [11344] = {.lex_state = 371},
  [11345] = {.lex_state = 371},
  [11346] = {.lex_state = 371},
  [11347] = {.lex_state = 371},
  [11348] = {.lex_state = 371},
  [11349] = {.lex_state = 371},
  [11350] = {.lex_state = 371},
  [11351] = {.lex_state = 371},
  [11352] = {.lex_state = 371},
  [11353] = {.lex_state = 371},
  [11354] = {.lex_state = 371},
  [11355] = {.lex_state = 371},
  [11356] = {.lex_state = 373},
  [11357] = {.lex_state = 371},
  [11358] = {.lex_state = 371},
  [11359] = {.lex_state = 371},
  [11360] = {.lex_state = 371},
  [11361] = {.lex_state = 63},
  [11362] = {.lex_state = 371},
  [11363] = {.lex_state = 371},
  [11364] = {.lex_state = 371},
  [11365] = {.lex_state = 371},
  [11366] = {.lex_state = 371},
  [11367] = {.lex_state = 371},
  [11368] = {.lex_state = 371},
  [11369] = {.lex_state = 371},
  [11370] = {.lex_state = 371},
  [11371] = {.lex_state = 371},
  [11372] = {.lex_state = 371},
  [11373] = {.lex_state = 371},
  [11374] = {.lex_state = 82},
  [11375] = {.lex_state = 371},
  [11376] = {.lex_state = 373},
  [11377] = {.lex_state = 371},
  [11378] = {.lex_state = 373},
  [11379] = {.lex_state = 371},
  [11380] = {.lex_state = 371},
  [11381] = {.lex_state = 371},
  [11382] = {.lex_state = 371},
  [11383] = {.lex_state = 82},
  [11384] = {.lex_state = 371},
  [11385] = {.lex_state = 371},
  [11386] = {.lex_state = 371},
  [11387] = {.lex_state = 371},
  [11388] = {.lex_state = 371},
  [11389] = {.lex_state = 371},
  [11390] = {.lex_state = 371},
  [11391] = {.lex_state = 371},
  [11392] = {.lex_state = 63},
  [11393] = {.lex_state = 371},
  [11394] = {.lex_state = 373},
  [11395] = {.lex_state = 373},
  [11396] = {.lex_state = 7},
  [11397] = {.lex_state = 371},
  [11398] = {.lex_state = 371},
  [11399] = {.lex_state = 371},
  [11400] = {.lex_state = 373},
  [11401] = {.lex_state = 371},
  [11402] = {.lex_state = 371},
  [11403] = {.lex_state = 7},
  [11404] = {.lex_state = 371},
  [11405] = {.lex_state = 371},
  [11406] = {.lex_state = 371},
  [11407] = {.lex_state = 373},
  [11408] = {.lex_state = 371},
  [11409] = {.lex_state = 371},
  [11410] = {.lex_state = 371},
  [11411] = {.lex_state = 371},
  [11412] = {.lex_state = 371},
  [11413] = {.lex_state = 373},
  [11414] = {.lex_state = 371},
  [11415] = {.lex_state = 373},
  [11416] = {.lex_state = 371},
  [11417] = {.lex_state = 371},
  [11418] = {.lex_state = 371},
  [11419] = {.lex_state = 371},
  [11420] = {.lex_state = 371},
  [11421] = {.lex_state = 371},
  [11422] = {.lex_state = 371},
  [11423] = {.lex_state = 371},
  [11424] = {.lex_state = 371},
  [11425] = {.lex_state = 371},
  [11426] = {.lex_state = 371},
  [11427] = {.lex_state = 371},
  [11428] = {.lex_state = 371},
  [11429] = {.lex_state = 371},
  [11430] = {.lex_state = 371},
  [11431] = {.lex_state = 371},
  [11432] = {.lex_state = 371},
  [11433] = {.lex_state = 371},
  [11434] = {.lex_state = 371},
  [11435] = {.lex_state = 371},
  [11436] = {.lex_state = 371},
  [11437] = {.lex_state = 7},
  [11438] = {.lex_state = 371},
  [11439] = {.lex_state = 82},
  [11440] = {.lex_state = 82},
  [11441] = {.lex_state = 371},
  [11442] = {.lex_state = 371},
  [11443] = {.lex_state = 371},
  [11444] = {.lex_state = 373},
  [11445] = {.lex_state = 371},
  [11446] = {.lex_state = 371},
  [11447] = {.lex_state = 371},
  [11448] = {.lex_state = 371},
  [11449] = {.lex_state = 371},
  [11450] = {.lex_state = 371},
  [11451] = {.lex_state = 371},
  [11452] = {.lex_state = 63},
  [11453] = {.lex_state = 371},
  [11454] = {.lex_state = 7},
  [11455] = {.lex_state = 7},
  [11456] = {.lex_state = 371},
  [11457] = {.lex_state = 371},
  [11458] = {.lex_state = 371},
  [11459] = {.lex_state = 371},
  [11460] = {.lex_state = 371},
  [11461] = {.lex_state = 371},
  [11462] = {.lex_state = 81},
  [11463] = {.lex_state = 371},
  [11464] = {.lex_state = 371},
  [11465] = {.lex_state = 371},
  [11466] = {.lex_state = 371},
  [11467] = {.lex_state = 371},
  [11468] = {.lex_state = 371},
  [11469] = {.lex_state = 371},
  [11470] = {.lex_state = 81},
  [11471] = {.lex_state = 372},
  [11472] = {.lex_state = 371},
  [11473] = {.lex_state = 371},
  [11474] = {.lex_state = 371},
  [11475] = {.lex_state = 63},
  [11476] = {.lex_state = 371},
  [11477] = {.lex_state = 82},
  [11478] = {.lex_state = 371},
  [11479] = {.lex_state = 371},
  [11480] = {.lex_state = 371},
  [11481] = {.lex_state = 371},
  [11482] = {.lex_state = 371},
  [11483] = {.lex_state = 371},
  [11484] = {.lex_state = 371},
  [11485] = {.lex_state = 371},
  [11486] = {.lex_state = 371},
  [11487] = {.lex_state = 373},
  [11488] = {.lex_state = 373},
  [11489] = {.lex_state = 371},
  [11490] = {.lex_state = 371},
  [11491] = {.lex_state = 371},
  [11492] = {.lex_state = 371},
  [11493] = {.lex_state = 371},
  [11494] = {.lex_state = 373},
  [11495] = {.lex_state = 373},
  [11496] = {.lex_state = 373},
  [11497] = {.lex_state = 373},
  [11498] = {.lex_state = 371},
  [11499] = {.lex_state = 371},
  [11500] = {.lex_state = 371},
  [11501] = {.lex_state = 7},
  [11502] = {.lex_state = 7},
  [11503] = {.lex_state = 7},
  [11504] = {.lex_state = 373},
  [11505] = {.lex_state = 7},
  [11506] = {.lex_state = 371},
  [11507] = {.lex_state = 371},
  [11508] = {.lex_state = 373},
  [11509] = {.lex_state = 373},
  [11510] = {.lex_state = 371},
  [11511] = {.lex_state = 371},
  [11512] = {.lex_state = 7},
  [11513] = {.lex_state = 7},
  [11514] = {.lex_state = 7},
  [11515] = {.lex_state = 371},
  [11516] = {.lex_state = 371},
  [11517] = {.lex_state = 373},
  [11518] = {.lex_state = 373},
  [11519] = {.lex_state = 7},
  [11520] = {.lex_state = 373},
  [11521] = {.lex_state = 371},
  [11522] = {.lex_state = 371},
  [11523] = {.lex_state = 373},
  [11524] = {.lex_state = 373},
  [11525] = {.lex_state = 371},
  [11526] = {.lex_state = 373},
  [11527] = {.lex_state = 373},
  [11528] = {.lex_state = 373},
  [11529] = {.lex_state = 371},
  [11530] = {.lex_state = 373},
  [11531] = {.lex_state = 371},
  [11532] = {.lex_state = 7},
  [11533] = {.lex_state = 371},
  [11534] = {.lex_state = 7},
  [11535] = {.lex_state = 7},
  [11536] = {.lex_state = 371},
  [11537] = {.lex_state = 373},
  [11538] = {.lex_state = 371},
  [11539] = {.lex_state = 373},
  [11540] = {.lex_state = 373},
  [11541] = {.lex_state = 371},
  [11542] = {.lex_state = 371},
  [11543] = {.lex_state = 371},
  [11544] = {.lex_state = 373},
  [11545] = {.lex_state = 373},
  [11546] = {.lex_state = 373},
  [11547] = {.lex_state = 371},
  [11548] = {.lex_state = 371},
  [11549] = {.lex_state = 371},
  [11550] = {.lex_state = 371},
  [11551] = {.lex_state = 371},
  [11552] = {.lex_state = 63},
  [11553] = {.lex_state = 373},
  [11554] = {.lex_state = 373},
  [11555] = {.lex_state = 373},
  [11556] = {.lex_state = 371},
  [11557] = {.lex_state = 373},
  [11558] = {.lex_state = 371},
  [11559] = {.lex_state = 371},
  [11560] = {.lex_state = 371},
  [11561] = {.lex_state = 371},
  [11562] = {.lex_state = 371},
  [11563] = {.lex_state = 371},
  [11564] = {.lex_state = 371},
  [11565] = {.lex_state = 371},
  [11566] = {.lex_state = 371},
  [11567] = {.lex_state = 371},
  [11568] = {.lex_state = 373},
  [11569] = {.lex_state = 373},
  [11570] = {.lex_state = 373},
  [11571] = {.lex_state = 373},
  [11572] = {.lex_state = 7},
  [11573] = {.lex_state = 7},
  [11574] = {.lex_state = 7},
  [11575] = {.lex_state = 371},
  [11576] = {.lex_state = 371},
  [11577] = {.lex_state = 371},
  [11578] = {.lex_state = 371},
  [11579] = {.lex_state = 371},
  [11580] = {.lex_state = 373},
  [11581] = {.lex_state = 371},
  [11582] = {.lex_state = 371},
  [11583] = {.lex_state = 373},
  [11584] = {.lex_state = 371},
  [11585] = {.lex_state = 371},
  [11586] = {.lex_state = 371},
  [11587] = {.lex_state = 371},
  [11588] = {.lex_state = 371},
  [11589] = {.lex_state = 371},
  [11590] = {.lex_state = 371},
  [11591] = {.lex_state = 371},
  [11592] = {.lex_state = 371},
  [11593] = {.lex_state = 371},
  [11594] = {.lex_state = 371},
  [11595] = {.lex_state = 371},
  [11596] = {.lex_state = 371},
  [11597] = {.lex_state = 371},
  [11598] = {.lex_state = 371},
  [11599] = {.lex_state = 371},
  [11600] = {.lex_state = 373},
  [11601] = {.lex_state = 371},
  [11602] = {.lex_state = 371},
  [11603] = {.lex_state = 371},
  [11604] = {.lex_state = 371},
  [11605] = {.lex_state = 371},
  [11606] = {.lex_state = 371},
  [11607] = {.lex_state = 371},
  [11608] = {.lex_state = 371},
  [11609] = {.lex_state = 373},
  [11610] = {.lex_state = 371},
  [11611] = {.lex_state = 373},
  [11612] = {.lex_state = 371},
  [11613] = {.lex_state = 371},
  [11614] = {.lex_state = 373},
  [11615] = {.lex_state = 371},
  [11616] = {.lex_state = 371},
  [11617] = {.lex_state = 373},
  [11618] = {.lex_state = 373},
  [11619] = {.lex_state = 371},
  [11620] = {.lex_state = 373},
  [11621] = {.lex_state = 371},
  [11622] = {.lex_state = 373},
  [11623] = {.lex_state = 371},
  [11624] = {.lex_state = 373},
  [11625] = {.lex_state = 371},
  [11626] = {.lex_state = 373},
  [11627] = {.lex_state = 371},
  [11628] = {.lex_state = 7},
  [11629] = {.lex_state = 373},
  [11630] = {.lex_state = 371},
  [11631] = {.lex_state = 371},
  [11632] = {.lex_state = 373},
  [11633] = {.lex_state = 371},
  [11634] = {.lex_state = 371},
  [11635] = {.lex_state = 371},
  [11636] = {.lex_state = 371},
  [11637] = {.lex_state = 371},
  [11638] = {.lex_state = 371},
  [11639] = {.lex_state = 371},
  [11640] = {.lex_state = 373},
  [11641] = {.lex_state = 371},
  [11642] = {.lex_state = 371},
  [11643] = {.lex_state = 373},
  [11644] = {.lex_state = 373},
  [11645] = {.lex_state = 371},
  [11646] = {.lex_state = 373},
  [11647] = {.lex_state = 373},
  [11648] = {.lex_state = 373},
  [11649] = {.lex_state = 371},
  [11650] = {.lex_state = 371},
  [11651] = {.lex_state = 373},
  [11652] = {.lex_state = 373},
  [11653] = {.lex_state = 371},
  [11654] = {.lex_state = 373},
  [11655] = {.lex_state = 7},
  [11656] = {.lex_state = 371},
  [11657] = {.lex_state = 373},
  [11658] = {.lex_state = 373},
  [11659] = {.lex_state = 7},
  [11660] = {.lex_state = 7},
  [11661] = {.lex_state = 371},
  [11662] = {.lex_state = 7},
  [11663] = {.lex_state = 0},
  [11664] = {.lex_state = 371},
  [11665] = {.lex_state = 371},
  [11666] = {.lex_state = 7},
  [11667] = {.lex_state = 7},
  [11668] = {.lex_state = 7},
  [11669] = {.lex_state = 7},
  [11670] = {.lex_state = 7},
  [11671] = {.lex_state = 371},
  [11672] = {.lex_state = 371},
  [11673] = {.lex_state = 7},
  [11674] = {.lex_state = 371},
  [11675] = {.lex_state = 7},
  [11676] = {.lex_state = 371},
  [11677] = {.lex_state = 7},
  [11678] = {.lex_state = 7},
  [11679] = {.lex_state = 7},
  [11680] = {.lex_state = 7},
  [11681] = {.lex_state = 371},
  [11682] = {.lex_state = 371},
  [11683] = {.lex_state = 7},
  [11684] = {.lex_state = 7},
  [11685] = {.lex_state = 7},
  [11686] = {.lex_state = 7},
  [11687] = {.lex_state = 7},
  [11688] = {.lex_state = 371},
  [11689] = {.lex_state = 371},
  [11690] = {.lex_state = 7},
  [11691] = {.lex_state = 371},
  [11692] = {.lex_state = 371},
  [11693] = {.lex_state = 371},
  [11694] = {.lex_state = 371},
  [11695] = {.lex_state = 7},
  [11696] = {.lex_state = 7},
  [11697] = {.lex_state = 371},
  [11698] = {.lex_state = 7},
  [11699] = {.lex_state = 7},
  [11700] = {.lex_state = 371},
  [11701] = {.lex_state = 7},
  [11702] = {.lex_state = 7},
  [11703] = {.lex_state = 7},
  [11704] = {.lex_state = 7},
  [11705] = {.lex_state = 7},
  [11706] = {.lex_state = 371},
  [11707] = {.lex_state = 371},
  [11708] = {.lex_state = 7},
  [11709] = {.lex_state = 7},
  [11710] = {.lex_state = 373},
  [11711] = {.lex_state = 371},
  [11712] = {.lex_state = 371},
  [11713] = {.lex_state = 371},
  [11714] = {.lex_state = 371},
  [11715] = {.lex_state = 7},
  [11716] = {.lex_state = 371},
  [11717] = {.lex_state = 7},
  [11718] = {.lex_state = 7},
  [11719] = {.lex_state = 7},
  [11720] = {.lex_state = 371},
  [11721] = {.lex_state = 371},
  [11722] = {.lex_state = 371},
  [11723] = {.lex_state = 371},
  [11724] = {.lex_state = 371},
  [11725] = {.lex_state = 371},
  [11726] = {.lex_state = 7},
  [11727] = {.lex_state = 371},
  [11728] = {.lex_state = 7},
  [11729] = {.lex_state = 371},
  [11730] = {.lex_state = 41},
  [11731] = {.lex_state = 7},
  [11732] = {.lex_state = 7},
  [11733] = {.lex_state = 371},
  [11734] = {.lex_state = 371},
  [11735] = {.lex_state = 7},
  [11736] = {.lex_state = 371},
  [11737] = {.lex_state = 371},
  [11738] = {.lex_state = 7},
  [11739] = {.lex_state = 7},
  [11740] = {.lex_state = 7},
  [11741] = {.lex_state = 7},
  [11742] = {.lex_state = 371},
  [11743] = {.lex_state = 7},
  [11744] = {.lex_state = 7},
  [11745] = {.lex_state = 371},
  [11746] = {.lex_state = 7},
  [11747] = {.lex_state = 371},
  [11748] = {.lex_state = 7},
  [11749] = {.lex_state = 7},
  [11750] = {.lex_state = 371},
  [11751] = {.lex_state = 371},
  [11752] = {.lex_state = 371},
  [11753] = {.lex_state = 371},
  [11754] = {.lex_state = 7},
  [11755] = {.lex_state = 371},
  [11756] = {.lex_state = 7},
  [11757] = {.lex_state = 7},
  [11758] = {.lex_state = 371},
  [11759] = {.lex_state = 7},
  [11760] = {.lex_state = 371},
  [11761] = {.lex_state = 371},
  [11762] = {.lex_state = 371},
  [11763] = {.lex_state = 7},
  [11764] = {.lex_state = 371},
  [11765] = {.lex_state = 371},
  [11766] = {.lex_state = 373},
  [11767] = {.lex_state = 0},
  [11768] = {.lex_state = 371},
  [11769] = {.lex_state = 371},
  [11770] = {.lex_state = 371},
  [11771] = {.lex_state = 371},
  [11772] = {.lex_state = 7},
  [11773] = {.lex_state = 7},
  [11774] = {.lex_state = 7},
  [11775] = {.lex_state = 7},
  [11776] = {.lex_state = 371},
  [11777] = {.lex_state = 7},
  [11778] = {.lex_state = 7},
  [11779] = {.lex_state = 7},
  [11780] = {.lex_state = 371},
  [11781] = {.lex_state = 371},
  [11782] = {.lex_state = 371},
  [11783] = {.lex_state = 25},
  [11784] = {.lex_state = 371},
  [11785] = {.lex_state = 371},
  [11786] = {.lex_state = 371},
  [11787] = {.lex_state = 371},
  [11788] = {.lex_state = 371},
  [11789] = {.lex_state = 371},
  [11790] = {.lex_state = 371},
  [11791] = {.lex_state = 371},
  [11792] = {.lex_state = 371},
  [11793] = {.lex_state = 371},
  [11794] = {.lex_state = 371},
  [11795] = {.lex_state = 371},
  [11796] = {.lex_state = 81},
  [11797] = {.lex_state = 371},
  [11798] = {.lex_state = 371},
  [11799] = {.lex_state = 41},
  [11800] = {.lex_state = 371},
  [11801] = {.lex_state = 371},
  [11802] = {.lex_state = 371},
  [11803] = {.lex_state = 371},
  [11804] = {.lex_state = 371},
  [11805] = {.lex_state = 371},
  [11806] = {.lex_state = 7},
  [11807] = {.lex_state = 371},
  [11808] = {.lex_state = 373},
  [11809] = {.lex_state = 371},
  [11810] = {.lex_state = 371},
  [11811] = {.lex_state = 371},
  [11812] = {.lex_state = 371},
  [11813] = {.lex_state = 7},
  [11814] = {.lex_state = 371},
  [11815] = {.lex_state = 371},
  [11816] = {.lex_state = 371},
  [11817] = {.lex_state = 371},
  [11818] = {.lex_state = 371},
  [11819] = {.lex_state = 371},
  [11820] = {.lex_state = 371},
  [11821] = {.lex_state = 371},
  [11822] = {.lex_state = 371},
  [11823] = {.lex_state = 373},
  [11824] = {.lex_state = 371},
  [11825] = {.lex_state = 371},
  [11826] = {.lex_state = 373},
  [11827] = {.lex_state = 371},
  [11828] = {.lex_state = 371},
  [11829] = {.lex_state = 371},
  [11830] = {.lex_state = 371},
  [11831] = {.lex_state = 371},
  [11832] = {.lex_state = 371},
  [11833] = {.lex_state = 371},
  [11834] = {.lex_state = 371},
  [11835] = {.lex_state = 371},
  [11836] = {.lex_state = 371},
  [11837] = {.lex_state = 7},
  [11838] = {.lex_state = 371},
  [11839] = {.lex_state = 371},
  [11840] = {.lex_state = 371},
  [11841] = {.lex_state = 371},
  [11842] = {.lex_state = 371},
  [11843] = {.lex_state = 371},
  [11844] = {.lex_state = 373},
  [11845] = {.lex_state = 371},
  [11846] = {.lex_state = 371},
  [11847] = {.lex_state = 371},
  [11848] = {.lex_state = 371},
  [11849] = {.lex_state = 371},
  [11850] = {.lex_state = 373},
  [11851] = {.lex_state = 371},
  [11852] = {.lex_state = 371},
  [11853] = {.lex_state = 371},
  [11854] = {.lex_state = 371},
  [11855] = {.lex_state = 371},
  [11856] = {.lex_state = 371},
  [11857] = {.lex_state = 371},
  [11858] = {.lex_state = 371},
  [11859] = {.lex_state = 371},
  [11860] = {.lex_state = 371},
  [11861] = {.lex_state = 371},
  [11862] = {.lex_state = 7},
  [11863] = {.lex_state = 371},
  [11864] = {.lex_state = 371},
  [11865] = {.lex_state = 371},
  [11866] = {.lex_state = 371},
  [11867] = {.lex_state = 371},
  [11868] = {.lex_state = 371},
  [11869] = {.lex_state = 371},
  [11870] = {.lex_state = 371},
  [11871] = {.lex_state = 371},
  [11872] = {.lex_state = 371},
  [11873] = {.lex_state = 371},
  [11874] = {.lex_state = 371},
  [11875] = {.lex_state = 371},
  [11876] = {.lex_state = 371},
  [11877] = {.lex_state = 25},
  [11878] = {.lex_state = 371},
  [11879] = {.lex_state = 371},
  [11880] = {.lex_state = 7},
  [11881] = {.lex_state = 371},
  [11882] = {.lex_state = 371},
  [11883] = {.lex_state = 371},
  [11884] = {.lex_state = 371},
  [11885] = {.lex_state = 371},
  [11886] = {.lex_state = 371},
  [11887] = {.lex_state = 371},
  [11888] = {.lex_state = 371},
  [11889] = {.lex_state = 371},
  [11890] = {.lex_state = 373},
  [11891] = {.lex_state = 371},
  [11892] = {.lex_state = 371},
  [11893] = {.lex_state = 371},
  [11894] = {.lex_state = 371},
  [11895] = {.lex_state = 371},
  [11896] = {.lex_state = 371},
  [11897] = {.lex_state = 371},
  [11898] = {.lex_state = 371},
  [11899] = {.lex_state = 371},
  [11900] = {.lex_state = 371},
  [11901] = {.lex_state = 371},
  [11902] = {.lex_state = 371},
  [11903] = {.lex_state = 371},
  [11904] = {.lex_state = 371},
  [11905] = {.lex_state = 371},
  [11906] = {.lex_state = 7},
  [11907] = {.lex_state = 371},
  [11908] = {.lex_state = 371},
  [11909] = {.lex_state = 41},
  [11910] = {.lex_state = 371},
  [11911] = {.lex_state = 371},
  [11912] = {.lex_state = 371},
  [11913] = {.lex_state = 371},
  [11914] = {.lex_state = 371},
  [11915] = {.lex_state = 371},
  [11916] = {.lex_state = 371},
  [11917] = {.lex_state = 371},
  [11918] = {.lex_state = 371},
  [11919] = {.lex_state = 371},
  [11920] = {.lex_state = 371},
  [11921] = {.lex_state = 371},
  [11922] = {.lex_state = 371},
  [11923] = {.lex_state = 81},
  [11924] = {.lex_state = 371},
  [11925] = {.lex_state = 371},
  [11926] = {.lex_state = 371},
  [11927] = {.lex_state = 371},
  [11928] = {.lex_state = 371},
  [11929] = {.lex_state = 371},
  [11930] = {.lex_state = 371},
  [11931] = {.lex_state = 371},
  [11932] = {.lex_state = 373},
  [11933] = {.lex_state = 373},
  [11934] = {.lex_state = 373},
  [11935] = {.lex_state = 371},
  [11936] = {.lex_state = 371},
  [11937] = {.lex_state = 371},
  [11938] = {.lex_state = 371},
  [11939] = {.lex_state = 371},
  [11940] = {.lex_state = 371},
  [11941] = {.lex_state = 371},
  [11942] = {.lex_state = 373},
  [11943] = {.lex_state = 373},
  [11944] = {.lex_state = 371},
  [11945] = {.lex_state = 371},
  [11946] = {.lex_state = 371},
  [11947] = {.lex_state = 371},
  [11948] = {.lex_state = 371},
  [11949] = {.lex_state = 371},
  [11950] = {.lex_state = 371},
  [11951] = {.lex_state = 41},
  [11952] = {.lex_state = 7},
  [11953] = {.lex_state = 371},
  [11954] = {.lex_state = 371},
  [11955] = {.lex_state = 371},
  [11956] = {.lex_state = 373},
  [11957] = {.lex_state = 371},
  [11958] = {.lex_state = 373},
  [11959] = {.lex_state = 371},
  [11960] = {.lex_state = 371},
  [11961] = {.lex_state = 371},
  [11962] = {.lex_state = 371},
  [11963] = {.lex_state = 371},
  [11964] = {.lex_state = 371},
  [11965] = {.lex_state = 371},
  [11966] = {.lex_state = 371},
  [11967] = {.lex_state = 371},
  [11968] = {.lex_state = 371},
  [11969] = {.lex_state = 371},
  [11970] = {.lex_state = 371},
  [11971] = {.lex_state = 7},
  [11972] = {.lex_state = 371},
  [11973] = {.lex_state = 371},
  [11974] = {.lex_state = 371},
  [11975] = {.lex_state = 371},
  [11976] = {.lex_state = 371},
  [11977] = {.lex_state = 371},
  [11978] = {.lex_state = 371},
  [11979] = {.lex_state = 7},
  [11980] = {.lex_state = 371},
  [11981] = {.lex_state = 371},
  [11982] = {.lex_state = 371},
  [11983] = {.lex_state = 7},
  [11984] = {.lex_state = 7},
  [11985] = {.lex_state = 371},
  [11986] = {.lex_state = 371},
  [11987] = {.lex_state = 371},
  [11988] = {.lex_state = 371},
  [11989] = {.lex_state = 7},
  [11990] = {.lex_state = 371},
  [11991] = {.lex_state = 7},
  [11992] = {.lex_state = 371},
  [11993] = {.lex_state = 371},
  [11994] = {.lex_state = 371},
  [11995] = {.lex_state = 371},
  [11996] = {.lex_state = 371},
  [11997] = {.lex_state = 371},
  [11998] = {.lex_state = 371},
  [11999] = {.lex_state = 371},
  [12000] = {.lex_state = 371},
  [12001] = {.lex_state = 371},
  [12002] = {.lex_state = 371},
  [12003] = {.lex_state = 371},
  [12004] = {.lex_state = 371},
  [12005] = {.lex_state = 371},
  [12006] = {.lex_state = 371},
  [12007] = {.lex_state = 371},
  [12008] = {.lex_state = 371},
  [12009] = {.lex_state = 371},
  [12010] = {.lex_state = 371},
  [12011] = {.lex_state = 371},
  [12012] = {.lex_state = 371},
  [12013] = {.lex_state = 371},
  [12014] = {.lex_state = 371},
  [12015] = {.lex_state = 371},
  [12016] = {.lex_state = 371},
  [12017] = {.lex_state = 371},
  [12018] = {.lex_state = 371},
  [12019] = {.lex_state = 7},
  [12020] = {.lex_state = 7},
  [12021] = {.lex_state = 7},
  [12022] = {.lex_state = 371},
  [12023] = {.lex_state = 371},
  [12024] = {.lex_state = 371},
  [12025] = {.lex_state = 7},
  [12026] = {.lex_state = 7},
  [12027] = {.lex_state = 371},
  [12028] = {.lex_state = 371},
  [12029] = {.lex_state = 7},
  [12030] = {.lex_state = 7},
  [12031] = {.lex_state = 371},
  [12032] = {.lex_state = 371},
  [12033] = {.lex_state = 371},
  [12034] = {.lex_state = 7},
  [12035] = {.lex_state = 371},
  [12036] = {.lex_state = 49},
  [12037] = {.lex_state = 7},
  [12038] = {.lex_state = 371},
  [12039] = {.lex_state = 371},
  [12040] = {.lex_state = 371},
  [12041] = {.lex_state = 371},
  [12042] = {.lex_state = 371},
  [12043] = {.lex_state = 371},
  [12044] = {.lex_state = 7},
  [12045] = {.lex_state = 371},
  [12046] = {.lex_state = 7},
  [12047] = {.lex_state = 371},
  [12048] = {.lex_state = 371},
  [12049] = {.lex_state = 371},
  [12050] = {.lex_state = 371},
  [12051] = {.lex_state = 371},
  [12052] = {.lex_state = 371},
  [12053] = {.lex_state = 7},
  [12054] = {.lex_state = 371},
  [12055] = {.lex_state = 371},
  [12056] = {.lex_state = 371},
  [12057] = {.lex_state = 371},
  [12058] = {.lex_state = 371},
  [12059] = {.lex_state = 371},
  [12060] = {.lex_state = 371},
  [12061] = {.lex_state = 7},
  [12062] = {.lex_state = 371},
  [12063] = {.lex_state = 371},
  [12064] = {.lex_state = 371},
  [12065] = {.lex_state = 371},
  [12066] = {.lex_state = 371},
  [12067] = {.lex_state = 371},
  [12068] = {.lex_state = 371},
  [12069] = {.lex_state = 371},
  [12070] = {.lex_state = 7},
  [12071] = {.lex_state = 371},
  [12072] = {.lex_state = 371},
  [12073] = {.lex_state = 371},
  [12074] = {.lex_state = 7},
  [12075] = {.lex_state = 371},
  [12076] = {.lex_state = 371},
  [12077] = {.lex_state = 371},
  [12078] = {.lex_state = 371},
  [12079] = {.lex_state = 7},
  [12080] = {.lex_state = 371},
  [12081] = {.lex_state = 7},
  [12082] = {.lex_state = 371},
  [12083] = {.lex_state = 371},
  [12084] = {.lex_state = 371},
  [12085] = {.lex_state = 7},
  [12086] = {.lex_state = 7},
  [12087] = {.lex_state = 371},
  [12088] = {.lex_state = 371},
  [12089] = {.lex_state = 371},
  [12090] = {.lex_state = 371},
  [12091] = {.lex_state = 371},
  [12092] = {.lex_state = 371},
  [12093] = {.lex_state = 371},
  [12094] = {.lex_state = 371},
  [12095] = {.lex_state = 371},
  [12096] = {.lex_state = 371},
  [12097] = {.lex_state = 371},
  [12098] = {.lex_state = 371},
  [12099] = {.lex_state = 371},
  [12100] = {.lex_state = 371},
  [12101] = {.lex_state = 371},
  [12102] = {.lex_state = 7},
  [12103] = {.lex_state = 371},
  [12104] = {.lex_state = 371},
  [12105] = {.lex_state = 371},
  [12106] = {.lex_state = 371},
  [12107] = {.lex_state = 371},
  [12108] = {.lex_state = 371},
  [12109] = {.lex_state = 371},
  [12110] = {.lex_state = 371},
  [12111] = {.lex_state = 371},
  [12112] = {.lex_state = 7},
  [12113] = {.lex_state = 7},
  [12114] = {.lex_state = 371},
  [12115] = {.lex_state = 7},
  [12116] = {.lex_state = 371},
  [12117] = {.lex_state = 7},
  [12118] = {.lex_state = 371},
  [12119] = {.lex_state = 7},
  [12120] = {.lex_state = 371},
  [12121] = {.lex_state = 371},
  [12122] = {.lex_state = 7},
  [12123] = {.lex_state = 371},
  [12124] = {.lex_state = 371},
  [12125] = {.lex_state = 371},
  [12126] = {.lex_state = 371},
  [12127] = {.lex_state = 371},
  [12128] = {.lex_state = 371},
  [12129] = {.lex_state = 371},
  [12130] = {.lex_state = 371},
  [12131] = {.lex_state = 371},
  [12132] = {.lex_state = 371},
  [12133] = {.lex_state = 371},
  [12134] = {.lex_state = 371},
  [12135] = {.lex_state = 371},
  [12136] = {.lex_state = 371},
  [12137] = {.lex_state = 371},
  [12138] = {.lex_state = 371},
  [12139] = {.lex_state = 371},
  [12140] = {.lex_state = 371},
  [12141] = {.lex_state = 7},
  [12142] = {.lex_state = 371},
  [12143] = {.lex_state = 371},
  [12144] = {.lex_state = 371},
  [12145] = {.lex_state = 371},
  [12146] = {.lex_state = 371},
  [12147] = {.lex_state = 371},
  [12148] = {.lex_state = 371},
  [12149] = {.lex_state = 371},
  [12150] = {.lex_state = 371},
  [12151] = {.lex_state = 371},
  [12152] = {.lex_state = 371},
  [12153] = {.lex_state = 371},
  [12154] = {.lex_state = 7},
  [12155] = {.lex_state = 371},
  [12156] = {.lex_state = 371},
  [12157] = {.lex_state = 371},
  [12158] = {.lex_state = 371},
  [12159] = {.lex_state = 371},
  [12160] = {.lex_state = 371},
  [12161] = {.lex_state = 371},
  [12162] = {.lex_state = 371},
  [12163] = {.lex_state = 371},
  [12164] = {.lex_state = 371},
  [12165] = {.lex_state = 7},
  [12166] = {.lex_state = 7},
  [12167] = {.lex_state = 7},
  [12168] = {.lex_state = 7},
  [12169] = {.lex_state = 371},
  [12170] = {.lex_state = 371},
  [12171] = {.lex_state = 371},
  [12172] = {.lex_state = 371},
  [12173] = {.lex_state = 7},
  [12174] = {.lex_state = 371},
  [12175] = {.lex_state = 7},
  [12176] = {.lex_state = 371},
  [12177] = {.lex_state = 371},
  [12178] = {.lex_state = 371},
  [12179] = {.lex_state = 371},
  [12180] = {.lex_state = 371},
  [12181] = {.lex_state = 7},
  [12182] = {.lex_state = 371},
  [12183] = {.lex_state = 371},
  [12184] = {.lex_state = 7},
  [12185] = {.lex_state = 371},
  [12186] = {.lex_state = 372},
  [12187] = {.lex_state = 7},
  [12188] = {.lex_state = 373},
  [12189] = {.lex_state = 371},
  [12190] = {.lex_state = 371},
  [12191] = {.lex_state = 371},
  [12192] = {.lex_state = 371},
  [12193] = {.lex_state = 371},
  [12194] = {.lex_state = 7},
  [12195] = {.lex_state = 7},
  [12196] = {.lex_state = 7},
  [12197] = {.lex_state = 7},
  [12198] = {.lex_state = 371},
  [12199] = {.lex_state = 7},
  [12200] = {.lex_state = 371},
  [12201] = {.lex_state = 371},
  [12202] = {.lex_state = 371},
  [12203] = {.lex_state = 7},
  [12204] = {.lex_state = 371},
  [12205] = {.lex_state = 371},
  [12206] = {.lex_state = 371},
  [12207] = {.lex_state = 371},
  [12208] = {.lex_state = 371},
  [12209] = {.lex_state = 371},
  [12210] = {.lex_state = 371},
  [12211] = {.lex_state = 371},
  [12212] = {.lex_state = 371},
  [12213] = {.lex_state = 43},
  [12214] = {.lex_state = 371},
  [12215] = {.lex_state = 371},
  [12216] = {.lex_state = 371},
  [12217] = {.lex_state = 7},
  [12218] = {.lex_state = 371},
  [12219] = {.lex_state = 371},
  [12220] = {.lex_state = 371},
  [12221] = {.lex_state = 371},
  [12222] = {.lex_state = 7},
  [12223] = {.lex_state = 371},
  [12224] = {.lex_state = 371},
  [12225] = {.lex_state = 371},
  [12226] = {.lex_state = 371},
  [12227] = {.lex_state = 7},
  [12228] = {.lex_state = 7},
  [12229] = {.lex_state = 371},
  [12230] = {.lex_state = 7},
  [12231] = {.lex_state = 371},
  [12232] = {.lex_state = 7},
  [12233] = {.lex_state = 371},
  [12234] = {.lex_state = 371},
  [12235] = {.lex_state = 371},
  [12236] = {.lex_state = 7},
  [12237] = {.lex_state = 371},
  [12238] = {.lex_state = 371},
  [12239] = {.lex_state = 371},
  [12240] = {.lex_state = 371},
  [12241] = {.lex_state = 371},
  [12242] = {.lex_state = 371},
  [12243] = {.lex_state = 7},
  [12244] = {.lex_state = 371},
  [12245] = {.lex_state = 371},
  [12246] = {.lex_state = 371},
  [12247] = {.lex_state = 371},
  [12248] = {.lex_state = 371},
  [12249] = {.lex_state = 371},
  [12250] = {.lex_state = 7},
  [12251] = {.lex_state = 371},
  [12252] = {.lex_state = 371},
  [12253] = {.lex_state = 371},
  [12254] = {.lex_state = 371},
  [12255] = {.lex_state = 371},
  [12256] = {.lex_state = 371},
  [12257] = {.lex_state = 371},
  [12258] = {.lex_state = 371},
  [12259] = {.lex_state = 7},
  [12260] = {.lex_state = 371},
  [12261] = {.lex_state = 7},
  [12262] = {.lex_state = 371},
  [12263] = {.lex_state = 371},
  [12264] = {.lex_state = 371},
  [12265] = {.lex_state = 371},
  [12266] = {.lex_state = 371},
  [12267] = {.lex_state = 7},
  [12268] = {.lex_state = 371},
  [12269] = {.lex_state = 371},
  [12270] = {.lex_state = 371},
  [12271] = {.lex_state = 371},
  [12272] = {.lex_state = 371},
  [12273] = {.lex_state = 371},
  [12274] = {.lex_state = 371},
  [12275] = {.lex_state = 371},
  [12276] = {.lex_state = 371},
  [12277] = {.lex_state = 371},
  [12278] = {.lex_state = 7},
  [12279] = {.lex_state = 371},
  [12280] = {.lex_state = 371},
  [12281] = {.lex_state = 0},
  [12282] = {.lex_state = 7},
  [12283] = {.lex_state = 371},
  [12284] = {.lex_state = 41},
  [12285] = {.lex_state = 371},
  [12286] = {.lex_state = 371},
  [12287] = {.lex_state = 7},
  [12288] = {.lex_state = 371},
  [12289] = {.lex_state = 371},
  [12290] = {.lex_state = 7},
  [12291] = {.lex_state = 371},
  [12292] = {.lex_state = 371},
  [12293] = {.lex_state = 371},
  [12294] = {.lex_state = 371},
  [12295] = {.lex_state = 371},
  [12296] = {.lex_state = 7},
  [12297] = {.lex_state = 371},
  [12298] = {.lex_state = 371},
  [12299] = {.lex_state = 7},
  [12300] = {.lex_state = 7},
  [12301] = {.lex_state = 7},
  [12302] = {.lex_state = 371},
  [12303] = {.lex_state = 7},
  [12304] = {.lex_state = 371},
  [12305] = {.lex_state = 371},
  [12306] = {.lex_state = 371},
  [12307] = {.lex_state = 371},
  [12308] = {.lex_state = 371},
  [12309] = {.lex_state = 371},
  [12310] = {.lex_state = 371},
  [12311] = {.lex_state = 371},
  [12312] = {.lex_state = 7},
  [12313] = {.lex_state = 371},
  [12314] = {.lex_state = 371},
  [12315] = {.lex_state = 371},
  [12316] = {.lex_state = 371},
  [12317] = {.lex_state = 371},
  [12318] = {.lex_state = 371},
  [12319] = {.lex_state = 81},
  [12320] = {.lex_state = 371},
  [12321] = {.lex_state = 371},
  [12322] = {.lex_state = 371},
  [12323] = {.lex_state = 371},
  [12324] = {.lex_state = 371},
  [12325] = {.lex_state = 371},
  [12326] = {.lex_state = 371},
  [12327] = {.lex_state = 371},
  [12328] = {.lex_state = 371},
  [12329] = {.lex_state = 371},
  [12330] = {.lex_state = 371},
  [12331] = {.lex_state = 371},
  [12332] = {.lex_state = 371},
  [12333] = {.lex_state = 0},
  [12334] = {.lex_state = 0},
  [12335] = {.lex_state = 371},
  [12336] = {.lex_state = 371},
  [12337] = {.lex_state = 7},
  [12338] = {.lex_state = 7},
  [12339] = {.lex_state = 371},
  [12340] = {.lex_state = 371},
  [12341] = {.lex_state = 371},
  [12342] = {.lex_state = 7},
  [12343] = {.lex_state = 371},
  [12344] = {.lex_state = 7},
  [12345] = {.lex_state = 371},
  [12346] = {.lex_state = 7},
  [12347] = {.lex_state = 7},
  [12348] = {.lex_state = 7},
  [12349] = {.lex_state = 371},
  [12350] = {.lex_state = 371},
  [12351] = {.lex_state = 371},
  [12352] = {.lex_state = 371},
  [12353] = {.lex_state = 371},
  [12354] = {.lex_state = 49},
  [12355] = {.lex_state = 371},
  [12356] = {.lex_state = 7},
  [12357] = {.lex_state = 7},
  [12358] = {.lex_state = 7},
  [12359] = {.lex_state = 7},
  [12360] = {.lex_state = 7},
  [12361] = {.lex_state = 371},
  [12362] = {.lex_state = 371},
  [12363] = {.lex_state = 371},
  [12364] = {.lex_state = 371},
  [12365] = {.lex_state = 372},
  [12366] = {.lex_state = 371},
  [12367] = {.lex_state = 373},
  [12368] = {.lex_state = 7},
  [12369] = {.lex_state = 7},
  [12370] = {.lex_state = 371},
  [12371] = {.lex_state = 371},
  [12372] = {.lex_state = 371},
  [12373] = {.lex_state = 7},
  [12374] = {.lex_state = 371},
  [12375] = {.lex_state = 371},
  [12376] = {.lex_state = 371},
  [12377] = {.lex_state = 371},
  [12378] = {.lex_state = 371},
  [12379] = {.lex_state = 371},
  [12380] = {.lex_state = 7},
  [12381] = {.lex_state = 371},
  [12382] = {.lex_state = 371},
  [12383] = {.lex_state = 371},
  [12384] = {.lex_state = 371},
  [12385] = {.lex_state = 371},
  [12386] = {.lex_state = 371},
  [12387] = {.lex_state = 0},
  [12388] = {.lex_state = 371},
  [12389] = {.lex_state = 371},
  [12390] = {.lex_state = 371},
  [12391] = {.lex_state = 371},
  [12392] = {.lex_state = 371},
  [12393] = {.lex_state = 371},
  [12394] = {.lex_state = 371},
  [12395] = {.lex_state = 371},
  [12396] = {.lex_state = 371},
  [12397] = {.lex_state = 371},
  [12398] = {.lex_state = 371},
  [12399] = {.lex_state = 371},
  [12400] = {.lex_state = 371},
  [12401] = {.lex_state = 371},
  [12402] = {.lex_state = 371},
  [12403] = {.lex_state = 371},
  [12404] = {.lex_state = 371},
  [12405] = {.lex_state = 371},
  [12406] = {.lex_state = 371},
  [12407] = {.lex_state = 7},
  [12408] = {.lex_state = 371},
  [12409] = {.lex_state = 371},
  [12410] = {.lex_state = 7},
  [12411] = {.lex_state = 371},
  [12412] = {.lex_state = 371},
  [12413] = {.lex_state = 371},
  [12414] = {.lex_state = 43},
  [12415] = {.lex_state = 371},
  [12416] = {.lex_state = 371},
  [12417] = {.lex_state = 371},
  [12418] = {.lex_state = 371},
  [12419] = {.lex_state = 371},
  [12420] = {.lex_state = 371},
  [12421] = {.lex_state = 0},
  [12422] = {.lex_state = 7},
  [12423] = {.lex_state = 371},
  [12424] = {.lex_state = 41},
  [12425] = {.lex_state = 371},
  [12426] = {.lex_state = 371},
  [12427] = {.lex_state = 371},
  [12428] = {.lex_state = 371},
  [12429] = {.lex_state = 371},
  [12430] = {.lex_state = 371},
  [12431] = {.lex_state = 373},
  [12432] = {.lex_state = 371},
  [12433] = {.lex_state = 7},
  [12434] = {.lex_state = 371},
  [12435] = {.lex_state = 371},
  [12436] = {.lex_state = 371},
  [12437] = {.lex_state = 371},
  [12438] = {.lex_state = 371},
  [12439] = {.lex_state = 371},
  [12440] = {.lex_state = 7},
  [12441] = {.lex_state = 7},
  [12442] = {.lex_state = 7},
  [12443] = {.lex_state = 371},
  [12444] = {.lex_state = 371},
  [12445] = {.lex_state = 371},
  [12446] = {.lex_state = 371},
  [12447] = {.lex_state = 371},
  [12448] = {.lex_state = 371},
  [12449] = {.lex_state = 7},
  [12450] = {.lex_state = 7},
  [12451] = {.lex_state = 371},
  [12452] = {.lex_state = 7},
  [12453] = {.lex_state = 371},
  [12454] = {.lex_state = 371},
  [12455] = {.lex_state = 0},
  [12456] = {.lex_state = 7},
  [12457] = {.lex_state = 371},
  [12458] = {.lex_state = 371},
  [12459] = {.lex_state = 371},
  [12460] = {.lex_state = 371},
  [12461] = {.lex_state = 372},
  [12462] = {.lex_state = 43},
  [12463] = {.lex_state = 371},
  [12464] = {.lex_state = 371},
  [12465] = {.lex_state = 371},
  [12466] = {.lex_state = 371},
  [12467] = {.lex_state = 371},
  [12468] = {.lex_state = 371},
  [12469] = {.lex_state = 371},
  [12470] = {.lex_state = 7},
  [12471] = {.lex_state = 371},
  [12472] = {.lex_state = 371},
  [12473] = {.lex_state = 371},
  [12474] = {.lex_state = 371},
  [12475] = {.lex_state = 371},
  [12476] = {.lex_state = 7},
  [12477] = {.lex_state = 7},
  [12478] = {.lex_state = 43},
  [12479] = {.lex_state = 7},
  [12480] = {.lex_state = 371},
  [12481] = {.lex_state = 371},
  [12482] = {.lex_state = 371},
  [12483] = {.lex_state = 371},
  [12484] = {.lex_state = 371},
  [12485] = {.lex_state = 371},
  [12486] = {.lex_state = 371},
  [12487] = {.lex_state = 371},
  [12488] = {.lex_state = 371},
  [12489] = {.lex_state = 371},
  [12490] = {.lex_state = 371},
  [12491] = {.lex_state = 371},
  [12492] = {.lex_state = 371},
  [12493] = {.lex_state = 371},
  [12494] = {.lex_state = 371},
  [12495] = {.lex_state = 371},
  [12496] = {.lex_state = 371},
  [12497] = {.lex_state = 371},
  [12498] = {.lex_state = 0},
  [12499] = {.lex_state = 0},
  [12500] = {.lex_state = 373},
  [12501] = {.lex_state = 371},
  [12502] = {.lex_state = 371},
  [12503] = {.lex_state = 371},
  [12504] = {.lex_state = 371},
  [12505] = {.lex_state = 371},
  [12506] = {.lex_state = 371},
  [12507] = {.lex_state = 371},
  [12508] = {.lex_state = 371},
  [12509] = {.lex_state = 371},
  [12510] = {.lex_state = 373},
  [12511] = {.lex_state = 0},
  [12512] = {.lex_state = 371},
  [12513] = {.lex_state = 371},
  [12514] = {.lex_state = 371},
  [12515] = {.lex_state = 371},
  [12516] = {.lex_state = 371},
  [12517] = {.lex_state = 371},
  [12518] = {.lex_state = 371},
  [12519] = {.lex_state = 371},
  [12520] = {.lex_state = 43},
  [12521] = {.lex_state = 371},
  [12522] = {.lex_state = 371},
  [12523] = {.lex_state = 371},
  [12524] = {.lex_state = 371},
  [12525] = {.lex_state = 371},
  [12526] = {.lex_state = 371},
  [12527] = {.lex_state = 371},
  [12528] = {.lex_state = 371},
  [12529] = {.lex_state = 371},
  [12530] = {.lex_state = 371},
  [12531] = {.lex_state = 373},
  [12532] = {.lex_state = 371},
  [12533] = {.lex_state = 371},
  [12534] = {.lex_state = 373},
  [12535] = {.lex_state = 371},
  [12536] = {.lex_state = 373},
  [12537] = {.lex_state = 371},
  [12538] = {.lex_state = 371},
  [12539] = {.lex_state = 371},
  [12540] = {.lex_state = 371},
  [12541] = {.lex_state = 371},
  [12542] = {.lex_state = 63},
  [12543] = {.lex_state = 371},
  [12544] = {.lex_state = 63},
  [12545] = {.lex_state = 371},
  [12546] = {.lex_state = 371},
  [12547] = {.lex_state = 371},
  [12548] = {.lex_state = 371},
  [12549] = {.lex_state = 371},
  [12550] = {.lex_state = 371},
  [12551] = {.lex_state = 371},
  [12552] = {.lex_state = 371},
  [12553] = {.lex_state = 371},
  [12554] = {.lex_state = 371},
  [12555] = {.lex_state = 0},
  [12556] = {.lex_state = 371},
  [12557] = {.lex_state = 373},
  [12558] = {.lex_state = 371},
  [12559] = {.lex_state = 371},
  [12560] = {.lex_state = 371},
  [12561] = {.lex_state = 371},
  [12562] = {.lex_state = 371},
  [12563] = {.lex_state = 371},
  [12564] = {.lex_state = 371},
  [12565] = {.lex_state = 371},
  [12566] = {.lex_state = 371},
  [12567] = {.lex_state = 371},
  [12568] = {.lex_state = 371},
  [12569] = {.lex_state = 371},
  [12570] = {.lex_state = 371},
  [12571] = {.lex_state = 371},
  [12572] = {.lex_state = 371},
  [12573] = {.lex_state = 371},
  [12574] = {.lex_state = 371},
  [12575] = {.lex_state = 0},
  [12576] = {.lex_state = 371},
  [12577] = {.lex_state = 371},
  [12578] = {.lex_state = 371},
  [12579] = {.lex_state = 371},
  [12580] = {.lex_state = 371},
  [12581] = {.lex_state = 371},
  [12582] = {.lex_state = 371},
  [12583] = {.lex_state = 371},
  [12584] = {.lex_state = 371},
  [12585] = {.lex_state = 371},
  [12586] = {.lex_state = 373},
  [12587] = {.lex_state = 373},
  [12588] = {.lex_state = 371},
  [12589] = {.lex_state = 0},
  [12590] = {.lex_state = 371},
  [12591] = {.lex_state = 371},
  [12592] = {.lex_state = 371},
  [12593] = {.lex_state = 0},
  [12594] = {.lex_state = 371},
  [12595] = {.lex_state = 0},
  [12596] = {.lex_state = 371},
  [12597] = {.lex_state = 371},
  [12598] = {.lex_state = 371},
  [12599] = {.lex_state = 371},
  [12600] = {.lex_state = 371},
  [12601] = {.lex_state = 371},
  [12602] = {.lex_state = 371},
  [12603] = {.lex_state = 371},
  [12604] = {.lex_state = 371},
  [12605] = {.lex_state = 371},
  [12606] = {.lex_state = 371},
  [12607] = {.lex_state = 371},
  [12608] = {.lex_state = 371},
  [12609] = {.lex_state = 371},
  [12610] = {.lex_state = 371},
  [12611] = {.lex_state = 371},
  [12612] = {.lex_state = 372},
  [12613] = {.lex_state = 371},
  [12614] = {.lex_state = 371},
  [12615] = {.lex_state = 371},
  [12616] = {.lex_state = 0},
  [12617] = {.lex_state = 371},
  [12618] = {.lex_state = 371},
  [12619] = {.lex_state = 371},
  [12620] = {.lex_state = 371},
  [12621] = {.lex_state = 371},
  [12622] = {.lex_state = 371},
  [12623] = {.lex_state = 371},
  [12624] = {.lex_state = 371},
  [12625] = {.lex_state = 371},
  [12626] = {.lex_state = 371},
  [12627] = {.lex_state = 371},
  [12628] = {.lex_state = 371},
  [12629] = {.lex_state = 371},
  [12630] = {.lex_state = 371},
  [12631] = {.lex_state = 371},
  [12632] = {.lex_state = 371},
  [12633] = {.lex_state = 371},
  [12634] = {.lex_state = 371},
  [12635] = {.lex_state = 371},
  [12636] = {.lex_state = 371},
  [12637] = {.lex_state = 0},
  [12638] = {.lex_state = 371},
  [12639] = {.lex_state = 371},
  [12640] = {.lex_state = 371},
  [12641] = {.lex_state = 371},
  [12642] = {.lex_state = 371},
  [12643] = {.lex_state = 371},
  [12644] = {.lex_state = 371},
  [12645] = {.lex_state = 49},
  [12646] = {.lex_state = 371},
  [12647] = {.lex_state = 371},
  [12648] = {.lex_state = 371},
  [12649] = {.lex_state = 371},
  [12650] = {.lex_state = 371},
  [12651] = {.lex_state = 371},
  [12652] = {.lex_state = 371},
  [12653] = {.lex_state = 371},
  [12654] = {.lex_state = 371},
  [12655] = {.lex_state = 0},
  [12656] = {.lex_state = 371},
  [12657] = {.lex_state = 371},
  [12658] = {.lex_state = 371},
  [12659] = {.lex_state = 371},
  [12660] = {.lex_state = 371},
  [12661] = {.lex_state = 371},
  [12662] = {.lex_state = 371},
  [12663] = {.lex_state = 371},
  [12664] = {.lex_state = 371},
  [12665] = {.lex_state = 371},
  [12666] = {.lex_state = 371},
  [12667] = {.lex_state = 371},
  [12668] = {.lex_state = 371},
  [12669] = {.lex_state = 371},
  [12670] = {.lex_state = 371},
  [12671] = {.lex_state = 0},
  [12672] = {.lex_state = 371},
  [12673] = {.lex_state = 371},
  [12674] = {.lex_state = 371},
  [12675] = {.lex_state = 371},
  [12676] = {.lex_state = 371},
  [12677] = {.lex_state = 371},
  [12678] = {.lex_state = 371},
  [12679] = {.lex_state = 371},
  [12680] = {.lex_state = 371},
  [12681] = {.lex_state = 371},
  [12682] = {.lex_state = 371},
  [12683] = {.lex_state = 371},
  [12684] = {.lex_state = 371},
  [12685] = {.lex_state = 371},
  [12686] = {.lex_state = 371},
  [12687] = {.lex_state = 371},
  [12688] = {.lex_state = 371},
  [12689] = {.lex_state = 371},
  [12690] = {.lex_state = 371},
  [12691] = {.lex_state = 371},
  [12692] = {.lex_state = 371},
  [12693] = {.lex_state = 371},
  [12694] = {.lex_state = 371},
  [12695] = {.lex_state = 371},
  [12696] = {.lex_state = 371},
  [12697] = {.lex_state = 371},
  [12698] = {.lex_state = 371},
  [12699] = {.lex_state = 371},
  [12700] = {.lex_state = 371},
  [12701] = {.lex_state = 371},
  [12702] = {.lex_state = 371},
  [12703] = {.lex_state = 371},
  [12704] = {.lex_state = 371},
  [12705] = {.lex_state = 371},
  [12706] = {.lex_state = 371},
  [12707] = {.lex_state = 371},
  [12708] = {.lex_state = 371},
  [12709] = {.lex_state = 371},
  [12710] = {.lex_state = 371},
  [12711] = {.lex_state = 371},
  [12712] = {.lex_state = 371},
  [12713] = {.lex_state = 371},
  [12714] = {.lex_state = 371},
  [12715] = {.lex_state = 371},
  [12716] = {.lex_state = 371},
  [12717] = {.lex_state = 371},
  [12718] = {.lex_state = 371},
  [12719] = {.lex_state = 371},
  [12720] = {.lex_state = 371},
  [12721] = {.lex_state = 371},
  [12722] = {.lex_state = 373},
  [12723] = {.lex_state = 371},
  [12724] = {.lex_state = 371},
  [12725] = {.lex_state = 371},
  [12726] = {.lex_state = 371},
  [12727] = {.lex_state = 371},
  [12728] = {.lex_state = 371},
  [12729] = {.lex_state = 371},
  [12730] = {.lex_state = 371},
  [12731] = {.lex_state = 371},
  [12732] = {.lex_state = 371},
  [12733] = {.lex_state = 371},
  [12734] = {.lex_state = 371},
  [12735] = {.lex_state = 371},
  [12736] = {.lex_state = 371},
  [12737] = {.lex_state = 371},
  [12738] = {.lex_state = 371},
  [12739] = {.lex_state = 371},
  [12740] = {.lex_state = 371},
  [12741] = {.lex_state = 371},
  [12742] = {.lex_state = 371},
  [12743] = {.lex_state = 371},
  [12744] = {.lex_state = 371},
  [12745] = {.lex_state = 371},
  [12746] = {.lex_state = 371},
  [12747] = {.lex_state = 371},
  [12748] = {.lex_state = 371},
  [12749] = {.lex_state = 371},
  [12750] = {.lex_state = 371},
  [12751] = {.lex_state = 371},
  [12752] = {.lex_state = 371},
  [12753] = {.lex_state = 371},
  [12754] = {.lex_state = 371},
  [12755] = {.lex_state = 371},
  [12756] = {.lex_state = 371},
  [12757] = {.lex_state = 63},
  [12758] = {.lex_state = 371},
  [12759] = {.lex_state = 371},
  [12760] = {.lex_state = 371},
  [12761] = {.lex_state = 371},
  [12762] = {.lex_state = 371},
  [12763] = {.lex_state = 371},
  [12764] = {.lex_state = 371},
  [12765] = {.lex_state = 371},
  [12766] = {.lex_state = 371},
  [12767] = {.lex_state = 371},
  [12768] = {.lex_state = 371},
  [12769] = {.lex_state = 371},
  [12770] = {.lex_state = 41},
  [12771] = {.lex_state = 371},
  [12772] = {.lex_state = 371},
  [12773] = {.lex_state = 371},
  [12774] = {.lex_state = 371},
  [12775] = {.lex_state = 371},
  [12776] = {.lex_state = 371},
  [12777] = {.lex_state = 371},
  [12778] = {.lex_state = 371},
  [12779] = {.lex_state = 371},
  [12780] = {.lex_state = 371},
  [12781] = {.lex_state = 371},
  [12782] = {.lex_state = 371},
  [12783] = {.lex_state = 371},
  [12784] = {.lex_state = 371},
  [12785] = {.lex_state = 371},
  [12786] = {.lex_state = 371},
  [12787] = {.lex_state = 371},
  [12788] = {.lex_state = 371},
  [12789] = {.lex_state = 371},
  [12790] = {.lex_state = 371},
  [12791] = {.lex_state = 371},
  [12792] = {.lex_state = 371},
  [12793] = {.lex_state = 371},
  [12794] = {.lex_state = 371},
  [12795] = {.lex_state = 373},
  [12796] = {.lex_state = 371},
  [12797] = {.lex_state = 371},
  [12798] = {.lex_state = 371},
  [12799] = {.lex_state = 371},
  [12800] = {.lex_state = 371},
  [12801] = {.lex_state = 0},
  [12802] = {.lex_state = 371},
  [12803] = {.lex_state = 0},
  [12804] = {.lex_state = 371},
  [12805] = {.lex_state = 371},
  [12806] = {.lex_state = 0},
  [12807] = {.lex_state = 371},
  [12808] = {.lex_state = 372},
  [12809] = {.lex_state = 0},
  [12810] = {.lex_state = 371},
  [12811] = {.lex_state = 371},
  [12812] = {.lex_state = 371},
  [12813] = {.lex_state = 371},
  [12814] = {.lex_state = 371},
  [12815] = {.lex_state = 371},
  [12816] = {.lex_state = 371},
  [12817] = {.lex_state = 7},
  [12818] = {.lex_state = 372},
  [12819] = {.lex_state = 371},
  [12820] = {.lex_state = 371},
  [12821] = {.lex_state = 371},
  [12822] = {.lex_state = 371},
  [12823] = {.lex_state = 371},
  [12824] = {.lex_state = 371},
  [12825] = {.lex_state = 371},
  [12826] = {.lex_state = 371},
  [12827] = {.lex_state = 372},
  [12828] = {.lex_state = 372},
  [12829] = {.lex_state = 372},
  [12830] = {.lex_state = 372},
  [12831] = {.lex_state = 371},
  [12832] = {.lex_state = 371},
  [12833] = {.lex_state = 371},
  [12834] = {.lex_state = 371},
  [12835] = {.lex_state = 371},
  [12836] = {.lex_state = 371},
  [12837] = {.lex_state = 371},
  [12838] = {.lex_state = 371},
  [12839] = {.lex_state = 371},
  [12840] = {.lex_state = 371},
  [12841] = {.lex_state = 371},
  [12842] = {.lex_state = 371},
  [12843] = {.lex_state = 371},
  [12844] = {.lex_state = 371},
  [12845] = {.lex_state = 371},
  [12846] = {.lex_state = 371},
  [12847] = {.lex_state = 371},
  [12848] = {.lex_state = 371},
  [12849] = {.lex_state = 371},
  [12850] = {.lex_state = 371},
  [12851] = {.lex_state = 371},
  [12852] = {.lex_state = 371},
  [12853] = {.lex_state = 371},
  [12854] = {.lex_state = 371},
  [12855] = {.lex_state = 372},
  [12856] = {.lex_state = 371},
  [12857] = {.lex_state = 371},
  [12858] = {.lex_state = 371},
  [12859] = {.lex_state = 371},
  [12860] = {.lex_state = 371},
  [12861] = {.lex_state = 371},
  [12862] = {.lex_state = 371},
  [12863] = {.lex_state = 0},
  [12864] = {.lex_state = 371},
  [12865] = {.lex_state = 371},
  [12866] = {.lex_state = 371},
  [12867] = {.lex_state = 371},
  [12868] = {.lex_state = 371},
  [12869] = {.lex_state = 371},
  [12870] = {.lex_state = 371},
  [12871] = {.lex_state = 371},
  [12872] = {.lex_state = 371},
  [12873] = {.lex_state = 371},
  [12874] = {.lex_state = 371},
  [12875] = {.lex_state = 373},
  [12876] = {.lex_state = 371},
  [12877] = {.lex_state = 371},
  [12878] = {.lex_state = 371},
  [12879] = {.lex_state = 371},
  [12880] = {.lex_state = 371},
  [12881] = {.lex_state = 371},
  [12882] = {.lex_state = 371},
  [12883] = {.lex_state = 371},
  [12884] = {.lex_state = 371},
  [12885] = {.lex_state = 0},
  [12886] = {.lex_state = 371},
  [12887] = {.lex_state = 371},
  [12888] = {.lex_state = 371},
  [12889] = {.lex_state = 371},
  [12890] = {.lex_state = 371},
  [12891] = {.lex_state = 371},
  [12892] = {.lex_state = 371},
  [12893] = {.lex_state = 371},
  [12894] = {.lex_state = 0},
  [12895] = {.lex_state = 371},
  [12896] = {.lex_state = 371},
  [12897] = {.lex_state = 371},
  [12898] = {.lex_state = 371},
  [12899] = {.lex_state = 371},
  [12900] = {.lex_state = 371},
  [12901] = {.lex_state = 371},
  [12902] = {.lex_state = 371},
  [12903] = {.lex_state = 371},
  [12904] = {.lex_state = 371},
  [12905] = {.lex_state = 371},
  [12906] = {.lex_state = 371},
  [12907] = {.lex_state = 0},
  [12908] = {.lex_state = 371},
  [12909] = {.lex_state = 371},
  [12910] = {.lex_state = 371},
  [12911] = {.lex_state = 371},
  [12912] = {.lex_state = 373},
  [12913] = {.lex_state = 371},
  [12914] = {.lex_state = 373},
  [12915] = {.lex_state = 371},
  [12916] = {.lex_state = 371},
  [12917] = {.lex_state = 371},
  [12918] = {.lex_state = 371},
  [12919] = {.lex_state = 371},
  [12920] = {.lex_state = 371},
  [12921] = {.lex_state = 371},
  [12922] = {.lex_state = 371},
  [12923] = {.lex_state = 371},
  [12924] = {.lex_state = 371},
  [12925] = {.lex_state = 371},
  [12926] = {.lex_state = 371},
  [12927] = {.lex_state = 371},
  [12928] = {.lex_state = 371},
  [12929] = {.lex_state = 51},
  [12930] = {.lex_state = 371},
  [12931] = {.lex_state = 371},
  [12932] = {.lex_state = 371},
  [12933] = {.lex_state = 371},
  [12934] = {.lex_state = 51},
  [12935] = {.lex_state = 371},
  [12936] = {.lex_state = 371},
  [12937] = {.lex_state = 371},
  [12938] = {.lex_state = 371},
  [12939] = {.lex_state = 371},
  [12940] = {.lex_state = 371},
  [12941] = {.lex_state = 371},
  [12942] = {.lex_state = 371},
  [12943] = {.lex_state = 371},
  [12944] = {.lex_state = 371},
  [12945] = {.lex_state = 371},
  [12946] = {.lex_state = 371},
  [12947] = {.lex_state = 0},
  [12948] = {.lex_state = 371},
  [12949] = {.lex_state = 371},
  [12950] = {.lex_state = 371},
  [12951] = {.lex_state = 371},
  [12952] = {.lex_state = 371},
  [12953] = {.lex_state = 373},
  [12954] = {.lex_state = 371},
  [12955] = {.lex_state = 371},
  [12956] = {.lex_state = 371},
  [12957] = {.lex_state = 371},
  [12958] = {.lex_state = 0},
  [12959] = {.lex_state = 371},
  [12960] = {.lex_state = 371},
  [12961] = {.lex_state = 371},
  [12962] = {.lex_state = 371},
  [12963] = {.lex_state = 371},
  [12964] = {.lex_state = 371},
  [12965] = {.lex_state = 371},
  [12966] = {.lex_state = 371},
  [12967] = {.lex_state = 371},
  [12968] = {.lex_state = 51},
  [12969] = {.lex_state = 371},
  [12970] = {.lex_state = 371},
  [12971] = {.lex_state = 371},
  [12972] = {.lex_state = 51},
  [12973] = {.lex_state = 371},
  [12974] = {.lex_state = 371},
  [12975] = {.lex_state = 371},
  [12976] = {.lex_state = 371},
  [12977] = {.lex_state = 371},
  [12978] = {.lex_state = 371},
  [12979] = {.lex_state = 371},
  [12980] = {.lex_state = 371},
  [12981] = {.lex_state = 371},
  [12982] = {.lex_state = 371},
  [12983] = {.lex_state = 371},
  [12984] = {.lex_state = 371},
  [12985] = {.lex_state = 371},
  [12986] = {.lex_state = 371},
  [12987] = {.lex_state = 371},
  [12988] = {.lex_state = 371},
  [12989] = {.lex_state = 51},
  [12990] = {.lex_state = 371},
  [12991] = {.lex_state = 371},
  [12992] = {.lex_state = 51},
  [12993] = {.lex_state = 371},
  [12994] = {.lex_state = 371},
  [12995] = {.lex_state = 371},
  [12996] = {.lex_state = 371},
  [12997] = {.lex_state = 371},
  [12998] = {.lex_state = 371},
  [12999] = {.lex_state = 371},
  [13000] = {.lex_state = 371},
  [13001] = {.lex_state = 371},
  [13002] = {.lex_state = 371},
  [13003] = {.lex_state = 371},
  [13004] = {.lex_state = 371},
  [13005] = {.lex_state = 371},
  [13006] = {.lex_state = 371},
  [13007] = {.lex_state = 371},
  [13008] = {.lex_state = 371},
  [13009] = {.lex_state = 371},
  [13010] = {.lex_state = 371},
  [13011] = {.lex_state = 371},
  [13012] = {.lex_state = 373},
  [13013] = {.lex_state = 371},
  [13014] = {.lex_state = 371},
  [13015] = {.lex_state = 371},
  [13016] = {.lex_state = 371},
  [13017] = {.lex_state = 371},
  [13018] = {.lex_state = 371},
  [13019] = {.lex_state = 371},
  [13020] = {.lex_state = 371},
  [13021] = {.lex_state = 371},
  [13022] = {.lex_state = 371},
  [13023] = {.lex_state = 371},
  [13024] = {.lex_state = 371},
  [13025] = {.lex_state = 371},
  [13026] = {.lex_state = 371},
  [13027] = {.lex_state = 0},
  [13028] = {.lex_state = 371},
  [13029] = {.lex_state = 371},
  [13030] = {.lex_state = 371},
  [13031] = {.lex_state = 371},
  [13032] = {.lex_state = 371},
  [13033] = {.lex_state = 371},
  [13034] = {.lex_state = 371},
  [13035] = {.lex_state = 371},
  [13036] = {.lex_state = 371},
  [13037] = {.lex_state = 371},
  [13038] = {.lex_state = 371},
  [13039] = {.lex_state = 371},
  [13040] = {.lex_state = 371},
  [13041] = {.lex_state = 0},
  [13042] = {.lex_state = 371},
  [13043] = {.lex_state = 371},
  [13044] = {.lex_state = 371},
  [13045] = {.lex_state = 371},
  [13046] = {.lex_state = 371},
  [13047] = {.lex_state = 371},
  [13048] = {.lex_state = 371},
  [13049] = {.lex_state = 371},
  [13050] = {.lex_state = 371},
  [13051] = {.lex_state = 371},
  [13052] = {.lex_state = 371},
  [13053] = {.lex_state = 371},
  [13054] = {.lex_state = 371},
  [13055] = {.lex_state = 371},
  [13056] = {.lex_state = 373},
  [13057] = {.lex_state = 371},
  [13058] = {.lex_state = 371},
  [13059] = {.lex_state = 371},
  [13060] = {.lex_state = 371},
  [13061] = {.lex_state = 371},
  [13062] = {.lex_state = 371},
  [13063] = {.lex_state = 371},
  [13064] = {.lex_state = 371},
  [13065] = {.lex_state = 371},
  [13066] = {.lex_state = 371},
  [13067] = {.lex_state = 371},
  [13068] = {.lex_state = 371},
  [13069] = {.lex_state = 371},
  [13070] = {.lex_state = 371},
  [13071] = {.lex_state = 371},
  [13072] = {.lex_state = 371},
  [13073] = {.lex_state = 371},
  [13074] = {.lex_state = 371},
  [13075] = {.lex_state = 371},
  [13076] = {.lex_state = 371},
  [13077] = {.lex_state = 371},
  [13078] = {.lex_state = 371},
  [13079] = {.lex_state = 371},
  [13080] = {.lex_state = 371},
  [13081] = {.lex_state = 371},
  [13082] = {.lex_state = 373},
  [13083] = {.lex_state = 373},
  [13084] = {.lex_state = 371},
  [13085] = {.lex_state = 371},
  [13086] = {.lex_state = 371},
  [13087] = {.lex_state = 371},
  [13088] = {.lex_state = 371},
  [13089] = {.lex_state = 371},
  [13090] = {.lex_state = 371},
  [13091] = {.lex_state = 371},
  [13092] = {.lex_state = 371},
  [13093] = {.lex_state = 371},
  [13094] = {.lex_state = 371},
  [13095] = {.lex_state = 371},
  [13096] = {.lex_state = 371},
  [13097] = {.lex_state = 371},
  [13098] = {.lex_state = 371},
  [13099] = {.lex_state = 371},
  [13100] = {.lex_state = 371},
  [13101] = {.lex_state = 371},
  [13102] = {.lex_state = 371},
  [13103] = {.lex_state = 371},
  [13104] = {.lex_state = 371},
  [13105] = {.lex_state = 0},
  [13106] = {.lex_state = 371},
  [13107] = {.lex_state = 371},
  [13108] = {.lex_state = 371},
  [13109] = {.lex_state = 371},
  [13110] = {.lex_state = 371},
  [13111] = {.lex_state = 371},
  [13112] = {.lex_state = 371},
  [13113] = {.lex_state = 371},
  [13114] = {.lex_state = 371},
  [13115] = {.lex_state = 373},
  [13116] = {.lex_state = 371},
  [13117] = {.lex_state = 371},
  [13118] = {.lex_state = 371},
  [13119] = {.lex_state = 371},
  [13120] = {.lex_state = 371},
  [13121] = {.lex_state = 371},
  [13122] = {.lex_state = 371},
  [13123] = {.lex_state = 371},
  [13124] = {.lex_state = 371},
  [13125] = {.lex_state = 371},
  [13126] = {.lex_state = 371},
  [13127] = {.lex_state = 371},
  [13128] = {.lex_state = 371},
  [13129] = {.lex_state = 371},
  [13130] = {.lex_state = 371},
  [13131] = {.lex_state = 371},
  [13132] = {.lex_state = 371},
  [13133] = {.lex_state = 371},
  [13134] = {.lex_state = 371},
  [13135] = {.lex_state = 7},
  [13136] = {.lex_state = 371},
  [13137] = {.lex_state = 371},
  [13138] = {.lex_state = 371},
  [13139] = {.lex_state = 371},
  [13140] = {.lex_state = 51},
  [13141] = {.lex_state = 371},
  [13142] = {.lex_state = 371},
  [13143] = {.lex_state = 371},
  [13144] = {.lex_state = 371},
  [13145] = {.lex_state = 51},
  [13146] = {.lex_state = 371},
  [13147] = {.lex_state = 371},
  [13148] = {.lex_state = 371},
  [13149] = {.lex_state = 371},
  [13150] = {.lex_state = 42},
  [13151] = {.lex_state = 371},
  [13152] = {.lex_state = 371},
  [13153] = {.lex_state = 371},
  [13154] = {.lex_state = 371},
  [13155] = {.lex_state = 371},
  [13156] = {.lex_state = 371},
  [13157] = {.lex_state = 371},
  [13158] = {.lex_state = 371},
  [13159] = {.lex_state = 371},
  [13160] = {.lex_state = 371},
  [13161] = {.lex_state = 51},
  [13162] = {.lex_state = 373},
  [13163] = {.lex_state = 371},
  [13164] = {.lex_state = 371},
  [13165] = {.lex_state = 371},
  [13166] = {.lex_state = 371},
  [13167] = {.lex_state = 371},
  [13168] = {.lex_state = 371},
  [13169] = {.lex_state = 371},
  [13170] = {.lex_state = 371},
  [13171] = {.lex_state = 371},
  [13172] = {.lex_state = 371},
  [13173] = {.lex_state = 371},
  [13174] = {.lex_state = 371},
  [13175] = {.lex_state = 371},
  [13176] = {.lex_state = 371},
  [13177] = {.lex_state = 371},
  [13178] = {.lex_state = 371},
  [13179] = {.lex_state = 371},
  [13180] = {.lex_state = 371},
  [13181] = {.lex_state = 371},
  [13182] = {.lex_state = 371},
  [13183] = {.lex_state = 371},
  [13184] = {.lex_state = 7},
  [13185] = {.lex_state = 7},
  [13186] = {.lex_state = 371},
  [13187] = {.lex_state = 371},
  [13188] = {.lex_state = 371},
  [13189] = {.lex_state = 371},
  [13190] = {.lex_state = 371},
  [13191] = {.lex_state = 371},
  [13192] = {.lex_state = 371},
  [13193] = {.lex_state = 371},
  [13194] = {.lex_state = 371},
  [13195] = {.lex_state = 371},
  [13196] = {.lex_state = 371},
  [13197] = {.lex_state = 371},
  [13198] = {.lex_state = 371},
  [13199] = {.lex_state = 371},
  [13200] = {.lex_state = 371},
  [13201] = {.lex_state = 7},
  [13202] = {.lex_state = 371},
  [13203] = {.lex_state = 371},
  [13204] = {.lex_state = 371},
  [13205] = {.lex_state = 371},
  [13206] = {.lex_state = 371},
  [13207] = {.lex_state = 371},
  [13208] = {.lex_state = 371},
  [13209] = {.lex_state = 371},
  [13210] = {.lex_state = 371},
  [13211] = {.lex_state = 371},
  [13212] = {.lex_state = 51},
  [13213] = {.lex_state = 371},
  [13214] = {.lex_state = 371},
  [13215] = {.lex_state = 371},
  [13216] = {.lex_state = 371},
  [13217] = {.lex_state = 371},
  [13218] = {.lex_state = 371},
  [13219] = {.lex_state = 371},
  [13220] = {.lex_state = 371},
  [13221] = {.lex_state = 371},
  [13222] = {.lex_state = 371},
  [13223] = {.lex_state = 371},
  [13224] = {.lex_state = 371},
  [13225] = {.lex_state = 371},
  [13226] = {.lex_state = 371},
  [13227] = {.lex_state = 371},
  [13228] = {.lex_state = 371},
  [13229] = {.lex_state = 371},
  [13230] = {.lex_state = 371},
  [13231] = {.lex_state = 371},
  [13232] = {.lex_state = 371},
  [13233] = {.lex_state = 371},
  [13234] = {.lex_state = 371},
  [13235] = {.lex_state = 371},
  [13236] = {.lex_state = 371},
  [13237] = {.lex_state = 371},
  [13238] = {.lex_state = 371},
  [13239] = {.lex_state = 371},
  [13240] = {.lex_state = 371},
  [13241] = {.lex_state = 371},
  [13242] = {.lex_state = 371},
  [13243] = {.lex_state = 371},
  [13244] = {.lex_state = 371},
  [13245] = {.lex_state = 51},
  [13246] = {.lex_state = 371},
  [13247] = {.lex_state = 371},
  [13248] = {.lex_state = 371},
  [13249] = {.lex_state = 371},
  [13250] = {.lex_state = 371},
  [13251] = {.lex_state = 371},
  [13252] = {.lex_state = 371},
  [13253] = {.lex_state = 371},
  [13254] = {.lex_state = 371},
  [13255] = {.lex_state = 371},
  [13256] = {.lex_state = 371},
  [13257] = {.lex_state = 371},
  [13258] = {.lex_state = 371},
  [13259] = {.lex_state = 371},
  [13260] = {.lex_state = 371},
  [13261] = {.lex_state = 371},
  [13262] = {.lex_state = 371},
  [13263] = {.lex_state = 371},
  [13264] = {.lex_state = 371},
  [13265] = {.lex_state = 371},
  [13266] = {.lex_state = 371},
  [13267] = {.lex_state = 371},
  [13268] = {.lex_state = 371},
  [13269] = {.lex_state = 371},
  [13270] = {.lex_state = 371},
  [13271] = {.lex_state = 371},
  [13272] = {.lex_state = 371},
  [13273] = {.lex_state = 371},
  [13274] = {.lex_state = 371},
  [13275] = {.lex_state = 371},
  [13276] = {.lex_state = 371},
  [13277] = {.lex_state = 371},
  [13278] = {.lex_state = 371},
  [13279] = {.lex_state = 371},
  [13280] = {.lex_state = 371},
  [13281] = {.lex_state = 371},
  [13282] = {.lex_state = 371},
  [13283] = {.lex_state = 0},
  [13284] = {.lex_state = 373},
  [13285] = {.lex_state = 371},
  [13286] = {.lex_state = 371},
  [13287] = {.lex_state = 8},
  [13288] = {.lex_state = 371},
  [13289] = {.lex_state = 373},
  [13290] = {.lex_state = 371},
  [13291] = {.lex_state = 371},
  [13292] = {.lex_state = 371},
  [13293] = {.lex_state = 371},
  [13294] = {.lex_state = 371},
  [13295] = {.lex_state = 371},
  [13296] = {.lex_state = 371},
  [13297] = {.lex_state = 371},
  [13298] = {.lex_state = 371},
  [13299] = {.lex_state = 371},
  [13300] = {.lex_state = 371},
  [13301] = {.lex_state = 371},
  [13302] = {.lex_state = 371},
  [13303] = {.lex_state = 371},
  [13304] = {.lex_state = 371},
  [13305] = {.lex_state = 371},
  [13306] = {.lex_state = 371},
  [13307] = {.lex_state = 371},
  [13308] = {.lex_state = 371},
  [13309] = {.lex_state = 371},
  [13310] = {.lex_state = 51},
  [13311] = {.lex_state = 371},
  [13312] = {.lex_state = 371},
  [13313] = {.lex_state = 371},
  [13314] = {.lex_state = 371},
  [13315] = {.lex_state = 371},
  [13316] = {.lex_state = 371},
  [13317] = {.lex_state = 371},
  [13318] = {.lex_state = 371},
  [13319] = {.lex_state = 371},
  [13320] = {.lex_state = 371},
  [13321] = {.lex_state = 371},
  [13322] = {.lex_state = 371},
  [13323] = {.lex_state = 371},
  [13324] = {.lex_state = 371},
  [13325] = {.lex_state = 371},
  [13326] = {.lex_state = 371},
  [13327] = {.lex_state = 371},
  [13328] = {.lex_state = 371},
  [13329] = {.lex_state = 371},
  [13330] = {.lex_state = 371},
  [13331] = {.lex_state = 371},
  [13332] = {.lex_state = 371},
  [13333] = {.lex_state = 371},
  [13334] = {.lex_state = 371},
  [13335] = {.lex_state = 371},
  [13336] = {.lex_state = 371},
  [13337] = {.lex_state = 371},
  [13338] = {.lex_state = 43},
  [13339] = {.lex_state = 371},
  [13340] = {.lex_state = 371},
  [13341] = {.lex_state = 371},
  [13342] = {.lex_state = 371},
  [13343] = {.lex_state = 371},
  [13344] = {.lex_state = 371},
  [13345] = {.lex_state = 371},
  [13346] = {.lex_state = 371},
  [13347] = {.lex_state = 371},
  [13348] = {.lex_state = 371},
  [13349] = {.lex_state = 371},
  [13350] = {.lex_state = 371},
  [13351] = {.lex_state = 371},
  [13352] = {.lex_state = 371},
  [13353] = {.lex_state = 371},
  [13354] = {.lex_state = 371},
  [13355] = {.lex_state = 371},
  [13356] = {.lex_state = 371},
  [13357] = {.lex_state = 371},
  [13358] = {.lex_state = 371},
  [13359] = {.lex_state = 371},
  [13360] = {.lex_state = 371},
  [13361] = {.lex_state = 0},
  [13362] = {.lex_state = 371},
  [13363] = {.lex_state = 371},
  [13364] = {.lex_state = 371},
  [13365] = {.lex_state = 371},
  [13366] = {.lex_state = 371},
  [13367] = {.lex_state = 371},
  [13368] = {.lex_state = 371},
  [13369] = {.lex_state = 371},
  [13370] = {.lex_state = 371},
  [13371] = {.lex_state = 371},
  [13372] = {.lex_state = 371},
  [13373] = {.lex_state = 371},
  [13374] = {.lex_state = 371},
  [13375] = {.lex_state = 371},
  [13376] = {.lex_state = 371},
  [13377] = {.lex_state = 371},
  [13378] = {.lex_state = 371},
  [13379] = {.lex_state = 371},
  [13380] = {.lex_state = 0},
  [13381] = {.lex_state = 371},
  [13382] = {.lex_state = 371},
  [13383] = {.lex_state = 371},
  [13384] = {.lex_state = 371},
  [13385] = {.lex_state = 371},
  [13386] = {.lex_state = 371},
  [13387] = {.lex_state = 371},
  [13388] = {.lex_state = 371},
  [13389] = {.lex_state = 371},
  [13390] = {.lex_state = 371},
  [13391] = {.lex_state = 371},
  [13392] = {.lex_state = 371},
  [13393] = {.lex_state = 371},
  [13394] = {.lex_state = 371},
  [13395] = {.lex_state = 371},
  [13396] = {.lex_state = 371},
  [13397] = {.lex_state = 371},
  [13398] = {.lex_state = 371},
  [13399] = {.lex_state = 371},
  [13400] = {.lex_state = 371},
  [13401] = {.lex_state = 371},
  [13402] = {.lex_state = 371},
  [13403] = {.lex_state = 371},
  [13404] = {.lex_state = 371},
  [13405] = {.lex_state = 371},
  [13406] = {.lex_state = 371},
  [13407] = {.lex_state = 51},
  [13408] = {.lex_state = 371},
  [13409] = {.lex_state = 371},
  [13410] = {.lex_state = 371},
  [13411] = {.lex_state = 371},
  [13412] = {.lex_state = 371},
  [13413] = {.lex_state = 371},
  [13414] = {.lex_state = 371},
  [13415] = {.lex_state = 371},
  [13416] = {.lex_state = 371},
  [13417] = {.lex_state = 371},
  [13418] = {.lex_state = 371},
  [13419] = {.lex_state = 371},
  [13420] = {.lex_state = 371},
  [13421] = {.lex_state = 371},
  [13422] = {.lex_state = 371},
  [13423] = {.lex_state = 371},
  [13424] = {.lex_state = 371},
  [13425] = {.lex_state = 371},
  [13426] = {.lex_state = 7},
  [13427] = {.lex_state = 371},
  [13428] = {.lex_state = 371},
  [13429] = {.lex_state = 371},
  [13430] = {.lex_state = 371},
  [13431] = {.lex_state = 371},
  [13432] = {.lex_state = 371},
  [13433] = {.lex_state = 7},
  [13434] = {.lex_state = 371},
  [13435] = {.lex_state = 371},
  [13436] = {.lex_state = 371},
  [13437] = {.lex_state = 7},
  [13438] = {.lex_state = 371},
  [13439] = {.lex_state = 51},
  [13440] = {.lex_state = 371},
  [13441] = {.lex_state = 371},
  [13442] = {.lex_state = 371},
  [13443] = {.lex_state = 371},
  [13444] = {.lex_state = 371},
  [13445] = {.lex_state = 371},
  [13446] = {.lex_state = 371},
  [13447] = {.lex_state = 371},
  [13448] = {.lex_state = 371},
  [13449] = {.lex_state = 371},
  [13450] = {.lex_state = 371},
  [13451] = {.lex_state = 0},
  [13452] = {.lex_state = 371},
  [13453] = {.lex_state = 371},
  [13454] = {.lex_state = 371},
  [13455] = {.lex_state = 371},
  [13456] = {.lex_state = 371},
  [13457] = {.lex_state = 371},
  [13458] = {.lex_state = 371},
  [13459] = {.lex_state = 371},
  [13460] = {.lex_state = 371},
  [13461] = {.lex_state = 371},
  [13462] = {.lex_state = 371},
  [13463] = {.lex_state = 371},
  [13464] = {.lex_state = 371},
  [13465] = {.lex_state = 371},
  [13466] = {.lex_state = 371},
  [13467] = {.lex_state = 371},
  [13468] = {.lex_state = 371},
  [13469] = {.lex_state = 371},
  [13470] = {.lex_state = 371},
  [13471] = {.lex_state = 371},
  [13472] = {.lex_state = 371},
  [13473] = {.lex_state = 371},
  [13474] = {.lex_state = 371},
  [13475] = {.lex_state = 371},
  [13476] = {.lex_state = 371},
  [13477] = {.lex_state = 371},
  [13478] = {.lex_state = 371},
  [13479] = {.lex_state = 371},
  [13480] = {.lex_state = 371},
  [13481] = {.lex_state = 371},
  [13482] = {.lex_state = 371},
  [13483] = {.lex_state = 371},
  [13484] = {.lex_state = 371},
  [13485] = {.lex_state = 371},
  [13486] = {.lex_state = 371},
  [13487] = {.lex_state = 371},
  [13488] = {.lex_state = 7},
  [13489] = {.lex_state = 371},
  [13490] = {.lex_state = 371},
  [13491] = {.lex_state = 371},
  [13492] = {.lex_state = 371},
  [13493] = {.lex_state = 371},
  [13494] = {.lex_state = 371},
  [13495] = {.lex_state = 371},
  [13496] = {.lex_state = 371},
  [13497] = {.lex_state = 371},
  [13498] = {.lex_state = 371},
  [13499] = {.lex_state = 371},
  [13500] = {.lex_state = 371},
  [13501] = {.lex_state = 371},
  [13502] = {.lex_state = 371},
  [13503] = {.lex_state = 371},
  [13504] = {.lex_state = 371},
  [13505] = {.lex_state = 371},
  [13506] = {.lex_state = 371},
  [13507] = {.lex_state = 371},
  [13508] = {.lex_state = 371},
  [13509] = {.lex_state = 371},
  [13510] = {.lex_state = 373},
  [13511] = {.lex_state = 371},
  [13512] = {.lex_state = 371},
  [13513] = {.lex_state = 371},
  [13514] = {.lex_state = 371},
  [13515] = {.lex_state = 371},
  [13516] = {.lex_state = 371},
  [13517] = {.lex_state = 371},
  [13518] = {.lex_state = 371},
  [13519] = {.lex_state = 371},
  [13520] = {.lex_state = 371},
  [13521] = {.lex_state = 371},
  [13522] = {.lex_state = 371},
  [13523] = {.lex_state = 371},
  [13524] = {.lex_state = 371},
  [13525] = {.lex_state = 371},
  [13526] = {.lex_state = 371},
  [13527] = {.lex_state = 371},
  [13528] = {.lex_state = 371},
  [13529] = {.lex_state = 371},
  [13530] = {.lex_state = 371},
  [13531] = {.lex_state = 371},
  [13532] = {.lex_state = 371},
  [13533] = {.lex_state = 371},
  [13534] = {.lex_state = 371},
  [13535] = {.lex_state = 371},
  [13536] = {.lex_state = 371},
  [13537] = {.lex_state = 371},
  [13538] = {.lex_state = 371},
  [13539] = {.lex_state = 371},
  [13540] = {.lex_state = 371},
  [13541] = {.lex_state = 371},
  [13542] = {.lex_state = 371},
  [13543] = {.lex_state = 371},
  [13544] = {.lex_state = 371},
  [13545] = {.lex_state = 371},
  [13546] = {.lex_state = 371},
  [13547] = {.lex_state = 371},
  [13548] = {.lex_state = 371},
  [13549] = {.lex_state = 371},
  [13550] = {.lex_state = 371},
  [13551] = {.lex_state = 371},
  [13552] = {.lex_state = 371},
  [13553] = {.lex_state = 371},
  [13554] = {.lex_state = 371},
  [13555] = {.lex_state = 371},
  [13556] = {.lex_state = 371},
  [13557] = {.lex_state = 371},
  [13558] = {.lex_state = 371},
  [13559] = {.lex_state = 371},
  [13560] = {.lex_state = 371},
  [13561] = {.lex_state = 371},
  [13562] = {.lex_state = 371},
  [13563] = {.lex_state = 371},
  [13564] = {.lex_state = 371},
  [13565] = {.lex_state = 371},
  [13566] = {.lex_state = 371},
  [13567] = {.lex_state = 371},
  [13568] = {.lex_state = 371},
  [13569] = {.lex_state = 371},
  [13570] = {.lex_state = 371},
  [13571] = {.lex_state = 371},
  [13572] = {.lex_state = 371},
  [13573] = {.lex_state = 371},
  [13574] = {.lex_state = 371},
  [13575] = {.lex_state = 371},
  [13576] = {.lex_state = 371},
  [13577] = {.lex_state = 371},
  [13578] = {.lex_state = 371},
  [13579] = {.lex_state = 0},
  [13580] = {.lex_state = 371},
  [13581] = {.lex_state = 371},
  [13582] = {.lex_state = 371},
  [13583] = {.lex_state = 371},
  [13584] = {.lex_state = 371},
  [13585] = {.lex_state = 371},
  [13586] = {.lex_state = 371},
  [13587] = {.lex_state = 371},
  [13588] = {.lex_state = 371},
  [13589] = {.lex_state = 371},
  [13590] = {.lex_state = 371},
  [13591] = {.lex_state = 371},
  [13592] = {.lex_state = 371},
  [13593] = {.lex_state = 371},
  [13594] = {.lex_state = 371},
  [13595] = {.lex_state = 371},
  [13596] = {.lex_state = 371},
  [13597] = {.lex_state = 371},
  [13598] = {.lex_state = 371},
  [13599] = {.lex_state = 371},
  [13600] = {.lex_state = 371},
  [13601] = {.lex_state = 371},
  [13602] = {.lex_state = 371},
  [13603] = {.lex_state = 371},
  [13604] = {.lex_state = 371},
  [13605] = {.lex_state = 371},
  [13606] = {.lex_state = 371},
  [13607] = {.lex_state = 371},
  [13608] = {.lex_state = 371},
  [13609] = {.lex_state = 371},
  [13610] = {.lex_state = 371},
  [13611] = {.lex_state = 371},
  [13612] = {.lex_state = 371},
  [13613] = {.lex_state = 371},
  [13614] = {.lex_state = 371},
  [13615] = {.lex_state = 371},
  [13616] = {.lex_state = 371},
  [13617] = {.lex_state = 63},
  [13618] = {.lex_state = 51},
  [13619] = {.lex_state = 371},
  [13620] = {.lex_state = 371},
  [13621] = {.lex_state = 371},
  [13622] = {.lex_state = 371},
  [13623] = {.lex_state = 371},
  [13624] = {.lex_state = 371},
  [13625] = {.lex_state = 371},
  [13626] = {.lex_state = 371},
  [13627] = {.lex_state = 371},
  [13628] = {.lex_state = 371},
  [13629] = {.lex_state = 371},
  [13630] = {.lex_state = 371},
  [13631] = {.lex_state = 371},
  [13632] = {.lex_state = 371},
  [13633] = {.lex_state = 371},
  [13634] = {.lex_state = 371},
  [13635] = {.lex_state = 371},
  [13636] = {.lex_state = 371},
  [13637] = {.lex_state = 371},
  [13638] = {.lex_state = 23},
  [13639] = {.lex_state = 371},
  [13640] = {.lex_state = 371},
  [13641] = {.lex_state = 371},
  [13642] = {.lex_state = 371},
  [13643] = {.lex_state = 373},
  [13644] = {.lex_state = 373},
  [13645] = {.lex_state = 371},
  [13646] = {.lex_state = 371},
  [13647] = {.lex_state = 371},
  [13648] = {.lex_state = 371},
  [13649] = {.lex_state = 371},
  [13650] = {.lex_state = 371},
  [13651] = {.lex_state = 0},
  [13652] = {.lex_state = 371},
  [13653] = {.lex_state = 371},
  [13654] = {.lex_state = 51},
  [13655] = {.lex_state = 371},
  [13656] = {.lex_state = 371},
  [13657] = {.lex_state = 371},
  [13658] = {.lex_state = 371},
  [13659] = {.lex_state = 371},
  [13660] = {.lex_state = 371},
  [13661] = {.lex_state = 371},
  [13662] = {.lex_state = 8},
  [13663] = {.lex_state = 371},
  [13664] = {.lex_state = 371},
  [13665] = {.lex_state = 371},
  [13666] = {.lex_state = 371},
  [13667] = {.lex_state = 371},
  [13668] = {.lex_state = 371},
  [13669] = {.lex_state = 371},
  [13670] = {.lex_state = 371},
  [13671] = {.lex_state = 371},
  [13672] = {.lex_state = 371},
  [13673] = {.lex_state = 371},
  [13674] = {.lex_state = 371},
  [13675] = {.lex_state = 371},
  [13676] = {.lex_state = 371},
  [13677] = {.lex_state = 371},
  [13678] = {.lex_state = 371},
  [13679] = {.lex_state = 371},
  [13680] = {.lex_state = 371},
  [13681] = {.lex_state = 43},
  [13682] = {.lex_state = 371},
  [13683] = {.lex_state = 371},
  [13684] = {.lex_state = 371},
  [13685] = {.lex_state = 371},
  [13686] = {.lex_state = 371},
  [13687] = {.lex_state = 371},
  [13688] = {.lex_state = 371},
  [13689] = {.lex_state = 371},
  [13690] = {.lex_state = 371},
  [13691] = {.lex_state = 371},
  [13692] = {.lex_state = 371},
  [13693] = {.lex_state = 371},
  [13694] = {.lex_state = 371},
  [13695] = {.lex_state = 371},
  [13696] = {.lex_state = 371},
  [13697] = {.lex_state = 371},
  [13698] = {.lex_state = 371},
  [13699] = {.lex_state = 371},
  [13700] = {.lex_state = 371},
  [13701] = {.lex_state = 371},
  [13702] = {.lex_state = 371},
  [13703] = {.lex_state = 23},
  [13704] = {.lex_state = 82},
  [13705] = {.lex_state = 371},
  [13706] = {.lex_state = 371},
  [13707] = {.lex_state = 0},
  [13708] = {.lex_state = 371},
  [13709] = {.lex_state = 371},
  [13710] = {.lex_state = 371},
  [13711] = {.lex_state = 371},
  [13712] = {.lex_state = 371},
  [13713] = {.lex_state = 371},
  [13714] = {.lex_state = 371},
  [13715] = {.lex_state = 371},
  [13716] = {.lex_state = 371},
  [13717] = {.lex_state = 371},
  [13718] = {.lex_state = 371},
  [13719] = {.lex_state = 371},
  [13720] = {.lex_state = 8},
  [13721] = {.lex_state = 371},
  [13722] = {.lex_state = 371},
  [13723] = {.lex_state = 371},
  [13724] = {.lex_state = 371},
  [13725] = {.lex_state = 371},
  [13726] = {.lex_state = 371},
  [13727] = {.lex_state = 371},
  [13728] = {.lex_state = 371},
  [13729] = {.lex_state = 7},
  [13730] = {.lex_state = 371},
  [13731] = {.lex_state = 0},
  [13732] = {.lex_state = 371},
  [13733] = {.lex_state = 371},
  [13734] = {.lex_state = 371},
  [13735] = {.lex_state = 371},
  [13736] = {.lex_state = 371},
  [13737] = {.lex_state = 371},
  [13738] = {.lex_state = 371},
  [13739] = {.lex_state = 371},
  [13740] = {.lex_state = 8},
  [13741] = {.lex_state = 371},
  [13742] = {.lex_state = 371},
  [13743] = {.lex_state = 371},
  [13744] = {.lex_state = 371},
  [13745] = {.lex_state = 371},
  [13746] = {.lex_state = 371},
  [13747] = {.lex_state = 371},
  [13748] = {.lex_state = 371},
  [13749] = {.lex_state = 373},
  [13750] = {.lex_state = 371},
  [13751] = {.lex_state = 371},
  [13752] = {.lex_state = 371},
  [13753] = {.lex_state = 373},
  [13754] = {.lex_state = 371},
  [13755] = {.lex_state = 373},
  [13756] = {.lex_state = 371},
  [13757] = {.lex_state = 371},
  [13758] = {.lex_state = 371},
  [13759] = {.lex_state = 371},
  [13760] = {.lex_state = 371},
  [13761] = {.lex_state = 371},
  [13762] = {.lex_state = 371},
  [13763] = {.lex_state = 0},
  [13764] = {.lex_state = 371},
  [13765] = {.lex_state = 371},
  [13766] = {.lex_state = 371},
  [13767] = {.lex_state = 371},
  [13768] = {.lex_state = 371},
  [13769] = {.lex_state = 8},
  [13770] = {.lex_state = 371},
  [13771] = {.lex_state = 371},
  [13772] = {.lex_state = 371},
  [13773] = {.lex_state = 371},
  [13774] = {.lex_state = 371},
  [13775] = {.lex_state = 371},
  [13776] = {.lex_state = 0},
  [13777] = {.lex_state = 371},
  [13778] = {.lex_state = 371},
  [13779] = {.lex_state = 371},
  [13780] = {.lex_state = 371},
  [13781] = {.lex_state = 371},
  [13782] = {.lex_state = 371},
  [13783] = {.lex_state = 371},
  [13784] = {.lex_state = 371},
  [13785] = {.lex_state = 371},
  [13786] = {.lex_state = 8},
  [13787] = {.lex_state = 51},
  [13788] = {.lex_state = 371},
  [13789] = {.lex_state = 371},
  [13790] = {.lex_state = 371},
  [13791] = {.lex_state = 371},
  [13792] = {.lex_state = 371},
  [13793] = {.lex_state = 371},
  [13794] = {.lex_state = 371},
  [13795] = {.lex_state = 8},
  [13796] = {.lex_state = 371},
  [13797] = {.lex_state = 371},
  [13798] = {.lex_state = 371},
  [13799] = {.lex_state = 8},
  [13800] = {.lex_state = 373},
  [13801] = {.lex_state = 371},
  [13802] = {.lex_state = 371},
  [13803] = {.lex_state = 371},
  [13804] = {.lex_state = 371},
  [13805] = {.lex_state = 371},
  [13806] = {.lex_state = 371},
  [13807] = {.lex_state = 371},
  [13808] = {.lex_state = 371},
  [13809] = {.lex_state = 371},
  [13810] = {.lex_state = 371},
  [13811] = {.lex_state = 371},
  [13812] = {.lex_state = 371},
  [13813] = {.lex_state = 371},
  [13814] = {.lex_state = 371},
  [13815] = {.lex_state = 0},
  [13816] = {.lex_state = 371},
  [13817] = {.lex_state = 371},
  [13818] = {.lex_state = 372},
  [13819] = {.lex_state = 371},
  [13820] = {.lex_state = 371},
  [13821] = {.lex_state = 371},
  [13822] = {.lex_state = 371},
  [13823] = {.lex_state = 371},
  [13824] = {.lex_state = 371},
  [13825] = {.lex_state = 371},
  [13826] = {.lex_state = 371},
  [13827] = {.lex_state = 371},
  [13828] = {.lex_state = 371},
  [13829] = {.lex_state = 371},
  [13830] = {.lex_state = 371},
  [13831] = {.lex_state = 371},
  [13832] = {.lex_state = 371},
  [13833] = {.lex_state = 371},
  [13834] = {.lex_state = 371},
  [13835] = {.lex_state = 371},
  [13836] = {.lex_state = 371},
  [13837] = {.lex_state = 371},
  [13838] = {.lex_state = 371},
  [13839] = {.lex_state = 371},
  [13840] = {.lex_state = 371},
  [13841] = {.lex_state = 371},
  [13842] = {.lex_state = 371},
  [13843] = {.lex_state = 371},
  [13844] = {.lex_state = 371},
  [13845] = {.lex_state = 371},
  [13846] = {.lex_state = 371},
  [13847] = {.lex_state = 371},
  [13848] = {.lex_state = 371},
  [13849] = {.lex_state = 371},
  [13850] = {.lex_state = 371},
  [13851] = {.lex_state = 371},
  [13852] = {.lex_state = 371},
  [13853] = {.lex_state = 371},
  [13854] = {.lex_state = 371},
  [13855] = {.lex_state = 371},
  [13856] = {.lex_state = 371},
  [13857] = {.lex_state = 371},
  [13858] = {.lex_state = 371},
  [13859] = {.lex_state = 371},
  [13860] = {.lex_state = 371},
  [13861] = {.lex_state = 371},
  [13862] = {.lex_state = 371},
  [13863] = {.lex_state = 371},
  [13864] = {.lex_state = 371},
  [13865] = {.lex_state = 371},
  [13866] = {.lex_state = 371},
  [13867] = {.lex_state = 371},
  [13868] = {.lex_state = 371},
  [13869] = {.lex_state = 371},
  [13870] = {.lex_state = 371},
  [13871] = {.lex_state = 371},
  [13872] = {.lex_state = 371},
  [13873] = {.lex_state = 371},
  [13874] = {.lex_state = 371},
  [13875] = {.lex_state = 371},
  [13876] = {.lex_state = 371},
  [13877] = {.lex_state = 371},
  [13878] = {.lex_state = 371},
  [13879] = {.lex_state = 371},
  [13880] = {.lex_state = 371},
  [13881] = {.lex_state = 371},
  [13882] = {.lex_state = 371},
  [13883] = {.lex_state = 371},
  [13884] = {.lex_state = 371},
  [13885] = {.lex_state = 371},
  [13886] = {.lex_state = 371},
  [13887] = {.lex_state = 371},
  [13888] = {.lex_state = 371},
  [13889] = {.lex_state = 371},
  [13890] = {.lex_state = 371},
  [13891] = {.lex_state = 371},
  [13892] = {.lex_state = 371},
  [13893] = {.lex_state = 371},
  [13894] = {.lex_state = 371},
  [13895] = {.lex_state = 371},
  [13896] = {.lex_state = 371},
  [13897] = {.lex_state = 371},
  [13898] = {.lex_state = 371},
  [13899] = {.lex_state = 371},
  [13900] = {.lex_state = 371},
  [13901] = {.lex_state = 371},
  [13902] = {.lex_state = 371},
  [13903] = {.lex_state = 371},
  [13904] = {.lex_state = 371},
  [13905] = {.lex_state = 371},
  [13906] = {.lex_state = 371},
  [13907] = {.lex_state = 371},
  [13908] = {.lex_state = 371},
  [13909] = {.lex_state = 371},
  [13910] = {.lex_state = 371},
  [13911] = {.lex_state = 371},
  [13912] = {.lex_state = 371},
  [13913] = {.lex_state = 371},
  [13914] = {.lex_state = 371},
  [13915] = {.lex_state = 0},
  [13916] = {.lex_state = 0},
  [13917] = {.lex_state = 8},
  [13918] = {.lex_state = 371},
  [13919] = {.lex_state = 8},
  [13920] = {.lex_state = 8},
  [13921] = {.lex_state = 8},
  [13922] = {.lex_state = 8},
  [13923] = {.lex_state = 8},
  [13924] = {.lex_state = 8},
  [13925] = {.lex_state = 371},
  [13926] = {.lex_state = 371},
  [13927] = {.lex_state = 371},
  [13928] = {.lex_state = 371},
  [13929] = {.lex_state = 371},
  [13930] = {.lex_state = 371},
  [13931] = {.lex_state = 371},
  [13932] = {.lex_state = 371},
  [13933] = {.lex_state = 371},
  [13934] = {.lex_state = 371},
  [13935] = {.lex_state = 371},
  [13936] = {.lex_state = 371},
  [13937] = {.lex_state = 371},
  [13938] = {.lex_state = 51},
  [13939] = {.lex_state = 371},
  [13940] = {.lex_state = 371},
  [13941] = {.lex_state = 371},
  [13942] = {.lex_state = 0},
  [13943] = {.lex_state = 371},
  [13944] = {.lex_state = 371},
  [13945] = {.lex_state = 371},
  [13946] = {.lex_state = 371},
  [13947] = {.lex_state = 371},
  [13948] = {.lex_state = 371},
  [13949] = {.lex_state = 371},
  [13950] = {.lex_state = 371},
  [13951] = {.lex_state = 51},
  [13952] = {.lex_state = 371},
  [13953] = {.lex_state = 371},
  [13954] = {.lex_state = 371},
  [13955] = {.lex_state = 371},
  [13956] = {.lex_state = 371},
  [13957] = {.lex_state = 371},
  [13958] = {.lex_state = 371},
  [13959] = {.lex_state = 371},
  [13960] = {.lex_state = 371},
  [13961] = {.lex_state = 371},
  [13962] = {.lex_state = 371},
  [13963] = {.lex_state = 371},
  [13964] = {.lex_state = 371},
  [13965] = {.lex_state = 371},
  [13966] = {.lex_state = 371},
  [13967] = {.lex_state = 371},
  [13968] = {.lex_state = 371},
  [13969] = {.lex_state = 371},
  [13970] = {.lex_state = 371},
  [13971] = {.lex_state = 371},
  [13972] = {.lex_state = 371},
  [13973] = {.lex_state = 371},
  [13974] = {.lex_state = 371},
  [13975] = {.lex_state = 371},
  [13976] = {.lex_state = 371},
  [13977] = {.lex_state = 371},
  [13978] = {.lex_state = 371},
  [13979] = {.lex_state = 371},
  [13980] = {.lex_state = 371},
  [13981] = {.lex_state = 371},
  [13982] = {.lex_state = 0},
  [13983] = {.lex_state = 371},
  [13984] = {.lex_state = 371},
  [13985] = {.lex_state = 371},
  [13986] = {.lex_state = 371},
  [13987] = {.lex_state = 371},
  [13988] = {.lex_state = 371},
  [13989] = {.lex_state = 371},
  [13990] = {.lex_state = 371},
  [13991] = {.lex_state = 371},
  [13992] = {.lex_state = 371},
  [13993] = {.lex_state = 371},
  [13994] = {.lex_state = 371},
  [13995] = {.lex_state = 371},
  [13996] = {.lex_state = 371},
  [13997] = {.lex_state = 51},
  [13998] = {.lex_state = 371},
  [13999] = {.lex_state = 371},
  [14000] = {.lex_state = 371},
  [14001] = {.lex_state = 371},
  [14002] = {.lex_state = 371},
  [14003] = {.lex_state = 371},
  [14004] = {.lex_state = 371},
  [14005] = {.lex_state = 371},
  [14006] = {.lex_state = 371},
  [14007] = {.lex_state = 371},
  [14008] = {.lex_state = 371},
  [14009] = {.lex_state = 371},
  [14010] = {.lex_state = 371},
  [14011] = {.lex_state = 371},
  [14012] = {.lex_state = 371},
  [14013] = {.lex_state = 371},
  [14014] = {.lex_state = 371},
  [14015] = {.lex_state = 371},
  [14016] = {.lex_state = 371},
  [14017] = {.lex_state = 371},
  [14018] = {.lex_state = 371},
  [14019] = {.lex_state = 371},
  [14020] = {.lex_state = 8},
  [14021] = {.lex_state = 51},
  [14022] = {.lex_state = 371},
  [14023] = {.lex_state = 371},
  [14024] = {.lex_state = 371},
  [14025] = {.lex_state = 371},
  [14026] = {.lex_state = 0},
  [14027] = {.lex_state = 371},
  [14028] = {.lex_state = 8},
  [14029] = {.lex_state = 371},
  [14030] = {.lex_state = 371},
  [14031] = {.lex_state = 371},
  [14032] = {.lex_state = 371},
  [14033] = {.lex_state = 371},
  [14034] = {.lex_state = 371},
  [14035] = {.lex_state = 371},
  [14036] = {.lex_state = 7},
  [14037] = {.lex_state = 7},
  [14038] = {.lex_state = 371},
  [14039] = {.lex_state = 371},
  [14040] = {.lex_state = 7},
  [14041] = {.lex_state = 371},
  [14042] = {.lex_state = 371},
  [14043] = {.lex_state = 371},
  [14044] = {.lex_state = 371},
  [14045] = {.lex_state = 371},
  [14046] = {.lex_state = 371},
  [14047] = {.lex_state = 371},
  [14048] = {.lex_state = 371},
  [14049] = {.lex_state = 371},
  [14050] = {.lex_state = 371},
  [14051] = {.lex_state = 371},
  [14052] = {.lex_state = 371},
  [14053] = {.lex_state = 371},
  [14054] = {.lex_state = 371},
  [14055] = {.lex_state = 371},
  [14056] = {.lex_state = 371},
  [14057] = {.lex_state = 371},
  [14058] = {.lex_state = 371},
  [14059] = {.lex_state = 371},
  [14060] = {.lex_state = 371},
  [14061] = {.lex_state = 371},
  [14062] = {.lex_state = 371},
  [14063] = {.lex_state = 371},
  [14064] = {.lex_state = 371},
  [14065] = {.lex_state = 371},
  [14066] = {.lex_state = 371},
  [14067] = {.lex_state = 371},
  [14068] = {.lex_state = 371},
  [14069] = {.lex_state = 371},
  [14070] = {.lex_state = 371},
  [14071] = {.lex_state = 371},
  [14072] = {.lex_state = 371},
  [14073] = {.lex_state = 371},
  [14074] = {.lex_state = 371},
  [14075] = {.lex_state = 371},
  [14076] = {.lex_state = 371},
  [14077] = {.lex_state = 371},
  [14078] = {.lex_state = 371},
  [14079] = {.lex_state = 371},
  [14080] = {.lex_state = 371},
  [14081] = {.lex_state = 371},
  [14082] = {.lex_state = 371},
  [14083] = {.lex_state = 371},
  [14084] = {.lex_state = 371},
  [14085] = {.lex_state = 7},
  [14086] = {.lex_state = 371},
  [14087] = {.lex_state = 371},
  [14088] = {.lex_state = 371},
  [14089] = {.lex_state = 371},
  [14090] = {.lex_state = 371},
  [14091] = {.lex_state = 371},
  [14092] = {.lex_state = 371},
  [14093] = {.lex_state = 371},
  [14094] = {.lex_state = 371},
  [14095] = {.lex_state = 371},
  [14096] = {.lex_state = 371},
  [14097] = {.lex_state = 371},
  [14098] = {.lex_state = 371},
  [14099] = {.lex_state = 371},
  [14100] = {.lex_state = 42},
  [14101] = {.lex_state = 371},
  [14102] = {.lex_state = 371},
  [14103] = {.lex_state = 371},
  [14104] = {.lex_state = 371},
  [14105] = {.lex_state = 7},
  [14106] = {.lex_state = 371},
  [14107] = {.lex_state = 371},
  [14108] = {.lex_state = 7},
  [14109] = {.lex_state = 371},
  [14110] = {.lex_state = 371},
  [14111] = {.lex_state = 371},
  [14112] = {.lex_state = 7},
  [14113] = {.lex_state = 7},
  [14114] = {.lex_state = 371},
  [14115] = {.lex_state = 371},
  [14116] = {.lex_state = 7},
  [14117] = {.lex_state = 8},
  [14118] = {.lex_state = 371},
  [14119] = {.lex_state = 371},
  [14120] = {.lex_state = 371},
  [14121] = {.lex_state = 371},
  [14122] = {.lex_state = 371},
  [14123] = {.lex_state = 371},
  [14124] = {.lex_state = 371},
  [14125] = {.lex_state = 371},
  [14126] = {.lex_state = 371},
  [14127] = {.lex_state = 82},
  [14128] = {.lex_state = 82},
  [14129] = {.lex_state = 371},
  [14130] = {.lex_state = 371},
  [14131] = {.lex_state = 371},
  [14132] = {.lex_state = 0},
  [14133] = {.lex_state = 371},
  [14134] = {.lex_state = 82},
  [14135] = {.lex_state = 371},
  [14136] = {.lex_state = 371},
  [14137] = {.lex_state = 82},
  [14138] = {.lex_state = 371},
  [14139] = {.lex_state = 371},
  [14140] = {.lex_state = 371},
  [14141] = {.lex_state = 371},
  [14142] = {.lex_state = 371},
  [14143] = {.lex_state = 371},
  [14144] = {.lex_state = 371},
  [14145] = {.lex_state = 371},
  [14146] = {.lex_state = 371},
  [14147] = {.lex_state = 371},
  [14148] = {.lex_state = 371},
  [14149] = {.lex_state = 371},
  [14150] = {.lex_state = 371},
  [14151] = {.lex_state = 371},
  [14152] = {.lex_state = 371},
  [14153] = {.lex_state = 371},
  [14154] = {.lex_state = 371},
  [14155] = {.lex_state = 371},
  [14156] = {.lex_state = 371},
  [14157] = {.lex_state = 0},
  [14158] = {.lex_state = 371},
  [14159] = {.lex_state = 371},
  [14160] = {.lex_state = 371},
  [14161] = {.lex_state = 371},
  [14162] = {.lex_state = 371},
  [14163] = {.lex_state = 371},
  [14164] = {.lex_state = 371},
  [14165] = {.lex_state = 371},
  [14166] = {.lex_state = 371},
  [14167] = {.lex_state = 371},
  [14168] = {.lex_state = 371},
  [14169] = {.lex_state = 371},
  [14170] = {.lex_state = 371},
  [14171] = {.lex_state = 371},
  [14172] = {.lex_state = 371},
  [14173] = {.lex_state = 371},
  [14174] = {.lex_state = 371},
  [14175] = {.lex_state = 371},
  [14176] = {.lex_state = 371},
  [14177] = {.lex_state = 371},
  [14178] = {.lex_state = 7},
  [14179] = {.lex_state = 371},
  [14180] = {.lex_state = 371},
  [14181] = {.lex_state = 371},
  [14182] = {.lex_state = 371},
  [14183] = {.lex_state = 371},
  [14184] = {.lex_state = 7},
  [14185] = {.lex_state = 7},
  [14186] = {.lex_state = 7},
  [14187] = {.lex_state = 371},
  [14188] = {.lex_state = 371},
  [14189] = {.lex_state = 7},
  [14190] = {.lex_state = 371},
  [14191] = {.lex_state = 371},
  [14192] = {.lex_state = 371},
  [14193] = {.lex_state = 371},
  [14194] = {.lex_state = 371},
  [14195] = {.lex_state = 371},
  [14196] = {.lex_state = 371},
  [14197] = {.lex_state = 371},
  [14198] = {.lex_state = 371},
  [14199] = {.lex_state = 371},
  [14200] = {.lex_state = 371},
  [14201] = {.lex_state = 371},
  [14202] = {.lex_state = 371},
  [14203] = {.lex_state = 371},
  [14204] = {.lex_state = 0},
  [14205] = {.lex_state = 371},
  [14206] = {.lex_state = 371},
  [14207] = {.lex_state = 371},
  [14208] = {.lex_state = 371},
  [14209] = {.lex_state = 371},
  [14210] = {.lex_state = 371},
  [14211] = {.lex_state = 371},
  [14212] = {.lex_state = 371},
  [14213] = {.lex_state = 371},
  [14214] = {.lex_state = 371},
  [14215] = {.lex_state = 371},
  [14216] = {.lex_state = 0},
  [14217] = {.lex_state = 371},
  [14218] = {.lex_state = 371},
  [14219] = {.lex_state = 371},
  [14220] = {.lex_state = 371},
  [14221] = {.lex_state = 371},
  [14222] = {.lex_state = 371},
  [14223] = {.lex_state = 371},
  [14224] = {.lex_state = 371},
  [14225] = {.lex_state = 371},
  [14226] = {.lex_state = 371},
  [14227] = {.lex_state = 371},
  [14228] = {.lex_state = 371},
  [14229] = {.lex_state = 371},
  [14230] = {.lex_state = 371},
  [14231] = {.lex_state = 371},
  [14232] = {.lex_state = 371},
  [14233] = {.lex_state = 371},
  [14234] = {.lex_state = 7},
  [14235] = {.lex_state = 371},
  [14236] = {.lex_state = 371},
  [14237] = {.lex_state = 371},
  [14238] = {.lex_state = 371},
  [14239] = {.lex_state = 371},
  [14240] = {.lex_state = 371},
  [14241] = {.lex_state = 7},
  [14242] = {.lex_state = 371},
  [14243] = {.lex_state = 371},
  [14244] = {.lex_state = 371},
  [14245] = {.lex_state = 371},
  [14246] = {.lex_state = 371},
  [14247] = {.lex_state = 7},
  [14248] = {.lex_state = 7},
  [14249] = {.lex_state = 373},
  [14250] = {.lex_state = 371},
  [14251] = {.lex_state = 0},
  [14252] = {.lex_state = 7},
  [14253] = {.lex_state = 371},
  [14254] = {.lex_state = 371},
  [14255] = {.lex_state = 371},
  [14256] = {.lex_state = 371},
  [14257] = {.lex_state = 371},
  [14258] = {.lex_state = 371},
  [14259] = {.lex_state = 371},
  [14260] = {.lex_state = 371},
  [14261] = {.lex_state = 371},
  [14262] = {.lex_state = 371},
  [14263] = {.lex_state = 371},
  [14264] = {.lex_state = 371},
  [14265] = {.lex_state = 371},
  [14266] = {.lex_state = 371},
  [14267] = {.lex_state = 371},
  [14268] = {.lex_state = 371},
  [14269] = {.lex_state = 371},
  [14270] = {.lex_state = 371},
  [14271] = {.lex_state = 371},
  [14272] = {.lex_state = 371},
  [14273] = {.lex_state = 371},
  [14274] = {.lex_state = 371},
  [14275] = {.lex_state = 371},
  [14276] = {.lex_state = 371},
  [14277] = {.lex_state = 371},
  [14278] = {.lex_state = 371},
  [14279] = {.lex_state = 371},
  [14280] = {.lex_state = 371},
  [14281] = {.lex_state = 371},
  [14282] = {.lex_state = 371},
  [14283] = {.lex_state = 371},
  [14284] = {.lex_state = 371},
  [14285] = {.lex_state = 371},
  [14286] = {.lex_state = 371},
  [14287] = {.lex_state = 371},
  [14288] = {.lex_state = 42},
  [14289] = {.lex_state = 371},
  [14290] = {.lex_state = 371},
  [14291] = {.lex_state = 371},
  [14292] = {.lex_state = 371},
  [14293] = {.lex_state = 371},
  [14294] = {.lex_state = 7},
  [14295] = {.lex_state = 371},
  [14296] = {.lex_state = 7},
  [14297] = {.lex_state = 371},
  [14298] = {.lex_state = 371},
  [14299] = {.lex_state = 371},
  [14300] = {.lex_state = 371},
  [14301] = {.lex_state = 371},
  [14302] = {.lex_state = 371},
  [14303] = {.lex_state = 371},
  [14304] = {.lex_state = 371},
  [14305] = {.lex_state = 371},
  [14306] = {.lex_state = 43},
  [14307] = {.lex_state = 371},
  [14308] = {.lex_state = 0},
  [14309] = {.lex_state = 372},
  [14310] = {.lex_state = 371},
  [14311] = {.lex_state = 371},
  [14312] = {.lex_state = 8},
  [14313] = {.lex_state = 8},
  [14314] = {.lex_state = 371},
  [14315] = {.lex_state = 7},
  [14316] = {.lex_state = 371},
  [14317] = {.lex_state = 371},
  [14318] = {.lex_state = 7},
  [14319] = {.lex_state = 371},
  [14320] = {.lex_state = 7},
  [14321] = {.lex_state = 371},
  [14322] = {.lex_state = 371},
  [14323] = {.lex_state = 371},
  [14324] = {.lex_state = 371},
  [14325] = {.lex_state = 371},
  [14326] = {.lex_state = 371},
  [14327] = {.lex_state = 371},
  [14328] = {.lex_state = 371},
  [14329] = {.lex_state = 371},
  [14330] = {.lex_state = 43},
  [14331] = {.lex_state = 371},
  [14332] = {.lex_state = 371},
  [14333] = {.lex_state = 371},
  [14334] = {.lex_state = 371},
  [14335] = {.lex_state = 371},
  [14336] = {.lex_state = 371},
  [14337] = {.lex_state = 7},
  [14338] = {.lex_state = 7},
  [14339] = {.lex_state = 7},
  [14340] = {.lex_state = 371},
  [14341] = {.lex_state = 371},
  [14342] = {.lex_state = 371},
  [14343] = {.lex_state = 7},
  [14344] = {.lex_state = 371},
  [14345] = {.lex_state = 371},
  [14346] = {.lex_state = 371},
  [14347] = {.lex_state = 371},
  [14348] = {.lex_state = 371},
  [14349] = {.lex_state = 371},
  [14350] = {.lex_state = 371},
  [14351] = {.lex_state = 371},
  [14352] = {.lex_state = 371},
  [14353] = {.lex_state = 371},
  [14354] = {.lex_state = 371},
  [14355] = {.lex_state = 371},
  [14356] = {.lex_state = 371},
  [14357] = {.lex_state = 7},
  [14358] = {.lex_state = 371},
  [14359] = {.lex_state = 371},
  [14360] = {.lex_state = 371},
  [14361] = {.lex_state = 371},
  [14362] = {.lex_state = 371},
  [14363] = {.lex_state = 371},
  [14364] = {.lex_state = 371},
  [14365] = {.lex_state = 371},
  [14366] = {.lex_state = 371},
  [14367] = {.lex_state = 371},
  [14368] = {.lex_state = 371},
  [14369] = {.lex_state = 371},
  [14370] = {.lex_state = 371},
  [14371] = {.lex_state = 371},
  [14372] = {.lex_state = 371},
  [14373] = {.lex_state = 371},
  [14374] = {.lex_state = 371},
  [14375] = {.lex_state = 0},
  [14376] = {.lex_state = 371},
  [14377] = {.lex_state = 371},
  [14378] = {.lex_state = 371},
  [14379] = {.lex_state = 371},
  [14380] = {.lex_state = 371},
  [14381] = {.lex_state = 371},
  [14382] = {.lex_state = 371},
  [14383] = {.lex_state = 371},
  [14384] = {.lex_state = 371},
  [14385] = {.lex_state = 371},
  [14386] = {.lex_state = 371},
  [14387] = {.lex_state = 371},
  [14388] = {.lex_state = 371},
  [14389] = {.lex_state = 7},
  [14390] = {.lex_state = 371},
  [14391] = {.lex_state = 371},
  [14392] = {.lex_state = 371},
  [14393] = {.lex_state = 371},
  [14394] = {.lex_state = 7},
  [14395] = {.lex_state = 371},
  [14396] = {.lex_state = 371},
  [14397] = {.lex_state = 371},
  [14398] = {.lex_state = 371},
  [14399] = {.lex_state = 371},
  [14400] = {.lex_state = 371},
  [14401] = {.lex_state = 371},
  [14402] = {.lex_state = 371},
  [14403] = {.lex_state = 371},
  [14404] = {.lex_state = 371},
  [14405] = {.lex_state = 0},
  [14406] = {.lex_state = 371},
  [14407] = {.lex_state = 371},
  [14408] = {.lex_state = 371},
  [14409] = {.lex_state = 371},
  [14410] = {.lex_state = 371},
  [14411] = {.lex_state = 371},
  [14412] = {.lex_state = 371},
  [14413] = {.lex_state = 371},
  [14414] = {.lex_state = 371},
  [14415] = {.lex_state = 371},
  [14416] = {.lex_state = 371},
  [14417] = {.lex_state = 371},
  [14418] = {.lex_state = 371},
  [14419] = {.lex_state = 371},
  [14420] = {.lex_state = 371},
  [14421] = {.lex_state = 371},
  [14422] = {.lex_state = 0},
  [14423] = {.lex_state = 372},
  [14424] = {.lex_state = 371},
  [14425] = {.lex_state = 8},
  [14426] = {.lex_state = 8},
  [14427] = {.lex_state = 371},
  [14428] = {.lex_state = 373},
  [14429] = {.lex_state = 371},
  [14430] = {.lex_state = 371},
  [14431] = {.lex_state = 7},
  [14432] = {.lex_state = 371},
  [14433] = {.lex_state = 371},
  [14434] = {.lex_state = 7},
  [14435] = {.lex_state = 7},
  [14436] = {.lex_state = 371},
  [14437] = {.lex_state = 43},
  [14438] = {.lex_state = 82},
  [14439] = {.lex_state = 82},
  [14440] = {.lex_state = 7},
  [14441] = {.lex_state = 371},
  [14442] = {.lex_state = 371},
  [14443] = {.lex_state = 371},
  [14444] = {.lex_state = 371},
  [14445] = {.lex_state = 371},
  [14446] = {.lex_state = 371},
  [14447] = {.lex_state = 371},
  [14448] = {.lex_state = 371},
  [14449] = {.lex_state = 371},
  [14450] = {.lex_state = 371},
  [14451] = {.lex_state = 371},
  [14452] = {.lex_state = 371},
  [14453] = {.lex_state = 371},
  [14454] = {.lex_state = 7},
  [14455] = {.lex_state = 371},
  [14456] = {.lex_state = 371},
  [14457] = {.lex_state = 371},
  [14458] = {.lex_state = 371},
  [14459] = {.lex_state = 371},
  [14460] = {.lex_state = 371},
  [14461] = {.lex_state = 371},
  [14462] = {.lex_state = 371},
  [14463] = {.lex_state = 371},
  [14464] = {.lex_state = 371},
  [14465] = {.lex_state = 371},
  [14466] = {.lex_state = 371},
  [14467] = {.lex_state = 371},
  [14468] = {.lex_state = 371},
  [14469] = {.lex_state = 371},
  [14470] = {.lex_state = 371},
  [14471] = {.lex_state = 371},
  [14472] = {.lex_state = 371},
  [14473] = {.lex_state = 371},
  [14474] = {.lex_state = 371},
  [14475] = {.lex_state = 371},
  [14476] = {.lex_state = 7},
  [14477] = {.lex_state = 371},
  [14478] = {.lex_state = 371},
  [14479] = {.lex_state = 371},
  [14480] = {.lex_state = 371},
  [14481] = {.lex_state = 371},
  [14482] = {.lex_state = 372},
  [14483] = {.lex_state = 8},
  [14484] = {.lex_state = 8},
  [14485] = {.lex_state = 371},
  [14486] = {.lex_state = 371},
  [14487] = {.lex_state = 7},
  [14488] = {.lex_state = 371},
  [14489] = {.lex_state = 371},
  [14490] = {.lex_state = 371},
  [14491] = {.lex_state = 371},
  [14492] = {.lex_state = 371},
  [14493] = {.lex_state = 371},
  [14494] = {.lex_state = 371},
  [14495] = {.lex_state = 371},
  [14496] = {.lex_state = 371},
  [14497] = {.lex_state = 371},
  [14498] = {.lex_state = 371},
  [14499] = {.lex_state = 7},
  [14500] = {.lex_state = 371},
  [14501] = {.lex_state = 371},
  [14502] = {.lex_state = 371},
  [14503] = {.lex_state = 371},
  [14504] = {.lex_state = 371},
  [14505] = {.lex_state = 0},
  [14506] = {.lex_state = 371},
  [14507] = {.lex_state = 371},
  [14508] = {.lex_state = 371},
  [14509] = {.lex_state = 371},
  [14510] = {.lex_state = 371},
  [14511] = {.lex_state = 371},
  [14512] = {.lex_state = 371},
  [14513] = {.lex_state = 371},
  [14514] = {.lex_state = 371},
  [14515] = {.lex_state = 371},
  [14516] = {.lex_state = 371},
  [14517] = {.lex_state = 371},
  [14518] = {.lex_state = 7},
  [14519] = {.lex_state = 371},
  [14520] = {.lex_state = 371},
  [14521] = {.lex_state = 7},
  [14522] = {.lex_state = 371},
  [14523] = {.lex_state = 371},
  [14524] = {.lex_state = 371},
  [14525] = {.lex_state = 7},
  [14526] = {.lex_state = 371},
  [14527] = {.lex_state = 371},
  [14528] = {.lex_state = 0},
  [14529] = {.lex_state = 371},
  [14530] = {.lex_state = 7},
  [14531] = {.lex_state = 371},
  [14532] = {.lex_state = 371},
  [14533] = {.lex_state = 372},
  [14534] = {.lex_state = 8},
  [14535] = {.lex_state = 8},
  [14536] = {.lex_state = 371},
  [14537] = {.lex_state = 371},
  [14538] = {.lex_state = 371},
  [14539] = {.lex_state = 371},
  [14540] = {.lex_state = 371},
  [14541] = {.lex_state = 371},
  [14542] = {.lex_state = 371},
  [14543] = {.lex_state = 42},
  [14544] = {.lex_state = 371},
  [14545] = {.lex_state = 371},
  [14546] = {.lex_state = 371},
  [14547] = {.lex_state = 371},
  [14548] = {.lex_state = 371},
  [14549] = {.lex_state = 7},
  [14550] = {.lex_state = 371},
  [14551] = {.lex_state = 371},
  [14552] = {.lex_state = 371},
  [14553] = {.lex_state = 371},
  [14554] = {.lex_state = 371},
  [14555] = {.lex_state = 371},
  [14556] = {.lex_state = 371},
  [14557] = {.lex_state = 371},
  [14558] = {.lex_state = 371},
  [14559] = {.lex_state = 371},
  [14560] = {.lex_state = 0},
  [14561] = {.lex_state = 371},
  [14562] = {.lex_state = 371},
  [14563] = {.lex_state = 371},
  [14564] = {.lex_state = 371},
  [14565] = {.lex_state = 371},
  [14566] = {.lex_state = 371},
  [14567] = {.lex_state = 371},
  [14568] = {.lex_state = 7},
  [14569] = {.lex_state = 7},
  [14570] = {.lex_state = 371},
  [14571] = {.lex_state = 371},
  [14572] = {.lex_state = 371},
  [14573] = {.lex_state = 371},
  [14574] = {.lex_state = 8},
  [14575] = {.lex_state = 8},
  [14576] = {.lex_state = 371},
  [14577] = {.lex_state = 371},
  [14578] = {.lex_state = 371},
  [14579] = {.lex_state = 371},
  [14580] = {.lex_state = 7},
  [14581] = {.lex_state = 371},
  [14582] = {.lex_state = 7},
  [14583] = {.lex_state = 371},
  [14584] = {.lex_state = 371},
  [14585] = {.lex_state = 371},
  [14586] = {.lex_state = 7},
  [14587] = {.lex_state = 371},
  [14588] = {.lex_state = 7},
  [14589] = {.lex_state = 371},
  [14590] = {.lex_state = 371},
  [14591] = {.lex_state = 371},
  [14592] = {.lex_state = 371},
  [14593] = {.lex_state = 371},
  [14594] = {.lex_state = 371},
  [14595] = {.lex_state = 7},
  [14596] = {.lex_state = 371},
  [14597] = {.lex_state = 371},
  [14598] = {.lex_state = 371},
  [14599] = {.lex_state = 371},
  [14600] = {.lex_state = 371},
  [14601] = {.lex_state = 371},
  [14602] = {.lex_state = 8},
  [14603] = {.lex_state = 8},
  [14604] = {.lex_state = 371},
  [14605] = {.lex_state = 371},
  [14606] = {.lex_state = 7},
  [14607] = {.lex_state = 371},
  [14608] = {.lex_state = 371},
  [14609] = {.lex_state = 371},
  [14610] = {.lex_state = 371},
  [14611] = {.lex_state = 371},
  [14612] = {.lex_state = 371},
  [14613] = {.lex_state = 371},
  [14614] = {.lex_state = 371},
  [14615] = {.lex_state = 371},
  [14616] = {.lex_state = 371},
  [14617] = {.lex_state = 371},
  [14618] = {.lex_state = 8},
  [14619] = {.lex_state = 8},
  [14620] = {.lex_state = 371},
  [14621] = {.lex_state = 371},
  [14622] = {.lex_state = 7},
  [14623] = {.lex_state = 371},
  [14624] = {.lex_state = 371},
  [14625] = {.lex_state = 371},
  [14626] = {.lex_state = 371},
  [14627] = {.lex_state = 7},
  [14628] = {.lex_state = 371},
  [14629] = {.lex_state = 7},
  [14630] = {.lex_state = 8},
  [14631] = {.lex_state = 8},
  [14632] = {.lex_state = 8},
  [14633] = {.lex_state = 8},
  [14634] = {.lex_state = 8},
  [14635] = {.lex_state = 8},
  [14636] = {.lex_state = 371},
  [14637] = {.lex_state = 8},
  [14638] = {.lex_state = 8},
  [14639] = {.lex_state = 371},
  [14640] = {.lex_state = 8},
  [14641] = {.lex_state = 8},
  [14642] = {.lex_state = 8},
  [14643] = {.lex_state = 8},
  [14644] = {.lex_state = 371},
  [14645] = {.lex_state = 7},
  [14646] = {.lex_state = 371},
  [14647] = {.lex_state = 371},
  [14648] = {.lex_state = 371},
  [14649] = {.lex_state = 7},
  [14650] = {.lex_state = 42},
  [14651] = {.lex_state = 7},
  [14652] = {.lex_state = 371},
  [14653] = {.lex_state = 7},
  [14654] = {.lex_state = 7},
  [14655] = {.lex_state = 8},
  [14656] = {.lex_state = 8},
  [14657] = {.lex_state = 373},
  [14658] = {.lex_state = 371},
  [14659] = {.lex_state = 371},
  [14660] = {.lex_state = 7},
  [14661] = {.lex_state = 7},
  [14662] = {.lex_state = 371},
  [14663] = {.lex_state = 371},
  [14664] = {.lex_state = 371},
  [14665] = {.lex_state = 371},
  [14666] = {.lex_state = 371},
  [14667] = {.lex_state = 371},
  [14668] = {.lex_state = 371},
  [14669] = {.lex_state = 371},
  [14670] = {.lex_state = 371},
  [14671] = {.lex_state = 371},
  [14672] = {.lex_state = 371},
  [14673] = {.lex_state = 371},
  [14674] = {.lex_state = 371},
  [14675] = {.lex_state = 371},
  [14676] = {.lex_state = 371},
  [14677] = {.lex_state = 0},
  [14678] = {.lex_state = 371},
  [14679] = {.lex_state = 371},
  [14680] = {.lex_state = 371},
  [14681] = {.lex_state = 7},
  [14682] = {.lex_state = 371},
  [14683] = {.lex_state = 371},
  [14684] = {.lex_state = 371},
  [14685] = {.lex_state = 371},
  [14686] = {.lex_state = 371},
  [14687] = {.lex_state = 371},
  [14688] = {.lex_state = 371},
  [14689] = {.lex_state = 371},
  [14690] = {.lex_state = 371},
  [14691] = {.lex_state = 371},
  [14692] = {.lex_state = 371},
  [14693] = {.lex_state = 371},
  [14694] = {.lex_state = 371},
  [14695] = {.lex_state = 371},
  [14696] = {.lex_state = 371},
  [14697] = {.lex_state = 371},
  [14698] = {.lex_state = 371},
  [14699] = {.lex_state = 371},
  [14700] = {.lex_state = 371},
  [14701] = {.lex_state = 371},
  [14702] = {.lex_state = 371},
  [14703] = {.lex_state = 7},
  [14704] = {.lex_state = 371},
  [14705] = {.lex_state = 371},
  [14706] = {.lex_state = 7},
  [14707] = {.lex_state = 371},
  [14708] = {.lex_state = 371},
  [14709] = {.lex_state = 371},
  [14710] = {.lex_state = 371},
  [14711] = {.lex_state = 7},
  [14712] = {.lex_state = 371},
  [14713] = {.lex_state = 371},
  [14714] = {.lex_state = 371},
  [14715] = {.lex_state = 7},
  [14716] = {.lex_state = 371},
  [14717] = {.lex_state = 371},
  [14718] = {.lex_state = 371},
  [14719] = {.lex_state = 371},
  [14720] = {.lex_state = 7},
  [14721] = {.lex_state = 7},
  [14722] = {.lex_state = 371},
  [14723] = {.lex_state = 7},
  [14724] = {.lex_state = 371},
  [14725] = {.lex_state = 371},
  [14726] = {.lex_state = 0},
  [14727] = {.lex_state = 371},
  [14728] = {.lex_state = 371},
  [14729] = {.lex_state = 371},
  [14730] = {.lex_state = 371},
  [14731] = {.lex_state = 371},
  [14732] = {.lex_state = 371},
  [14733] = {.lex_state = 371},
  [14734] = {.lex_state = 371},
  [14735] = {.lex_state = 371},
  [14736] = {.lex_state = 371},
  [14737] = {.lex_state = 371},
  [14738] = {.lex_state = 371},
  [14739] = {.lex_state = 82},
  [14740] = {.lex_state = 371},
  [14741] = {.lex_state = 82},
  [14742] = {.lex_state = 371},
  [14743] = {.lex_state = 371},
  [14744] = {.lex_state = 371},
  [14745] = {.lex_state = 371},
  [14746] = {.lex_state = 371},
  [14747] = {.lex_state = 371},
  [14748] = {.lex_state = 371},
  [14749] = {.lex_state = 371},
  [14750] = {.lex_state = 7},
  [14751] = {.lex_state = 7},
  [14752] = {.lex_state = 371},
  [14753] = {.lex_state = 7},
  [14754] = {.lex_state = 371},
  [14755] = {.lex_state = 371},
  [14756] = {.lex_state = 371},
  [14757] = {.lex_state = 371},
  [14758] = {.lex_state = 371},
  [14759] = {.lex_state = 371},
  [14760] = {.lex_state = 371},
  [14761] = {.lex_state = 0},
  [14762] = {.lex_state = 7},
  [14763] = {.lex_state = 7},
  [14764] = {.lex_state = 371},
  [14765] = {.lex_state = 7},
  [14766] = {.lex_state = 371},
  [14767] = {.lex_state = 371},
  [14768] = {.lex_state = 371},
  [14769] = {.lex_state = 371},
  [14770] = {.lex_state = 7},
  [14771] = {.lex_state = 371},
  [14772] = {.lex_state = 7},
  [14773] = {.lex_state = 371},
  [14774] = {.lex_state = 371},
  [14775] = {.lex_state = 372},
  [14776] = {.lex_state = 371},
  [14777] = {.lex_state = 371},
  [14778] = {.lex_state = 7},
  [14779] = {.lex_state = 371},
  [14780] = {.lex_state = 371},
  [14781] = {.lex_state = 371},
  [14782] = {.lex_state = 371},
  [14783] = {.lex_state = 371},
  [14784] = {.lex_state = 0},
  [14785] = {.lex_state = 371},
  [14786] = {.lex_state = 43},
  [14787] = {.lex_state = 371},
  [14788] = {.lex_state = 371},
  [14789] = {.lex_state = 0},
  [14790] = {.lex_state = 371},
  [14791] = {.lex_state = 371},
  [14792] = {.lex_state = 371},
  [14793] = {.lex_state = 371},
  [14794] = {.lex_state = 371},
  [14795] = {.lex_state = 371},
  [14796] = {.lex_state = 371},
  [14797] = {.lex_state = 371},
  [14798] = {.lex_state = 371},
  [14799] = {.lex_state = 7},
  [14800] = {.lex_state = 371},
  [14801] = {.lex_state = 371},
  [14802] = {.lex_state = 371},
  [14803] = {.lex_state = 0},
  [14804] = {.lex_state = 371},
  [14805] = {.lex_state = 41},
  [14806] = {.lex_state = 371},
  [14807] = {.lex_state = 371},
  [14808] = {.lex_state = 371},
  [14809] = {.lex_state = 371},
  [14810] = {.lex_state = 371},
  [14811] = {.lex_state = 371},
  [14812] = {.lex_state = 371},
  [14813] = {.lex_state = 371},
  [14814] = {.lex_state = 371},
  [14815] = {.lex_state = 371},
  [14816] = {.lex_state = 371},
  [14817] = {.lex_state = 371},
  [14818] = {.lex_state = 371},
  [14819] = {.lex_state = 371},
  [14820] = {.lex_state = 371},
  [14821] = {.lex_state = 371},
  [14822] = {.lex_state = 371},
  [14823] = {.lex_state = 371},
  [14824] = {.lex_state = 371},
  [14825] = {.lex_state = 371},
  [14826] = {.lex_state = 371},
  [14827] = {.lex_state = 371},
  [14828] = {.lex_state = 371},
  [14829] = {.lex_state = 371},
  [14830] = {.lex_state = 371},
  [14831] = {.lex_state = 7},
  [14832] = {.lex_state = 371},
  [14833] = {.lex_state = 7},
  [14834] = {.lex_state = 371},
  [14835] = {.lex_state = 371},
  [14836] = {.lex_state = 371},
  [14837] = {.lex_state = 371},
  [14838] = {.lex_state = 371},
  [14839] = {.lex_state = 371},
  [14840] = {.lex_state = 371},
  [14841] = {.lex_state = 371},
  [14842] = {.lex_state = 371},
  [14843] = {.lex_state = 7},
  [14844] = {.lex_state = 371},
  [14845] = {.lex_state = 371},
  [14846] = {.lex_state = 371},
  [14847] = {.lex_state = 371},
  [14848] = {.lex_state = 371},
  [14849] = {.lex_state = 372},
  [14850] = {.lex_state = 371},
  [14851] = {.lex_state = 371},
  [14852] = {.lex_state = 371},
  [14853] = {.lex_state = 371},
  [14854] = {.lex_state = 371},
  [14855] = {.lex_state = 371},
  [14856] = {.lex_state = 371},
  [14857] = {.lex_state = 7},
  [14858] = {.lex_state = 371},
  [14859] = {.lex_state = 371},
  [14860] = {.lex_state = 371},
  [14861] = {.lex_state = 371},
  [14862] = {.lex_state = 371},
  [14863] = {.lex_state = 371},
  [14864] = {.lex_state = 7},
  [14865] = {.lex_state = 371},
  [14866] = {.lex_state = 371},
  [14867] = {.lex_state = 371},
  [14868] = {.lex_state = 371},
  [14869] = {.lex_state = 371},
  [14870] = {.lex_state = 371},
  [14871] = {.lex_state = 371},
  [14872] = {.lex_state = 371},
  [14873] = {.lex_state = 371},
  [14874] = {.lex_state = 371},
  [14875] = {.lex_state = 371},
  [14876] = {.lex_state = 371},
  [14877] = {.lex_state = 371},
  [14878] = {.lex_state = 371},
  [14879] = {.lex_state = 371},
  [14880] = {.lex_state = 371},
  [14881] = {.lex_state = 371},
  [14882] = {.lex_state = 371},
  [14883] = {.lex_state = 371},
  [14884] = {.lex_state = 371},
  [14885] = {.lex_state = 371},
  [14886] = {.lex_state = 371},
  [14887] = {.lex_state = 7},
  [14888] = {.lex_state = 371},
  [14889] = {.lex_state = 371},
  [14890] = {.lex_state = 371},
  [14891] = {.lex_state = 371},
  [14892] = {.lex_state = 371},
  [14893] = {.lex_state = 371},
  [14894] = {.lex_state = 371},
  [14895] = {.lex_state = 371},
  [14896] = {.lex_state = 371},
  [14897] = {.lex_state = 371},
  [14898] = {.lex_state = 371},
  [14899] = {.lex_state = 371},
  [14900] = {.lex_state = 371},
  [14901] = {.lex_state = 371},
  [14902] = {.lex_state = 7},
  [14903] = {.lex_state = 7},
  [14904] = {.lex_state = 371},
  [14905] = {.lex_state = 371},
  [14906] = {.lex_state = 371},
  [14907] = {.lex_state = 371},
  [14908] = {.lex_state = 371},
  [14909] = {.lex_state = 371},
  [14910] = {.lex_state = 371},
  [14911] = {.lex_state = 7},
  [14912] = {.lex_state = 371},
  [14913] = {.lex_state = 371},
  [14914] = {.lex_state = 371},
  [14915] = {.lex_state = 371},
  [14916] = {.lex_state = 371},
  [14917] = {.lex_state = 371},
  [14918] = {.lex_state = 42},
  [14919] = {.lex_state = 7},
  [14920] = {.lex_state = 7},
  [14921] = {.lex_state = 7},
  [14922] = {.lex_state = 371},
  [14923] = {.lex_state = 82},
  [14924] = {.lex_state = 371},
  [14925] = {.lex_state = 371},
  [14926] = {.lex_state = 371},
  [14927] = {.lex_state = 371},
  [14928] = {.lex_state = 371},
  [14929] = {.lex_state = 371},
  [14930] = {.lex_state = 371},
  [14931] = {.lex_state = 371},
  [14932] = {.lex_state = 371},
  [14933] = {.lex_state = 371},
  [14934] = {.lex_state = 371},
  [14935] = {.lex_state = 371},
  [14936] = {.lex_state = 371},
  [14937] = {.lex_state = 42},
  [14938] = {.lex_state = 371},
  [14939] = {.lex_state = 371},
  [14940] = {.lex_state = 371},
  [14941] = {.lex_state = 371},
  [14942] = {.lex_state = 371},
  [14943] = {.lex_state = 371},
  [14944] = {.lex_state = 371},
  [14945] = {.lex_state = 82},
  [14946] = {.lex_state = 7},
  [14947] = {.lex_state = 7},
  [14948] = {.lex_state = 371},
  [14949] = {.lex_state = 371},
  [14950] = {.lex_state = 371},
  [14951] = {.lex_state = 7},
  [14952] = {.lex_state = 371},
  [14953] = {.lex_state = 371},
  [14954] = {.lex_state = 371},
  [14955] = {.lex_state = 42},
  [14956] = {.lex_state = 371},
  [14957] = {.lex_state = 371},
  [14958] = {.lex_state = 7},
  [14959] = {.lex_state = 371},
  [14960] = {.lex_state = 371},
  [14961] = {.lex_state = 371},
  [14962] = {.lex_state = 371},
  [14963] = {.lex_state = 42},
  [14964] = {.lex_state = 371},
  [14965] = {.lex_state = 371},
  [14966] = {.lex_state = 371},
  [14967] = {.lex_state = 371},
  [14968] = {.lex_state = 371},
  [14969] = {.lex_state = 42},
  [14970] = {.lex_state = 371},
  [14971] = {.lex_state = 371},
  [14972] = {.lex_state = 371},
  [14973] = {.lex_state = 42},
  [14974] = {.lex_state = 371},
  [14975] = {.lex_state = 371},
  [14976] = {.lex_state = 42},
  [14977] = {.lex_state = 371},
  [14978] = {.lex_state = 0},
  [14979] = {.lex_state = 7},
  [14980] = {.lex_state = 371},
  [14981] = {.lex_state = 371},
  [14982] = {.lex_state = 371},
  [14983] = {.lex_state = 371},
  [14984] = {.lex_state = 371},
  [14985] = {.lex_state = 371},
  [14986] = {.lex_state = 371},
  [14987] = {.lex_state = 7},
  [14988] = {.lex_state = 371},
  [14989] = {.lex_state = 371},
  [14990] = {.lex_state = 371},
  [14991] = {.lex_state = 371},
  [14992] = {.lex_state = 371},
  [14993] = {.lex_state = 371},
  [14994] = {.lex_state = 371},
  [14995] = {.lex_state = 7},
  [14996] = {.lex_state = 371},
  [14997] = {.lex_state = 371},
  [14998] = {.lex_state = 371},
  [14999] = {.lex_state = 371},
  [15000] = {.lex_state = 371},
  [15001] = {.lex_state = 371},
  [15002] = {.lex_state = 63},
  [15003] = {.lex_state = 41},
  [15004] = {.lex_state = 371},
  [15005] = {.lex_state = 371},
  [15006] = {.lex_state = 7},
  [15007] = {.lex_state = 371},
  [15008] = {.lex_state = 371},
  [15009] = {.lex_state = 371},
  [15010] = {.lex_state = 371},
  [15011] = {.lex_state = 371},
  [15012] = {.lex_state = 371},
  [15013] = {.lex_state = 371},
  [15014] = {.lex_state = 371},
  [15015] = {.lex_state = 371},
  [15016] = {.lex_state = 371},
  [15017] = {.lex_state = 371},
  [15018] = {.lex_state = 371},
  [15019] = {.lex_state = 371},
  [15020] = {.lex_state = 371},
  [15021] = {.lex_state = 371},
  [15022] = {.lex_state = 371},
  [15023] = {.lex_state = 371},
  [15024] = {.lex_state = 371},
  [15025] = {.lex_state = 371},
  [15026] = {.lex_state = 371},
  [15027] = {.lex_state = 371},
  [15028] = {.lex_state = 371},
  [15029] = {.lex_state = 371},
  [15030] = {.lex_state = 371},
  [15031] = {.lex_state = 7},
  [15032] = {.lex_state = 371},
  [15033] = {.lex_state = 371},
  [15034] = {.lex_state = 371},
  [15035] = {.lex_state = 42},
  [15036] = {.lex_state = 371},
  [15037] = {.lex_state = 371},
  [15038] = {.lex_state = 371},
  [15039] = {.lex_state = 371},
  [15040] = {.lex_state = 371},
  [15041] = {.lex_state = 371},
  [15042] = {.lex_state = 371},
  [15043] = {.lex_state = 371},
  [15044] = {.lex_state = 371},
  [15045] = {.lex_state = 371},
  [15046] = {.lex_state = 371},
  [15047] = {.lex_state = 371},
  [15048] = {.lex_state = 0},
  [15049] = {.lex_state = 371},
  [15050] = {.lex_state = 371},
  [15051] = {.lex_state = 371},
  [15052] = {.lex_state = 371},
  [15053] = {.lex_state = 371},
  [15054] = {.lex_state = 371},
  [15055] = {.lex_state = 371},
  [15056] = {.lex_state = 7},
  [15057] = {.lex_state = 7},
  [15058] = {.lex_state = 371},
  [15059] = {.lex_state = 371},
  [15060] = {.lex_state = 371},
  [15061] = {.lex_state = 371},
  [15062] = {.lex_state = 371},
  [15063] = {.lex_state = 371},
  [15064] = {.lex_state = 371},
  [15065] = {.lex_state = 371},
  [15066] = {.lex_state = 371},
  [15067] = {.lex_state = 371},
  [15068] = {.lex_state = 0},
  [15069] = {.lex_state = 371},
  [15070] = {.lex_state = 371},
  [15071] = {.lex_state = 371},
  [15072] = {.lex_state = 371},
  [15073] = {.lex_state = 8},
  [15074] = {.lex_state = 371},
  [15075] = {.lex_state = 371},
  [15076] = {.lex_state = 371},
  [15077] = {.lex_state = 371},
  [15078] = {.lex_state = 371},
  [15079] = {.lex_state = 371},
  [15080] = {.lex_state = 371},
  [15081] = {.lex_state = 371},
  [15082] = {.lex_state = 371},
  [15083] = {.lex_state = 371},
  [15084] = {.lex_state = 371},
  [15085] = {.lex_state = 371},
  [15086] = {.lex_state = 7},
  [15087] = {.lex_state = 371},
  [15088] = {.lex_state = 371},
  [15089] = {.lex_state = 7},
  [15090] = {.lex_state = 371},
  [15091] = {.lex_state = 371},
  [15092] = {.lex_state = 371},
  [15093] = {.lex_state = 371},
  [15094] = {.lex_state = 371},
  [15095] = {.lex_state = 7},
  [15096] = {.lex_state = 371},
  [15097] = {.lex_state = 371},
  [15098] = {.lex_state = 371},
  [15099] = {.lex_state = 371},
  [15100] = {.lex_state = 371},
  [15101] = {.lex_state = 371},
  [15102] = {.lex_state = 371},
  [15103] = {.lex_state = 42},
  [15104] = {.lex_state = 371},
  [15105] = {.lex_state = 7},
  [15106] = {.lex_state = 7},
  [15107] = {.lex_state = 8},
  [15108] = {.lex_state = 0},
  [15109] = {.lex_state = 0},
  [15110] = {.lex_state = 0},
  [15111] = {.lex_state = 0},
  [15112] = {.lex_state = 0},
  [15113] = {.lex_state = 7},
  [15114] = {.lex_state = 0},
  [15115] = {.lex_state = 0},
  [15116] = {.lex_state = 371},
  [15117] = {.lex_state = 0},
  [15118] = {.lex_state = 373},
  [15119] = {.lex_state = 373},
  [15120] = {.lex_state = 371},
  [15121] = {.lex_state = 0},
  [15122] = {.lex_state = 0},
  [15123] = {.lex_state = 0},
  [15124] = {.lex_state = 0},
  [15125] = {.lex_state = 373},
  [15126] = {.lex_state = 0},
  [15127] = {.lex_state = 0},
  [15128] = {.lex_state = 26},
  [15129] = {.lex_state = 0},
  [15130] = {.lex_state = 0},
  [15131] = {.lex_state = 371},
  [15132] = {.lex_state = 0},
  [15133] = {.lex_state = 373},
  [15134] = {.lex_state = 397},
  [15135] = {.lex_state = 0},
  [15136] = {.lex_state = 0},
  [15137] = {.lex_state = 0},
  [15138] = {.lex_state = 0},
  [15139] = {.lex_state = 0},
  [15140] = {.lex_state = 0},
  [15141] = {.lex_state = 0},
  [15142] = {.lex_state = 0},
  [15143] = {.lex_state = 0},
  [15144] = {.lex_state = 0},
  [15145] = {.lex_state = 0},
  [15146] = {.lex_state = 0},
  [15147] = {.lex_state = 371},
  [15148] = {.lex_state = 0},
  [15149] = {.lex_state = 7},
  [15150] = {.lex_state = 371},
  [15151] = {.lex_state = 0},
  [15152] = {.lex_state = 373},
  [15153] = {.lex_state = 0},
  [15154] = {.lex_state = 0},
  [15155] = {.lex_state = 0},
  [15156] = {.lex_state = 0},
  [15157] = {.lex_state = 0},
  [15158] = {.lex_state = 0},
  [15159] = {.lex_state = 0},
  [15160] = {.lex_state = 0},
  [15161] = {.lex_state = 0},
  [15162] = {.lex_state = 0},
  [15163] = {.lex_state = 0},
  [15164] = {.lex_state = 0},
  [15165] = {.lex_state = 0},
  [15166] = {.lex_state = 0},
  [15167] = {.lex_state = 0},
  [15168] = {.lex_state = 0},
  [15169] = {.lex_state = 0},
  [15170] = {.lex_state = 0},
  [15171] = {.lex_state = 0},
  [15172] = {.lex_state = 0},
  [15173] = {.lex_state = 0},
  [15174] = {.lex_state = 0},
  [15175] = {.lex_state = 7},
  [15176] = {.lex_state = 7},
  [15177] = {.lex_state = 0},
  [15178] = {.lex_state = 0},
  [15179] = {.lex_state = 0},
  [15180] = {.lex_state = 0},
  [15181] = {.lex_state = 373},
  [15182] = {.lex_state = 0},
  [15183] = {.lex_state = 0},
  [15184] = {.lex_state = 0},
  [15185] = {.lex_state = 0},
  [15186] = {.lex_state = 0},
  [15187] = {.lex_state = 0},
  [15188] = {.lex_state = 0},
  [15189] = {.lex_state = 0},
  [15190] = {.lex_state = 371},
  [15191] = {.lex_state = 0},
  [15192] = {.lex_state = 0},
  [15193] = {.lex_state = 0},
  [15194] = {.lex_state = 0},
  [15195] = {.lex_state = 0},
  [15196] = {.lex_state = 0},
  [15197] = {.lex_state = 0},
  [15198] = {.lex_state = 0},
  [15199] = {.lex_state = 0},
  [15200] = {.lex_state = 0},
  [15201] = {.lex_state = 0},
  [15202] = {.lex_state = 0},
  [15203] = {.lex_state = 0},
  [15204] = {.lex_state = 0},
  [15205] = {.lex_state = 0},
  [15206] = {.lex_state = 0},
  [15207] = {.lex_state = 0},
  [15208] = {.lex_state = 0},
  [15209] = {.lex_state = 0},
  [15210] = {.lex_state = 0},
  [15211] = {.lex_state = 0},
  [15212] = {.lex_state = 0},
  [15213] = {.lex_state = 0},
  [15214] = {.lex_state = 0},
  [15215] = {.lex_state = 0},
  [15216] = {.lex_state = 0},
  [15217] = {.lex_state = 0},
  [15218] = {.lex_state = 0},
  [15219] = {.lex_state = 0},
  [15220] = {.lex_state = 0},
  [15221] = {.lex_state = 7},
  [15222] = {.lex_state = 7},
  [15223] = {.lex_state = 0},
  [15224] = {.lex_state = 0},
  [15225] = {.lex_state = 0},
  [15226] = {.lex_state = 0},
  [15227] = {.lex_state = 0},
  [15228] = {.lex_state = 0},
  [15229] = {.lex_state = 0},
  [15230] = {.lex_state = 0},
  [15231] = {.lex_state = 0},
  [15232] = {.lex_state = 0},
  [15233] = {.lex_state = 0},
  [15234] = {.lex_state = 0},
  [15235] = {.lex_state = 0},
  [15236] = {.lex_state = 373},
  [15237] = {.lex_state = 0},
  [15238] = {.lex_state = 0},
  [15239] = {.lex_state = 0},
  [15240] = {.lex_state = 0},
  [15241] = {.lex_state = 0},
  [15242] = {.lex_state = 0},
  [15243] = {.lex_state = 0},
  [15244] = {.lex_state = 0},
  [15245] = {.lex_state = 0},
  [15246] = {.lex_state = 0},
  [15247] = {.lex_state = 0},
  [15248] = {.lex_state = 0},
  [15249] = {.lex_state = 0},
  [15250] = {.lex_state = 0},
  [15251] = {.lex_state = 0},
  [15252] = {.lex_state = 373},
  [15253] = {.lex_state = 0},
  [15254] = {.lex_state = 0},
  [15255] = {.lex_state = 0},
  [15256] = {.lex_state = 373},
  [15257] = {.lex_state = 0},
  [15258] = {.lex_state = 0},
  [15259] = {.lex_state = 0},
  [15260] = {.lex_state = 0},
  [15261] = {.lex_state = 63},
  [15262] = {.lex_state = 373},
  [15263] = {.lex_state = 371},
  [15264] = {.lex_state = 0},
  [15265] = {.lex_state = 0},
  [15266] = {.lex_state = 0},
  [15267] = {.lex_state = 0},
  [15268] = {.lex_state = 42},
  [15269] = {.lex_state = 0},
  [15270] = {.lex_state = 371},
  [15271] = {.lex_state = 0},
  [15272] = {.lex_state = 0},
  [15273] = {.lex_state = 0},
  [15274] = {.lex_state = 0},
  [15275] = {.lex_state = 0},
  [15276] = {.lex_state = 0},
  [15277] = {.lex_state = 0},
  [15278] = {.lex_state = 371},
  [15279] = {.lex_state = 0},
  [15280] = {.lex_state = 0},
  [15281] = {.lex_state = 0},
  [15282] = {.lex_state = 0},
  [15283] = {.lex_state = 7},
  [15284] = {.lex_state = 0},
  [15285] = {.lex_state = 0},
  [15286] = {.lex_state = 0},
  [15287] = {.lex_state = 0},
  [15288] = {.lex_state = 0},
  [15289] = {.lex_state = 0},
  [15290] = {.lex_state = 0},
  [15291] = {.lex_state = 0},
  [15292] = {.lex_state = 0},
  [15293] = {.lex_state = 0},
  [15294] = {.lex_state = 397},
  [15295] = {.lex_state = 0},
  [15296] = {.lex_state = 0},
  [15297] = {.lex_state = 0},
  [15298] = {.lex_state = 0},
  [15299] = {.lex_state = 0},
  [15300] = {.lex_state = 0},
  [15301] = {.lex_state = 0},
  [15302] = {.lex_state = 0},
  [15303] = {.lex_state = 0},
  [15304] = {.lex_state = 0},
  [15305] = {.lex_state = 0},
  [15306] = {.lex_state = 0},
  [15307] = {.lex_state = 0},
  [15308] = {.lex_state = 0},
  [15309] = {.lex_state = 0},
  [15310] = {.lex_state = 371},
  [15311] = {.lex_state = 0},
  [15312] = {.lex_state = 0},
  [15313] = {.lex_state = 0},
  [15314] = {.lex_state = 0},
  [15315] = {.lex_state = 0},
  [15316] = {.lex_state = 371},
  [15317] = {.lex_state = 0},
  [15318] = {.lex_state = 0},
  [15319] = {.lex_state = 371},
  [15320] = {.lex_state = 0},
  [15321] = {.lex_state = 0},
  [15322] = {.lex_state = 0},
  [15323] = {.lex_state = 0},
  [15324] = {.lex_state = 0},
  [15325] = {.lex_state = 0},
  [15326] = {.lex_state = 0},
  [15327] = {.lex_state = 0},
  [15328] = {.lex_state = 0},
  [15329] = {.lex_state = 0},
  [15330] = {.lex_state = 0},
  [15331] = {.lex_state = 0},
  [15332] = {.lex_state = 0},
  [15333] = {.lex_state = 0},
  [15334] = {.lex_state = 0},
  [15335] = {.lex_state = 0},
  [15336] = {.lex_state = 0},
  [15337] = {.lex_state = 0},
  [15338] = {.lex_state = 0},
  [15339] = {.lex_state = 7},
  [15340] = {.lex_state = 0},
  [15341] = {.lex_state = 0},
  [15342] = {.lex_state = 0},
  [15343] = {.lex_state = 0},
  [15344] = {.lex_state = 0},
  [15345] = {.lex_state = 7},
  [15346] = {.lex_state = 0},
  [15347] = {.lex_state = 0},
  [15348] = {.lex_state = 0},
  [15349] = {.lex_state = 81},
  [15350] = {.lex_state = 373},
  [15351] = {.lex_state = 7},
  [15352] = {.lex_state = 0},
  [15353] = {.lex_state = 0},
  [15354] = {.lex_state = 371},
  [15355] = {.lex_state = 0},
  [15356] = {.lex_state = 0},
  [15357] = {.lex_state = 0},
  [15358] = {.lex_state = 0},
  [15359] = {.lex_state = 7},
  [15360] = {.lex_state = 0},
  [15361] = {.lex_state = 7},
  [15362] = {.lex_state = 0},
  [15363] = {.lex_state = 63},
  [15364] = {.lex_state = 0},
  [15365] = {.lex_state = 0},
  [15366] = {.lex_state = 0},
  [15367] = {.lex_state = 0},
  [15368] = {.lex_state = 371},
  [15369] = {.lex_state = 0},
  [15370] = {.lex_state = 0},
  [15371] = {.lex_state = 0},
  [15372] = {.lex_state = 0},
  [15373] = {.lex_state = 0},
  [15374] = {.lex_state = 63},
  [15375] = {.lex_state = 0},
  [15376] = {.lex_state = 0},
  [15377] = {.lex_state = 0},
  [15378] = {.lex_state = 63},
  [15379] = {.lex_state = 0},
  [15380] = {.lex_state = 0},
  [15381] = {.lex_state = 371},
  [15382] = {.lex_state = 0},
  [15383] = {.lex_state = 0},
  [15384] = {.lex_state = 7},
  [15385] = {.lex_state = 0},
  [15386] = {.lex_state = 0},
  [15387] = {.lex_state = 0},
  [15388] = {.lex_state = 0},
  [15389] = {.lex_state = 373},
  [15390] = {.lex_state = 7},
  [15391] = {.lex_state = 7},
  [15392] = {.lex_state = 371},
  [15393] = {.lex_state = 373},
  [15394] = {.lex_state = 0},
  [15395] = {.lex_state = 373},
  [15396] = {.lex_state = 0},
  [15397] = {.lex_state = 0},
  [15398] = {.lex_state = 0},
  [15399] = {.lex_state = 0},
  [15400] = {.lex_state = 0},
  [15401] = {.lex_state = 0},
  [15402] = {.lex_state = 0},
  [15403] = {.lex_state = 0},
  [15404] = {.lex_state = 0},
  [15405] = {.lex_state = 0},
  [15406] = {.lex_state = 0},
  [15407] = {.lex_state = 0},
  [15408] = {.lex_state = 0},
  [15409] = {.lex_state = 0},
  [15410] = {.lex_state = 0},
  [15411] = {.lex_state = 0},
  [15412] = {.lex_state = 0},
  [15413] = {.lex_state = 0},
  [15414] = {.lex_state = 0},
  [15415] = {.lex_state = 0},
  [15416] = {.lex_state = 0},
  [15417] = {.lex_state = 0},
  [15418] = {.lex_state = 0},
  [15419] = {.lex_state = 373},
  [15420] = {.lex_state = 7},
  [15421] = {.lex_state = 7},
  [15422] = {.lex_state = 0},
  [15423] = {.lex_state = 371},
  [15424] = {.lex_state = 0},
  [15425] = {.lex_state = 0},
  [15426] = {.lex_state = 0},
  [15427] = {.lex_state = 371},
  [15428] = {.lex_state = 0},
  [15429] = {.lex_state = 0},
  [15430] = {.lex_state = 0},
  [15431] = {.lex_state = 373},
  [15432] = {.lex_state = 0},
  [15433] = {.lex_state = 7},
  [15434] = {.lex_state = 0},
  [15435] = {.lex_state = 0},
  [15436] = {.lex_state = 0},
  [15437] = {.lex_state = 0},
  [15438] = {.lex_state = 0},
  [15439] = {.lex_state = 0},
  [15440] = {.lex_state = 0},
  [15441] = {.lex_state = 0},
  [15442] = {.lex_state = 0},
  [15443] = {.lex_state = 0},
  [15444] = {.lex_state = 0},
  [15445] = {.lex_state = 0},
  [15446] = {.lex_state = 0},
  [15447] = {.lex_state = 0},
  [15448] = {.lex_state = 0},
  [15449] = {.lex_state = 0},
  [15450] = {.lex_state = 0},
  [15451] = {.lex_state = 0},
  [15452] = {.lex_state = 0},
  [15453] = {.lex_state = 0},
  [15454] = {.lex_state = 0},
  [15455] = {.lex_state = 0},
  [15456] = {.lex_state = 0},
  [15457] = {.lex_state = 82},
  [15458] = {.lex_state = 7},
  [15459] = {.lex_state = 0},
  [15460] = {.lex_state = 0},
  [15461] = {.lex_state = 0},
  [15462] = {.lex_state = 0},
  [15463] = {.lex_state = 371},
  [15464] = {.lex_state = 0},
  [15465] = {.lex_state = 0},
  [15466] = {.lex_state = 0},
  [15467] = {.lex_state = 0},
  [15468] = {.lex_state = 0},
  [15469] = {.lex_state = 0},
  [15470] = {.lex_state = 0},
  [15471] = {.lex_state = 0},
  [15472] = {.lex_state = 0},
  [15473] = {.lex_state = 0},
  [15474] = {.lex_state = 0},
  [15475] = {.lex_state = 0},
  [15476] = {.lex_state = 0},
  [15477] = {.lex_state = 7},
  [15478] = {.lex_state = 0},
  [15479] = {.lex_state = 0},
  [15480] = {.lex_state = 0},
  [15481] = {.lex_state = 371},
  [15482] = {.lex_state = 0},
  [15483] = {.lex_state = 0},
  [15484] = {.lex_state = 0},
  [15485] = {.lex_state = 0},
  [15486] = {.lex_state = 0},
  [15487] = {.lex_state = 373},
  [15488] = {.lex_state = 0},
  [15489] = {.lex_state = 0},
  [15490] = {.lex_state = 0},
  [15491] = {.lex_state = 0},
  [15492] = {.lex_state = 7},
  [15493] = {.lex_state = 0},
  [15494] = {.lex_state = 0},
  [15495] = {.lex_state = 0},
  [15496] = {.lex_state = 0},
  [15497] = {.lex_state = 0},
  [15498] = {.lex_state = 0},
  [15499] = {.lex_state = 0},
  [15500] = {.lex_state = 0},
  [15501] = {.lex_state = 7},
  [15502] = {.lex_state = 0},
  [15503] = {.lex_state = 0},
  [15504] = {.lex_state = 7},
  [15505] = {.lex_state = 0},
  [15506] = {.lex_state = 0},
  [15507] = {.lex_state = 0},
  [15508] = {.lex_state = 0},
  [15509] = {.lex_state = 0},
  [15510] = {.lex_state = 0},
  [15511] = {.lex_state = 0},
  [15512] = {.lex_state = 0},
  [15513] = {.lex_state = 0},
  [15514] = {.lex_state = 0},
  [15515] = {.lex_state = 0},
  [15516] = {.lex_state = 0},
  [15517] = {.lex_state = 0},
  [15518] = {.lex_state = 0},
  [15519] = {.lex_state = 0},
  [15520] = {.lex_state = 0},
  [15521] = {.lex_state = 0},
  [15522] = {.lex_state = 0},
  [15523] = {.lex_state = 0},
  [15524] = {.lex_state = 0},
  [15525] = {.lex_state = 0},
  [15526] = {.lex_state = 7},
  [15527] = {.lex_state = 0},
  [15528] = {.lex_state = 0},
  [15529] = {.lex_state = 0},
  [15530] = {.lex_state = 0},
  [15531] = {.lex_state = 371},
  [15532] = {.lex_state = 0},
  [15533] = {.lex_state = 0},
  [15534] = {.lex_state = 0},
  [15535] = {.lex_state = 0},
  [15536] = {.lex_state = 373},
  [15537] = {.lex_state = 0},
  [15538] = {.lex_state = 0},
  [15539] = {.lex_state = 0},
  [15540] = {.lex_state = 0},
  [15541] = {.lex_state = 0},
  [15542] = {.lex_state = 0},
  [15543] = {.lex_state = 0},
  [15544] = {.lex_state = 0},
  [15545] = {.lex_state = 0},
  [15546] = {.lex_state = 0},
  [15547] = {.lex_state = 0},
  [15548] = {.lex_state = 0},
  [15549] = {.lex_state = 0},
  [15550] = {.lex_state = 0},
  [15551] = {.lex_state = 0},
  [15552] = {.lex_state = 373},
  [15553] = {.lex_state = 0},
  [15554] = {.lex_state = 0},
  [15555] = {.lex_state = 7},
  [15556] = {.lex_state = 373},
  [15557] = {.lex_state = 0},
  [15558] = {.lex_state = 0},
  [15559] = {.lex_state = 0},
  [15560] = {.lex_state = 0},
  [15561] = {.lex_state = 0},
  [15562] = {.lex_state = 0},
  [15563] = {.lex_state = 0},
  [15564] = {.lex_state = 26},
  [15565] = {.lex_state = 0},
  [15566] = {.lex_state = 0},
  [15567] = {.lex_state = 0},
  [15568] = {.lex_state = 0},
  [15569] = {.lex_state = 0},
  [15570] = {.lex_state = 0},
  [15571] = {.lex_state = 0},
  [15572] = {.lex_state = 371},
  [15573] = {.lex_state = 371},
  [15574] = {.lex_state = 0},
  [15575] = {.lex_state = 0},
  [15576] = {.lex_state = 0},
  [15577] = {.lex_state = 0},
  [15578] = {.lex_state = 0},
  [15579] = {.lex_state = 0},
  [15580] = {.lex_state = 0},
  [15581] = {.lex_state = 0},
  [15582] = {.lex_state = 0},
  [15583] = {.lex_state = 371},
  [15584] = {.lex_state = 0},
  [15585] = {.lex_state = 0},
  [15586] = {.lex_state = 0},
  [15587] = {.lex_state = 371},
  [15588] = {.lex_state = 0},
  [15589] = {.lex_state = 0},
  [15590] = {.lex_state = 0},
  [15591] = {.lex_state = 0},
  [15592] = {.lex_state = 0},
  [15593] = {.lex_state = 0},
  [15594] = {.lex_state = 371},
  [15595] = {.lex_state = 0},
  [15596] = {.lex_state = 0},
  [15597] = {.lex_state = 0},
  [15598] = {.lex_state = 0},
  [15599] = {.lex_state = 0},
  [15600] = {.lex_state = 0},
  [15601] = {.lex_state = 371},
  [15602] = {.lex_state = 0},
  [15603] = {.lex_state = 0},
  [15604] = {.lex_state = 0},
  [15605] = {.lex_state = 0},
  [15606] = {.lex_state = 0},
  [15607] = {.lex_state = 7},
  [15608] = {.lex_state = 0},
  [15609] = {.lex_state = 0},
  [15610] = {.lex_state = 373},
  [15611] = {.lex_state = 0},
  [15612] = {.lex_state = 0},
  [15613] = {.lex_state = 0},
  [15614] = {.lex_state = 0},
  [15615] = {.lex_state = 0},
  [15616] = {.lex_state = 0},
  [15617] = {.lex_state = 0},
  [15618] = {.lex_state = 82},
  [15619] = {.lex_state = 0},
  [15620] = {.lex_state = 0},
  [15621] = {.lex_state = 371},
  [15622] = {.lex_state = 0},
  [15623] = {.lex_state = 0},
  [15624] = {.lex_state = 0},
  [15625] = {.lex_state = 0},
  [15626] = {.lex_state = 0},
  [15627] = {.lex_state = 0},
  [15628] = {.lex_state = 0},
  [15629] = {.lex_state = 0},
  [15630] = {.lex_state = 0},
  [15631] = {.lex_state = 7},
  [15632] = {.lex_state = 0},
  [15633] = {.lex_state = 0},
  [15634] = {.lex_state = 0},
  [15635] = {.lex_state = 0},
  [15636] = {.lex_state = 0},
  [15637] = {.lex_state = 0},
  [15638] = {.lex_state = 82},
  [15639] = {.lex_state = 0},
  [15640] = {.lex_state = 0},
  [15641] = {.lex_state = 7},
  [15642] = {.lex_state = 0},
  [15643] = {.lex_state = 0},
  [15644] = {.lex_state = 371},
  [15645] = {.lex_state = 0},
  [15646] = {.lex_state = 0},
  [15647] = {.lex_state = 373},
  [15648] = {.lex_state = 7},
  [15649] = {.lex_state = 0},
  [15650] = {.lex_state = 397},
  [15651] = {.lex_state = 0},
  [15652] = {.lex_state = 0},
  [15653] = {.lex_state = 0},
  [15654] = {.lex_state = 7},
  [15655] = {.lex_state = 0},
  [15656] = {.lex_state = 0},
  [15657] = {.lex_state = 371},
  [15658] = {.lex_state = 0},
  [15659] = {.lex_state = 0},
  [15660] = {.lex_state = 0},
  [15661] = {.lex_state = 0},
  [15662] = {.lex_state = 0},
  [15663] = {.lex_state = 0},
  [15664] = {.lex_state = 0},
  [15665] = {.lex_state = 0},
  [15666] = {.lex_state = 371},
  [15667] = {.lex_state = 0},
  [15668] = {.lex_state = 0},
  [15669] = {.lex_state = 0},
  [15670] = {.lex_state = 0},
  [15671] = {.lex_state = 0},
  [15672] = {.lex_state = 0},
  [15673] = {.lex_state = 0},
  [15674] = {.lex_state = 0},
  [15675] = {.lex_state = 0},
  [15676] = {.lex_state = 0},
  [15677] = {.lex_state = 0},
  [15678] = {.lex_state = 0},
  [15679] = {.lex_state = 0},
  [15680] = {.lex_state = 0},
  [15681] = {.lex_state = 0},
  [15682] = {.lex_state = 7},
  [15683] = {.lex_state = 0},
  [15684] = {.lex_state = 0},
  [15685] = {.lex_state = 0},
  [15686] = {.lex_state = 0},
  [15687] = {.lex_state = 0},
  [15688] = {.lex_state = 0},
  [15689] = {.lex_state = 0},
  [15690] = {.lex_state = 0},
  [15691] = {.lex_state = 0},
  [15692] = {.lex_state = 0},
  [15693] = {.lex_state = 0},
  [15694] = {.lex_state = 0},
  [15695] = {.lex_state = 0},
  [15696] = {.lex_state = 7},
  [15697] = {.lex_state = 0},
  [15698] = {.lex_state = 0},
  [15699] = {.lex_state = 371},
  [15700] = {.lex_state = 0},
  [15701] = {.lex_state = 0},
  [15702] = {.lex_state = 0},
  [15703] = {.lex_state = 0},
  [15704] = {.lex_state = 0},
  [15705] = {.lex_state = 0},
  [15706] = {.lex_state = 0},
  [15707] = {.lex_state = 0},
  [15708] = {.lex_state = 0},
  [15709] = {.lex_state = 0},
  [15710] = {.lex_state = 0},
  [15711] = {.lex_state = 0},
  [15712] = {.lex_state = 0},
  [15713] = {.lex_state = 0},
  [15714] = {.lex_state = 0},
  [15715] = {.lex_state = 0},
  [15716] = {.lex_state = 373},
  [15717] = {.lex_state = 0},
  [15718] = {.lex_state = 0},
  [15719] = {.lex_state = 0},
  [15720] = {.lex_state = 0},
  [15721] = {.lex_state = 0},
  [15722] = {.lex_state = 0},
  [15723] = {.lex_state = 0},
  [15724] = {.lex_state = 0},
  [15725] = {.lex_state = 0},
  [15726] = {.lex_state = 0},
  [15727] = {.lex_state = 0},
  [15728] = {.lex_state = 82},
  [15729] = {.lex_state = 0},
  [15730] = {.lex_state = 0},
  [15731] = {.lex_state = 0},
  [15732] = {.lex_state = 0},
  [15733] = {.lex_state = 0},
  [15734] = {.lex_state = 371},
  [15735] = {.lex_state = 0},
  [15736] = {.lex_state = 0},
  [15737] = {.lex_state = 371},
  [15738] = {.lex_state = 0},
  [15739] = {.lex_state = 0},
  [15740] = {.lex_state = 0},
  [15741] = {.lex_state = 0},
  [15742] = {.lex_state = 0},
  [15743] = {.lex_state = 0},
  [15744] = {.lex_state = 0},
  [15745] = {.lex_state = 0},
  [15746] = {.lex_state = 0},
  [15747] = {.lex_state = 0},
  [15748] = {.lex_state = 0},
  [15749] = {.lex_state = 373},
  [15750] = {.lex_state = 0},
  [15751] = {.lex_state = 0},
  [15752] = {.lex_state = 7},
  [15753] = {.lex_state = 371},
  [15754] = {.lex_state = 371},
  [15755] = {.lex_state = 0},
  [15756] = {.lex_state = 0},
  [15757] = {.lex_state = 0},
  [15758] = {.lex_state = 0},
  [15759] = {.lex_state = 0},
  [15760] = {.lex_state = 0},
  [15761] = {.lex_state = 7},
  [15762] = {.lex_state = 0},
  [15763] = {.lex_state = 0},
  [15764] = {.lex_state = 0},
  [15765] = {.lex_state = 0},
  [15766] = {.lex_state = 0},
  [15767] = {.lex_state = 0},
  [15768] = {.lex_state = 0},
  [15769] = {.lex_state = 0},
  [15770] = {.lex_state = 0},
  [15771] = {.lex_state = 0},
  [15772] = {.lex_state = 0},
  [15773] = {.lex_state = 0},
  [15774] = {.lex_state = 0},
  [15775] = {.lex_state = 0},
  [15776] = {.lex_state = 0},
  [15777] = {.lex_state = 0},
  [15778] = {.lex_state = 0},
  [15779] = {.lex_state = 0},
  [15780] = {.lex_state = 0},
  [15781] = {.lex_state = 0},
  [15782] = {.lex_state = 7},
  [15783] = {.lex_state = 0},
  [15784] = {.lex_state = 0},
  [15785] = {.lex_state = 0},
  [15786] = {.lex_state = 0},
  [15787] = {.lex_state = 0},
  [15788] = {.lex_state = 7},
  [15789] = {.lex_state = 0},
  [15790] = {.lex_state = 0},
  [15791] = {.lex_state = 0},
  [15792] = {.lex_state = 0},
  [15793] = {.lex_state = 0},
  [15794] = {.lex_state = 7},
  [15795] = {.lex_state = 0},
  [15796] = {.lex_state = 0},
  [15797] = {.lex_state = 0},
  [15798] = {.lex_state = 0},
  [15799] = {.lex_state = 0},
  [15800] = {.lex_state = 0},
  [15801] = {.lex_state = 0},
  [15802] = {.lex_state = 0},
  [15803] = {.lex_state = 0},
  [15804] = {.lex_state = 373},
  [15805] = {.lex_state = 0},
  [15806] = {.lex_state = 0},
  [15807] = {.lex_state = 0},
  [15808] = {.lex_state = 0},
  [15809] = {.lex_state = 0},
  [15810] = {.lex_state = 0},
  [15811] = {.lex_state = 0},
  [15812] = {.lex_state = 0},
  [15813] = {.lex_state = 0},
  [15814] = {.lex_state = 0},
  [15815] = {.lex_state = 0},
  [15816] = {.lex_state = 82},
  [15817] = {.lex_state = 0},
  [15818] = {.lex_state = 0},
  [15819] = {.lex_state = 7},
  [15820] = {.lex_state = 0},
  [15821] = {.lex_state = 371},
  [15822] = {.lex_state = 371},
  [15823] = {.lex_state = 0},
  [15824] = {.lex_state = 0},
  [15825] = {.lex_state = 371},
  [15826] = {.lex_state = 0},
  [15827] = {.lex_state = 0},
  [15828] = {.lex_state = 0},
  [15829] = {.lex_state = 397},
  [15830] = {.lex_state = 7},
  [15831] = {.lex_state = 0},
  [15832] = {.lex_state = 0},
  [15833] = {.lex_state = 0},
  [15834] = {.lex_state = 0},
  [15835] = {.lex_state = 0},
  [15836] = {.lex_state = 0},
  [15837] = {.lex_state = 82},
  [15838] = {.lex_state = 0},
  [15839] = {.lex_state = 0},
  [15840] = {.lex_state = 0},
  [15841] = {.lex_state = 0},
  [15842] = {.lex_state = 0},
  [15843] = {.lex_state = 0},
  [15844] = {.lex_state = 0},
  [15845] = {.lex_state = 0},
  [15846] = {.lex_state = 0},
  [15847] = {.lex_state = 0},
  [15848] = {.lex_state = 0},
  [15849] = {.lex_state = 0},
  [15850] = {.lex_state = 0},
  [15851] = {.lex_state = 0},
  [15852] = {.lex_state = 0},
  [15853] = {.lex_state = 0},
  [15854] = {.lex_state = 0},
  [15855] = {.lex_state = 0},
  [15856] = {.lex_state = 0},
  [15857] = {.lex_state = 0},
  [15858] = {.lex_state = 0},
  [15859] = {.lex_state = 0},
  [15860] = {.lex_state = 0},
  [15861] = {.lex_state = 0},
  [15862] = {.lex_state = 0},
  [15863] = {.lex_state = 0},
  [15864] = {.lex_state = 0},
  [15865] = {.lex_state = 0},
  [15866] = {.lex_state = 0},
  [15867] = {.lex_state = 0},
  [15868] = {.lex_state = 0},
  [15869] = {.lex_state = 0},
  [15870] = {.lex_state = 0},
  [15871] = {.lex_state = 0},
  [15872] = {.lex_state = 0},
  [15873] = {.lex_state = 0},
  [15874] = {.lex_state = 0},
  [15875] = {.lex_state = 0},
  [15876] = {.lex_state = 0},
  [15877] = {.lex_state = 7},
  [15878] = {.lex_state = 0},
  [15879] = {.lex_state = 0},
  [15880] = {.lex_state = 0},
  [15881] = {.lex_state = 0},
  [15882] = {.lex_state = 0},
  [15883] = {.lex_state = 0},
  [15884] = {.lex_state = 0},
  [15885] = {.lex_state = 0},
  [15886] = {.lex_state = 0},
  [15887] = {.lex_state = 0},
  [15888] = {.lex_state = 0},
  [15889] = {.lex_state = 0},
  [15890] = {.lex_state = 0},
  [15891] = {.lex_state = 7},
  [15892] = {.lex_state = 0},
  [15893] = {.lex_state = 0},
  [15894] = {.lex_state = 371},
  [15895] = {.lex_state = 0},
  [15896] = {.lex_state = 0},
  [15897] = {.lex_state = 0},
  [15898] = {.lex_state = 0},
  [15899] = {.lex_state = 0},
  [15900] = {.lex_state = 0},
  [15901] = {.lex_state = 0},
  [15902] = {.lex_state = 0},
  [15903] = {.lex_state = 0},
  [15904] = {.lex_state = 0},
  [15905] = {.lex_state = 0},
  [15906] = {.lex_state = 0},
  [15907] = {.lex_state = 0},
  [15908] = {.lex_state = 0},
  [15909] = {.lex_state = 0},
  [15910] = {.lex_state = 0},
  [15911] = {.lex_state = 0},
  [15912] = {.lex_state = 0},
  [15913] = {.lex_state = 0},
  [15914] = {.lex_state = 0},
  [15915] = {.lex_state = 0},
  [15916] = {.lex_state = 0},
  [15917] = {.lex_state = 0},
  [15918] = {.lex_state = 371},
  [15919] = {.lex_state = 0},
  [15920] = {.lex_state = 0},
  [15921] = {.lex_state = 7},
  [15922] = {.lex_state = 0},
  [15923] = {.lex_state = 0},
  [15924] = {.lex_state = 0},
  [15925] = {.lex_state = 0},
  [15926] = {.lex_state = 0},
  [15927] = {.lex_state = 0},
  [15928] = {.lex_state = 371},
  [15929] = {.lex_state = 0},
  [15930] = {.lex_state = 371},
  [15931] = {.lex_state = 0},
  [15932] = {.lex_state = 0},
  [15933] = {.lex_state = 0},
  [15934] = {.lex_state = 0},
  [15935] = {.lex_state = 0},
  [15936] = {.lex_state = 0},
  [15937] = {.lex_state = 0},
  [15938] = {.lex_state = 7},
  [15939] = {.lex_state = 0},
  [15940] = {.lex_state = 0},
  [15941] = {.lex_state = 0},
  [15942] = {.lex_state = 0},
  [15943] = {.lex_state = 0},
  [15944] = {.lex_state = 0},
  [15945] = {.lex_state = 0},
  [15946] = {.lex_state = 7},
  [15947] = {.lex_state = 78},
  [15948] = {.lex_state = 0},
  [15949] = {.lex_state = 0},
  [15950] = {.lex_state = 0},
  [15951] = {.lex_state = 371},
  [15952] = {.lex_state = 0},
  [15953] = {.lex_state = 7},
  [15954] = {.lex_state = 0},
  [15955] = {.lex_state = 0},
  [15956] = {.lex_state = 0},
  [15957] = {.lex_state = 0},
  [15958] = {.lex_state = 0},
  [15959] = {.lex_state = 0},
  [15960] = {.lex_state = 0},
  [15961] = {.lex_state = 0},
  [15962] = {.lex_state = 0},
  [15963] = {.lex_state = 0},
  [15964] = {.lex_state = 0},
  [15965] = {.lex_state = 0},
  [15966] = {.lex_state = 7},
  [15967] = {.lex_state = 0},
  [15968] = {.lex_state = 0},
  [15969] = {.lex_state = 0},
  [15970] = {.lex_state = 0},
  [15971] = {.lex_state = 0},
  [15972] = {.lex_state = 0},
  [15973] = {.lex_state = 7},
  [15974] = {.lex_state = 0},
  [15975] = {.lex_state = 0},
  [15976] = {.lex_state = 0},
  [15977] = {.lex_state = 0},
  [15978] = {.lex_state = 7},
  [15979] = {.lex_state = 0},
  [15980] = {.lex_state = 0},
  [15981] = {.lex_state = 0},
  [15982] = {.lex_state = 0},
  [15983] = {.lex_state = 0},
  [15984] = {.lex_state = 0},
  [15985] = {.lex_state = 0},
  [15986] = {.lex_state = 0},
  [15987] = {.lex_state = 0},
  [15988] = {.lex_state = 0},
  [15989] = {.lex_state = 0},
  [15990] = {.lex_state = 0},
  [15991] = {.lex_state = 371},
  [15992] = {.lex_state = 0},
  [15993] = {.lex_state = 0},
  [15994] = {.lex_state = 0},
  [15995] = {.lex_state = 0},
  [15996] = {.lex_state = 0},
  [15997] = {.lex_state = 0},
  [15998] = {.lex_state = 0},
  [15999] = {.lex_state = 0},
  [16000] = {.lex_state = 0},
  [16001] = {.lex_state = 0},
  [16002] = {.lex_state = 0},
  [16003] = {.lex_state = 0},
  [16004] = {.lex_state = 0},
  [16005] = {.lex_state = 0},
  [16006] = {.lex_state = 26},
  [16007] = {.lex_state = 0},
  [16008] = {.lex_state = 0},
  [16009] = {.lex_state = 0},
  [16010] = {.lex_state = 0},
  [16011] = {.lex_state = 0},
  [16012] = {.lex_state = 0},
  [16013] = {.lex_state = 7},
  [16014] = {.lex_state = 42},
  [16015] = {.lex_state = 42},
  [16016] = {.lex_state = 0},
  [16017] = {.lex_state = 0},
  [16018] = {.lex_state = 0},
  [16019] = {.lex_state = 0},
  [16020] = {.lex_state = 0},
  [16021] = {.lex_state = 0},
  [16022] = {.lex_state = 0},
  [16023] = {.lex_state = 0},
  [16024] = {.lex_state = 0},
  [16025] = {.lex_state = 0},
  [16026] = {.lex_state = 0},
  [16027] = {.lex_state = 0},
  [16028] = {.lex_state = 373},
  [16029] = {.lex_state = 0},
  [16030] = {.lex_state = 0},
  [16031] = {.lex_state = 371},
  [16032] = {.lex_state = 7},
  [16033] = {.lex_state = 0},
  [16034] = {.lex_state = 0},
  [16035] = {.lex_state = 0},
  [16036] = {.lex_state = 81},
  [16037] = {.lex_state = 371},
  [16038] = {.lex_state = 0},
  [16039] = {.lex_state = 0},
  [16040] = {.lex_state = 0},
  [16041] = {.lex_state = 7},
  [16042] = {.lex_state = 0},
  [16043] = {.lex_state = 0},
  [16044] = {.lex_state = 0},
  [16045] = {.lex_state = 371},
  [16046] = {.lex_state = 0},
  [16047] = {.lex_state = 0},
  [16048] = {.lex_state = 0},
  [16049] = {.lex_state = 0},
  [16050] = {.lex_state = 0},
  [16051] = {.lex_state = 0},
  [16052] = {.lex_state = 0},
  [16053] = {.lex_state = 371},
  [16054] = {.lex_state = 0},
  [16055] = {.lex_state = 371},
  [16056] = {.lex_state = 371},
  [16057] = {.lex_state = 0},
  [16058] = {.lex_state = 0},
  [16059] = {.lex_state = 0},
  [16060] = {.lex_state = 0},
  [16061] = {.lex_state = 0},
  [16062] = {.lex_state = 26},
  [16063] = {.lex_state = 0},
  [16064] = {.lex_state = 0},
  [16065] = {.lex_state = 0},
  [16066] = {.lex_state = 0},
  [16067] = {.lex_state = 0},
  [16068] = {.lex_state = 0},
  [16069] = {.lex_state = 0},
  [16070] = {.lex_state = 0},
  [16071] = {.lex_state = 0},
  [16072] = {.lex_state = 371},
  [16073] = {.lex_state = 0},
  [16074] = {.lex_state = 0},
  [16075] = {.lex_state = 0},
  [16076] = {.lex_state = 0},
  [16077] = {.lex_state = 0},
  [16078] = {.lex_state = 0},
  [16079] = {.lex_state = 0},
  [16080] = {.lex_state = 0},
  [16081] = {.lex_state = 0},
  [16082] = {.lex_state = 0},
  [16083] = {.lex_state = 0},
  [16084] = {.lex_state = 0},
  [16085] = {.lex_state = 0},
  [16086] = {.lex_state = 0},
  [16087] = {.lex_state = 0},
  [16088] = {.lex_state = 371},
  [16089] = {.lex_state = 0},
  [16090] = {.lex_state = 371},
  [16091] = {.lex_state = 0},
  [16092] = {.lex_state = 0},
  [16093] = {.lex_state = 0},
  [16094] = {.lex_state = 0},
  [16095] = {.lex_state = 0},
  [16096] = {.lex_state = 0},
  [16097] = {.lex_state = 0},
  [16098] = {.lex_state = 0},
  [16099] = {.lex_state = 0},
  [16100] = {.lex_state = 0},
  [16101] = {.lex_state = 371},
  [16102] = {.lex_state = 0},
  [16103] = {.lex_state = 0},
  [16104] = {.lex_state = 0},
  [16105] = {.lex_state = 0},
  [16106] = {.lex_state = 0},
  [16107] = {.lex_state = 0},
  [16108] = {.lex_state = 7},
  [16109] = {.lex_state = 0},
  [16110] = {.lex_state = 0},
  [16111] = {.lex_state = 0},
  [16112] = {.lex_state = 0},
  [16113] = {.lex_state = 0},
  [16114] = {.lex_state = 0},
  [16115] = {.lex_state = 0},
  [16116] = {.lex_state = 7},
  [16117] = {.lex_state = 0},
  [16118] = {.lex_state = 0},
  [16119] = {.lex_state = 0},
  [16120] = {.lex_state = 0},
  [16121] = {.lex_state = 0},
  [16122] = {.lex_state = 0},
  [16123] = {.lex_state = 0},
  [16124] = {.lex_state = 0},
  [16125] = {.lex_state = 0},
  [16126] = {.lex_state = 0},
  [16127] = {.lex_state = 0},
  [16128] = {.lex_state = 0},
  [16129] = {.lex_state = 0},
  [16130] = {.lex_state = 371},
  [16131] = {.lex_state = 0},
  [16132] = {.lex_state = 0},
  [16133] = {.lex_state = 0},
  [16134] = {.lex_state = 0},
  [16135] = {.lex_state = 0},
  [16136] = {.lex_state = 0},
  [16137] = {.lex_state = 7},
  [16138] = {.lex_state = 0},
  [16139] = {.lex_state = 0},
  [16140] = {.lex_state = 0},
  [16141] = {.lex_state = 0},
  [16142] = {.lex_state = 42},
  [16143] = {.lex_state = 0},
  [16144] = {.lex_state = 0},
  [16145] = {.lex_state = 371},
  [16146] = {.lex_state = 0},
  [16147] = {.lex_state = 0},
  [16148] = {.lex_state = 0},
  [16149] = {.lex_state = 0},
  [16150] = {.lex_state = 7},
  [16151] = {.lex_state = 0},
  [16152] = {.lex_state = 0},
  [16153] = {.lex_state = 0},
  [16154] = {.lex_state = 0},
  [16155] = {.lex_state = 0},
  [16156] = {.lex_state = 0},
  [16157] = {.lex_state = 0},
  [16158] = {.lex_state = 0},
  [16159] = {.lex_state = 0},
  [16160] = {.lex_state = 7},
  [16161] = {.lex_state = 0},
  [16162] = {.lex_state = 0},
  [16163] = {.lex_state = 0},
  [16164] = {.lex_state = 7},
  [16165] = {.lex_state = 0},
  [16166] = {.lex_state = 0},
  [16167] = {.lex_state = 0},
  [16168] = {.lex_state = 0},
  [16169] = {.lex_state = 7},
  [16170] = {.lex_state = 371},
  [16171] = {.lex_state = 0},
  [16172] = {.lex_state = 373},
  [16173] = {.lex_state = 373},
  [16174] = {.lex_state = 0},
  [16175] = {.lex_state = 0},
  [16176] = {.lex_state = 0},
  [16177] = {.lex_state = 0},
  [16178] = {.lex_state = 371},
  [16179] = {.lex_state = 373},
  [16180] = {.lex_state = 0},
  [16181] = {.lex_state = 0},
  [16182] = {.lex_state = 0},
  [16183] = {.lex_state = 0},
  [16184] = {.lex_state = 0},
  [16185] = {.lex_state = 0},
  [16186] = {.lex_state = 0},
  [16187] = {.lex_state = 0},
  [16188] = {.lex_state = 0},
  [16189] = {.lex_state = 371},
  [16190] = {.lex_state = 371},
  [16191] = {.lex_state = 0},
  [16192] = {.lex_state = 0},
  [16193] = {.lex_state = 0},
  [16194] = {.lex_state = 0},
  [16195] = {.lex_state = 0},
  [16196] = {.lex_state = 7},
  [16197] = {.lex_state = 0},
  [16198] = {.lex_state = 0},
  [16199] = {.lex_state = 0},
  [16200] = {.lex_state = 0},
  [16201] = {.lex_state = 0},
  [16202] = {.lex_state = 0},
  [16203] = {.lex_state = 0},
  [16204] = {.lex_state = 0},
  [16205] = {.lex_state = 0},
  [16206] = {.lex_state = 0},
  [16207] = {.lex_state = 0},
  [16208] = {.lex_state = 0},
  [16209] = {.lex_state = 0},
  [16210] = {.lex_state = 0},
  [16211] = {.lex_state = 0},
  [16212] = {.lex_state = 0},
  [16213] = {.lex_state = 0},
  [16214] = {.lex_state = 0},
  [16215] = {.lex_state = 0},
  [16216] = {.lex_state = 0},
  [16217] = {.lex_state = 0},
  [16218] = {.lex_state = 0},
  [16219] = {.lex_state = 0},
  [16220] = {.lex_state = 0},
  [16221] = {.lex_state = 0},
  [16222] = {.lex_state = 0},
  [16223] = {.lex_state = 0},
  [16224] = {.lex_state = 0},
  [16225] = {.lex_state = 0},
  [16226] = {.lex_state = 0},
  [16227] = {.lex_state = 0},
  [16228] = {.lex_state = 0},
  [16229] = {.lex_state = 7},
  [16230] = {.lex_state = 0},
  [16231] = {.lex_state = 0},
  [16232] = {.lex_state = 7},
  [16233] = {.lex_state = 82},
  [16234] = {.lex_state = 0},
  [16235] = {.lex_state = 0},
  [16236] = {.lex_state = 0},
  [16237] = {.lex_state = 0},
  [16238] = {.lex_state = 0},
  [16239] = {.lex_state = 371},
  [16240] = {.lex_state = 0},
  [16241] = {.lex_state = 0},
  [16242] = {.lex_state = 0},
  [16243] = {.lex_state = 371},
  [16244] = {.lex_state = 0},
  [16245] = {.lex_state = 0},
  [16246] = {.lex_state = 0},
  [16247] = {.lex_state = 0},
  [16248] = {.lex_state = 0},
  [16249] = {.lex_state = 0},
  [16250] = {.lex_state = 0},
  [16251] = {.lex_state = 0},
  [16252] = {.lex_state = 0},
  [16253] = {.lex_state = 0},
  [16254] = {.lex_state = 0},
  [16255] = {.lex_state = 0},
  [16256] = {.lex_state = 0},
  [16257] = {.lex_state = 0},
  [16258] = {.lex_state = 0},
  [16259] = {.lex_state = 0},
  [16260] = {.lex_state = 0},
  [16261] = {.lex_state = 0},
  [16262] = {.lex_state = 0},
  [16263] = {.lex_state = 0},
  [16264] = {.lex_state = 7},
  [16265] = {.lex_state = 0},
  [16266] = {.lex_state = 0},
  [16267] = {.lex_state = 0},
  [16268] = {.lex_state = 0},
  [16269] = {.lex_state = 0},
  [16270] = {.lex_state = 0},
  [16271] = {.lex_state = 7},
  [16272] = {.lex_state = 0},
  [16273] = {.lex_state = 0},
  [16274] = {.lex_state = 0},
  [16275] = {.lex_state = 373},
  [16276] = {.lex_state = 0},
  [16277] = {.lex_state = 0},
  [16278] = {.lex_state = 0},
  [16279] = {.lex_state = 0},
  [16280] = {.lex_state = 0},
  [16281] = {.lex_state = 0},
  [16282] = {.lex_state = 0},
  [16283] = {.lex_state = 0},
  [16284] = {.lex_state = 0},
  [16285] = {.lex_state = 0},
  [16286] = {.lex_state = 0},
  [16287] = {.lex_state = 0},
  [16288] = {.lex_state = 0},
  [16289] = {.lex_state = 0},
  [16290] = {.lex_state = 0},
  [16291] = {.lex_state = 0},
  [16292] = {.lex_state = 0},
  [16293] = {.lex_state = 0},
  [16294] = {.lex_state = 7},
  [16295] = {.lex_state = 7},
  [16296] = {.lex_state = 7},
  [16297] = {.lex_state = 0},
  [16298] = {.lex_state = 0},
  [16299] = {.lex_state = 0},
  [16300] = {.lex_state = 0},
  [16301] = {.lex_state = 0},
  [16302] = {.lex_state = 0},
  [16303] = {.lex_state = 0},
  [16304] = {.lex_state = 0},
  [16305] = {.lex_state = 371},
  [16306] = {.lex_state = 0},
  [16307] = {.lex_state = 0},
  [16308] = {.lex_state = 0},
  [16309] = {.lex_state = 0},
  [16310] = {.lex_state = 0},
  [16311] = {.lex_state = 0},
  [16312] = {.lex_state = 7},
  [16313] = {.lex_state = 0},
  [16314] = {.lex_state = 0},
  [16315] = {.lex_state = 0},
  [16316] = {.lex_state = 0},
  [16317] = {.lex_state = 0},
  [16318] = {.lex_state = 0},
  [16319] = {.lex_state = 0},
  [16320] = {.lex_state = 0},
  [16321] = {.lex_state = 0},
  [16322] = {.lex_state = 0},
  [16323] = {.lex_state = 0},
  [16324] = {.lex_state = 0},
  [16325] = {.lex_state = 0},
  [16326] = {.lex_state = 7},
  [16327] = {.lex_state = 0},
  [16328] = {.lex_state = 0},
  [16329] = {.lex_state = 0},
  [16330] = {.lex_state = 0},
  [16331] = {.lex_state = 0},
  [16332] = {.lex_state = 371},
  [16333] = {.lex_state = 0},
  [16334] = {.lex_state = 0},
  [16335] = {.lex_state = 7},
  [16336] = {.lex_state = 0},
  [16337] = {.lex_state = 0},
  [16338] = {.lex_state = 0},
  [16339] = {.lex_state = 0},
  [16340] = {.lex_state = 0},
  [16341] = {.lex_state = 0},
  [16342] = {.lex_state = 0},
  [16343] = {.lex_state = 373},
  [16344] = {.lex_state = 371},
  [16345] = {.lex_state = 0},
  [16346] = {.lex_state = 0},
  [16347] = {.lex_state = 0},
  [16348] = {.lex_state = 0},
  [16349] = {.lex_state = 0},
  [16350] = {.lex_state = 0},
  [16351] = {.lex_state = 0},
  [16352] = {.lex_state = 373},
  [16353] = {.lex_state = 0},
  [16354] = {.lex_state = 0},
  [16355] = {.lex_state = 0},
  [16356] = {.lex_state = 0},
  [16357] = {.lex_state = 0},
  [16358] = {.lex_state = 0},
  [16359] = {.lex_state = 0},
  [16360] = {.lex_state = 42},
  [16361] = {.lex_state = 42},
  [16362] = {.lex_state = 7},
  [16363] = {.lex_state = 0},
  [16364] = {.lex_state = 0},
  [16365] = {.lex_state = 371},
  [16366] = {.lex_state = 0},
  [16367] = {.lex_state = 0},
  [16368] = {.lex_state = 0},
  [16369] = {.lex_state = 371},
  [16370] = {.lex_state = 0},
  [16371] = {.lex_state = 0},
  [16372] = {.lex_state = 63},
  [16373] = {.lex_state = 0},
  [16374] = {.lex_state = 0},
  [16375] = {.lex_state = 0},
  [16376] = {.lex_state = 0},
  [16377] = {.lex_state = 0},
  [16378] = {.lex_state = 0},
  [16379] = {.lex_state = 0},
  [16380] = {.lex_state = 371},
  [16381] = {.lex_state = 0},
  [16382] = {.lex_state = 0},
  [16383] = {.lex_state = 42},
  [16384] = {.lex_state = 42},
  [16385] = {.lex_state = 371},
  [16386] = {.lex_state = 0},
  [16387] = {.lex_state = 0},
  [16388] = {.lex_state = 0},
  [16389] = {.lex_state = 0},
  [16390] = {.lex_state = 0},
  [16391] = {.lex_state = 371},
  [16392] = {.lex_state = 0},
  [16393] = {.lex_state = 0},
  [16394] = {.lex_state = 0},
  [16395] = {.lex_state = 0},
  [16396] = {.lex_state = 0},
  [16397] = {.lex_state = 0},
  [16398] = {.lex_state = 0},
  [16399] = {.lex_state = 0},
  [16400] = {.lex_state = 0},
  [16401] = {.lex_state = 371},
  [16402] = {.lex_state = 7},
  [16403] = {.lex_state = 0},
  [16404] = {.lex_state = 42},
  [16405] = {.lex_state = 42},
  [16406] = {.lex_state = 0},
  [16407] = {.lex_state = 0},
  [16408] = {.lex_state = 0},
  [16409] = {.lex_state = 7},
  [16410] = {.lex_state = 0},
  [16411] = {.lex_state = 0},
  [16412] = {.lex_state = 0},
  [16413] = {.lex_state = 373},
  [16414] = {.lex_state = 7},
  [16415] = {.lex_state = 0},
  [16416] = {.lex_state = 371},
  [16417] = {.lex_state = 0},
  [16418] = {.lex_state = 0},
  [16419] = {.lex_state = 42},
  [16420] = {.lex_state = 42},
  [16421] = {.lex_state = 0},
  [16422] = {.lex_state = 0},
  [16423] = {.lex_state = 371},
  [16424] = {.lex_state = 7},
  [16425] = {.lex_state = 0},
  [16426] = {.lex_state = 26},
  [16427] = {.lex_state = 371},
  [16428] = {.lex_state = 0},
  [16429] = {.lex_state = 42},
  [16430] = {.lex_state = 42},
  [16431] = {.lex_state = 0},
  [16432] = {.lex_state = 0},
  [16433] = {.lex_state = 0},
  [16434] = {.lex_state = 0},
  [16435] = {.lex_state = 0},
  [16436] = {.lex_state = 42},
  [16437] = {.lex_state = 42},
  [16438] = {.lex_state = 373},
  [16439] = {.lex_state = 371},
  [16440] = {.lex_state = 0},
  [16441] = {.lex_state = 371},
  [16442] = {.lex_state = 0},
  [16443] = {.lex_state = 42},
  [16444] = {.lex_state = 42},
  [16445] = {.lex_state = 0},
  [16446] = {.lex_state = 0},
  [16447] = {.lex_state = 0},
  [16448] = {.lex_state = 0},
  [16449] = {.lex_state = 0},
  [16450] = {.lex_state = 0},
  [16451] = {.lex_state = 0},
  [16452] = {.lex_state = 371},
  [16453] = {.lex_state = 81},
  [16454] = {.lex_state = 0},
  [16455] = {.lex_state = 0},
  [16456] = {.lex_state = 0},
  [16457] = {.lex_state = 0},
  [16458] = {.lex_state = 0},
  [16459] = {.lex_state = 0},
  [16460] = {.lex_state = 0},
  [16461] = {.lex_state = 0},
  [16462] = {.lex_state = 373},
  [16463] = {.lex_state = 7},
  [16464] = {.lex_state = 0},
  [16465] = {.lex_state = 0},
  [16466] = {.lex_state = 0},
  [16467] = {.lex_state = 0},
  [16468] = {.lex_state = 0},
  [16469] = {.lex_state = 0},
  [16470] = {.lex_state = 0},
  [16471] = {.lex_state = 0},
  [16472] = {.lex_state = 0},
  [16473] = {.lex_state = 0},
  [16474] = {.lex_state = 42},
  [16475] = {.lex_state = 42},
  [16476] = {.lex_state = 0},
  [16477] = {.lex_state = 0},
  [16478] = {.lex_state = 0},
  [16479] = {.lex_state = 7},
  [16480] = {.lex_state = 7},
  [16481] = {.lex_state = 7},
  [16482] = {.lex_state = 0},
  [16483] = {.lex_state = 0},
  [16484] = {.lex_state = 0},
  [16485] = {.lex_state = 371},
  [16486] = {.lex_state = 0},
  [16487] = {.lex_state = 0},
  [16488] = {.lex_state = 0},
  [16489] = {.lex_state = 0},
  [16490] = {.lex_state = 0},
  [16491] = {.lex_state = 0},
  [16492] = {.lex_state = 0},
  [16493] = {.lex_state = 0},
  [16494] = {.lex_state = 0},
  [16495] = {.lex_state = 0},
  [16496] = {.lex_state = 0},
  [16497] = {.lex_state = 0},
  [16498] = {.lex_state = 0},
  [16499] = {.lex_state = 0},
  [16500] = {.lex_state = 0},
  [16501] = {.lex_state = 0},
  [16502] = {.lex_state = 0},
  [16503] = {.lex_state = 0},
  [16504] = {.lex_state = 0},
  [16505] = {.lex_state = 371},
  [16506] = {.lex_state = 371},
  [16507] = {.lex_state = 371},
  [16508] = {.lex_state = 0},
  [16509] = {.lex_state = 0},
  [16510] = {.lex_state = 7},
  [16511] = {.lex_state = 0},
  [16512] = {.lex_state = 0},
  [16513] = {.lex_state = 0},
  [16514] = {.lex_state = 0},
  [16515] = {.lex_state = 0},
  [16516] = {.lex_state = 26},
  [16517] = {.lex_state = 0},
  [16518] = {.lex_state = 0},
  [16519] = {.lex_state = 0},
  [16520] = {.lex_state = 0},
  [16521] = {.lex_state = 0},
  [16522] = {.lex_state = 0},
  [16523] = {.lex_state = 0},
  [16524] = {.lex_state = 0},
  [16525] = {.lex_state = 0},
  [16526] = {.lex_state = 0},
  [16527] = {.lex_state = 0},
  [16528] = {.lex_state = 0},
  [16529] = {.lex_state = 0},
  [16530] = {.lex_state = 0},
  [16531] = {.lex_state = 0},
  [16532] = {.lex_state = 0},
  [16533] = {.lex_state = 0},
  [16534] = {.lex_state = 0},
  [16535] = {.lex_state = 0},
  [16536] = {.lex_state = 0},
  [16537] = {.lex_state = 0},
  [16538] = {.lex_state = 0},
  [16539] = {.lex_state = 0},
  [16540] = {.lex_state = 0},
  [16541] = {.lex_state = 0},
  [16542] = {.lex_state = 0},
  [16543] = {.lex_state = 0},
  [16544] = {.lex_state = 0},
  [16545] = {.lex_state = 0},
  [16546] = {.lex_state = 0},
  [16547] = {.lex_state = 0},
  [16548] = {.lex_state = 0},
  [16549] = {.lex_state = 0},
  [16550] = {.lex_state = 0},
  [16551] = {.lex_state = 0},
  [16552] = {.lex_state = 7},
  [16553] = {.lex_state = 0},
  [16554] = {.lex_state = 0},
  [16555] = {.lex_state = 7},
  [16556] = {.lex_state = 0},
  [16557] = {.lex_state = 0},
  [16558] = {.lex_state = 0},
  [16559] = {.lex_state = 0},
  [16560] = {.lex_state = 0},
  [16561] = {.lex_state = 0},
  [16562] = {.lex_state = 0},
  [16563] = {.lex_state = 0},
  [16564] = {.lex_state = 0},
  [16565] = {.lex_state = 0},
  [16566] = {.lex_state = 0},
  [16567] = {.lex_state = 0},
  [16568] = {.lex_state = 0},
  [16569] = {.lex_state = 0},
  [16570] = {.lex_state = 7},
  [16571] = {.lex_state = 0},
  [16572] = {.lex_state = 26},
  [16573] = {.lex_state = 0},
  [16574] = {.lex_state = 0},
  [16575] = {.lex_state = 371},
  [16576] = {.lex_state = 0},
  [16577] = {.lex_state = 0},
  [16578] = {.lex_state = 0},
  [16579] = {.lex_state = 0},
  [16580] = {.lex_state = 0},
  [16581] = {.lex_state = 0},
  [16582] = {.lex_state = 0},
  [16583] = {.lex_state = 0},
  [16584] = {.lex_state = 0},
  [16585] = {.lex_state = 371},
  [16586] = {.lex_state = 0},
  [16587] = {.lex_state = 0},
  [16588] = {.lex_state = 0},
  [16589] = {.lex_state = 0},
  [16590] = {.lex_state = 0},
  [16591] = {.lex_state = 7},
  [16592] = {.lex_state = 7},
  [16593] = {.lex_state = 7},
  [16594] = {.lex_state = 0},
  [16595] = {.lex_state = 0},
  [16596] = {.lex_state = 0},
  [16597] = {.lex_state = 0},
  [16598] = {.lex_state = 0},
  [16599] = {.lex_state = 0},
  [16600] = {.lex_state = 0},
  [16601] = {.lex_state = 7},
  [16602] = {.lex_state = 0},
  [16603] = {.lex_state = 0},
  [16604] = {.lex_state = 0},
  [16605] = {.lex_state = 0},
  [16606] = {.lex_state = 0},
  [16607] = {.lex_state = 0},
  [16608] = {.lex_state = 0},
  [16609] = {.lex_state = 0},
  [16610] = {.lex_state = 0},
  [16611] = {.lex_state = 0},
  [16612] = {.lex_state = 0},
  [16613] = {.lex_state = 0},
  [16614] = {.lex_state = 0},
  [16615] = {.lex_state = 0},
  [16616] = {.lex_state = 0},
  [16617] = {.lex_state = 0},
  [16618] = {.lex_state = 0},
  [16619] = {.lex_state = 0},
  [16620] = {.lex_state = 0},
  [16621] = {.lex_state = 0},
  [16622] = {.lex_state = 0},
  [16623] = {.lex_state = 0},
  [16624] = {.lex_state = 0},
  [16625] = {.lex_state = 0},
  [16626] = {.lex_state = 0},
  [16627] = {.lex_state = 0},
  [16628] = {.lex_state = 0},
  [16629] = {.lex_state = 0},
  [16630] = {.lex_state = 0},
  [16631] = {.lex_state = 371},
  [16632] = {.lex_state = 371},
  [16633] = {.lex_state = 0},
  [16634] = {.lex_state = 0},
  [16635] = {.lex_state = 0},
  [16636] = {.lex_state = 7},
  [16637] = {.lex_state = 0},
  [16638] = {.lex_state = 0},
  [16639] = {.lex_state = 0},
  [16640] = {.lex_state = 371},
  [16641] = {.lex_state = 0},
  [16642] = {.lex_state = 371},
  [16643] = {.lex_state = 0},
  [16644] = {.lex_state = 0},
  [16645] = {.lex_state = 7},
  [16646] = {.lex_state = 7},
  [16647] = {.lex_state = 0},
  [16648] = {.lex_state = 0},
  [16649] = {.lex_state = 7},
  [16650] = {.lex_state = 371},
  [16651] = {.lex_state = 0},
  [16652] = {.lex_state = 0},
  [16653] = {.lex_state = 0},
  [16654] = {.lex_state = 371},
  [16655] = {.lex_state = 0},
  [16656] = {.lex_state = 371},
  [16657] = {.lex_state = 0},
  [16658] = {.lex_state = 0},
  [16659] = {.lex_state = 371},
  [16660] = {.lex_state = 0},
  [16661] = {.lex_state = 0},
  [16662] = {.lex_state = 371},
  [16663] = {.lex_state = 399},
  [16664] = {.lex_state = 0},
  [16665] = {.lex_state = 0},
  [16666] = {.lex_state = 0},
  [16667] = {.lex_state = 371},
  [16668] = {.lex_state = 7},
  [16669] = {.lex_state = 0},
  [16670] = {.lex_state = 0},
  [16671] = {.lex_state = 371},
  [16672] = {.lex_state = 371},
  [16673] = {.lex_state = 399},
  [16674] = {.lex_state = 0},
  [16675] = {.lex_state = 373},
  [16676] = {.lex_state = 0},
  [16677] = {.lex_state = 0},
  [16678] = {.lex_state = 371},
  [16679] = {.lex_state = 371},
  [16680] = {.lex_state = 0},
  [16681] = {.lex_state = 371},
  [16682] = {.lex_state = 0},
  [16683] = {.lex_state = 0},
  [16684] = {.lex_state = 0},
  [16685] = {.lex_state = 371},
  [16686] = {.lex_state = 371},
  [16687] = {.lex_state = 0},
  [16688] = {.lex_state = 0},
  [16689] = {.lex_state = 371},
  [16690] = {.lex_state = 371},
  [16691] = {.lex_state = 371},
  [16692] = {.lex_state = 0},
  [16693] = {.lex_state = 371},
  [16694] = {.lex_state = 371},
  [16695] = {.lex_state = 0},
  [16696] = {.lex_state = 7},
  [16697] = {.lex_state = 0},
  [16698] = {.lex_state = 7},
  [16699] = {.lex_state = 371},
  [16700] = {.lex_state = 371},
  [16701] = {.lex_state = 371},
  [16702] = {.lex_state = 0},
  [16703] = {.lex_state = 7},
  [16704] = {.lex_state = 371},
  [16705] = {.lex_state = 7},
  [16706] = {.lex_state = 0},
  [16707] = {.lex_state = 7},
  [16708] = {.lex_state = 7},
  [16709] = {.lex_state = 0},
  [16710] = {.lex_state = 371},
  [16711] = {.lex_state = 0},
  [16712] = {.lex_state = 0},
  [16713] = {.lex_state = 7},
  [16714] = {.lex_state = 7},
  [16715] = {.lex_state = 7},
  [16716] = {.lex_state = 371},
  [16717] = {.lex_state = 371},
  [16718] = {.lex_state = 0},
  [16719] = {.lex_state = 0},
  [16720] = {.lex_state = 7},
  [16721] = {.lex_state = 371},
  [16722] = {.lex_state = 371},
  [16723] = {.lex_state = 371},
  [16724] = {.lex_state = 371},
  [16725] = {.lex_state = 0},
  [16726] = {.lex_state = 371},
  [16727] = {.lex_state = 371},
  [16728] = {.lex_state = 7},
  [16729] = {.lex_state = 0},
  [16730] = {.lex_state = 0},
  [16731] = {.lex_state = 7},
  [16732] = {.lex_state = 7},
  [16733] = {.lex_state = 0},
  [16734] = {.lex_state = 7},
  [16735] = {.lex_state = 0},
  [16736] = {.lex_state = 0},
  [16737] = {.lex_state = 0},
  [16738] = {.lex_state = 0},
  [16739] = {.lex_state = 0},
  [16740] = {.lex_state = 0},
  [16741] = {.lex_state = 371},
  [16742] = {.lex_state = 0},
  [16743] = {.lex_state = 0},
  [16744] = {.lex_state = 0},
  [16745] = {.lex_state = 371},
  [16746] = {.lex_state = 0},
  [16747] = {.lex_state = 0},
  [16748] = {.lex_state = 7},
  [16749] = {.lex_state = 0},
  [16750] = {.lex_state = 0},
  [16751] = {.lex_state = 371},
  [16752] = {.lex_state = 371},
  [16753] = {.lex_state = 0},
  [16754] = {.lex_state = 82},
  [16755] = {.lex_state = 0},
  [16756] = {.lex_state = 0},
  [16757] = {.lex_state = 7},
  [16758] = {.lex_state = 371},
  [16759] = {.lex_state = 371},
  [16760] = {.lex_state = 371},
  [16761] = {.lex_state = 371},
  [16762] = {.lex_state = 0},
  [16763] = {.lex_state = 371},
  [16764] = {.lex_state = 0},
  [16765] = {.lex_state = 0},
  [16766] = {.lex_state = 0},
  [16767] = {.lex_state = 371},
  [16768] = {.lex_state = 0},
  [16769] = {.lex_state = 371},
  [16770] = {.lex_state = 0},
  [16771] = {.lex_state = 0},
  [16772] = {.lex_state = 371},
  [16773] = {.lex_state = 0},
  [16774] = {.lex_state = 371},
  [16775] = {.lex_state = 0},
  [16776] = {.lex_state = 0},
  [16777] = {.lex_state = 0},
  [16778] = {.lex_state = 0},
  [16779] = {.lex_state = 371},
  [16780] = {.lex_state = 371},
  [16781] = {.lex_state = 0},
  [16782] = {.lex_state = 0},
  [16783] = {.lex_state = 371},
  [16784] = {.lex_state = 371},
  [16785] = {.lex_state = 0},
  [16786] = {.lex_state = 0},
  [16787] = {.lex_state = 7},
  [16788] = {.lex_state = 7},
  [16789] = {.lex_state = 0},
  [16790] = {.lex_state = 7},
  [16791] = {.lex_state = 371},
  [16792] = {.lex_state = 7},
  [16793] = {.lex_state = 7},
  [16794] = {.lex_state = 7},
  [16795] = {.lex_state = 0},
  [16796] = {.lex_state = 7},
  [16797] = {.lex_state = 371},
  [16798] = {.lex_state = 0},
  [16799] = {.lex_state = 0},
  [16800] = {.lex_state = 7},
  [16801] = {.lex_state = 7},
  [16802] = {.lex_state = 7},
  [16803] = {.lex_state = 371},
  [16804] = {.lex_state = 371},
  [16805] = {.lex_state = 0},
  [16806] = {.lex_state = 0},
  [16807] = {.lex_state = 0},
  [16808] = {.lex_state = 371},
  [16809] = {.lex_state = 0},
  [16810] = {.lex_state = 371},
  [16811] = {.lex_state = 7},
  [16812] = {.lex_state = 0},
  [16813] = {.lex_state = 63},
  [16814] = {.lex_state = 371},
  [16815] = {.lex_state = 63},
  [16816] = {.lex_state = 371},
  [16817] = {.lex_state = 0},
  [16818] = {.lex_state = 371},
  [16819] = {.lex_state = 0},
  [16820] = {.lex_state = 0},
  [16821] = {.lex_state = 0},
  [16822] = {.lex_state = 0},
  [16823] = {.lex_state = 0},
  [16824] = {.lex_state = 371},
  [16825] = {.lex_state = 371},
  [16826] = {.lex_state = 0},
  [16827] = {.lex_state = 0},
  [16828] = {.lex_state = 371},
  [16829] = {.lex_state = 0},
  [16830] = {.lex_state = 0},
  [16831] = {.lex_state = 0},
  [16832] = {.lex_state = 371},
  [16833] = {.lex_state = 371},
  [16834] = {.lex_state = 0},
  [16835] = {.lex_state = 371},
  [16836] = {.lex_state = 371},
  [16837] = {.lex_state = 371},
  [16838] = {.lex_state = 371},
  [16839] = {.lex_state = 0},
  [16840] = {.lex_state = 7},
  [16841] = {.lex_state = 0},
  [16842] = {.lex_state = 0},
  [16843] = {.lex_state = 0},
  [16844] = {.lex_state = 371},
  [16845] = {.lex_state = 0},
  [16846] = {.lex_state = 0},
  [16847] = {.lex_state = 0},
  [16848] = {.lex_state = 371},
  [16849] = {.lex_state = 0},
  [16850] = {.lex_state = 371},
  [16851] = {.lex_state = 0},
  [16852] = {.lex_state = 0},
  [16853] = {.lex_state = 371},
  [16854] = {.lex_state = 7},
  [16855] = {.lex_state = 371},
  [16856] = {.lex_state = 0},
  [16857] = {.lex_state = 371},
  [16858] = {.lex_state = 371},
  [16859] = {.lex_state = 0},
  [16860] = {.lex_state = 0},
  [16861] = {.lex_state = 0},
  [16862] = {.lex_state = 0},
  [16863] = {.lex_state = 371},
  [16864] = {.lex_state = 371},
  [16865] = {.lex_state = 0},
  [16866] = {.lex_state = 371},
  [16867] = {.lex_state = 0},
  [16868] = {.lex_state = 0},
  [16869] = {.lex_state = 373},
  [16870] = {.lex_state = 371},
  [16871] = {.lex_state = 7},
  [16872] = {.lex_state = 0},
  [16873] = {.lex_state = 371},
  [16874] = {.lex_state = 371},
  [16875] = {.lex_state = 0},
  [16876] = {.lex_state = 0},
  [16877] = {.lex_state = 0},
  [16878] = {.lex_state = 0},
  [16879] = {.lex_state = 0},
  [16880] = {.lex_state = 0},
  [16881] = {.lex_state = 0},
  [16882] = {.lex_state = 0},
  [16883] = {.lex_state = 371},
  [16884] = {.lex_state = 371},
  [16885] = {.lex_state = 371},
  [16886] = {.lex_state = 0},
  [16887] = {.lex_state = 371},
  [16888] = {.lex_state = 371},
  [16889] = {.lex_state = 0},
  [16890] = {.lex_state = 371},
  [16891] = {.lex_state = 371},
  [16892] = {.lex_state = 371},
  [16893] = {.lex_state = 371},
  [16894] = {.lex_state = 0},
  [16895] = {.lex_state = 371},
  [16896] = {.lex_state = 371},
  [16897] = {.lex_state = 0},
  [16898] = {.lex_state = 0},
  [16899] = {.lex_state = 371},
  [16900] = {.lex_state = 0},
  [16901] = {.lex_state = 0},
  [16902] = {.lex_state = 0},
  [16903] = {.lex_state = 0},
  [16904] = {.lex_state = 63},
  [16905] = {.lex_state = 0},
  [16906] = {.lex_state = 371},
  [16907] = {.lex_state = 0},
  [16908] = {.lex_state = 0},
  [16909] = {.lex_state = 0},
  [16910] = {.lex_state = 0},
  [16911] = {.lex_state = 0},
  [16912] = {.lex_state = 371},
  [16913] = {.lex_state = 0},
  [16914] = {.lex_state = 0},
  [16915] = {.lex_state = 373},
  [16916] = {.lex_state = 371},
  [16917] = {.lex_state = 0},
  [16918] = {.lex_state = 0},
  [16919] = {.lex_state = 0},
  [16920] = {.lex_state = 0},
  [16921] = {.lex_state = 0},
  [16922] = {.lex_state = 0},
  [16923] = {.lex_state = 0},
  [16924] = {.lex_state = 0},
  [16925] = {.lex_state = 0},
  [16926] = {.lex_state = 0},
  [16927] = {.lex_state = 371},
  [16928] = {.lex_state = 0},
  [16929] = {.lex_state = 371},
  [16930] = {.lex_state = 0},
  [16931] = {.lex_state = 0},
  [16932] = {.lex_state = 0},
  [16933] = {.lex_state = 0},
  [16934] = {.lex_state = 0},
  [16935] = {.lex_state = 0},
  [16936] = {.lex_state = 0},
  [16937] = {.lex_state = 0},
  [16938] = {.lex_state = 0},
  [16939] = {.lex_state = 0},
  [16940] = {.lex_state = 0},
  [16941] = {.lex_state = 371},
  [16942] = {.lex_state = 0},
  [16943] = {.lex_state = 0},
  [16944] = {.lex_state = 371},
  [16945] = {.lex_state = 0},
  [16946] = {.lex_state = 0},
  [16947] = {.lex_state = 0},
  [16948] = {.lex_state = 0},
  [16949] = {.lex_state = 0},
  [16950] = {.lex_state = 0},
  [16951] = {.lex_state = 0},
  [16952] = {.lex_state = 0},
  [16953] = {.lex_state = 0},
  [16954] = {.lex_state = 0},
  [16955] = {.lex_state = 0},
  [16956] = {.lex_state = 371},
  [16957] = {.lex_state = 0},
  [16958] = {.lex_state = 0},
  [16959] = {.lex_state = 0},
  [16960] = {.lex_state = 0},
  [16961] = {.lex_state = 0},
  [16962] = {.lex_state = 0},
  [16963] = {.lex_state = 7},
  [16964] = {.lex_state = 7},
  [16965] = {.lex_state = 41},
  [16966] = {.lex_state = 371},
  [16967] = {.lex_state = 371},
  [16968] = {.lex_state = 0},
  [16969] = {.lex_state = 0},
  [16970] = {.lex_state = 371},
  [16971] = {.lex_state = 0},
  [16972] = {.lex_state = 7},
  [16973] = {.lex_state = 371},
  [16974] = {.lex_state = 7},
  [16975] = {.lex_state = 7},
  [16976] = {.lex_state = 7},
  [16977] = {.lex_state = 0},
  [16978] = {.lex_state = 371},
  [16979] = {.lex_state = 371},
  [16980] = {.lex_state = 0},
  [16981] = {.lex_state = 0},
  [16982] = {.lex_state = 0},
  [16983] = {.lex_state = 7},
  [16984] = {.lex_state = 0},
  [16985] = {.lex_state = 0},
  [16986] = {.lex_state = 0},
  [16987] = {.lex_state = 0},
  [16988] = {.lex_state = 0},
  [16989] = {.lex_state = 371},
  [16990] = {.lex_state = 0},
  [16991] = {.lex_state = 0},
  [16992] = {.lex_state = 0},
  [16993] = {.lex_state = 0},
  [16994] = {.lex_state = 7},
  [16995] = {.lex_state = 7},
  [16996] = {.lex_state = 7},
  [16997] = {.lex_state = 371},
  [16998] = {.lex_state = 399},
  [16999] = {.lex_state = 0},
  [17000] = {.lex_state = 7},
  [17001] = {.lex_state = 371},
  [17002] = {.lex_state = 0},
  [17003] = {.lex_state = 0},
  [17004] = {.lex_state = 0},
  [17005] = {.lex_state = 0},
  [17006] = {.lex_state = 0},
  [17007] = {.lex_state = 371},
  [17008] = {.lex_state = 0},
  [17009] = {.lex_state = 371},
  [17010] = {.lex_state = 7},
  [17011] = {.lex_state = 0},
  [17012] = {.lex_state = 371},
  [17013] = {.lex_state = 0},
  [17014] = {.lex_state = 0},
  [17015] = {.lex_state = 371},
  [17016] = {.lex_state = 0},
  [17017] = {.lex_state = 371},
  [17018] = {.lex_state = 371},
  [17019] = {.lex_state = 0},
  [17020] = {.lex_state = 0},
  [17021] = {.lex_state = 371},
  [17022] = {.lex_state = 0},
  [17023] = {.lex_state = 0},
  [17024] = {.lex_state = 0},
  [17025] = {.lex_state = 7},
  [17026] = {.lex_state = 0},
  [17027] = {.lex_state = 7},
  [17028] = {.lex_state = 7},
  [17029] = {.lex_state = 0},
  [17030] = {.lex_state = 0},
  [17031] = {.lex_state = 0},
  [17032] = {.lex_state = 0},
  [17033] = {.lex_state = 371},
  [17034] = {.lex_state = 7},
  [17035] = {.lex_state = 7},
  [17036] = {.lex_state = 41},
  [17037] = {.lex_state = 371},
  [17038] = {.lex_state = 0},
  [17039] = {.lex_state = 371},
  [17040] = {.lex_state = 0},
  [17041] = {.lex_state = 0},
  [17042] = {.lex_state = 0},
  [17043] = {.lex_state = 0},
  [17044] = {.lex_state = 371},
  [17045] = {.lex_state = 7},
  [17046] = {.lex_state = 371},
  [17047] = {.lex_state = 7},
  [17048] = {.lex_state = 0},
  [17049] = {.lex_state = 0},
  [17050] = {.lex_state = 0},
  [17051] = {.lex_state = 0},
  [17052] = {.lex_state = 371},
  [17053] = {.lex_state = 371},
  [17054] = {.lex_state = 0},
  [17055] = {.lex_state = 0},
  [17056] = {.lex_state = 7},
  [17057] = {.lex_state = 0},
  [17058] = {.lex_state = 0},
  [17059] = {.lex_state = 0},
  [17060] = {.lex_state = 7},
  [17061] = {.lex_state = 7},
  [17062] = {.lex_state = 7},
  [17063] = {.lex_state = 41},
  [17064] = {.lex_state = 371},
  [17065] = {.lex_state = 371},
  [17066] = {.lex_state = 0},
  [17067] = {.lex_state = 371},
  [17068] = {.lex_state = 371},
  [17069] = {.lex_state = 0},
  [17070] = {.lex_state = 371},
  [17071] = {.lex_state = 371},
  [17072] = {.lex_state = 0},
  [17073] = {.lex_state = 0},
  [17074] = {.lex_state = 371},
  [17075] = {.lex_state = 371},
  [17076] = {.lex_state = 0},
  [17077] = {.lex_state = 0},
  [17078] = {.lex_state = 0},
  [17079] = {.lex_state = 371},
  [17080] = {.lex_state = 7},
  [17081] = {.lex_state = 7},
  [17082] = {.lex_state = 41},
  [17083] = {.lex_state = 371},
  [17084] = {.lex_state = 0},
  [17085] = {.lex_state = 371},
  [17086] = {.lex_state = 0},
  [17087] = {.lex_state = 0},
  [17088] = {.lex_state = 0},
  [17089] = {.lex_state = 0},
  [17090] = {.lex_state = 371},
  [17091] = {.lex_state = 371},
  [17092] = {.lex_state = 0},
  [17093] = {.lex_state = 7},
  [17094] = {.lex_state = 0},
  [17095] = {.lex_state = 371},
  [17096] = {.lex_state = 371},
  [17097] = {.lex_state = 0},
  [17098] = {.lex_state = 0},
  [17099] = {.lex_state = 0},
  [17100] = {.lex_state = 0},
  [17101] = {.lex_state = 0},
  [17102] = {.lex_state = 0},
  [17103] = {.lex_state = 371},
  [17104] = {.lex_state = 0},
  [17105] = {.lex_state = 0},
  [17106] = {.lex_state = 7},
  [17107] = {.lex_state = 371},
  [17108] = {.lex_state = 41},
  [17109] = {.lex_state = 0},
  [17110] = {.lex_state = 371},
  [17111] = {.lex_state = 0},
  [17112] = {.lex_state = 0},
  [17113] = {.lex_state = 371},
  [17114] = {.lex_state = 0},
  [17115] = {.lex_state = 0},
  [17116] = {.lex_state = 0},
  [17117] = {.lex_state = 0},
  [17118] = {.lex_state = 0},
  [17119] = {.lex_state = 371},
  [17120] = {.lex_state = 0},
  [17121] = {.lex_state = 0},
  [17122] = {.lex_state = 41},
  [17123] = {.lex_state = 0},
  [17124] = {.lex_state = 0},
  [17125] = {.lex_state = 0},
  [17126] = {.lex_state = 371},
  [17127] = {.lex_state = 0},
  [17128] = {.lex_state = 0},
  [17129] = {.lex_state = 0},
  [17130] = {.lex_state = 7},
  [17131] = {.lex_state = 7},
  [17132] = {.lex_state = 0},
  [17133] = {.lex_state = 0},
  [17134] = {.lex_state = 7},
  [17135] = {.lex_state = 0},
  [17136] = {.lex_state = 7},
  [17137] = {.lex_state = 7},
  [17138] = {.lex_state = 0},
  [17139] = {.lex_state = 0},
  [17140] = {.lex_state = 371},
  [17141] = {.lex_state = 0},
  [17142] = {.lex_state = 0},
  [17143] = {.lex_state = 0},
  [17144] = {.lex_state = 371},
  [17145] = {.lex_state = 0},
  [17146] = {.lex_state = 7},
  [17147] = {.lex_state = 7},
  [17148] = {.lex_state = 7},
  [17149] = {.lex_state = 0},
  [17150] = {.lex_state = 7},
  [17151] = {.lex_state = 0},
  [17152] = {.lex_state = 0},
  [17153] = {.lex_state = 371},
  [17154] = {.lex_state = 371},
  [17155] = {.lex_state = 0},
  [17156] = {.lex_state = 371},
  [17157] = {.lex_state = 0},
  [17158] = {.lex_state = 371},
  [17159] = {.lex_state = 7},
  [17160] = {.lex_state = 0},
  [17161] = {.lex_state = 371},
  [17162] = {.lex_state = 371},
  [17163] = {.lex_state = 371},
  [17164] = {.lex_state = 0},
  [17165] = {.lex_state = 371},
  [17166] = {.lex_state = 0},
  [17167] = {.lex_state = 0},
  [17168] = {.lex_state = 0},
  [17169] = {.lex_state = 0},
  [17170] = {.lex_state = 0},
  [17171] = {.lex_state = 0},
  [17172] = {.lex_state = 0},
  [17173] = {.lex_state = 0},
  [17174] = {.lex_state = 0},
  [17175] = {.lex_state = 0},
  [17176] = {.lex_state = 0},
  [17177] = {.lex_state = 0},
  [17178] = {.lex_state = 0},
  [17179] = {.lex_state = 0},
  [17180] = {.lex_state = 0},
  [17181] = {.lex_state = 0},
  [17182] = {.lex_state = 0},
  [17183] = {.lex_state = 0},
  [17184] = {.lex_state = 371},
  [17185] = {.lex_state = 7},
  [17186] = {.lex_state = 0},
  [17187] = {.lex_state = 371},
  [17188] = {.lex_state = 371},
  [17189] = {.lex_state = 0},
  [17190] = {.lex_state = 0},
  [17191] = {.lex_state = 0},
  [17192] = {.lex_state = 0},
  [17193] = {.lex_state = 0},
  [17194] = {.lex_state = 0},
  [17195] = {.lex_state = 0},
  [17196] = {.lex_state = 0},
  [17197] = {.lex_state = 0},
  [17198] = {.lex_state = 371},
  [17199] = {.lex_state = 0},
  [17200] = {.lex_state = 0},
  [17201] = {.lex_state = 0},
  [17202] = {.lex_state = 0},
  [17203] = {.lex_state = 371},
  [17204] = {.lex_state = 371},
  [17205] = {.lex_state = 7},
  [17206] = {.lex_state = 7},
  [17207] = {.lex_state = 0},
  [17208] = {.lex_state = 7},
  [17209] = {.lex_state = 7},
  [17210] = {.lex_state = 0},
  [17211] = {.lex_state = 0},
  [17212] = {.lex_state = 0},
  [17213] = {.lex_state = 0},
  [17214] = {.lex_state = 7},
  [17215] = {.lex_state = 0},
  [17216] = {.lex_state = 0},
  [17217] = {.lex_state = 371},
  [17218] = {.lex_state = 0},
  [17219] = {.lex_state = 0},
  [17220] = {.lex_state = 0},
  [17221] = {.lex_state = 371},
  [17222] = {.lex_state = 0},
  [17223] = {.lex_state = 7},
  [17224] = {.lex_state = 7},
  [17225] = {.lex_state = 371},
  [17226] = {.lex_state = 371},
  [17227] = {.lex_state = 0},
  [17228] = {.lex_state = 0},
  [17229] = {.lex_state = 7},
  [17230] = {.lex_state = 0},
  [17231] = {.lex_state = 0},
  [17232] = {.lex_state = 371},
  [17233] = {.lex_state = 371},
  [17234] = {.lex_state = 7},
  [17235] = {.lex_state = 0},
  [17236] = {.lex_state = 0},
  [17237] = {.lex_state = 0},
  [17238] = {.lex_state = 371},
  [17239] = {.lex_state = 371},
  [17240] = {.lex_state = 0},
  [17241] = {.lex_state = 0},
  [17242] = {.lex_state = 373},
  [17243] = {.lex_state = 0},
  [17244] = {.lex_state = 0},
  [17245] = {.lex_state = 0},
  [17246] = {.lex_state = 0},
  [17247] = {.lex_state = 0},
  [17248] = {.lex_state = 371},
  [17249] = {.lex_state = 0},
  [17250] = {.lex_state = 0},
  [17251] = {.lex_state = 7},
  [17252] = {.lex_state = 7},
  [17253] = {.lex_state = 371},
  [17254] = {.lex_state = 0},
  [17255] = {.lex_state = 7},
  [17256] = {.lex_state = 0},
  [17257] = {.lex_state = 0},
  [17258] = {.lex_state = 0},
  [17259] = {.lex_state = 0},
  [17260] = {.lex_state = 0},
  [17261] = {.lex_state = 0},
  [17262] = {.lex_state = 0},
  [17263] = {.lex_state = 0},
  [17264] = {.lex_state = 0},
  [17265] = {.lex_state = 63},
  [17266] = {.lex_state = 371},
  [17267] = {.lex_state = 0},
  [17268] = {.lex_state = 0},
  [17269] = {.lex_state = 371},
  [17270] = {.lex_state = 0},
  [17271] = {.lex_state = 0},
  [17272] = {.lex_state = 371},
  [17273] = {.lex_state = 0},
  [17274] = {.lex_state = 0},
  [17275] = {.lex_state = 0},
  [17276] = {.lex_state = 373},
  [17277] = {.lex_state = 0},
  [17278] = {.lex_state = 7},
  [17279] = {.lex_state = 0},
  [17280] = {.lex_state = 371},
  [17281] = {.lex_state = 371},
  [17282] = {.lex_state = 0},
  [17283] = {.lex_state = 371},
  [17284] = {.lex_state = 0},
  [17285] = {.lex_state = 0},
  [17286] = {.lex_state = 0},
  [17287] = {.lex_state = 371},
  [17288] = {.lex_state = 371},
  [17289] = {.lex_state = 0},
  [17290] = {.lex_state = 371},
  [17291] = {.lex_state = 0},
  [17292] = {.lex_state = 371},
  [17293] = {.lex_state = 371},
  [17294] = {.lex_state = 0},
  [17295] = {.lex_state = 0},
  [17296] = {.lex_state = 0},
  [17297] = {.lex_state = 0},
  [17298] = {.lex_state = 371},
  [17299] = {.lex_state = 0},
  [17300] = {.lex_state = 0},
  [17301] = {.lex_state = 371},
  [17302] = {.lex_state = 371},
  [17303] = {.lex_state = 7},
  [17304] = {.lex_state = 0},
  [17305] = {.lex_state = 0},
  [17306] = {.lex_state = 0},
  [17307] = {.lex_state = 0},
  [17308] = {.lex_state = 0},
  [17309] = {.lex_state = 0},
  [17310] = {.lex_state = 0},
  [17311] = {.lex_state = 371},
  [17312] = {.lex_state = 0},
  [17313] = {.lex_state = 7},
  [17314] = {.lex_state = 0},
  [17315] = {.lex_state = 371},
  [17316] = {.lex_state = 0},
  [17317] = {.lex_state = 371},
  [17318] = {.lex_state = 0},
  [17319] = {.lex_state = 0},
  [17320] = {.lex_state = 7},
  [17321] = {.lex_state = 371},
  [17322] = {.lex_state = 371},
  [17323] = {.lex_state = 0},
  [17324] = {.lex_state = 371},
  [17325] = {.lex_state = 371},
  [17326] = {.lex_state = 0},
  [17327] = {.lex_state = 371},
  [17328] = {.lex_state = 0},
  [17329] = {.lex_state = 0},
  [17330] = {.lex_state = 371},
  [17331] = {.lex_state = 7},
  [17332] = {.lex_state = 7},
  [17333] = {.lex_state = 0},
  [17334] = {.lex_state = 7},
  [17335] = {.lex_state = 7},
  [17336] = {.lex_state = 7},
  [17337] = {.lex_state = 7},
  [17338] = {.lex_state = 7},
  [17339] = {.lex_state = 0},
  [17340] = {.lex_state = 371},
  [17341] = {.lex_state = 7},
  [17342] = {.lex_state = 0},
  [17343] = {.lex_state = 7},
  [17344] = {.lex_state = 373},
  [17345] = {.lex_state = 7},
  [17346] = {.lex_state = 7},
  [17347] = {.lex_state = 373},
  [17348] = {.lex_state = 0},
  [17349] = {.lex_state = 7},
  [17350] = {.lex_state = 7},
  [17351] = {.lex_state = 0},
  [17352] = {.lex_state = 371},
  [17353] = {.lex_state = 41},
  [17354] = {.lex_state = 7},
  [17355] = {.lex_state = 371},
  [17356] = {.lex_state = 0},
  [17357] = {.lex_state = 0},
  [17358] = {.lex_state = 0},
  [17359] = {.lex_state = 0},
  [17360] = {.lex_state = 7},
  [17361] = {.lex_state = 7},
  [17362] = {.lex_state = 0},
  [17363] = {.lex_state = 7},
  [17364] = {.lex_state = 0},
  [17365] = {.lex_state = 0},
  [17366] = {.lex_state = 0},
  [17367] = {.lex_state = 371},
  [17368] = {.lex_state = 373},
  [17369] = {.lex_state = 0},
  [17370] = {.lex_state = 0},
  [17371] = {.lex_state = 0},
  [17372] = {.lex_state = 371},
  [17373] = {.lex_state = 373},
  [17374] = {.lex_state = 0},
  [17375] = {.lex_state = 0},
  [17376] = {.lex_state = 0},
  [17377] = {.lex_state = 0},
  [17378] = {.lex_state = 0},
  [17379] = {.lex_state = 0},
  [17380] = {.lex_state = 0},
  [17381] = {.lex_state = 0},
  [17382] = {.lex_state = 0},
  [17383] = {.lex_state = 2},
  [17384] = {.lex_state = 0},
  [17385] = {.lex_state = 0},
  [17386] = {.lex_state = 0},
  [17387] = {.lex_state = 0},
  [17388] = {.lex_state = 0},
  [17389] = {.lex_state = 0},
  [17390] = {.lex_state = 0},
  [17391] = {.lex_state = 0},
  [17392] = {.lex_state = 0},
  [17393] = {.lex_state = 0},
  [17394] = {.lex_state = 0},
  [17395] = {.lex_state = 0},
  [17396] = {.lex_state = 371},
  [17397] = {.lex_state = 0},
  [17398] = {.lex_state = 371},
  [17399] = {.lex_state = 0},
  [17400] = {.lex_state = 371},
  [17401] = {.lex_state = 0},
  [17402] = {.lex_state = 0},
  [17403] = {.lex_state = 0},
  [17404] = {.lex_state = 0},
  [17405] = {.lex_state = 0},
  [17406] = {.lex_state = 0},
  [17407] = {.lex_state = 0},
  [17408] = {.lex_state = 0},
  [17409] = {.lex_state = 0},
  [17410] = {.lex_state = 0},
  [17411] = {.lex_state = 0},
  [17412] = {.lex_state = 7},
  [17413] = {.lex_state = 0},
  [17414] = {.lex_state = 0},
  [17415] = {.lex_state = 0},
  [17416] = {.lex_state = 0},
  [17417] = {.lex_state = 0},
  [17418] = {.lex_state = 0},
  [17419] = {.lex_state = 0},
  [17420] = {.lex_state = 0},
  [17421] = {.lex_state = 682},
  [17422] = {.lex_state = 0},
  [17423] = {.lex_state = 0},
  [17424] = {.lex_state = 0},
  [17425] = {.lex_state = 0},
  [17426] = {.lex_state = 0},
  [17427] = {.lex_state = 0},
  [17428] = {.lex_state = 0},
  [17429] = {.lex_state = 373},
  [17430] = {.lex_state = 0},
  [17431] = {.lex_state = 0},
  [17432] = {.lex_state = 0},
  [17433] = {.lex_state = 0},
  [17434] = {.lex_state = 0},
  [17435] = {.lex_state = 0},
  [17436] = {.lex_state = 0},
  [17437] = {.lex_state = 0},
  [17438] = {.lex_state = 0},
  [17439] = {.lex_state = 0},
  [17440] = {.lex_state = 0},
  [17441] = {.lex_state = 0},
  [17442] = {.lex_state = 0},
  [17443] = {.lex_state = 0},
  [17444] = {.lex_state = 0},
  [17445] = {.lex_state = 0},
  [17446] = {.lex_state = 0},
  [17447] = {.lex_state = 0},
  [17448] = {.lex_state = 0},
  [17449] = {.lex_state = 0},
  [17450] = {.lex_state = 0},
  [17451] = {.lex_state = 0},
  [17452] = {.lex_state = 0},
  [17453] = {.lex_state = 0},
  [17454] = {.lex_state = 0},
  [17455] = {.lex_state = 0},
  [17456] = {.lex_state = 0},
  [17457] = {.lex_state = 0},
  [17458] = {.lex_state = 0},
  [17459] = {.lex_state = 0},
  [17460] = {.lex_state = 371},
  [17461] = {.lex_state = 0},
  [17462] = {.lex_state = 0},
  [17463] = {.lex_state = 0},
  [17464] = {.lex_state = 0},
  [17465] = {.lex_state = 0},
  [17466] = {.lex_state = 0},
  [17467] = {.lex_state = 0},
  [17468] = {.lex_state = 0},
  [17469] = {.lex_state = 0},
  [17470] = {.lex_state = 0},
  [17471] = {.lex_state = 373},
  [17472] = {.lex_state = 0},
  [17473] = {.lex_state = 0},
  [17474] = {.lex_state = 0},
  [17475] = {.lex_state = 0},
  [17476] = {.lex_state = 0},
  [17477] = {.lex_state = 0},
  [17478] = {.lex_state = 0},
  [17479] = {.lex_state = 0},
  [17480] = {.lex_state = 0},
  [17481] = {.lex_state = 0},
  [17482] = {.lex_state = 0},
  [17483] = {.lex_state = 0},
  [17484] = {.lex_state = 0},
  [17485] = {.lex_state = 0},
  [17486] = {.lex_state = 0},
  [17487] = {.lex_state = 0},
  [17488] = {.lex_state = 0},
  [17489] = {.lex_state = 0},
  [17490] = {.lex_state = 0},
  [17491] = {.lex_state = 0},
  [17492] = {.lex_state = 0},
  [17493] = {.lex_state = 0},
  [17494] = {.lex_state = 0},
  [17495] = {.lex_state = 371},
  [17496] = {.lex_state = 0},
  [17497] = {.lex_state = 0},
  [17498] = {.lex_state = 0},
  [17499] = {.lex_state = 0},
  [17500] = {.lex_state = 0},
  [17501] = {.lex_state = 0},
  [17502] = {.lex_state = 0},
  [17503] = {.lex_state = 0},
  [17504] = {.lex_state = 0},
  [17505] = {.lex_state = 0},
  [17506] = {.lex_state = 0},
  [17507] = {.lex_state = 0},
  [17508] = {.lex_state = 0},
  [17509] = {.lex_state = 0},
  [17510] = {.lex_state = 0},
  [17511] = {.lex_state = 0},
  [17512] = {.lex_state = 0},
  [17513] = {.lex_state = 0},
  [17514] = {.lex_state = 0},
  [17515] = {.lex_state = 0},
  [17516] = {.lex_state = 0},
  [17517] = {.lex_state = 0},
  [17518] = {.lex_state = 0},
  [17519] = {.lex_state = 0},
  [17520] = {.lex_state = 0},
  [17521] = {.lex_state = 0},
  [17522] = {.lex_state = 682},
  [17523] = {.lex_state = 0},
  [17524] = {.lex_state = 0},
  [17525] = {.lex_state = 0},
  [17526] = {.lex_state = 0},
  [17527] = {.lex_state = 0},
  [17528] = {.lex_state = 0},
  [17529] = {.lex_state = 371},
  [17530] = {.lex_state = 0},
  [17531] = {.lex_state = 0},
  [17532] = {.lex_state = 0},
  [17533] = {.lex_state = 0},
  [17534] = {.lex_state = 0},
  [17535] = {.lex_state = 371},
  [17536] = {.lex_state = 0},
  [17537] = {.lex_state = 0},
  [17538] = {.lex_state = 371},
  [17539] = {.lex_state = 0},
  [17540] = {.lex_state = 0},
  [17541] = {.lex_state = 0},
  [17542] = {.lex_state = 373},
  [17543] = {.lex_state = 0},
  [17544] = {.lex_state = 0},
  [17545] = {.lex_state = 0},
  [17546] = {.lex_state = 0},
  [17547] = {.lex_state = 0},
  [17548] = {.lex_state = 0},
  [17549] = {.lex_state = 0},
  [17550] = {.lex_state = 0},
  [17551] = {.lex_state = 0},
  [17552] = {.lex_state = 0},
  [17553] = {.lex_state = 7},
  [17554] = {.lex_state = 0},
  [17555] = {.lex_state = 0},
  [17556] = {.lex_state = 0},
  [17557] = {.lex_state = 0},
  [17558] = {.lex_state = 7},
  [17559] = {.lex_state = 0},
  [17560] = {.lex_state = 0},
  [17561] = {.lex_state = 0},
  [17562] = {.lex_state = 371},
  [17563] = {.lex_state = 0},
  [17564] = {.lex_state = 371},
  [17565] = {.lex_state = 371},
  [17566] = {.lex_state = 0},
  [17567] = {.lex_state = 0},
  [17568] = {.lex_state = 0},
  [17569] = {.lex_state = 371},
  [17570] = {.lex_state = 0},
  [17571] = {.lex_state = 0},
  [17572] = {.lex_state = 0},
  [17573] = {.lex_state = 0},
  [17574] = {.lex_state = 0},
  [17575] = {.lex_state = 0},
  [17576] = {.lex_state = 0},
  [17577] = {.lex_state = 0},
  [17578] = {.lex_state = 0},
  [17579] = {.lex_state = 0},
  [17580] = {.lex_state = 0},
  [17581] = {.lex_state = 0},
  [17582] = {.lex_state = 0},
  [17583] = {.lex_state = 0},
  [17584] = {.lex_state = 0},
  [17585] = {.lex_state = 0},
  [17586] = {.lex_state = 0},
  [17587] = {.lex_state = 0},
  [17588] = {.lex_state = 0},
  [17589] = {.lex_state = 7},
  [17590] = {.lex_state = 0},
  [17591] = {.lex_state = 0},
  [17592] = {.lex_state = 0},
  [17593] = {.lex_state = 0},
  [17594] = {.lex_state = 373},
  [17595] = {.lex_state = 0},
  [17596] = {.lex_state = 0},
  [17597] = {.lex_state = 682},
  [17598] = {.lex_state = 0},
  [17599] = {.lex_state = 0},
  [17600] = {.lex_state = 0},
  [17601] = {.lex_state = 0},
  [17602] = {.lex_state = 0},
  [17603] = {.lex_state = 7},
  [17604] = {.lex_state = 0},
  [17605] = {.lex_state = 0},
  [17606] = {.lex_state = 0},
  [17607] = {.lex_state = 0},
  [17608] = {.lex_state = 0},
  [17609] = {.lex_state = 0},
  [17610] = {.lex_state = 0},
  [17611] = {.lex_state = 0},
  [17612] = {.lex_state = 0},
  [17613] = {.lex_state = 0},
  [17614] = {.lex_state = 371},
  [17615] = {.lex_state = 0},
  [17616] = {.lex_state = 0},
  [17617] = {.lex_state = 0},
  [17618] = {.lex_state = 0},
  [17619] = {.lex_state = 0},
  [17620] = {.lex_state = 0},
  [17621] = {.lex_state = 373},
  [17622] = {.lex_state = 0},
  [17623] = {.lex_state = 0},
  [17624] = {.lex_state = 0},
  [17625] = {.lex_state = 0},
  [17626] = {.lex_state = 0},
  [17627] = {.lex_state = 0},
  [17628] = {.lex_state = 0},
  [17629] = {.lex_state = 0},
  [17630] = {.lex_state = 0},
  [17631] = {.lex_state = 0},
  [17632] = {.lex_state = 0},
  [17633] = {.lex_state = 7},
  [17634] = {.lex_state = 0},
  [17635] = {.lex_state = 0},
  [17636] = {.lex_state = 0},
  [17637] = {.lex_state = 0},
  [17638] = {.lex_state = 0},
  [17639] = {.lex_state = 371},
  [17640] = {.lex_state = 0},
  [17641] = {.lex_state = 0},
  [17642] = {.lex_state = 0},
  [17643] = {.lex_state = 0},
  [17644] = {.lex_state = 0},
  [17645] = {.lex_state = 371},
  [17646] = {.lex_state = 7},
  [17647] = {.lex_state = 0},
  [17648] = {.lex_state = 371},
  [17649] = {.lex_state = 7},
  [17650] = {.lex_state = 371},
  [17651] = {.lex_state = 0},
  [17652] = {.lex_state = 0},
  [17653] = {.lex_state = 0},
  [17654] = {.lex_state = 0},
  [17655] = {.lex_state = 0},
  [17656] = {.lex_state = 0},
  [17657] = {.lex_state = 0},
  [17658] = {.lex_state = 0},
  [17659] = {.lex_state = 0},
  [17660] = {.lex_state = 0},
  [17661] = {.lex_state = 0},
  [17662] = {.lex_state = 0},
  [17663] = {.lex_state = 0},
  [17664] = {.lex_state = 0},
  [17665] = {.lex_state = 0},
  [17666] = {.lex_state = 0},
  [17667] = {.lex_state = 0},
  [17668] = {.lex_state = 0},
  [17669] = {.lex_state = 0},
  [17670] = {.lex_state = 0},
  [17671] = {.lex_state = 0},
  [17672] = {.lex_state = 682},
  [17673] = {.lex_state = 0},
  [17674] = {.lex_state = 0},
  [17675] = {.lex_state = 0},
  [17676] = {.lex_state = 7},
  [17677] = {.lex_state = 0},
  [17678] = {.lex_state = 0},
  [17679] = {.lex_state = 0},
  [17680] = {.lex_state = 682},
  [17681] = {.lex_state = 0},
  [17682] = {.lex_state = 2},
  [17683] = {.lex_state = 371},
  [17684] = {.lex_state = 0},
  [17685] = {.lex_state = 0},
  [17686] = {.lex_state = 2},
  [17687] = {.lex_state = 0},
  [17688] = {.lex_state = 0},
  [17689] = {.lex_state = 0},
  [17690] = {.lex_state = 0},
  [17691] = {.lex_state = 0},
  [17692] = {.lex_state = 0},
  [17693] = {.lex_state = 0},
  [17694] = {.lex_state = 0},
  [17695] = {.lex_state = 373},
  [17696] = {.lex_state = 0},
  [17697] = {.lex_state = 0},
  [17698] = {.lex_state = 0},
  [17699] = {.lex_state = 0},
  [17700] = {.lex_state = 0},
  [17701] = {.lex_state = 0},
  [17702] = {.lex_state = 0},
  [17703] = {.lex_state = 0},
  [17704] = {.lex_state = 0},
  [17705] = {.lex_state = 0},
  [17706] = {.lex_state = 0},
  [17707] = {.lex_state = 0},
  [17708] = {.lex_state = 7},
  [17709] = {.lex_state = 0},
  [17710] = {.lex_state = 0},
  [17711] = {.lex_state = 0},
  [17712] = {.lex_state = 0},
  [17713] = {.lex_state = 0},
  [17714] = {.lex_state = 0},
  [17715] = {.lex_state = 0},
  [17716] = {.lex_state = 0},
  [17717] = {.lex_state = 0},
  [17718] = {.lex_state = 0},
  [17719] = {.lex_state = 0},
  [17720] = {.lex_state = 371},
  [17721] = {.lex_state = 0},
  [17722] = {.lex_state = 0},
  [17723] = {.lex_state = 0},
  [17724] = {.lex_state = 0},
  [17725] = {.lex_state = 371},
  [17726] = {.lex_state = 0},
  [17727] = {.lex_state = 0},
  [17728] = {.lex_state = 0},
  [17729] = {.lex_state = 0},
  [17730] = {.lex_state = 0},
  [17731] = {.lex_state = 7},
  [17732] = {.lex_state = 0},
  [17733] = {.lex_state = 7},
  [17734] = {.lex_state = 682},
  [17735] = {.lex_state = 0},
  [17736] = {.lex_state = 7},
  [17737] = {.lex_state = 0},
  [17738] = {.lex_state = 0},
  [17739] = {.lex_state = 0},
  [17740] = {.lex_state = 0},
  [17741] = {.lex_state = 0},
  [17742] = {.lex_state = 0},
  [17743] = {.lex_state = 0},
  [17744] = {.lex_state = 0},
  [17745] = {.lex_state = 0},
  [17746] = {.lex_state = 371},
  [17747] = {.lex_state = 0},
  [17748] = {.lex_state = 0},
  [17749] = {.lex_state = 0},
  [17750] = {.lex_state = 0},
  [17751] = {.lex_state = 0},
  [17752] = {.lex_state = 0},
  [17753] = {.lex_state = 0},
  [17754] = {.lex_state = 0},
  [17755] = {.lex_state = 0},
  [17756] = {.lex_state = 0},
  [17757] = {.lex_state = 0},
  [17758] = {.lex_state = 0},
  [17759] = {.lex_state = 0},
  [17760] = {.lex_state = 371},
  [17761] = {.lex_state = 0},
  [17762] = {.lex_state = 0},
  [17763] = {.lex_state = 371},
  [17764] = {.lex_state = 0},
  [17765] = {.lex_state = 0},
  [17766] = {.lex_state = 0},
  [17767] = {.lex_state = 371},
  [17768] = {.lex_state = 0},
  [17769] = {.lex_state = 371},
  [17770] = {.lex_state = 0},
  [17771] = {.lex_state = 0},
  [17772] = {.lex_state = 371},
  [17773] = {.lex_state = 0},
  [17774] = {.lex_state = 0},
  [17775] = {.lex_state = 371},
  [17776] = {.lex_state = 7},
  [17777] = {.lex_state = 371},
  [17778] = {.lex_state = 0},
  [17779] = {.lex_state = 0},
  [17780] = {.lex_state = 7},
  [17781] = {.lex_state = 0},
  [17782] = {.lex_state = 0},
  [17783] = {.lex_state = 0},
  [17784] = {.lex_state = 0},
  [17785] = {.lex_state = 0},
  [17786] = {.lex_state = 0},
  [17787] = {.lex_state = 0},
  [17788] = {.lex_state = 0},
  [17789] = {.lex_state = 0},
  [17790] = {.lex_state = 0},
  [17791] = {.lex_state = 0},
  [17792] = {.lex_state = 0},
  [17793] = {.lex_state = 7},
  [17794] = {.lex_state = 682},
  [17795] = {.lex_state = 0},
  [17796] = {.lex_state = 371},
  [17797] = {.lex_state = 371},
  [17798] = {.lex_state = 0},
  [17799] = {.lex_state = 0},
  [17800] = {.lex_state = 0},
  [17801] = {.lex_state = 0},
  [17802] = {.lex_state = 0},
  [17803] = {.lex_state = 0},
  [17804] = {.lex_state = 0},
  [17805] = {.lex_state = 0},
  [17806] = {.lex_state = 0},
  [17807] = {.lex_state = 0},
  [17808] = {.lex_state = 371},
  [17809] = {.lex_state = 0},
  [17810] = {.lex_state = 0},
  [17811] = {.lex_state = 0},
  [17812] = {.lex_state = 0},
  [17813] = {.lex_state = 0},
  [17814] = {.lex_state = 0},
  [17815] = {.lex_state = 0},
  [17816] = {.lex_state = 0},
  [17817] = {.lex_state = 0},
  [17818] = {.lex_state = 0},
  [17819] = {.lex_state = 0},
  [17820] = {.lex_state = 7},
  [17821] = {.lex_state = 0},
  [17822] = {.lex_state = 7},
  [17823] = {.lex_state = 7},
  [17824] = {.lex_state = 0},
  [17825] = {.lex_state = 0},
  [17826] = {.lex_state = 0},
  [17827] = {.lex_state = 371},
  [17828] = {.lex_state = 0},
  [17829] = {.lex_state = 371},
  [17830] = {.lex_state = 0},
  [17831] = {.lex_state = 0},
  [17832] = {.lex_state = 0},
  [17833] = {.lex_state = 0},
  [17834] = {.lex_state = 0},
  [17835] = {.lex_state = 373},
  [17836] = {.lex_state = 0},
  [17837] = {.lex_state = 373},
  [17838] = {.lex_state = 0},
  [17839] = {.lex_state = 0},
  [17840] = {.lex_state = 0},
  [17841] = {.lex_state = 0},
  [17842] = {.lex_state = 371},
  [17843] = {.lex_state = 0},
  [17844] = {.lex_state = 0},
  [17845] = {.lex_state = 0},
  [17846] = {.lex_state = 0},
  [17847] = {.lex_state = 0},
  [17848] = {.lex_state = 373},
  [17849] = {.lex_state = 0},
  [17850] = {.lex_state = 682},
  [17851] = {.lex_state = 0},
  [17852] = {.lex_state = 0},
  [17853] = {.lex_state = 0},
  [17854] = {.lex_state = 7},
  [17855] = {.lex_state = 373},
  [17856] = {.lex_state = 0},
  [17857] = {.lex_state = 0},
  [17858] = {.lex_state = 0},
  [17859] = {.lex_state = 0},
  [17860] = {.lex_state = 0},
  [17861] = {.lex_state = 0},
  [17862] = {.lex_state = 7},
  [17863] = {.lex_state = 0},
  [17864] = {.lex_state = 0},
  [17865] = {.lex_state = 0},
  [17866] = {.lex_state = 2},
  [17867] = {.lex_state = 0},
  [17868] = {.lex_state = 0},
  [17869] = {.lex_state = 371},
  [17870] = {.lex_state = 0},
  [17871] = {.lex_state = 0},
  [17872] = {.lex_state = 0},
  [17873] = {.lex_state = 0},
  [17874] = {.lex_state = 371},
  [17875] = {.lex_state = 0},
  [17876] = {.lex_state = 0},
  [17877] = {.lex_state = 0},
  [17878] = {.lex_state = 0},
  [17879] = {.lex_state = 0},
  [17880] = {.lex_state = 371},
  [17881] = {.lex_state = 0},
  [17882] = {.lex_state = 0},
  [17883] = {.lex_state = 0},
  [17884] = {.lex_state = 0},
  [17885] = {.lex_state = 7},
  [17886] = {.lex_state = 0},
  [17887] = {.lex_state = 373},
  [17888] = {.lex_state = 0},
  [17889] = {.lex_state = 0},
  [17890] = {.lex_state = 0},
  [17891] = {.lex_state = 0},
  [17892] = {.lex_state = 0},
  [17893] = {.lex_state = 371},
  [17894] = {.lex_state = 0},
  [17895] = {.lex_state = 0},
  [17896] = {.lex_state = 0},
  [17897] = {.lex_state = 0},
  [17898] = {.lex_state = 0},
  [17899] = {.lex_state = 0},
  [17900] = {.lex_state = 371},
  [17901] = {.lex_state = 0},
  [17902] = {.lex_state = 682},
  [17903] = {.lex_state = 0},
  [17904] = {.lex_state = 0},
  [17905] = {.lex_state = 371},
  [17906] = {.lex_state = 0},
  [17907] = {.lex_state = 0},
  [17908] = {.lex_state = 0},
  [17909] = {.lex_state = 0},
  [17910] = {.lex_state = 0},
  [17911] = {.lex_state = 0},
  [17912] = {.lex_state = 0},
  [17913] = {.lex_state = 7},
  [17914] = {.lex_state = 0},
  [17915] = {.lex_state = 0},
  [17916] = {.lex_state = 0},
  [17917] = {.lex_state = 371},
  [17918] = {.lex_state = 63},
  [17919] = {.lex_state = 0},
  [17920] = {.lex_state = 371},
  [17921] = {.lex_state = 7},
  [17922] = {.lex_state = 0},
  [17923] = {.lex_state = 0},
  [17924] = {.lex_state = 7},
  [17925] = {.lex_state = 371},
  [17926] = {.lex_state = 78},
  [17927] = {.lex_state = 0},
  [17928] = {.lex_state = 0},
  [17929] = {.lex_state = 0},
  [17930] = {.lex_state = 0},
  [17931] = {.lex_state = 371},
  [17932] = {.lex_state = 371},
  [17933] = {.lex_state = 0},
  [17934] = {.lex_state = 0},
  [17935] = {.lex_state = 0},
  [17936] = {.lex_state = 0},
  [17937] = {.lex_state = 371},
  [17938] = {.lex_state = 0},
  [17939] = {.lex_state = 0},
  [17940] = {.lex_state = 0},
  [17941] = {.lex_state = 0},
  [17942] = {.lex_state = 0},
  [17943] = {.lex_state = 0},
  [17944] = {.lex_state = 0},
  [17945] = {.lex_state = 0},
  [17946] = {.lex_state = 371},
  [17947] = {.lex_state = 0},
  [17948] = {.lex_state = 0},
  [17949] = {.lex_state = 0},
  [17950] = {.lex_state = 0},
  [17951] = {.lex_state = 0},
  [17952] = {.lex_state = 0},
  [17953] = {.lex_state = 0},
  [17954] = {.lex_state = 0},
  [17955] = {.lex_state = 371},
  [17956] = {.lex_state = 0},
  [17957] = {.lex_state = 0},
  [17958] = {.lex_state = 0},
  [17959] = {.lex_state = 0},
  [17960] = {.lex_state = 0},
  [17961] = {.lex_state = 0},
  [17962] = {.lex_state = 0},
  [17963] = {.lex_state = 0},
  [17964] = {.lex_state = 0},
  [17965] = {.lex_state = 0},
  [17966] = {.lex_state = 0},
  [17967] = {.lex_state = 682},
  [17968] = {.lex_state = 0},
  [17969] = {.lex_state = 0},
  [17970] = {.lex_state = 371},
  [17971] = {.lex_state = 371},
  [17972] = {.lex_state = 0},
  [17973] = {.lex_state = 7},
  [17974] = {.lex_state = 0},
  [17975] = {.lex_state = 0},
  [17976] = {.lex_state = 0},
  [17977] = {.lex_state = 0},
  [17978] = {.lex_state = 0},
  [17979] = {.lex_state = 371},
  [17980] = {.lex_state = 0},
  [17981] = {.lex_state = 7},
  [17982] = {.lex_state = 371},
  [17983] = {.lex_state = 682},
  [17984] = {.lex_state = 0},
  [17985] = {.lex_state = 0},
  [17986] = {.lex_state = 371},
  [17987] = {.lex_state = 0},
  [17988] = {.lex_state = 7},
  [17989] = {.lex_state = 0},
  [17990] = {.lex_state = 0},
  [17991] = {.lex_state = 0},
  [17992] = {.lex_state = 371},
  [17993] = {.lex_state = 0},
  [17994] = {.lex_state = 0},
  [17995] = {.lex_state = 0},
  [17996] = {.lex_state = 0},
  [17997] = {.lex_state = 0},
  [17998] = {.lex_state = 0},
  [17999] = {.lex_state = 371},
  [18000] = {.lex_state = 7},
  [18001] = {.lex_state = 7},
  [18002] = {.lex_state = 682},
  [18003] = {.lex_state = 0},
  [18004] = {.lex_state = 371},
  [18005] = {.lex_state = 371},
  [18006] = {.lex_state = 0},
  [18007] = {.lex_state = 0},
  [18008] = {.lex_state = 0},
  [18009] = {.lex_state = 0},
  [18010] = {.lex_state = 0},
  [18011] = {.lex_state = 371},
  [18012] = {.lex_state = 0},
  [18013] = {.lex_state = 373},
  [18014] = {.lex_state = 0},
  [18015] = {.lex_state = 371},
  [18016] = {.lex_state = 371},
  [18017] = {.lex_state = 373},
  [18018] = {.lex_state = 0},
  [18019] = {.lex_state = 0},
  [18020] = {.lex_state = 0},
  [18021] = {.lex_state = 0},
  [18022] = {.lex_state = 371},
  [18023] = {.lex_state = 0},
  [18024] = {.lex_state = 0},
  [18025] = {.lex_state = 682},
  [18026] = {.lex_state = 0},
  [18027] = {.lex_state = 0},
  [18028] = {.lex_state = 0},
  [18029] = {.lex_state = 0},
  [18030] = {.lex_state = 0},
  [18031] = {.lex_state = 7},
  [18032] = {.lex_state = 371},
  [18033] = {.lex_state = 0},
  [18034] = {.lex_state = 682},
  [18035] = {.lex_state = 0},
  [18036] = {.lex_state = 0},
  [18037] = {.lex_state = 0},
  [18038] = {.lex_state = 0},
  [18039] = {.lex_state = 0},
  [18040] = {.lex_state = 682},
  [18041] = {.lex_state = 7},
  [18042] = {.lex_state = 0},
  [18043] = {.lex_state = 0},
  [18044] = {.lex_state = 0},
  [18045] = {.lex_state = 0},
  [18046] = {.lex_state = 0},
  [18047] = {.lex_state = 0},
  [18048] = {.lex_state = 682},
  [18049] = {.lex_state = 0},
  [18050] = {.lex_state = 0},
  [18051] = {.lex_state = 0},
  [18052] = {.lex_state = 0},
  [18053] = {.lex_state = 0},
  [18054] = {.lex_state = 0},
  [18055] = {.lex_state = 0},
  [18056] = {.lex_state = 0},
  [18057] = {.lex_state = 371},
  [18058] = {.lex_state = 0},
  [18059] = {.lex_state = 0},
  [18060] = {.lex_state = 0},
  [18061] = {.lex_state = 0},
  [18062] = {.lex_state = 371},
  [18063] = {.lex_state = 0},
  [18064] = {.lex_state = 682},
  [18065] = {.lex_state = 0},
  [18066] = {.lex_state = 7},
  [18067] = {.lex_state = 373},
  [18068] = {.lex_state = 0},
  [18069] = {.lex_state = 0},
  [18070] = {.lex_state = 0},
  [18071] = {.lex_state = 7},
  [18072] = {.lex_state = 682},
  [18073] = {.lex_state = 7},
  [18074] = {.lex_state = 0},
  [18075] = {.lex_state = 0},
  [18076] = {.lex_state = 0},
  [18077] = {.lex_state = 0},
  [18078] = {.lex_state = 682},
  [18079] = {.lex_state = 682},
  [18080] = {.lex_state = 682},
  [18081] = {.lex_state = 0},
  [18082] = {.lex_state = 682},
  [18083] = {.lex_state = 682},
  [18084] = {.lex_state = 682},
  [18085] = {.lex_state = 371},
  [18086] = {.lex_state = 682},
  [18087] = {.lex_state = 682},
  [18088] = {.lex_state = 682},
  [18089] = {.lex_state = 371},
  [18090] = {.lex_state = 0},
  [18091] = {.lex_state = 0},
  [18092] = {.lex_state = 0},
  [18093] = {.lex_state = 682},
  [18094] = {.lex_state = 7},
  [18095] = {.lex_state = 682},
  [18096] = {.lex_state = 682},
  [18097] = {.lex_state = 682},
  [18098] = {.lex_state = 682},
  [18099] = {.lex_state = 682},
  [18100] = {.lex_state = 0},
  [18101] = {.lex_state = 0},
  [18102] = {.lex_state = 371},
  [18103] = {.lex_state = 0},
  [18104] = {.lex_state = 0},
  [18105] = {.lex_state = 0},
  [18106] = {.lex_state = 0},
  [18107] = {.lex_state = 373},
  [18108] = {.lex_state = 7},
  [18109] = {.lex_state = 0},
  [18110] = {.lex_state = 7},
  [18111] = {.lex_state = 0},
  [18112] = {.lex_state = 373},
  [18113] = {.lex_state = 0},
  [18114] = {.lex_state = 371},
  [18115] = {.lex_state = 7},
  [18116] = {.lex_state = 0},
  [18117] = {.lex_state = 0},
  [18118] = {.lex_state = 0},
  [18119] = {.lex_state = 7},
  [18120] = {.lex_state = 371},
  [18121] = {.lex_state = 682},
  [18122] = {.lex_state = 3},
  [18123] = {.lex_state = 7},
  [18124] = {.lex_state = 7},
  [18125] = {.lex_state = 7},
  [18126] = {.lex_state = 7},
  [18127] = {.lex_state = 7},
  [18128] = {.lex_state = 7},
  [18129] = {.lex_state = 7},
  [18130] = {.lex_state = 0},
  [18131] = {.lex_state = 4},
  [18132] = {.lex_state = 7},
  [18133] = {.lex_state = 0},
  [18134] = {.lex_state = 0},
  [18135] = {.lex_state = 371},
  [18136] = {.lex_state = 7},
  [18137] = {.lex_state = 7},
  [18138] = {.lex_state = 7},
  [18139] = {.lex_state = 0},
  [18140] = {.lex_state = 0},
  [18141] = {.lex_state = 0},
  [18142] = {.lex_state = 0},
  [18143] = {.lex_state = 0},
  [18144] = {.lex_state = 0},
  [18145] = {.lex_state = 7},
  [18146] = {.lex_state = 0},
  [18147] = {.lex_state = 0},
  [18148] = {.lex_state = 7},
  [18149] = {.lex_state = 0},
  [18150] = {.lex_state = 0},
  [18151] = {.lex_state = 371},
  [18152] = {.lex_state = 0},
  [18153] = {.lex_state = 7},
  [18154] = {.lex_state = 0},
  [18155] = {.lex_state = 7},
  [18156] = {.lex_state = 0},
  [18157] = {.lex_state = 0},
  [18158] = {.lex_state = 0},
  [18159] = {.lex_state = 0},
  [18160] = {.lex_state = 0},
  [18161] = {.lex_state = 0},
  [18162] = {.lex_state = 0},
  [18163] = {.lex_state = 0},
  [18164] = {.lex_state = 0},
  [18165] = {.lex_state = 0},
  [18166] = {.lex_state = 371},
  [18167] = {.lex_state = 0},
  [18168] = {.lex_state = 371},
  [18169] = {.lex_state = 0},
  [18170] = {.lex_state = 373},
  [18171] = {.lex_state = 373},
  [18172] = {.lex_state = 0},
  [18173] = {.lex_state = 0},
  [18174] = {.lex_state = 0},
  [18175] = {.lex_state = 371},
  [18176] = {.lex_state = 0},
  [18177] = {.lex_state = 0},
  [18178] = {.lex_state = 0},
  [18179] = {.lex_state = 0},
  [18180] = {.lex_state = 0},
  [18181] = {.lex_state = 371},
  [18182] = {.lex_state = 0},
  [18183] = {.lex_state = 373},
  [18184] = {.lex_state = 7},
  [18185] = {.lex_state = 0},
  [18186] = {.lex_state = 0},
  [18187] = {.lex_state = 0},
  [18188] = {.lex_state = 0},
  [18189] = {.lex_state = 0},
  [18190] = {.lex_state = 7},
  [18191] = {.lex_state = 371},
  [18192] = {.lex_state = 0},
  [18193] = {.lex_state = 0},
  [18194] = {.lex_state = 0},
  [18195] = {.lex_state = 0},
  [18196] = {.lex_state = 0},
  [18197] = {.lex_state = 0},
  [18198] = {.lex_state = 0},
  [18199] = {.lex_state = 7},
  [18200] = {.lex_state = 7},
  [18201] = {.lex_state = 0},
  [18202] = {.lex_state = 0},
  [18203] = {.lex_state = 373},
  [18204] = {.lex_state = 0},
  [18205] = {.lex_state = 7},
  [18206] = {.lex_state = 371},
  [18207] = {.lex_state = 0},
  [18208] = {.lex_state = 0},
  [18209] = {.lex_state = 373},
  [18210] = {.lex_state = 0},
  [18211] = {.lex_state = 0},
  [18212] = {.lex_state = 0},
  [18213] = {.lex_state = 2},
  [18214] = {.lex_state = 0},
  [18215] = {.lex_state = 0},
  [18216] = {.lex_state = 0},
  [18217] = {.lex_state = 371},
  [18218] = {.lex_state = 0},
  [18219] = {.lex_state = 0},
  [18220] = {.lex_state = 0},
  [18221] = {.lex_state = 373},
  [18222] = {.lex_state = 0},
  [18223] = {.lex_state = 371},
  [18224] = {.lex_state = 371},
  [18225] = {.lex_state = 0},
  [18226] = {.lex_state = 0},
  [18227] = {.lex_state = 0},
  [18228] = {.lex_state = 0},
  [18229] = {.lex_state = 0},
  [18230] = {.lex_state = 0},
  [18231] = {.lex_state = 0},
  [18232] = {.lex_state = 0},
  [18233] = {.lex_state = 0},
  [18234] = {.lex_state = 0},
  [18235] = {.lex_state = 0},
  [18236] = {.lex_state = 0},
  [18237] = {.lex_state = 0},
  [18238] = {.lex_state = 0},
  [18239] = {.lex_state = 0},
  [18240] = {.lex_state = 371},
  [18241] = {.lex_state = 2},
  [18242] = {.lex_state = 373},
  [18243] = {.lex_state = 0},
  [18244] = {.lex_state = 371},
  [18245] = {.lex_state = 0},
  [18246] = {.lex_state = 0},
  [18247] = {.lex_state = 0},
  [18248] = {.lex_state = 0},
  [18249] = {.lex_state = 0},
  [18250] = {.lex_state = 0},
  [18251] = {.lex_state = 2},
  [18252] = {.lex_state = 0},
  [18253] = {.lex_state = 0},
  [18254] = {.lex_state = 0},
  [18255] = {.lex_state = 0},
  [18256] = {.lex_state = 0},
  [18257] = {.lex_state = 7},
  [18258] = {.lex_state = 0},
  [18259] = {.lex_state = 0},
  [18260] = {.lex_state = 0},
  [18261] = {.lex_state = 371},
  [18262] = {.lex_state = 0},
  [18263] = {.lex_state = 0},
  [18264] = {.lex_state = 0},
  [18265] = {.lex_state = 0},
  [18266] = {.lex_state = 0},
  [18267] = {.lex_state = 0},
  [18268] = {.lex_state = 0},
  [18269] = {.lex_state = 0},
  [18270] = {.lex_state = 0},
  [18271] = {.lex_state = 0},
  [18272] = {.lex_state = 0},
  [18273] = {.lex_state = 0},
  [18274] = {.lex_state = 84},
  [18275] = {.lex_state = 0},
  [18276] = {.lex_state = 0},
  [18277] = {.lex_state = 0},
  [18278] = {.lex_state = 0},
  [18279] = {.lex_state = 0},
  [18280] = {.lex_state = 371},
  [18281] = {.lex_state = 371},
  [18282] = {.lex_state = 0},
  [18283] = {.lex_state = 0},
  [18284] = {.lex_state = 0},
  [18285] = {.lex_state = 0},
  [18286] = {.lex_state = 7},
  [18287] = {.lex_state = 0},
  [18288] = {.lex_state = 0},
  [18289] = {.lex_state = 0},
  [18290] = {.lex_state = 0},
  [18291] = {.lex_state = 0},
  [18292] = {.lex_state = 7},
  [18293] = {.lex_state = 0},
  [18294] = {.lex_state = 0},
  [18295] = {.lex_state = 371},
  [18296] = {.lex_state = 371},
  [18297] = {.lex_state = 0},
  [18298] = {.lex_state = 0},
  [18299] = {.lex_state = 0},
  [18300] = {.lex_state = 0},
  [18301] = {.lex_state = 0},
  [18302] = {.lex_state = 0},
  [18303] = {.lex_state = 0},
  [18304] = {.lex_state = 0},
  [18305] = {.lex_state = 0},
  [18306] = {.lex_state = 0},
  [18307] = {.lex_state = 0},
  [18308] = {.lex_state = 0},
  [18309] = {.lex_state = 371},
  [18310] = {.lex_state = 0},
  [18311] = {.lex_state = 0},
  [18312] = {.lex_state = 0},
  [18313] = {.lex_state = 0},
  [18314] = {.lex_state = 0},
  [18315] = {.lex_state = 0},
  [18316] = {.lex_state = 0},
  [18317] = {.lex_state = 0},
  [18318] = {.lex_state = 7},
  [18319] = {.lex_state = 371},
  [18320] = {.lex_state = 371},
  [18321] = {.lex_state = 0},
  [18322] = {.lex_state = 373},
  [18323] = {.lex_state = 0},
  [18324] = {.lex_state = 0},
  [18325] = {.lex_state = 0},
  [18326] = {.lex_state = 373},
  [18327] = {.lex_state = 371},
  [18328] = {.lex_state = 371},
  [18329] = {.lex_state = 0},
  [18330] = {.lex_state = 373},
  [18331] = {.lex_state = 0},
  [18332] = {.lex_state = 0},
  [18333] = {.lex_state = 371},
  [18334] = {.lex_state = 0},
  [18335] = {.lex_state = 0},
  [18336] = {.lex_state = 0},
  [18337] = {.lex_state = 0},
  [18338] = {.lex_state = 0},
  [18339] = {.lex_state = 371},
  [18340] = {.lex_state = 0},
  [18341] = {.lex_state = 7},
  [18342] = {.lex_state = 371},
  [18343] = {.lex_state = 7},
  [18344] = {.lex_state = 0},
  [18345] = {.lex_state = 0},
  [18346] = {.lex_state = 7},
  [18347] = {.lex_state = 0},
  [18348] = {.lex_state = 0},
  [18349] = {.lex_state = 0},
  [18350] = {.lex_state = 0},
  [18351] = {.lex_state = 0},
  [18352] = {.lex_state = 373},
  [18353] = {.lex_state = 371},
  [18354] = {.lex_state = 0},
  [18355] = {.lex_state = 0},
  [18356] = {.lex_state = 0},
  [18357] = {.lex_state = 0},
  [18358] = {.lex_state = 7},
  [18359] = {.lex_state = 371},
  [18360] = {.lex_state = 0},
  [18361] = {.lex_state = 0},
  [18362] = {.lex_state = 0},
  [18363] = {.lex_state = 0},
  [18364] = {.lex_state = 0},
  [18365] = {.lex_state = 0},
  [18366] = {.lex_state = 0},
  [18367] = {.lex_state = 0},
  [18368] = {.lex_state = 0},
  [18369] = {.lex_state = 0},
  [18370] = {.lex_state = 0},
  [18371] = {.lex_state = 373},
  [18372] = {.lex_state = 0},
  [18373] = {.lex_state = 0},
  [18374] = {.lex_state = 0},
  [18375] = {.lex_state = 0},
  [18376] = {.lex_state = 0},
  [18377] = {.lex_state = 0},
  [18378] = {.lex_state = 0},
  [18379] = {.lex_state = 0},
  [18380] = {.lex_state = 0},
  [18381] = {.lex_state = 0},
  [18382] = {.lex_state = 0},
  [18383] = {.lex_state = 0},
  [18384] = {.lex_state = 0},
  [18385] = {.lex_state = 0},
  [18386] = {.lex_state = 0},
  [18387] = {.lex_state = 0},
  [18388] = {.lex_state = 0},
  [18389] = {.lex_state = 0},
  [18390] = {.lex_state = 0},
  [18391] = {.lex_state = 0},
  [18392] = {.lex_state = 0},
  [18393] = {.lex_state = 0},
  [18394] = {.lex_state = 0},
  [18395] = {.lex_state = 371},
  [18396] = {.lex_state = 0},
  [18397] = {.lex_state = 0},
  [18398] = {.lex_state = 7},
  [18399] = {.lex_state = 0},
  [18400] = {.lex_state = 0},
  [18401] = {.lex_state = 0},
  [18402] = {.lex_state = 0},
  [18403] = {.lex_state = 0},
  [18404] = {.lex_state = 0},
  [18405] = {.lex_state = 0},
  [18406] = {.lex_state = 7},
  [18407] = {.lex_state = 0},
  [18408] = {.lex_state = 0},
  [18409] = {.lex_state = 0},
  [18410] = {.lex_state = 371},
  [18411] = {.lex_state = 0},
  [18412] = {.lex_state = 7},
  [18413] = {.lex_state = 0},
  [18414] = {.lex_state = 0},
  [18415] = {.lex_state = 371},
  [18416] = {.lex_state = 0},
  [18417] = {.lex_state = 0},
  [18418] = {.lex_state = 0},
  [18419] = {.lex_state = 7},
  [18420] = {.lex_state = 0},
  [18421] = {.lex_state = 0},
  [18422] = {.lex_state = 0},
  [18423] = {.lex_state = 0},
  [18424] = {.lex_state = 0},
  [18425] = {.lex_state = 0},
  [18426] = {.lex_state = 0},
  [18427] = {.lex_state = 371},
  [18428] = {.lex_state = 0},
  [18429] = {.lex_state = 371},
  [18430] = {.lex_state = 371},
  [18431] = {.lex_state = 0},
  [18432] = {.lex_state = 0},
  [18433] = {.lex_state = 0},
  [18434] = {.lex_state = 0},
  [18435] = {.lex_state = 373},
  [18436] = {.lex_state = 0},
  [18437] = {.lex_state = 0},
  [18438] = {.lex_state = 0},
  [18439] = {.lex_state = 7},
  [18440] = {.lex_state = 0},
  [18441] = {.lex_state = 371},
  [18442] = {.lex_state = 371},
  [18443] = {.lex_state = 371},
  [18444] = {.lex_state = 0},
  [18445] = {.lex_state = 7},
  [18446] = {.lex_state = 7},
  [18447] = {.lex_state = 7},
  [18448] = {.lex_state = 7},
  [18449] = {.lex_state = 7},
  [18450] = {.lex_state = 7},
  [18451] = {.lex_state = 7},
  [18452] = {.lex_state = 371},
  [18453] = {.lex_state = 7},
  [18454] = {.lex_state = 0},
  [18455] = {.lex_state = 7},
  [18456] = {.lex_state = 0},
  [18457] = {.lex_state = 7},
  [18458] = {.lex_state = 7},
  [18459] = {.lex_state = 7},
  [18460] = {.lex_state = 0},
  [18461] = {.lex_state = 7},
  [18462] = {.lex_state = 0},
  [18463] = {.lex_state = 0},
  [18464] = {.lex_state = 7},
  [18465] = {.lex_state = 0},
  [18466] = {.lex_state = 371},
  [18467] = {.lex_state = 371},
  [18468] = {.lex_state = 7},
  [18469] = {.lex_state = 0},
  [18470] = {.lex_state = 0},
  [18471] = {.lex_state = 0},
  [18472] = {.lex_state = 0},
  [18473] = {.lex_state = 0},
  [18474] = {.lex_state = 0},
  [18475] = {.lex_state = 0},
  [18476] = {.lex_state = 0},
  [18477] = {.lex_state = 0},
  [18478] = {.lex_state = 0},
  [18479] = {.lex_state = 0},
  [18480] = {.lex_state = 373},
  [18481] = {.lex_state = 373},
  [18482] = {.lex_state = 0},
  [18483] = {.lex_state = 0},
  [18484] = {.lex_state = 0},
  [18485] = {.lex_state = 0},
  [18486] = {.lex_state = 0},
  [18487] = {.lex_state = 0},
  [18488] = {.lex_state = 0},
  [18489] = {.lex_state = 373},
  [18490] = {.lex_state = 7},
  [18491] = {.lex_state = 0},
  [18492] = {.lex_state = 0},
  [18493] = {.lex_state = 371},
  [18494] = {.lex_state = 0},
  [18495] = {.lex_state = 7},
  [18496] = {.lex_state = 7},
  [18497] = {.lex_state = 0},
  [18498] = {.lex_state = 373},
  [18499] = {.lex_state = 7},
  [18500] = {.lex_state = 7},
  [18501] = {.lex_state = 0},
  [18502] = {.lex_state = 0},
  [18503] = {.lex_state = 0},
  [18504] = {.lex_state = 0},
  [18505] = {.lex_state = 0},
  [18506] = {.lex_state = 0},
  [18507] = {.lex_state = 0},
  [18508] = {.lex_state = 371},
  [18509] = {.lex_state = 0},
  [18510] = {.lex_state = 0},
  [18511] = {.lex_state = 0},
  [18512] = {.lex_state = 0},
  [18513] = {.lex_state = 0},
  [18514] = {.lex_state = 371},
  [18515] = {.lex_state = 0},
  [18516] = {.lex_state = 0},
  [18517] = {.lex_state = 0},
  [18518] = {.lex_state = 373},
  [18519] = {.lex_state = 0},
  [18520] = {.lex_state = 371},
  [18521] = {.lex_state = 0},
  [18522] = {.lex_state = 0},
  [18523] = {.lex_state = 0},
  [18524] = {.lex_state = 0},
  [18525] = {.lex_state = 0},
  [18526] = {.lex_state = 0},
  [18527] = {.lex_state = 0},
  [18528] = {.lex_state = 0},
  [18529] = {.lex_state = 0},
  [18530] = {.lex_state = 7},
  [18531] = {.lex_state = 0},
  [18532] = {.lex_state = 371},
  [18533] = {.lex_state = 0},
  [18534] = {.lex_state = 0},
  [18535] = {.lex_state = 0},
  [18536] = {.lex_state = 0},
  [18537] = {.lex_state = 371},
  [18538] = {.lex_state = 0},
  [18539] = {.lex_state = 0},
  [18540] = {.lex_state = 0},
  [18541] = {.lex_state = 0},
  [18542] = {.lex_state = 0},
  [18543] = {.lex_state = 0},
  [18544] = {.lex_state = 0},
  [18545] = {.lex_state = 371},
  [18546] = {.lex_state = 7},
  [18547] = {.lex_state = 371},
  [18548] = {.lex_state = 0},
  [18549] = {.lex_state = 0},
  [18550] = {.lex_state = 0},
  [18551] = {.lex_state = 371},
  [18552] = {.lex_state = 0},
  [18553] = {.lex_state = 0},
  [18554] = {.lex_state = 0},
  [18555] = {.lex_state = 7},
  [18556] = {.lex_state = 371},
  [18557] = {.lex_state = 0},
  [18558] = {.lex_state = 0},
  [18559] = {.lex_state = 371},
  [18560] = {.lex_state = 0},
  [18561] = {.lex_state = 0},
  [18562] = {.lex_state = 371},
  [18563] = {.lex_state = 0},
  [18564] = {.lex_state = 371},
  [18565] = {.lex_state = 0},
  [18566] = {.lex_state = 0},
  [18567] = {.lex_state = 0},
  [18568] = {.lex_state = 0},
  [18569] = {.lex_state = 7},
  [18570] = {.lex_state = 371},
  [18571] = {.lex_state = 0},
  [18572] = {.lex_state = 0},
  [18573] = {.lex_state = 0},
  [18574] = {.lex_state = 0},
  [18575] = {.lex_state = 0},
  [18576] = {.lex_state = 0},
  [18577] = {.lex_state = 0},
  [18578] = {.lex_state = 0},
  [18579] = {.lex_state = 0},
  [18580] = {.lex_state = 0},
  [18581] = {.lex_state = 0},
  [18582] = {.lex_state = 0},
  [18583] = {.lex_state = 0},
  [18584] = {.lex_state = 0},
  [18585] = {.lex_state = 0},
  [18586] = {.lex_state = 0},
  [18587] = {.lex_state = 0},
  [18588] = {.lex_state = 0},
  [18589] = {.lex_state = 7},
  [18590] = {.lex_state = 0},
  [18591] = {.lex_state = 0},
  [18592] = {.lex_state = 0},
  [18593] = {.lex_state = 0},
  [18594] = {.lex_state = 0},
  [18595] = {.lex_state = 0},
  [18596] = {.lex_state = 0},
  [18597] = {.lex_state = 0},
  [18598] = {.lex_state = 0},
  [18599] = {.lex_state = 0},
  [18600] = {.lex_state = 0},
  [18601] = {.lex_state = 371},
  [18602] = {.lex_state = 0},
  [18603] = {.lex_state = 0},
  [18604] = {.lex_state = 0},
  [18605] = {.lex_state = 0},
  [18606] = {.lex_state = 0},
  [18607] = {.lex_state = 0},
  [18608] = {.lex_state = 0},
  [18609] = {.lex_state = 371},
  [18610] = {.lex_state = 0},
  [18611] = {.lex_state = 0},
  [18612] = {.lex_state = 0},
  [18613] = {.lex_state = 0},
  [18614] = {.lex_state = 371},
  [18615] = {.lex_state = 0},
  [18616] = {.lex_state = 371},
  [18617] = {.lex_state = 371},
  [18618] = {.lex_state = 7},
  [18619] = {.lex_state = 0},
  [18620] = {.lex_state = 7},
  [18621] = {.lex_state = 0},
  [18622] = {.lex_state = 0},
  [18623] = {.lex_state = 373},
  [18624] = {.lex_state = 0},
  [18625] = {.lex_state = 0},
  [18626] = {.lex_state = 371},
  [18627] = {.lex_state = 0},
  [18628] = {.lex_state = 0},
  [18629] = {.lex_state = 0},
  [18630] = {.lex_state = 371},
  [18631] = {.lex_state = 682},
  [18632] = {.lex_state = 0},
  [18633] = {.lex_state = 7},
  [18634] = {.lex_state = 7},
  [18635] = {.lex_state = 7},
  [18636] = {.lex_state = 7},
  [18637] = {.lex_state = 7},
  [18638] = {.lex_state = 7},
  [18639] = {.lex_state = 7},
  [18640] = {.lex_state = 0},
  [18641] = {.lex_state = 7},
  [18642] = {.lex_state = 0},
  [18643] = {.lex_state = 0},
  [18644] = {.lex_state = 0},
  [18645] = {.lex_state = 7},
  [18646] = {.lex_state = 7},
  [18647] = {.lex_state = 7},
  [18648] = {.lex_state = 0},
  [18649] = {.lex_state = 7},
  [18650] = {.lex_state = 0},
  [18651] = {.lex_state = 0},
  [18652] = {.lex_state = 0},
  [18653] = {.lex_state = 0},
  [18654] = {.lex_state = 0},
  [18655] = {.lex_state = 371},
  [18656] = {.lex_state = 7},
  [18657] = {.lex_state = 0},
  [18658] = {.lex_state = 0},
  [18659] = {.lex_state = 0},
  [18660] = {.lex_state = 0},
  [18661] = {.lex_state = 0},
  [18662] = {.lex_state = 371},
  [18663] = {.lex_state = 0},
  [18664] = {.lex_state = 373},
  [18665] = {.lex_state = 373},
  [18666] = {.lex_state = 0},
  [18667] = {.lex_state = 0},
  [18668] = {.lex_state = 371},
  [18669] = {.lex_state = 0},
  [18670] = {.lex_state = 0},
  [18671] = {.lex_state = 0},
  [18672] = {.lex_state = 0},
  [18673] = {.lex_state = 373},
  [18674] = {.lex_state = 7},
  [18675] = {.lex_state = 0},
  [18676] = {.lex_state = 0},
  [18677] = {.lex_state = 371},
  [18678] = {.lex_state = 0},
  [18679] = {.lex_state = 371},
  [18680] = {.lex_state = 7},
  [18681] = {.lex_state = 373},
  [18682] = {.lex_state = 0},
  [18683] = {.lex_state = 7},
  [18684] = {.lex_state = 371},
  [18685] = {.lex_state = 0},
  [18686] = {.lex_state = 7},
  [18687] = {.lex_state = 371},
  [18688] = {.lex_state = 0},
  [18689] = {.lex_state = 0},
  [18690] = {.lex_state = 0},
  [18691] = {.lex_state = 371},
  [18692] = {.lex_state = 0},
  [18693] = {.lex_state = 0},
  [18694] = {.lex_state = 0},
  [18695] = {.lex_state = 0},
  [18696] = {.lex_state = 0},
  [18697] = {.lex_state = 0},
  [18698] = {.lex_state = 0},
  [18699] = {.lex_state = 371},
  [18700] = {.lex_state = 0},
  [18701] = {.lex_state = 373},
  [18702] = {.lex_state = 0},
  [18703] = {.lex_state = 371},
  [18704] = {.lex_state = 0},
  [18705] = {.lex_state = 0},
  [18706] = {.lex_state = 0},
  [18707] = {.lex_state = 0},
  [18708] = {.lex_state = 0},
  [18709] = {.lex_state = 0},
  [18710] = {.lex_state = 0},
  [18711] = {.lex_state = 0},
  [18712] = {.lex_state = 0},
  [18713] = {.lex_state = 7},
  [18714] = {.lex_state = 0},
  [18715] = {.lex_state = 371},
  [18716] = {.lex_state = 0},
  [18717] = {.lex_state = 0},
  [18718] = {.lex_state = 0},
  [18719] = {.lex_state = 0},
  [18720] = {.lex_state = 371},
  [18721] = {.lex_state = 0},
  [18722] = {.lex_state = 0},
  [18723] = {.lex_state = 0},
  [18724] = {.lex_state = 371},
  [18725] = {.lex_state = 0},
  [18726] = {.lex_state = 0},
  [18727] = {.lex_state = 0},
  [18728] = {.lex_state = 0},
  [18729] = {.lex_state = 7},
  [18730] = {.lex_state = 371},
  [18731] = {.lex_state = 0},
  [18732] = {.lex_state = 0},
  [18733] = {.lex_state = 0},
  [18734] = {.lex_state = 0},
  [18735] = {.lex_state = 0},
  [18736] = {.lex_state = 0},
  [18737] = {.lex_state = 0},
  [18738] = {.lex_state = 7},
  [18739] = {.lex_state = 371},
  [18740] = {.lex_state = 0},
  [18741] = {.lex_state = 0},
  [18742] = {.lex_state = 0},
  [18743] = {.lex_state = 0},
  [18744] = {.lex_state = 0},
  [18745] = {.lex_state = 0},
  [18746] = {.lex_state = 371},
  [18747] = {.lex_state = 371},
  [18748] = {.lex_state = 0},
  [18749] = {.lex_state = 0},
  [18750] = {.lex_state = 0},
  [18751] = {.lex_state = 0},
  [18752] = {.lex_state = 0},
  [18753] = {.lex_state = 371},
  [18754] = {.lex_state = 0},
  [18755] = {.lex_state = 0},
  [18756] = {.lex_state = 2},
  [18757] = {.lex_state = 7},
  [18758] = {.lex_state = 0},
  [18759] = {.lex_state = 371},
  [18760] = {.lex_state = 0},
  [18761] = {.lex_state = 371},
  [18762] = {.lex_state = 0},
  [18763] = {.lex_state = 0},
  [18764] = {.lex_state = 0},
  [18765] = {.lex_state = 7},
  [18766] = {.lex_state = 0},
  [18767] = {.lex_state = 0},
  [18768] = {.lex_state = 0},
  [18769] = {.lex_state = 371},
  [18770] = {.lex_state = 0},
  [18771] = {.lex_state = 0},
  [18772] = {.lex_state = 0},
  [18773] = {.lex_state = 0},
  [18774] = {.lex_state = 0},
  [18775] = {.lex_state = 0},
  [18776] = {.lex_state = 0},
  [18777] = {.lex_state = 0},
  [18778] = {.lex_state = 0},
  [18779] = {.lex_state = 0},
  [18780] = {.lex_state = 0},
  [18781] = {.lex_state = 0},
  [18782] = {.lex_state = 0},
  [18783] = {.lex_state = 371},
  [18784] = {.lex_state = 0},
  [18785] = {.lex_state = 373},
  [18786] = {.lex_state = 0},
  [18787] = {.lex_state = 0},
  [18788] = {.lex_state = 0},
  [18789] = {.lex_state = 0},
  [18790] = {.lex_state = 373},
  [18791] = {.lex_state = 0},
  [18792] = {.lex_state = 0},
  [18793] = {.lex_state = 0},
  [18794] = {.lex_state = 0},
  [18795] = {.lex_state = 0},
  [18796] = {.lex_state = 371},
  [18797] = {.lex_state = 371},
  [18798] = {.lex_state = 0},
  [18799] = {.lex_state = 0},
  [18800] = {.lex_state = 7},
  [18801] = {.lex_state = 7},
  [18802] = {.lex_state = 7},
  [18803] = {.lex_state = 7},
  [18804] = {.lex_state = 7},
  [18805] = {.lex_state = 7},
  [18806] = {.lex_state = 7},
  [18807] = {.lex_state = 0},
  [18808] = {.lex_state = 7},
  [18809] = {.lex_state = 0},
  [18810] = {.lex_state = 0},
  [18811] = {.lex_state = 0},
  [18812] = {.lex_state = 7},
  [18813] = {.lex_state = 7},
  [18814] = {.lex_state = 7},
  [18815] = {.lex_state = 0},
  [18816] = {.lex_state = 7},
  [18817] = {.lex_state = 0},
  [18818] = {.lex_state = 0},
  [18819] = {.lex_state = 371},
  [18820] = {.lex_state = 0},
  [18821] = {.lex_state = 0},
  [18822] = {.lex_state = 371},
  [18823] = {.lex_state = 7},
  [18824] = {.lex_state = 0},
  [18825] = {.lex_state = 0},
  [18826] = {.lex_state = 0},
  [18827] = {.lex_state = 0},
  [18828] = {.lex_state = 7},
  [18829] = {.lex_state = 0},
  [18830] = {.lex_state = 373},
  [18831] = {.lex_state = 373},
  [18832] = {.lex_state = 0},
  [18833] = {.lex_state = 0},
  [18834] = {.lex_state = 0},
  [18835] = {.lex_state = 0},
  [18836] = {.lex_state = 0},
  [18837] = {.lex_state = 0},
  [18838] = {.lex_state = 0},
  [18839] = {.lex_state = 373},
  [18840] = {.lex_state = 7},
  [18841] = {.lex_state = 0},
  [18842] = {.lex_state = 0},
  [18843] = {.lex_state = 371},
  [18844] = {.lex_state = 0},
  [18845] = {.lex_state = 371},
  [18846] = {.lex_state = 7},
  [18847] = {.lex_state = 0},
  [18848] = {.lex_state = 0},
  [18849] = {.lex_state = 7},
  [18850] = {.lex_state = 0},
  [18851] = {.lex_state = 0},
  [18852] = {.lex_state = 0},
  [18853] = {.lex_state = 0},
  [18854] = {.lex_state = 0},
  [18855] = {.lex_state = 0},
  [18856] = {.lex_state = 371},
  [18857] = {.lex_state = 0},
  [18858] = {.lex_state = 0},
  [18859] = {.lex_state = 0},
  [18860] = {.lex_state = 0},
  [18861] = {.lex_state = 0},
  [18862] = {.lex_state = 0},
  [18863] = {.lex_state = 0},
  [18864] = {.lex_state = 0},
  [18865] = {.lex_state = 373},
  [18866] = {.lex_state = 0},
  [18867] = {.lex_state = 371},
  [18868] = {.lex_state = 0},
  [18869] = {.lex_state = 0},
  [18870] = {.lex_state = 0},
  [18871] = {.lex_state = 0},
  [18872] = {.lex_state = 0},
  [18873] = {.lex_state = 0},
  [18874] = {.lex_state = 0},
  [18875] = {.lex_state = 0},
  [18876] = {.lex_state = 0},
  [18877] = {.lex_state = 7},
  [18878] = {.lex_state = 0},
  [18879] = {.lex_state = 371},
  [18880] = {.lex_state = 0},
  [18881] = {.lex_state = 0},
  [18882] = {.lex_state = 0},
  [18883] = {.lex_state = 0},
  [18884] = {.lex_state = 371},
  [18885] = {.lex_state = 0},
  [18886] = {.lex_state = 0},
  [18887] = {.lex_state = 0},
  [18888] = {.lex_state = 0},
  [18889] = {.lex_state = 0},
  [18890] = {.lex_state = 0},
  [18891] = {.lex_state = 0},
  [18892] = {.lex_state = 0},
  [18893] = {.lex_state = 7},
  [18894] = {.lex_state = 371},
  [18895] = {.lex_state = 0},
  [18896] = {.lex_state = 7},
  [18897] = {.lex_state = 0},
  [18898] = {.lex_state = 0},
  [18899] = {.lex_state = 371},
  [18900] = {.lex_state = 0},
  [18901] = {.lex_state = 7},
  [18902] = {.lex_state = 371},
  [18903] = {.lex_state = 0},
  [18904] = {.lex_state = 0},
  [18905] = {.lex_state = 0},
  [18906] = {.lex_state = 0},
  [18907] = {.lex_state = 0},
  [18908] = {.lex_state = 371},
  [18909] = {.lex_state = 0},
  [18910] = {.lex_state = 371},
  [18911] = {.lex_state = 0},
  [18912] = {.lex_state = 371},
  [18913] = {.lex_state = 0},
  [18914] = {.lex_state = 0},
  [18915] = {.lex_state = 0},
  [18916] = {.lex_state = 371},
  [18917] = {.lex_state = 0},
  [18918] = {.lex_state = 371},
  [18919] = {.lex_state = 7},
  [18920] = {.lex_state = 0},
  [18921] = {.lex_state = 0},
  [18922] = {.lex_state = 0},
  [18923] = {.lex_state = 0},
  [18924] = {.lex_state = 0},
  [18925] = {.lex_state = 371},
  [18926] = {.lex_state = 371},
  [18927] = {.lex_state = 0},
  [18928] = {.lex_state = 0},
  [18929] = {.lex_state = 0},
  [18930] = {.lex_state = 0},
  [18931] = {.lex_state = 371},
  [18932] = {.lex_state = 0},
  [18933] = {.lex_state = 0},
  [18934] = {.lex_state = 371},
  [18935] = {.lex_state = 0},
  [18936] = {.lex_state = 0},
  [18937] = {.lex_state = 0},
  [18938] = {.lex_state = 0},
  [18939] = {.lex_state = 0},
  [18940] = {.lex_state = 371},
  [18941] = {.lex_state = 0},
  [18942] = {.lex_state = 0},
  [18943] = {.lex_state = 0},
  [18944] = {.lex_state = 371},
  [18945] = {.lex_state = 7},
  [18946] = {.lex_state = 7},
  [18947] = {.lex_state = 7},
  [18948] = {.lex_state = 7},
  [18949] = {.lex_state = 7},
  [18950] = {.lex_state = 7},
  [18951] = {.lex_state = 7},
  [18952] = {.lex_state = 7},
  [18953] = {.lex_state = 0},
  [18954] = {.lex_state = 0},
  [18955] = {.lex_state = 0},
  [18956] = {.lex_state = 7},
  [18957] = {.lex_state = 7},
  [18958] = {.lex_state = 7},
  [18959] = {.lex_state = 7},
  [18960] = {.lex_state = 0},
  [18961] = {.lex_state = 0},
  [18962] = {.lex_state = 0},
  [18963] = {.lex_state = 0},
  [18964] = {.lex_state = 371},
  [18965] = {.lex_state = 7},
  [18966] = {.lex_state = 0},
  [18967] = {.lex_state = 0},
  [18968] = {.lex_state = 0},
  [18969] = {.lex_state = 0},
  [18970] = {.lex_state = 0},
  [18971] = {.lex_state = 0},
  [18972] = {.lex_state = 0},
  [18973] = {.lex_state = 0},
  [18974] = {.lex_state = 0},
  [18975] = {.lex_state = 0},
  [18976] = {.lex_state = 373},
  [18977] = {.lex_state = 371},
  [18978] = {.lex_state = 0},
  [18979] = {.lex_state = 0},
  [18980] = {.lex_state = 7},
  [18981] = {.lex_state = 7},
  [18982] = {.lex_state = 0},
  [18983] = {.lex_state = 7},
  [18984] = {.lex_state = 0},
  [18985] = {.lex_state = 0},
  [18986] = {.lex_state = 0},
  [18987] = {.lex_state = 0},
  [18988] = {.lex_state = 371},
  [18989] = {.lex_state = 0},
  [18990] = {.lex_state = 0},
  [18991] = {.lex_state = 0},
  [18992] = {.lex_state = 0},
  [18993] = {.lex_state = 0},
  [18994] = {.lex_state = 0},
  [18995] = {.lex_state = 373},
  [18996] = {.lex_state = 371},
  [18997] = {.lex_state = 0},
  [18998] = {.lex_state = 0},
  [18999] = {.lex_state = 0},
  [19000] = {.lex_state = 0},
  [19001] = {.lex_state = 0},
  [19002] = {.lex_state = 0},
  [19003] = {.lex_state = 0},
  [19004] = {.lex_state = 0},
  [19005] = {.lex_state = 0},
  [19006] = {.lex_state = 371},
  [19007] = {.lex_state = 0},
  [19008] = {.lex_state = 0},
  [19009] = {.lex_state = 0},
  [19010] = {.lex_state = 0},
  [19011] = {.lex_state = 371},
  [19012] = {.lex_state = 0},
  [19013] = {.lex_state = 7},
  [19014] = {.lex_state = 0},
  [19015] = {.lex_state = 0},
  [19016] = {.lex_state = 0},
  [19017] = {.lex_state = 0},
  [19018] = {.lex_state = 371},
  [19019] = {.lex_state = 0},
  [19020] = {.lex_state = 371},
  [19021] = {.lex_state = 0},
  [19022] = {.lex_state = 0},
  [19023] = {.lex_state = 371},
  [19024] = {.lex_state = 0},
  [19025] = {.lex_state = 371},
  [19026] = {.lex_state = 0},
  [19027] = {.lex_state = 0},
  [19028] = {.lex_state = 0},
  [19029] = {.lex_state = 0},
  [19030] = {.lex_state = 0},
  [19031] = {.lex_state = 0},
  [19032] = {.lex_state = 371},
  [19033] = {.lex_state = 0},
  [19034] = {.lex_state = 0},
  [19035] = {.lex_state = 0},
  [19036] = {.lex_state = 371},
  [19037] = {.lex_state = 371},
  [19038] = {.lex_state = 0},
  [19039] = {.lex_state = 371},
  [19040] = {.lex_state = 371},
  [19041] = {.lex_state = 0},
  [19042] = {.lex_state = 7},
  [19043] = {.lex_state = 0},
  [19044] = {.lex_state = 371},
  [19045] = {.lex_state = 0},
  [19046] = {.lex_state = 0},
  [19047] = {.lex_state = 7},
  [19048] = {.lex_state = 7},
  [19049] = {.lex_state = 7},
  [19050] = {.lex_state = 7},
  [19051] = {.lex_state = 7},
  [19052] = {.lex_state = 7},
  [19053] = {.lex_state = 7},
  [19054] = {.lex_state = 7},
  [19055] = {.lex_state = 7},
  [19056] = {.lex_state = 371},
  [19057] = {.lex_state = 0},
  [19058] = {.lex_state = 7},
  [19059] = {.lex_state = 7},
  [19060] = {.lex_state = 7},
  [19061] = {.lex_state = 7},
  [19062] = {.lex_state = 0},
  [19063] = {.lex_state = 373},
  [19064] = {.lex_state = 0},
  [19065] = {.lex_state = 0},
  [19066] = {.lex_state = 0},
  [19067] = {.lex_state = 7},
  [19068] = {.lex_state = 7},
  [19069] = {.lex_state = 373},
  [19070] = {.lex_state = 371},
  [19071] = {.lex_state = 0},
  [19072] = {.lex_state = 0},
  [19073] = {.lex_state = 0},
  [19074] = {.lex_state = 0},
  [19075] = {.lex_state = 0},
  [19076] = {.lex_state = 0},
  [19077] = {.lex_state = 0},
  [19078] = {.lex_state = 373},
  [19079] = {.lex_state = 0},
  [19080] = {.lex_state = 7},
  [19081] = {.lex_state = 0},
  [19082] = {.lex_state = 0},
  [19083] = {.lex_state = 0},
  [19084] = {.lex_state = 371},
  [19085] = {.lex_state = 0},
  [19086] = {.lex_state = 0},
  [19087] = {.lex_state = 0},
  [19088] = {.lex_state = 0},
  [19089] = {.lex_state = 371},
  [19090] = {.lex_state = 0},
  [19091] = {.lex_state = 371},
  [19092] = {.lex_state = 371},
  [19093] = {.lex_state = 0},
  [19094] = {.lex_state = 373},
  [19095] = {.lex_state = 371},
  [19096] = {.lex_state = 0},
  [19097] = {.lex_state = 0},
  [19098] = {.lex_state = 7},
  [19099] = {.lex_state = 7},
  [19100] = {.lex_state = 7},
  [19101] = {.lex_state = 7},
  [19102] = {.lex_state = 7},
  [19103] = {.lex_state = 7},
  [19104] = {.lex_state = 7},
  [19105] = {.lex_state = 7},
  [19106] = {.lex_state = 371},
  [19107] = {.lex_state = 0},
  [19108] = {.lex_state = 371},
  [19109] = {.lex_state = 7},
  [19110] = {.lex_state = 7},
  [19111] = {.lex_state = 7},
  [19112] = {.lex_state = 7},
  [19113] = {.lex_state = 0},
  [19114] = {.lex_state = 7},
  [19115] = {.lex_state = 0},
  [19116] = {.lex_state = 0},
  [19117] = {.lex_state = 7},
  [19118] = {.lex_state = 7},
  [19119] = {.lex_state = 371},
  [19120] = {.lex_state = 0},
  [19121] = {.lex_state = 0},
  [19122] = {.lex_state = 0},
  [19123] = {.lex_state = 0},
  [19124] = {.lex_state = 0},
  [19125] = {.lex_state = 0},
  [19126] = {.lex_state = 371},
  [19127] = {.lex_state = 0},
  [19128] = {.lex_state = 0},
  [19129] = {.lex_state = 0},
  [19130] = {.lex_state = 0},
  [19131] = {.lex_state = 0},
  [19132] = {.lex_state = 0},
  [19133] = {.lex_state = 0},
  [19134] = {.lex_state = 0},
  [19135] = {.lex_state = 0},
  [19136] = {.lex_state = 0},
  [19137] = {.lex_state = 371},
  [19138] = {.lex_state = 0},
  [19139] = {.lex_state = 371},
  [19140] = {.lex_state = 7},
  [19141] = {.lex_state = 7},
  [19142] = {.lex_state = 7},
  [19143] = {.lex_state = 7},
  [19144] = {.lex_state = 7},
  [19145] = {.lex_state = 371},
  [19146] = {.lex_state = 371},
  [19147] = {.lex_state = 7},
  [19148] = {.lex_state = 7},
  [19149] = {.lex_state = 7},
  [19150] = {.lex_state = 0},
  [19151] = {.lex_state = 371},
  [19152] = {.lex_state = 7},
  [19153] = {.lex_state = 7},
  [19154] = {.lex_state = 7},
  [19155] = {.lex_state = 7},
  [19156] = {.lex_state = 7},
  [19157] = {.lex_state = 371},
  [19158] = {.lex_state = 371},
  [19159] = {.lex_state = 7},
  [19160] = {.lex_state = 7},
  [19161] = {.lex_state = 7},
  [19162] = {.lex_state = 0},
  [19163] = {.lex_state = 7},
  [19164] = {.lex_state = 7},
  [19165] = {.lex_state = 7},
  [19166] = {.lex_state = 7},
  [19167] = {.lex_state = 7},
  [19168] = {.lex_state = 0},
  [19169] = {.lex_state = 0},
  [19170] = {.lex_state = 7},
  [19171] = {.lex_state = 7},
  [19172] = {.lex_state = 7},
  [19173] = {.lex_state = 0},
  [19174] = {.lex_state = 7},
  [19175] = {.lex_state = 7},
  [19176] = {.lex_state = 7},
  [19177] = {.lex_state = 7},
  [19178] = {.lex_state = 7},
  [19179] = {.lex_state = 7},
  [19180] = {.lex_state = 0},
  [19181] = {.lex_state = 7},
  [19182] = {.lex_state = 7},
  [19183] = {.lex_state = 7},
  [19184] = {.lex_state = 0},
  [19185] = {.lex_state = 7},
  [19186] = {.lex_state = 7},
  [19187] = {.lex_state = 7},
  [19188] = {.lex_state = 7},
  [19189] = {.lex_state = 7},
  [19190] = {.lex_state = 0},
  [19191] = {.lex_state = 0},
  [19192] = {.lex_state = 7},
  [19193] = {.lex_state = 7},
  [19194] = {.lex_state = 7},
  [19195] = {.lex_state = 0},
  [19196] = {.lex_state = 7},
  [19197] = {.lex_state = 7},
  [19198] = {.lex_state = 7},
  [19199] = {.lex_state = 7},
  [19200] = {.lex_state = 7},
  [19201] = {.lex_state = 0},
  [19202] = {.lex_state = 0},
  [19203] = {.lex_state = 7},
  [19204] = {.lex_state = 7},
  [19205] = {.lex_state = 7},
  [19206] = {.lex_state = 0},
  [19207] = {.lex_state = 7},
  [19208] = {.lex_state = 7},
  [19209] = {.lex_state = 7},
  [19210] = {.lex_state = 7},
  [19211] = {.lex_state = 7},
  [19212] = {.lex_state = 0},
  [19213] = {.lex_state = 371},
  [19214] = {.lex_state = 7},
  [19215] = {.lex_state = 7},
  [19216] = {.lex_state = 7},
  [19217] = {.lex_state = 0},
  [19218] = {.lex_state = 371},
  [19219] = {.lex_state = 371},
  [19220] = {.lex_state = 0},
  [19221] = {.lex_state = 0},
  [19222] = {.lex_state = 0},
  [19223] = {.lex_state = 0},
  [19224] = {.lex_state = 0},
  [19225] = {.lex_state = 0},
  [19226] = {.lex_state = 0},
  [19227] = {.lex_state = 0},
  [19228] = {.lex_state = 0},
  [19229] = {.lex_state = 7},
  [19230] = {.lex_state = 0},
  [19231] = {.lex_state = 373},
  [19232] = {.lex_state = 0},
  [19233] = {.lex_state = 371},
  [19234] = {.lex_state = 371},
  [19235] = {.lex_state = 371},
  [19236] = {.lex_state = 0},
  [19237] = {.lex_state = 0},
  [19238] = {.lex_state = 0},
  [19239] = {.lex_state = 371},
  [19240] = {.lex_state = 373},
  [19241] = {.lex_state = 0},
  [19242] = {.lex_state = 0},
  [19243] = {.lex_state = 0},
  [19244] = {.lex_state = 0},
  [19245] = {.lex_state = 0},
  [19246] = {.lex_state = 0},
  [19247] = {.lex_state = 7},
  [19248] = {.lex_state = 7},
  [19249] = {.lex_state = 7},
  [19250] = {.lex_state = 7},
  [19251] = {.lex_state = 7},
  [19252] = {.lex_state = 0},
  [19253] = {.lex_state = 0},
  [19254] = {.lex_state = 7},
  [19255] = {.lex_state = 0},
  [19256] = {.lex_state = 0},
  [19257] = {.lex_state = 7},
  [19258] = {.lex_state = 7},
  [19259] = {.lex_state = 7},
  [19260] = {.lex_state = 0},
  [19261] = {.lex_state = 371},
  [19262] = {.lex_state = 0},
  [19263] = {.lex_state = 0},
  [19264] = {.lex_state = 373},
  [19265] = {.lex_state = 7},
  [19266] = {.lex_state = 0},
  [19267] = {.lex_state = 371},
  [19268] = {.lex_state = 371},
  [19269] = {.lex_state = 0},
  [19270] = {.lex_state = 371},
  [19271] = {.lex_state = 0},
  [19272] = {.lex_state = 0},
  [19273] = {.lex_state = 7},
  [19274] = {.lex_state = 0},
  [19275] = {.lex_state = 0},
  [19276] = {.lex_state = 0},
  [19277] = {.lex_state = 0},
  [19278] = {.lex_state = 0},
  [19279] = {.lex_state = 0},
  [19280] = {.lex_state = 0},
  [19281] = {.lex_state = 0},
  [19282] = {.lex_state = 0},
  [19283] = {.lex_state = 0},
  [19284] = {.lex_state = 0},
  [19285] = {.lex_state = 371},
  [19286] = {.lex_state = 0},
  [19287] = {.lex_state = 0},
  [19288] = {.lex_state = 0},
  [19289] = {.lex_state = 0},
  [19290] = {.lex_state = 0},
  [19291] = {.lex_state = 7},
  [19292] = {.lex_state = 0},
  [19293] = {.lex_state = 0},
  [19294] = {.lex_state = 0},
  [19295] = {.lex_state = 371},
  [19296] = {.lex_state = 7},
  [19297] = {.lex_state = 0},
  [19298] = {.lex_state = 0},
  [19299] = {.lex_state = 0},
  [19300] = {.lex_state = 0},
  [19301] = {.lex_state = 7},
  [19302] = {.lex_state = 0},
  [19303] = {.lex_state = 0},
  [19304] = {.lex_state = 371},
  [19305] = {.lex_state = 0},
  [19306] = {.lex_state = 0},
  [19307] = {.lex_state = 0},
  [19308] = {.lex_state = 0},
  [19309] = {.lex_state = 371},
  [19310] = {.lex_state = 0},
  [19311] = {.lex_state = 0},
  [19312] = {.lex_state = 0},
  [19313] = {.lex_state = 0},
  [19314] = {.lex_state = 373},
  [19315] = {.lex_state = 0},
  [19316] = {.lex_state = 0},
  [19317] = {.lex_state = 0},
  [19318] = {.lex_state = 0},
  [19319] = {.lex_state = 0},
  [19320] = {.lex_state = 7},
  [19321] = {.lex_state = 0},
  [19322] = {.lex_state = 0},
  [19323] = {.lex_state = 0},
  [19324] = {.lex_state = 371},
  [19325] = {.lex_state = 0},
  [19326] = {.lex_state = 0},
  [19327] = {.lex_state = 0},
  [19328] = {.lex_state = 0},
  [19329] = {.lex_state = 0},
  [19330] = {.lex_state = 0},
  [19331] = {.lex_state = 7},
  [19332] = {.lex_state = 0},
  [19333] = {.lex_state = 0},
  [19334] = {.lex_state = 0},
  [19335] = {.lex_state = 0},
  [19336] = {.lex_state = 371},
  [19337] = {.lex_state = 7},
  [19338] = {.lex_state = 0},
  [19339] = {.lex_state = 0},
  [19340] = {.lex_state = 0},
  [19341] = {.lex_state = 0},
  [19342] = {.lex_state = 0},
  [19343] = {.lex_state = 0},
  [19344] = {.lex_state = 0},
  [19345] = {.lex_state = 371},
  [19346] = {.lex_state = 0},
  [19347] = {.lex_state = 0},
  [19348] = {.lex_state = 7},
  [19349] = {.lex_state = 371},
  [19350] = {.lex_state = 0},
  [19351] = {.lex_state = 371},
  [19352] = {.lex_state = 371},
  [19353] = {.lex_state = 0},
  [19354] = {.lex_state = 0},
  [19355] = {.lex_state = 7},
  [19356] = {.lex_state = 0},
  [19357] = {.lex_state = 7},
  [19358] = {.lex_state = 371},
  [19359] = {.lex_state = 0},
  [19360] = {.lex_state = 0},
  [19361] = {.lex_state = 0},
  [19362] = {.lex_state = 0},
  [19363] = {.lex_state = 0},
  [19364] = {.lex_state = 0},
  [19365] = {.lex_state = 0},
  [19366] = {.lex_state = 0},
  [19367] = {.lex_state = 0},
  [19368] = {.lex_state = 0},
  [19369] = {.lex_state = 0},
  [19370] = {.lex_state = 0},
  [19371] = {.lex_state = 0},
  [19372] = {.lex_state = 7},
  [19373] = {.lex_state = 0},
  [19374] = {.lex_state = 0},
  [19375] = {.lex_state = 371},
  [19376] = {.lex_state = 7},
  [19377] = {.lex_state = 0},
  [19378] = {.lex_state = 7},
  [19379] = {.lex_state = 0},
  [19380] = {.lex_state = 0},
  [19381] = {.lex_state = 0},
  [19382] = {.lex_state = 0},
  [19383] = {.lex_state = 0},
  [19384] = {.lex_state = 0},
  [19385] = {.lex_state = 0},
  [19386] = {.lex_state = 0},
  [19387] = {.lex_state = 0},
  [19388] = {.lex_state = 0},
  [19389] = {.lex_state = 0},
  [19390] = {.lex_state = 0},
  [19391] = {.lex_state = 0},
  [19392] = {.lex_state = 0},
  [19393] = {.lex_state = 0},
  [19394] = {.lex_state = 0},
  [19395] = {.lex_state = 0},
  [19396] = {.lex_state = 0},
  [19397] = {.lex_state = 0},
  [19398] = {.lex_state = 0},
  [19399] = {.lex_state = 0},
  [19400] = {.lex_state = 0},
  [19401] = {.lex_state = 0},
  [19402] = {.lex_state = 0},
  [19403] = {.lex_state = 0},
  [19404] = {.lex_state = 0},
  [19405] = {.lex_state = 0},
  [19406] = {.lex_state = 0},
  [19407] = {.lex_state = 0},
  [19408] = {.lex_state = 0},
  [19409] = {.lex_state = 373},
  [19410] = {.lex_state = 0},
  [19411] = {.lex_state = 0},
  [19412] = {.lex_state = 0},
  [19413] = {.lex_state = 0},
  [19414] = {.lex_state = 0},
  [19415] = {.lex_state = 0},
  [19416] = {.lex_state = 0},
  [19417] = {.lex_state = 0},
  [19418] = {.lex_state = 0},
  [19419] = {.lex_state = 0},
  [19420] = {.lex_state = 0},
  [19421] = {.lex_state = 0},
  [19422] = {.lex_state = 0},
  [19423] = {.lex_state = 0},
  [19424] = {.lex_state = 0},
  [19425] = {.lex_state = 0},
  [19426] = {.lex_state = 0},
  [19427] = {.lex_state = 0},
  [19428] = {.lex_state = 0},
  [19429] = {.lex_state = 0},
  [19430] = {.lex_state = 0},
  [19431] = {.lex_state = 0},
  [19432] = {.lex_state = 0},
  [19433] = {.lex_state = 0},
  [19434] = {.lex_state = 0},
  [19435] = {.lex_state = 373},
  [19436] = {.lex_state = 0},
  [19437] = {.lex_state = 0},
  [19438] = {.lex_state = 0},
  [19439] = {.lex_state = 0},
  [19440] = {.lex_state = 0},
  [19441] = {.lex_state = 0},
  [19442] = {.lex_state = 0},
  [19443] = {.lex_state = 0},
  [19444] = {.lex_state = 371},
  [19445] = {.lex_state = 0},
  [19446] = {.lex_state = 0},
  [19447] = {.lex_state = 0},
  [19448] = {.lex_state = 371},
  [19449] = {.lex_state = 0},
  [19450] = {.lex_state = 0},
  [19451] = {.lex_state = 0},
  [19452] = {.lex_state = 0},
  [19453] = {.lex_state = 0},
  [19454] = {.lex_state = 0},
  [19455] = {.lex_state = 373},
  [19456] = {.lex_state = 0},
  [19457] = {.lex_state = 371},
  [19458] = {.lex_state = 7},
  [19459] = {.lex_state = 373},
  [19460] = {.lex_state = 0},
  [19461] = {.lex_state = 371},
  [19462] = {.lex_state = 0},
  [19463] = {.lex_state = 371},
  [19464] = {.lex_state = 0},
  [19465] = {.lex_state = 0},
  [19466] = {.lex_state = 0},
  [19467] = {.lex_state = 0},
  [19468] = {.lex_state = 0},
  [19469] = {.lex_state = 0},
  [19470] = {.lex_state = 0},
  [19471] = {.lex_state = 0},
  [19472] = {.lex_state = 0},
  [19473] = {.lex_state = 0},
  [19474] = {.lex_state = 0},
  [19475] = {.lex_state = 0},
  [19476] = {.lex_state = 371},
  [19477] = {.lex_state = 0},
  [19478] = {.lex_state = 371},
  [19479] = {.lex_state = 0},
  [19480] = {.lex_state = 371},
  [19481] = {.lex_state = 0},
  [19482] = {.lex_state = 371},
  [19483] = {.lex_state = 371},
  [19484] = {.lex_state = 0},
  [19485] = {.lex_state = 0},
  [19486] = {.lex_state = 371},
  [19487] = {.lex_state = 0},
  [19488] = {.lex_state = 0},
  [19489] = {.lex_state = 371},
  [19490] = {.lex_state = 371},
  [19491] = {.lex_state = 371},
  [19492] = {.lex_state = 0},
  [19493] = {.lex_state = 0},
  [19494] = {.lex_state = 0},
  [19495] = {.lex_state = 0},
  [19496] = {.lex_state = 0},
  [19497] = {.lex_state = 0},
  [19498] = {.lex_state = 0},
  [19499] = {.lex_state = 0},
  [19500] = {.lex_state = 0},
  [19501] = {.lex_state = 0},
  [19502] = {.lex_state = 0},
  [19503] = {.lex_state = 0},
  [19504] = {.lex_state = 371},
  [19505] = {.lex_state = 7},
  [19506] = {.lex_state = 0},
  [19507] = {.lex_state = 7},
  [19508] = {.lex_state = 371},
  [19509] = {.lex_state = 0},
  [19510] = {.lex_state = 7},
  [19511] = {.lex_state = 7},
  [19512] = {.lex_state = 0},
  [19513] = {.lex_state = 0},
  [19514] = {.lex_state = 7},
  [19515] = {.lex_state = 0},
  [19516] = {.lex_state = 373},
  [19517] = {.lex_state = 0},
  [19518] = {.lex_state = 0},
  [19519] = {.lex_state = 0},
  [19520] = {.lex_state = 0},
  [19521] = {.lex_state = 371},
  [19522] = {.lex_state = 7},
  [19523] = {.lex_state = 0},
  [19524] = {.lex_state = 371},
  [19525] = {.lex_state = 0},
  [19526] = {.lex_state = 0},
  [19527] = {.lex_state = 0},
  [19528] = {.lex_state = 0},
  [19529] = {.lex_state = 0},
  [19530] = {.lex_state = 0},
  [19531] = {.lex_state = 371},
  [19532] = {.lex_state = 0},
  [19533] = {.lex_state = 0},
  [19534] = {.lex_state = 0},
  [19535] = {.lex_state = 0},
  [19536] = {.lex_state = 0},
  [19537] = {.lex_state = 0},
  [19538] = {.lex_state = 0},
  [19539] = {.lex_state = 0},
  [19540] = {.lex_state = 0},
  [19541] = {.lex_state = 0},
  [19542] = {.lex_state = 0},
  [19543] = {.lex_state = 0},
  [19544] = {.lex_state = 0},
  [19545] = {.lex_state = 0},
  [19546] = {.lex_state = 0},
  [19547] = {.lex_state = 0},
  [19548] = {.lex_state = 0},
  [19549] = {.lex_state = 0},
  [19550] = {.lex_state = 0},
  [19551] = {.lex_state = 0},
  [19552] = {.lex_state = 0},
  [19553] = {.lex_state = 7},
  [19554] = {.lex_state = 0},
  [19555] = {.lex_state = 0},
  [19556] = {.lex_state = 0},
  [19557] = {.lex_state = 373},
  [19558] = {.lex_state = 0},
  [19559] = {.lex_state = 0},
  [19560] = {.lex_state = 0},
  [19561] = {.lex_state = 0},
  [19562] = {.lex_state = 0},
  [19563] = {.lex_state = 0},
  [19564] = {.lex_state = 7},
  [19565] = {.lex_state = 0},
  [19566] = {.lex_state = 0},
  [19567] = {.lex_state = 371},
  [19568] = {.lex_state = 0},
  [19569] = {.lex_state = 371},
  [19570] = {.lex_state = 0},
  [19571] = {.lex_state = 373},
  [19572] = {.lex_state = 371},
  [19573] = {.lex_state = 0},
  [19574] = {.lex_state = 7},
  [19575] = {.lex_state = 373},
  [19576] = {.lex_state = 7},
  [19577] = {.lex_state = 7},
  [19578] = {.lex_state = 0},
  [19579] = {.lex_state = 0},
  [19580] = {.lex_state = 0},
  [19581] = {.lex_state = 0},
  [19582] = {.lex_state = 0},
  [19583] = {.lex_state = 371},
  [19584] = {.lex_state = 0},
  [19585] = {.lex_state = 0},
  [19586] = {.lex_state = 0},
  [19587] = {.lex_state = 0},
  [19588] = {.lex_state = 0},
  [19589] = {.lex_state = 0},
  [19590] = {.lex_state = 0},
  [19591] = {.lex_state = 0},
  [19592] = {.lex_state = 0},
  [19593] = {.lex_state = 0},
  [19594] = {.lex_state = 371},
  [19595] = {.lex_state = 7},
  [19596] = {.lex_state = 0},
  [19597] = {.lex_state = 0},
  [19598] = {.lex_state = 0},
  [19599] = {.lex_state = 0},
  [19600] = {.lex_state = 0},
  [19601] = {.lex_state = 0},
  [19602] = {.lex_state = 0},
  [19603] = {.lex_state = 0},
  [19604] = {.lex_state = 0},
  [19605] = {.lex_state = 371},
  [19606] = {.lex_state = 371},
  [19607] = {.lex_state = 0},
  [19608] = {.lex_state = 0},
  [19609] = {.lex_state = 0},
  [19610] = {.lex_state = 0},
  [19611] = {.lex_state = 0},
  [19612] = {.lex_state = 371},
  [19613] = {.lex_state = 0},
  [19614] = {.lex_state = 0},
  [19615] = {.lex_state = 0},
  [19616] = {.lex_state = 0},
  [19617] = {.lex_state = 0},
  [19618] = {.lex_state = 0},
  [19619] = {.lex_state = 371},
  [19620] = {.lex_state = 0},
  [19621] = {.lex_state = 0},
  [19622] = {.lex_state = 0},
  [19623] = {.lex_state = 0},
  [19624] = {.lex_state = 0},
  [19625] = {.lex_state = 371},
  [19626] = {.lex_state = 0},
  [19627] = {.lex_state = 0},
  [19628] = {.lex_state = 371},
  [19629] = {.lex_state = 0},
  [19630] = {.lex_state = 371},
  [19631] = {.lex_state = 0},
  [19632] = {.lex_state = 0},
  [19633] = {.lex_state = 0},
  [19634] = {.lex_state = 0},
  [19635] = {.lex_state = 0},
  [19636] = {.lex_state = 3},
  [19637] = {.lex_state = 371},
  [19638] = {.lex_state = 0},
  [19639] = {.lex_state = 0},
  [19640] = {.lex_state = 0},
  [19641] = {.lex_state = 0},
  [19642] = {.lex_state = 0},
  [19643] = {.lex_state = 0},
  [19644] = {.lex_state = 0},
  [19645] = {.lex_state = 0},
  [19646] = {.lex_state = 0},
  [19647] = {.lex_state = 0},
  [19648] = {.lex_state = 0},
  [19649] = {.lex_state = 371},
  [19650] = {.lex_state = 0},
  [19651] = {.lex_state = 0},
  [19652] = {.lex_state = 0},
  [19653] = {.lex_state = 371},
  [19654] = {.lex_state = 0},
  [19655] = {.lex_state = 0},
  [19656] = {.lex_state = 0},
  [19657] = {.lex_state = 7},
  [19658] = {.lex_state = 0},
  [19659] = {.lex_state = 0},
  [19660] = {.lex_state = 0},
  [19661] = {.lex_state = 0},
  [19662] = {.lex_state = 0},
  [19663] = {.lex_state = 7},
  [19664] = {.lex_state = 0},
  [19665] = {.lex_state = 0},
  [19666] = {.lex_state = 0},
  [19667] = {.lex_state = 0},
  [19668] = {.lex_state = 0},
  [19669] = {.lex_state = 0},
  [19670] = {.lex_state = 0},
  [19671] = {.lex_state = 0},
  [19672] = {.lex_state = 0},
  [19673] = {.lex_state = 0},
  [19674] = {.lex_state = 0},
  [19675] = {.lex_state = 0},
  [19676] = {.lex_state = 0},
  [19677] = {.lex_state = 0},
  [19678] = {.lex_state = 0},
  [19679] = {.lex_state = 0},
  [19680] = {.lex_state = 0},
  [19681] = {.lex_state = 0},
  [19682] = {.lex_state = 0},
  [19683] = {.lex_state = 0},
  [19684] = {.lex_state = 0},
  [19685] = {.lex_state = 0},
  [19686] = {.lex_state = 0},
  [19687] = {.lex_state = 0},
  [19688] = {.lex_state = 0},
  [19689] = {.lex_state = 0},
  [19690] = {.lex_state = 0},
  [19691] = {.lex_state = 0},
  [19692] = {.lex_state = 0},
  [19693] = {.lex_state = 0},
  [19694] = {.lex_state = 371},
  [19695] = {.lex_state = 0},
  [19696] = {.lex_state = 0},
  [19697] = {.lex_state = 0},
  [19698] = {.lex_state = 0},
  [19699] = {.lex_state = 0},
  [19700] = {.lex_state = 0},
  [19701] = {.lex_state = 0},
  [19702] = {.lex_state = 373},
  [19703] = {.lex_state = 0},
  [19704] = {.lex_state = 0},
  [19705] = {.lex_state = 0},
  [19706] = {.lex_state = 0},
  [19707] = {.lex_state = 0},
  [19708] = {.lex_state = 0},
  [19709] = {.lex_state = 0},
  [19710] = {.lex_state = 0},
  [19711] = {.lex_state = 0},
  [19712] = {.lex_state = 0},
  [19713] = {.lex_state = 0},
  [19714] = {.lex_state = 0},
  [19715] = {.lex_state = 0},
  [19716] = {.lex_state = 371},
  [19717] = {.lex_state = 0},
  [19718] = {.lex_state = 0},
  [19719] = {.lex_state = 0},
  [19720] = {.lex_state = 7},
  [19721] = {.lex_state = 0},
  [19722] = {.lex_state = 7},
  [19723] = {.lex_state = 0},
  [19724] = {.lex_state = 0},
  [19725] = {.lex_state = 7},
  [19726] = {.lex_state = 0},
  [19727] = {.lex_state = 0},
  [19728] = {.lex_state = 0},
  [19729] = {.lex_state = 7},
  [19730] = {.lex_state = 0},
  [19731] = {.lex_state = 0},
  [19732] = {.lex_state = 0},
  [19733] = {.lex_state = 0},
  [19734] = {.lex_state = 0},
  [19735] = {.lex_state = 63},
  [19736] = {.lex_state = 0},
  [19737] = {.lex_state = 0},
  [19738] = {.lex_state = 0},
  [19739] = {.lex_state = 0},
  [19740] = {.lex_state = 0},
  [19741] = {.lex_state = 0},
  [19742] = {.lex_state = 0},
  [19743] = {.lex_state = 0},
  [19744] = {.lex_state = 0},
  [19745] = {.lex_state = 0},
  [19746] = {.lex_state = 371},
  [19747] = {.lex_state = 0},
  [19748] = {.lex_state = 7},
  [19749] = {.lex_state = 2},
  [19750] = {.lex_state = 7},
  [19751] = {.lex_state = 0},
  [19752] = {.lex_state = 0},
  [19753] = {.lex_state = 0},
  [19754] = {.lex_state = 0},
  [19755] = {.lex_state = 0},
  [19756] = {.lex_state = 371},
  [19757] = {.lex_state = 371},
  [19758] = {.lex_state = 0},
  [19759] = {.lex_state = 0},
  [19760] = {.lex_state = 371},
  [19761] = {.lex_state = 0},
  [19762] = {.lex_state = 0},
  [19763] = {.lex_state = 7},
  [19764] = {.lex_state = 0},
  [19765] = {.lex_state = 0},
  [19766] = {.lex_state = 0},
  [19767] = {.lex_state = 0},
  [19768] = {.lex_state = 0},
  [19769] = {.lex_state = 371},
  [19770] = {.lex_state = 7},
  [19771] = {.lex_state = 2},
  [19772] = {.lex_state = 2},
  [19773] = {.lex_state = 371},
  [19774] = {.lex_state = 0},
  [19775] = {.lex_state = 0},
  [19776] = {.lex_state = 0},
  [19777] = {.lex_state = 0},
  [19778] = {.lex_state = 0},
  [19779] = {.lex_state = 0},
  [19780] = {.lex_state = 0},
  [19781] = {.lex_state = 0},
  [19782] = {.lex_state = 0},
  [19783] = {.lex_state = 0},
  [19784] = {.lex_state = 0},
  [19785] = {.lex_state = 0},
  [19786] = {.lex_state = 0},
  [19787] = {.lex_state = 0},
  [19788] = {.lex_state = 0},
  [19789] = {.lex_state = 0},
  [19790] = {.lex_state = 0},
  [19791] = {.lex_state = 0},
  [19792] = {.lex_state = 0},
  [19793] = {.lex_state = 0},
  [19794] = {.lex_state = 373},
  [19795] = {.lex_state = 0},
  [19796] = {.lex_state = 0},
  [19797] = {.lex_state = 0},
  [19798] = {.lex_state = 7},
  [19799] = {.lex_state = 7},
  [19800] = {.lex_state = 7},
  [19801] = {.lex_state = 0},
  [19802] = {.lex_state = 7},
  [19803] = {.lex_state = 7},
  [19804] = {.lex_state = 0},
  [19805] = {.lex_state = 371},
  [19806] = {.lex_state = 0},
  [19807] = {.lex_state = 373},
  [19808] = {.lex_state = 0},
  [19809] = {.lex_state = 0},
  [19810] = {.lex_state = 0},
  [19811] = {.lex_state = 0},
  [19812] = {.lex_state = 2},
  [19813] = {.lex_state = 0},
  [19814] = {.lex_state = 7},
  [19815] = {.lex_state = 7},
  [19816] = {.lex_state = 7},
  [19817] = {.lex_state = 0},
  [19818] = {.lex_state = 7},
  [19819] = {.lex_state = 682},
  [19820] = {.lex_state = 0},
  [19821] = {.lex_state = 371},
  [19822] = {.lex_state = 0},
  [19823] = {.lex_state = 0},
  [19824] = {.lex_state = 0},
  [19825] = {.lex_state = 0},
  [19826] = {.lex_state = 7},
  [19827] = {.lex_state = 7},
  [19828] = {.lex_state = 7},
  [19829] = {.lex_state = 0},
  [19830] = {.lex_state = 7},
  [19831] = {.lex_state = 0},
  [19832] = {.lex_state = 371},
  [19833] = {.lex_state = 0},
  [19834] = {.lex_state = 0},
  [19835] = {.lex_state = 0},
  [19836] = {.lex_state = 7},
  [19837] = {.lex_state = 7},
  [19838] = {.lex_state = 7},
  [19839] = {.lex_state = 0},
  [19840] = {.lex_state = 7},
  [19841] = {.lex_state = 0},
  [19842] = {.lex_state = 371},
  [19843] = {.lex_state = 0},
  [19844] = {.lex_state = 0},
  [19845] = {.lex_state = 0},
  [19846] = {.lex_state = 7},
  [19847] = {.lex_state = 7},
  [19848] = {.lex_state = 7},
  [19849] = {.lex_state = 0},
  [19850] = {.lex_state = 7},
  [19851] = {.lex_state = 7},
  [19852] = {.lex_state = 371},
  [19853] = {.lex_state = 0},
  [19854] = {.lex_state = 0},
  [19855] = {.lex_state = 0},
  [19856] = {.lex_state = 7},
  [19857] = {.lex_state = 7},
  [19858] = {.lex_state = 7},
  [19859] = {.lex_state = 0},
  [19860] = {.lex_state = 7},
  [19861] = {.lex_state = 7},
  [19862] = {.lex_state = 371},
  [19863] = {.lex_state = 0},
  [19864] = {.lex_state = 0},
  [19865] = {.lex_state = 0},
  [19866] = {.lex_state = 7},
  [19867] = {.lex_state = 7},
  [19868] = {.lex_state = 7},
  [19869] = {.lex_state = 0},
  [19870] = {.lex_state = 7},
  [19871] = {.lex_state = 7},
  [19872] = {.lex_state = 371},
  [19873] = {.lex_state = 0},
  [19874] = {.lex_state = 0},
  [19875] = {.lex_state = 0},
  [19876] = {.lex_state = 7},
  [19877] = {.lex_state = 7},
  [19878] = {.lex_state = 7},
  [19879] = {.lex_state = 0},
  [19880] = {.lex_state = 7},
  [19881] = {.lex_state = 373},
  [19882] = {.lex_state = 371},
  [19883] = {.lex_state = 0},
  [19884] = {.lex_state = 0},
  [19885] = {.lex_state = 0},
  [19886] = {.lex_state = 0},
  [19887] = {.lex_state = 0},
  [19888] = {.lex_state = 0},
  [19889] = {.lex_state = 0},
  [19890] = {.lex_state = 0},
  [19891] = {.lex_state = 0},
  [19892] = {.lex_state = 682},
  [19893] = {.lex_state = 7},
  [19894] = {.lex_state = 0},
  [19895] = {.lex_state = 0},
  [19896] = {.lex_state = 373},
  [19897] = {.lex_state = 371},
  [19898] = {.lex_state = 371},
  [19899] = {.lex_state = 371},
  [19900] = {.lex_state = 0},
  [19901] = {.lex_state = 373},
  [19902] = {.lex_state = 0},
  [19903] = {.lex_state = 0},
  [19904] = {.lex_state = 0},
  [19905] = {.lex_state = 371},
  [19906] = {.lex_state = 7},
  [19907] = {.lex_state = 0},
  [19908] = {.lex_state = 7},
  [19909] = {.lex_state = 0},
  [19910] = {.lex_state = 373},
  [19911] = {.lex_state = 0},
  [19912] = {.lex_state = 0},
  [19913] = {.lex_state = 0},
  [19914] = {.lex_state = 0},
  [19915] = {.lex_state = 7},
  [19916] = {.lex_state = 0},
  [19917] = {.lex_state = 0},
  [19918] = {.lex_state = 371},
  [19919] = {.lex_state = 0},
  [19920] = {.lex_state = 0},
  [19921] = {.lex_state = 7},
  [19922] = {.lex_state = 0},
  [19923] = {.lex_state = 7},
  [19924] = {.lex_state = 7},
  [19925] = {.lex_state = 0},
  [19926] = {.lex_state = 0},
  [19927] = {.lex_state = 7},
  [19928] = {.lex_state = 0},
  [19929] = {.lex_state = 0},
  [19930] = {.lex_state = 0},
  [19931] = {.lex_state = 0},
  [19932] = {.lex_state = 0},
  [19933] = {.lex_state = 0},
  [19934] = {.lex_state = 0},
  [19935] = {.lex_state = 0},
  [19936] = {.lex_state = 0},
  [19937] = {.lex_state = 0},
  [19938] = {.lex_state = 0},
  [19939] = {.lex_state = 0},
  [19940] = {.lex_state = 373},
  [19941] = {.lex_state = 0},
  [19942] = {.lex_state = 4},
  [19943] = {.lex_state = 0},
  [19944] = {.lex_state = 7},
  [19945] = {.lex_state = 0},
  [19946] = {.lex_state = 0},
  [19947] = {.lex_state = 0},
  [19948] = {.lex_state = 371},
  [19949] = {.lex_state = 371},
  [19950] = {.lex_state = 371},
  [19951] = {.lex_state = 0},
  [19952] = {.lex_state = 373},
  [19953] = {.lex_state = 0},
  [19954] = {.lex_state = 0},
  [19955] = {.lex_state = 0},
  [19956] = {.lex_state = 0},
  [19957] = {.lex_state = 7},
  [19958] = {.lex_state = 373},
  [19959] = {.lex_state = 7},
  [19960] = {.lex_state = 0},
  [19961] = {.lex_state = 373},
  [19962] = {.lex_state = 0},
  [19963] = {.lex_state = 0},
  [19964] = {.lex_state = 0},
  [19965] = {.lex_state = 0},
  [19966] = {.lex_state = 7},
  [19967] = {.lex_state = 0},
  [19968] = {.lex_state = 0},
  [19969] = {.lex_state = 0},
  [19970] = {.lex_state = 0},
  [19971] = {.lex_state = 0},
  [19972] = {.lex_state = 7},
  [19973] = {.lex_state = 0},
  [19974] = {.lex_state = 7},
  [19975] = {.lex_state = 373},
  [19976] = {.lex_state = 0},
  [19977] = {.lex_state = 7},
  [19978] = {.lex_state = 0},
  [19979] = {.lex_state = 0},
  [19980] = {.lex_state = 0},
  [19981] = {.lex_state = 373},
  [19982] = {.lex_state = 0},
  [19983] = {.lex_state = 0},
  [19984] = {.lex_state = 0},
  [19985] = {.lex_state = 0},
  [19986] = {.lex_state = 0},
  [19987] = {.lex_state = 0},
  [19988] = {.lex_state = 0},
  [19989] = {.lex_state = 0},
  [19990] = {.lex_state = 682},
  [19991] = {.lex_state = 0},
  [19992] = {.lex_state = 0},
  [19993] = {.lex_state = 0},
  [19994] = {.lex_state = 7},
  [19995] = {.lex_state = 0},
  [19996] = {.lex_state = 0},
  [19997] = {.lex_state = 0},
  [19998] = {.lex_state = 371},
  [19999] = {.lex_state = 371},
  [20000] = {.lex_state = 0},
  [20001] = {.lex_state = 373},
  [20002] = {.lex_state = 0},
  [20003] = {.lex_state = 0},
  [20004] = {.lex_state = 7},
  [20005] = {.lex_state = 0},
  [20006] = {.lex_state = 7},
  [20007] = {.lex_state = 0},
  [20008] = {.lex_state = 7},
  [20009] = {.lex_state = 0},
  [20010] = {.lex_state = 373},
  [20011] = {.lex_state = 373},
  [20012] = {.lex_state = 0},
  [20013] = {.lex_state = 0},
  [20014] = {.lex_state = 0},
  [20015] = {.lex_state = 0},
  [20016] = {.lex_state = 0},
  [20017] = {.lex_state = 0},
  [20018] = {.lex_state = 0},
  [20019] = {.lex_state = 0},
  [20020] = {.lex_state = 7},
  [20021] = {.lex_state = 0},
  [20022] = {.lex_state = 7},
  [20023] = {.lex_state = 0},
  [20024] = {.lex_state = 0},
  [20025] = {.lex_state = 7},
  [20026] = {.lex_state = 0},
  [20027] = {.lex_state = 0},
  [20028] = {.lex_state = 0},
  [20029] = {.lex_state = 0},
  [20030] = {.lex_state = 0},
  [20031] = {.lex_state = 0},
  [20032] = {.lex_state = 0},
  [20033] = {.lex_state = 0},
  [20034] = {.lex_state = 0},
  [20035] = {.lex_state = 0},
  [20036] = {.lex_state = 7},
  [20037] = {.lex_state = 7},
  [20038] = {.lex_state = 371},
  [20039] = {.lex_state = 7},
  [20040] = {.lex_state = 0},
  [20041] = {.lex_state = 371},
  [20042] = {.lex_state = 0},
  [20043] = {.lex_state = 0},
  [20044] = {.lex_state = 0},
  [20045] = {.lex_state = 7},
  [20046] = {.lex_state = 7},
  [20047] = {.lex_state = 0},
  [20048] = {.lex_state = 0},
  [20049] = {.lex_state = 0},
  [20050] = {.lex_state = 0},
  [20051] = {.lex_state = 0},
  [20052] = {.lex_state = 0},
  [20053] = {.lex_state = 0},
  [20054] = {.lex_state = 7},
  [20055] = {.lex_state = 0},
  [20056] = {.lex_state = 7},
  [20057] = {.lex_state = 0},
  [20058] = {.lex_state = 0},
  [20059] = {.lex_state = 7},
  [20060] = {.lex_state = 0},
  [20061] = {.lex_state = 0},
  [20062] = {.lex_state = 0},
  [20063] = {.lex_state = 0},
  [20064] = {.lex_state = 0},
  [20065] = {.lex_state = 0},
  [20066] = {.lex_state = 0},
  [20067] = {.lex_state = 7},
  [20068] = {.lex_state = 0},
  [20069] = {.lex_state = 0},
  [20070] = {.lex_state = 0},
  [20071] = {.lex_state = 0},
  [20072] = {.lex_state = 0},
  [20073] = {.lex_state = 7},
  [20074] = {.lex_state = 7},
  [20075] = {.lex_state = 0},
  [20076] = {.lex_state = 0},
  [20077] = {.lex_state = 0},
  [20078] = {.lex_state = 0},
  [20079] = {.lex_state = 7},
  [20080] = {.lex_state = 7},
  [20081] = {.lex_state = 7},
  [20082] = {.lex_state = 0},
  [20083] = {.lex_state = 7},
  [20084] = {.lex_state = 0},
  [20085] = {.lex_state = 7},
  [20086] = {.lex_state = 0},
  [20087] = {.lex_state = 0},
  [20088] = {.lex_state = 0},
  [20089] = {.lex_state = 0},
  [20090] = {.lex_state = 7},
  [20091] = {.lex_state = 7},
  [20092] = {.lex_state = 0},
  [20093] = {.lex_state = 0},
  [20094] = {.lex_state = 0},
  [20095] = {.lex_state = 0},
  [20096] = {.lex_state = 7},
  [20097] = {.lex_state = 0},
  [20098] = {.lex_state = 0},
  [20099] = {.lex_state = 0},
  [20100] = {.lex_state = 371},
  [20101] = {.lex_state = 0},
  [20102] = {.lex_state = 0},
  [20103] = {.lex_state = 7},
  [20104] = {.lex_state = 0},
  [20105] = {.lex_state = 0},
  [20106] = {.lex_state = 0},
  [20107] = {.lex_state = 0},
  [20108] = {.lex_state = 7},
  [20109] = {.lex_state = 0},
  [20110] = {.lex_state = 0},
  [20111] = {.lex_state = 0},
  [20112] = {.lex_state = 0},
  [20113] = {.lex_state = 7},
  [20114] = {.lex_state = 0},
  [20115] = {.lex_state = 0},
  [20116] = {.lex_state = 0},
  [20117] = {.lex_state = 7},
  [20118] = {.lex_state = 7},
  [20119] = {.lex_state = 0},
  [20120] = {.lex_state = 0},
  [20121] = {.lex_state = 7},
  [20122] = {.lex_state = 0},
  [20123] = {.lex_state = 7},
  [20124] = {.lex_state = 371},
  [20125] = {.lex_state = 0},
  [20126] = {.lex_state = 371},
  [20127] = {.lex_state = 0},
  [20128] = {.lex_state = 7},
  [20129] = {.lex_state = 0},
  [20130] = {.lex_state = 0},
  [20131] = {.lex_state = 0},
  [20132] = {.lex_state = 0},
  [20133] = {.lex_state = 7},
  [20134] = {.lex_state = 0},
  [20135] = {.lex_state = 0},
  [20136] = {.lex_state = 371},
  [20137] = {.lex_state = 0},
  [20138] = {.lex_state = 0},
  [20139] = {.lex_state = 0},
  [20140] = {.lex_state = 0},
  [20141] = {.lex_state = 0},
  [20142] = {.lex_state = 0},
  [20143] = {.lex_state = 0},
  [20144] = {.lex_state = 0},
  [20145] = {.lex_state = 371},
  [20146] = {.lex_state = 0},
  [20147] = {.lex_state = 371},
  [20148] = {.lex_state = 371},
  [20149] = {.lex_state = 7},
  [20150] = {.lex_state = 7},
  [20151] = {.lex_state = 0},
  [20152] = {.lex_state = 0},
  [20153] = {.lex_state = 0},
  [20154] = {.lex_state = 0},
  [20155] = {.lex_state = 0},
  [20156] = {.lex_state = 0},
  [20157] = {.lex_state = 0},
  [20158] = {.lex_state = 0},
  [20159] = {.lex_state = 0},
  [20160] = {.lex_state = 0},
  [20161] = {.lex_state = 0},
  [20162] = {.lex_state = 7},
  [20163] = {.lex_state = 0},
  [20164] = {.lex_state = 7},
  [20165] = {.lex_state = 7},
  [20166] = {.lex_state = 7},
  [20167] = {.lex_state = 7},
  [20168] = {.lex_state = 0},
  [20169] = {.lex_state = 0},
  [20170] = {.lex_state = 0},
  [20171] = {.lex_state = 0},
  [20172] = {.lex_state = 0},
  [20173] = {.lex_state = 0},
  [20174] = {.lex_state = 0},
  [20175] = {.lex_state = 0},
  [20176] = {.lex_state = 0},
  [20177] = {.lex_state = 0},
  [20178] = {.lex_state = 0},
  [20179] = {.lex_state = 371},
  [20180] = {.lex_state = 7},
  [20181] = {.lex_state = 371},
  [20182] = {.lex_state = 0},
  [20183] = {.lex_state = 0},
  [20184] = {.lex_state = 0},
  [20185] = {.lex_state = 0},
  [20186] = {.lex_state = 0},
  [20187] = {.lex_state = 7},
  [20188] = {.lex_state = 0},
  [20189] = {.lex_state = 0},
  [20190] = {.lex_state = 0},
  [20191] = {.lex_state = 0},
  [20192] = {.lex_state = 7},
  [20193] = {.lex_state = 0},
  [20194] = {.lex_state = 0},
  [20195] = {.lex_state = 0},
  [20196] = {.lex_state = 7},
  [20197] = {.lex_state = 0},
  [20198] = {.lex_state = 0},
  [20199] = {.lex_state = 0},
  [20200] = {.lex_state = 0},
  [20201] = {.lex_state = 0},
  [20202] = {.lex_state = 0},
  [20203] = {.lex_state = 0},
  [20204] = {.lex_state = 0},
  [20205] = {.lex_state = 0},
  [20206] = {.lex_state = 0},
  [20207] = {.lex_state = 0},
  [20208] = {.lex_state = 7},
  [20209] = {.lex_state = 0},
  [20210] = {.lex_state = 0},
  [20211] = {.lex_state = 7},
  [20212] = {.lex_state = 0},
  [20213] = {.lex_state = 0},
  [20214] = {.lex_state = 0},
  [20215] = {.lex_state = 0},
  [20216] = {.lex_state = 0},
  [20217] = {.lex_state = 0},
  [20218] = {.lex_state = 0},
  [20219] = {.lex_state = 0},
  [20220] = {.lex_state = 0},
  [20221] = {.lex_state = 0},
  [20222] = {.lex_state = 0},
  [20223] = {.lex_state = 0},
  [20224] = {.lex_state = 0},
  [20225] = {.lex_state = 7},
  [20226] = {.lex_state = 0},
  [20227] = {.lex_state = 0},
  [20228] = {.lex_state = 371},
  [20229] = {.lex_state = 0},
  [20230] = {.lex_state = 0},
  [20231] = {.lex_state = 0},
  [20232] = {.lex_state = 0},
  [20233] = {.lex_state = 0},
  [20234] = {.lex_state = 0},
  [20235] = {.lex_state = 0},
  [20236] = {.lex_state = 0},
  [20237] = {.lex_state = 0},
  [20238] = {.lex_state = 0},
  [20239] = {.lex_state = 0},
  [20240] = {.lex_state = 0},
  [20241] = {.lex_state = 0},
  [20242] = {.lex_state = 0},
  [20243] = {.lex_state = 371},
  [20244] = {.lex_state = 0},
  [20245] = {.lex_state = 0},
  [20246] = {.lex_state = 0},
  [20247] = {.lex_state = 371},
  [20248] = {.lex_state = 0},
  [20249] = {.lex_state = 0},
  [20250] = {.lex_state = 371},
  [20251] = {.lex_state = 0},
  [20252] = {.lex_state = 7},
  [20253] = {.lex_state = 0},
  [20254] = {.lex_state = 0},
  [20255] = {.lex_state = 0},
  [20256] = {.lex_state = 0},
  [20257] = {.lex_state = 0},
  [20258] = {.lex_state = 0},
  [20259] = {.lex_state = 0},
  [20260] = {.lex_state = 0},
  [20261] = {.lex_state = 0},
  [20262] = {.lex_state = 0},
  [20263] = {.lex_state = 371},
  [20264] = {.lex_state = 0},
  [20265] = {.lex_state = 0},
  [20266] = {.lex_state = 0},
  [20267] = {.lex_state = 2},
  [20268] = {.lex_state = 0},
  [20269] = {.lex_state = 373},
  [20270] = {.lex_state = 0},
  [20271] = {.lex_state = 0},
  [20272] = {.lex_state = 0},
  [20273] = {.lex_state = 0},
  [20274] = {.lex_state = 0},
  [20275] = {.lex_state = 371},
  [20276] = {.lex_state = 0},
  [20277] = {.lex_state = 0},
  [20278] = {.lex_state = 0},
  [20279] = {.lex_state = 0},
  [20280] = {.lex_state = 371},
  [20281] = {.lex_state = 7},
  [20282] = {.lex_state = 0},
  [20283] = {.lex_state = 0},
  [20284] = {.lex_state = 0},
  [20285] = {.lex_state = 371},
  [20286] = {.lex_state = 7},
  [20287] = {.lex_state = 0},
  [20288] = {.lex_state = 0},
  [20289] = {.lex_state = 7},
  [20290] = {.lex_state = 7},
  [20291] = {.lex_state = 0},
  [20292] = {.lex_state = 371},
  [20293] = {.lex_state = 0},
  [20294] = {.lex_state = 371},
  [20295] = {.lex_state = 7},
  [20296] = {.lex_state = 0},
  [20297] = {.lex_state = 371},
  [20298] = {.lex_state = 7},
  [20299] = {.lex_state = 7},
  [20300] = {.lex_state = 371},
  [20301] = {.lex_state = 7},
  [20302] = {.lex_state = 0},
  [20303] = {.lex_state = 373},
  [20304] = {.lex_state = 7},
  [20305] = {.lex_state = 7},
  [20306] = {.lex_state = 0},
  [20307] = {.lex_state = 0},
  [20308] = {.lex_state = 371},
  [20309] = {.lex_state = 7},
  [20310] = {.lex_state = 0},
  [20311] = {.lex_state = 0},
  [20312] = {.lex_state = 7},
  [20313] = {.lex_state = 7},
  [20314] = {.lex_state = 371},
  [20315] = {.lex_state = 7},
  [20316] = {.lex_state = 0},
  [20317] = {.lex_state = 0},
  [20318] = {.lex_state = 7},
  [20319] = {.lex_state = 7},
  [20320] = {.lex_state = 371},
  [20321] = {.lex_state = 0},
  [20322] = {.lex_state = 371},
  [20323] = {.lex_state = 7},
  [20324] = {.lex_state = 0},
  [20325] = {.lex_state = 371},
  [20326] = {.lex_state = 7},
  [20327] = {.lex_state = 7},
  [20328] = {.lex_state = 371},
  [20329] = {.lex_state = 7},
  [20330] = {.lex_state = 7},
  [20331] = {.lex_state = 0},
  [20332] = {.lex_state = 0},
  [20333] = {.lex_state = 371},
  [20334] = {.lex_state = 7},
  [20335] = {.lex_state = 0},
  [20336] = {.lex_state = 0},
  [20337] = {.lex_state = 7},
  [20338] = {.lex_state = 7},
  [20339] = {.lex_state = 371},
  [20340] = {.lex_state = 7},
  [20341] = {.lex_state = 7},
  [20342] = {.lex_state = 0},
  [20343] = {.lex_state = 0},
  [20344] = {.lex_state = 371},
  [20345] = {.lex_state = 7},
  [20346] = {.lex_state = 371},
  [20347] = {.lex_state = 7},
  [20348] = {.lex_state = 7},
  [20349] = {.lex_state = 371},
  [20350] = {.lex_state = 7},
  [20351] = {.lex_state = 7},
  [20352] = {.lex_state = 0},
  [20353] = {.lex_state = 371},
  [20354] = {.lex_state = 7},
  [20355] = {.lex_state = 7},
  [20356] = {.lex_state = 7},
  [20357] = {.lex_state = 7},
  [20358] = {.lex_state = 7},
  [20359] = {.lex_state = 7},
  [20360] = {.lex_state = 7},
  [20361] = {.lex_state = 7},
  [20362] = {.lex_state = 7},
  [20363] = {.lex_state = 7},
  [20364] = {.lex_state = 7},
  [20365] = {.lex_state = 7},
  [20366] = {.lex_state = 7},
  [20367] = {.lex_state = 7},
  [20368] = {.lex_state = 7},
  [20369] = {.lex_state = 7},
  [20370] = {.lex_state = 7},
  [20371] = {.lex_state = 7},
  [20372] = {.lex_state = 7},
  [20373] = {.lex_state = 7},
  [20374] = {.lex_state = 7},
  [20375] = {.lex_state = 7},
  [20376] = {.lex_state = 7},
  [20377] = {.lex_state = 7},
  [20378] = {.lex_state = 0},
  [20379] = {.lex_state = 0},
  [20380] = {.lex_state = 0},
  [20381] = {.lex_state = 0},
  [20382] = {.lex_state = 0},
  [20383] = {.lex_state = 0},
  [20384] = {.lex_state = 0},
  [20385] = {.lex_state = 0},
  [20386] = {.lex_state = 0},
  [20387] = {.lex_state = 0},
  [20388] = {.lex_state = 0},
  [20389] = {.lex_state = 0},
  [20390] = {.lex_state = 0},
  [20391] = {.lex_state = 0},
  [20392] = {.lex_state = 7},
  [20393] = {.lex_state = 0},
  [20394] = {.lex_state = 0},
  [20395] = {.lex_state = 0},
  [20396] = {.lex_state = 0},
  [20397] = {.lex_state = 0},
  [20398] = {.lex_state = 0},
  [20399] = {.lex_state = 0},
  [20400] = {.lex_state = 0},
  [20401] = {.lex_state = 0},
  [20402] = {.lex_state = 371},
  [20403] = {.lex_state = 7},
  [20404] = {.lex_state = 371},
  [20405] = {.lex_state = 371},
  [20406] = {.lex_state = 0},
  [20407] = {.lex_state = 0},
  [20408] = {.lex_state = 0},
  [20409] = {.lex_state = 0},
  [20410] = {.lex_state = 371},
  [20411] = {.lex_state = 0},
  [20412] = {.lex_state = 0},
  [20413] = {.lex_state = 0},
  [20414] = {.lex_state = 0},
  [20415] = {.lex_state = 0},
  [20416] = {.lex_state = 0},
  [20417] = {.lex_state = 0},
  [20418] = {.lex_state = 0},
  [20419] = {.lex_state = 0},
  [20420] = {.lex_state = 0},
  [20421] = {.lex_state = 0},
  [20422] = {.lex_state = 371},
  [20423] = {.lex_state = 371},
  [20424] = {.lex_state = 0},
  [20425] = {.lex_state = 0},
  [20426] = {.lex_state = 0},
  [20427] = {.lex_state = 0},
  [20428] = {.lex_state = 371},
  [20429] = {.lex_state = 371},
  [20430] = {.lex_state = 0},
  [20431] = {.lex_state = 0},
  [20432] = {.lex_state = 0},
  [20433] = {.lex_state = 0},
  [20434] = {.lex_state = 371},
  [20435] = {.lex_state = 371},
  [20436] = {.lex_state = 0},
  [20437] = {.lex_state = 0},
  [20438] = {.lex_state = 0},
  [20439] = {.lex_state = 0},
  [20440] = {.lex_state = 371},
  [20441] = {.lex_state = 371},
  [20442] = {.lex_state = 0},
  [20443] = {.lex_state = 0},
  [20444] = {.lex_state = 0},
  [20445] = {.lex_state = 371},
  [20446] = {.lex_state = 371},
  [20447] = {.lex_state = 373},
  [20448] = {.lex_state = 371},
  [20449] = {.lex_state = 371},
  [20450] = {.lex_state = 371},
  [20451] = {.lex_state = 371},
  [20452] = {.lex_state = 371},
  [20453] = {.lex_state = 371},
  [20454] = {.lex_state = 371},
  [20455] = {.lex_state = 371},
  [20456] = {.lex_state = 371},
  [20457] = {.lex_state = 371},
  [20458] = {.lex_state = 371},
  [20459] = {.lex_state = 371},
  [20460] = {.lex_state = 371},
  [20461] = {.lex_state = 371},
  [20462] = {.lex_state = 371},
  [20463] = {.lex_state = 371},
  [20464] = {.lex_state = 371},
  [20465] = {.lex_state = 7},
  [20466] = {.lex_state = 0},
  [20467] = {.lex_state = 371},
  [20468] = {.lex_state = 7},
  [20469] = {.lex_state = 7},
  [20470] = {.lex_state = 7},
  [20471] = {.lex_state = 0},
  [20472] = {.lex_state = 0},
  [20473] = {.lex_state = 7},
  [20474] = {.lex_state = 0},
  [20475] = {.lex_state = 371},
  [20476] = {.lex_state = 7},
  [20477] = {.lex_state = 0},
  [20478] = {.lex_state = 373},
  [20479] = {.lex_state = 371},
  [20480] = {.lex_state = 0},
  [20481] = {.lex_state = 0},
  [20482] = {.lex_state = 371},
  [20483] = {.lex_state = 0},
  [20484] = {.lex_state = 0},
  [20485] = {.lex_state = 371},
  [20486] = {.lex_state = 7},
  [20487] = {.lex_state = 0},
  [20488] = {.lex_state = 0},
  [20489] = {.lex_state = 371},
  [20490] = {.lex_state = 7},
  [20491] = {.lex_state = 0},
  [20492] = {.lex_state = 371},
  [20493] = {.lex_state = 0},
  [20494] = {.lex_state = 0},
  [20495] = {.lex_state = 371},
  [20496] = {.lex_state = 0},
  [20497] = {.lex_state = 0},
  [20498] = {.lex_state = 371},
  [20499] = {.lex_state = 7},
  [20500] = {.lex_state = 0},
  [20501] = {.lex_state = 371},
  [20502] = {.lex_state = 0},
  [20503] = {.lex_state = 0},
  [20504] = {.lex_state = 0},
  [20505] = {.lex_state = 0},
  [20506] = {.lex_state = 0},
  [20507] = {.lex_state = 0},
  [20508] = {.lex_state = 0},
  [20509] = {.lex_state = 0},
  [20510] = {.lex_state = 7},
  [20511] = {.lex_state = 7},
  [20512] = {.lex_state = 371},
  [20513] = {.lex_state = 0},
  [20514] = {.lex_state = 0},
  [20515] = {.lex_state = 0},
  [20516] = {.lex_state = 0},
  [20517] = {.lex_state = 0},
  [20518] = {.lex_state = 7},
  [20519] = {.lex_state = 7},
  [20520] = {.lex_state = 7},
  [20521] = {.lex_state = 7},
  [20522] = {.lex_state = 7},
  [20523] = {.lex_state = 7},
  [20524] = {.lex_state = 0},
  [20525] = {.lex_state = 7},
  [20526] = {.lex_state = 7},
  [20527] = {.lex_state = 7},
  [20528] = {.lex_state = 7},
  [20529] = {.lex_state = 371},
  [20530] = {.lex_state = 371},
  [20531] = {.lex_state = 7},
  [20532] = {.lex_state = 0},
  [20533] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_simple_identifier] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [aux_sym_id_directive_token1] = ACTIONS(1),
    [aux_sym_id_directive_token2] = ACTIONS(1),
    [aux_sym_id_directive_token3] = ACTIONS(1),
    [aux_sym_id_directive_token4] = ACTIONS(1),
    [aux_sym_zero_directive_token1] = ACTIONS(1),
    [aux_sym_zero_directive_token2] = ACTIONS(1),
    [aux_sym_zero_directive_token3] = ACTIONS(1),
    [aux_sym_zero_directive_token4] = ACTIONS(1),
    [aux_sym_zero_directive_token5] = ACTIONS(1),
    [aux_sym_zero_directive_token6] = ACTIONS(1),
    [aux_sym_zero_directive_token7] = ACTIONS(1),
    [aux_sym_zero_directive_token8] = ACTIONS(1),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1),
    [anon_sym_wire] = ACTIONS(1),
    [anon_sym_tri] = ACTIONS(1),
    [anon_sym_tri0] = ACTIONS(1),
    [anon_sym_tri1] = ACTIONS(1),
    [anon_sym_wand] = ACTIONS(1),
    [anon_sym_triand] = ACTIONS(1),
    [anon_sym_wor] = ACTIONS(1),
    [anon_sym_trior] = ACTIONS(1),
    [anon_sym_trireg] = ACTIONS(1),
    [anon_sym_uwire] = ACTIONS(1),
    [anon_sym_none] = ACTIONS(1),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1),
    [anon_sym_pull0] = ACTIONS(1),
    [anon_sym_pull1] = ACTIONS(1),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1),
    [aux_sym_begin_keywords_token1] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_endmodule] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_extern] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_macromodule] = ACTIONS(1),
    [anon_sym_endinterface] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_endprogram] = ACTIONS(1),
    [anon_sym_program] = ACTIONS(1),
    [anon_sym_checker] = ACTIONS(1),
    [anon_sym_endchecker] = ACTIONS(1),
    [anon_sym_virtual] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
    [anon_sym_endclass] = ACTIONS(1),
    [anon_sym_pure] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_endpackage] = ACTIONS(1),
    [anon_sym_timeunit] = ACTIONS(1),
    [anon_sym_timeprecision] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_input] = ACTIONS(1),
    [anon_sym_output] = ACTIONS(1),
    [anon_sym_inout] = ACTIONS(1),
    [anon_sym_ref] = ACTIONS(1),
    [anon_sym_0] = ACTIONS(1),
    [anon_sym_1] = ACTIONS(1),
    [anon_sym_2] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_clocking] = ACTIONS(1),
    [anon_sym_disable] = ACTIONS(1),
    [anon_sym_iff] = ACTIONS(1),
    [anon_sym_defparam] = ACTIONS(1),
    [anon_sym_bind] = ACTIONS(1),
    [anon_sym_forkjoin] = ACTIONS(1),
    [anon_sym_rand] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_local] = ACTIONS(1),
    [anon_sym_randc] = ACTIONS(1),
    [anon_sym_super] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_constraint] = ACTIONS(1),
    [anon_sym_solve] = ACTIONS(1),
    [anon_sym_before] = ACTIONS(1),
    [anon_sym_soft] = ACTIONS(1),
    [anon_sym_u2013_GT] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_foreach] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_unique] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_localparam] = ACTIONS(1),
    [anon_sym_parameter] = ACTIONS(1),
    [anon_sym_specparam] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_genvar] = ACTIONS(1),
    [anon_sym_vectored] = ACTIONS(1),
    [anon_sym_scalared] = ACTIONS(1),
    [anon_sym_interconnect] = ACTIONS(1),
    [anon_sym_typedef] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_nettype] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_automatic] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_packed] = ACTIONS(1),
    [anon_sym_chandle] = ACTIONS(1),
    [anon_sym_event] = ACTIONS(1),
    [anon_sym_byte] = ACTIONS(1),
    [anon_sym_shortint] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_longint] = ACTIONS(1),
    [anon_sym_integer] = ACTIONS(1),
    [anon_sym_time] = ACTIONS(1),
    [anon_sym_bit] = ACTIONS(1),
    [anon_sym_logic] = ACTIONS(1),
    [anon_sym_reg] = ACTIONS(1),
    [anon_sym_shortreal] = ACTIONS(1),
    [anon_sym_real] = ACTIONS(1),
    [anon_sym_realtime] = ACTIONS(1),
    [anon_sym_supply0] = ACTIONS(1),
    [anon_sym_supply1] = ACTIONS(1),
    [anon_sym_signed] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_tagged] = ACTIONS(1),
    [anon_sym_highz1] = ACTIONS(1),
    [anon_sym_highz0] = ACTIONS(1),
    [anon_sym_strong0] = ACTIONS(1),
    [anon_sym_weak0] = ACTIONS(1),
    [anon_sym_strong1] = ACTIONS(1),
    [anon_sym_weak1] = ACTIONS(1),
    [anon_sym_small] = ACTIONS(1),
    [anon_sym_medium] = ACTIONS(1),
    [anon_sym_large] = ACTIONS(1),
    [anon_sym_1step] = ACTIONS(1),
    [anon_sym_PATHPULSE_DOLLAR_EQ] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_task] = ACTIONS(1),
    [anon_sym_context] = ACTIONS(1),
    [anon_sym_endtask] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_u2013] = ACTIONS(1),
    [anon_sym_u2013u2013] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_modport] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_property] = ACTIONS(1),
    [anon_sym_assume] = ACTIONS(1),
    [anon_sym_cover] = ACTIONS(1),
    [anon_sym_expect] = ACTIONS(1),
    [anon_sym_sequence] = ACTIONS(1),
    [anon_sym_restrict] = ACTIONS(1),
    [anon_sym_endproperty] = ACTIONS(1),
    [anon_sym_strong] = ACTIONS(1),
    [anon_sym_weak] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_PIPE_DASH_GT] = ACTIONS(1),
    [anon_sym_PIPE_EQ_GT] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_endcase] = ACTIONS(1),
    [anon_sym_POUND_DASH_POUND] = ACTIONS(1),
    [anon_sym_POUND_EQ_POUND] = ACTIONS(1),
    [anon_sym_nexttime] = ACTIONS(1),
    [anon_sym_s_nexttime] = ACTIONS(1),
    [anon_sym_always] = ACTIONS(1),
    [anon_sym_s_always] = ACTIONS(1),
    [anon_sym_s_eventually] = ACTIONS(1),
    [anon_sym_eventually] = ACTIONS(1),
    [anon_sym_until] = ACTIONS(1),
    [anon_sym_s_until] = ACTIONS(1),
    [anon_sym_until_with] = ACTIONS(1),
    [anon_sym_s_until_with] = ACTIONS(1),
    [anon_sym_implies] = ACTIONS(1),
    [anon_sym_accept_on] = ACTIONS(1),
    [anon_sym_reject_on] = ACTIONS(1),
    [anon_sym_sync_accept_on] = ACTIONS(1),
    [anon_sym_sync_reject_on] = ACTIONS(1),
    [anon_sym_endsequence] = ACTIONS(1),
    [anon_sym_untyped] = ACTIONS(1),
    [anon_sym_intersect] = ACTIONS(1),
    [anon_sym_first_match] = ACTIONS(1),
    [anon_sym_throughout] = ACTIONS(1),
    [anon_sym_within] = ACTIONS(1),
    [anon_sym_POUND_POUND] = ACTIONS(1),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(1),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACK_STAR] = ACTIONS(1),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACK_EQ] = ACTIONS(1),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(1),
    [anon_sym_dist] = ACTIONS(1),
    [anon_sym_covergroup] = ACTIONS(1),
    [anon_sym_endgroup] = ACTIONS(1),
    [anon_sym_option] = ACTIONS(1),
    [anon_sym_type_option] = ACTIONS(1),
    [anon_sym_sample] = ACTIONS(1),
    [anon_sym_AT_AT] = ACTIONS(1),
    [anon_sym_begin] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_coverpoint] = ACTIONS(1),
    [anon_sym_wildcard] = ACTIONS(1),
    [anon_sym_bins] = ACTIONS(1),
    [anon_sym_illegal_bins] = ACTIONS(1),
    [anon_sym_ignore_bins] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_LBRACKu2013_GT] = ACTIONS(1),
    [anon_sym_cross] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_matches] = ACTIONS(1),
    [anon_sym_binsof] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_pulldown] = ACTIONS(1),
    [anon_sym_pullup] = ACTIONS(1),
    [anon_sym_cmos] = ACTIONS(1),
    [anon_sym_rcmos] = ACTIONS(1),
    [anon_sym_bufif0] = ACTIONS(1),
    [anon_sym_bufif1] = ACTIONS(1),
    [anon_sym_notif0] = ACTIONS(1),
    [anon_sym_notif1] = ACTIONS(1),
    [anon_sym_nmos] = ACTIONS(1),
    [anon_sym_pmos] = ACTIONS(1),
    [anon_sym_rnmos] = ACTIONS(1),
    [anon_sym_rpmos] = ACTIONS(1),
    [anon_sym_nand] = ACTIONS(1),
    [anon_sym_nor] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_xnor] = ACTIONS(1),
    [anon_sym_buf] = ACTIONS(1),
    [anon_sym_tranif0] = ACTIONS(1),
    [anon_sym_tranif1] = ACTIONS(1),
    [anon_sym_rtranif1] = ACTIONS(1),
    [anon_sym_rtranif0] = ACTIONS(1),
    [anon_sym_tran] = ACTIONS(1),
    [anon_sym_rtran] = ACTIONS(1),
    [anon_sym_generate] = ACTIONS(1),
    [anon_sym_endgenerate] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_primitive] = ACTIONS(1),
    [anon_sym_endprimitive] = ACTIONS(1),
    [anon_sym_table] = ACTIONS(1),
    [anon_sym_initial] = ACTIONS(1),
    [anon_sym_1_SQUOTEb0] = ACTIONS(1),
    [anon_sym_1_SQUOTEb1] = ACTIONS(1),
    [anon_sym_1_SQUOTEbx] = ACTIONS(1),
    [anon_sym_1_SQUOTEbX] = ACTIONS(1),
    [anon_sym_1_SQUOTEB0] = ACTIONS(1),
    [anon_sym_1_SQUOTEB1] = ACTIONS(1),
    [anon_sym_1_SQUOTEBx] = ACTIONS(1),
    [anon_sym_1_SQUOTEBX] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [sym_output_symbol] = ACTIONS(1),
    [sym_level_symbol] = ACTIONS(1),
    [sym_edge_symbol] = ACTIONS(1),
    [anon_sym_assign] = ACTIONS(1),
    [anon_sym_alias] = ACTIONS(1),
    [anon_sym_always_comb] = ACTIONS(1),
    [anon_sym_always_latch] = ACTIONS(1),
    [anon_sym_always_ff] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_deassign] = ACTIONS(1),
    [anon_sym_force] = ACTIONS(1),
    [anon_sym_release] = ACTIONS(1),
    [anon_sym_fork] = ACTIONS(1),
    [anon_sym_join] = ACTIONS(1),
    [anon_sym_join_any] = ACTIONS(1),
    [anon_sym_join_none] = ACTIONS(1),
    [anon_sym_repeat] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_AT_STAR] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_wait] = ACTIONS(1),
    [anon_sym_wait_order] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_DASH_GT_GT] = ACTIONS(1),
    [anon_sym_unique0] = ACTIONS(1),
    [anon_sym_priority] = ACTIONS(1),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1),
    [anon_sym_inside] = ACTIONS(1),
    [anon_sym_casez] = ACTIONS(1),
    [anon_sym_casex] = ACTIONS(1),
    [anon_sym_randcase] = ACTIONS(1),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1),
    [anon_sym_forever] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_endclocking] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_specify] = ACTIONS(1),
    [anon_sym_endspecify] = ACTIONS(1),
    [anon_sym_pulsestyle_onevent] = ACTIONS(1),
    [anon_sym_pulsestyle_ondetect] = ACTIONS(1),
    [anon_sym_showcancelled] = ACTIONS(1),
    [anon_sym_noshowcancelled] = ACTIONS(1),
    [anon_sym_STAR_GT] = ACTIONS(1),
    [anon_sym_posedge] = ACTIONS(1),
    [anon_sym_negedge] = ACTIONS(1),
    [anon_sym_edge] = ACTIONS(1),
    [anon_sym_ifnone] = ACTIONS(1),
    [aux_sym_edge_descriptor_token1] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1),
    [anon_sym_SQUOTEb0] = ACTIONS(1),
    [anon_sym_SQUOTEb1] = ACTIONS(1),
    [anon_sym_SQUOTEB0] = ACTIONS(1),
    [anon_sym_SQUOTEB1] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_PLUS_COLON] = ACTIONS(1),
    [anon_sym_DASH_COLON] = ACTIONS(1),
    [anon_sym_std] = ACTIONS(1),
    [anon_sym_randomize] = ACTIONS(1),
    [anon_sym_null] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_CARET_TILDE] = ACTIONS(1),
    [anon_sym_TILDE_CARET] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_LT_LT_LT] = ACTIONS(1),
    [anon_sym_LT_DASH_GT] = ACTIONS(1),
    [anon_sym_this] = ACTIONS(1),
    [anon_sym_s] = ACTIONS(1),
    [anon_sym_ms] = ACTIONS(1),
    [anon_sym_us] = ACTIONS(1),
    [anon_sym_ns] = ACTIONS(1),
    [anon_sym_ps] = ACTIONS(1),
    [anon_sym_fs] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_TILDE_AMP] = ACTIONS(1),
    [anon_sym_TILDE_PIPE] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_SQUOTE0] = ACTIONS(1),
    [anon_sym_SQUOTE1] = ACTIONS(1),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1),
    [anon_sym_LPAREN_STAR] = ACTIONS(1),
    [anon_sym_STAR_RPAREN] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOLLARroot] = ACTIONS(1),
    [anon_sym_DOLLARunit] = ACTIONS(1),
    [sym_system_tf_identifier] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(17891),
    [sym_include_compiler_directive] = STATE(548),
    [sym_text_macro_definition] = STATE(548),
    [sym_text_macro_usage] = STATE(548),
    [sym_id_directive] = STATE(548),
    [sym_zero_directive] = STATE(548),
    [sym_timescale_compiler_directive] = STATE(548),
    [sym_default_nettype_compiler_directive] = STATE(548),
    [sym_unconnected_drive] = STATE(548),
    [sym_line_compiler_directive] = STATE(548),
    [sym_begin_keywords] = STATE(548),
    [sym__directives] = STATE(548),
    [sym__description] = STATE(548),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(548),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(548),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(548),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_package_declaration] = STATE(548),
    [sym_timeunits_declaration] = STATE(548),
    [sym_bind_directive] = STATE(548),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(548),
    [sym_package_or_generate_item_declaration] = STATE(548),
    [sym_anonymous_program] = STATE(548),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(548),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_udp_nonansi_declaration] = STATE(11645),
    [sym_udp_ansi_declaration] = STATE(12517),
    [sym_udp_declaration] = STATE(548),
    [sym_attribute_instance] = STATE(4172),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym_source_file_repeat1] = STATE(548),
    [aux_sym__description_repeat1] = STATE(4172),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(35),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(41),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_package] = ACTIONS(49),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_primitive] = ACTIONS(113),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2] = {
    [sym_include_compiler_directive] = STATE(5),
    [sym_text_macro_definition] = STATE(5),
    [sym_text_macro_usage] = STATE(5),
    [sym_id_directive] = STATE(5),
    [sym_zero_directive] = STATE(5),
    [sym_timescale_compiler_directive] = STATE(5),
    [sym_default_nettype_compiler_directive] = STATE(5),
    [sym_unconnected_drive] = STATE(5),
    [sym_line_compiler_directive] = STATE(5),
    [sym_begin_keywords] = STATE(5),
    [sym__directives] = STATE(5),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(5),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(5),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(3),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(5),
    [sym_module_or_generate_item] = STATE(5),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(5),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(5),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(5),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(5),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(123),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [3] = {
    [sym_include_compiler_directive] = STATE(7),
    [sym_text_macro_definition] = STATE(7),
    [sym_text_macro_usage] = STATE(7),
    [sym_id_directive] = STATE(7),
    [sym_zero_directive] = STATE(7),
    [sym_timescale_compiler_directive] = STATE(7),
    [sym_default_nettype_compiler_directive] = STATE(7),
    [sym_unconnected_drive] = STATE(7),
    [sym_line_compiler_directive] = STATE(7),
    [sym_begin_keywords] = STATE(7),
    [sym__directives] = STATE(7),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(7),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(7),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(7),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(7),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(7),
    [sym_module_or_generate_item] = STATE(7),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(7),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(7),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(7),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(7),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(7),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(205),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(208),
    [aux_sym_text_macro_definition_token1] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(214),
    [aux_sym_id_directive_token1] = ACTIONS(217),
    [aux_sym_id_directive_token2] = ACTIONS(217),
    [aux_sym_id_directive_token3] = ACTIONS(217),
    [aux_sym_id_directive_token4] = ACTIONS(220),
    [aux_sym_zero_directive_token1] = ACTIONS(223),
    [aux_sym_zero_directive_token2] = ACTIONS(223),
    [aux_sym_zero_directive_token3] = ACTIONS(223),
    [aux_sym_zero_directive_token4] = ACTIONS(223),
    [aux_sym_zero_directive_token5] = ACTIONS(223),
    [aux_sym_zero_directive_token6] = ACTIONS(223),
    [aux_sym_zero_directive_token7] = ACTIONS(223),
    [aux_sym_zero_directive_token8] = ACTIONS(223),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(226),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(229),
    [anon_sym_wire] = ACTIONS(232),
    [anon_sym_tri] = ACTIONS(232),
    [anon_sym_tri0] = ACTIONS(232),
    [anon_sym_tri1] = ACTIONS(232),
    [anon_sym_wand] = ACTIONS(232),
    [anon_sym_triand] = ACTIONS(232),
    [anon_sym_wor] = ACTIONS(232),
    [anon_sym_trior] = ACTIONS(232),
    [anon_sym_trireg] = ACTIONS(232),
    [anon_sym_uwire] = ACTIONS(232),
    [aux_sym_unconnected_drive_token1] = ACTIONS(235),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(238),
    [aux_sym_begin_keywords_token1] = ACTIONS(241),
    [anon_sym_SEMI] = ACTIONS(244),
    [anon_sym_endmodule] = ACTIONS(247),
    [anon_sym_extern] = ACTIONS(250),
    [anon_sym_module] = ACTIONS(253),
    [anon_sym_macromodule] = ACTIONS(253),
    [anon_sym_interface] = ACTIONS(256),
    [anon_sym_program] = ACTIONS(259),
    [anon_sym_checker] = ACTIONS(262),
    [anon_sym_virtual] = ACTIONS(265),
    [anon_sym_class] = ACTIONS(268),
    [anon_sym_timeunit] = ACTIONS(271),
    [anon_sym_timeprecision] = ACTIONS(274),
    [anon_sym_type] = ACTIONS(277),
    [anon_sym_input] = ACTIONS(280),
    [anon_sym_output] = ACTIONS(283),
    [anon_sym_inout] = ACTIONS(286),
    [anon_sym_ref] = ACTIONS(289),
    [anon_sym_DOLLARfatal] = ACTIONS(292),
    [anon_sym_DOLLARerror] = ACTIONS(295),
    [anon_sym_DOLLARwarning] = ACTIONS(295),
    [anon_sym_DOLLARinfo] = ACTIONS(295),
    [anon_sym_default] = ACTIONS(298),
    [anon_sym_clocking] = ACTIONS(301),
    [anon_sym_defparam] = ACTIONS(304),
    [anon_sym_bind] = ACTIONS(307),
    [anon_sym_const] = ACTIONS(310),
    [anon_sym_function] = ACTIONS(313),
    [anon_sym_static] = ACTIONS(316),
    [anon_sym_constraint] = ACTIONS(319),
    [anon_sym_if] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(325),
    [anon_sym_localparam] = ACTIONS(328),
    [anon_sym_parameter] = ACTIONS(331),
    [anon_sym_specparam] = ACTIONS(334),
    [anon_sym_var] = ACTIONS(337),
    [anon_sym_import] = ACTIONS(340),
    [anon_sym_export] = ACTIONS(343),
    [anon_sym_genvar] = ACTIONS(346),
    [anon_sym_interconnect] = ACTIONS(349),
    [anon_sym_typedef] = ACTIONS(352),
    [anon_sym_enum] = ACTIONS(355),
    [anon_sym_struct] = ACTIONS(358),
    [anon_sym_union] = ACTIONS(361),
    [anon_sym_nettype] = ACTIONS(364),
    [anon_sym_automatic] = ACTIONS(367),
    [anon_sym_string] = ACTIONS(370),
    [anon_sym_chandle] = ACTIONS(370),
    [anon_sym_event] = ACTIONS(370),
    [anon_sym_byte] = ACTIONS(373),
    [anon_sym_shortint] = ACTIONS(373),
    [anon_sym_int] = ACTIONS(373),
    [anon_sym_longint] = ACTIONS(373),
    [anon_sym_integer] = ACTIONS(373),
    [anon_sym_time] = ACTIONS(373),
    [anon_sym_bit] = ACTIONS(376),
    [anon_sym_logic] = ACTIONS(376),
    [anon_sym_reg] = ACTIONS(376),
    [anon_sym_shortreal] = ACTIONS(379),
    [anon_sym_real] = ACTIONS(379),
    [anon_sym_realtime] = ACTIONS(379),
    [anon_sym_supply0] = ACTIONS(232),
    [anon_sym_supply1] = ACTIONS(232),
    [anon_sym_signed] = ACTIONS(382),
    [anon_sym_unsigned] = ACTIONS(382),
    [anon_sym_task] = ACTIONS(385),
    [anon_sym_assert] = ACTIONS(388),
    [anon_sym_property] = ACTIONS(391),
    [anon_sym_assume] = ACTIONS(394),
    [anon_sym_cover] = ACTIONS(397),
    [anon_sym_sequence] = ACTIONS(400),
    [anon_sym_restrict] = ACTIONS(403),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_or] = ACTIONS(409),
    [anon_sym_and] = ACTIONS(409),
    [anon_sym_case] = ACTIONS(412),
    [anon_sym_always] = ACTIONS(415),
    [anon_sym_covergroup] = ACTIONS(418),
    [anon_sym_let] = ACTIONS(421),
    [anon_sym_pulldown] = ACTIONS(424),
    [anon_sym_pullup] = ACTIONS(427),
    [anon_sym_cmos] = ACTIONS(430),
    [anon_sym_rcmos] = ACTIONS(430),
    [anon_sym_bufif0] = ACTIONS(433),
    [anon_sym_bufif1] = ACTIONS(433),
    [anon_sym_notif0] = ACTIONS(433),
    [anon_sym_notif1] = ACTIONS(433),
    [anon_sym_nmos] = ACTIONS(436),
    [anon_sym_pmos] = ACTIONS(436),
    [anon_sym_rnmos] = ACTIONS(436),
    [anon_sym_rpmos] = ACTIONS(436),
    [anon_sym_nand] = ACTIONS(409),
    [anon_sym_nor] = ACTIONS(409),
    [anon_sym_xor] = ACTIONS(409),
    [anon_sym_xnor] = ACTIONS(409),
    [anon_sym_buf] = ACTIONS(406),
    [anon_sym_tranif0] = ACTIONS(439),
    [anon_sym_tranif1] = ACTIONS(439),
    [anon_sym_rtranif1] = ACTIONS(439),
    [anon_sym_rtranif0] = ACTIONS(439),
    [anon_sym_tran] = ACTIONS(442),
    [anon_sym_rtran] = ACTIONS(442),
    [anon_sym_generate] = ACTIONS(445),
    [anon_sym_for] = ACTIONS(448),
    [anon_sym_initial] = ACTIONS(451),
    [anon_sym_assign] = ACTIONS(454),
    [anon_sym_alias] = ACTIONS(457),
    [anon_sym_always_comb] = ACTIONS(415),
    [anon_sym_always_latch] = ACTIONS(415),
    [anon_sym_always_ff] = ACTIONS(415),
    [anon_sym_final] = ACTIONS(460),
    [anon_sym_global] = ACTIONS(463),
    [anon_sym_specify] = ACTIONS(466),
    [anon_sym_LPAREN_STAR] = ACTIONS(469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(472),
    [anon_sym_DOLLARunit] = ACTIONS(475),
  },
  [4] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(478),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(481),
    [aux_sym_text_macro_definition_token1] = ACTIONS(484),
    [anon_sym_BQUOTE] = ACTIONS(487),
    [aux_sym_id_directive_token1] = ACTIONS(490),
    [aux_sym_id_directive_token2] = ACTIONS(490),
    [aux_sym_id_directive_token3] = ACTIONS(490),
    [aux_sym_id_directive_token4] = ACTIONS(493),
    [aux_sym_zero_directive_token1] = ACTIONS(496),
    [aux_sym_zero_directive_token2] = ACTIONS(496),
    [aux_sym_zero_directive_token3] = ACTIONS(496),
    [aux_sym_zero_directive_token4] = ACTIONS(496),
    [aux_sym_zero_directive_token5] = ACTIONS(496),
    [aux_sym_zero_directive_token6] = ACTIONS(496),
    [aux_sym_zero_directive_token7] = ACTIONS(496),
    [aux_sym_zero_directive_token8] = ACTIONS(496),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(499),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(502),
    [anon_sym_wire] = ACTIONS(505),
    [anon_sym_tri] = ACTIONS(505),
    [anon_sym_tri0] = ACTIONS(505),
    [anon_sym_tri1] = ACTIONS(505),
    [anon_sym_wand] = ACTIONS(505),
    [anon_sym_triand] = ACTIONS(505),
    [anon_sym_wor] = ACTIONS(505),
    [anon_sym_trior] = ACTIONS(505),
    [anon_sym_trireg] = ACTIONS(505),
    [anon_sym_uwire] = ACTIONS(505),
    [aux_sym_unconnected_drive_token1] = ACTIONS(508),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(511),
    [aux_sym_begin_keywords_token1] = ACTIONS(514),
    [anon_sym_SEMI] = ACTIONS(517),
    [anon_sym_endmodule] = ACTIONS(520),
    [anon_sym_extern] = ACTIONS(522),
    [anon_sym_module] = ACTIONS(525),
    [anon_sym_macromodule] = ACTIONS(525),
    [anon_sym_interface] = ACTIONS(528),
    [anon_sym_program] = ACTIONS(531),
    [anon_sym_checker] = ACTIONS(534),
    [anon_sym_virtual] = ACTIONS(537),
    [anon_sym_class] = ACTIONS(540),
    [anon_sym_timeunit] = ACTIONS(543),
    [anon_sym_timeprecision] = ACTIONS(546),
    [anon_sym_type] = ACTIONS(549),
    [anon_sym_input] = ACTIONS(552),
    [anon_sym_output] = ACTIONS(555),
    [anon_sym_inout] = ACTIONS(558),
    [anon_sym_ref] = ACTIONS(561),
    [anon_sym_DOLLARfatal] = ACTIONS(564),
    [anon_sym_DOLLARerror] = ACTIONS(567),
    [anon_sym_DOLLARwarning] = ACTIONS(567),
    [anon_sym_DOLLARinfo] = ACTIONS(567),
    [anon_sym_default] = ACTIONS(570),
    [anon_sym_clocking] = ACTIONS(573),
    [anon_sym_defparam] = ACTIONS(576),
    [anon_sym_bind] = ACTIONS(579),
    [anon_sym_const] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(585),
    [anon_sym_static] = ACTIONS(588),
    [anon_sym_constraint] = ACTIONS(591),
    [anon_sym_if] = ACTIONS(594),
    [anon_sym_LBRACK] = ACTIONS(597),
    [anon_sym_localparam] = ACTIONS(600),
    [anon_sym_parameter] = ACTIONS(603),
    [anon_sym_specparam] = ACTIONS(606),
    [anon_sym_var] = ACTIONS(609),
    [anon_sym_import] = ACTIONS(612),
    [anon_sym_export] = ACTIONS(615),
    [anon_sym_genvar] = ACTIONS(618),
    [anon_sym_interconnect] = ACTIONS(621),
    [anon_sym_typedef] = ACTIONS(624),
    [anon_sym_enum] = ACTIONS(627),
    [anon_sym_struct] = ACTIONS(630),
    [anon_sym_union] = ACTIONS(633),
    [anon_sym_nettype] = ACTIONS(636),
    [anon_sym_automatic] = ACTIONS(639),
    [anon_sym_string] = ACTIONS(642),
    [anon_sym_chandle] = ACTIONS(642),
    [anon_sym_event] = ACTIONS(642),
    [anon_sym_byte] = ACTIONS(645),
    [anon_sym_shortint] = ACTIONS(645),
    [anon_sym_int] = ACTIONS(645),
    [anon_sym_longint] = ACTIONS(645),
    [anon_sym_integer] = ACTIONS(645),
    [anon_sym_time] = ACTIONS(645),
    [anon_sym_bit] = ACTIONS(648),
    [anon_sym_logic] = ACTIONS(648),
    [anon_sym_reg] = ACTIONS(648),
    [anon_sym_shortreal] = ACTIONS(651),
    [anon_sym_real] = ACTIONS(651),
    [anon_sym_realtime] = ACTIONS(651),
    [anon_sym_supply0] = ACTIONS(505),
    [anon_sym_supply1] = ACTIONS(505),
    [anon_sym_signed] = ACTIONS(654),
    [anon_sym_unsigned] = ACTIONS(654),
    [anon_sym_task] = ACTIONS(657),
    [anon_sym_assert] = ACTIONS(660),
    [anon_sym_property] = ACTIONS(663),
    [anon_sym_assume] = ACTIONS(666),
    [anon_sym_cover] = ACTIONS(669),
    [anon_sym_sequence] = ACTIONS(672),
    [anon_sym_restrict] = ACTIONS(675),
    [anon_sym_not] = ACTIONS(678),
    [anon_sym_or] = ACTIONS(681),
    [anon_sym_and] = ACTIONS(681),
    [anon_sym_case] = ACTIONS(684),
    [anon_sym_always] = ACTIONS(687),
    [anon_sym_covergroup] = ACTIONS(690),
    [anon_sym_let] = ACTIONS(693),
    [anon_sym_pulldown] = ACTIONS(696),
    [anon_sym_pullup] = ACTIONS(699),
    [anon_sym_cmos] = ACTIONS(702),
    [anon_sym_rcmos] = ACTIONS(702),
    [anon_sym_bufif0] = ACTIONS(705),
    [anon_sym_bufif1] = ACTIONS(705),
    [anon_sym_notif0] = ACTIONS(705),
    [anon_sym_notif1] = ACTIONS(705),
    [anon_sym_nmos] = ACTIONS(708),
    [anon_sym_pmos] = ACTIONS(708),
    [anon_sym_rnmos] = ACTIONS(708),
    [anon_sym_rpmos] = ACTIONS(708),
    [anon_sym_nand] = ACTIONS(681),
    [anon_sym_nor] = ACTIONS(681),
    [anon_sym_xor] = ACTIONS(681),
    [anon_sym_xnor] = ACTIONS(681),
    [anon_sym_buf] = ACTIONS(678),
    [anon_sym_tranif0] = ACTIONS(711),
    [anon_sym_tranif1] = ACTIONS(711),
    [anon_sym_rtranif1] = ACTIONS(711),
    [anon_sym_rtranif0] = ACTIONS(711),
    [anon_sym_tran] = ACTIONS(714),
    [anon_sym_rtran] = ACTIONS(714),
    [anon_sym_generate] = ACTIONS(717),
    [anon_sym_for] = ACTIONS(720),
    [anon_sym_initial] = ACTIONS(723),
    [anon_sym_assign] = ACTIONS(726),
    [anon_sym_alias] = ACTIONS(729),
    [anon_sym_always_comb] = ACTIONS(687),
    [anon_sym_always_latch] = ACTIONS(687),
    [anon_sym_always_ff] = ACTIONS(687),
    [anon_sym_final] = ACTIONS(732),
    [anon_sym_global] = ACTIONS(735),
    [anon_sym_specify] = ACTIONS(738),
    [anon_sym_LPAREN_STAR] = ACTIONS(741),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(744),
    [anon_sym_DOLLARunit] = ACTIONS(747),
  },
  [5] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(750),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [6] = {
    [sym_include_compiler_directive] = STATE(7),
    [sym_text_macro_definition] = STATE(7),
    [sym_text_macro_usage] = STATE(7),
    [sym_id_directive] = STATE(7),
    [sym_zero_directive] = STATE(7),
    [sym_timescale_compiler_directive] = STATE(7),
    [sym_default_nettype_compiler_directive] = STATE(7),
    [sym_unconnected_drive] = STATE(7),
    [sym_line_compiler_directive] = STATE(7),
    [sym_begin_keywords] = STATE(7),
    [sym__directives] = STATE(7),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(7),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(7),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(7),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(9),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(7),
    [sym_module_or_generate_item] = STATE(7),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(7),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(7),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(7),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(7),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(7),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(750),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [7] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(752),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [8] = {
    [sym_include_compiler_directive] = STATE(11),
    [sym_text_macro_definition] = STATE(11),
    [sym_text_macro_usage] = STATE(11),
    [sym_id_directive] = STATE(11),
    [sym_zero_directive] = STATE(11),
    [sym_timescale_compiler_directive] = STATE(11),
    [sym_default_nettype_compiler_directive] = STATE(11),
    [sym_unconnected_drive] = STATE(11),
    [sym_line_compiler_directive] = STATE(11),
    [sym_begin_keywords] = STATE(11),
    [sym__directives] = STATE(11),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(11),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(11),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(11),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(12),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(11),
    [sym_module_or_generate_item] = STATE(11),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(11),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(11),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(11),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(11),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(11),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(754),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [9] = {
    [sym_include_compiler_directive] = STATE(10),
    [sym_text_macro_definition] = STATE(10),
    [sym_text_macro_usage] = STATE(10),
    [sym_id_directive] = STATE(10),
    [sym_zero_directive] = STATE(10),
    [sym_timescale_compiler_directive] = STATE(10),
    [sym_default_nettype_compiler_directive] = STATE(10),
    [sym_unconnected_drive] = STATE(10),
    [sym_line_compiler_directive] = STATE(10),
    [sym_begin_keywords] = STATE(10),
    [sym__directives] = STATE(10),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(10),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(10),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(10),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(10),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(10),
    [sym_module_or_generate_item] = STATE(10),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(10),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(10),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(10),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(10),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(10),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(205),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(208),
    [aux_sym_text_macro_definition_token1] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(214),
    [aux_sym_id_directive_token1] = ACTIONS(217),
    [aux_sym_id_directive_token2] = ACTIONS(217),
    [aux_sym_id_directive_token3] = ACTIONS(217),
    [aux_sym_id_directive_token4] = ACTIONS(220),
    [aux_sym_zero_directive_token1] = ACTIONS(223),
    [aux_sym_zero_directive_token2] = ACTIONS(223),
    [aux_sym_zero_directive_token3] = ACTIONS(223),
    [aux_sym_zero_directive_token4] = ACTIONS(223),
    [aux_sym_zero_directive_token5] = ACTIONS(223),
    [aux_sym_zero_directive_token6] = ACTIONS(223),
    [aux_sym_zero_directive_token7] = ACTIONS(223),
    [aux_sym_zero_directive_token8] = ACTIONS(223),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(226),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(229),
    [anon_sym_wire] = ACTIONS(232),
    [anon_sym_tri] = ACTIONS(232),
    [anon_sym_tri0] = ACTIONS(232),
    [anon_sym_tri1] = ACTIONS(232),
    [anon_sym_wand] = ACTIONS(232),
    [anon_sym_triand] = ACTIONS(232),
    [anon_sym_wor] = ACTIONS(232),
    [anon_sym_trior] = ACTIONS(232),
    [anon_sym_trireg] = ACTIONS(232),
    [anon_sym_uwire] = ACTIONS(232),
    [aux_sym_unconnected_drive_token1] = ACTIONS(235),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(238),
    [aux_sym_begin_keywords_token1] = ACTIONS(241),
    [anon_sym_SEMI] = ACTIONS(244),
    [anon_sym_endmodule] = ACTIONS(756),
    [anon_sym_extern] = ACTIONS(250),
    [anon_sym_module] = ACTIONS(253),
    [anon_sym_macromodule] = ACTIONS(253),
    [anon_sym_interface] = ACTIONS(256),
    [anon_sym_program] = ACTIONS(259),
    [anon_sym_checker] = ACTIONS(262),
    [anon_sym_virtual] = ACTIONS(265),
    [anon_sym_class] = ACTIONS(268),
    [anon_sym_timeunit] = ACTIONS(271),
    [anon_sym_timeprecision] = ACTIONS(274),
    [anon_sym_type] = ACTIONS(277),
    [anon_sym_input] = ACTIONS(280),
    [anon_sym_output] = ACTIONS(283),
    [anon_sym_inout] = ACTIONS(286),
    [anon_sym_ref] = ACTIONS(289),
    [anon_sym_DOLLARfatal] = ACTIONS(292),
    [anon_sym_DOLLARerror] = ACTIONS(295),
    [anon_sym_DOLLARwarning] = ACTIONS(295),
    [anon_sym_DOLLARinfo] = ACTIONS(295),
    [anon_sym_default] = ACTIONS(298),
    [anon_sym_clocking] = ACTIONS(301),
    [anon_sym_defparam] = ACTIONS(304),
    [anon_sym_bind] = ACTIONS(307),
    [anon_sym_const] = ACTIONS(310),
    [anon_sym_function] = ACTIONS(313),
    [anon_sym_static] = ACTIONS(316),
    [anon_sym_constraint] = ACTIONS(319),
    [anon_sym_if] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(325),
    [anon_sym_localparam] = ACTIONS(328),
    [anon_sym_parameter] = ACTIONS(331),
    [anon_sym_specparam] = ACTIONS(334),
    [anon_sym_var] = ACTIONS(337),
    [anon_sym_import] = ACTIONS(340),
    [anon_sym_export] = ACTIONS(343),
    [anon_sym_genvar] = ACTIONS(346),
    [anon_sym_interconnect] = ACTIONS(349),
    [anon_sym_typedef] = ACTIONS(352),
    [anon_sym_enum] = ACTIONS(355),
    [anon_sym_struct] = ACTIONS(358),
    [anon_sym_union] = ACTIONS(361),
    [anon_sym_nettype] = ACTIONS(364),
    [anon_sym_automatic] = ACTIONS(367),
    [anon_sym_string] = ACTIONS(370),
    [anon_sym_chandle] = ACTIONS(370),
    [anon_sym_event] = ACTIONS(370),
    [anon_sym_byte] = ACTIONS(373),
    [anon_sym_shortint] = ACTIONS(373),
    [anon_sym_int] = ACTIONS(373),
    [anon_sym_longint] = ACTIONS(373),
    [anon_sym_integer] = ACTIONS(373),
    [anon_sym_time] = ACTIONS(373),
    [anon_sym_bit] = ACTIONS(376),
    [anon_sym_logic] = ACTIONS(376),
    [anon_sym_reg] = ACTIONS(376),
    [anon_sym_shortreal] = ACTIONS(379),
    [anon_sym_real] = ACTIONS(379),
    [anon_sym_realtime] = ACTIONS(379),
    [anon_sym_supply0] = ACTIONS(232),
    [anon_sym_supply1] = ACTIONS(232),
    [anon_sym_signed] = ACTIONS(382),
    [anon_sym_unsigned] = ACTIONS(382),
    [anon_sym_task] = ACTIONS(385),
    [anon_sym_assert] = ACTIONS(388),
    [anon_sym_property] = ACTIONS(391),
    [anon_sym_assume] = ACTIONS(394),
    [anon_sym_cover] = ACTIONS(397),
    [anon_sym_sequence] = ACTIONS(400),
    [anon_sym_restrict] = ACTIONS(403),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_or] = ACTIONS(409),
    [anon_sym_and] = ACTIONS(409),
    [anon_sym_case] = ACTIONS(412),
    [anon_sym_always] = ACTIONS(415),
    [anon_sym_covergroup] = ACTIONS(418),
    [anon_sym_let] = ACTIONS(421),
    [anon_sym_pulldown] = ACTIONS(424),
    [anon_sym_pullup] = ACTIONS(427),
    [anon_sym_cmos] = ACTIONS(430),
    [anon_sym_rcmos] = ACTIONS(430),
    [anon_sym_bufif0] = ACTIONS(433),
    [anon_sym_bufif1] = ACTIONS(433),
    [anon_sym_notif0] = ACTIONS(433),
    [anon_sym_notif1] = ACTIONS(433),
    [anon_sym_nmos] = ACTIONS(436),
    [anon_sym_pmos] = ACTIONS(436),
    [anon_sym_rnmos] = ACTIONS(436),
    [anon_sym_rpmos] = ACTIONS(436),
    [anon_sym_nand] = ACTIONS(409),
    [anon_sym_nor] = ACTIONS(409),
    [anon_sym_xor] = ACTIONS(409),
    [anon_sym_xnor] = ACTIONS(409),
    [anon_sym_buf] = ACTIONS(406),
    [anon_sym_tranif0] = ACTIONS(439),
    [anon_sym_tranif1] = ACTIONS(439),
    [anon_sym_rtranif1] = ACTIONS(439),
    [anon_sym_rtranif0] = ACTIONS(439),
    [anon_sym_tran] = ACTIONS(442),
    [anon_sym_rtran] = ACTIONS(442),
    [anon_sym_generate] = ACTIONS(445),
    [anon_sym_for] = ACTIONS(448),
    [anon_sym_initial] = ACTIONS(451),
    [anon_sym_assign] = ACTIONS(454),
    [anon_sym_alias] = ACTIONS(457),
    [anon_sym_always_comb] = ACTIONS(415),
    [anon_sym_always_latch] = ACTIONS(415),
    [anon_sym_always_ff] = ACTIONS(415),
    [anon_sym_final] = ACTIONS(460),
    [anon_sym_global] = ACTIONS(463),
    [anon_sym_specify] = ACTIONS(466),
    [anon_sym_LPAREN_STAR] = ACTIONS(469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(472),
    [anon_sym_DOLLARunit] = ACTIONS(475),
  },
  [10] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(754),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [11] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(759),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [12] = {
    [sym_include_compiler_directive] = STATE(13),
    [sym_text_macro_definition] = STATE(13),
    [sym_text_macro_usage] = STATE(13),
    [sym_id_directive] = STATE(13),
    [sym_zero_directive] = STATE(13),
    [sym_timescale_compiler_directive] = STATE(13),
    [sym_default_nettype_compiler_directive] = STATE(13),
    [sym_unconnected_drive] = STATE(13),
    [sym_line_compiler_directive] = STATE(13),
    [sym_begin_keywords] = STATE(13),
    [sym__directives] = STATE(13),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(13),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(13),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(13),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(13),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(13),
    [sym_module_or_generate_item] = STATE(13),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(13),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(13),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(13),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(13),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(13),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(205),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(208),
    [aux_sym_text_macro_definition_token1] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(214),
    [aux_sym_id_directive_token1] = ACTIONS(217),
    [aux_sym_id_directive_token2] = ACTIONS(217),
    [aux_sym_id_directive_token3] = ACTIONS(217),
    [aux_sym_id_directive_token4] = ACTIONS(220),
    [aux_sym_zero_directive_token1] = ACTIONS(223),
    [aux_sym_zero_directive_token2] = ACTIONS(223),
    [aux_sym_zero_directive_token3] = ACTIONS(223),
    [aux_sym_zero_directive_token4] = ACTIONS(223),
    [aux_sym_zero_directive_token5] = ACTIONS(223),
    [aux_sym_zero_directive_token6] = ACTIONS(223),
    [aux_sym_zero_directive_token7] = ACTIONS(223),
    [aux_sym_zero_directive_token8] = ACTIONS(223),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(226),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(229),
    [anon_sym_wire] = ACTIONS(232),
    [anon_sym_tri] = ACTIONS(232),
    [anon_sym_tri0] = ACTIONS(232),
    [anon_sym_tri1] = ACTIONS(232),
    [anon_sym_wand] = ACTIONS(232),
    [anon_sym_triand] = ACTIONS(232),
    [anon_sym_wor] = ACTIONS(232),
    [anon_sym_trior] = ACTIONS(232),
    [anon_sym_trireg] = ACTIONS(232),
    [anon_sym_uwire] = ACTIONS(232),
    [aux_sym_unconnected_drive_token1] = ACTIONS(235),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(238),
    [aux_sym_begin_keywords_token1] = ACTIONS(241),
    [anon_sym_SEMI] = ACTIONS(244),
    [anon_sym_endmodule] = ACTIONS(761),
    [anon_sym_extern] = ACTIONS(250),
    [anon_sym_module] = ACTIONS(253),
    [anon_sym_macromodule] = ACTIONS(253),
    [anon_sym_interface] = ACTIONS(256),
    [anon_sym_program] = ACTIONS(259),
    [anon_sym_checker] = ACTIONS(262),
    [anon_sym_virtual] = ACTIONS(265),
    [anon_sym_class] = ACTIONS(268),
    [anon_sym_timeunit] = ACTIONS(271),
    [anon_sym_timeprecision] = ACTIONS(274),
    [anon_sym_type] = ACTIONS(277),
    [anon_sym_input] = ACTIONS(280),
    [anon_sym_output] = ACTIONS(283),
    [anon_sym_inout] = ACTIONS(286),
    [anon_sym_ref] = ACTIONS(289),
    [anon_sym_DOLLARfatal] = ACTIONS(292),
    [anon_sym_DOLLARerror] = ACTIONS(295),
    [anon_sym_DOLLARwarning] = ACTIONS(295),
    [anon_sym_DOLLARinfo] = ACTIONS(295),
    [anon_sym_default] = ACTIONS(298),
    [anon_sym_clocking] = ACTIONS(301),
    [anon_sym_defparam] = ACTIONS(304),
    [anon_sym_bind] = ACTIONS(307),
    [anon_sym_const] = ACTIONS(310),
    [anon_sym_function] = ACTIONS(313),
    [anon_sym_static] = ACTIONS(316),
    [anon_sym_constraint] = ACTIONS(319),
    [anon_sym_if] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(325),
    [anon_sym_localparam] = ACTIONS(328),
    [anon_sym_parameter] = ACTIONS(331),
    [anon_sym_specparam] = ACTIONS(334),
    [anon_sym_var] = ACTIONS(337),
    [anon_sym_import] = ACTIONS(340),
    [anon_sym_export] = ACTIONS(343),
    [anon_sym_genvar] = ACTIONS(346),
    [anon_sym_interconnect] = ACTIONS(349),
    [anon_sym_typedef] = ACTIONS(352),
    [anon_sym_enum] = ACTIONS(355),
    [anon_sym_struct] = ACTIONS(358),
    [anon_sym_union] = ACTIONS(361),
    [anon_sym_nettype] = ACTIONS(364),
    [anon_sym_automatic] = ACTIONS(367),
    [anon_sym_string] = ACTIONS(370),
    [anon_sym_chandle] = ACTIONS(370),
    [anon_sym_event] = ACTIONS(370),
    [anon_sym_byte] = ACTIONS(373),
    [anon_sym_shortint] = ACTIONS(373),
    [anon_sym_int] = ACTIONS(373),
    [anon_sym_longint] = ACTIONS(373),
    [anon_sym_integer] = ACTIONS(373),
    [anon_sym_time] = ACTIONS(373),
    [anon_sym_bit] = ACTIONS(376),
    [anon_sym_logic] = ACTIONS(376),
    [anon_sym_reg] = ACTIONS(376),
    [anon_sym_shortreal] = ACTIONS(379),
    [anon_sym_real] = ACTIONS(379),
    [anon_sym_realtime] = ACTIONS(379),
    [anon_sym_supply0] = ACTIONS(232),
    [anon_sym_supply1] = ACTIONS(232),
    [anon_sym_signed] = ACTIONS(382),
    [anon_sym_unsigned] = ACTIONS(382),
    [anon_sym_task] = ACTIONS(385),
    [anon_sym_assert] = ACTIONS(388),
    [anon_sym_property] = ACTIONS(391),
    [anon_sym_assume] = ACTIONS(394),
    [anon_sym_cover] = ACTIONS(397),
    [anon_sym_sequence] = ACTIONS(400),
    [anon_sym_restrict] = ACTIONS(403),
    [anon_sym_not] = ACTIONS(406),
    [anon_sym_or] = ACTIONS(409),
    [anon_sym_and] = ACTIONS(409),
    [anon_sym_case] = ACTIONS(412),
    [anon_sym_always] = ACTIONS(415),
    [anon_sym_covergroup] = ACTIONS(418),
    [anon_sym_let] = ACTIONS(421),
    [anon_sym_pulldown] = ACTIONS(424),
    [anon_sym_pullup] = ACTIONS(427),
    [anon_sym_cmos] = ACTIONS(430),
    [anon_sym_rcmos] = ACTIONS(430),
    [anon_sym_bufif0] = ACTIONS(433),
    [anon_sym_bufif1] = ACTIONS(433),
    [anon_sym_notif0] = ACTIONS(433),
    [anon_sym_notif1] = ACTIONS(433),
    [anon_sym_nmos] = ACTIONS(436),
    [anon_sym_pmos] = ACTIONS(436),
    [anon_sym_rnmos] = ACTIONS(436),
    [anon_sym_rpmos] = ACTIONS(436),
    [anon_sym_nand] = ACTIONS(409),
    [anon_sym_nor] = ACTIONS(409),
    [anon_sym_xor] = ACTIONS(409),
    [anon_sym_xnor] = ACTIONS(409),
    [anon_sym_buf] = ACTIONS(406),
    [anon_sym_tranif0] = ACTIONS(439),
    [anon_sym_tranif1] = ACTIONS(439),
    [anon_sym_rtranif1] = ACTIONS(439),
    [anon_sym_rtranif0] = ACTIONS(439),
    [anon_sym_tran] = ACTIONS(442),
    [anon_sym_rtran] = ACTIONS(442),
    [anon_sym_generate] = ACTIONS(445),
    [anon_sym_for] = ACTIONS(448),
    [anon_sym_initial] = ACTIONS(451),
    [anon_sym_assign] = ACTIONS(454),
    [anon_sym_alias] = ACTIONS(457),
    [anon_sym_always_comb] = ACTIONS(415),
    [anon_sym_always_latch] = ACTIONS(415),
    [anon_sym_always_ff] = ACTIONS(415),
    [anon_sym_final] = ACTIONS(460),
    [anon_sym_global] = ACTIONS(463),
    [anon_sym_specify] = ACTIONS(466),
    [anon_sym_LPAREN_STAR] = ACTIONS(469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(472),
    [anon_sym_DOLLARunit] = ACTIONS(475),
  },
  [13] = {
    [sym_include_compiler_directive] = STATE(4),
    [sym_text_macro_definition] = STATE(4),
    [sym_text_macro_usage] = STATE(4),
    [sym_id_directive] = STATE(4),
    [sym_zero_directive] = STATE(4),
    [sym_timescale_compiler_directive] = STATE(4),
    [sym_default_nettype_compiler_directive] = STATE(4),
    [sym_unconnected_drive] = STATE(4),
    [sym_line_compiler_directive] = STATE(4),
    [sym_begin_keywords] = STATE(4),
    [sym__directives] = STATE(4),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(4),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(4),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(4),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4),
    [sym_port_declaration] = STATE(19495),
    [sym_elaboration_system_task] = STATE(1199),
    [sym__module_common_item] = STATE(1199),
    [sym__module_item] = STATE(4),
    [sym_module_or_generate_item] = STATE(4),
    [sym__module_or_generate_item_declaration] = STATE(1199),
    [sym__non_port_module_item] = STATE(4),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1199),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1199),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(4),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1199),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1199),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1199),
    [sym_program_instantiation] = STATE(1199),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(4),
    [sym_loop_generate_construct] = STATE(1199),
    [sym__conditional_generate_construct] = STATE(1199),
    [sym_if_generate_construct] = STATE(1199),
    [sym_case_generate_construct] = STATE(1199),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1199),
    [sym_net_alias] = STATE(1199),
    [sym_initial_construct] = STATE(1199),
    [sym_always_construct] = STATE(1199),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1199),
    [sym__assertion_item] = STATE(1199),
    [sym_deferred_immediate_assertion_item] = STATE(1199),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1199),
    [sym_specify_block] = STATE(4),
    [sym_attribute_instance] = STATE(14),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(14),
    [aux_sym_module_declaration_repeat1] = STATE(4),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_endmodule] = ACTIONS(764),
    [anon_sym_extern] = ACTIONS(125),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_specify] = ACTIONS(199),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [14] = {
    [sym_module_keyword] = STATE(12139),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1241),
    [sym__module_common_item] = STATE(1241),
    [sym__module_or_generate_item_declaration] = STATE(1241),
    [sym_parameter_override] = STATE(1241),
    [sym_bind_directive] = STATE(1241),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1241),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_specparam_declaration] = STATE(1380),
    [sym_inout_declaration] = STATE(18782),
    [sym_input_declaration] = STATE(18782),
    [sym_output_declaration] = STATE(18782),
    [sym_interface_port_declaration] = STATE(18782),
    [sym_ref_declaration] = STATE(18782),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1241),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1241),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1241),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1241),
    [sym_interface_instantiation] = STATE(1241),
    [sym_program_instantiation] = STATE(1241),
    [sym_checker_instantiation] = STATE(1224),
    [sym_loop_generate_construct] = STATE(1241),
    [sym__conditional_generate_construct] = STATE(1241),
    [sym_if_generate_construct] = STATE(1241),
    [sym_case_generate_construct] = STATE(1241),
    [sym_udp_instantiation] = STATE(1241),
    [sym_continuous_assign] = STATE(1241),
    [sym_net_alias] = STATE(1241),
    [sym_initial_construct] = STATE(1241),
    [sym_always_construct] = STATE(1241),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1241),
    [sym__assertion_item] = STATE(1241),
    [sym_deferred_immediate_assertion_item] = STATE(1241),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1241),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10538),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(766),
    [anon_sym_program] = ACTIONS(768),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_specparam] = ACTIONS(149),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [15] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10403),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(94),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10632),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(94),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_COLON] = ACTIONS(772),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [16] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(83),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(83),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(83),
    [sym_checker_or_generate_item_declaration] = STATE(83),
    [sym__checker_generate_item] = STATE(83),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(83),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(83),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(83),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(864),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(932),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [17] = {
    [sym_checker_declaration] = STATE(1249),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1250),
    [sym__module_common_item] = STATE(1252),
    [sym_module_or_generate_item] = STATE(1234),
    [sym__module_or_generate_item_declaration] = STATE(1252),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1252),
    [sym_interface_or_generate_item] = STATE(1234),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__checker_or_generate_item] = STATE(1234),
    [sym_checker_or_generate_item_declaration] = STATE(1234),
    [sym__checker_generate_item] = STATE(1234),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1252),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(1249),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1253),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(1249),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1255),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(1249),
    [sym_property_declaration] = STATE(1249),
    [sym_sequence_declaration] = STATE(1249),
    [sym_covergroup_declaration] = STATE(1249),
    [sym_let_declaration] = STATE(1249),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1252),
    [sym_program_instantiation] = STATE(1252),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(1234),
    [sym_loop_generate_construct] = STATE(1250),
    [sym__conditional_generate_construct] = STATE(1250),
    [sym_if_generate_construct] = STATE(1250),
    [sym_case_generate_construct] = STATE(1250),
    [sym_generate_block] = STATE(1233),
    [sym__generate_item] = STATE(1234),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1255),
    [sym_net_alias] = STATE(1252),
    [sym_initial_construct] = STATE(1255),
    [sym_always_construct] = STATE(1255),
    [sym_always_keyword] = STATE(4281),
    [sym_final_construct] = STATE(1255),
    [sym__assertion_item] = STATE(1255),
    [sym_deferred_immediate_assertion_item] = STATE(1255),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1253),
    [sym_attribute_instance] = STATE(90),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(19649),
    [sym__identifier] = STATE(10638),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(90),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(954),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(960),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_rand] = ACTIONS(962),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(964),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(966),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(968),
    [anon_sym_cover] = ACTIONS(970),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_begin] = ACTIONS(972),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(974),
    [anon_sym_initial] = ACTIONS(976),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(978),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [18] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(56),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(56),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(56),
    [sym_checker_or_generate_item_declaration] = STATE(56),
    [sym__checker_generate_item] = STATE(56),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(56),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(56),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(56),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(980),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(982),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [19] = {
    [sym_checker_declaration] = STATE(1249),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1250),
    [sym__module_common_item] = STATE(1252),
    [sym_module_or_generate_item] = STATE(1234),
    [sym__module_or_generate_item_declaration] = STATE(1252),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1252),
    [sym_interface_or_generate_item] = STATE(1234),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__checker_or_generate_item] = STATE(1234),
    [sym_checker_or_generate_item_declaration] = STATE(1234),
    [sym__checker_generate_item] = STATE(1234),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1252),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(1249),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1253),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(1249),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1255),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(1249),
    [sym_property_declaration] = STATE(1249),
    [sym_sequence_declaration] = STATE(1249),
    [sym_covergroup_declaration] = STATE(1249),
    [sym_let_declaration] = STATE(1249),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1252),
    [sym_program_instantiation] = STATE(1252),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(1234),
    [sym_loop_generate_construct] = STATE(1250),
    [sym__conditional_generate_construct] = STATE(1250),
    [sym_if_generate_construct] = STATE(1250),
    [sym_case_generate_construct] = STATE(1250),
    [sym_generate_block] = STATE(1227),
    [sym__generate_item] = STATE(1234),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1255),
    [sym_net_alias] = STATE(1252),
    [sym_initial_construct] = STATE(1255),
    [sym_always_construct] = STATE(1255),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1255),
    [sym__assertion_item] = STATE(1255),
    [sym_deferred_immediate_assertion_item] = STATE(1255),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1253),
    [sym_attribute_instance] = STATE(98),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(19649),
    [sym__identifier] = STATE(10649),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(98),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(954),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(960),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_rand] = ACTIONS(962),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_begin] = ACTIONS(972),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [20] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10411),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(94),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10632),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(94),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [21] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(71),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(71),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(71),
    [sym_checker_or_generate_item_declaration] = STATE(71),
    [sym__checker_generate_item] = STATE(71),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(71),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(71),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(71),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(984),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(986),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [22] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10421),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(94),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10632),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(94),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [23] = {
    [sym_checker_declaration] = STATE(1249),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1250),
    [sym__module_common_item] = STATE(1252),
    [sym_module_or_generate_item] = STATE(1234),
    [sym__module_or_generate_item_declaration] = STATE(1252),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1252),
    [sym_interface_or_generate_item] = STATE(1234),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__checker_or_generate_item] = STATE(1234),
    [sym_checker_or_generate_item_declaration] = STATE(1234),
    [sym__checker_generate_item] = STATE(1234),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1252),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(1249),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1253),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(1249),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1255),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(1249),
    [sym_property_declaration] = STATE(1249),
    [sym_sequence_declaration] = STATE(1249),
    [sym_covergroup_declaration] = STATE(1249),
    [sym_let_declaration] = STATE(1249),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1252),
    [sym_program_instantiation] = STATE(1252),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(1234),
    [sym_loop_generate_construct] = STATE(1250),
    [sym__conditional_generate_construct] = STATE(1250),
    [sym_if_generate_construct] = STATE(1250),
    [sym_case_generate_construct] = STATE(1250),
    [sym_generate_block] = STATE(1193),
    [sym__generate_item] = STATE(1234),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1255),
    [sym_net_alias] = STATE(1252),
    [sym_initial_construct] = STATE(1255),
    [sym_always_construct] = STATE(1255),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1255),
    [sym__assertion_item] = STATE(1255),
    [sym_deferred_immediate_assertion_item] = STATE(1255),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1253),
    [sym_attribute_instance] = STATE(98),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(19649),
    [sym__identifier] = STATE(10649),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(98),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(954),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(960),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_rand] = ACTIONS(962),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_begin] = ACTIONS(972),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [24] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(5120),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(5120),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(5120),
    [sym_checker_or_generate_item_declaration] = STATE(5120),
    [sym__checker_generate_item] = STATE(5120),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(5120),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym_generate_block] = STATE(4670),
    [sym__generate_item] = STATE(5120),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4242),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(96),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18537),
    [sym__identifier] = STATE(10633),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(96),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1022),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1040),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1044),
    [anon_sym_cover] = ACTIONS(1046),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_begin] = ACTIONS(1056),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1066),
    [anon_sym_initial] = ACTIONS(1068),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1074),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [25] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(5120),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(5120),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(5120),
    [sym_checker_or_generate_item_declaration] = STATE(5120),
    [sym__checker_generate_item] = STATE(5120),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(5120),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym_generate_block] = STATE(5030),
    [sym__generate_item] = STATE(5120),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18537),
    [sym__identifier] = STATE(10651),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_begin] = ACTIONS(1056),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [26] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(5120),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(5120),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(5120),
    [sym_checker_or_generate_item_declaration] = STATE(5120),
    [sym__checker_generate_item] = STATE(5120),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(5120),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym_generate_block] = STATE(4783),
    [sym__generate_item] = STATE(5120),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18537),
    [sym__identifier] = STATE(10651),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_begin] = ACTIONS(1056),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [27] = {
    [sym_checker_declaration] = STATE(6437),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6438),
    [sym__module_common_item] = STATE(6439),
    [sym_module_or_generate_item] = STATE(6390),
    [sym__module_or_generate_item_declaration] = STATE(6439),
    [sym_parameter_override] = STATE(6436),
    [sym_bind_directive] = STATE(6439),
    [sym_interface_or_generate_item] = STATE(6390),
    [sym_extern_tf_declaration] = STATE(6428),
    [sym__checker_or_generate_item] = STATE(6390),
    [sym_checker_or_generate_item_declaration] = STATE(6390),
    [sym__checker_generate_item] = STATE(6390),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6439),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6437),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6440),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6437),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6441),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6437),
    [sym_property_declaration] = STATE(6437),
    [sym_sequence_declaration] = STATE(6437),
    [sym_covergroup_declaration] = STATE(6437),
    [sym_let_declaration] = STATE(6437),
    [sym_gate_instantiation] = STATE(6436),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6436),
    [sym_interface_instantiation] = STATE(6439),
    [sym_program_instantiation] = STATE(6439),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6390),
    [sym_loop_generate_construct] = STATE(6438),
    [sym__conditional_generate_construct] = STATE(6438),
    [sym_if_generate_construct] = STATE(6438),
    [sym_case_generate_construct] = STATE(6438),
    [sym_generate_block] = STATE(6591),
    [sym__generate_item] = STATE(6390),
    [sym_udp_instantiation] = STATE(6436),
    [sym_continuous_assign] = STATE(6441),
    [sym_net_alias] = STATE(6439),
    [sym_initial_construct] = STATE(6441),
    [sym_always_construct] = STATE(6441),
    [sym_always_keyword] = STATE(4246),
    [sym_final_construct] = STATE(6441),
    [sym__assertion_item] = STATE(6441),
    [sym_deferred_immediate_assertion_item] = STATE(6441),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6440),
    [sym_attribute_instance] = STATE(92),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18720),
    [sym__identifier] = STATE(10642),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(92),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1092),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1108),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1126),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1144),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1148),
    [anon_sym_cover] = ACTIONS(1150),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_begin] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1170),
    [anon_sym_initial] = ACTIONS(1172),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1178),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [28] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(55),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(55),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(55),
    [sym_checker_or_generate_item_declaration] = STATE(55),
    [sym__checker_generate_item] = STATE(55),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(55),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(55),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(55),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1182),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1184),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [29] = {
    [sym_checker_declaration] = STATE(6437),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6438),
    [sym__module_common_item] = STATE(6439),
    [sym_module_or_generate_item] = STATE(6390),
    [sym__module_or_generate_item_declaration] = STATE(6439),
    [sym_parameter_override] = STATE(6436),
    [sym_bind_directive] = STATE(6439),
    [sym_interface_or_generate_item] = STATE(6390),
    [sym_extern_tf_declaration] = STATE(6428),
    [sym__checker_or_generate_item] = STATE(6390),
    [sym_checker_or_generate_item_declaration] = STATE(6390),
    [sym__checker_generate_item] = STATE(6390),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6439),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6437),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6440),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6437),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6441),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6437),
    [sym_property_declaration] = STATE(6437),
    [sym_sequence_declaration] = STATE(6437),
    [sym_covergroup_declaration] = STATE(6437),
    [sym_let_declaration] = STATE(6437),
    [sym_gate_instantiation] = STATE(6436),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6436),
    [sym_interface_instantiation] = STATE(6439),
    [sym_program_instantiation] = STATE(6439),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6390),
    [sym_loop_generate_construct] = STATE(6438),
    [sym__conditional_generate_construct] = STATE(6438),
    [sym_if_generate_construct] = STATE(6438),
    [sym_case_generate_construct] = STATE(6438),
    [sym_generate_block] = STATE(6304),
    [sym__generate_item] = STATE(6390),
    [sym_udp_instantiation] = STATE(6436),
    [sym_continuous_assign] = STATE(6441),
    [sym_net_alias] = STATE(6439),
    [sym_initial_construct] = STATE(6441),
    [sym_always_construct] = STATE(6441),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(6441),
    [sym__assertion_item] = STATE(6441),
    [sym_deferred_immediate_assertion_item] = STATE(6441),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6440),
    [sym_attribute_instance] = STATE(99),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18720),
    [sym__identifier] = STATE(10653),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(99),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1092),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1108),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_begin] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [30] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(58),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(58),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(58),
    [sym_checker_or_generate_item_declaration] = STATE(58),
    [sym__checker_generate_item] = STATE(58),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(58),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(58),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(58),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1200),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1202),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [31] = {
    [sym_checker_declaration] = STATE(6437),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6438),
    [sym__module_common_item] = STATE(6439),
    [sym_module_or_generate_item] = STATE(6390),
    [sym__module_or_generate_item_declaration] = STATE(6439),
    [sym_parameter_override] = STATE(6436),
    [sym_bind_directive] = STATE(6439),
    [sym_interface_or_generate_item] = STATE(6390),
    [sym_extern_tf_declaration] = STATE(6428),
    [sym__checker_or_generate_item] = STATE(6390),
    [sym_checker_or_generate_item_declaration] = STATE(6390),
    [sym__checker_generate_item] = STATE(6390),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6439),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6437),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6440),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6437),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6441),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6437),
    [sym_property_declaration] = STATE(6437),
    [sym_sequence_declaration] = STATE(6437),
    [sym_covergroup_declaration] = STATE(6437),
    [sym_let_declaration] = STATE(6437),
    [sym_gate_instantiation] = STATE(6436),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6436),
    [sym_interface_instantiation] = STATE(6439),
    [sym_program_instantiation] = STATE(6439),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6390),
    [sym_loop_generate_construct] = STATE(6438),
    [sym__conditional_generate_construct] = STATE(6438),
    [sym_if_generate_construct] = STATE(6438),
    [sym_case_generate_construct] = STATE(6438),
    [sym_generate_block] = STATE(6340),
    [sym__generate_item] = STATE(6390),
    [sym_udp_instantiation] = STATE(6436),
    [sym_continuous_assign] = STATE(6441),
    [sym_net_alias] = STATE(6439),
    [sym_initial_construct] = STATE(6441),
    [sym_always_construct] = STATE(6441),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(6441),
    [sym__assertion_item] = STATE(6441),
    [sym_deferred_immediate_assertion_item] = STATE(6441),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6440),
    [sym_attribute_instance] = STATE(99),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18720),
    [sym__identifier] = STATE(10653),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(99),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1092),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1108),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_begin] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [32] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10252),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4226),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(97),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10659),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(97),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(1206),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(1208),
    [anon_sym_cover] = ACTIONS(1210),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(1212),
    [anon_sym_initial] = ACTIONS(1214),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1216),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [33] = {
    [sym_checker_declaration] = STATE(1249),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1250),
    [sym__module_common_item] = STATE(1252),
    [sym_module_or_generate_item] = STATE(1234),
    [sym__module_or_generate_item_declaration] = STATE(1252),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1252),
    [sym_interface_or_generate_item] = STATE(1234),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__checker_or_generate_item] = STATE(1234),
    [sym_checker_or_generate_item_declaration] = STATE(1234),
    [sym__checker_generate_item] = STATE(1234),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1252),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(1249),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1253),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(1249),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1255),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(1249),
    [sym_property_declaration] = STATE(1249),
    [sym_sequence_declaration] = STATE(1249),
    [sym_covergroup_declaration] = STATE(1249),
    [sym_let_declaration] = STATE(1249),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1252),
    [sym_program_instantiation] = STATE(1252),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(1234),
    [sym_loop_generate_construct] = STATE(1250),
    [sym__conditional_generate_construct] = STATE(1250),
    [sym_if_generate_construct] = STATE(1250),
    [sym_case_generate_construct] = STATE(1250),
    [sym_generate_block] = STATE(1240),
    [sym__generate_item] = STATE(1234),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1255),
    [sym_net_alias] = STATE(1252),
    [sym_initial_construct] = STATE(1255),
    [sym_always_construct] = STATE(1255),
    [sym_always_keyword] = STATE(4281),
    [sym_final_construct] = STATE(1255),
    [sym__assertion_item] = STATE(1255),
    [sym_deferred_immediate_assertion_item] = STATE(1255),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1253),
    [sym_attribute_instance] = STATE(90),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(19649),
    [sym__identifier] = STATE(10638),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(90),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(954),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(960),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_rand] = ACTIONS(962),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(964),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(966),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(968),
    [anon_sym_cover] = ACTIONS(970),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_begin] = ACTIONS(972),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(974),
    [anon_sym_initial] = ACTIONS(976),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(978),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [34] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(64),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(64),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(64),
    [sym_checker_or_generate_item_declaration] = STATE(64),
    [sym__checker_generate_item] = STATE(64),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(64),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(64),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(64),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1218),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1220),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [35] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(5059),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(5059),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(5059),
    [sym_checker_or_generate_item_declaration] = STATE(5059),
    [sym__checker_generate_item] = STATE(5059),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(5059),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym_generate_block] = STATE(5087),
    [sym__generate_item] = STATE(5059),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18884),
    [sym__identifier] = STATE(10655),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_begin] = ACTIONS(1222),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [36] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(66),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(66),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(66),
    [sym_checker_or_generate_item_declaration] = STATE(66),
    [sym__checker_generate_item] = STATE(66),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(66),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(66),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(66),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1224),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1226),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [37] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(5059),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(5059),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(5059),
    [sym_checker_or_generate_item_declaration] = STATE(5059),
    [sym__checker_generate_item] = STATE(5059),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(5059),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym_generate_block] = STATE(5208),
    [sym__generate_item] = STATE(5059),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18884),
    [sym__identifier] = STATE(10655),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_begin] = ACTIONS(1222),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [38] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(5059),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(5059),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(5059),
    [sym_checker_or_generate_item_declaration] = STATE(5059),
    [sym__checker_generate_item] = STATE(5059),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(5059),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym_generate_block] = STATE(5217),
    [sym__generate_item] = STATE(5059),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4249),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(95),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18884),
    [sym__identifier] = STATE(10647),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(95),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(1228),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(1230),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(1232),
    [anon_sym_cover] = ACTIONS(1234),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_begin] = ACTIONS(1222),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(1236),
    [anon_sym_initial] = ACTIONS(1238),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1240),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [39] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(72),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(72),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(72),
    [sym_checker_or_generate_item_declaration] = STATE(72),
    [sym__checker_generate_item] = STATE(72),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(72),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(72),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(72),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1242),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1244),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [40] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10224),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(94),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10632),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(94),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [41] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(74),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(74),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(74),
    [sym_checker_or_generate_item_declaration] = STATE(74),
    [sym__checker_generate_item] = STATE(74),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(74),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(74),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(74),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1246),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1248),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [42] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10252),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(94),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10632),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(94),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [43] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(10314),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4226),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(97),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10659),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(97),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(1206),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(1208),
    [anon_sym_cover] = ACTIONS(1210),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(1212),
    [anon_sym_initial] = ACTIONS(1214),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1216),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [44] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(80),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(80),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(80),
    [sym_checker_or_generate_item_declaration] = STATE(80),
    [sym__checker_generate_item] = STATE(80),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(80),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(80),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(80),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_COLON] = ACTIONS(1250),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1252),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [45] = {
    [sym_checker_declaration] = STATE(6437),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6438),
    [sym__module_common_item] = STATE(6439),
    [sym_module_or_generate_item] = STATE(6390),
    [sym__module_or_generate_item_declaration] = STATE(6439),
    [sym_parameter_override] = STATE(6436),
    [sym_bind_directive] = STATE(6439),
    [sym_interface_or_generate_item] = STATE(6390),
    [sym_extern_tf_declaration] = STATE(6428),
    [sym__checker_or_generate_item] = STATE(6390),
    [sym_checker_or_generate_item_declaration] = STATE(6390),
    [sym__checker_generate_item] = STATE(6390),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6439),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6437),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6440),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6437),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6441),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6437),
    [sym_property_declaration] = STATE(6437),
    [sym_sequence_declaration] = STATE(6437),
    [sym_covergroup_declaration] = STATE(6437),
    [sym_let_declaration] = STATE(6437),
    [sym_gate_instantiation] = STATE(6436),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6436),
    [sym_interface_instantiation] = STATE(6439),
    [sym_program_instantiation] = STATE(6439),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6390),
    [sym_loop_generate_construct] = STATE(6438),
    [sym__conditional_generate_construct] = STATE(6438),
    [sym_if_generate_construct] = STATE(6438),
    [sym_case_generate_construct] = STATE(6438),
    [sym_generate_block] = STATE(6510),
    [sym__generate_item] = STATE(6390),
    [sym_udp_instantiation] = STATE(6436),
    [sym_continuous_assign] = STATE(6441),
    [sym_net_alias] = STATE(6439),
    [sym_initial_construct] = STATE(6441),
    [sym_always_construct] = STATE(6441),
    [sym_always_keyword] = STATE(4246),
    [sym_final_construct] = STATE(6441),
    [sym__assertion_item] = STATE(6441),
    [sym_deferred_immediate_assertion_item] = STATE(6441),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6440),
    [sym_attribute_instance] = STATE(92),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18720),
    [sym__identifier] = STATE(10642),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(92),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1092),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1108),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1126),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1144),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1148),
    [anon_sym_cover] = ACTIONS(1150),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_begin] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1170),
    [anon_sym_initial] = ACTIONS(1172),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1178),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [46] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(5059),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(5059),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(5059),
    [sym_checker_or_generate_item_declaration] = STATE(5059),
    [sym__checker_generate_item] = STATE(5059),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(5059),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym_generate_block] = STATE(4734),
    [sym__generate_item] = STATE(5059),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4249),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(95),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18884),
    [sym__identifier] = STATE(10647),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(95),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(1228),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(1230),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(1232),
    [anon_sym_cover] = ACTIONS(1234),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_begin] = ACTIONS(1222),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(1236),
    [anon_sym_initial] = ACTIONS(1238),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1240),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [47] = {
    [sym_checker_declaration] = STATE(9989),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(9990),
    [sym__module_common_item] = STATE(9991),
    [sym_module_or_generate_item] = STATE(9841),
    [sym__module_or_generate_item_declaration] = STATE(9991),
    [sym_parameter_override] = STATE(9988),
    [sym_bind_directive] = STATE(9991),
    [sym_interface_or_generate_item] = STATE(9841),
    [sym_extern_tf_declaration] = STATE(9980),
    [sym__checker_or_generate_item] = STATE(9841),
    [sym_checker_or_generate_item_declaration] = STATE(9841),
    [sym__checker_generate_item] = STATE(9841),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(9991),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9989),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(9992),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9989),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(9993),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9989),
    [sym_property_declaration] = STATE(9989),
    [sym_sequence_declaration] = STATE(9989),
    [sym_covergroup_declaration] = STATE(9989),
    [sym_let_declaration] = STATE(9989),
    [sym_gate_instantiation] = STATE(9988),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(9988),
    [sym_interface_instantiation] = STATE(9991),
    [sym_program_instantiation] = STATE(9991),
    [sym_checker_instantiation] = STATE(10149),
    [sym_generate_region] = STATE(9841),
    [sym_loop_generate_construct] = STATE(9990),
    [sym__conditional_generate_construct] = STATE(9990),
    [sym_if_generate_construct] = STATE(9990),
    [sym_case_generate_construct] = STATE(9990),
    [sym_generate_block] = STATE(9807),
    [sym__generate_item] = STATE(9841),
    [sym_udp_instantiation] = STATE(9988),
    [sym_continuous_assign] = STATE(9993),
    [sym_net_alias] = STATE(9991),
    [sym_initial_construct] = STATE(9993),
    [sym_always_construct] = STATE(9993),
    [sym_always_keyword] = STATE(4226),
    [sym_final_construct] = STATE(9993),
    [sym__assertion_item] = STATE(9993),
    [sym_deferred_immediate_assertion_item] = STATE(9993),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(9992),
    [sym_attribute_instance] = STATE(97),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18281),
    [sym__identifier] = STATE(10659),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(97),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(770),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(788),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_rand] = ACTIONS(796),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(1206),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(1208),
    [anon_sym_cover] = ACTIONS(1210),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_begin] = ACTIONS(840),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(848),
    [anon_sym_for] = ACTIONS(1212),
    [anon_sym_initial] = ACTIONS(1214),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1216),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [48] = {
    [sym_checker_declaration] = STATE(1249),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1250),
    [sym__module_common_item] = STATE(1252),
    [sym_module_or_generate_item] = STATE(1234),
    [sym__module_or_generate_item_declaration] = STATE(1252),
    [sym_parameter_override] = STATE(1199),
    [sym_bind_directive] = STATE(1252),
    [sym_interface_or_generate_item] = STATE(1234),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__checker_or_generate_item] = STATE(1234),
    [sym_checker_or_generate_item_declaration] = STATE(1234),
    [sym__checker_generate_item] = STATE(1234),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1252),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(1249),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1253),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(1249),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1255),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(1249),
    [sym_property_declaration] = STATE(1249),
    [sym_sequence_declaration] = STATE(1249),
    [sym_covergroup_declaration] = STATE(1249),
    [sym_let_declaration] = STATE(1249),
    [sym_gate_instantiation] = STATE(1199),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1199),
    [sym_interface_instantiation] = STATE(1252),
    [sym_program_instantiation] = STATE(1252),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(1234),
    [sym_loop_generate_construct] = STATE(1250),
    [sym__conditional_generate_construct] = STATE(1250),
    [sym_if_generate_construct] = STATE(1250),
    [sym_case_generate_construct] = STATE(1250),
    [sym_generate_block] = STATE(1193),
    [sym__generate_item] = STATE(1234),
    [sym_udp_instantiation] = STATE(1199),
    [sym_continuous_assign] = STATE(1255),
    [sym_net_alias] = STATE(1252),
    [sym_initial_construct] = STATE(1255),
    [sym_always_construct] = STATE(1255),
    [sym_always_keyword] = STATE(4281),
    [sym_final_construct] = STATE(1255),
    [sym__assertion_item] = STATE(1255),
    [sym_deferred_immediate_assertion_item] = STATE(1255),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1253),
    [sym_attribute_instance] = STATE(90),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(19649),
    [sym__identifier] = STATE(10638),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(90),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(954),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(960),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_rand] = ACTIONS(962),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(964),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(966),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(968),
    [anon_sym_cover] = ACTIONS(970),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_begin] = ACTIONS(972),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(974),
    [anon_sym_initial] = ACTIONS(976),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(978),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [49] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(5120),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(5120),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(5120),
    [sym_checker_or_generate_item_declaration] = STATE(5120),
    [sym__checker_generate_item] = STATE(5120),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(5120),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym_generate_block] = STATE(4783),
    [sym__generate_item] = STATE(5120),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4242),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(96),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18537),
    [sym__identifier] = STATE(10633),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(96),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1022),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1040),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1044),
    [anon_sym_cover] = ACTIONS(1046),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_begin] = ACTIONS(1056),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1066),
    [anon_sym_initial] = ACTIONS(1068),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1074),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [50] = {
    [sym_checker_declaration] = STATE(6437),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6438),
    [sym__module_common_item] = STATE(6439),
    [sym_module_or_generate_item] = STATE(6390),
    [sym__module_or_generate_item_declaration] = STATE(6439),
    [sym_parameter_override] = STATE(6436),
    [sym_bind_directive] = STATE(6439),
    [sym_interface_or_generate_item] = STATE(6390),
    [sym_extern_tf_declaration] = STATE(6428),
    [sym__checker_or_generate_item] = STATE(6390),
    [sym_checker_or_generate_item_declaration] = STATE(6390),
    [sym__checker_generate_item] = STATE(6390),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6439),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6437),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6440),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6437),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6441),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6437),
    [sym_property_declaration] = STATE(6437),
    [sym_sequence_declaration] = STATE(6437),
    [sym_covergroup_declaration] = STATE(6437),
    [sym_let_declaration] = STATE(6437),
    [sym_gate_instantiation] = STATE(6436),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6436),
    [sym_interface_instantiation] = STATE(6439),
    [sym_program_instantiation] = STATE(6439),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6390),
    [sym_loop_generate_construct] = STATE(6438),
    [sym__conditional_generate_construct] = STATE(6438),
    [sym_if_generate_construct] = STATE(6438),
    [sym_case_generate_construct] = STATE(6438),
    [sym_generate_block] = STATE(6340),
    [sym__generate_item] = STATE(6390),
    [sym_udp_instantiation] = STATE(6436),
    [sym_continuous_assign] = STATE(6441),
    [sym_net_alias] = STATE(6439),
    [sym_initial_construct] = STATE(6441),
    [sym_always_construct] = STATE(6441),
    [sym_always_keyword] = STATE(4246),
    [sym_final_construct] = STATE(6441),
    [sym__assertion_item] = STATE(6441),
    [sym_deferred_immediate_assertion_item] = STATE(6441),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6440),
    [sym_attribute_instance] = STATE(92),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18720),
    [sym__identifier] = STATE(10642),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(92),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1092),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1108),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1126),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1144),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1148),
    [anon_sym_cover] = ACTIONS(1150),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_begin] = ACTIONS(1160),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1170),
    [anon_sym_initial] = ACTIONS(1172),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1178),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [51] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(5059),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(5059),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(5059),
    [sym_checker_or_generate_item_declaration] = STATE(5059),
    [sym__checker_generate_item] = STATE(5059),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(5059),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym_generate_block] = STATE(5208),
    [sym__generate_item] = STATE(5059),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4249),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(95),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18884),
    [sym__identifier] = STATE(10647),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(95),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(1228),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(1230),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(1232),
    [anon_sym_cover] = ACTIONS(1234),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_begin] = ACTIONS(1222),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(1236),
    [anon_sym_initial] = ACTIONS(1238),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1240),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [52] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(5120),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(5120),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(5120),
    [sym_checker_or_generate_item_declaration] = STATE(5120),
    [sym__checker_generate_item] = STATE(5120),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(5120),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym_generate_block] = STATE(4836),
    [sym__generate_item] = STATE(5120),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4242),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(96),
    [sym_escaped_identifier] = STATE(10616),
    [sym_generate_block_identifier] = STATE(18537),
    [sym__identifier] = STATE(10633),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(96),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1022),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1040),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1044),
    [anon_sym_cover] = ACTIONS(1046),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_begin] = ACTIONS(1056),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_for] = ACTIONS(1066),
    [anon_sym_initial] = ACTIONS(1068),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1074),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [53] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1254),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [54] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1256),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [55] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1258),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [56] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1260),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [57] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(58),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(58),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(58),
    [sym_checker_or_generate_item_declaration] = STATE(58),
    [sym__checker_generate_item] = STATE(58),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(58),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(58),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(58),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1202),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [58] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1262),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [59] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(60),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(60),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(60),
    [sym_checker_or_generate_item_declaration] = STATE(60),
    [sym__checker_generate_item] = STATE(60),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(60),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(60),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(60),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1264),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [60] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1266),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [61] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(62),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(62),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(62),
    [sym_checker_or_generate_item_declaration] = STATE(62),
    [sym__checker_generate_item] = STATE(62),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(62),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(62),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(62),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1268),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [62] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1270),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [63] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(71),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(71),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(71),
    [sym_checker_or_generate_item_declaration] = STATE(71),
    [sym__checker_generate_item] = STATE(71),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(71),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(71),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(71),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(986),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [64] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1272),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [65] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(66),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(66),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(66),
    [sym_checker_or_generate_item_declaration] = STATE(66),
    [sym__checker_generate_item] = STATE(66),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(66),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(66),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(66),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1226),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [66] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1274),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [67] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(68),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(68),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(68),
    [sym_checker_or_generate_item_declaration] = STATE(68),
    [sym__checker_generate_item] = STATE(68),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(68),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(68),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(68),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1276),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [68] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1278),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [69] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(70),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(70),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(70),
    [sym_checker_or_generate_item_declaration] = STATE(70),
    [sym__checker_generate_item] = STATE(70),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(70),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(70),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(70),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1280),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [70] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1282),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [71] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1284),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [72] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1286),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [73] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(74),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(74),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(74),
    [sym_checker_or_generate_item_declaration] = STATE(74),
    [sym__checker_generate_item] = STATE(74),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(74),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(74),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(74),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1248),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [74] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [75] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(79),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(79),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(79),
    [sym_checker_or_generate_item_declaration] = STATE(79),
    [sym__checker_generate_item] = STATE(79),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(79),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(79),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(79),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [76] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1292),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [77] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(78),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(78),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(78),
    [sym_checker_or_generate_item_declaration] = STATE(78),
    [sym__checker_generate_item] = STATE(78),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(78),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(78),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(78),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1294),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [78] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1296),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [79] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1298),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [80] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1300),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [81] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(83),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(83),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(83),
    [sym_checker_or_generate_item_declaration] = STATE(83),
    [sym__checker_generate_item] = STATE(83),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(83),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(83),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(83),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(932),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [82] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(86),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(86),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(86),
    [sym_checker_or_generate_item_declaration] = STATE(86),
    [sym__checker_generate_item] = STATE(86),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(86),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(86),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(86),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1302),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [83] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1304),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [84] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(53),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(53),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(53),
    [sym_checker_or_generate_item_declaration] = STATE(53),
    [sym__checker_generate_item] = STATE(53),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(53),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(53),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(53),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1306),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [85] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(85),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(85),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(85),
    [sym_checker_or_generate_item_declaration] = STATE(85),
    [sym__checker_generate_item] = STATE(85),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(85),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(85),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(85),
    [sym_simple_identifier] = ACTIONS(1308),
    [anon_sym_wire] = ACTIONS(1311),
    [anon_sym_tri] = ACTIONS(1311),
    [anon_sym_tri0] = ACTIONS(1311),
    [anon_sym_tri1] = ACTIONS(1311),
    [anon_sym_wand] = ACTIONS(1311),
    [anon_sym_triand] = ACTIONS(1311),
    [anon_sym_wor] = ACTIONS(1311),
    [anon_sym_trior] = ACTIONS(1311),
    [anon_sym_trireg] = ACTIONS(1311),
    [anon_sym_uwire] = ACTIONS(1311),
    [anon_sym_SEMI] = ACTIONS(1314),
    [anon_sym_extern] = ACTIONS(1317),
    [anon_sym_interface] = ACTIONS(1320),
    [anon_sym_checker] = ACTIONS(1323),
    [anon_sym_virtual] = ACTIONS(1326),
    [anon_sym_class] = ACTIONS(1329),
    [anon_sym_type] = ACTIONS(1332),
    [anon_sym_DOLLARfatal] = ACTIONS(1335),
    [anon_sym_DOLLARerror] = ACTIONS(1338),
    [anon_sym_DOLLARwarning] = ACTIONS(1338),
    [anon_sym_DOLLARinfo] = ACTIONS(1338),
    [anon_sym_default] = ACTIONS(1341),
    [anon_sym_clocking] = ACTIONS(1344),
    [anon_sym_defparam] = ACTIONS(1347),
    [anon_sym_bind] = ACTIONS(1350),
    [anon_sym_rand] = ACTIONS(1353),
    [anon_sym_const] = ACTIONS(1356),
    [anon_sym_function] = ACTIONS(1359),
    [anon_sym_static] = ACTIONS(1362),
    [anon_sym_constraint] = ACTIONS(1365),
    [anon_sym_if] = ACTIONS(1368),
    [anon_sym_LBRACK] = ACTIONS(1371),
    [anon_sym_localparam] = ACTIONS(1374),
    [anon_sym_parameter] = ACTIONS(1377),
    [anon_sym_var] = ACTIONS(1380),
    [anon_sym_import] = ACTIONS(1383),
    [anon_sym_export] = ACTIONS(1386),
    [anon_sym_genvar] = ACTIONS(1389),
    [anon_sym_interconnect] = ACTIONS(1392),
    [anon_sym_typedef] = ACTIONS(1395),
    [anon_sym_enum] = ACTIONS(1398),
    [anon_sym_struct] = ACTIONS(1401),
    [anon_sym_union] = ACTIONS(1404),
    [anon_sym_nettype] = ACTIONS(1407),
    [anon_sym_automatic] = ACTIONS(1410),
    [anon_sym_string] = ACTIONS(1413),
    [anon_sym_chandle] = ACTIONS(1413),
    [anon_sym_event] = ACTIONS(1413),
    [anon_sym_byte] = ACTIONS(1416),
    [anon_sym_shortint] = ACTIONS(1416),
    [anon_sym_int] = ACTIONS(1416),
    [anon_sym_longint] = ACTIONS(1416),
    [anon_sym_integer] = ACTIONS(1416),
    [anon_sym_time] = ACTIONS(1416),
    [anon_sym_bit] = ACTIONS(1419),
    [anon_sym_logic] = ACTIONS(1419),
    [anon_sym_reg] = ACTIONS(1419),
    [anon_sym_shortreal] = ACTIONS(1422),
    [anon_sym_real] = ACTIONS(1422),
    [anon_sym_realtime] = ACTIONS(1422),
    [anon_sym_supply0] = ACTIONS(1311),
    [anon_sym_supply1] = ACTIONS(1311),
    [anon_sym_signed] = ACTIONS(1425),
    [anon_sym_unsigned] = ACTIONS(1425),
    [anon_sym_task] = ACTIONS(1428),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_property] = ACTIONS(1434),
    [anon_sym_assume] = ACTIONS(1437),
    [anon_sym_cover] = ACTIONS(1440),
    [anon_sym_sequence] = ACTIONS(1443),
    [anon_sym_restrict] = ACTIONS(1446),
    [anon_sym_not] = ACTIONS(1449),
    [anon_sym_or] = ACTIONS(1452),
    [anon_sym_and] = ACTIONS(1452),
    [anon_sym_case] = ACTIONS(1455),
    [anon_sym_always] = ACTIONS(1458),
    [anon_sym_covergroup] = ACTIONS(1461),
    [anon_sym_end] = ACTIONS(1464),
    [anon_sym_let] = ACTIONS(1466),
    [anon_sym_pulldown] = ACTIONS(1469),
    [anon_sym_pullup] = ACTIONS(1472),
    [anon_sym_cmos] = ACTIONS(1475),
    [anon_sym_rcmos] = ACTIONS(1475),
    [anon_sym_bufif0] = ACTIONS(1478),
    [anon_sym_bufif1] = ACTIONS(1478),
    [anon_sym_notif0] = ACTIONS(1478),
    [anon_sym_notif1] = ACTIONS(1478),
    [anon_sym_nmos] = ACTIONS(1481),
    [anon_sym_pmos] = ACTIONS(1481),
    [anon_sym_rnmos] = ACTIONS(1481),
    [anon_sym_rpmos] = ACTIONS(1481),
    [anon_sym_nand] = ACTIONS(1452),
    [anon_sym_nor] = ACTIONS(1452),
    [anon_sym_xor] = ACTIONS(1452),
    [anon_sym_xnor] = ACTIONS(1452),
    [anon_sym_buf] = ACTIONS(1449),
    [anon_sym_tranif0] = ACTIONS(1484),
    [anon_sym_tranif1] = ACTIONS(1484),
    [anon_sym_rtranif1] = ACTIONS(1484),
    [anon_sym_rtranif0] = ACTIONS(1484),
    [anon_sym_tran] = ACTIONS(1487),
    [anon_sym_rtran] = ACTIONS(1487),
    [anon_sym_generate] = ACTIONS(1490),
    [anon_sym_for] = ACTIONS(1493),
    [anon_sym_initial] = ACTIONS(1496),
    [anon_sym_assign] = ACTIONS(1499),
    [anon_sym_alias] = ACTIONS(1502),
    [anon_sym_always_comb] = ACTIONS(1458),
    [anon_sym_always_latch] = ACTIONS(1458),
    [anon_sym_always_ff] = ACTIONS(1458),
    [anon_sym_final] = ACTIONS(1505),
    [anon_sym_global] = ACTIONS(1508),
    [anon_sym_LPAREN_STAR] = ACTIONS(1511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1514),
    [anon_sym_DOLLARunit] = ACTIONS(1517),
  },
  [86] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1520),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [87] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(87),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(87),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(87),
    [sym_checker_or_generate_item_declaration] = STATE(87),
    [sym__checker_generate_item] = STATE(87),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(87),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(87),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(87),
    [sym_simple_identifier] = ACTIONS(1308),
    [anon_sym_wire] = ACTIONS(1311),
    [anon_sym_tri] = ACTIONS(1311),
    [anon_sym_tri0] = ACTIONS(1311),
    [anon_sym_tri1] = ACTIONS(1311),
    [anon_sym_wand] = ACTIONS(1311),
    [anon_sym_triand] = ACTIONS(1311),
    [anon_sym_wor] = ACTIONS(1311),
    [anon_sym_trior] = ACTIONS(1311),
    [anon_sym_trireg] = ACTIONS(1311),
    [anon_sym_uwire] = ACTIONS(1311),
    [anon_sym_SEMI] = ACTIONS(1522),
    [anon_sym_extern] = ACTIONS(1525),
    [anon_sym_interface] = ACTIONS(1528),
    [anon_sym_checker] = ACTIONS(1531),
    [anon_sym_virtual] = ACTIONS(1534),
    [anon_sym_class] = ACTIONS(1537),
    [anon_sym_type] = ACTIONS(1332),
    [anon_sym_DOLLARfatal] = ACTIONS(1540),
    [anon_sym_DOLLARerror] = ACTIONS(1543),
    [anon_sym_DOLLARwarning] = ACTIONS(1543),
    [anon_sym_DOLLARinfo] = ACTIONS(1543),
    [anon_sym_default] = ACTIONS(1546),
    [anon_sym_clocking] = ACTIONS(1549),
    [anon_sym_defparam] = ACTIONS(1552),
    [anon_sym_bind] = ACTIONS(1555),
    [anon_sym_rand] = ACTIONS(1558),
    [anon_sym_const] = ACTIONS(1561),
    [anon_sym_function] = ACTIONS(1564),
    [anon_sym_static] = ACTIONS(1567),
    [anon_sym_constraint] = ACTIONS(1570),
    [anon_sym_if] = ACTIONS(1573),
    [anon_sym_LBRACK] = ACTIONS(1371),
    [anon_sym_localparam] = ACTIONS(1374),
    [anon_sym_parameter] = ACTIONS(1377),
    [anon_sym_var] = ACTIONS(1576),
    [anon_sym_import] = ACTIONS(1579),
    [anon_sym_export] = ACTIONS(1582),
    [anon_sym_genvar] = ACTIONS(1585),
    [anon_sym_interconnect] = ACTIONS(1588),
    [anon_sym_typedef] = ACTIONS(1591),
    [anon_sym_enum] = ACTIONS(1398),
    [anon_sym_struct] = ACTIONS(1401),
    [anon_sym_union] = ACTIONS(1404),
    [anon_sym_nettype] = ACTIONS(1594),
    [anon_sym_automatic] = ACTIONS(1410),
    [anon_sym_string] = ACTIONS(1413),
    [anon_sym_chandle] = ACTIONS(1413),
    [anon_sym_event] = ACTIONS(1413),
    [anon_sym_byte] = ACTIONS(1416),
    [anon_sym_shortint] = ACTIONS(1416),
    [anon_sym_int] = ACTIONS(1416),
    [anon_sym_longint] = ACTIONS(1416),
    [anon_sym_integer] = ACTIONS(1416),
    [anon_sym_time] = ACTIONS(1416),
    [anon_sym_bit] = ACTIONS(1419),
    [anon_sym_logic] = ACTIONS(1419),
    [anon_sym_reg] = ACTIONS(1419),
    [anon_sym_shortreal] = ACTIONS(1422),
    [anon_sym_real] = ACTIONS(1422),
    [anon_sym_realtime] = ACTIONS(1422),
    [anon_sym_supply0] = ACTIONS(1311),
    [anon_sym_supply1] = ACTIONS(1311),
    [anon_sym_signed] = ACTIONS(1425),
    [anon_sym_unsigned] = ACTIONS(1425),
    [anon_sym_task] = ACTIONS(1597),
    [anon_sym_assert] = ACTIONS(1600),
    [anon_sym_property] = ACTIONS(1603),
    [anon_sym_assume] = ACTIONS(1606),
    [anon_sym_cover] = ACTIONS(1609),
    [anon_sym_sequence] = ACTIONS(1612),
    [anon_sym_restrict] = ACTIONS(1615),
    [anon_sym_not] = ACTIONS(1449),
    [anon_sym_or] = ACTIONS(1452),
    [anon_sym_and] = ACTIONS(1452),
    [anon_sym_case] = ACTIONS(1618),
    [anon_sym_always] = ACTIONS(1458),
    [anon_sym_covergroup] = ACTIONS(1621),
    [anon_sym_let] = ACTIONS(1624),
    [anon_sym_pulldown] = ACTIONS(1627),
    [anon_sym_pullup] = ACTIONS(1630),
    [anon_sym_cmos] = ACTIONS(1475),
    [anon_sym_rcmos] = ACTIONS(1475),
    [anon_sym_bufif0] = ACTIONS(1478),
    [anon_sym_bufif1] = ACTIONS(1478),
    [anon_sym_notif0] = ACTIONS(1478),
    [anon_sym_notif1] = ACTIONS(1478),
    [anon_sym_nmos] = ACTIONS(1481),
    [anon_sym_pmos] = ACTIONS(1481),
    [anon_sym_rnmos] = ACTIONS(1481),
    [anon_sym_rpmos] = ACTIONS(1481),
    [anon_sym_nand] = ACTIONS(1452),
    [anon_sym_nor] = ACTIONS(1452),
    [anon_sym_xor] = ACTIONS(1452),
    [anon_sym_xnor] = ACTIONS(1452),
    [anon_sym_buf] = ACTIONS(1449),
    [anon_sym_tranif0] = ACTIONS(1484),
    [anon_sym_tranif1] = ACTIONS(1484),
    [anon_sym_rtranif1] = ACTIONS(1484),
    [anon_sym_rtranif0] = ACTIONS(1484),
    [anon_sym_tran] = ACTIONS(1487),
    [anon_sym_rtran] = ACTIONS(1487),
    [anon_sym_generate] = ACTIONS(1633),
    [anon_sym_endgenerate] = ACTIONS(1464),
    [anon_sym_for] = ACTIONS(1636),
    [anon_sym_initial] = ACTIONS(1639),
    [anon_sym_assign] = ACTIONS(1642),
    [anon_sym_alias] = ACTIONS(1645),
    [anon_sym_always_comb] = ACTIONS(1458),
    [anon_sym_always_latch] = ACTIONS(1458),
    [anon_sym_always_ff] = ACTIONS(1458),
    [anon_sym_final] = ACTIONS(1648),
    [anon_sym_global] = ACTIONS(1651),
    [anon_sym_LPAREN_STAR] = ACTIONS(1511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1514),
    [anon_sym_DOLLARunit] = ACTIONS(1517),
  },
  [88] = {
    [sym_checker_declaration] = STATE(5144),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4724),
    [sym__module_common_item] = STATE(4908),
    [sym_module_or_generate_item] = STATE(54),
    [sym__module_or_generate_item_declaration] = STATE(4908),
    [sym_parameter_override] = STATE(5127),
    [sym_bind_directive] = STATE(4908),
    [sym_interface_or_generate_item] = STATE(54),
    [sym_extern_tf_declaration] = STATE(4839),
    [sym__checker_or_generate_item] = STATE(54),
    [sym_checker_or_generate_item_declaration] = STATE(54),
    [sym__checker_generate_item] = STATE(54),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4908),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(5144),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4769),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5144),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4801),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(5144),
    [sym_property_declaration] = STATE(5144),
    [sym_sequence_declaration] = STATE(5144),
    [sym_covergroup_declaration] = STATE(5144),
    [sym_let_declaration] = STATE(5144),
    [sym_gate_instantiation] = STATE(5127),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5127),
    [sym_interface_instantiation] = STATE(4908),
    [sym_program_instantiation] = STATE(4908),
    [sym_checker_instantiation] = STATE(4840),
    [sym_generate_region] = STATE(54),
    [sym_loop_generate_construct] = STATE(4724),
    [sym__conditional_generate_construct] = STATE(4724),
    [sym_if_generate_construct] = STATE(4724),
    [sym_case_generate_construct] = STATE(4724),
    [sym__generate_item] = STATE(54),
    [sym_udp_instantiation] = STATE(5127),
    [sym_continuous_assign] = STATE(4801),
    [sym_net_alias] = STATE(4908),
    [sym_initial_construct] = STATE(4801),
    [sym_always_construct] = STATE(4801),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4801),
    [sym__assertion_item] = STATE(4801),
    [sym_deferred_immediate_assertion_item] = STATE(4801),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4769),
    [sym_attribute_instance] = STATE(91),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(91),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(54),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(988),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1004),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_rand] = ACTIONS(1012),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(1064),
    [anon_sym_endgenerate] = ACTIONS(1654),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [89] = {
    [sym_checker_declaration] = STATE(5052),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(5054),
    [sym__module_common_item] = STATE(5080),
    [sym_module_or_generate_item] = STATE(76),
    [sym__module_or_generate_item_declaration] = STATE(5080),
    [sym_parameter_override] = STATE(4957),
    [sym_bind_directive] = STATE(5080),
    [sym_interface_or_generate_item] = STATE(76),
    [sym_extern_tf_declaration] = STATE(4858),
    [sym__checker_or_generate_item] = STATE(76),
    [sym_checker_or_generate_item_declaration] = STATE(76),
    [sym__checker_generate_item] = STATE(76),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(5080),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(5052),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(5108),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(5052),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(5172),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(5052),
    [sym_property_declaration] = STATE(5052),
    [sym_sequence_declaration] = STATE(5052),
    [sym_covergroup_declaration] = STATE(5052),
    [sym_let_declaration] = STATE(5052),
    [sym_gate_instantiation] = STATE(4957),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4957),
    [sym_interface_instantiation] = STATE(5080),
    [sym_program_instantiation] = STATE(5080),
    [sym_checker_instantiation] = STATE(4607),
    [sym_generate_region] = STATE(76),
    [sym_loop_generate_construct] = STATE(5054),
    [sym__conditional_generate_construct] = STATE(5054),
    [sym_if_generate_construct] = STATE(5054),
    [sym_case_generate_construct] = STATE(5054),
    [sym__generate_item] = STATE(76),
    [sym_udp_instantiation] = STATE(4957),
    [sym_continuous_assign] = STATE(5172),
    [sym_net_alias] = STATE(5080),
    [sym_initial_construct] = STATE(5172),
    [sym_always_construct] = STATE(5172),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(5172),
    [sym__assertion_item] = STATE(5172),
    [sym_deferred_immediate_assertion_item] = STATE(5172),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(5108),
    [sym_attribute_instance] = STATE(93),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(93),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_generate_region_repeat1] = STATE(76),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(862),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(880),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_rand] = ACTIONS(888),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_end] = ACTIONS(1656),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_generate] = ACTIONS(940),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [90] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1190),
    [sym__module_common_item] = STATE(1190),
    [sym__module_or_generate_item_declaration] = STATE(1190),
    [sym_parameter_override] = STATE(1241),
    [sym_bind_directive] = STATE(1190),
    [sym_extern_tf_declaration] = STATE(1215),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1190),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1190),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1190),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1241),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1241),
    [sym_interface_instantiation] = STATE(1190),
    [sym_program_instantiation] = STATE(1190),
    [sym_checker_instantiation] = STATE(1224),
    [sym_loop_generate_construct] = STATE(1190),
    [sym__conditional_generate_construct] = STATE(1190),
    [sym_if_generate_construct] = STATE(1190),
    [sym_case_generate_construct] = STATE(1190),
    [sym_udp_instantiation] = STATE(1241),
    [sym_continuous_assign] = STATE(1190),
    [sym_net_alias] = STATE(1190),
    [sym_initial_construct] = STATE(1190),
    [sym_always_construct] = STATE(1190),
    [sym_always_keyword] = STATE(4281),
    [sym_final_construct] = STATE(1190),
    [sym__assertion_item] = STATE(1190),
    [sym_deferred_immediate_assertion_item] = STATE(1190),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1190),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10646),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(964),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(966),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(968),
    [anon_sym_cover] = ACTIONS(970),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(974),
    [anon_sym_initial] = ACTIONS(976),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(978),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [91] = {
    [sym_checker_declaration] = STATE(4830),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4942),
    [sym__module_common_item] = STATE(4942),
    [sym__module_or_generate_item_declaration] = STATE(4942),
    [sym_parameter_override] = STATE(5022),
    [sym_bind_directive] = STATE(4942),
    [sym_extern_tf_declaration] = STATE(4641),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4942),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(4830),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4942),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(4830),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4942),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(4830),
    [sym_property_declaration] = STATE(4830),
    [sym_sequence_declaration] = STATE(4830),
    [sym_covergroup_declaration] = STATE(4830),
    [sym_let_declaration] = STATE(4830),
    [sym_gate_instantiation] = STATE(5022),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5022),
    [sym_interface_instantiation] = STATE(4942),
    [sym_program_instantiation] = STATE(4942),
    [sym_checker_instantiation] = STATE(4840),
    [sym_loop_generate_construct] = STATE(4942),
    [sym__conditional_generate_construct] = STATE(4942),
    [sym_if_generate_construct] = STATE(4942),
    [sym_case_generate_construct] = STATE(4942),
    [sym_udp_instantiation] = STATE(5022),
    [sym_continuous_assign] = STATE(4942),
    [sym_net_alias] = STATE(4942),
    [sym_initial_construct] = STATE(4942),
    [sym_always_construct] = STATE(4942),
    [sym_always_keyword] = STATE(4265),
    [sym_final_construct] = STATE(4942),
    [sym__assertion_item] = STATE(4942),
    [sym_deferred_immediate_assertion_item] = STATE(4942),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4942),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10658),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1658),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1660),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1078),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1080),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1082),
    [anon_sym_cover] = ACTIONS(1084),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1086),
    [anon_sym_initial] = ACTIONS(1088),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1090),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [92] = {
    [sym_checker_declaration] = STATE(6426),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6457),
    [sym__module_common_item] = STATE(6457),
    [sym__module_or_generate_item_declaration] = STATE(6457),
    [sym_parameter_override] = STATE(6455),
    [sym_bind_directive] = STATE(6457),
    [sym_extern_tf_declaration] = STATE(6445),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6457),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6426),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6457),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6426),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6457),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6426),
    [sym_property_declaration] = STATE(6426),
    [sym_sequence_declaration] = STATE(6426),
    [sym_covergroup_declaration] = STATE(6426),
    [sym_let_declaration] = STATE(6426),
    [sym_gate_instantiation] = STATE(6455),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6455),
    [sym_interface_instantiation] = STATE(6457),
    [sym_program_instantiation] = STATE(6457),
    [sym_checker_instantiation] = STATE(6394),
    [sym_loop_generate_construct] = STATE(6457),
    [sym__conditional_generate_construct] = STATE(6457),
    [sym_if_generate_construct] = STATE(6457),
    [sym_case_generate_construct] = STATE(6457),
    [sym_udp_instantiation] = STATE(6455),
    [sym_continuous_assign] = STATE(6457),
    [sym_net_alias] = STATE(6457),
    [sym_initial_construct] = STATE(6457),
    [sym_always_construct] = STATE(6457),
    [sym_always_keyword] = STATE(4246),
    [sym_final_construct] = STATE(6457),
    [sym__assertion_item] = STATE(6457),
    [sym_deferred_immediate_assertion_item] = STATE(6457),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6457),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10648),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1662),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1664),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1126),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1144),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1148),
    [anon_sym_cover] = ACTIONS(1150),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1170),
    [anon_sym_initial] = ACTIONS(1172),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1178),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [93] = {
    [sym_checker_declaration] = STATE(4815),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(4728),
    [sym__module_common_item] = STATE(4728),
    [sym__module_or_generate_item_declaration] = STATE(4728),
    [sym_parameter_override] = STATE(4712),
    [sym_bind_directive] = STATE(4728),
    [sym_extern_tf_declaration] = STATE(4611),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(4728),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(4815),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(4728),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(4815),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(4728),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(4815),
    [sym_property_declaration] = STATE(4815),
    [sym_sequence_declaration] = STATE(4815),
    [sym_covergroup_declaration] = STATE(4815),
    [sym_let_declaration] = STATE(4815),
    [sym_gate_instantiation] = STATE(4712),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4712),
    [sym_interface_instantiation] = STATE(4728),
    [sym_program_instantiation] = STATE(4728),
    [sym_checker_instantiation] = STATE(4607),
    [sym_loop_generate_construct] = STATE(4728),
    [sym__conditional_generate_construct] = STATE(4728),
    [sym_if_generate_construct] = STATE(4728),
    [sym_case_generate_construct] = STATE(4728),
    [sym_udp_instantiation] = STATE(4712),
    [sym_continuous_assign] = STATE(4728),
    [sym_net_alias] = STATE(4728),
    [sym_initial_construct] = STATE(4728),
    [sym_always_construct] = STATE(4728),
    [sym_always_keyword] = STATE(4273),
    [sym_final_construct] = STATE(4728),
    [sym__assertion_item] = STATE(4728),
    [sym_deferred_immediate_assertion_item] = STATE(4728),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(4728),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10634),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1666),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(1668),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(916),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(920),
    [anon_sym_cover] = ACTIONS(922),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(942),
    [anon_sym_initial] = ACTIONS(944),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(950),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [94] = {
    [sym_checker_declaration] = STATE(9975),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(10020),
    [sym__module_common_item] = STATE(10020),
    [sym__module_or_generate_item_declaration] = STATE(10020),
    [sym_parameter_override] = STATE(10395),
    [sym_bind_directive] = STATE(10020),
    [sym_extern_tf_declaration] = STATE(9994),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(10020),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9975),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(10020),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9975),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(10020),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9975),
    [sym_property_declaration] = STATE(9975),
    [sym_sequence_declaration] = STATE(9975),
    [sym_covergroup_declaration] = STATE(9975),
    [sym_let_declaration] = STATE(9975),
    [sym_gate_instantiation] = STATE(10395),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(10395),
    [sym_interface_instantiation] = STATE(10020),
    [sym_program_instantiation] = STATE(10020),
    [sym_checker_instantiation] = STATE(10149),
    [sym_loop_generate_construct] = STATE(10020),
    [sym__conditional_generate_construct] = STATE(10020),
    [sym_if_generate_construct] = STATE(10020),
    [sym_case_generate_construct] = STATE(10020),
    [sym_udp_instantiation] = STATE(10395),
    [sym_continuous_assign] = STATE(10020),
    [sym_net_alias] = STATE(10020),
    [sym_initial_construct] = STATE(10020),
    [sym_always_construct] = STATE(10020),
    [sym_always_keyword] = STATE(4261),
    [sym_final_construct] = STATE(10020),
    [sym__assertion_item] = STATE(10020),
    [sym_deferred_immediate_assertion_item] = STATE(10020),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(10020),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10644),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1670),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(1672),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(824),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(828),
    [anon_sym_cover] = ACTIONS(830),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(850),
    [anon_sym_initial] = ACTIONS(852),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(858),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [95] = {
    [sym_checker_declaration] = STATE(4815),
    [sym_class_declaration] = STATE(4815),
    [sym_interface_class_declaration] = STATE(4815),
    [sym_elaboration_system_task] = STATE(4728),
    [sym__module_common_item] = STATE(4728),
    [sym__module_or_generate_item_declaration] = STATE(4728),
    [sym_parameter_override] = STATE(4712),
    [sym_bind_directive] = STATE(4728),
    [sym_extern_tf_declaration] = STATE(4611),
    [sym_class_constructor_declaration] = STATE(4815),
    [sym_extern_constraint_declaration] = STATE(4815),
    [sym_package_or_generate_item_declaration] = STATE(4728),
    [sym_local_parameter_declaration] = STATE(17747),
    [sym_parameter_declaration] = STATE(17747),
    [sym__any_parameter_declaration] = STATE(17747),
    [sym_data_declaration] = STATE(4815),
    [sym_package_import_declaration] = STATE(4971),
    [sym_genvar_declaration] = STATE(4728),
    [sym_net_declaration] = STATE(4815),
    [sym_type_declaration] = STATE(4971),
    [sym_net_type_declaration] = STATE(4971),
    [sym_lifetime] = STATE(8385),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12718),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8108),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18130),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(4815),
    [sym_dpi_import_export] = STATE(4815),
    [sym_task_declaration] = STATE(4815),
    [sym_overload_declaration] = STATE(4815),
    [sym_concurrent_assertion_item] = STATE(4728),
    [sym__concurrent_assertion_statement] = STATE(4607),
    [sym_assert_property_statement] = STATE(4607),
    [sym_assume_property_statement] = STATE(4607),
    [sym_cover_property_statement] = STATE(4607),
    [sym_cover_sequence_statement] = STATE(4607),
    [sym_restrict_property_statement] = STATE(4607),
    [sym__assertion_item_declaration] = STATE(4815),
    [sym_property_declaration] = STATE(4815),
    [sym_sequence_declaration] = STATE(4815),
    [sym_covergroup_declaration] = STATE(4815),
    [sym_let_declaration] = STATE(4815),
    [sym_gate_instantiation] = STATE(4712),
    [sym_cmos_switchtype] = STATE(11773),
    [sym_enable_gatetype] = STATE(11655),
    [sym_mos_switchtype] = STATE(11777),
    [sym_n_input_gatetype] = STATE(11659),
    [sym_n_output_gatetype] = STATE(11660),
    [sym_pass_en_switchtype] = STATE(11703),
    [sym_pass_switchtype] = STATE(12261),
    [sym_module_instantiation] = STATE(4712),
    [sym_interface_instantiation] = STATE(4728),
    [sym_program_instantiation] = STATE(4728),
    [sym_checker_instantiation] = STATE(4607),
    [sym_loop_generate_construct] = STATE(4728),
    [sym__conditional_generate_construct] = STATE(4728),
    [sym_if_generate_construct] = STATE(4728),
    [sym_case_generate_construct] = STATE(4728),
    [sym_udp_instantiation] = STATE(4712),
    [sym_continuous_assign] = STATE(4728),
    [sym_net_alias] = STATE(4728),
    [sym_initial_construct] = STATE(4728),
    [sym_always_construct] = STATE(4728),
    [sym_always_keyword] = STATE(4249),
    [sym_final_construct] = STATE(4728),
    [sym__assertion_item] = STATE(4728),
    [sym_deferred_immediate_assertion_item] = STATE(4728),
    [sym__deferred_immediate_assertion_statement] = STATE(4609),
    [sym_deferred_immediate_assert_statement] = STATE(4609),
    [sym_deferred_immediate_assume_statement] = STATE(4609),
    [sym_deferred_immediate_cover_statement] = STATE(4609),
    [sym_clocking_declaration] = STATE(4728),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10652),
    [sym_package_scope] = STATE(15055),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1666),
    [anon_sym_extern] = ACTIONS(866),
    [anon_sym_interface] = ACTIONS(868),
    [anon_sym_checker] = ACTIONS(870),
    [anon_sym_virtual] = ACTIONS(872),
    [anon_sym_class] = ACTIONS(874),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(876),
    [anon_sym_DOLLARerror] = ACTIONS(878),
    [anon_sym_DOLLARwarning] = ACTIONS(878),
    [anon_sym_DOLLARinfo] = ACTIONS(878),
    [anon_sym_default] = ACTIONS(1668),
    [anon_sym_clocking] = ACTIONS(882),
    [anon_sym_defparam] = ACTIONS(884),
    [anon_sym_bind] = ACTIONS(886),
    [anon_sym_const] = ACTIONS(890),
    [anon_sym_function] = ACTIONS(892),
    [anon_sym_static] = ACTIONS(894),
    [anon_sym_constraint] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(1228),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(900),
    [anon_sym_import] = ACTIONS(902),
    [anon_sym_export] = ACTIONS(904),
    [anon_sym_genvar] = ACTIONS(906),
    [anon_sym_interconnect] = ACTIONS(908),
    [anon_sym_typedef] = ACTIONS(910),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(912),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(914),
    [anon_sym_assert] = ACTIONS(1230),
    [anon_sym_property] = ACTIONS(918),
    [anon_sym_assume] = ACTIONS(1232),
    [anon_sym_cover] = ACTIONS(1234),
    [anon_sym_sequence] = ACTIONS(924),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(928),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(930),
    [anon_sym_let] = ACTIONS(934),
    [anon_sym_pulldown] = ACTIONS(936),
    [anon_sym_pullup] = ACTIONS(938),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1236),
    [anon_sym_initial] = ACTIONS(1238),
    [anon_sym_assign] = ACTIONS(946),
    [anon_sym_alias] = ACTIONS(948),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1240),
    [anon_sym_global] = ACTIONS(952),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [96] = {
    [sym_checker_declaration] = STATE(4830),
    [sym_class_declaration] = STATE(4830),
    [sym_interface_class_declaration] = STATE(4830),
    [sym_elaboration_system_task] = STATE(4942),
    [sym__module_common_item] = STATE(4942),
    [sym__module_or_generate_item_declaration] = STATE(4942),
    [sym_parameter_override] = STATE(5022),
    [sym_bind_directive] = STATE(4942),
    [sym_extern_tf_declaration] = STATE(4641),
    [sym_class_constructor_declaration] = STATE(4830),
    [sym_extern_constraint_declaration] = STATE(4830),
    [sym_package_or_generate_item_declaration] = STATE(4942),
    [sym_local_parameter_declaration] = STATE(18702),
    [sym_parameter_declaration] = STATE(18702),
    [sym__any_parameter_declaration] = STATE(18702),
    [sym_data_declaration] = STATE(4830),
    [sym_package_import_declaration] = STATE(4831),
    [sym_genvar_declaration] = STATE(4942),
    [sym_net_declaration] = STATE(4830),
    [sym_type_declaration] = STATE(4831),
    [sym_net_type_declaration] = STATE(4831),
    [sym_lifetime] = STATE(8399),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12547),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8063),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19332),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(4830),
    [sym_dpi_import_export] = STATE(4830),
    [sym_task_declaration] = STATE(4830),
    [sym_overload_declaration] = STATE(4830),
    [sym_concurrent_assertion_item] = STATE(4942),
    [sym__concurrent_assertion_statement] = STATE(4840),
    [sym_assert_property_statement] = STATE(4840),
    [sym_assume_property_statement] = STATE(4840),
    [sym_cover_property_statement] = STATE(4840),
    [sym_cover_sequence_statement] = STATE(4840),
    [sym_restrict_property_statement] = STATE(4840),
    [sym__assertion_item_declaration] = STATE(4830),
    [sym_property_declaration] = STATE(4830),
    [sym_sequence_declaration] = STATE(4830),
    [sym_covergroup_declaration] = STATE(4830),
    [sym_let_declaration] = STATE(4830),
    [sym_gate_instantiation] = STATE(5022),
    [sym_cmos_switchtype] = STATE(11667),
    [sym_enable_gatetype] = STATE(11532),
    [sym_mos_switchtype] = STATE(11670),
    [sym_n_input_gatetype] = STATE(11534),
    [sym_n_output_gatetype] = STATE(11535),
    [sym_pass_en_switchtype] = STATE(11675),
    [sym_pass_switchtype] = STATE(12442),
    [sym_module_instantiation] = STATE(5022),
    [sym_interface_instantiation] = STATE(4942),
    [sym_program_instantiation] = STATE(4942),
    [sym_checker_instantiation] = STATE(4840),
    [sym_loop_generate_construct] = STATE(4942),
    [sym__conditional_generate_construct] = STATE(4942),
    [sym_if_generate_construct] = STATE(4942),
    [sym_case_generate_construct] = STATE(4942),
    [sym_udp_instantiation] = STATE(5022),
    [sym_continuous_assign] = STATE(4942),
    [sym_net_alias] = STATE(4942),
    [sym_initial_construct] = STATE(4942),
    [sym_always_construct] = STATE(4942),
    [sym_always_keyword] = STATE(4242),
    [sym_final_construct] = STATE(4942),
    [sym__assertion_item] = STATE(4942),
    [sym_deferred_immediate_assertion_item] = STATE(4942),
    [sym__deferred_immediate_assertion_statement] = STATE(4860),
    [sym_deferred_immediate_assert_statement] = STATE(4860),
    [sym_deferred_immediate_assume_statement] = STATE(4860),
    [sym_deferred_immediate_cover_statement] = STATE(4860),
    [sym_clocking_declaration] = STATE(4942),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10657),
    [sym_package_scope] = STATE(14999),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1658),
    [anon_sym_extern] = ACTIONS(990),
    [anon_sym_interface] = ACTIONS(992),
    [anon_sym_checker] = ACTIONS(994),
    [anon_sym_virtual] = ACTIONS(996),
    [anon_sym_class] = ACTIONS(998),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1000),
    [anon_sym_DOLLARerror] = ACTIONS(1002),
    [anon_sym_DOLLARwarning] = ACTIONS(1002),
    [anon_sym_DOLLARinfo] = ACTIONS(1002),
    [anon_sym_default] = ACTIONS(1660),
    [anon_sym_clocking] = ACTIONS(1006),
    [anon_sym_defparam] = ACTIONS(1008),
    [anon_sym_bind] = ACTIONS(1010),
    [anon_sym_const] = ACTIONS(1014),
    [anon_sym_function] = ACTIONS(1016),
    [anon_sym_static] = ACTIONS(1018),
    [anon_sym_constraint] = ACTIONS(1020),
    [anon_sym_if] = ACTIONS(1022),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1024),
    [anon_sym_import] = ACTIONS(1026),
    [anon_sym_export] = ACTIONS(1028),
    [anon_sym_genvar] = ACTIONS(1030),
    [anon_sym_interconnect] = ACTIONS(1032),
    [anon_sym_typedef] = ACTIONS(1034),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1036),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1038),
    [anon_sym_assert] = ACTIONS(1040),
    [anon_sym_property] = ACTIONS(1042),
    [anon_sym_assume] = ACTIONS(1044),
    [anon_sym_cover] = ACTIONS(1046),
    [anon_sym_sequence] = ACTIONS(1048),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1052),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1054),
    [anon_sym_let] = ACTIONS(1058),
    [anon_sym_pulldown] = ACTIONS(1060),
    [anon_sym_pullup] = ACTIONS(1062),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1066),
    [anon_sym_initial] = ACTIONS(1068),
    [anon_sym_assign] = ACTIONS(1070),
    [anon_sym_alias] = ACTIONS(1072),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1074),
    [anon_sym_global] = ACTIONS(1076),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [97] = {
    [sym_checker_declaration] = STATE(9975),
    [sym_class_declaration] = STATE(9975),
    [sym_interface_class_declaration] = STATE(9975),
    [sym_elaboration_system_task] = STATE(10020),
    [sym__module_common_item] = STATE(10020),
    [sym__module_or_generate_item_declaration] = STATE(10020),
    [sym_parameter_override] = STATE(10395),
    [sym_bind_directive] = STATE(10020),
    [sym_extern_tf_declaration] = STATE(9994),
    [sym_class_constructor_declaration] = STATE(9975),
    [sym_extern_constraint_declaration] = STATE(9975),
    [sym_package_or_generate_item_declaration] = STATE(10020),
    [sym_local_parameter_declaration] = STATE(20000),
    [sym_parameter_declaration] = STATE(20000),
    [sym__any_parameter_declaration] = STATE(20000),
    [sym_data_declaration] = STATE(9975),
    [sym_package_import_declaration] = STATE(9765),
    [sym_genvar_declaration] = STATE(10020),
    [sym_net_declaration] = STATE(9975),
    [sym_type_declaration] = STATE(9765),
    [sym_net_type_declaration] = STATE(9765),
    [sym_lifetime] = STATE(8396),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12735),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8046),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19887),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(9975),
    [sym_dpi_import_export] = STATE(9975),
    [sym_task_declaration] = STATE(9975),
    [sym_overload_declaration] = STATE(9975),
    [sym_concurrent_assertion_item] = STATE(10020),
    [sym__concurrent_assertion_statement] = STATE(10149),
    [sym_assert_property_statement] = STATE(10149),
    [sym_assume_property_statement] = STATE(10149),
    [sym_cover_property_statement] = STATE(10149),
    [sym_cover_sequence_statement] = STATE(10149),
    [sym_restrict_property_statement] = STATE(10149),
    [sym__assertion_item_declaration] = STATE(9975),
    [sym_property_declaration] = STATE(9975),
    [sym_sequence_declaration] = STATE(9975),
    [sym_covergroup_declaration] = STATE(9975),
    [sym_let_declaration] = STATE(9975),
    [sym_gate_instantiation] = STATE(10395),
    [sym_cmos_switchtype] = STATE(11679),
    [sym_enable_gatetype] = STATE(11501),
    [sym_mos_switchtype] = STATE(11686),
    [sym_n_input_gatetype] = STATE(11502),
    [sym_n_output_gatetype] = STATE(11503),
    [sym_pass_en_switchtype] = STATE(11690),
    [sym_pass_switchtype] = STATE(11989),
    [sym_module_instantiation] = STATE(10395),
    [sym_interface_instantiation] = STATE(10020),
    [sym_program_instantiation] = STATE(10020),
    [sym_checker_instantiation] = STATE(10149),
    [sym_loop_generate_construct] = STATE(10020),
    [sym__conditional_generate_construct] = STATE(10020),
    [sym_if_generate_construct] = STATE(10020),
    [sym_case_generate_construct] = STATE(10020),
    [sym_udp_instantiation] = STATE(10395),
    [sym_continuous_assign] = STATE(10020),
    [sym_net_alias] = STATE(10020),
    [sym_initial_construct] = STATE(10020),
    [sym_always_construct] = STATE(10020),
    [sym_always_keyword] = STATE(4226),
    [sym_final_construct] = STATE(10020),
    [sym__assertion_item] = STATE(10020),
    [sym_deferred_immediate_assertion_item] = STATE(10020),
    [sym__deferred_immediate_assertion_statement] = STATE(10150),
    [sym_deferred_immediate_assert_statement] = STATE(10150),
    [sym_deferred_immediate_assume_statement] = STATE(10150),
    [sym_deferred_immediate_cover_statement] = STATE(10150),
    [sym_clocking_declaration] = STATE(10020),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10654),
    [sym_package_scope] = STATE(15060),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1670),
    [anon_sym_extern] = ACTIONS(774),
    [anon_sym_interface] = ACTIONS(776),
    [anon_sym_checker] = ACTIONS(778),
    [anon_sym_virtual] = ACTIONS(780),
    [anon_sym_class] = ACTIONS(782),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(784),
    [anon_sym_DOLLARerror] = ACTIONS(786),
    [anon_sym_DOLLARwarning] = ACTIONS(786),
    [anon_sym_DOLLARinfo] = ACTIONS(786),
    [anon_sym_default] = ACTIONS(1672),
    [anon_sym_clocking] = ACTIONS(790),
    [anon_sym_defparam] = ACTIONS(792),
    [anon_sym_bind] = ACTIONS(794),
    [anon_sym_const] = ACTIONS(798),
    [anon_sym_function] = ACTIONS(800),
    [anon_sym_static] = ACTIONS(802),
    [anon_sym_constraint] = ACTIONS(804),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(808),
    [anon_sym_import] = ACTIONS(810),
    [anon_sym_export] = ACTIONS(812),
    [anon_sym_genvar] = ACTIONS(814),
    [anon_sym_interconnect] = ACTIONS(816),
    [anon_sym_typedef] = ACTIONS(818),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(820),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(822),
    [anon_sym_assert] = ACTIONS(1206),
    [anon_sym_property] = ACTIONS(826),
    [anon_sym_assume] = ACTIONS(1208),
    [anon_sym_cover] = ACTIONS(1210),
    [anon_sym_sequence] = ACTIONS(832),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(838),
    [anon_sym_let] = ACTIONS(842),
    [anon_sym_pulldown] = ACTIONS(844),
    [anon_sym_pullup] = ACTIONS(846),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1212),
    [anon_sym_initial] = ACTIONS(1214),
    [anon_sym_assign] = ACTIONS(854),
    [anon_sym_alias] = ACTIONS(856),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1216),
    [anon_sym_global] = ACTIONS(860),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [98] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1190),
    [sym__module_common_item] = STATE(1190),
    [sym__module_or_generate_item_declaration] = STATE(1190),
    [sym_parameter_override] = STATE(1241),
    [sym_bind_directive] = STATE(1190),
    [sym_extern_tf_declaration] = STATE(1215),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1190),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1190),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1190),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_gate_instantiation] = STATE(1241),
    [sym_cmos_switchtype] = STATE(11718),
    [sym_enable_gatetype] = STATE(11572),
    [sym_mos_switchtype] = STATE(11719),
    [sym_n_input_gatetype] = STATE(11573),
    [sym_n_output_gatetype] = STATE(11574),
    [sym_pass_en_switchtype] = STATE(11779),
    [sym_pass_switchtype] = STATE(12232),
    [sym_module_instantiation] = STATE(1241),
    [sym_interface_instantiation] = STATE(1190),
    [sym_program_instantiation] = STATE(1190),
    [sym_checker_instantiation] = STATE(1224),
    [sym_loop_generate_construct] = STATE(1190),
    [sym__conditional_generate_construct] = STATE(1190),
    [sym_if_generate_construct] = STATE(1190),
    [sym_case_generate_construct] = STATE(1190),
    [sym_udp_instantiation] = STATE(1241),
    [sym_continuous_assign] = STATE(1190),
    [sym_net_alias] = STATE(1190),
    [sym_initial_construct] = STATE(1190),
    [sym_always_construct] = STATE(1190),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1190),
    [sym__assertion_item] = STATE(1190),
    [sym_deferred_immediate_assertion_item] = STATE(1190),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1190),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10650),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_defparam] = ACTIONS(145),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_pulldown] = ACTIONS(171),
    [anon_sym_pullup] = ACTIONS(173),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [99] = {
    [sym_checker_declaration] = STATE(6426),
    [sym_class_declaration] = STATE(6426),
    [sym_interface_class_declaration] = STATE(6426),
    [sym_elaboration_system_task] = STATE(6457),
    [sym__module_common_item] = STATE(6457),
    [sym__module_or_generate_item_declaration] = STATE(6457),
    [sym_parameter_override] = STATE(6455),
    [sym_bind_directive] = STATE(6457),
    [sym_extern_tf_declaration] = STATE(6445),
    [sym_class_constructor_declaration] = STATE(6426),
    [sym_extern_constraint_declaration] = STATE(6426),
    [sym_package_or_generate_item_declaration] = STATE(6457),
    [sym_local_parameter_declaration] = STATE(18081),
    [sym_parameter_declaration] = STATE(18081),
    [sym__any_parameter_declaration] = STATE(18081),
    [sym_data_declaration] = STATE(6426),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6457),
    [sym_net_declaration] = STATE(6426),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8051),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6426),
    [sym_dpi_import_export] = STATE(6426),
    [sym_task_declaration] = STATE(6426),
    [sym_overload_declaration] = STATE(6426),
    [sym_concurrent_assertion_item] = STATE(6457),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6426),
    [sym_property_declaration] = STATE(6426),
    [sym_sequence_declaration] = STATE(6426),
    [sym_covergroup_declaration] = STATE(6426),
    [sym_let_declaration] = STATE(6426),
    [sym_gate_instantiation] = STATE(6455),
    [sym_cmos_switchtype] = STATE(11731),
    [sym_enable_gatetype] = STATE(11512),
    [sym_mos_switchtype] = STATE(11732),
    [sym_n_input_gatetype] = STATE(11513),
    [sym_n_output_gatetype] = STATE(11514),
    [sym_pass_en_switchtype] = STATE(11735),
    [sym_pass_switchtype] = STATE(12479),
    [sym_module_instantiation] = STATE(6455),
    [sym_interface_instantiation] = STATE(6457),
    [sym_program_instantiation] = STATE(6457),
    [sym_checker_instantiation] = STATE(6394),
    [sym_loop_generate_construct] = STATE(6457),
    [sym__conditional_generate_construct] = STATE(6457),
    [sym_if_generate_construct] = STATE(6457),
    [sym_case_generate_construct] = STATE(6457),
    [sym_udp_instantiation] = STATE(6455),
    [sym_continuous_assign] = STATE(6457),
    [sym_net_alias] = STATE(6457),
    [sym_initial_construct] = STATE(6457),
    [sym_always_construct] = STATE(6457),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(6457),
    [sym__assertion_item] = STATE(6457),
    [sym_deferred_immediate_assertion_item] = STATE(6457),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6457),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(10616),
    [sym__identifier] = STATE(10656),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(121),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(1662),
    [anon_sym_extern] = ACTIONS(1094),
    [anon_sym_interface] = ACTIONS(1096),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(1100),
    [anon_sym_class] = ACTIONS(1102),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(1664),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_defparam] = ACTIONS(1112),
    [anon_sym_bind] = ACTIONS(1114),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(1120),
    [anon_sym_static] = ACTIONS(1122),
    [anon_sym_constraint] = ACTIONS(1124),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(1130),
    [anon_sym_export] = ACTIONS(1132),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_interconnect] = ACTIONS(1136),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(1142),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_not] = ACTIONS(163),
    [anon_sym_or] = ACTIONS(165),
    [anon_sym_and] = ACTIONS(165),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_pulldown] = ACTIONS(1164),
    [anon_sym_pullup] = ACTIONS(1166),
    [anon_sym_cmos] = ACTIONS(175),
    [anon_sym_rcmos] = ACTIONS(175),
    [anon_sym_bufif0] = ACTIONS(177),
    [anon_sym_bufif1] = ACTIONS(177),
    [anon_sym_notif0] = ACTIONS(177),
    [anon_sym_notif1] = ACTIONS(177),
    [anon_sym_nmos] = ACTIONS(179),
    [anon_sym_pmos] = ACTIONS(179),
    [anon_sym_rnmos] = ACTIONS(179),
    [anon_sym_rpmos] = ACTIONS(179),
    [anon_sym_nand] = ACTIONS(165),
    [anon_sym_nor] = ACTIONS(165),
    [anon_sym_xor] = ACTIONS(165),
    [anon_sym_xnor] = ACTIONS(165),
    [anon_sym_buf] = ACTIONS(163),
    [anon_sym_tranif0] = ACTIONS(181),
    [anon_sym_tranif1] = ACTIONS(181),
    [anon_sym_rtranif1] = ACTIONS(181),
    [anon_sym_rtranif0] = ACTIONS(181),
    [anon_sym_tran] = ACTIONS(183),
    [anon_sym_rtran] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_alias] = ACTIONS(1176),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [100] = {
    [ts_builtin_sym_end] = ACTIONS(1674),
    [sym_simple_identifier] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_GT] = ACTIONS(1676),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1674),
    [anon_sym_RPAREN] = ACTIONS(1674),
    [anon_sym_COMMA] = ACTIONS(1674),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1674),
    [anon_sym_BQUOTE] = ACTIONS(1676),
    [aux_sym_id_directive_token1] = ACTIONS(1674),
    [aux_sym_id_directive_token2] = ACTIONS(1674),
    [aux_sym_id_directive_token3] = ACTIONS(1674),
    [aux_sym_id_directive_token4] = ACTIONS(1676),
    [aux_sym_zero_directive_token1] = ACTIONS(1674),
    [aux_sym_zero_directive_token2] = ACTIONS(1674),
    [aux_sym_zero_directive_token3] = ACTIONS(1674),
    [aux_sym_zero_directive_token4] = ACTIONS(1674),
    [aux_sym_zero_directive_token5] = ACTIONS(1674),
    [aux_sym_zero_directive_token6] = ACTIONS(1674),
    [aux_sym_zero_directive_token7] = ACTIONS(1674),
    [aux_sym_zero_directive_token8] = ACTIONS(1674),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1674),
    [anon_sym_SLASH] = ACTIONS(1676),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1674),
    [anon_sym_wire] = ACTIONS(1676),
    [anon_sym_tri] = ACTIONS(1676),
    [anon_sym_tri0] = ACTIONS(1676),
    [anon_sym_tri1] = ACTIONS(1676),
    [anon_sym_wand] = ACTIONS(1676),
    [anon_sym_triand] = ACTIONS(1676),
    [anon_sym_wor] = ACTIONS(1676),
    [anon_sym_trior] = ACTIONS(1676),
    [anon_sym_trireg] = ACTIONS(1676),
    [anon_sym_uwire] = ACTIONS(1676),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1674),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1674),
    [aux_sym_begin_keywords_token1] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_endmodule] = ACTIONS(1676),
    [anon_sym_COLON] = ACTIONS(1674),
    [anon_sym_extern] = ACTIONS(1676),
    [anon_sym_module] = ACTIONS(1676),
    [anon_sym_macromodule] = ACTIONS(1676),
    [anon_sym_endinterface] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_endprogram] = ACTIONS(1676),
    [anon_sym_program] = ACTIONS(1676),
    [anon_sym_checker] = ACTIONS(1676),
    [anon_sym_virtual] = ACTIONS(1676),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_package] = ACTIONS(1676),
    [anon_sym_endpackage] = ACTIONS(1676),
    [anon_sym_timeunit] = ACTIONS(1676),
    [anon_sym_timeprecision] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_DOT] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1674),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_input] = ACTIONS(1676),
    [anon_sym_output] = ACTIONS(1676),
    [anon_sym_inout] = ACTIONS(1676),
    [anon_sym_ref] = ACTIONS(1676),
    [anon_sym_DOLLARfatal] = ACTIONS(1674),
    [anon_sym_DOLLARerror] = ACTIONS(1674),
    [anon_sym_DOLLARwarning] = ACTIONS(1674),
    [anon_sym_DOLLARinfo] = ACTIONS(1674),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_clocking] = ACTIONS(1676),
    [anon_sym_iff] = ACTIONS(1676),
    [anon_sym_defparam] = ACTIONS(1676),
    [anon_sym_bind] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_constraint] = ACTIONS(1676),
    [anon_sym_u2013_GT] = ACTIONS(1674),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_RBRACK] = ACTIONS(1674),
    [anon_sym_localparam] = ACTIONS(1676),
    [anon_sym_parameter] = ACTIONS(1676),
    [anon_sym_specparam] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_genvar] = ACTIONS(1676),
    [anon_sym_interconnect] = ACTIONS(1676),
    [anon_sym_typedef] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [anon_sym_struct] = ACTIONS(1676),
    [anon_sym_union] = ACTIONS(1676),
    [anon_sym_nettype] = ACTIONS(1676),
    [anon_sym_with] = ACTIONS(1676),
    [anon_sym_automatic] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_chandle] = ACTIONS(1676),
    [anon_sym_event] = ACTIONS(1676),
    [anon_sym_byte] = ACTIONS(1676),
    [anon_sym_shortint] = ACTIONS(1676),
    [anon_sym_int] = ACTIONS(1676),
    [anon_sym_longint] = ACTIONS(1676),
    [anon_sym_integer] = ACTIONS(1676),
    [anon_sym_time] = ACTIONS(1676),
    [anon_sym_bit] = ACTIONS(1676),
    [anon_sym_logic] = ACTIONS(1676),
    [anon_sym_reg] = ACTIONS(1676),
    [anon_sym_shortreal] = ACTIONS(1676),
    [anon_sym_real] = ACTIONS(1676),
    [anon_sym_realtime] = ACTIONS(1676),
    [anon_sym_supply0] = ACTIONS(1676),
    [anon_sym_supply1] = ACTIONS(1676),
    [anon_sym_signed] = ACTIONS(1676),
    [anon_sym_unsigned] = ACTIONS(1676),
    [anon_sym_task] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1674),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_modport] = ACTIONS(1676),
    [anon_sym_assert] = ACTIONS(1676),
    [anon_sym_property] = ACTIONS(1676),
    [anon_sym_assume] = ACTIONS(1676),
    [anon_sym_cover] = ACTIONS(1676),
    [anon_sym_sequence] = ACTIONS(1676),
    [anon_sym_restrict] = ACTIONS(1676),
    [anon_sym_not] = ACTIONS(1676),
    [anon_sym_or] = ACTIONS(1676),
    [anon_sym_and] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_always] = ACTIONS(1676),
    [anon_sym_dist] = ACTIONS(1676),
    [anon_sym_covergroup] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1676),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_matches] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_pulldown] = ACTIONS(1676),
    [anon_sym_pullup] = ACTIONS(1676),
    [anon_sym_cmos] = ACTIONS(1676),
    [anon_sym_rcmos] = ACTIONS(1676),
    [anon_sym_bufif0] = ACTIONS(1676),
    [anon_sym_bufif1] = ACTIONS(1676),
    [anon_sym_notif0] = ACTIONS(1676),
    [anon_sym_notif1] = ACTIONS(1676),
    [anon_sym_nmos] = ACTIONS(1676),
    [anon_sym_pmos] = ACTIONS(1676),
    [anon_sym_rnmos] = ACTIONS(1676),
    [anon_sym_rpmos] = ACTIONS(1676),
    [anon_sym_nand] = ACTIONS(1676),
    [anon_sym_nor] = ACTIONS(1676),
    [anon_sym_xor] = ACTIONS(1676),
    [anon_sym_xnor] = ACTIONS(1676),
    [anon_sym_buf] = ACTIONS(1676),
    [anon_sym_tranif0] = ACTIONS(1676),
    [anon_sym_tranif1] = ACTIONS(1676),
    [anon_sym_rtranif1] = ACTIONS(1676),
    [anon_sym_rtranif0] = ACTIONS(1676),
    [anon_sym_tran] = ACTIONS(1676),
    [anon_sym_rtran] = ACTIONS(1676),
    [anon_sym_generate] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_primitive] = ACTIONS(1676),
    [anon_sym_initial] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_assign] = ACTIONS(1676),
    [anon_sym_alias] = ACTIONS(1676),
    [anon_sym_always_comb] = ACTIONS(1676),
    [anon_sym_always_latch] = ACTIONS(1676),
    [anon_sym_always_ff] = ACTIONS(1676),
    [anon_sym_final] = ACTIONS(1676),
    [anon_sym_DASH_GT] = ACTIONS(1674),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1674),
    [anon_sym_inside] = ACTIONS(1676),
    [anon_sym_global] = ACTIONS(1676),
    [anon_sym_specify] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_LT_LT] = ACTIONS(1676),
    [anon_sym_QMARK] = ACTIONS(1674),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1676),
    [anon_sym_CARET_TILDE] = ACTIONS(1674),
    [anon_sym_TILDE_CARET] = ACTIONS(1674),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT_LT] = ACTIONS(1674),
    [anon_sym_LT_DASH_GT] = ACTIONS(1674),
    [anon_sym_LPAREN_STAR] = ACTIONS(1674),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1674),
    [anon_sym_DOLLARunit] = ACTIONS(1674),
  },
  [101] = {
    [ts_builtin_sym_end] = ACTIONS(1678),
    [sym_simple_identifier] = ACTIONS(1680),
    [anon_sym_LT] = ACTIONS(1680),
    [anon_sym_GT] = ACTIONS(1680),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1678),
    [anon_sym_RPAREN] = ACTIONS(1678),
    [anon_sym_COMMA] = ACTIONS(1678),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1678),
    [anon_sym_BQUOTE] = ACTIONS(1680),
    [aux_sym_id_directive_token1] = ACTIONS(1678),
    [aux_sym_id_directive_token2] = ACTIONS(1678),
    [aux_sym_id_directive_token3] = ACTIONS(1678),
    [aux_sym_id_directive_token4] = ACTIONS(1680),
    [aux_sym_zero_directive_token1] = ACTIONS(1678),
    [aux_sym_zero_directive_token2] = ACTIONS(1678),
    [aux_sym_zero_directive_token3] = ACTIONS(1678),
    [aux_sym_zero_directive_token4] = ACTIONS(1678),
    [aux_sym_zero_directive_token5] = ACTIONS(1678),
    [aux_sym_zero_directive_token6] = ACTIONS(1678),
    [aux_sym_zero_directive_token7] = ACTIONS(1678),
    [aux_sym_zero_directive_token8] = ACTIONS(1678),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1678),
    [anon_sym_SLASH] = ACTIONS(1680),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1678),
    [anon_sym_wire] = ACTIONS(1680),
    [anon_sym_tri] = ACTIONS(1680),
    [anon_sym_tri0] = ACTIONS(1680),
    [anon_sym_tri1] = ACTIONS(1680),
    [anon_sym_wand] = ACTIONS(1680),
    [anon_sym_triand] = ACTIONS(1680),
    [anon_sym_wor] = ACTIONS(1680),
    [anon_sym_trior] = ACTIONS(1680),
    [anon_sym_trireg] = ACTIONS(1680),
    [anon_sym_uwire] = ACTIONS(1680),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1678),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1678),
    [aux_sym_begin_keywords_token1] = ACTIONS(1678),
    [anon_sym_SEMI] = ACTIONS(1678),
    [anon_sym_endmodule] = ACTIONS(1680),
    [anon_sym_COLON] = ACTIONS(1678),
    [anon_sym_extern] = ACTIONS(1680),
    [anon_sym_module] = ACTIONS(1680),
    [anon_sym_macromodule] = ACTIONS(1680),
    [anon_sym_endinterface] = ACTIONS(1680),
    [anon_sym_interface] = ACTIONS(1680),
    [anon_sym_endprogram] = ACTIONS(1680),
    [anon_sym_program] = ACTIONS(1680),
    [anon_sym_checker] = ACTIONS(1680),
    [anon_sym_virtual] = ACTIONS(1680),
    [anon_sym_class] = ACTIONS(1680),
    [anon_sym_package] = ACTIONS(1680),
    [anon_sym_endpackage] = ACTIONS(1680),
    [anon_sym_timeunit] = ACTIONS(1680),
    [anon_sym_timeprecision] = ACTIONS(1680),
    [anon_sym_type] = ACTIONS(1680),
    [anon_sym_DOT] = ACTIONS(1678),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_RBRACE] = ACTIONS(1678),
    [anon_sym_input] = ACTIONS(1680),
    [anon_sym_output] = ACTIONS(1680),
    [anon_sym_inout] = ACTIONS(1680),
    [anon_sym_ref] = ACTIONS(1680),
    [anon_sym_DOLLARfatal] = ACTIONS(1678),
    [anon_sym_DOLLARerror] = ACTIONS(1678),
    [anon_sym_DOLLARwarning] = ACTIONS(1678),
    [anon_sym_DOLLARinfo] = ACTIONS(1678),
    [anon_sym_default] = ACTIONS(1680),
    [anon_sym_clocking] = ACTIONS(1680),
    [anon_sym_iff] = ACTIONS(1680),
    [anon_sym_defparam] = ACTIONS(1680),
    [anon_sym_bind] = ACTIONS(1680),
    [anon_sym_const] = ACTIONS(1680),
    [anon_sym_function] = ACTIONS(1680),
    [anon_sym_static] = ACTIONS(1680),
    [anon_sym_constraint] = ACTIONS(1680),
    [anon_sym_u2013_GT] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(1680),
    [anon_sym_else] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1678),
    [anon_sym_RBRACK] = ACTIONS(1678),
    [anon_sym_localparam] = ACTIONS(1680),
    [anon_sym_parameter] = ACTIONS(1680),
    [anon_sym_specparam] = ACTIONS(1680),
    [anon_sym_var] = ACTIONS(1680),
    [anon_sym_import] = ACTIONS(1680),
    [anon_sym_STAR] = ACTIONS(1680),
    [anon_sym_export] = ACTIONS(1680),
    [anon_sym_genvar] = ACTIONS(1680),
    [anon_sym_interconnect] = ACTIONS(1680),
    [anon_sym_typedef] = ACTIONS(1680),
    [anon_sym_enum] = ACTIONS(1680),
    [anon_sym_struct] = ACTIONS(1680),
    [anon_sym_union] = ACTIONS(1680),
    [anon_sym_nettype] = ACTIONS(1680),
    [anon_sym_with] = ACTIONS(1680),
    [anon_sym_automatic] = ACTIONS(1680),
    [anon_sym_string] = ACTIONS(1680),
    [anon_sym_chandle] = ACTIONS(1680),
    [anon_sym_event] = ACTIONS(1680),
    [anon_sym_byte] = ACTIONS(1680),
    [anon_sym_shortint] = ACTIONS(1680),
    [anon_sym_int] = ACTIONS(1680),
    [anon_sym_longint] = ACTIONS(1680),
    [anon_sym_integer] = ACTIONS(1680),
    [anon_sym_time] = ACTIONS(1680),
    [anon_sym_bit] = ACTIONS(1680),
    [anon_sym_logic] = ACTIONS(1680),
    [anon_sym_reg] = ACTIONS(1680),
    [anon_sym_shortreal] = ACTIONS(1680),
    [anon_sym_real] = ACTIONS(1680),
    [anon_sym_realtime] = ACTIONS(1680),
    [anon_sym_supply0] = ACTIONS(1680),
    [anon_sym_supply1] = ACTIONS(1680),
    [anon_sym_signed] = ACTIONS(1680),
    [anon_sym_unsigned] = ACTIONS(1680),
    [anon_sym_task] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1678),
    [anon_sym_STAR_STAR] = ACTIONS(1678),
    [anon_sym_PERCENT] = ACTIONS(1678),
    [anon_sym_EQ_EQ] = ACTIONS(1680),
    [anon_sym_BANG_EQ] = ACTIONS(1680),
    [anon_sym_LT_EQ] = ACTIONS(1678),
    [anon_sym_GT_EQ] = ACTIONS(1678),
    [anon_sym_modport] = ACTIONS(1680),
    [anon_sym_assert] = ACTIONS(1680),
    [anon_sym_property] = ACTIONS(1680),
    [anon_sym_assume] = ACTIONS(1680),
    [anon_sym_cover] = ACTIONS(1680),
    [anon_sym_sequence] = ACTIONS(1680),
    [anon_sym_restrict] = ACTIONS(1680),
    [anon_sym_not] = ACTIONS(1680),
    [anon_sym_or] = ACTIONS(1680),
    [anon_sym_and] = ACTIONS(1680),
    [anon_sym_case] = ACTIONS(1680),
    [anon_sym_always] = ACTIONS(1680),
    [anon_sym_dist] = ACTIONS(1680),
    [anon_sym_covergroup] = ACTIONS(1680),
    [anon_sym_AMP_AMP] = ACTIONS(1680),
    [anon_sym_PIPE_PIPE] = ACTIONS(1678),
    [anon_sym_matches] = ACTIONS(1680),
    [anon_sym_let] = ACTIONS(1680),
    [anon_sym_pulldown] = ACTIONS(1680),
    [anon_sym_pullup] = ACTIONS(1680),
    [anon_sym_cmos] = ACTIONS(1680),
    [anon_sym_rcmos] = ACTIONS(1680),
    [anon_sym_bufif0] = ACTIONS(1680),
    [anon_sym_bufif1] = ACTIONS(1680),
    [anon_sym_notif0] = ACTIONS(1680),
    [anon_sym_notif1] = ACTIONS(1680),
    [anon_sym_nmos] = ACTIONS(1680),
    [anon_sym_pmos] = ACTIONS(1680),
    [anon_sym_rnmos] = ACTIONS(1680),
    [anon_sym_rpmos] = ACTIONS(1680),
    [anon_sym_nand] = ACTIONS(1680),
    [anon_sym_nor] = ACTIONS(1680),
    [anon_sym_xor] = ACTIONS(1680),
    [anon_sym_xnor] = ACTIONS(1680),
    [anon_sym_buf] = ACTIONS(1680),
    [anon_sym_tranif0] = ACTIONS(1680),
    [anon_sym_tranif1] = ACTIONS(1680),
    [anon_sym_rtranif1] = ACTIONS(1680),
    [anon_sym_rtranif0] = ACTIONS(1680),
    [anon_sym_tran] = ACTIONS(1680),
    [anon_sym_rtran] = ACTIONS(1680),
    [anon_sym_generate] = ACTIONS(1680),
    [anon_sym_for] = ACTIONS(1680),
    [anon_sym_primitive] = ACTIONS(1680),
    [anon_sym_initial] = ACTIONS(1680),
    [anon_sym_DASH] = ACTIONS(1680),
    [anon_sym_assign] = ACTIONS(1680),
    [anon_sym_alias] = ACTIONS(1680),
    [anon_sym_always_comb] = ACTIONS(1680),
    [anon_sym_always_latch] = ACTIONS(1680),
    [anon_sym_always_ff] = ACTIONS(1680),
    [anon_sym_final] = ACTIONS(1680),
    [anon_sym_DASH_GT] = ACTIONS(1678),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1678),
    [anon_sym_inside] = ACTIONS(1680),
    [anon_sym_global] = ACTIONS(1680),
    [anon_sym_specify] = ACTIONS(1680),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1678),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1678),
    [anon_sym_GT_GT] = ACTIONS(1680),
    [anon_sym_LT_LT] = ACTIONS(1680),
    [anon_sym_QMARK] = ACTIONS(1678),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_AMP] = ACTIONS(1680),
    [anon_sym_PIPE] = ACTIONS(1680),
    [anon_sym_CARET] = ACTIONS(1680),
    [anon_sym_CARET_TILDE] = ACTIONS(1678),
    [anon_sym_TILDE_CARET] = ACTIONS(1678),
    [anon_sym_GT_GT_GT] = ACTIONS(1678),
    [anon_sym_LT_LT_LT] = ACTIONS(1678),
    [anon_sym_LT_DASH_GT] = ACTIONS(1678),
    [anon_sym_LPAREN_STAR] = ACTIONS(1678),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1678),
    [anon_sym_DOLLARunit] = ACTIONS(1678),
  },
  [102] = {
    [ts_builtin_sym_end] = ACTIONS(1682),
    [sym_simple_identifier] = ACTIONS(1684),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1682),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_EQ] = ACTIONS(1682),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1684),
    [aux_sym_id_directive_token1] = ACTIONS(1682),
    [aux_sym_id_directive_token2] = ACTIONS(1682),
    [aux_sym_id_directive_token3] = ACTIONS(1682),
    [aux_sym_id_directive_token4] = ACTIONS(1684),
    [aux_sym_zero_directive_token1] = ACTIONS(1682),
    [aux_sym_zero_directive_token2] = ACTIONS(1682),
    [aux_sym_zero_directive_token3] = ACTIONS(1682),
    [aux_sym_zero_directive_token4] = ACTIONS(1682),
    [aux_sym_zero_directive_token5] = ACTIONS(1682),
    [aux_sym_zero_directive_token6] = ACTIONS(1682),
    [aux_sym_zero_directive_token7] = ACTIONS(1682),
    [aux_sym_zero_directive_token8] = ACTIONS(1682),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1682),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1682),
    [anon_sym_wire] = ACTIONS(1684),
    [anon_sym_tri] = ACTIONS(1684),
    [anon_sym_tri0] = ACTIONS(1684),
    [anon_sym_tri1] = ACTIONS(1684),
    [anon_sym_wand] = ACTIONS(1684),
    [anon_sym_triand] = ACTIONS(1684),
    [anon_sym_wor] = ACTIONS(1684),
    [anon_sym_trior] = ACTIONS(1684),
    [anon_sym_trireg] = ACTIONS(1684),
    [anon_sym_uwire] = ACTIONS(1684),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1682),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1682),
    [aux_sym_begin_keywords_token1] = ACTIONS(1682),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_endmodule] = ACTIONS(1684),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_extern] = ACTIONS(1684),
    [anon_sym_module] = ACTIONS(1684),
    [anon_sym_macromodule] = ACTIONS(1684),
    [anon_sym_endinterface] = ACTIONS(1684),
    [anon_sym_interface] = ACTIONS(1684),
    [anon_sym_endprogram] = ACTIONS(1684),
    [anon_sym_program] = ACTIONS(1684),
    [anon_sym_checker] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_class] = ACTIONS(1684),
    [anon_sym_extends] = ACTIONS(1684),
    [anon_sym_implements] = ACTIONS(1684),
    [anon_sym_endclass] = ACTIONS(1684),
    [anon_sym_pure] = ACTIONS(1684),
    [anon_sym_package] = ACTIONS(1684),
    [anon_sym_endpackage] = ACTIONS(1684),
    [anon_sym_timeunit] = ACTIONS(1684),
    [anon_sym_timeprecision] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_RBRACE] = ACTIONS(1682),
    [anon_sym_input] = ACTIONS(1684),
    [anon_sym_output] = ACTIONS(1684),
    [anon_sym_inout] = ACTIONS(1684),
    [anon_sym_ref] = ACTIONS(1684),
    [anon_sym_DOLLARfatal] = ACTIONS(1682),
    [anon_sym_DOLLARerror] = ACTIONS(1682),
    [anon_sym_DOLLARwarning] = ACTIONS(1682),
    [anon_sym_DOLLARinfo] = ACTIONS(1682),
    [anon_sym_default] = ACTIONS(1684),
    [anon_sym_clocking] = ACTIONS(1684),
    [anon_sym_iff] = ACTIONS(1684),
    [anon_sym_defparam] = ACTIONS(1684),
    [anon_sym_bind] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_function] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_constraint] = ACTIONS(1684),
    [anon_sym_before] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_localparam] = ACTIONS(1684),
    [anon_sym_parameter] = ACTIONS(1684),
    [anon_sym_specparam] = ACTIONS(1684),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_export] = ACTIONS(1684),
    [anon_sym_genvar] = ACTIONS(1684),
    [anon_sym_interconnect] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_supply0] = ACTIONS(1684),
    [anon_sym_supply1] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_task] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_modport] = ACTIONS(1684),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_property] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_sequence] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_not] = ACTIONS(1684),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_and] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_always] = ACTIONS(1684),
    [anon_sym_covergroup] = ACTIONS(1684),
    [anon_sym_let] = ACTIONS(1684),
    [anon_sym_pulldown] = ACTIONS(1684),
    [anon_sym_pullup] = ACTIONS(1684),
    [anon_sym_cmos] = ACTIONS(1684),
    [anon_sym_rcmos] = ACTIONS(1684),
    [anon_sym_bufif0] = ACTIONS(1684),
    [anon_sym_bufif1] = ACTIONS(1684),
    [anon_sym_notif0] = ACTIONS(1684),
    [anon_sym_notif1] = ACTIONS(1684),
    [anon_sym_nmos] = ACTIONS(1684),
    [anon_sym_pmos] = ACTIONS(1684),
    [anon_sym_rnmos] = ACTIONS(1684),
    [anon_sym_rpmos] = ACTIONS(1684),
    [anon_sym_nand] = ACTIONS(1684),
    [anon_sym_nor] = ACTIONS(1684),
    [anon_sym_xor] = ACTIONS(1684),
    [anon_sym_xnor] = ACTIONS(1684),
    [anon_sym_buf] = ACTIONS(1684),
    [anon_sym_tranif0] = ACTIONS(1684),
    [anon_sym_tranif1] = ACTIONS(1684),
    [anon_sym_rtranif1] = ACTIONS(1684),
    [anon_sym_rtranif0] = ACTIONS(1684),
    [anon_sym_tran] = ACTIONS(1684),
    [anon_sym_rtran] = ACTIONS(1684),
    [anon_sym_generate] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_primitive] = ACTIONS(1684),
    [anon_sym_initial] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_alias] = ACTIONS(1684),
    [anon_sym_always_comb] = ACTIONS(1684),
    [anon_sym_always_latch] = ACTIONS(1684),
    [anon_sym_always_ff] = ACTIONS(1684),
    [anon_sym_final] = ACTIONS(1684),
    [anon_sym_PLUS_EQ] = ACTIONS(1682),
    [anon_sym_DASH_EQ] = ACTIONS(1682),
    [anon_sym_STAR_EQ] = ACTIONS(1682),
    [anon_sym_SLASH_EQ] = ACTIONS(1682),
    [anon_sym_PERCENT_EQ] = ACTIONS(1682),
    [anon_sym_AMP_EQ] = ACTIONS(1682),
    [anon_sym_PIPE_EQ] = ACTIONS(1682),
    [anon_sym_CARET_EQ] = ACTIONS(1682),
    [anon_sym_LT_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT_EQ] = ACTIONS(1682),
    [anon_sym_LT_LT_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1682),
    [anon_sym_AT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_while] = ACTIONS(1684),
    [anon_sym_endclocking] = ACTIONS(1684),
    [anon_sym_global] = ACTIONS(1684),
    [anon_sym_specify] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [anon_sym_STAR_RPAREN] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1682),
    [anon_sym_DOLLARunit] = ACTIONS(1682),
  },
  [103] = {
    [ts_builtin_sym_end] = ACTIONS(1686),
    [sym_simple_identifier] = ACTIONS(1688),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1686),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_EQ] = ACTIONS(1686),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1688),
    [aux_sym_id_directive_token1] = ACTIONS(1686),
    [aux_sym_id_directive_token2] = ACTIONS(1686),
    [aux_sym_id_directive_token3] = ACTIONS(1686),
    [aux_sym_id_directive_token4] = ACTIONS(1688),
    [aux_sym_zero_directive_token1] = ACTIONS(1686),
    [aux_sym_zero_directive_token2] = ACTIONS(1686),
    [aux_sym_zero_directive_token3] = ACTIONS(1686),
    [aux_sym_zero_directive_token4] = ACTIONS(1686),
    [aux_sym_zero_directive_token5] = ACTIONS(1686),
    [aux_sym_zero_directive_token6] = ACTIONS(1686),
    [aux_sym_zero_directive_token7] = ACTIONS(1686),
    [aux_sym_zero_directive_token8] = ACTIONS(1686),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1686),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1686),
    [anon_sym_wire] = ACTIONS(1688),
    [anon_sym_tri] = ACTIONS(1688),
    [anon_sym_tri0] = ACTIONS(1688),
    [anon_sym_tri1] = ACTIONS(1688),
    [anon_sym_wand] = ACTIONS(1688),
    [anon_sym_triand] = ACTIONS(1688),
    [anon_sym_wor] = ACTIONS(1688),
    [anon_sym_trior] = ACTIONS(1688),
    [anon_sym_trireg] = ACTIONS(1688),
    [anon_sym_uwire] = ACTIONS(1688),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1686),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1686),
    [aux_sym_begin_keywords_token1] = ACTIONS(1686),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_endmodule] = ACTIONS(1688),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_extern] = ACTIONS(1688),
    [anon_sym_module] = ACTIONS(1688),
    [anon_sym_macromodule] = ACTIONS(1688),
    [anon_sym_endinterface] = ACTIONS(1688),
    [anon_sym_interface] = ACTIONS(1688),
    [anon_sym_endprogram] = ACTIONS(1688),
    [anon_sym_program] = ACTIONS(1688),
    [anon_sym_checker] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_class] = ACTIONS(1688),
    [anon_sym_extends] = ACTIONS(1688),
    [anon_sym_implements] = ACTIONS(1688),
    [anon_sym_endclass] = ACTIONS(1688),
    [anon_sym_pure] = ACTIONS(1688),
    [anon_sym_package] = ACTIONS(1688),
    [anon_sym_endpackage] = ACTIONS(1688),
    [anon_sym_timeunit] = ACTIONS(1688),
    [anon_sym_timeprecision] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_RBRACE] = ACTIONS(1686),
    [anon_sym_input] = ACTIONS(1688),
    [anon_sym_output] = ACTIONS(1688),
    [anon_sym_inout] = ACTIONS(1688),
    [anon_sym_ref] = ACTIONS(1688),
    [anon_sym_DOLLARfatal] = ACTIONS(1686),
    [anon_sym_DOLLARerror] = ACTIONS(1686),
    [anon_sym_DOLLARwarning] = ACTIONS(1686),
    [anon_sym_DOLLARinfo] = ACTIONS(1686),
    [anon_sym_default] = ACTIONS(1688),
    [anon_sym_clocking] = ACTIONS(1688),
    [anon_sym_iff] = ACTIONS(1688),
    [anon_sym_defparam] = ACTIONS(1688),
    [anon_sym_bind] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_function] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_constraint] = ACTIONS(1688),
    [anon_sym_before] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_localparam] = ACTIONS(1688),
    [anon_sym_parameter] = ACTIONS(1688),
    [anon_sym_specparam] = ACTIONS(1688),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_export] = ACTIONS(1688),
    [anon_sym_genvar] = ACTIONS(1688),
    [anon_sym_interconnect] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_supply0] = ACTIONS(1688),
    [anon_sym_supply1] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_task] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_modport] = ACTIONS(1688),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_property] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_sequence] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_not] = ACTIONS(1688),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_and] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_always] = ACTIONS(1688),
    [anon_sym_covergroup] = ACTIONS(1688),
    [anon_sym_let] = ACTIONS(1688),
    [anon_sym_pulldown] = ACTIONS(1688),
    [anon_sym_pullup] = ACTIONS(1688),
    [anon_sym_cmos] = ACTIONS(1688),
    [anon_sym_rcmos] = ACTIONS(1688),
    [anon_sym_bufif0] = ACTIONS(1688),
    [anon_sym_bufif1] = ACTIONS(1688),
    [anon_sym_notif0] = ACTIONS(1688),
    [anon_sym_notif1] = ACTIONS(1688),
    [anon_sym_nmos] = ACTIONS(1688),
    [anon_sym_pmos] = ACTIONS(1688),
    [anon_sym_rnmos] = ACTIONS(1688),
    [anon_sym_rpmos] = ACTIONS(1688),
    [anon_sym_nand] = ACTIONS(1688),
    [anon_sym_nor] = ACTIONS(1688),
    [anon_sym_xor] = ACTIONS(1688),
    [anon_sym_xnor] = ACTIONS(1688),
    [anon_sym_buf] = ACTIONS(1688),
    [anon_sym_tranif0] = ACTIONS(1688),
    [anon_sym_tranif1] = ACTIONS(1688),
    [anon_sym_rtranif1] = ACTIONS(1688),
    [anon_sym_rtranif0] = ACTIONS(1688),
    [anon_sym_tran] = ACTIONS(1688),
    [anon_sym_rtran] = ACTIONS(1688),
    [anon_sym_generate] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_primitive] = ACTIONS(1688),
    [anon_sym_initial] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_alias] = ACTIONS(1688),
    [anon_sym_always_comb] = ACTIONS(1688),
    [anon_sym_always_latch] = ACTIONS(1688),
    [anon_sym_always_ff] = ACTIONS(1688),
    [anon_sym_final] = ACTIONS(1688),
    [anon_sym_PLUS_EQ] = ACTIONS(1686),
    [anon_sym_DASH_EQ] = ACTIONS(1686),
    [anon_sym_STAR_EQ] = ACTIONS(1686),
    [anon_sym_SLASH_EQ] = ACTIONS(1686),
    [anon_sym_PERCENT_EQ] = ACTIONS(1686),
    [anon_sym_AMP_EQ] = ACTIONS(1686),
    [anon_sym_PIPE_EQ] = ACTIONS(1686),
    [anon_sym_CARET_EQ] = ACTIONS(1686),
    [anon_sym_LT_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT_EQ] = ACTIONS(1686),
    [anon_sym_LT_LT_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1686),
    [anon_sym_AT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_while] = ACTIONS(1688),
    [anon_sym_endclocking] = ACTIONS(1688),
    [anon_sym_global] = ACTIONS(1688),
    [anon_sym_specify] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [anon_sym_STAR_RPAREN] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1686),
    [anon_sym_DOLLARunit] = ACTIONS(1686),
  },
  [104] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1692),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [105] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1696),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [106] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1698),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [107] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(114),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(106),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(106),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1700),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [108] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(112),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(110),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(110),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1702),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [109] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(1704),
    [anon_sym_wire] = ACTIONS(1707),
    [anon_sym_tri] = ACTIONS(1707),
    [anon_sym_tri0] = ACTIONS(1707),
    [anon_sym_tri1] = ACTIONS(1707),
    [anon_sym_wand] = ACTIONS(1707),
    [anon_sym_triand] = ACTIONS(1707),
    [anon_sym_wor] = ACTIONS(1707),
    [anon_sym_trior] = ACTIONS(1707),
    [anon_sym_trireg] = ACTIONS(1707),
    [anon_sym_uwire] = ACTIONS(1707),
    [anon_sym_SEMI] = ACTIONS(1710),
    [anon_sym_extern] = ACTIONS(1713),
    [anon_sym_endinterface] = ACTIONS(1716),
    [anon_sym_interface] = ACTIONS(1718),
    [anon_sym_program] = ACTIONS(1721),
    [anon_sym_checker] = ACTIONS(1724),
    [anon_sym_virtual] = ACTIONS(1727),
    [anon_sym_class] = ACTIONS(1730),
    [anon_sym_timeunit] = ACTIONS(1733),
    [anon_sym_timeprecision] = ACTIONS(1736),
    [anon_sym_type] = ACTIONS(1739),
    [anon_sym_input] = ACTIONS(1742),
    [anon_sym_output] = ACTIONS(1745),
    [anon_sym_inout] = ACTIONS(1748),
    [anon_sym_ref] = ACTIONS(1751),
    [anon_sym_DOLLARfatal] = ACTIONS(1754),
    [anon_sym_DOLLARerror] = ACTIONS(1757),
    [anon_sym_DOLLARwarning] = ACTIONS(1757),
    [anon_sym_DOLLARinfo] = ACTIONS(1757),
    [anon_sym_default] = ACTIONS(1760),
    [anon_sym_clocking] = ACTIONS(1763),
    [anon_sym_bind] = ACTIONS(1766),
    [anon_sym_const] = ACTIONS(1769),
    [anon_sym_function] = ACTIONS(1772),
    [anon_sym_static] = ACTIONS(1775),
    [anon_sym_constraint] = ACTIONS(1778),
    [anon_sym_if] = ACTIONS(1781),
    [anon_sym_LBRACK] = ACTIONS(1784),
    [anon_sym_localparam] = ACTIONS(1787),
    [anon_sym_parameter] = ACTIONS(1790),
    [anon_sym_var] = ACTIONS(1793),
    [anon_sym_import] = ACTIONS(1796),
    [anon_sym_export] = ACTIONS(1799),
    [anon_sym_genvar] = ACTIONS(1802),
    [anon_sym_interconnect] = ACTIONS(1805),
    [anon_sym_typedef] = ACTIONS(1808),
    [anon_sym_enum] = ACTIONS(1811),
    [anon_sym_struct] = ACTIONS(1814),
    [anon_sym_union] = ACTIONS(1817),
    [anon_sym_nettype] = ACTIONS(1820),
    [anon_sym_automatic] = ACTIONS(1823),
    [anon_sym_string] = ACTIONS(1826),
    [anon_sym_chandle] = ACTIONS(1826),
    [anon_sym_event] = ACTIONS(1826),
    [anon_sym_byte] = ACTIONS(1829),
    [anon_sym_shortint] = ACTIONS(1829),
    [anon_sym_int] = ACTIONS(1829),
    [anon_sym_longint] = ACTIONS(1829),
    [anon_sym_integer] = ACTIONS(1829),
    [anon_sym_time] = ACTIONS(1829),
    [anon_sym_bit] = ACTIONS(1832),
    [anon_sym_logic] = ACTIONS(1832),
    [anon_sym_reg] = ACTIONS(1832),
    [anon_sym_shortreal] = ACTIONS(1835),
    [anon_sym_real] = ACTIONS(1835),
    [anon_sym_realtime] = ACTIONS(1835),
    [anon_sym_supply0] = ACTIONS(1707),
    [anon_sym_supply1] = ACTIONS(1707),
    [anon_sym_signed] = ACTIONS(1838),
    [anon_sym_unsigned] = ACTIONS(1838),
    [anon_sym_task] = ACTIONS(1841),
    [anon_sym_modport] = ACTIONS(1844),
    [anon_sym_assert] = ACTIONS(1847),
    [anon_sym_property] = ACTIONS(1850),
    [anon_sym_assume] = ACTIONS(1853),
    [anon_sym_cover] = ACTIONS(1856),
    [anon_sym_sequence] = ACTIONS(1859),
    [anon_sym_restrict] = ACTIONS(1862),
    [anon_sym_case] = ACTIONS(1865),
    [anon_sym_always] = ACTIONS(1868),
    [anon_sym_covergroup] = ACTIONS(1871),
    [anon_sym_let] = ACTIONS(1874),
    [anon_sym_generate] = ACTIONS(1877),
    [anon_sym_for] = ACTIONS(1880),
    [anon_sym_initial] = ACTIONS(1883),
    [anon_sym_assign] = ACTIONS(1886),
    [anon_sym_alias] = ACTIONS(1889),
    [anon_sym_always_comb] = ACTIONS(1868),
    [anon_sym_always_latch] = ACTIONS(1868),
    [anon_sym_always_ff] = ACTIONS(1868),
    [anon_sym_final] = ACTIONS(1892),
    [anon_sym_global] = ACTIONS(1895),
    [anon_sym_LPAREN_STAR] = ACTIONS(1898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1901),
    [anon_sym_DOLLARunit] = ACTIONS(1904),
  },
  [110] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1907),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [111] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1909),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [112] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(104),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(104),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(1911),
    [anon_sym_wire] = ACTIONS(1914),
    [anon_sym_tri] = ACTIONS(1914),
    [anon_sym_tri0] = ACTIONS(1914),
    [anon_sym_tri1] = ACTIONS(1914),
    [anon_sym_wand] = ACTIONS(1914),
    [anon_sym_triand] = ACTIONS(1914),
    [anon_sym_wor] = ACTIONS(1914),
    [anon_sym_trior] = ACTIONS(1914),
    [anon_sym_trireg] = ACTIONS(1914),
    [anon_sym_uwire] = ACTIONS(1914),
    [anon_sym_SEMI] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1920),
    [anon_sym_endinterface] = ACTIONS(1923),
    [anon_sym_interface] = ACTIONS(1926),
    [anon_sym_program] = ACTIONS(1929),
    [anon_sym_checker] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1935),
    [anon_sym_class] = ACTIONS(1938),
    [anon_sym_timeunit] = ACTIONS(1941),
    [anon_sym_timeprecision] = ACTIONS(1944),
    [anon_sym_type] = ACTIONS(1947),
    [anon_sym_input] = ACTIONS(1950),
    [anon_sym_output] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1956),
    [anon_sym_ref] = ACTIONS(1959),
    [anon_sym_DOLLARfatal] = ACTIONS(1962),
    [anon_sym_DOLLARerror] = ACTIONS(1965),
    [anon_sym_DOLLARwarning] = ACTIONS(1965),
    [anon_sym_DOLLARinfo] = ACTIONS(1965),
    [anon_sym_default] = ACTIONS(1968),
    [anon_sym_clocking] = ACTIONS(1971),
    [anon_sym_bind] = ACTIONS(1974),
    [anon_sym_const] = ACTIONS(1977),
    [anon_sym_function] = ACTIONS(1980),
    [anon_sym_static] = ACTIONS(1983),
    [anon_sym_constraint] = ACTIONS(1986),
    [anon_sym_if] = ACTIONS(1989),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_localparam] = ACTIONS(1995),
    [anon_sym_parameter] = ACTIONS(1998),
    [anon_sym_var] = ACTIONS(2001),
    [anon_sym_import] = ACTIONS(2004),
    [anon_sym_export] = ACTIONS(2007),
    [anon_sym_genvar] = ACTIONS(2010),
    [anon_sym_interconnect] = ACTIONS(2013),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2019),
    [anon_sym_struct] = ACTIONS(2022),
    [anon_sym_union] = ACTIONS(2025),
    [anon_sym_nettype] = ACTIONS(2028),
    [anon_sym_automatic] = ACTIONS(2031),
    [anon_sym_string] = ACTIONS(2034),
    [anon_sym_chandle] = ACTIONS(2034),
    [anon_sym_event] = ACTIONS(2034),
    [anon_sym_byte] = ACTIONS(2037),
    [anon_sym_shortint] = ACTIONS(2037),
    [anon_sym_int] = ACTIONS(2037),
    [anon_sym_longint] = ACTIONS(2037),
    [anon_sym_integer] = ACTIONS(2037),
    [anon_sym_time] = ACTIONS(2037),
    [anon_sym_bit] = ACTIONS(2040),
    [anon_sym_logic] = ACTIONS(2040),
    [anon_sym_reg] = ACTIONS(2040),
    [anon_sym_shortreal] = ACTIONS(2043),
    [anon_sym_real] = ACTIONS(2043),
    [anon_sym_realtime] = ACTIONS(2043),
    [anon_sym_supply0] = ACTIONS(1914),
    [anon_sym_supply1] = ACTIONS(1914),
    [anon_sym_signed] = ACTIONS(2046),
    [anon_sym_unsigned] = ACTIONS(2046),
    [anon_sym_task] = ACTIONS(2049),
    [anon_sym_modport] = ACTIONS(2052),
    [anon_sym_assert] = ACTIONS(2055),
    [anon_sym_property] = ACTIONS(2058),
    [anon_sym_assume] = ACTIONS(2061),
    [anon_sym_cover] = ACTIONS(2064),
    [anon_sym_sequence] = ACTIONS(2067),
    [anon_sym_restrict] = ACTIONS(2070),
    [anon_sym_case] = ACTIONS(2073),
    [anon_sym_always] = ACTIONS(2076),
    [anon_sym_covergroup] = ACTIONS(2079),
    [anon_sym_let] = ACTIONS(2082),
    [anon_sym_generate] = ACTIONS(2085),
    [anon_sym_for] = ACTIONS(2088),
    [anon_sym_initial] = ACTIONS(2091),
    [anon_sym_assign] = ACTIONS(2094),
    [anon_sym_alias] = ACTIONS(2097),
    [anon_sym_always_comb] = ACTIONS(2076),
    [anon_sym_always_latch] = ACTIONS(2076),
    [anon_sym_always_ff] = ACTIONS(2076),
    [anon_sym_final] = ACTIONS(2100),
    [anon_sym_global] = ACTIONS(2103),
    [anon_sym_LPAREN_STAR] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2109),
    [anon_sym_DOLLARunit] = ACTIONS(2112),
  },
  [113] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(115),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(105),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(105),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(2115),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [114] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(116),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(116),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(1911),
    [anon_sym_wire] = ACTIONS(1914),
    [anon_sym_tri] = ACTIONS(1914),
    [anon_sym_tri0] = ACTIONS(1914),
    [anon_sym_tri1] = ACTIONS(1914),
    [anon_sym_wand] = ACTIONS(1914),
    [anon_sym_triand] = ACTIONS(1914),
    [anon_sym_wor] = ACTIONS(1914),
    [anon_sym_trior] = ACTIONS(1914),
    [anon_sym_trireg] = ACTIONS(1914),
    [anon_sym_uwire] = ACTIONS(1914),
    [anon_sym_SEMI] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1920),
    [anon_sym_endinterface] = ACTIONS(2117),
    [anon_sym_interface] = ACTIONS(1926),
    [anon_sym_program] = ACTIONS(1929),
    [anon_sym_checker] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1935),
    [anon_sym_class] = ACTIONS(1938),
    [anon_sym_timeunit] = ACTIONS(1941),
    [anon_sym_timeprecision] = ACTIONS(1944),
    [anon_sym_type] = ACTIONS(1947),
    [anon_sym_input] = ACTIONS(1950),
    [anon_sym_output] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1956),
    [anon_sym_ref] = ACTIONS(1959),
    [anon_sym_DOLLARfatal] = ACTIONS(1962),
    [anon_sym_DOLLARerror] = ACTIONS(1965),
    [anon_sym_DOLLARwarning] = ACTIONS(1965),
    [anon_sym_DOLLARinfo] = ACTIONS(1965),
    [anon_sym_default] = ACTIONS(1968),
    [anon_sym_clocking] = ACTIONS(1971),
    [anon_sym_bind] = ACTIONS(1974),
    [anon_sym_const] = ACTIONS(1977),
    [anon_sym_function] = ACTIONS(1980),
    [anon_sym_static] = ACTIONS(1983),
    [anon_sym_constraint] = ACTIONS(1986),
    [anon_sym_if] = ACTIONS(1989),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_localparam] = ACTIONS(1995),
    [anon_sym_parameter] = ACTIONS(1998),
    [anon_sym_var] = ACTIONS(2001),
    [anon_sym_import] = ACTIONS(2004),
    [anon_sym_export] = ACTIONS(2007),
    [anon_sym_genvar] = ACTIONS(2010),
    [anon_sym_interconnect] = ACTIONS(2013),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2019),
    [anon_sym_struct] = ACTIONS(2022),
    [anon_sym_union] = ACTIONS(2025),
    [anon_sym_nettype] = ACTIONS(2028),
    [anon_sym_automatic] = ACTIONS(2031),
    [anon_sym_string] = ACTIONS(2034),
    [anon_sym_chandle] = ACTIONS(2034),
    [anon_sym_event] = ACTIONS(2034),
    [anon_sym_byte] = ACTIONS(2037),
    [anon_sym_shortint] = ACTIONS(2037),
    [anon_sym_int] = ACTIONS(2037),
    [anon_sym_longint] = ACTIONS(2037),
    [anon_sym_integer] = ACTIONS(2037),
    [anon_sym_time] = ACTIONS(2037),
    [anon_sym_bit] = ACTIONS(2040),
    [anon_sym_logic] = ACTIONS(2040),
    [anon_sym_reg] = ACTIONS(2040),
    [anon_sym_shortreal] = ACTIONS(2043),
    [anon_sym_real] = ACTIONS(2043),
    [anon_sym_realtime] = ACTIONS(2043),
    [anon_sym_supply0] = ACTIONS(1914),
    [anon_sym_supply1] = ACTIONS(1914),
    [anon_sym_signed] = ACTIONS(2046),
    [anon_sym_unsigned] = ACTIONS(2046),
    [anon_sym_task] = ACTIONS(2049),
    [anon_sym_modport] = ACTIONS(2052),
    [anon_sym_assert] = ACTIONS(2055),
    [anon_sym_property] = ACTIONS(2058),
    [anon_sym_assume] = ACTIONS(2061),
    [anon_sym_cover] = ACTIONS(2064),
    [anon_sym_sequence] = ACTIONS(2067),
    [anon_sym_restrict] = ACTIONS(2070),
    [anon_sym_case] = ACTIONS(2073),
    [anon_sym_always] = ACTIONS(2076),
    [anon_sym_covergroup] = ACTIONS(2079),
    [anon_sym_let] = ACTIONS(2082),
    [anon_sym_generate] = ACTIONS(2085),
    [anon_sym_for] = ACTIONS(2088),
    [anon_sym_initial] = ACTIONS(2091),
    [anon_sym_assign] = ACTIONS(2094),
    [anon_sym_alias] = ACTIONS(2097),
    [anon_sym_always_comb] = ACTIONS(2076),
    [anon_sym_always_latch] = ACTIONS(2076),
    [anon_sym_always_ff] = ACTIONS(2076),
    [anon_sym_final] = ACTIONS(2100),
    [anon_sym_global] = ACTIONS(2103),
    [anon_sym_LPAREN_STAR] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2109),
    [anon_sym_DOLLARunit] = ACTIONS(2112),
  },
  [115] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(111),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(111),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(1911),
    [anon_sym_wire] = ACTIONS(1914),
    [anon_sym_tri] = ACTIONS(1914),
    [anon_sym_tri0] = ACTIONS(1914),
    [anon_sym_tri1] = ACTIONS(1914),
    [anon_sym_wand] = ACTIONS(1914),
    [anon_sym_triand] = ACTIONS(1914),
    [anon_sym_wor] = ACTIONS(1914),
    [anon_sym_trior] = ACTIONS(1914),
    [anon_sym_trireg] = ACTIONS(1914),
    [anon_sym_uwire] = ACTIONS(1914),
    [anon_sym_SEMI] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1920),
    [anon_sym_endinterface] = ACTIONS(2120),
    [anon_sym_interface] = ACTIONS(1926),
    [anon_sym_program] = ACTIONS(1929),
    [anon_sym_checker] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1935),
    [anon_sym_class] = ACTIONS(1938),
    [anon_sym_timeunit] = ACTIONS(1941),
    [anon_sym_timeprecision] = ACTIONS(1944),
    [anon_sym_type] = ACTIONS(1947),
    [anon_sym_input] = ACTIONS(1950),
    [anon_sym_output] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1956),
    [anon_sym_ref] = ACTIONS(1959),
    [anon_sym_DOLLARfatal] = ACTIONS(1962),
    [anon_sym_DOLLARerror] = ACTIONS(1965),
    [anon_sym_DOLLARwarning] = ACTIONS(1965),
    [anon_sym_DOLLARinfo] = ACTIONS(1965),
    [anon_sym_default] = ACTIONS(1968),
    [anon_sym_clocking] = ACTIONS(1971),
    [anon_sym_bind] = ACTIONS(1974),
    [anon_sym_const] = ACTIONS(1977),
    [anon_sym_function] = ACTIONS(1980),
    [anon_sym_static] = ACTIONS(1983),
    [anon_sym_constraint] = ACTIONS(1986),
    [anon_sym_if] = ACTIONS(1989),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_localparam] = ACTIONS(1995),
    [anon_sym_parameter] = ACTIONS(1998),
    [anon_sym_var] = ACTIONS(2001),
    [anon_sym_import] = ACTIONS(2004),
    [anon_sym_export] = ACTIONS(2007),
    [anon_sym_genvar] = ACTIONS(2010),
    [anon_sym_interconnect] = ACTIONS(2013),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2019),
    [anon_sym_struct] = ACTIONS(2022),
    [anon_sym_union] = ACTIONS(2025),
    [anon_sym_nettype] = ACTIONS(2028),
    [anon_sym_automatic] = ACTIONS(2031),
    [anon_sym_string] = ACTIONS(2034),
    [anon_sym_chandle] = ACTIONS(2034),
    [anon_sym_event] = ACTIONS(2034),
    [anon_sym_byte] = ACTIONS(2037),
    [anon_sym_shortint] = ACTIONS(2037),
    [anon_sym_int] = ACTIONS(2037),
    [anon_sym_longint] = ACTIONS(2037),
    [anon_sym_integer] = ACTIONS(2037),
    [anon_sym_time] = ACTIONS(2037),
    [anon_sym_bit] = ACTIONS(2040),
    [anon_sym_logic] = ACTIONS(2040),
    [anon_sym_reg] = ACTIONS(2040),
    [anon_sym_shortreal] = ACTIONS(2043),
    [anon_sym_real] = ACTIONS(2043),
    [anon_sym_realtime] = ACTIONS(2043),
    [anon_sym_supply0] = ACTIONS(1914),
    [anon_sym_supply1] = ACTIONS(1914),
    [anon_sym_signed] = ACTIONS(2046),
    [anon_sym_unsigned] = ACTIONS(2046),
    [anon_sym_task] = ACTIONS(2049),
    [anon_sym_modport] = ACTIONS(2052),
    [anon_sym_assert] = ACTIONS(2055),
    [anon_sym_property] = ACTIONS(2058),
    [anon_sym_assume] = ACTIONS(2061),
    [anon_sym_cover] = ACTIONS(2064),
    [anon_sym_sequence] = ACTIONS(2067),
    [anon_sym_restrict] = ACTIONS(2070),
    [anon_sym_case] = ACTIONS(2073),
    [anon_sym_always] = ACTIONS(2076),
    [anon_sym_covergroup] = ACTIONS(2079),
    [anon_sym_let] = ACTIONS(2082),
    [anon_sym_generate] = ACTIONS(2085),
    [anon_sym_for] = ACTIONS(2088),
    [anon_sym_initial] = ACTIONS(2091),
    [anon_sym_assign] = ACTIONS(2094),
    [anon_sym_alias] = ACTIONS(2097),
    [anon_sym_always_comb] = ACTIONS(2076),
    [anon_sym_always_latch] = ACTIONS(2076),
    [anon_sym_always_ff] = ACTIONS(2076),
    [anon_sym_final] = ACTIONS(2100),
    [anon_sym_global] = ACTIONS(2103),
    [anon_sym_LPAREN_STAR] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2109),
    [anon_sym_DOLLARunit] = ACTIONS(2112),
  },
  [116] = {
    [sym_interface_declaration] = STATE(5374),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(5374),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5374),
    [sym_port_declaration] = STATE(19202),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(5374),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym_interface_item] = STATE(109),
    [sym__non_port_interface_item] = STATE(5374),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(5374),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5374),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(505),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(505),
    [aux_sym_interface_declaration_repeat1] = STATE(109),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(2123),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [117] = {
    [ts_builtin_sym_end] = ACTIONS(2125),
    [sym_simple_identifier] = ACTIONS(2127),
    [anon_sym_LT] = ACTIONS(2127),
    [anon_sym_GT] = ACTIONS(2127),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(2125),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_RPAREN] = ACTIONS(2125),
    [anon_sym_COMMA] = ACTIONS(2125),
    [aux_sym_text_macro_definition_token1] = ACTIONS(2125),
    [anon_sym_BQUOTE] = ACTIONS(2127),
    [aux_sym_id_directive_token1] = ACTIONS(2125),
    [aux_sym_id_directive_token2] = ACTIONS(2125),
    [aux_sym_id_directive_token3] = ACTIONS(2125),
    [aux_sym_id_directive_token4] = ACTIONS(2127),
    [aux_sym_zero_directive_token1] = ACTIONS(2125),
    [aux_sym_zero_directive_token2] = ACTIONS(2125),
    [aux_sym_zero_directive_token3] = ACTIONS(2125),
    [aux_sym_zero_directive_token4] = ACTIONS(2125),
    [aux_sym_zero_directive_token5] = ACTIONS(2125),
    [aux_sym_zero_directive_token6] = ACTIONS(2125),
    [aux_sym_zero_directive_token7] = ACTIONS(2125),
    [aux_sym_zero_directive_token8] = ACTIONS(2125),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(2125),
    [anon_sym_SLASH] = ACTIONS(2127),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(2125),
    [anon_sym_wire] = ACTIONS(2127),
    [anon_sym_tri] = ACTIONS(2127),
    [anon_sym_tri0] = ACTIONS(2127),
    [anon_sym_tri1] = ACTIONS(2127),
    [anon_sym_wand] = ACTIONS(2127),
    [anon_sym_triand] = ACTIONS(2127),
    [anon_sym_wor] = ACTIONS(2127),
    [anon_sym_trior] = ACTIONS(2127),
    [anon_sym_trireg] = ACTIONS(2127),
    [anon_sym_uwire] = ACTIONS(2127),
    [aux_sym_unconnected_drive_token1] = ACTIONS(2125),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(2125),
    [aux_sym_begin_keywords_token1] = ACTIONS(2125),
    [anon_sym_SEMI] = ACTIONS(2125),
    [anon_sym_endmodule] = ACTIONS(2127),
    [anon_sym_COLON] = ACTIONS(2125),
    [anon_sym_extern] = ACTIONS(2127),
    [anon_sym_module] = ACTIONS(2127),
    [anon_sym_macromodule] = ACTIONS(2127),
    [anon_sym_interface] = ACTIONS(2127),
    [anon_sym_program] = ACTIONS(2127),
    [anon_sym_checker] = ACTIONS(2127),
    [anon_sym_virtual] = ACTIONS(2127),
    [anon_sym_class] = ACTIONS(2127),
    [anon_sym_package] = ACTIONS(2127),
    [anon_sym_timeunit] = ACTIONS(2127),
    [anon_sym_timeprecision] = ACTIONS(2127),
    [anon_sym_type] = ACTIONS(2127),
    [anon_sym_DOT] = ACTIONS(2125),
    [anon_sym_LBRACE] = ACTIONS(2125),
    [anon_sym_RBRACE] = ACTIONS(2125),
    [anon_sym_input] = ACTIONS(2127),
    [anon_sym_output] = ACTIONS(2127),
    [anon_sym_inout] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2127),
    [anon_sym_DOLLARfatal] = ACTIONS(2125),
    [anon_sym_DOLLARerror] = ACTIONS(2125),
    [anon_sym_DOLLARwarning] = ACTIONS(2125),
    [anon_sym_DOLLARinfo] = ACTIONS(2125),
    [anon_sym_default] = ACTIONS(2127),
    [anon_sym_clocking] = ACTIONS(2127),
    [anon_sym_defparam] = ACTIONS(2127),
    [anon_sym_bind] = ACTIONS(2127),
    [anon_sym_const] = ACTIONS(2127),
    [anon_sym_function] = ACTIONS(2127),
    [anon_sym_static] = ACTIONS(2127),
    [anon_sym_constraint] = ACTIONS(2127),
    [anon_sym_if] = ACTIONS(2127),
    [anon_sym_LBRACK] = ACTIONS(2125),
    [anon_sym_RBRACK] = ACTIONS(2125),
    [anon_sym_localparam] = ACTIONS(2127),
    [anon_sym_parameter] = ACTIONS(2127),
    [anon_sym_specparam] = ACTIONS(2127),
    [anon_sym_var] = ACTIONS(2127),
    [anon_sym_import] = ACTIONS(2127),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_export] = ACTIONS(2127),
    [anon_sym_genvar] = ACTIONS(2127),
    [anon_sym_interconnect] = ACTIONS(2127),
    [anon_sym_typedef] = ACTIONS(2127),
    [anon_sym_enum] = ACTIONS(2127),
    [anon_sym_struct] = ACTIONS(2127),
    [anon_sym_union] = ACTIONS(2127),
    [anon_sym_nettype] = ACTIONS(2127),
    [anon_sym_automatic] = ACTIONS(2127),
    [anon_sym_string] = ACTIONS(2127),
    [anon_sym_chandle] = ACTIONS(2127),
    [anon_sym_event] = ACTIONS(2127),
    [anon_sym_byte] = ACTIONS(2127),
    [anon_sym_shortint] = ACTIONS(2127),
    [anon_sym_int] = ACTIONS(2127),
    [anon_sym_longint] = ACTIONS(2127),
    [anon_sym_integer] = ACTIONS(2127),
    [anon_sym_time] = ACTIONS(2127),
    [anon_sym_bit] = ACTIONS(2127),
    [anon_sym_logic] = ACTIONS(2127),
    [anon_sym_reg] = ACTIONS(2127),
    [anon_sym_shortreal] = ACTIONS(2127),
    [anon_sym_real] = ACTIONS(2127),
    [anon_sym_realtime] = ACTIONS(2127),
    [anon_sym_supply0] = ACTIONS(2127),
    [anon_sym_supply1] = ACTIONS(2127),
    [anon_sym_signed] = ACTIONS(2127),
    [anon_sym_unsigned] = ACTIONS(2127),
    [anon_sym_task] = ACTIONS(2127),
    [anon_sym_PLUS] = ACTIONS(2125),
    [anon_sym_STAR_STAR] = ACTIONS(2125),
    [anon_sym_PERCENT] = ACTIONS(2125),
    [anon_sym_EQ_EQ] = ACTIONS(2127),
    [anon_sym_BANG_EQ] = ACTIONS(2127),
    [anon_sym_LT_EQ] = ACTIONS(2125),
    [anon_sym_GT_EQ] = ACTIONS(2125),
    [anon_sym_assert] = ACTIONS(2127),
    [anon_sym_property] = ACTIONS(2127),
    [anon_sym_assume] = ACTIONS(2127),
    [anon_sym_cover] = ACTIONS(2127),
    [anon_sym_sequence] = ACTIONS(2127),
    [anon_sym_restrict] = ACTIONS(2127),
    [anon_sym_not] = ACTIONS(2127),
    [anon_sym_or] = ACTIONS(2127),
    [anon_sym_and] = ACTIONS(2127),
    [anon_sym_case] = ACTIONS(2127),
    [anon_sym_always] = ACTIONS(2127),
    [anon_sym_covergroup] = ACTIONS(2127),
    [anon_sym_AMP_AMP] = ACTIONS(2125),
    [anon_sym_PIPE_PIPE] = ACTIONS(2125),
    [anon_sym_let] = ACTIONS(2127),
    [anon_sym_pulldown] = ACTIONS(2127),
    [anon_sym_pullup] = ACTIONS(2127),
    [anon_sym_cmos] = ACTIONS(2127),
    [anon_sym_rcmos] = ACTIONS(2127),
    [anon_sym_bufif0] = ACTIONS(2127),
    [anon_sym_bufif1] = ACTIONS(2127),
    [anon_sym_notif0] = ACTIONS(2127),
    [anon_sym_notif1] = ACTIONS(2127),
    [anon_sym_nmos] = ACTIONS(2127),
    [anon_sym_pmos] = ACTIONS(2127),
    [anon_sym_rnmos] = ACTIONS(2127),
    [anon_sym_rpmos] = ACTIONS(2127),
    [anon_sym_nand] = ACTIONS(2127),
    [anon_sym_nor] = ACTIONS(2127),
    [anon_sym_xor] = ACTIONS(2127),
    [anon_sym_xnor] = ACTIONS(2127),
    [anon_sym_buf] = ACTIONS(2127),
    [anon_sym_tranif0] = ACTIONS(2127),
    [anon_sym_tranif1] = ACTIONS(2127),
    [anon_sym_rtranif1] = ACTIONS(2127),
    [anon_sym_rtranif0] = ACTIONS(2127),
    [anon_sym_tran] = ACTIONS(2127),
    [anon_sym_rtran] = ACTIONS(2127),
    [anon_sym_generate] = ACTIONS(2127),
    [anon_sym_for] = ACTIONS(2127),
    [anon_sym_primitive] = ACTIONS(2127),
    [anon_sym_initial] = ACTIONS(2127),
    [anon_sym_DASH] = ACTIONS(2127),
    [anon_sym_assign] = ACTIONS(2127),
    [anon_sym_alias] = ACTIONS(2127),
    [anon_sym_always_comb] = ACTIONS(2127),
    [anon_sym_always_latch] = ACTIONS(2127),
    [anon_sym_always_ff] = ACTIONS(2127),
    [anon_sym_final] = ACTIONS(2127),
    [anon_sym_DASH_GT] = ACTIONS(2125),
    [anon_sym_global] = ACTIONS(2127),
    [anon_sym_specify] = ACTIONS(2127),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2125),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2125),
    [anon_sym_GT_GT] = ACTIONS(2127),
    [anon_sym_LT_LT] = ACTIONS(2127),
    [anon_sym_QMARK] = ACTIONS(2125),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2125),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2125),
    [anon_sym_AMP] = ACTIONS(2127),
    [anon_sym_PIPE] = ACTIONS(2127),
    [anon_sym_CARET] = ACTIONS(2127),
    [anon_sym_CARET_TILDE] = ACTIONS(2125),
    [anon_sym_TILDE_CARET] = ACTIONS(2125),
    [anon_sym_GT_GT_GT] = ACTIONS(2125),
    [anon_sym_LT_LT_LT] = ACTIONS(2125),
    [anon_sym_LT_DASH_GT] = ACTIONS(2125),
    [anon_sym_SQUOTE] = ACTIONS(2125),
    [anon_sym_LPAREN_STAR] = ACTIONS(2125),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2125),
    [anon_sym_DOLLARunit] = ACTIONS(2125),
  },
  [118] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(177),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2561),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2561),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(177),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2149),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [119] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2245),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2245),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2233),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [120] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(163),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2214),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2214),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(163),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2235),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [121] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2214),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2214),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2235),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [122] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2563),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2563),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2237),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [123] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(156),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2200),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2200),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(156),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2239),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [124] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(127),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2277),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2277),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(127),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2241),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [125] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2203),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2203),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2243),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [126] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(128),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2281),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2281),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(128),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2245),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [127] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2281),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2281),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2245),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [128] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2284),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2284),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [129] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(131),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2284),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2284),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(131),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [130] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(133),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2287),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2287),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(133),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2249),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [131] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2293),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2293),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2251),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [132] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(134),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2294),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2294),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(134),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2253),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [133] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2295),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2295),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2255),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [134] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2302),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2302),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2257),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [135] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(121),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2227),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2227),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2259),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [136] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(138),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2331),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2331),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(138),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2261),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [137] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(139),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2333),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2333),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(139),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [138] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2333),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2333),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [139] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2336),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2336),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2265),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [140] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(142),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2336),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2336),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(142),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2265),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [141] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(144),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2338),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2338),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(144),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2267),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [142] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2342),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2342),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2269),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [143] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(145),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2343),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2343),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(145),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2271),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [144] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2344),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2344),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2273),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [145] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2348),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2348),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2275),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [146] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(148),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2369),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2369),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(148),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2277),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [147] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(187),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2371),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2371),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(187),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2279),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [148] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2371),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2371),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2279),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [149] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(151),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2374),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2374),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(151),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2281),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [150] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(153),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2375),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2375),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(153),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2283),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [151] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2379),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2379),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2285),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [152] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(154),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2380),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2380),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(154),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2287),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [153] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2381),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2381),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2289),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [154] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2385),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2385),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2291),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [155] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(174),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2213),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2213),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(174),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2293),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [156] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2273),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2273),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2295),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [157] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(159),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2408),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2408),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(159),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2297),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [158] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(160),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2410),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2410),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(160),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2299),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [159] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2410),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2410),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2299),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [160] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2414),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2414),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2301),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [161] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(164),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2414),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2414),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(164),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2301),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [162] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(166),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2415),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2415),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(166),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2303),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [163] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2216),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2216),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2305),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [164] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2419),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2419),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2307),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [165] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(167),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2420),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2420),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(167),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2309),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [166] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2421),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2421),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2311),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [167] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2425),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2425),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2313),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [168] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(179),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2218),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2218),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(179),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [169] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(171),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2558),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2558),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(171),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2317),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [170] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(172),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2559),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2559),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(172),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2319),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [171] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2559),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2559),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2319),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [172] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2560),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2560),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2321),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [173] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(175),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2560),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2560),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(175),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2321),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [174] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2218),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2218),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [175] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2564),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2564),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2323),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [176] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(178),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2565),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2565),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(178),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2325),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [177] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2566),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2566),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2327),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [178] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2568),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2568),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2329),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [179] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2229),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2229),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2331),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [180] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(183),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2229),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2229),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(183),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2331),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [181] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(185),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2232),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2232),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(185),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2333),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [182] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(122),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2216),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2216),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2305),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [183] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2237),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2237),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2335),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [184] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(119),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2238),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2238),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(119),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2337),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [185] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2239),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2239),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [186] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(125),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2220),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2220),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(125),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2341),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [187] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2374),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(515),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(515),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2374),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2281),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [188] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(194),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2815),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(194),
    [aux_sym_task_body_declaration_repeat1] = STATE(2815),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2345),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [189] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2941),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2941),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2347),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [190] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(196),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3082),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(196),
    [aux_sym_task_body_declaration_repeat1] = STATE(3082),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2349),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [191] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(206),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2876),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(206),
    [aux_sym_task_body_declaration_repeat1] = STATE(2876),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2351),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [192] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2673),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2673),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [193] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(197),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2828),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(197),
    [aux_sym_task_body_declaration_repeat1] = STATE(2828),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2355),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [194] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2828),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2828),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2355),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [195] = {
    [sym_interface_declaration] = STATE(200),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(200),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(199),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(200),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__non_port_interface_item] = STATE(200),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(200),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(200),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(556),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(556),
    [aux_sym_interface_declaration_repeat2] = STATE(200),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(2115),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [196] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2876),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2876),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2351),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [197] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2837),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2837),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2357),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [198] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(201),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2838),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(201),
    [aux_sym_task_body_declaration_repeat1] = STATE(2838),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2359),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [199] = {
    [sym_interface_declaration] = STATE(216),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(216),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(216),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(216),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__non_port_interface_item] = STATE(216),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(216),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(216),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(556),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(556),
    [aux_sym_interface_declaration_repeat2] = STATE(216),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(1911),
    [anon_sym_wire] = ACTIONS(1914),
    [anon_sym_tri] = ACTIONS(1914),
    [anon_sym_tri0] = ACTIONS(1914),
    [anon_sym_tri1] = ACTIONS(1914),
    [anon_sym_wand] = ACTIONS(1914),
    [anon_sym_triand] = ACTIONS(1914),
    [anon_sym_wor] = ACTIONS(1914),
    [anon_sym_trior] = ACTIONS(1914),
    [anon_sym_trireg] = ACTIONS(1914),
    [anon_sym_uwire] = ACTIONS(1914),
    [anon_sym_SEMI] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1920),
    [anon_sym_endinterface] = ACTIONS(2120),
    [anon_sym_interface] = ACTIONS(1926),
    [anon_sym_program] = ACTIONS(1929),
    [anon_sym_checker] = ACTIONS(1932),
    [anon_sym_virtual] = ACTIONS(1935),
    [anon_sym_class] = ACTIONS(1938),
    [anon_sym_timeunit] = ACTIONS(1941),
    [anon_sym_timeprecision] = ACTIONS(1944),
    [anon_sym_type] = ACTIONS(1947),
    [anon_sym_DOLLARfatal] = ACTIONS(1962),
    [anon_sym_DOLLARerror] = ACTIONS(1965),
    [anon_sym_DOLLARwarning] = ACTIONS(1965),
    [anon_sym_DOLLARinfo] = ACTIONS(1965),
    [anon_sym_default] = ACTIONS(1968),
    [anon_sym_clocking] = ACTIONS(1971),
    [anon_sym_bind] = ACTIONS(1974),
    [anon_sym_const] = ACTIONS(1977),
    [anon_sym_function] = ACTIONS(1980),
    [anon_sym_static] = ACTIONS(1983),
    [anon_sym_constraint] = ACTIONS(1986),
    [anon_sym_if] = ACTIONS(1989),
    [anon_sym_LBRACK] = ACTIONS(1992),
    [anon_sym_localparam] = ACTIONS(1995),
    [anon_sym_parameter] = ACTIONS(1998),
    [anon_sym_var] = ACTIONS(2001),
    [anon_sym_import] = ACTIONS(2004),
    [anon_sym_export] = ACTIONS(2007),
    [anon_sym_genvar] = ACTIONS(2010),
    [anon_sym_interconnect] = ACTIONS(2013),
    [anon_sym_typedef] = ACTIONS(2016),
    [anon_sym_enum] = ACTIONS(2019),
    [anon_sym_struct] = ACTIONS(2022),
    [anon_sym_union] = ACTIONS(2025),
    [anon_sym_nettype] = ACTIONS(2028),
    [anon_sym_automatic] = ACTIONS(2031),
    [anon_sym_string] = ACTIONS(2034),
    [anon_sym_chandle] = ACTIONS(2034),
    [anon_sym_event] = ACTIONS(2034),
    [anon_sym_byte] = ACTIONS(2037),
    [anon_sym_shortint] = ACTIONS(2037),
    [anon_sym_int] = ACTIONS(2037),
    [anon_sym_longint] = ACTIONS(2037),
    [anon_sym_integer] = ACTIONS(2037),
    [anon_sym_time] = ACTIONS(2037),
    [anon_sym_bit] = ACTIONS(2040),
    [anon_sym_logic] = ACTIONS(2040),
    [anon_sym_reg] = ACTIONS(2040),
    [anon_sym_shortreal] = ACTIONS(2043),
    [anon_sym_real] = ACTIONS(2043),
    [anon_sym_realtime] = ACTIONS(2043),
    [anon_sym_supply0] = ACTIONS(1914),
    [anon_sym_supply1] = ACTIONS(1914),
    [anon_sym_signed] = ACTIONS(2046),
    [anon_sym_unsigned] = ACTIONS(2046),
    [anon_sym_task] = ACTIONS(2049),
    [anon_sym_modport] = ACTIONS(2052),
    [anon_sym_assert] = ACTIONS(2055),
    [anon_sym_property] = ACTIONS(2058),
    [anon_sym_assume] = ACTIONS(2061),
    [anon_sym_cover] = ACTIONS(2064),
    [anon_sym_sequence] = ACTIONS(2067),
    [anon_sym_restrict] = ACTIONS(2070),
    [anon_sym_case] = ACTIONS(2073),
    [anon_sym_always] = ACTIONS(2076),
    [anon_sym_covergroup] = ACTIONS(2079),
    [anon_sym_let] = ACTIONS(2082),
    [anon_sym_generate] = ACTIONS(2085),
    [anon_sym_for] = ACTIONS(2088),
    [anon_sym_initial] = ACTIONS(2091),
    [anon_sym_assign] = ACTIONS(2094),
    [anon_sym_alias] = ACTIONS(2097),
    [anon_sym_always_comb] = ACTIONS(2076),
    [anon_sym_always_latch] = ACTIONS(2076),
    [anon_sym_always_ff] = ACTIONS(2076),
    [anon_sym_final] = ACTIONS(2100),
    [anon_sym_global] = ACTIONS(2103),
    [anon_sym_LPAREN_STAR] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2109),
    [anon_sym_DOLLARunit] = ACTIONS(2112),
  },
  [200] = {
    [sym_interface_declaration] = STATE(217),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(217),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(217),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(217),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__non_port_interface_item] = STATE(217),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(217),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(217),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(556),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(556),
    [aux_sym_interface_declaration_repeat2] = STATE(217),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1696),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [201] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2847),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2847),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2361),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [202] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(230),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2824),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(230),
    [aux_sym_task_body_declaration_repeat1] = STATE(2824),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2363),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [203] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(205),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2890),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(205),
    [aux_sym_task_body_declaration_repeat1] = STATE(2890),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2365),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [204] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(207),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2895),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(207),
    [aux_sym_task_body_declaration_repeat1] = STATE(2895),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2367),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [205] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2895),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2895),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2367),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [206] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2893),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2893),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2369),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [207] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2904),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2904),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2371),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [208] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(211),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2905),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(211),
    [aux_sym_task_body_declaration_repeat1] = STATE(2905),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2373),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [209] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(224),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2637),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(224),
    [aux_sym_task_body_declaration_repeat1] = STATE(2637),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [210] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2637),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2637),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [211] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2915),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2915),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [212] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(220),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2741),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(220),
    [aux_sym_task_body_declaration_repeat1] = STATE(2741),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [213] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2741),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2741),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [214] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(226),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2902),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(226),
    [aux_sym_task_body_declaration_repeat1] = STATE(2902),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2381),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [215] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(219),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3206),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(219),
    [aux_sym_task_body_declaration_repeat1] = STATE(3206),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2383),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [216] = {
    [sym_interface_declaration] = STATE(217),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(217),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(217),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(217),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__non_port_interface_item] = STATE(217),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(217),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(217),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(556),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(556),
    [aux_sym_interface_declaration_repeat2] = STATE(217),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(1690),
    [anon_sym_endinterface] = ACTIONS(1909),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(127),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_modport] = ACTIONS(1694),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [217] = {
    [sym_interface_declaration] = STATE(217),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(217),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(217),
    [sym_elaboration_system_task] = STATE(1201),
    [sym__module_common_item] = STATE(1201),
    [sym__module_or_generate_item_declaration] = STATE(1201),
    [sym_bind_directive] = STATE(1201),
    [sym_interface_or_generate_item] = STATE(217),
    [sym_extern_tf_declaration] = STATE(1201),
    [sym__non_port_interface_item] = STATE(217),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1201),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1201),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_modport_declaration] = STATE(217),
    [sym_concurrent_assertion_item] = STATE(1201),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1201),
    [sym_program_instantiation] = STATE(1201),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(217),
    [sym_loop_generate_construct] = STATE(1201),
    [sym__conditional_generate_construct] = STATE(1201),
    [sym_if_generate_construct] = STATE(1201),
    [sym_case_generate_construct] = STATE(1201),
    [sym_continuous_assign] = STATE(1201),
    [sym_net_alias] = STATE(1201),
    [sym_initial_construct] = STATE(1201),
    [sym_always_construct] = STATE(1201),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1201),
    [sym__assertion_item] = STATE(1201),
    [sym_deferred_immediate_assertion_item] = STATE(1201),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1201),
    [sym_attribute_instance] = STATE(556),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(556),
    [aux_sym_interface_declaration_repeat2] = STATE(217),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(2385),
    [anon_sym_wire] = ACTIONS(2388),
    [anon_sym_tri] = ACTIONS(2388),
    [anon_sym_tri0] = ACTIONS(2388),
    [anon_sym_tri1] = ACTIONS(2388),
    [anon_sym_wand] = ACTIONS(2388),
    [anon_sym_triand] = ACTIONS(2388),
    [anon_sym_wor] = ACTIONS(2388),
    [anon_sym_trior] = ACTIONS(2388),
    [anon_sym_trireg] = ACTIONS(2388),
    [anon_sym_uwire] = ACTIONS(2388),
    [anon_sym_SEMI] = ACTIONS(2391),
    [anon_sym_extern] = ACTIONS(2394),
    [anon_sym_endinterface] = ACTIONS(2397),
    [anon_sym_interface] = ACTIONS(2399),
    [anon_sym_program] = ACTIONS(2402),
    [anon_sym_checker] = ACTIONS(2405),
    [anon_sym_virtual] = ACTIONS(2408),
    [anon_sym_class] = ACTIONS(2411),
    [anon_sym_timeunit] = ACTIONS(2414),
    [anon_sym_timeprecision] = ACTIONS(2417),
    [anon_sym_type] = ACTIONS(2420),
    [anon_sym_DOLLARfatal] = ACTIONS(2423),
    [anon_sym_DOLLARerror] = ACTIONS(2426),
    [anon_sym_DOLLARwarning] = ACTIONS(2426),
    [anon_sym_DOLLARinfo] = ACTIONS(2426),
    [anon_sym_default] = ACTIONS(2429),
    [anon_sym_clocking] = ACTIONS(2432),
    [anon_sym_bind] = ACTIONS(2435),
    [anon_sym_const] = ACTIONS(2438),
    [anon_sym_function] = ACTIONS(2441),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_constraint] = ACTIONS(2447),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_LBRACK] = ACTIONS(2453),
    [anon_sym_localparam] = ACTIONS(2456),
    [anon_sym_parameter] = ACTIONS(2459),
    [anon_sym_var] = ACTIONS(2462),
    [anon_sym_import] = ACTIONS(2465),
    [anon_sym_export] = ACTIONS(2468),
    [anon_sym_genvar] = ACTIONS(2471),
    [anon_sym_interconnect] = ACTIONS(2474),
    [anon_sym_typedef] = ACTIONS(2477),
    [anon_sym_enum] = ACTIONS(2480),
    [anon_sym_struct] = ACTIONS(2483),
    [anon_sym_union] = ACTIONS(2486),
    [anon_sym_nettype] = ACTIONS(2489),
    [anon_sym_automatic] = ACTIONS(2492),
    [anon_sym_string] = ACTIONS(2495),
    [anon_sym_chandle] = ACTIONS(2495),
    [anon_sym_event] = ACTIONS(2495),
    [anon_sym_byte] = ACTIONS(2498),
    [anon_sym_shortint] = ACTIONS(2498),
    [anon_sym_int] = ACTIONS(2498),
    [anon_sym_longint] = ACTIONS(2498),
    [anon_sym_integer] = ACTIONS(2498),
    [anon_sym_time] = ACTIONS(2498),
    [anon_sym_bit] = ACTIONS(2501),
    [anon_sym_logic] = ACTIONS(2501),
    [anon_sym_reg] = ACTIONS(2501),
    [anon_sym_shortreal] = ACTIONS(2504),
    [anon_sym_real] = ACTIONS(2504),
    [anon_sym_realtime] = ACTIONS(2504),
    [anon_sym_supply0] = ACTIONS(2388),
    [anon_sym_supply1] = ACTIONS(2388),
    [anon_sym_signed] = ACTIONS(2507),
    [anon_sym_unsigned] = ACTIONS(2507),
    [anon_sym_task] = ACTIONS(2510),
    [anon_sym_modport] = ACTIONS(2513),
    [anon_sym_assert] = ACTIONS(2516),
    [anon_sym_property] = ACTIONS(2519),
    [anon_sym_assume] = ACTIONS(2522),
    [anon_sym_cover] = ACTIONS(2525),
    [anon_sym_sequence] = ACTIONS(2528),
    [anon_sym_restrict] = ACTIONS(2531),
    [anon_sym_case] = ACTIONS(2534),
    [anon_sym_always] = ACTIONS(2537),
    [anon_sym_covergroup] = ACTIONS(2540),
    [anon_sym_let] = ACTIONS(2543),
    [anon_sym_generate] = ACTIONS(2546),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_initial] = ACTIONS(2552),
    [anon_sym_assign] = ACTIONS(2555),
    [anon_sym_alias] = ACTIONS(2558),
    [anon_sym_always_comb] = ACTIONS(2537),
    [anon_sym_always_latch] = ACTIONS(2537),
    [anon_sym_always_ff] = ACTIONS(2537),
    [anon_sym_final] = ACTIONS(2561),
    [anon_sym_global] = ACTIONS(2564),
    [anon_sym_LPAREN_STAR] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2570),
    [anon_sym_DOLLARunit] = ACTIONS(2573),
  },
  [218] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(222),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3217),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(222),
    [aux_sym_task_body_declaration_repeat1] = STATE(3217),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2576),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [219] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3217),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(3217),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2576),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [220] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2754),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2754),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2578),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [221] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(228),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2755),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(228),
    [aux_sym_task_body_declaration_repeat1] = STATE(2755),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2580),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [222] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3221),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(3221),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2582),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [223] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(227),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3223),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(227),
    [aux_sym_task_body_declaration_repeat1] = STATE(3223),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2584),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [224] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2652),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2652),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2586),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [225] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(192),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2654),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(192),
    [aux_sym_task_body_declaration_repeat1] = STATE(2654),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2588),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [226] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2662),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2662),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2590),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [227] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3229),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(3229),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2592),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [228] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2767),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2767),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2594),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [229] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(232),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2866),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(232),
    [aux_sym_task_body_declaration_repeat1] = STATE(2866),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2596),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [230] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2866),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2866),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2596),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [231] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(210),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2616),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(210),
    [aux_sym_task_body_declaration_repeat1] = STATE(2616),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2598),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [232] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2903),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [aux_sym_task_body_declaration_repeat1] = STATE(2903),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2600),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [233] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(189),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2908),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(189),
    [aux_sym_task_body_declaration_repeat1] = STATE(2908),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2602),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [234] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(213),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2726),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(478),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(213),
    [aux_sym_task_body_declaration_repeat1] = STATE(2726),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2604),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [235] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(249),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6655),
    [sym_statement_or_null] = STATE(2049),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(249),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2049),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2606),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [236] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(252),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8842),
    [sym_statement_or_null] = STATE(2039),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(252),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2039),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2612),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [237] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(266),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6857),
    [sym_statement_or_null] = STATE(2079),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(266),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2079),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2616),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [238] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(262),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6199),
    [sym_statement_or_null] = STATE(2076),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(262),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2076),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2620),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [239] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(243),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4438),
    [sym_statement_or_null] = STATE(2108),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(243),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2108),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2624),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [240] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(256),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7130),
    [sym_statement_or_null] = STATE(2078),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(256),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2078),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2628),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [241] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(260),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(1012),
    [sym_statement_or_null] = STATE(2050),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(260),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2050),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2632),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [242] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(245),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4362),
    [sym_statement_or_null] = STATE(2090),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(245),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2090),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_COLON] = ACTIONS(2636),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [243] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4527),
    [sym_statement_or_null] = STATE(2106),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2106),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [244] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(254),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(1017),
    [sym_statement_or_null] = STATE(2092),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(254),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2092),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [245] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4349),
    [sym_statement_or_null] = STATE(2098),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2098),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [246] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(255),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4378),
    [sym_statement_or_null] = STATE(2101),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(255),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2101),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [247] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4357),
    [sym_statement_or_null] = STATE(2065),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2065),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [248] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6675),
    [sym_statement_or_null] = STATE(2089),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2089),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [249] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6690),
    [sym_statement_or_null] = STATE(2057),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2057),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [250] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6710),
    [sym_statement_or_null] = STATE(2086),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2086),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [251] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(250),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6903),
    [sym_statement_or_null] = STATE(2084),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(250),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2084),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [252] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8874),
    [sym_statement_or_null] = STATE(2041),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2041),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [253] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(247),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4344),
    [sym_statement_or_null] = STATE(2063),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(247),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2063),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [254] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(992),
    [sym_statement_or_null] = STATE(2095),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2095),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [255] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4443),
    [sym_statement_or_null] = STATE(2105),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2105),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [256] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7168),
    [sym_statement_or_null] = STATE(2053),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2053),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [257] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(259),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8918),
    [sym_statement_or_null] = STATE(2042),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(259),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2042),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [258] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(261),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7135),
    [sym_statement_or_null] = STATE(2103),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(261),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2103),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [259] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8831),
    [sym_statement_or_null] = STATE(2043),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2043),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [260] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(994),
    [sym_statement_or_null] = STATE(2097),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2097),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [261] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7171),
    [sym_statement_or_null] = STATE(2040),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2040),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [262] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6233),
    [sym_statement_or_null] = STATE(2102),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2102),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [263] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(264),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6134),
    [sym_statement_or_null] = STATE(2054),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(264),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2054),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [264] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6156),
    [sym_statement_or_null] = STATE(2060),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2060),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [265] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(248),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6671),
    [sym_statement_or_null] = STATE(2075),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(248),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2075),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [266] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6885),
    [sym_statement_or_null] = STATE(2082),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2082),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [267] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6998),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(2646),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_SEMI] = ACTIONS(2648),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_iff] = ACTIONS(2644),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_else] = ACTIONS(2644),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_endproperty] = ACTIONS(2644),
    [anon_sym_or] = ACTIONS(2644),
    [anon_sym_and] = ACTIONS(2644),
    [anon_sym_PIPE_DASH_GT] = ACTIONS(2648),
    [anon_sym_PIPE_EQ_GT] = ACTIONS(2648),
    [anon_sym_POUND_DASH_POUND] = ACTIONS(2648),
    [anon_sym_POUND_EQ_POUND] = ACTIONS(2648),
    [anon_sym_until] = ACTIONS(2644),
    [anon_sym_s_until] = ACTIONS(2644),
    [anon_sym_until_with] = ACTIONS(2644),
    [anon_sym_s_until_with] = ACTIONS(2644),
    [anon_sym_implies] = ACTIONS(2644),
    [anon_sym_intersect] = ACTIONS(2644),
    [anon_sym_throughout] = ACTIONS(2644),
    [anon_sym_within] = ACTIONS(2644),
    [anon_sym_POUND_POUND] = ACTIONS(2644),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(2648),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_STAR] = ACTIONS(2644),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_EQ] = ACTIONS(2648),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(2648),
    [anon_sym_dist] = ACTIONS(2644),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [268] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(443),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2570),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(443),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2570),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2694),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [269] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(281),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2216),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(281),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2216),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2305),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [270] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2208),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2208),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2696),
    [anon_sym_endfunction] = ACTIONS(2698),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [271] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(274),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2212),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(274),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2212),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2700),
    [anon_sym_endfunction] = ACTIONS(2702),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [272] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(499),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2834),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(499),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2834),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2706),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2738),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [273] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2478),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2766),
    [anon_sym_endfunction] = ACTIONS(2768),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [274] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2217),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2217),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2770),
    [anon_sym_endfunction] = ACTIONS(2772),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [275] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(280),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2217),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(280),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2217),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2770),
    [anon_sym_endfunction] = ACTIONS(2772),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [276] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(310),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2478),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(310),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2478),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2766),
    [anon_sym_endfunction] = ACTIONS(2768),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [277] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(315),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2563),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(315),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2563),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2237),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [278] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(432),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2208),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(432),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2208),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2696),
    [anon_sym_endfunction] = ACTIONS(2698),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [279] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(283),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2228),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(283),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2228),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2774),
    [anon_sym_endfunction] = ACTIONS(2776),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [280] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2228),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2228),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2774),
    [anon_sym_endfunction] = ACTIONS(2776),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [281] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2563),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2563),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2237),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [282] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(286),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2229),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(286),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2229),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2331),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [283] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2234),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2234),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2778),
    [anon_sym_endfunction] = ACTIONS(2780),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [284] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(287),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2234),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(287),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2234),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2778),
    [anon_sym_endfunction] = ACTIONS(2780),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [285] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(289),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2237),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(289),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2237),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2335),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [286] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2237),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2237),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2335),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [287] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2242),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2242),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2782),
    [anon_sym_endfunction] = ACTIONS(2784),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [288] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(292),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2242),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(292),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2242),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2782),
    [anon_sym_endfunction] = ACTIONS(2784),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [289] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2244),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2244),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2786),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [290] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(293),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2244),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(293),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2244),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2786),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [291] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(296),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2246),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(296),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2246),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2788),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [292] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2249),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2249),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2790),
    [anon_sym_endfunction] = ACTIONS(2792),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [293] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2250),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2250),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2794),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [294] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(298),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2250),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(298),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2250),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2794),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [295] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(299),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2251),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(299),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2251),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2796),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [296] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2253),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2253),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2798),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [297] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(301),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2253),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(301),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2253),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2798),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [298] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2260),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2260),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2800),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [299] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2261),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2261),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2802),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [300] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(302),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2261),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(302),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2261),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2802),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [301] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2262),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2262),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2804),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [302] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2267),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2267),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2806),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [303] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(305),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2276),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(305),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2276),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2808),
    [anon_sym_endfunction] = ACTIONS(2810),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [304] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(489),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2618),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(489),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2618),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2812),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2814),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [305] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2280),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2280),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2816),
    [anon_sym_endfunction] = ACTIONS(2818),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [306] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(308),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2280),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(308),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2280),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2816),
    [anon_sym_endfunction] = ACTIONS(2818),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [307] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(312),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2283),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(312),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2283),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2820),
    [anon_sym_endfunction] = ACTIONS(2822),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [308] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2283),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2283),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2820),
    [anon_sym_endfunction] = ACTIONS(2822),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [309] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(317),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2284),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(317),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2284),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [310] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2263),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2263),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2824),
    [anon_sym_endfunction] = ACTIONS(2826),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [311] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(348),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2263),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(348),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2263),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2824),
    [anon_sym_endfunction] = ACTIONS(2826),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [312] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2290),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2290),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2828),
    [anon_sym_endfunction] = ACTIONS(2830),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [313] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(320),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2290),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(320),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2290),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2828),
    [anon_sym_endfunction] = ACTIONS(2830),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [314] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(322),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2293),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(322),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2293),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2251),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [315] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2268),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2268),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2832),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [316] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(353),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2268),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(353),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2268),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2832),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [317] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2293),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2293),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2251),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [318] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(270),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2215),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(270),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2215),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2834),
    [anon_sym_endfunction] = ACTIONS(2836),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [319] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(367),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2274),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(367),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2274),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2838),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [320] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2299),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2299),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2840),
    [anon_sym_endfunction] = ACTIONS(2842),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [321] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(325),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2299),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(325),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2299),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2840),
    [anon_sym_endfunction] = ACTIONS(2842),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [322] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2301),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2301),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2844),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [323] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(326),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2301),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(326),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2301),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2844),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [324] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(329),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2303),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(329),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2303),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2846),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [325] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2309),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2309),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2848),
    [anon_sym_endfunction] = ACTIONS(2850),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [326] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2310),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2310),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2852),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [327] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(331),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2310),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(331),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2310),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2852),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [328] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(332),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2312),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(332),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2312),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2854),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [329] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2313),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2313),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2856),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [330] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(334),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2313),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(334),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2313),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2856),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [331] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2317),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2317),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2858),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [332] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2318),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2318),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2860),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [333] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(335),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2318),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(335),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2318),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2860),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [334] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2319),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2319),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2862),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [335] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2322),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2322),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2864),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [336] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(339),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2330),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(339),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2330),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2866),
    [anon_sym_endfunction] = ACTIONS(2868),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [337] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(454),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2727),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(454),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2727),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2870),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2872),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [338] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(453),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2874),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(453),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2874),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2874),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2876),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [339] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2332),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2332),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2878),
    [anon_sym_endfunction] = ACTIONS(2880),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [340] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(342),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2332),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(342),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2332),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2878),
    [anon_sym_endfunction] = ACTIONS(2880),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [341] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(344),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2335),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(344),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2335),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2882),
    [anon_sym_endfunction] = ACTIONS(2884),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [342] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2335),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2335),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2882),
    [anon_sym_endfunction] = ACTIONS(2884),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [343] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(347),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2336),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(347),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2336),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2265),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [344] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2340),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2340),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2886),
    [anon_sym_endfunction] = ACTIONS(2888),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [345] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(349),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2340),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(349),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2340),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2886),
    [anon_sym_endfunction] = ACTIONS(2888),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [346] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(351),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2342),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(351),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2342),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2269),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [347] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2342),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2342),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2269),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [348] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2577),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2577),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2890),
    [anon_sym_endfunction] = ACTIONS(2892),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [349] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2345),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2345),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2894),
    [anon_sym_endfunction] = ACTIONS(2896),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [350] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(357),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2345),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(357),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2345),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2894),
    [anon_sym_endfunction] = ACTIONS(2896),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [351] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2347),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2347),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2898),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [352] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(358),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2347),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(358),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2347),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2898),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [353] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2199),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2199),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2900),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [354] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(361),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2349),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(361),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2349),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2902),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [355] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(392),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2199),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(392),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2199),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2900),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [356] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(397),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2201),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(397),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2201),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2904),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [357] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2351),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2351),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2906),
    [anon_sym_endfunction] = ACTIONS(2908),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [358] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2352),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2352),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2910),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [359] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(363),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2352),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(363),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2352),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2910),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [360] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(447),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2353),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(447),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2353),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2912),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [361] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2354),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2354),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2914),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [362] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(366),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2354),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(366),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2354),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2914),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [363] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2357),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2357),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2916),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [364] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2576),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2576),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2918),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [365] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(369),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2358),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(369),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2358),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2920),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [366] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2359),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2359),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2922),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [367] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2204),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2204),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2924),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [368] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(401),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2204),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(401),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2204),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2924),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [369] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2362),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2362),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2926),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [370] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(372),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2368),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(372),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2368),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2928),
    [anon_sym_endfunction] = ACTIONS(2930),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [371] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(480),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2816),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(480),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2816),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2932),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2934),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [372] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2370),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2370),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2936),
    [anon_sym_endfunction] = ACTIONS(2938),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [373] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(375),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2370),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(375),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2370),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2936),
    [anon_sym_endfunction] = ACTIONS(2938),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [374] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(377),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2373),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(377),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2373),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2940),
    [anon_sym_endfunction] = ACTIONS(2942),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [375] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2373),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2373),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2940),
    [anon_sym_endfunction] = ACTIONS(2942),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [376] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(380),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2374),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(380),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2374),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2281),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [377] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2377),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2377),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2944),
    [anon_sym_endfunction] = ACTIONS(2946),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [378] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(381),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2377),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(381),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2377),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2944),
    [anon_sym_endfunction] = ACTIONS(2946),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [379] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(383),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2379),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(383),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2379),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2285),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [380] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2379),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2379),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2285),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [381] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2382),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2382),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2948),
    [anon_sym_endfunction] = ACTIONS(2950),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [382] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(386),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2382),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(386),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2382),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2948),
    [anon_sym_endfunction] = ACTIONS(2950),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [383] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2384),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2384),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2952),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [384] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(387),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2384),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(387),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2384),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2952),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [385] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(390),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2386),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(390),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2386),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2954),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [386] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2389),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2389),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2956),
    [anon_sym_endfunction] = ACTIONS(2958),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [387] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2390),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2390),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2960),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [388] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(393),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2390),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(393),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2390),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2960),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [389] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(394),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2391),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(394),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2391),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2962),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [390] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2392),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2392),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2964),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [391] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(396),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2392),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(396),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2392),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2964),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [392] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2224),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2224),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2966),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [393] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2395),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2395),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2968),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [394] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2396),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2396),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2970),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [395] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(398),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2396),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(398),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2396),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2970),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [396] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2397),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2397),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2972),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [397] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2225),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2225),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2974),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [398] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2400),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2400),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [399] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(431),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2225),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(431),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2225),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2974),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [400] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(403),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2407),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(403),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2407),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2978),
    [anon_sym_endfunction] = ACTIONS(2980),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [401] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2230),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2230),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2982),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [402] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(498),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2891),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(498),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2891),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(2984),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(2986),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [403] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2409),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2409),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2988),
    [anon_sym_endfunction] = ACTIONS(2990),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [404] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(406),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2409),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(406),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2409),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2988),
    [anon_sym_endfunction] = ACTIONS(2990),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [405] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(409),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2413),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(409),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2413),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2992),
    [anon_sym_endfunction] = ACTIONS(2994),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [406] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2413),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2413),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2992),
    [anon_sym_endfunction] = ACTIONS(2994),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [407] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(412),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2414),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(412),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2414),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2301),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [408] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(273),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2210),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(273),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2210),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2996),
    [anon_sym_endfunction] = ACTIONS(2998),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [409] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2417),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2417),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(3000),
    [anon_sym_endfunction] = ACTIONS(3002),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [410] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(413),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2417),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(413),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2417),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(3000),
    [anon_sym_endfunction] = ACTIONS(3002),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [411] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(415),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2419),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(415),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2419),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2307),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [412] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2419),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2419),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2307),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [413] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2422),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2422),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(3004),
    [anon_sym_endfunction] = ACTIONS(3006),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [414] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(418),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2422),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(418),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2422),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(3004),
    [anon_sym_endfunction] = ACTIONS(3006),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [415] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2424),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2424),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3008),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [416] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(419),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2424),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(419),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2424),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3008),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [417] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(422),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2426),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(422),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2426),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3010),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [418] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2428),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2428),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(3012),
    [anon_sym_endfunction] = ACTIONS(3014),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [419] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2429),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2429),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3016),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [420] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(424),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2429),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(424),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2429),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3016),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [421] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(425),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2430),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(425),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2430),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3018),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [422] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2431),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2431),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3020),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [423] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(427),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2431),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(427),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2431),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3020),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [424] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2434),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2434),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3022),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [425] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2435),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2435),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3024),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [426] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(428),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2435),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(428),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2435),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3024),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [427] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2436),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2436),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3026),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [428] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2439),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2439),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3028),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [429] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(523),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2949),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(523),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2949),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(3030),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3032),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [430] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(528),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2961),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(528),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2961),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_COLON] = ACTIONS(3034),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3036),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [431] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2256),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2256),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3038),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [432] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2210),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2210),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2996),
    [anon_sym_endfunction] = ACTIONS(2998),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [433] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(435),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2560),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(435),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2560),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2321),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [434] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(436),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2564),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(436),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2564),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2323),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [435] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2564),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2564),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2323),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [436] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2567),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3040),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [437] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(439),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2567),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(439),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3040),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [438] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(441),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2569),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(441),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2569),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3042),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [439] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2570),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2570),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2694),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [440] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(444),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2571),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(444),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2571),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3044),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [441] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2572),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2572),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3046),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [442] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(446),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2572),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(446),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2572),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3046),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [443] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2573),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2573),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3048),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [444] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2574),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2574),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3050),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [445] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(364),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2574),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(364),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2574),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3050),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [446] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2575),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2575),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3052),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [447] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2358),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(547),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(547),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2358),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2920),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [448] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(537),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3227),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(537),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3227),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [449] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(458),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2939),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(458),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2939),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3056),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [450] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2939),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2939),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3056),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [451] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3113),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3113),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [452] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2943),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2943),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3060),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [453] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2658),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2658),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3062),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [454] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2746),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2746),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3064),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [455] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(461),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2754),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(461),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2754),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2578),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [456] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(462),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2756),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(462),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2756),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3066),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [457] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(479),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2614),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(479),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2614),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3068),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [458] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2991),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2991),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3070),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [459] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(464),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2764),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(464),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2764),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3072),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [460] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(467),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2991),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(467),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2991),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3070),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [461] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2764),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2764),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3072),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [462] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2771),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2771),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3074),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [463] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(468),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2997),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(468),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2997),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3076),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [464] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2783),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2783),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3078),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [465] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(470),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2783),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(470),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2783),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3078),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [466] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(471),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2784),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(471),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2784),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3080),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [467] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3005),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3005),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3082),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [468] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3006),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3006),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3084),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [469] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(474),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3006),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(474),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3006),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3084),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [470] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2790),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2790),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3086),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [471] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2791),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2791),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3088),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [472] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(473),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2791),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(473),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2791),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3088),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [473] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2797),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2797),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3090),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [474] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3081),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3081),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [475] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3013),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3013),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3094),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [476] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3104),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3104),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [477] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(497),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3104),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(497),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3104),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [478] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(20395),
    [sym_parameter_declaration] = STATE(20395),
    [sym__any_parameter_declaration] = STATE(20395),
    [sym_data_declaration] = STATE(5408),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_port_direction] = STATE(8381),
    [sym_overload_declaration] = STATE(5408),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5408),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(5500),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8357),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(5500),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3098),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [479] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2921),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2921),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3100),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [480] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2830),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2830),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3102),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [481] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(484),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2837),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(484),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2837),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2357),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [482] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(485),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2839),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(485),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2839),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3104),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [483] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(486),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2846),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(486),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2846),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3106),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [484] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2846),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2846),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3106),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [485] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2849),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2849),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3108),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [486] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2856),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2856),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3110),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [487] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(490),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2856),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(490),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2856),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3110),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [488] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(491),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2858),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(491),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2858),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [489] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2641),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2641),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3114),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [490] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2864),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2864),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [491] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2865),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2865),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3118),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [492] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(493),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2865),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(493),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2865),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3118),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [493] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2871),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2871),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [494] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(503),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2652),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(503),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2652),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2586),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [495] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(504),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2656),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(504),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2656),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3122),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [496] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(451),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2893),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(451),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2893),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2369),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [497] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2909),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2909),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [498] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2896),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2896),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3126),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [499] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2869),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2869),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3128),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [500] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(512),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2671),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(512),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2671),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3130),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [501] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(507),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2904),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(507),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2904),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2371),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [502] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(508),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2906),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(508),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2906),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3132),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [503] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2671),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2671),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3130),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [504] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2675),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2675),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3134),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [505] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1215),
    [sym__module_common_item] = STATE(1215),
    [sym__module_or_generate_item_declaration] = STATE(1215),
    [sym_bind_directive] = STATE(1215),
    [sym_extern_tf_declaration] = STATE(1215),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1215),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(18782),
    [sym_input_declaration] = STATE(18782),
    [sym_output_declaration] = STATE(18782),
    [sym_interface_port_declaration] = STATE(18782),
    [sym_ref_declaration] = STATE(18782),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1215),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1215),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1215),
    [sym_program_instantiation] = STATE(1215),
    [sym_checker_instantiation] = STATE(1224),
    [sym_loop_generate_construct] = STATE(1215),
    [sym__conditional_generate_construct] = STATE(1215),
    [sym_if_generate_construct] = STATE(1215),
    [sym_case_generate_construct] = STATE(1215),
    [sym_continuous_assign] = STATE(1215),
    [sym_net_alias] = STATE(1215),
    [sym_initial_construct] = STATE(1215),
    [sym_always_construct] = STATE(1215),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1215),
    [sym__assertion_item] = STATE(1215),
    [sym_deferred_immediate_assertion_item] = STATE(1215),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1215),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10685),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(766),
    [anon_sym_program] = ACTIONS(768),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [506] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(509),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2914),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(509),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2914),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [507] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2914),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2914),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [508] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2916),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2916),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3138),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [509] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2923),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2923),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [510] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(516),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2923),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(516),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2923),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [511] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(517),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2924),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(517),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2924),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3142),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [512] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2686),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2686),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [513] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(522),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2686),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(522),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2686),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [514] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(526),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2687),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(526),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2687),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3146),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [515] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(20395),
    [sym_parameter_declaration] = STATE(20395),
    [sym__any_parameter_declaration] = STATE(20395),
    [sym_data_declaration] = STATE(5408),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_port_direction] = STATE(8381),
    [sym_overload_declaration] = STATE(5408),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5408),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(5500),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8357),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(5500),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3148),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_input] = ACTIONS(2137),
    [anon_sym_output] = ACTIONS(2137),
    [anon_sym_inout] = ACTIONS(2137),
    [anon_sym_ref] = ACTIONS(2137),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2143),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [516] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2930),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2930),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3150),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [517] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2931),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2931),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [518] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(521),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2931),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(521),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2931),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [519] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(450),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2903),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(450),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2903),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2600),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [520] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(452),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2922),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(452),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2922),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3154),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [521] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2936),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2936),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [522] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2698),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2698),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3158),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [523] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2951),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2951),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3160),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [524] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(525),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2954),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(525),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2954),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3162),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [525] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2956),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2956),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3164),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [526] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2699),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2699),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3166),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [527] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(536),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2699),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(536),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2699),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3166),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [528] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2963),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2963),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3168),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [529] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(530),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2966),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(530),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2966),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3170),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [530] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5719),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2967),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(545),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8299),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(545),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2967),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3172),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [531] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2593),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2593),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3174),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [532] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(475),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2593),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(475),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2593),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3174),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [533] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(535),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3221),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(535),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3221),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(2582),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [534] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(531),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3113),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(531),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3113),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [535] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3227),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3227),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [536] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2707),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2707),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [537] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3239),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3239),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3178),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [538] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(541),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3239),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(541),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3239),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3178),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [539] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(542),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3242),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(542),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3242),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [540] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(476),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2612),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(476),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(2612),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3182),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [541] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3249),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3249),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [542] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3250),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3186),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [543] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(544),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3250),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(544),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3186),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [544] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5428),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(3255),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(546),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8281),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(546),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_task_body_declaration_repeat1] = STATE(3255),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_endtask] = ACTIONS(3188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [545] = {
    [sym_local_parameter_declaration] = STATE(19638),
    [sym_parameter_declaration] = STATE(19638),
    [sym__any_parameter_declaration] = STATE(19638),
    [sym_data_declaration] = STATE(5707),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_overload_declaration] = STATE(5707),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_let_declaration] = STATE(5707),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7252),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(5500),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8354),
    [sym_package_scope] = STATE(12841),
    [aux_sym__description_repeat1] = STATE(5500),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3190),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_bind] = ACTIONS(2710),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2718),
    [anon_sym_import] = ACTIONS(2720),
    [anon_sym_typedef] = ACTIONS(2722),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2724),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_let] = ACTIONS(2740),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [546] = {
    [sym_local_parameter_declaration] = STATE(20395),
    [sym_parameter_declaration] = STATE(20395),
    [sym__any_parameter_declaration] = STATE(20395),
    [sym_data_declaration] = STATE(5408),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_overload_declaration] = STATE(5408),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5408),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(5500),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8357),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(5500),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3098),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [547] = {
    [sym_local_parameter_declaration] = STATE(20395),
    [sym_parameter_declaration] = STATE(20395),
    [sym__any_parameter_declaration] = STATE(20395),
    [sym_data_declaration] = STATE(5408),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14364),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(12782),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(15594),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_overload_declaration] = STATE(5408),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_let_declaration] = STATE(5408),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(5500),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(8357),
    [sym_package_scope] = STATE(12786),
    [aux_sym__description_repeat1] = STATE(5500),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3148),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_bind] = ACTIONS(2141),
    [anon_sym_const] = ACTIONS(2608),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(2157),
    [anon_sym_import] = ACTIONS(2159),
    [anon_sym_typedef] = ACTIONS(2161),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(2163),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_let] = ACTIONS(2183),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(2225),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [548] = {
    [sym_include_compiler_directive] = STATE(549),
    [sym_text_macro_definition] = STATE(549),
    [sym_text_macro_usage] = STATE(549),
    [sym_id_directive] = STATE(549),
    [sym_zero_directive] = STATE(549),
    [sym_timescale_compiler_directive] = STATE(549),
    [sym_default_nettype_compiler_directive] = STATE(549),
    [sym_unconnected_drive] = STATE(549),
    [sym_line_compiler_directive] = STATE(549),
    [sym_begin_keywords] = STATE(549),
    [sym__directives] = STATE(549),
    [sym__description] = STATE(549),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(549),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(549),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(549),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_package_declaration] = STATE(549),
    [sym_timeunits_declaration] = STATE(549),
    [sym_bind_directive] = STATE(549),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(549),
    [sym_package_or_generate_item_declaration] = STATE(549),
    [sym_anonymous_program] = STATE(549),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(549),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_udp_nonansi_declaration] = STATE(11645),
    [sym_udp_ansi_declaration] = STATE(12517),
    [sym_udp_declaration] = STATE(549),
    [sym_attribute_instance] = STATE(4172),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym_source_file_repeat1] = STATE(549),
    [aux_sym__description_repeat1] = STATE(4172),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [ts_builtin_sym_end] = ACTIONS(3192),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(9),
    [aux_sym_text_macro_definition_token1] = ACTIONS(11),
    [anon_sym_BQUOTE] = ACTIONS(13),
    [aux_sym_id_directive_token1] = ACTIONS(15),
    [aux_sym_id_directive_token2] = ACTIONS(15),
    [aux_sym_id_directive_token3] = ACTIONS(15),
    [aux_sym_id_directive_token4] = ACTIONS(17),
    [aux_sym_zero_directive_token1] = ACTIONS(19),
    [aux_sym_zero_directive_token2] = ACTIONS(19),
    [aux_sym_zero_directive_token3] = ACTIONS(19),
    [aux_sym_zero_directive_token4] = ACTIONS(19),
    [aux_sym_zero_directive_token5] = ACTIONS(19),
    [aux_sym_zero_directive_token6] = ACTIONS(19),
    [aux_sym_zero_directive_token7] = ACTIONS(19),
    [aux_sym_zero_directive_token8] = ACTIONS(19),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(21),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(23),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [aux_sym_unconnected_drive_token1] = ACTIONS(27),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(29),
    [aux_sym_begin_keywords_token1] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(35),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(39),
    [anon_sym_program] = ACTIONS(41),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_package] = ACTIONS(49),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_primitive] = ACTIONS(113),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [549] = {
    [sym_include_compiler_directive] = STATE(549),
    [sym_text_macro_definition] = STATE(549),
    [sym_text_macro_usage] = STATE(549),
    [sym_id_directive] = STATE(549),
    [sym_zero_directive] = STATE(549),
    [sym_timescale_compiler_directive] = STATE(549),
    [sym_default_nettype_compiler_directive] = STATE(549),
    [sym_unconnected_drive] = STATE(549),
    [sym_line_compiler_directive] = STATE(549),
    [sym_begin_keywords] = STATE(549),
    [sym__directives] = STATE(549),
    [sym__description] = STATE(549),
    [sym_module_header] = STATE(11455),
    [sym_module_declaration] = STATE(549),
    [sym_module_keyword] = STATE(12262),
    [sym_interface_declaration] = STATE(549),
    [sym_interface_nonansi_header] = STATE(113),
    [sym_interface_ansi_header] = STATE(195),
    [sym_program_declaration] = STATE(549),
    [sym_program_nonansi_header] = STATE(563),
    [sym_program_ansi_header] = STATE(939),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_package_declaration] = STATE(549),
    [sym_timeunits_declaration] = STATE(549),
    [sym_bind_directive] = STATE(549),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(549),
    [sym_package_or_generate_item_declaration] = STATE(549),
    [sym_anonymous_program] = STATE(549),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(549),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_udp_nonansi_declaration] = STATE(11645),
    [sym_udp_ansi_declaration] = STATE(12517),
    [sym_udp_declaration] = STATE(549),
    [sym_attribute_instance] = STATE(4172),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym_source_file_repeat1] = STATE(549),
    [aux_sym__description_repeat1] = STATE(4172),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [ts_builtin_sym_end] = ACTIONS(3194),
    [sym_simple_identifier] = ACTIONS(3196),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(3199),
    [aux_sym_text_macro_definition_token1] = ACTIONS(3202),
    [anon_sym_BQUOTE] = ACTIONS(3205),
    [aux_sym_id_directive_token1] = ACTIONS(3208),
    [aux_sym_id_directive_token2] = ACTIONS(3208),
    [aux_sym_id_directive_token3] = ACTIONS(3208),
    [aux_sym_id_directive_token4] = ACTIONS(3211),
    [aux_sym_zero_directive_token1] = ACTIONS(3214),
    [aux_sym_zero_directive_token2] = ACTIONS(3214),
    [aux_sym_zero_directive_token3] = ACTIONS(3214),
    [aux_sym_zero_directive_token4] = ACTIONS(3214),
    [aux_sym_zero_directive_token5] = ACTIONS(3214),
    [aux_sym_zero_directive_token6] = ACTIONS(3214),
    [aux_sym_zero_directive_token7] = ACTIONS(3214),
    [aux_sym_zero_directive_token8] = ACTIONS(3214),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(3217),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(3220),
    [anon_sym_wire] = ACTIONS(3223),
    [anon_sym_tri] = ACTIONS(3223),
    [anon_sym_tri0] = ACTIONS(3223),
    [anon_sym_tri1] = ACTIONS(3223),
    [anon_sym_wand] = ACTIONS(3223),
    [anon_sym_triand] = ACTIONS(3223),
    [anon_sym_wor] = ACTIONS(3223),
    [anon_sym_trior] = ACTIONS(3223),
    [anon_sym_trireg] = ACTIONS(3223),
    [anon_sym_uwire] = ACTIONS(3223),
    [aux_sym_unconnected_drive_token1] = ACTIONS(3226),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(3229),
    [aux_sym_begin_keywords_token1] = ACTIONS(3232),
    [anon_sym_SEMI] = ACTIONS(3235),
    [anon_sym_extern] = ACTIONS(3238),
    [anon_sym_module] = ACTIONS(3241),
    [anon_sym_macromodule] = ACTIONS(3241),
    [anon_sym_interface] = ACTIONS(3244),
    [anon_sym_program] = ACTIONS(3247),
    [anon_sym_checker] = ACTIONS(3250),
    [anon_sym_virtual] = ACTIONS(3253),
    [anon_sym_class] = ACTIONS(3256),
    [anon_sym_package] = ACTIONS(3259),
    [anon_sym_timeunit] = ACTIONS(3262),
    [anon_sym_timeprecision] = ACTIONS(3265),
    [anon_sym_type] = ACTIONS(3268),
    [anon_sym_bind] = ACTIONS(3271),
    [anon_sym_const] = ACTIONS(3274),
    [anon_sym_function] = ACTIONS(3277),
    [anon_sym_static] = ACTIONS(3280),
    [anon_sym_constraint] = ACTIONS(3283),
    [anon_sym_LBRACK] = ACTIONS(3286),
    [anon_sym_localparam] = ACTIONS(3289),
    [anon_sym_parameter] = ACTIONS(3292),
    [anon_sym_var] = ACTIONS(3295),
    [anon_sym_import] = ACTIONS(3298),
    [anon_sym_export] = ACTIONS(3301),
    [anon_sym_interconnect] = ACTIONS(3304),
    [anon_sym_typedef] = ACTIONS(3307),
    [anon_sym_enum] = ACTIONS(3310),
    [anon_sym_struct] = ACTIONS(3313),
    [anon_sym_union] = ACTIONS(3316),
    [anon_sym_nettype] = ACTIONS(3319),
    [anon_sym_automatic] = ACTIONS(3322),
    [anon_sym_string] = ACTIONS(3325),
    [anon_sym_chandle] = ACTIONS(3325),
    [anon_sym_event] = ACTIONS(3325),
    [anon_sym_byte] = ACTIONS(3328),
    [anon_sym_shortint] = ACTIONS(3328),
    [anon_sym_int] = ACTIONS(3328),
    [anon_sym_longint] = ACTIONS(3328),
    [anon_sym_integer] = ACTIONS(3328),
    [anon_sym_time] = ACTIONS(3328),
    [anon_sym_bit] = ACTIONS(3331),
    [anon_sym_logic] = ACTIONS(3331),
    [anon_sym_reg] = ACTIONS(3331),
    [anon_sym_shortreal] = ACTIONS(3334),
    [anon_sym_real] = ACTIONS(3334),
    [anon_sym_realtime] = ACTIONS(3334),
    [anon_sym_supply0] = ACTIONS(3223),
    [anon_sym_supply1] = ACTIONS(3223),
    [anon_sym_signed] = ACTIONS(3337),
    [anon_sym_unsigned] = ACTIONS(3337),
    [anon_sym_task] = ACTIONS(3340),
    [anon_sym_property] = ACTIONS(3343),
    [anon_sym_sequence] = ACTIONS(3346),
    [anon_sym_covergroup] = ACTIONS(3349),
    [anon_sym_let] = ACTIONS(3352),
    [anon_sym_primitive] = ACTIONS(3355),
    [anon_sym_LPAREN_STAR] = ACTIONS(3358),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3361),
    [anon_sym_DOLLARunit] = ACTIONS(3364),
  },
  [550] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15714),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15714),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_output_terminal] = STATE(19123),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(14761),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(603),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5758),
    [sym_package_scope] = STATE(12263),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(603),
    [aux_sym_checker_instantiation_repeat1] = STATE(15717),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13428),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3369),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3373),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3375),
    [anon_sym_LBRACE] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3403),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3409),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [551] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15274),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15274),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_output_terminal] = STATE(19123),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(14761),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(580),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5758),
    [sym_package_scope] = STATE(12263),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(580),
    [aux_sym_checker_instantiation_repeat1] = STATE(15275),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13428),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3411),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3413),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3415),
    [anon_sym_LBRACE] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3403),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3409),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [552] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15154),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15154),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_output_terminal] = STATE(19123),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(14761),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(574),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5758),
    [sym_package_scope] = STATE(12263),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(574),
    [aux_sym_checker_instantiation_repeat1] = STATE(15155),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13428),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3417),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3419),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3421),
    [anon_sym_LBRACE] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3403),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3409),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [553] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15353),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15353),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_output_terminal] = STATE(19123),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(14761),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(573),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5758),
    [sym_package_scope] = STATE(12263),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(573),
    [aux_sym_checker_instantiation_repeat1] = STATE(15823),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13428),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3423),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3425),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACE] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3403),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3409),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [554] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15357),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15357),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_output_terminal] = STATE(19123),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(14761),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(586),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5758),
    [sym_package_scope] = STATE(12263),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(586),
    [aux_sym_checker_instantiation_repeat1] = STATE(15358),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13428),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3429),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3431),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3403),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3409),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [555] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8077),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_SEMI] = ACTIONS(2648),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_or] = ACTIONS(2644),
    [anon_sym_and] = ACTIONS(2644),
    [anon_sym_endsequence] = ACTIONS(2644),
    [anon_sym_intersect] = ACTIONS(2644),
    [anon_sym_throughout] = ACTIONS(2644),
    [anon_sym_within] = ACTIONS(2644),
    [anon_sym_POUND_POUND] = ACTIONS(2644),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(2648),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_STAR] = ACTIONS(2644),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(2648),
    [anon_sym_LBRACK_EQ] = ACTIONS(2648),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(2648),
    [anon_sym_dist] = ACTIONS(2644),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [556] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_elaboration_system_task] = STATE(1215),
    [sym__module_common_item] = STATE(1215),
    [sym__module_or_generate_item_declaration] = STATE(1215),
    [sym_bind_directive] = STATE(1215),
    [sym_extern_tf_declaration] = STATE(1215),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(1215),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(1215),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(1215),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_interface_instantiation] = STATE(1215),
    [sym_program_instantiation] = STATE(1215),
    [sym_checker_instantiation] = STATE(1224),
    [sym_loop_generate_construct] = STATE(1215),
    [sym__conditional_generate_construct] = STATE(1215),
    [sym_if_generate_construct] = STATE(1215),
    [sym_case_generate_construct] = STATE(1215),
    [sym_continuous_assign] = STATE(1215),
    [sym_net_alias] = STATE(1215),
    [sym_initial_construct] = STATE(1215),
    [sym_always_construct] = STATE(1215),
    [sym_always_keyword] = STATE(4235),
    [sym_final_construct] = STATE(1215),
    [sym__assertion_item] = STATE(1215),
    [sym_deferred_immediate_assertion_item] = STATE(1215),
    [sym__deferred_immediate_assertion_statement] = STATE(1226),
    [sym_deferred_immediate_assert_statement] = STATE(1226),
    [sym_deferred_immediate_assume_statement] = STATE(1226),
    [sym_deferred_immediate_cover_statement] = STATE(1226),
    [sym_clocking_declaration] = STATE(1215),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10744),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_extern] = ACTIONS(956),
    [anon_sym_interface] = ACTIONS(766),
    [anon_sym_program] = ACTIONS(768),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(155),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(157),
    [anon_sym_cover] = ACTIONS(159),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_alias] = ACTIONS(193),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [557] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(569),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(569),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(3475),
    [anon_sym_wire] = ACTIONS(3478),
    [anon_sym_tri] = ACTIONS(3478),
    [anon_sym_tri0] = ACTIONS(3478),
    [anon_sym_tri1] = ACTIONS(3478),
    [anon_sym_wand] = ACTIONS(3478),
    [anon_sym_triand] = ACTIONS(3478),
    [anon_sym_wor] = ACTIONS(3478),
    [anon_sym_trior] = ACTIONS(3478),
    [anon_sym_trireg] = ACTIONS(3478),
    [anon_sym_uwire] = ACTIONS(3478),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_interface] = ACTIONS(3484),
    [anon_sym_endprogram] = ACTIONS(3487),
    [anon_sym_checker] = ACTIONS(3490),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3496),
    [anon_sym_timeunit] = ACTIONS(3499),
    [anon_sym_timeprecision] = ACTIONS(3502),
    [anon_sym_type] = ACTIONS(3505),
    [anon_sym_input] = ACTIONS(3508),
    [anon_sym_output] = ACTIONS(3511),
    [anon_sym_inout] = ACTIONS(3514),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_DOLLARfatal] = ACTIONS(3520),
    [anon_sym_DOLLARerror] = ACTIONS(3523),
    [anon_sym_DOLLARwarning] = ACTIONS(3523),
    [anon_sym_DOLLARinfo] = ACTIONS(3523),
    [anon_sym_default] = ACTIONS(3526),
    [anon_sym_clocking] = ACTIONS(3529),
    [anon_sym_bind] = ACTIONS(3532),
    [anon_sym_const] = ACTIONS(3535),
    [anon_sym_function] = ACTIONS(3538),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_constraint] = ACTIONS(3544),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_LBRACK] = ACTIONS(3550),
    [anon_sym_localparam] = ACTIONS(3553),
    [anon_sym_parameter] = ACTIONS(3556),
    [anon_sym_var] = ACTIONS(3559),
    [anon_sym_import] = ACTIONS(3562),
    [anon_sym_export] = ACTIONS(3565),
    [anon_sym_genvar] = ACTIONS(3568),
    [anon_sym_interconnect] = ACTIONS(3571),
    [anon_sym_typedef] = ACTIONS(3574),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3580),
    [anon_sym_union] = ACTIONS(3583),
    [anon_sym_nettype] = ACTIONS(3586),
    [anon_sym_automatic] = ACTIONS(3589),
    [anon_sym_string] = ACTIONS(3592),
    [anon_sym_chandle] = ACTIONS(3592),
    [anon_sym_event] = ACTIONS(3592),
    [anon_sym_byte] = ACTIONS(3595),
    [anon_sym_shortint] = ACTIONS(3595),
    [anon_sym_int] = ACTIONS(3595),
    [anon_sym_longint] = ACTIONS(3595),
    [anon_sym_integer] = ACTIONS(3595),
    [anon_sym_time] = ACTIONS(3595),
    [anon_sym_bit] = ACTIONS(3598),
    [anon_sym_logic] = ACTIONS(3598),
    [anon_sym_reg] = ACTIONS(3598),
    [anon_sym_shortreal] = ACTIONS(3601),
    [anon_sym_real] = ACTIONS(3601),
    [anon_sym_realtime] = ACTIONS(3601),
    [anon_sym_supply0] = ACTIONS(3478),
    [anon_sym_supply1] = ACTIONS(3478),
    [anon_sym_signed] = ACTIONS(3604),
    [anon_sym_unsigned] = ACTIONS(3604),
    [anon_sym_task] = ACTIONS(3607),
    [anon_sym_assert] = ACTIONS(3610),
    [anon_sym_property] = ACTIONS(3613),
    [anon_sym_assume] = ACTIONS(3616),
    [anon_sym_cover] = ACTIONS(3619),
    [anon_sym_sequence] = ACTIONS(3622),
    [anon_sym_restrict] = ACTIONS(3625),
    [anon_sym_case] = ACTIONS(3628),
    [anon_sym_covergroup] = ACTIONS(3631),
    [anon_sym_let] = ACTIONS(3634),
    [anon_sym_generate] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3640),
    [anon_sym_initial] = ACTIONS(3643),
    [anon_sym_assign] = ACTIONS(3646),
    [anon_sym_final] = ACTIONS(3649),
    [anon_sym_global] = ACTIONS(3652),
    [anon_sym_LPAREN_STAR] = ACTIONS(3655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3658),
    [anon_sym_DOLLARunit] = ACTIONS(3661),
  },
  [558] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(561),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(562),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(562),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3664),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [559] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3674),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [560] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(557),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(564),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(564),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3676),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [561] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(559),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(559),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(3475),
    [anon_sym_wire] = ACTIONS(3478),
    [anon_sym_tri] = ACTIONS(3478),
    [anon_sym_tri0] = ACTIONS(3478),
    [anon_sym_tri1] = ACTIONS(3478),
    [anon_sym_wand] = ACTIONS(3478),
    [anon_sym_triand] = ACTIONS(3478),
    [anon_sym_wor] = ACTIONS(3478),
    [anon_sym_trior] = ACTIONS(3478),
    [anon_sym_trireg] = ACTIONS(3478),
    [anon_sym_uwire] = ACTIONS(3478),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_interface] = ACTIONS(3484),
    [anon_sym_endprogram] = ACTIONS(3678),
    [anon_sym_checker] = ACTIONS(3490),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3496),
    [anon_sym_timeunit] = ACTIONS(3499),
    [anon_sym_timeprecision] = ACTIONS(3502),
    [anon_sym_type] = ACTIONS(3505),
    [anon_sym_input] = ACTIONS(3508),
    [anon_sym_output] = ACTIONS(3511),
    [anon_sym_inout] = ACTIONS(3514),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_DOLLARfatal] = ACTIONS(3520),
    [anon_sym_DOLLARerror] = ACTIONS(3523),
    [anon_sym_DOLLARwarning] = ACTIONS(3523),
    [anon_sym_DOLLARinfo] = ACTIONS(3523),
    [anon_sym_default] = ACTIONS(3526),
    [anon_sym_clocking] = ACTIONS(3529),
    [anon_sym_bind] = ACTIONS(3532),
    [anon_sym_const] = ACTIONS(3535),
    [anon_sym_function] = ACTIONS(3538),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_constraint] = ACTIONS(3544),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_LBRACK] = ACTIONS(3550),
    [anon_sym_localparam] = ACTIONS(3553),
    [anon_sym_parameter] = ACTIONS(3556),
    [anon_sym_var] = ACTIONS(3559),
    [anon_sym_import] = ACTIONS(3562),
    [anon_sym_export] = ACTIONS(3565),
    [anon_sym_genvar] = ACTIONS(3568),
    [anon_sym_interconnect] = ACTIONS(3571),
    [anon_sym_typedef] = ACTIONS(3574),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3580),
    [anon_sym_union] = ACTIONS(3583),
    [anon_sym_nettype] = ACTIONS(3586),
    [anon_sym_automatic] = ACTIONS(3589),
    [anon_sym_string] = ACTIONS(3592),
    [anon_sym_chandle] = ACTIONS(3592),
    [anon_sym_event] = ACTIONS(3592),
    [anon_sym_byte] = ACTIONS(3595),
    [anon_sym_shortint] = ACTIONS(3595),
    [anon_sym_int] = ACTIONS(3595),
    [anon_sym_longint] = ACTIONS(3595),
    [anon_sym_integer] = ACTIONS(3595),
    [anon_sym_time] = ACTIONS(3595),
    [anon_sym_bit] = ACTIONS(3598),
    [anon_sym_logic] = ACTIONS(3598),
    [anon_sym_reg] = ACTIONS(3598),
    [anon_sym_shortreal] = ACTIONS(3601),
    [anon_sym_real] = ACTIONS(3601),
    [anon_sym_realtime] = ACTIONS(3601),
    [anon_sym_supply0] = ACTIONS(3478),
    [anon_sym_supply1] = ACTIONS(3478),
    [anon_sym_signed] = ACTIONS(3604),
    [anon_sym_unsigned] = ACTIONS(3604),
    [anon_sym_task] = ACTIONS(3607),
    [anon_sym_assert] = ACTIONS(3610),
    [anon_sym_property] = ACTIONS(3613),
    [anon_sym_assume] = ACTIONS(3616),
    [anon_sym_cover] = ACTIONS(3619),
    [anon_sym_sequence] = ACTIONS(3622),
    [anon_sym_restrict] = ACTIONS(3625),
    [anon_sym_case] = ACTIONS(3628),
    [anon_sym_covergroup] = ACTIONS(3631),
    [anon_sym_let] = ACTIONS(3634),
    [anon_sym_generate] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3640),
    [anon_sym_initial] = ACTIONS(3643),
    [anon_sym_assign] = ACTIONS(3646),
    [anon_sym_final] = ACTIONS(3649),
    [anon_sym_global] = ACTIONS(3652),
    [anon_sym_LPAREN_STAR] = ACTIONS(3655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3658),
    [anon_sym_DOLLARunit] = ACTIONS(3661),
  },
  [562] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3681),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [563] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(566),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(568),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(568),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3683),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [564] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3685),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [565] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3687),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [566] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(565),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(565),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(3475),
    [anon_sym_wire] = ACTIONS(3478),
    [anon_sym_tri] = ACTIONS(3478),
    [anon_sym_tri0] = ACTIONS(3478),
    [anon_sym_tri1] = ACTIONS(3478),
    [anon_sym_wand] = ACTIONS(3478),
    [anon_sym_triand] = ACTIONS(3478),
    [anon_sym_wor] = ACTIONS(3478),
    [anon_sym_trior] = ACTIONS(3478),
    [anon_sym_trireg] = ACTIONS(3478),
    [anon_sym_uwire] = ACTIONS(3478),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_interface] = ACTIONS(3484),
    [anon_sym_endprogram] = ACTIONS(3689),
    [anon_sym_checker] = ACTIONS(3490),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3496),
    [anon_sym_timeunit] = ACTIONS(3499),
    [anon_sym_timeprecision] = ACTIONS(3502),
    [anon_sym_type] = ACTIONS(3505),
    [anon_sym_input] = ACTIONS(3508),
    [anon_sym_output] = ACTIONS(3511),
    [anon_sym_inout] = ACTIONS(3514),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_DOLLARfatal] = ACTIONS(3520),
    [anon_sym_DOLLARerror] = ACTIONS(3523),
    [anon_sym_DOLLARwarning] = ACTIONS(3523),
    [anon_sym_DOLLARinfo] = ACTIONS(3523),
    [anon_sym_default] = ACTIONS(3526),
    [anon_sym_clocking] = ACTIONS(3529),
    [anon_sym_bind] = ACTIONS(3532),
    [anon_sym_const] = ACTIONS(3535),
    [anon_sym_function] = ACTIONS(3538),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_constraint] = ACTIONS(3544),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_LBRACK] = ACTIONS(3550),
    [anon_sym_localparam] = ACTIONS(3553),
    [anon_sym_parameter] = ACTIONS(3556),
    [anon_sym_var] = ACTIONS(3559),
    [anon_sym_import] = ACTIONS(3562),
    [anon_sym_export] = ACTIONS(3565),
    [anon_sym_genvar] = ACTIONS(3568),
    [anon_sym_interconnect] = ACTIONS(3571),
    [anon_sym_typedef] = ACTIONS(3574),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3580),
    [anon_sym_union] = ACTIONS(3583),
    [anon_sym_nettype] = ACTIONS(3586),
    [anon_sym_automatic] = ACTIONS(3589),
    [anon_sym_string] = ACTIONS(3592),
    [anon_sym_chandle] = ACTIONS(3592),
    [anon_sym_event] = ACTIONS(3592),
    [anon_sym_byte] = ACTIONS(3595),
    [anon_sym_shortint] = ACTIONS(3595),
    [anon_sym_int] = ACTIONS(3595),
    [anon_sym_longint] = ACTIONS(3595),
    [anon_sym_integer] = ACTIONS(3595),
    [anon_sym_time] = ACTIONS(3595),
    [anon_sym_bit] = ACTIONS(3598),
    [anon_sym_logic] = ACTIONS(3598),
    [anon_sym_reg] = ACTIONS(3598),
    [anon_sym_shortreal] = ACTIONS(3601),
    [anon_sym_real] = ACTIONS(3601),
    [anon_sym_realtime] = ACTIONS(3601),
    [anon_sym_supply0] = ACTIONS(3478),
    [anon_sym_supply1] = ACTIONS(3478),
    [anon_sym_signed] = ACTIONS(3604),
    [anon_sym_unsigned] = ACTIONS(3604),
    [anon_sym_task] = ACTIONS(3607),
    [anon_sym_assert] = ACTIONS(3610),
    [anon_sym_property] = ACTIONS(3613),
    [anon_sym_assume] = ACTIONS(3616),
    [anon_sym_cover] = ACTIONS(3619),
    [anon_sym_sequence] = ACTIONS(3622),
    [anon_sym_restrict] = ACTIONS(3625),
    [anon_sym_case] = ACTIONS(3628),
    [anon_sym_covergroup] = ACTIONS(3631),
    [anon_sym_let] = ACTIONS(3634),
    [anon_sym_generate] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3640),
    [anon_sym_initial] = ACTIONS(3643),
    [anon_sym_assign] = ACTIONS(3646),
    [anon_sym_final] = ACTIONS(3649),
    [anon_sym_global] = ACTIONS(3652),
    [anon_sym_LPAREN_STAR] = ACTIONS(3655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3658),
    [anon_sym_DOLLARunit] = ACTIONS(3661),
  },
  [567] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(3692),
    [anon_sym_wire] = ACTIONS(3695),
    [anon_sym_tri] = ACTIONS(3695),
    [anon_sym_tri0] = ACTIONS(3695),
    [anon_sym_tri1] = ACTIONS(3695),
    [anon_sym_wand] = ACTIONS(3695),
    [anon_sym_triand] = ACTIONS(3695),
    [anon_sym_wor] = ACTIONS(3695),
    [anon_sym_trior] = ACTIONS(3695),
    [anon_sym_trireg] = ACTIONS(3695),
    [anon_sym_uwire] = ACTIONS(3695),
    [anon_sym_SEMI] = ACTIONS(3698),
    [anon_sym_interface] = ACTIONS(3701),
    [anon_sym_endprogram] = ACTIONS(3704),
    [anon_sym_checker] = ACTIONS(3706),
    [anon_sym_virtual] = ACTIONS(3709),
    [anon_sym_class] = ACTIONS(3712),
    [anon_sym_timeunit] = ACTIONS(3715),
    [anon_sym_timeprecision] = ACTIONS(3718),
    [anon_sym_type] = ACTIONS(3721),
    [anon_sym_input] = ACTIONS(3724),
    [anon_sym_output] = ACTIONS(3727),
    [anon_sym_inout] = ACTIONS(3730),
    [anon_sym_ref] = ACTIONS(3733),
    [anon_sym_DOLLARfatal] = ACTIONS(3736),
    [anon_sym_DOLLARerror] = ACTIONS(3739),
    [anon_sym_DOLLARwarning] = ACTIONS(3739),
    [anon_sym_DOLLARinfo] = ACTIONS(3739),
    [anon_sym_default] = ACTIONS(3742),
    [anon_sym_clocking] = ACTIONS(3745),
    [anon_sym_bind] = ACTIONS(3748),
    [anon_sym_const] = ACTIONS(3751),
    [anon_sym_function] = ACTIONS(3754),
    [anon_sym_static] = ACTIONS(3757),
    [anon_sym_constraint] = ACTIONS(3760),
    [anon_sym_if] = ACTIONS(3763),
    [anon_sym_LBRACK] = ACTIONS(3766),
    [anon_sym_localparam] = ACTIONS(3769),
    [anon_sym_parameter] = ACTIONS(3772),
    [anon_sym_var] = ACTIONS(3775),
    [anon_sym_import] = ACTIONS(3778),
    [anon_sym_export] = ACTIONS(3781),
    [anon_sym_genvar] = ACTIONS(3784),
    [anon_sym_interconnect] = ACTIONS(3787),
    [anon_sym_typedef] = ACTIONS(3790),
    [anon_sym_enum] = ACTIONS(3793),
    [anon_sym_struct] = ACTIONS(3796),
    [anon_sym_union] = ACTIONS(3799),
    [anon_sym_nettype] = ACTIONS(3802),
    [anon_sym_automatic] = ACTIONS(3805),
    [anon_sym_string] = ACTIONS(3808),
    [anon_sym_chandle] = ACTIONS(3808),
    [anon_sym_event] = ACTIONS(3808),
    [anon_sym_byte] = ACTIONS(3811),
    [anon_sym_shortint] = ACTIONS(3811),
    [anon_sym_int] = ACTIONS(3811),
    [anon_sym_longint] = ACTIONS(3811),
    [anon_sym_integer] = ACTIONS(3811),
    [anon_sym_time] = ACTIONS(3811),
    [anon_sym_bit] = ACTIONS(3814),
    [anon_sym_logic] = ACTIONS(3814),
    [anon_sym_reg] = ACTIONS(3814),
    [anon_sym_shortreal] = ACTIONS(3817),
    [anon_sym_real] = ACTIONS(3817),
    [anon_sym_realtime] = ACTIONS(3817),
    [anon_sym_supply0] = ACTIONS(3695),
    [anon_sym_supply1] = ACTIONS(3695),
    [anon_sym_signed] = ACTIONS(3820),
    [anon_sym_unsigned] = ACTIONS(3820),
    [anon_sym_task] = ACTIONS(3823),
    [anon_sym_assert] = ACTIONS(3826),
    [anon_sym_property] = ACTIONS(3829),
    [anon_sym_assume] = ACTIONS(3832),
    [anon_sym_cover] = ACTIONS(3835),
    [anon_sym_sequence] = ACTIONS(3838),
    [anon_sym_restrict] = ACTIONS(3841),
    [anon_sym_case] = ACTIONS(3844),
    [anon_sym_covergroup] = ACTIONS(3847),
    [anon_sym_let] = ACTIONS(3850),
    [anon_sym_generate] = ACTIONS(3853),
    [anon_sym_for] = ACTIONS(3856),
    [anon_sym_initial] = ACTIONS(3859),
    [anon_sym_assign] = ACTIONS(3862),
    [anon_sym_final] = ACTIONS(3865),
    [anon_sym_global] = ACTIONS(3868),
    [anon_sym_LPAREN_STAR] = ACTIONS(3871),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3874),
    [anon_sym_DOLLARunit] = ACTIONS(3877),
  },
  [568] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3880),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [569] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_port_declaration] = STATE(17846),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_program_item] = STATE(567),
    [sym_non_port_program_item] = STATE(5658),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(17865),
    [sym_input_declaration] = STATE(17865),
    [sym_output_declaration] = STATE(17865),
    [sym_interface_port_declaration] = STATE(17865),
    [sym_ref_declaration] = STATE(17865),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1465),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1465),
    [aux_sym_program_declaration_repeat1] = STATE(567),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3882),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [570] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15353),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15353),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7379),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(573),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(573),
    [aux_sym_checker_instantiation_repeat1] = STATE(15823),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3423),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3425),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [571] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_wire] = ACTIONS(1684),
    [anon_sym_tri] = ACTIONS(1684),
    [anon_sym_tri0] = ACTIONS(1684),
    [anon_sym_tri1] = ACTIONS(1684),
    [anon_sym_wand] = ACTIONS(1684),
    [anon_sym_triand] = ACTIONS(1684),
    [anon_sym_wor] = ACTIONS(1684),
    [anon_sym_trior] = ACTIONS(1684),
    [anon_sym_trireg] = ACTIONS(1684),
    [anon_sym_uwire] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_extern] = ACTIONS(1684),
    [anon_sym_interface] = ACTIONS(1684),
    [anon_sym_checker] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_class] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_RBRACE] = ACTIONS(1682),
    [anon_sym_DOLLARfatal] = ACTIONS(1682),
    [anon_sym_DOLLARerror] = ACTIONS(1682),
    [anon_sym_DOLLARwarning] = ACTIONS(1682),
    [anon_sym_DOLLARinfo] = ACTIONS(1682),
    [anon_sym_default] = ACTIONS(1684),
    [anon_sym_clocking] = ACTIONS(1684),
    [anon_sym_defparam] = ACTIONS(1684),
    [anon_sym_bind] = ACTIONS(1684),
    [anon_sym_rand] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_function] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_constraint] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_COLON_EQ] = ACTIONS(1682),
    [anon_sym_COLON_SLASH] = ACTIONS(1682),
    [anon_sym_localparam] = ACTIONS(1684),
    [anon_sym_parameter] = ACTIONS(1684),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_export] = ACTIONS(1684),
    [anon_sym_genvar] = ACTIONS(1684),
    [anon_sym_interconnect] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_supply0] = ACTIONS(1684),
    [anon_sym_supply1] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_task] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_property] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_sequence] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_not] = ACTIONS(1684),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_and] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_always] = ACTIONS(1684),
    [anon_sym_covergroup] = ACTIONS(1684),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_let] = ACTIONS(1684),
    [anon_sym_pulldown] = ACTIONS(1684),
    [anon_sym_pullup] = ACTIONS(1684),
    [anon_sym_cmos] = ACTIONS(1684),
    [anon_sym_rcmos] = ACTIONS(1684),
    [anon_sym_bufif0] = ACTIONS(1684),
    [anon_sym_bufif1] = ACTIONS(1684),
    [anon_sym_notif0] = ACTIONS(1684),
    [anon_sym_notif1] = ACTIONS(1684),
    [anon_sym_nmos] = ACTIONS(1684),
    [anon_sym_pmos] = ACTIONS(1684),
    [anon_sym_rnmos] = ACTIONS(1684),
    [anon_sym_rpmos] = ACTIONS(1684),
    [anon_sym_nand] = ACTIONS(1684),
    [anon_sym_nor] = ACTIONS(1684),
    [anon_sym_xor] = ACTIONS(1684),
    [anon_sym_xnor] = ACTIONS(1684),
    [anon_sym_buf] = ACTIONS(1684),
    [anon_sym_tranif0] = ACTIONS(1684),
    [anon_sym_tranif1] = ACTIONS(1684),
    [anon_sym_rtranif1] = ACTIONS(1684),
    [anon_sym_rtranif0] = ACTIONS(1684),
    [anon_sym_tran] = ACTIONS(1684),
    [anon_sym_rtran] = ACTIONS(1684),
    [anon_sym_generate] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_initial] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_alias] = ACTIONS(1684),
    [anon_sym_always_comb] = ACTIONS(1684),
    [anon_sym_always_latch] = ACTIONS(1684),
    [anon_sym_always_ff] = ACTIONS(1684),
    [anon_sym_final] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_global] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARunit] = ACTIONS(1682),
  },
  [572] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_wire] = ACTIONS(1688),
    [anon_sym_tri] = ACTIONS(1688),
    [anon_sym_tri0] = ACTIONS(1688),
    [anon_sym_tri1] = ACTIONS(1688),
    [anon_sym_wand] = ACTIONS(1688),
    [anon_sym_triand] = ACTIONS(1688),
    [anon_sym_wor] = ACTIONS(1688),
    [anon_sym_trior] = ACTIONS(1688),
    [anon_sym_trireg] = ACTIONS(1688),
    [anon_sym_uwire] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_extern] = ACTIONS(1688),
    [anon_sym_interface] = ACTIONS(1688),
    [anon_sym_checker] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_class] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_RBRACE] = ACTIONS(1686),
    [anon_sym_DOLLARfatal] = ACTIONS(1686),
    [anon_sym_DOLLARerror] = ACTIONS(1686),
    [anon_sym_DOLLARwarning] = ACTIONS(1686),
    [anon_sym_DOLLARinfo] = ACTIONS(1686),
    [anon_sym_default] = ACTIONS(1688),
    [anon_sym_clocking] = ACTIONS(1688),
    [anon_sym_defparam] = ACTIONS(1688),
    [anon_sym_bind] = ACTIONS(1688),
    [anon_sym_rand] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_function] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_constraint] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_COLON_EQ] = ACTIONS(1686),
    [anon_sym_COLON_SLASH] = ACTIONS(1686),
    [anon_sym_localparam] = ACTIONS(1688),
    [anon_sym_parameter] = ACTIONS(1688),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_export] = ACTIONS(1688),
    [anon_sym_genvar] = ACTIONS(1688),
    [anon_sym_interconnect] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_supply0] = ACTIONS(1688),
    [anon_sym_supply1] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_task] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_property] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_sequence] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_not] = ACTIONS(1688),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_and] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_always] = ACTIONS(1688),
    [anon_sym_covergroup] = ACTIONS(1688),
    [anon_sym_end] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_let] = ACTIONS(1688),
    [anon_sym_pulldown] = ACTIONS(1688),
    [anon_sym_pullup] = ACTIONS(1688),
    [anon_sym_cmos] = ACTIONS(1688),
    [anon_sym_rcmos] = ACTIONS(1688),
    [anon_sym_bufif0] = ACTIONS(1688),
    [anon_sym_bufif1] = ACTIONS(1688),
    [anon_sym_notif0] = ACTIONS(1688),
    [anon_sym_notif1] = ACTIONS(1688),
    [anon_sym_nmos] = ACTIONS(1688),
    [anon_sym_pmos] = ACTIONS(1688),
    [anon_sym_rnmos] = ACTIONS(1688),
    [anon_sym_rpmos] = ACTIONS(1688),
    [anon_sym_nand] = ACTIONS(1688),
    [anon_sym_nor] = ACTIONS(1688),
    [anon_sym_xor] = ACTIONS(1688),
    [anon_sym_xnor] = ACTIONS(1688),
    [anon_sym_buf] = ACTIONS(1688),
    [anon_sym_tranif0] = ACTIONS(1688),
    [anon_sym_tranif1] = ACTIONS(1688),
    [anon_sym_rtranif1] = ACTIONS(1688),
    [anon_sym_rtranif0] = ACTIONS(1688),
    [anon_sym_tran] = ACTIONS(1688),
    [anon_sym_rtran] = ACTIONS(1688),
    [anon_sym_generate] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_initial] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_alias] = ACTIONS(1688),
    [anon_sym_always_comb] = ACTIONS(1688),
    [anon_sym_always_latch] = ACTIONS(1688),
    [anon_sym_always_ff] = ACTIONS(1688),
    [anon_sym_final] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_global] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARunit] = ACTIONS(1686),
  },
  [573] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15900),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15900),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7400),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15881),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3886),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3888),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3890),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [574] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15168),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15168),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7400),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15167),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3892),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3894),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3896),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [575] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15404),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15404),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(577),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(577),
    [aux_sym_checker_instantiation_repeat1] = STATE(15406),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3898),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3900),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3902),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [576] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15839),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15839),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15836),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3904),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3908),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [577] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15447),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15447),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3910),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3912),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3914),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [578] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15714),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15714),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(582),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(582),
    [aux_sym_checker_instantiation_repeat1] = STATE(15717),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3916),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3918),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3920),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [579] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15353),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15353),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(589),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(589),
    [aux_sym_checker_instantiation_repeat1] = STATE(15823),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3922),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3924),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3926),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [580] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15287),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15287),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7400),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15286),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3928),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3930),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3932),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [581] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15841),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15841),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(583),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(583),
    [aux_sym_checker_instantiation_repeat1] = STATE(15849),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3934),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3936),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3938),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [582] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15908),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15908),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15899),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3940),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3942),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3944),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [583] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15907),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15907),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15905),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3946),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3948),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [584] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16216),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16216),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16217),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3952),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3954),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3956),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [585] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15357),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15357),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(605),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(605),
    [aux_sym_checker_instantiation_repeat1] = STATE(15358),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3958),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3960),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3962),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [586] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15402),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15402),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7400),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15399),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3964),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3966),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3968),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [587] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16247),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16247),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(609),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(609),
    [aux_sym_checker_instantiation_repeat1] = STATE(16248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3970),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3972),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3974),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [588] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16245),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16245),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16242),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3976),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3978),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3980),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [589] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15900),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15900),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15881),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3886),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3982),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3984),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [590] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16457),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16457),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(592),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(592),
    [aux_sym_checker_instantiation_repeat1] = STATE(16458),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3986),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3988),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3990),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [591] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16490),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16490),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(593),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(593),
    [aux_sym_checker_instantiation_repeat1] = STATE(16494),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3992),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(3994),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(3996),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [592] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16488),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16488),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16487),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3998),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4000),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4002),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [593] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16528),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16528),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16524),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4006),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4008),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [594] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15154),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15154),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(596),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(596),
    [aux_sym_checker_instantiation_repeat1] = STATE(15155),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4010),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4012),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4014),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [595] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15170),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15170),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(597),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(597),
    [aux_sym_checker_instantiation_repeat1] = STATE(15172),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4016),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4018),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4020),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [596] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15168),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15168),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15167),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3892),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4022),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4024),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [597] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15189),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15189),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15187),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4026),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4028),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4030),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [598] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15274),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15274),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(600),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(600),
    [aux_sym_checker_instantiation_repeat1] = STATE(15275),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4032),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4034),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4036),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [599] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15289),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15289),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(601),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(601),
    [aux_sym_checker_instantiation_repeat1] = STATE(15291),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4038),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4040),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [600] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15287),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15287),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15286),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3928),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4044),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4046),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [601] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15307),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15307),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15305),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4048),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4050),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4052),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [602] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16378),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16378),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16263),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4054),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4056),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4058),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [603] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15908),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15908),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7400),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15899),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3940),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4060),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4062),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [604] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15920),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15920),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(606),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(606),
    [aux_sym_checker_instantiation_repeat1] = STATE(15933),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4064),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4066),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4068),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [605] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15402),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15402),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(15399),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(3964),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4070),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4072),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [606] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16084),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16084),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16075),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4074),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4076),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4078),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [607] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15792),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15792),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(576),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(576),
    [aux_sym_checker_instantiation_repeat1] = STATE(15793),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4080),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4082),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4084),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [608] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(15915),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(15915),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(602),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(602),
    [aux_sym_checker_instantiation_repeat1] = STATE(15917),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4086),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4088),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4090),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [609] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16281),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16281),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_checker_instantiation_repeat1] = STATE(16279),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4092),
    [anon_sym_COMMA] = ACTIONS(3371),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_DOT_STAR] = ACTIONS(4094),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(4096),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [610] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17188),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [611] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17033),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(612),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(612),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [612] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17071),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [613] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17110),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(617),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(617),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [614] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16895),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [615] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16797),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(616),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(616),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [616] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16893),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [617] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17126),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [618] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17126),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(620),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(620),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [619] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17009),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(624),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(624),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [620] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17162),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [621] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17018),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(622),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(622),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [622] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17266),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [623] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16779),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [624] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17065),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [625] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17065),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(639),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(639),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [626] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16689),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(632),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(632),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [627] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17156),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(623),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(623),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [628] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16654),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(629),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(629),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [629] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16704),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [630] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16759),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(633),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(633),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [631] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17188),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(638),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(638),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [632] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16833),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [633] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16804),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [634] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16642),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(610),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(610),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [635] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16804),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(637),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(637),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [636] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16833),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(614),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(614),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [637] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(16836),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [638] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17198),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [639] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12496),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_property_spec] = STATE(17107),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5723),
    [sym_package_scope] = STATE(12388),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [640] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16765),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16765),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(641),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(641),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4118),
    [anon_sym_COMMA] = ACTIONS(4118),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [641] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16865),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16865),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5588),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5588),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_RPAREN] = ACTIONS(4120),
    [anon_sym_COMMA] = ACTIONS(4120),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(3407),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [642] = {
    [ts_builtin_sym_end] = ACTIONS(4122),
    [sym_simple_identifier] = ACTIONS(4124),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4122),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4122),
    [anon_sym_BQUOTE] = ACTIONS(4124),
    [aux_sym_id_directive_token1] = ACTIONS(4122),
    [aux_sym_id_directive_token2] = ACTIONS(4122),
    [aux_sym_id_directive_token3] = ACTIONS(4122),
    [aux_sym_id_directive_token4] = ACTIONS(4124),
    [aux_sym_zero_directive_token1] = ACTIONS(4122),
    [aux_sym_zero_directive_token2] = ACTIONS(4122),
    [aux_sym_zero_directive_token3] = ACTIONS(4122),
    [aux_sym_zero_directive_token4] = ACTIONS(4122),
    [aux_sym_zero_directive_token5] = ACTIONS(4122),
    [aux_sym_zero_directive_token6] = ACTIONS(4122),
    [aux_sym_zero_directive_token7] = ACTIONS(4122),
    [aux_sym_zero_directive_token8] = ACTIONS(4122),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4122),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4122),
    [anon_sym_wire] = ACTIONS(4124),
    [anon_sym_tri] = ACTIONS(4124),
    [anon_sym_tri0] = ACTIONS(4124),
    [anon_sym_tri1] = ACTIONS(4124),
    [anon_sym_wand] = ACTIONS(4124),
    [anon_sym_triand] = ACTIONS(4124),
    [anon_sym_wor] = ACTIONS(4124),
    [anon_sym_trior] = ACTIONS(4124),
    [anon_sym_trireg] = ACTIONS(4124),
    [anon_sym_uwire] = ACTIONS(4124),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4122),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4122),
    [aux_sym_begin_keywords_token1] = ACTIONS(4122),
    [anon_sym_SEMI] = ACTIONS(4122),
    [anon_sym_endmodule] = ACTIONS(4124),
    [anon_sym_extern] = ACTIONS(4124),
    [anon_sym_module] = ACTIONS(4124),
    [anon_sym_macromodule] = ACTIONS(4124),
    [anon_sym_endinterface] = ACTIONS(4124),
    [anon_sym_interface] = ACTIONS(4124),
    [anon_sym_endprogram] = ACTIONS(4124),
    [anon_sym_program] = ACTIONS(4124),
    [anon_sym_checker] = ACTIONS(4124),
    [anon_sym_virtual] = ACTIONS(4124),
    [anon_sym_class] = ACTIONS(4124),
    [anon_sym_endclass] = ACTIONS(4124),
    [anon_sym_pure] = ACTIONS(4124),
    [anon_sym_package] = ACTIONS(4124),
    [anon_sym_endpackage] = ACTIONS(4124),
    [anon_sym_timeunit] = ACTIONS(4124),
    [anon_sym_timeprecision] = ACTIONS(4124),
    [anon_sym_type] = ACTIONS(4124),
    [anon_sym_input] = ACTIONS(4124),
    [anon_sym_output] = ACTIONS(4124),
    [anon_sym_inout] = ACTIONS(4124),
    [anon_sym_ref] = ACTIONS(4124),
    [anon_sym_DOLLARfatal] = ACTIONS(4122),
    [anon_sym_DOLLARerror] = ACTIONS(4122),
    [anon_sym_DOLLARwarning] = ACTIONS(4122),
    [anon_sym_DOLLARinfo] = ACTIONS(4122),
    [anon_sym_default] = ACTIONS(4124),
    [anon_sym_clocking] = ACTIONS(4124),
    [anon_sym_defparam] = ACTIONS(4124),
    [anon_sym_bind] = ACTIONS(4124),
    [anon_sym_const] = ACTIONS(4124),
    [anon_sym_function] = ACTIONS(4124),
    [anon_sym_static] = ACTIONS(4124),
    [anon_sym_constraint] = ACTIONS(4124),
    [anon_sym_if] = ACTIONS(4124),
    [anon_sym_else] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4122),
    [anon_sym_localparam] = ACTIONS(4124),
    [anon_sym_parameter] = ACTIONS(4124),
    [anon_sym_specparam] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4124),
    [anon_sym_import] = ACTIONS(4124),
    [anon_sym_export] = ACTIONS(4124),
    [anon_sym_genvar] = ACTIONS(4124),
    [anon_sym_interconnect] = ACTIONS(4124),
    [anon_sym_typedef] = ACTIONS(4124),
    [anon_sym_enum] = ACTIONS(4124),
    [anon_sym_struct] = ACTIONS(4124),
    [anon_sym_union] = ACTIONS(4124),
    [anon_sym_nettype] = ACTIONS(4124),
    [anon_sym_automatic] = ACTIONS(4124),
    [anon_sym_string] = ACTIONS(4124),
    [anon_sym_chandle] = ACTIONS(4124),
    [anon_sym_event] = ACTIONS(4124),
    [anon_sym_byte] = ACTIONS(4124),
    [anon_sym_shortint] = ACTIONS(4124),
    [anon_sym_int] = ACTIONS(4124),
    [anon_sym_longint] = ACTIONS(4124),
    [anon_sym_integer] = ACTIONS(4124),
    [anon_sym_time] = ACTIONS(4124),
    [anon_sym_bit] = ACTIONS(4124),
    [anon_sym_logic] = ACTIONS(4124),
    [anon_sym_reg] = ACTIONS(4124),
    [anon_sym_shortreal] = ACTIONS(4124),
    [anon_sym_real] = ACTIONS(4124),
    [anon_sym_realtime] = ACTIONS(4124),
    [anon_sym_supply0] = ACTIONS(4124),
    [anon_sym_supply1] = ACTIONS(4124),
    [anon_sym_signed] = ACTIONS(4124),
    [anon_sym_unsigned] = ACTIONS(4124),
    [anon_sym_task] = ACTIONS(4124),
    [anon_sym_modport] = ACTIONS(4124),
    [anon_sym_assert] = ACTIONS(4124),
    [anon_sym_property] = ACTIONS(4124),
    [anon_sym_assume] = ACTIONS(4124),
    [anon_sym_cover] = ACTIONS(4124),
    [anon_sym_sequence] = ACTIONS(4124),
    [anon_sym_restrict] = ACTIONS(4124),
    [anon_sym_not] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_case] = ACTIONS(4124),
    [anon_sym_always] = ACTIONS(4124),
    [anon_sym_covergroup] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_pulldown] = ACTIONS(4124),
    [anon_sym_pullup] = ACTIONS(4124),
    [anon_sym_cmos] = ACTIONS(4124),
    [anon_sym_rcmos] = ACTIONS(4124),
    [anon_sym_bufif0] = ACTIONS(4124),
    [anon_sym_bufif1] = ACTIONS(4124),
    [anon_sym_notif0] = ACTIONS(4124),
    [anon_sym_notif1] = ACTIONS(4124),
    [anon_sym_nmos] = ACTIONS(4124),
    [anon_sym_pmos] = ACTIONS(4124),
    [anon_sym_rnmos] = ACTIONS(4124),
    [anon_sym_rpmos] = ACTIONS(4124),
    [anon_sym_nand] = ACTIONS(4124),
    [anon_sym_nor] = ACTIONS(4124),
    [anon_sym_xor] = ACTIONS(4124),
    [anon_sym_xnor] = ACTIONS(4124),
    [anon_sym_buf] = ACTIONS(4124),
    [anon_sym_tranif0] = ACTIONS(4124),
    [anon_sym_tranif1] = ACTIONS(4124),
    [anon_sym_rtranif1] = ACTIONS(4124),
    [anon_sym_rtranif0] = ACTIONS(4124),
    [anon_sym_tran] = ACTIONS(4124),
    [anon_sym_rtran] = ACTIONS(4124),
    [anon_sym_generate] = ACTIONS(4124),
    [anon_sym_for] = ACTIONS(4124),
    [anon_sym_primitive] = ACTIONS(4124),
    [anon_sym_initial] = ACTIONS(4124),
    [anon_sym_assign] = ACTIONS(4124),
    [anon_sym_alias] = ACTIONS(4124),
    [anon_sym_always_comb] = ACTIONS(4124),
    [anon_sym_always_latch] = ACTIONS(4124),
    [anon_sym_always_ff] = ACTIONS(4124),
    [anon_sym_final] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4124),
    [anon_sym_specify] = ACTIONS(4124),
    [anon_sym_LPAREN_STAR] = ACTIONS(4122),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4122),
    [anon_sym_DOLLARunit] = ACTIONS(4122),
  },
  [643] = {
    [ts_builtin_sym_end] = ACTIONS(4126),
    [sym_simple_identifier] = ACTIONS(4128),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4126),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4126),
    [anon_sym_BQUOTE] = ACTIONS(4128),
    [aux_sym_id_directive_token1] = ACTIONS(4126),
    [aux_sym_id_directive_token2] = ACTIONS(4126),
    [aux_sym_id_directive_token3] = ACTIONS(4126),
    [aux_sym_id_directive_token4] = ACTIONS(4128),
    [aux_sym_zero_directive_token1] = ACTIONS(4126),
    [aux_sym_zero_directive_token2] = ACTIONS(4126),
    [aux_sym_zero_directive_token3] = ACTIONS(4126),
    [aux_sym_zero_directive_token4] = ACTIONS(4126),
    [aux_sym_zero_directive_token5] = ACTIONS(4126),
    [aux_sym_zero_directive_token6] = ACTIONS(4126),
    [aux_sym_zero_directive_token7] = ACTIONS(4126),
    [aux_sym_zero_directive_token8] = ACTIONS(4126),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4126),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4126),
    [anon_sym_wire] = ACTIONS(4128),
    [anon_sym_tri] = ACTIONS(4128),
    [anon_sym_tri0] = ACTIONS(4128),
    [anon_sym_tri1] = ACTIONS(4128),
    [anon_sym_wand] = ACTIONS(4128),
    [anon_sym_triand] = ACTIONS(4128),
    [anon_sym_wor] = ACTIONS(4128),
    [anon_sym_trior] = ACTIONS(4128),
    [anon_sym_trireg] = ACTIONS(4128),
    [anon_sym_uwire] = ACTIONS(4128),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4126),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4126),
    [aux_sym_begin_keywords_token1] = ACTIONS(4126),
    [anon_sym_SEMI] = ACTIONS(4126),
    [anon_sym_endmodule] = ACTIONS(4128),
    [anon_sym_extern] = ACTIONS(4128),
    [anon_sym_module] = ACTIONS(4128),
    [anon_sym_macromodule] = ACTIONS(4128),
    [anon_sym_endinterface] = ACTIONS(4128),
    [anon_sym_interface] = ACTIONS(4128),
    [anon_sym_endprogram] = ACTIONS(4128),
    [anon_sym_program] = ACTIONS(4128),
    [anon_sym_checker] = ACTIONS(4128),
    [anon_sym_virtual] = ACTIONS(4128),
    [anon_sym_class] = ACTIONS(4128),
    [anon_sym_endclass] = ACTIONS(4128),
    [anon_sym_pure] = ACTIONS(4128),
    [anon_sym_package] = ACTIONS(4128),
    [anon_sym_endpackage] = ACTIONS(4128),
    [anon_sym_timeunit] = ACTIONS(4128),
    [anon_sym_timeprecision] = ACTIONS(4128),
    [anon_sym_type] = ACTIONS(4128),
    [anon_sym_input] = ACTIONS(4128),
    [anon_sym_output] = ACTIONS(4128),
    [anon_sym_inout] = ACTIONS(4128),
    [anon_sym_ref] = ACTIONS(4128),
    [anon_sym_DOLLARfatal] = ACTIONS(4126),
    [anon_sym_DOLLARerror] = ACTIONS(4126),
    [anon_sym_DOLLARwarning] = ACTIONS(4126),
    [anon_sym_DOLLARinfo] = ACTIONS(4126),
    [anon_sym_default] = ACTIONS(4128),
    [anon_sym_clocking] = ACTIONS(4128),
    [anon_sym_defparam] = ACTIONS(4128),
    [anon_sym_bind] = ACTIONS(4128),
    [anon_sym_const] = ACTIONS(4128),
    [anon_sym_function] = ACTIONS(4128),
    [anon_sym_static] = ACTIONS(4128),
    [anon_sym_constraint] = ACTIONS(4128),
    [anon_sym_if] = ACTIONS(4128),
    [anon_sym_else] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4126),
    [anon_sym_localparam] = ACTIONS(4128),
    [anon_sym_parameter] = ACTIONS(4128),
    [anon_sym_specparam] = ACTIONS(4128),
    [anon_sym_var] = ACTIONS(4128),
    [anon_sym_import] = ACTIONS(4128),
    [anon_sym_export] = ACTIONS(4128),
    [anon_sym_genvar] = ACTIONS(4128),
    [anon_sym_interconnect] = ACTIONS(4128),
    [anon_sym_typedef] = ACTIONS(4128),
    [anon_sym_enum] = ACTIONS(4128),
    [anon_sym_struct] = ACTIONS(4128),
    [anon_sym_union] = ACTIONS(4128),
    [anon_sym_nettype] = ACTIONS(4128),
    [anon_sym_automatic] = ACTIONS(4128),
    [anon_sym_string] = ACTIONS(4128),
    [anon_sym_chandle] = ACTIONS(4128),
    [anon_sym_event] = ACTIONS(4128),
    [anon_sym_byte] = ACTIONS(4128),
    [anon_sym_shortint] = ACTIONS(4128),
    [anon_sym_int] = ACTIONS(4128),
    [anon_sym_longint] = ACTIONS(4128),
    [anon_sym_integer] = ACTIONS(4128),
    [anon_sym_time] = ACTIONS(4128),
    [anon_sym_bit] = ACTIONS(4128),
    [anon_sym_logic] = ACTIONS(4128),
    [anon_sym_reg] = ACTIONS(4128),
    [anon_sym_shortreal] = ACTIONS(4128),
    [anon_sym_real] = ACTIONS(4128),
    [anon_sym_realtime] = ACTIONS(4128),
    [anon_sym_supply0] = ACTIONS(4128),
    [anon_sym_supply1] = ACTIONS(4128),
    [anon_sym_signed] = ACTIONS(4128),
    [anon_sym_unsigned] = ACTIONS(4128),
    [anon_sym_task] = ACTIONS(4128),
    [anon_sym_modport] = ACTIONS(4128),
    [anon_sym_assert] = ACTIONS(4128),
    [anon_sym_property] = ACTIONS(4128),
    [anon_sym_assume] = ACTIONS(4128),
    [anon_sym_cover] = ACTIONS(4128),
    [anon_sym_sequence] = ACTIONS(4128),
    [anon_sym_restrict] = ACTIONS(4128),
    [anon_sym_not] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_case] = ACTIONS(4128),
    [anon_sym_always] = ACTIONS(4128),
    [anon_sym_covergroup] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_pulldown] = ACTIONS(4128),
    [anon_sym_pullup] = ACTIONS(4128),
    [anon_sym_cmos] = ACTIONS(4128),
    [anon_sym_rcmos] = ACTIONS(4128),
    [anon_sym_bufif0] = ACTIONS(4128),
    [anon_sym_bufif1] = ACTIONS(4128),
    [anon_sym_notif0] = ACTIONS(4128),
    [anon_sym_notif1] = ACTIONS(4128),
    [anon_sym_nmos] = ACTIONS(4128),
    [anon_sym_pmos] = ACTIONS(4128),
    [anon_sym_rnmos] = ACTIONS(4128),
    [anon_sym_rpmos] = ACTIONS(4128),
    [anon_sym_nand] = ACTIONS(4128),
    [anon_sym_nor] = ACTIONS(4128),
    [anon_sym_xor] = ACTIONS(4128),
    [anon_sym_xnor] = ACTIONS(4128),
    [anon_sym_buf] = ACTIONS(4128),
    [anon_sym_tranif0] = ACTIONS(4128),
    [anon_sym_tranif1] = ACTIONS(4128),
    [anon_sym_rtranif1] = ACTIONS(4128),
    [anon_sym_rtranif0] = ACTIONS(4128),
    [anon_sym_tran] = ACTIONS(4128),
    [anon_sym_rtran] = ACTIONS(4128),
    [anon_sym_generate] = ACTIONS(4128),
    [anon_sym_for] = ACTIONS(4128),
    [anon_sym_primitive] = ACTIONS(4128),
    [anon_sym_initial] = ACTIONS(4128),
    [anon_sym_assign] = ACTIONS(4128),
    [anon_sym_alias] = ACTIONS(4128),
    [anon_sym_always_comb] = ACTIONS(4128),
    [anon_sym_always_latch] = ACTIONS(4128),
    [anon_sym_always_ff] = ACTIONS(4128),
    [anon_sym_final] = ACTIONS(4128),
    [anon_sym_global] = ACTIONS(4128),
    [anon_sym_specify] = ACTIONS(4128),
    [anon_sym_LPAREN_STAR] = ACTIONS(4126),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4126),
    [anon_sym_DOLLARunit] = ACTIONS(4126),
  },
  [644] = {
    [ts_builtin_sym_end] = ACTIONS(4130),
    [sym_simple_identifier] = ACTIONS(4132),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4130),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4130),
    [anon_sym_BQUOTE] = ACTIONS(4132),
    [aux_sym_id_directive_token1] = ACTIONS(4130),
    [aux_sym_id_directive_token2] = ACTIONS(4130),
    [aux_sym_id_directive_token3] = ACTIONS(4130),
    [aux_sym_id_directive_token4] = ACTIONS(4132),
    [aux_sym_zero_directive_token1] = ACTIONS(4130),
    [aux_sym_zero_directive_token2] = ACTIONS(4130),
    [aux_sym_zero_directive_token3] = ACTIONS(4130),
    [aux_sym_zero_directive_token4] = ACTIONS(4130),
    [aux_sym_zero_directive_token5] = ACTIONS(4130),
    [aux_sym_zero_directive_token6] = ACTIONS(4130),
    [aux_sym_zero_directive_token7] = ACTIONS(4130),
    [aux_sym_zero_directive_token8] = ACTIONS(4130),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4130),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4130),
    [anon_sym_wire] = ACTIONS(4132),
    [anon_sym_tri] = ACTIONS(4132),
    [anon_sym_tri0] = ACTIONS(4132),
    [anon_sym_tri1] = ACTIONS(4132),
    [anon_sym_wand] = ACTIONS(4132),
    [anon_sym_triand] = ACTIONS(4132),
    [anon_sym_wor] = ACTIONS(4132),
    [anon_sym_trior] = ACTIONS(4132),
    [anon_sym_trireg] = ACTIONS(4132),
    [anon_sym_uwire] = ACTIONS(4132),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4130),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4130),
    [aux_sym_begin_keywords_token1] = ACTIONS(4130),
    [anon_sym_SEMI] = ACTIONS(4130),
    [anon_sym_endmodule] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4134),
    [anon_sym_extern] = ACTIONS(4132),
    [anon_sym_module] = ACTIONS(4132),
    [anon_sym_macromodule] = ACTIONS(4132),
    [anon_sym_endinterface] = ACTIONS(4132),
    [anon_sym_interface] = ACTIONS(4132),
    [anon_sym_endprogram] = ACTIONS(4132),
    [anon_sym_program] = ACTIONS(4132),
    [anon_sym_checker] = ACTIONS(4132),
    [anon_sym_virtual] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4132),
    [anon_sym_package] = ACTIONS(4132),
    [anon_sym_endpackage] = ACTIONS(4132),
    [anon_sym_timeunit] = ACTIONS(4132),
    [anon_sym_timeprecision] = ACTIONS(4132),
    [anon_sym_type] = ACTIONS(4132),
    [anon_sym_input] = ACTIONS(4132),
    [anon_sym_output] = ACTIONS(4132),
    [anon_sym_inout] = ACTIONS(4132),
    [anon_sym_ref] = ACTIONS(4132),
    [anon_sym_DOLLARfatal] = ACTIONS(4130),
    [anon_sym_DOLLARerror] = ACTIONS(4130),
    [anon_sym_DOLLARwarning] = ACTIONS(4130),
    [anon_sym_DOLLARinfo] = ACTIONS(4130),
    [anon_sym_default] = ACTIONS(4132),
    [anon_sym_clocking] = ACTIONS(4132),
    [anon_sym_defparam] = ACTIONS(4132),
    [anon_sym_bind] = ACTIONS(4132),
    [anon_sym_const] = ACTIONS(4132),
    [anon_sym_function] = ACTIONS(4132),
    [anon_sym_static] = ACTIONS(4132),
    [anon_sym_constraint] = ACTIONS(4132),
    [anon_sym_if] = ACTIONS(4132),
    [anon_sym_else] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4130),
    [anon_sym_localparam] = ACTIONS(4132),
    [anon_sym_parameter] = ACTIONS(4132),
    [anon_sym_specparam] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4132),
    [anon_sym_import] = ACTIONS(4132),
    [anon_sym_export] = ACTIONS(4132),
    [anon_sym_genvar] = ACTIONS(4132),
    [anon_sym_interconnect] = ACTIONS(4132),
    [anon_sym_typedef] = ACTIONS(4132),
    [anon_sym_enum] = ACTIONS(4132),
    [anon_sym_struct] = ACTIONS(4132),
    [anon_sym_union] = ACTIONS(4132),
    [anon_sym_nettype] = ACTIONS(4132),
    [anon_sym_automatic] = ACTIONS(4132),
    [anon_sym_string] = ACTIONS(4132),
    [anon_sym_chandle] = ACTIONS(4132),
    [anon_sym_event] = ACTIONS(4132),
    [anon_sym_byte] = ACTIONS(4132),
    [anon_sym_shortint] = ACTIONS(4132),
    [anon_sym_int] = ACTIONS(4132),
    [anon_sym_longint] = ACTIONS(4132),
    [anon_sym_integer] = ACTIONS(4132),
    [anon_sym_time] = ACTIONS(4132),
    [anon_sym_bit] = ACTIONS(4132),
    [anon_sym_logic] = ACTIONS(4132),
    [anon_sym_reg] = ACTIONS(4132),
    [anon_sym_shortreal] = ACTIONS(4132),
    [anon_sym_real] = ACTIONS(4132),
    [anon_sym_realtime] = ACTIONS(4132),
    [anon_sym_supply0] = ACTIONS(4132),
    [anon_sym_supply1] = ACTIONS(4132),
    [anon_sym_signed] = ACTIONS(4132),
    [anon_sym_unsigned] = ACTIONS(4132),
    [anon_sym_task] = ACTIONS(4132),
    [anon_sym_modport] = ACTIONS(4132),
    [anon_sym_assert] = ACTIONS(4132),
    [anon_sym_property] = ACTIONS(4132),
    [anon_sym_assume] = ACTIONS(4132),
    [anon_sym_cover] = ACTIONS(4132),
    [anon_sym_sequence] = ACTIONS(4132),
    [anon_sym_restrict] = ACTIONS(4132),
    [anon_sym_not] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_case] = ACTIONS(4132),
    [anon_sym_always] = ACTIONS(4132),
    [anon_sym_covergroup] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_pulldown] = ACTIONS(4132),
    [anon_sym_pullup] = ACTIONS(4132),
    [anon_sym_cmos] = ACTIONS(4132),
    [anon_sym_rcmos] = ACTIONS(4132),
    [anon_sym_bufif0] = ACTIONS(4132),
    [anon_sym_bufif1] = ACTIONS(4132),
    [anon_sym_notif0] = ACTIONS(4132),
    [anon_sym_notif1] = ACTIONS(4132),
    [anon_sym_nmos] = ACTIONS(4132),
    [anon_sym_pmos] = ACTIONS(4132),
    [anon_sym_rnmos] = ACTIONS(4132),
    [anon_sym_rpmos] = ACTIONS(4132),
    [anon_sym_nand] = ACTIONS(4132),
    [anon_sym_nor] = ACTIONS(4132),
    [anon_sym_xor] = ACTIONS(4132),
    [anon_sym_xnor] = ACTIONS(4132),
    [anon_sym_buf] = ACTIONS(4132),
    [anon_sym_tranif0] = ACTIONS(4132),
    [anon_sym_tranif1] = ACTIONS(4132),
    [anon_sym_rtranif1] = ACTIONS(4132),
    [anon_sym_rtranif0] = ACTIONS(4132),
    [anon_sym_tran] = ACTIONS(4132),
    [anon_sym_rtran] = ACTIONS(4132),
    [anon_sym_generate] = ACTIONS(4132),
    [anon_sym_for] = ACTIONS(4132),
    [anon_sym_primitive] = ACTIONS(4132),
    [anon_sym_initial] = ACTIONS(4132),
    [anon_sym_assign] = ACTIONS(4132),
    [anon_sym_alias] = ACTIONS(4132),
    [anon_sym_always_comb] = ACTIONS(4132),
    [anon_sym_always_latch] = ACTIONS(4132),
    [anon_sym_always_ff] = ACTIONS(4132),
    [anon_sym_final] = ACTIONS(4132),
    [anon_sym_endclocking] = ACTIONS(4132),
    [anon_sym_global] = ACTIONS(4132),
    [anon_sym_specify] = ACTIONS(4132),
    [anon_sym_LPAREN_STAR] = ACTIONS(4130),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4130),
    [anon_sym_DOLLARunit] = ACTIONS(4130),
  },
  [645] = {
    [ts_builtin_sym_end] = ACTIONS(4136),
    [sym_simple_identifier] = ACTIONS(4138),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4136),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4136),
    [anon_sym_BQUOTE] = ACTIONS(4138),
    [aux_sym_id_directive_token1] = ACTIONS(4136),
    [aux_sym_id_directive_token2] = ACTIONS(4136),
    [aux_sym_id_directive_token3] = ACTIONS(4136),
    [aux_sym_id_directive_token4] = ACTIONS(4138),
    [aux_sym_zero_directive_token1] = ACTIONS(4136),
    [aux_sym_zero_directive_token2] = ACTIONS(4136),
    [aux_sym_zero_directive_token3] = ACTIONS(4136),
    [aux_sym_zero_directive_token4] = ACTIONS(4136),
    [aux_sym_zero_directive_token5] = ACTIONS(4136),
    [aux_sym_zero_directive_token6] = ACTIONS(4136),
    [aux_sym_zero_directive_token7] = ACTIONS(4136),
    [aux_sym_zero_directive_token8] = ACTIONS(4136),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4136),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4136),
    [anon_sym_wire] = ACTIONS(4138),
    [anon_sym_tri] = ACTIONS(4138),
    [anon_sym_tri0] = ACTIONS(4138),
    [anon_sym_tri1] = ACTIONS(4138),
    [anon_sym_wand] = ACTIONS(4138),
    [anon_sym_triand] = ACTIONS(4138),
    [anon_sym_wor] = ACTIONS(4138),
    [anon_sym_trior] = ACTIONS(4138),
    [anon_sym_trireg] = ACTIONS(4138),
    [anon_sym_uwire] = ACTIONS(4138),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4136),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4136),
    [aux_sym_begin_keywords_token1] = ACTIONS(4136),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_endmodule] = ACTIONS(4138),
    [anon_sym_extern] = ACTIONS(4138),
    [anon_sym_module] = ACTIONS(4138),
    [anon_sym_macromodule] = ACTIONS(4138),
    [anon_sym_endinterface] = ACTIONS(4138),
    [anon_sym_interface] = ACTIONS(4138),
    [anon_sym_endprogram] = ACTIONS(4138),
    [anon_sym_program] = ACTIONS(4138),
    [anon_sym_checker] = ACTIONS(4138),
    [anon_sym_virtual] = ACTIONS(4138),
    [anon_sym_class] = ACTIONS(4138),
    [anon_sym_endclass] = ACTIONS(4138),
    [anon_sym_pure] = ACTIONS(4138),
    [anon_sym_package] = ACTIONS(4138),
    [anon_sym_endpackage] = ACTIONS(4138),
    [anon_sym_timeunit] = ACTIONS(4138),
    [anon_sym_timeprecision] = ACTIONS(4138),
    [anon_sym_type] = ACTIONS(4138),
    [anon_sym_input] = ACTIONS(4138),
    [anon_sym_output] = ACTIONS(4138),
    [anon_sym_inout] = ACTIONS(4138),
    [anon_sym_ref] = ACTIONS(4138),
    [anon_sym_DOLLARfatal] = ACTIONS(4136),
    [anon_sym_DOLLARerror] = ACTIONS(4136),
    [anon_sym_DOLLARwarning] = ACTIONS(4136),
    [anon_sym_DOLLARinfo] = ACTIONS(4136),
    [anon_sym_default] = ACTIONS(4138),
    [anon_sym_clocking] = ACTIONS(4138),
    [anon_sym_defparam] = ACTIONS(4138),
    [anon_sym_bind] = ACTIONS(4138),
    [anon_sym_const] = ACTIONS(4138),
    [anon_sym_function] = ACTIONS(4138),
    [anon_sym_static] = ACTIONS(4138),
    [anon_sym_constraint] = ACTIONS(4138),
    [anon_sym_if] = ACTIONS(4138),
    [anon_sym_else] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_localparam] = ACTIONS(4138),
    [anon_sym_parameter] = ACTIONS(4138),
    [anon_sym_specparam] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_import] = ACTIONS(4138),
    [anon_sym_export] = ACTIONS(4138),
    [anon_sym_genvar] = ACTIONS(4138),
    [anon_sym_interconnect] = ACTIONS(4138),
    [anon_sym_typedef] = ACTIONS(4138),
    [anon_sym_enum] = ACTIONS(4138),
    [anon_sym_struct] = ACTIONS(4138),
    [anon_sym_union] = ACTIONS(4138),
    [anon_sym_nettype] = ACTIONS(4138),
    [anon_sym_automatic] = ACTIONS(4138),
    [anon_sym_string] = ACTIONS(4138),
    [anon_sym_chandle] = ACTIONS(4138),
    [anon_sym_event] = ACTIONS(4138),
    [anon_sym_byte] = ACTIONS(4138),
    [anon_sym_shortint] = ACTIONS(4138),
    [anon_sym_int] = ACTIONS(4138),
    [anon_sym_longint] = ACTIONS(4138),
    [anon_sym_integer] = ACTIONS(4138),
    [anon_sym_time] = ACTIONS(4138),
    [anon_sym_bit] = ACTIONS(4138),
    [anon_sym_logic] = ACTIONS(4138),
    [anon_sym_reg] = ACTIONS(4138),
    [anon_sym_shortreal] = ACTIONS(4138),
    [anon_sym_real] = ACTIONS(4138),
    [anon_sym_realtime] = ACTIONS(4138),
    [anon_sym_supply0] = ACTIONS(4138),
    [anon_sym_supply1] = ACTIONS(4138),
    [anon_sym_signed] = ACTIONS(4138),
    [anon_sym_unsigned] = ACTIONS(4138),
    [anon_sym_task] = ACTIONS(4138),
    [anon_sym_modport] = ACTIONS(4138),
    [anon_sym_assert] = ACTIONS(4138),
    [anon_sym_property] = ACTIONS(4138),
    [anon_sym_assume] = ACTIONS(4138),
    [anon_sym_cover] = ACTIONS(4138),
    [anon_sym_sequence] = ACTIONS(4138),
    [anon_sym_restrict] = ACTIONS(4138),
    [anon_sym_not] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_case] = ACTIONS(4138),
    [anon_sym_always] = ACTIONS(4138),
    [anon_sym_covergroup] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_pulldown] = ACTIONS(4138),
    [anon_sym_pullup] = ACTIONS(4138),
    [anon_sym_cmos] = ACTIONS(4138),
    [anon_sym_rcmos] = ACTIONS(4138),
    [anon_sym_bufif0] = ACTIONS(4138),
    [anon_sym_bufif1] = ACTIONS(4138),
    [anon_sym_notif0] = ACTIONS(4138),
    [anon_sym_notif1] = ACTIONS(4138),
    [anon_sym_nmos] = ACTIONS(4138),
    [anon_sym_pmos] = ACTIONS(4138),
    [anon_sym_rnmos] = ACTIONS(4138),
    [anon_sym_rpmos] = ACTIONS(4138),
    [anon_sym_nand] = ACTIONS(4138),
    [anon_sym_nor] = ACTIONS(4138),
    [anon_sym_xor] = ACTIONS(4138),
    [anon_sym_xnor] = ACTIONS(4138),
    [anon_sym_buf] = ACTIONS(4138),
    [anon_sym_tranif0] = ACTIONS(4138),
    [anon_sym_tranif1] = ACTIONS(4138),
    [anon_sym_rtranif1] = ACTIONS(4138),
    [anon_sym_rtranif0] = ACTIONS(4138),
    [anon_sym_tran] = ACTIONS(4138),
    [anon_sym_rtran] = ACTIONS(4138),
    [anon_sym_generate] = ACTIONS(4138),
    [anon_sym_for] = ACTIONS(4138),
    [anon_sym_primitive] = ACTIONS(4138),
    [anon_sym_initial] = ACTIONS(4138),
    [anon_sym_assign] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_always_comb] = ACTIONS(4138),
    [anon_sym_always_latch] = ACTIONS(4138),
    [anon_sym_always_ff] = ACTIONS(4138),
    [anon_sym_final] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_specify] = ACTIONS(4138),
    [anon_sym_LPAREN_STAR] = ACTIONS(4136),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4136),
    [anon_sym_DOLLARunit] = ACTIONS(4136),
  },
  [646] = {
    [ts_builtin_sym_end] = ACTIONS(4140),
    [sym_simple_identifier] = ACTIONS(4142),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4140),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4140),
    [anon_sym_BQUOTE] = ACTIONS(4142),
    [aux_sym_id_directive_token1] = ACTIONS(4140),
    [aux_sym_id_directive_token2] = ACTIONS(4140),
    [aux_sym_id_directive_token3] = ACTIONS(4140),
    [aux_sym_id_directive_token4] = ACTIONS(4142),
    [aux_sym_zero_directive_token1] = ACTIONS(4140),
    [aux_sym_zero_directive_token2] = ACTIONS(4140),
    [aux_sym_zero_directive_token3] = ACTIONS(4140),
    [aux_sym_zero_directive_token4] = ACTIONS(4140),
    [aux_sym_zero_directive_token5] = ACTIONS(4140),
    [aux_sym_zero_directive_token6] = ACTIONS(4140),
    [aux_sym_zero_directive_token7] = ACTIONS(4140),
    [aux_sym_zero_directive_token8] = ACTIONS(4140),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4140),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4140),
    [anon_sym_wire] = ACTIONS(4142),
    [anon_sym_tri] = ACTIONS(4142),
    [anon_sym_tri0] = ACTIONS(4142),
    [anon_sym_tri1] = ACTIONS(4142),
    [anon_sym_wand] = ACTIONS(4142),
    [anon_sym_triand] = ACTIONS(4142),
    [anon_sym_wor] = ACTIONS(4142),
    [anon_sym_trior] = ACTIONS(4142),
    [anon_sym_trireg] = ACTIONS(4142),
    [anon_sym_uwire] = ACTIONS(4142),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4140),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4140),
    [aux_sym_begin_keywords_token1] = ACTIONS(4140),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_endmodule] = ACTIONS(4142),
    [anon_sym_extern] = ACTIONS(4142),
    [anon_sym_module] = ACTIONS(4142),
    [anon_sym_macromodule] = ACTIONS(4142),
    [anon_sym_endinterface] = ACTIONS(4142),
    [anon_sym_interface] = ACTIONS(4142),
    [anon_sym_endprogram] = ACTIONS(4142),
    [anon_sym_program] = ACTIONS(4142),
    [anon_sym_checker] = ACTIONS(4142),
    [anon_sym_virtual] = ACTIONS(4142),
    [anon_sym_class] = ACTIONS(4142),
    [anon_sym_endclass] = ACTIONS(4142),
    [anon_sym_pure] = ACTIONS(4142),
    [anon_sym_package] = ACTIONS(4142),
    [anon_sym_endpackage] = ACTIONS(4142),
    [anon_sym_timeunit] = ACTIONS(4142),
    [anon_sym_timeprecision] = ACTIONS(4142),
    [anon_sym_type] = ACTIONS(4142),
    [anon_sym_input] = ACTIONS(4142),
    [anon_sym_output] = ACTIONS(4142),
    [anon_sym_inout] = ACTIONS(4142),
    [anon_sym_ref] = ACTIONS(4142),
    [anon_sym_DOLLARfatal] = ACTIONS(4140),
    [anon_sym_DOLLARerror] = ACTIONS(4140),
    [anon_sym_DOLLARwarning] = ACTIONS(4140),
    [anon_sym_DOLLARinfo] = ACTIONS(4140),
    [anon_sym_default] = ACTIONS(4142),
    [anon_sym_clocking] = ACTIONS(4142),
    [anon_sym_defparam] = ACTIONS(4142),
    [anon_sym_bind] = ACTIONS(4142),
    [anon_sym_const] = ACTIONS(4142),
    [anon_sym_function] = ACTIONS(4142),
    [anon_sym_static] = ACTIONS(4142),
    [anon_sym_constraint] = ACTIONS(4142),
    [anon_sym_if] = ACTIONS(4142),
    [anon_sym_else] = ACTIONS(4142),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_localparam] = ACTIONS(4142),
    [anon_sym_parameter] = ACTIONS(4142),
    [anon_sym_specparam] = ACTIONS(4142),
    [anon_sym_var] = ACTIONS(4142),
    [anon_sym_import] = ACTIONS(4142),
    [anon_sym_export] = ACTIONS(4142),
    [anon_sym_genvar] = ACTIONS(4142),
    [anon_sym_interconnect] = ACTIONS(4142),
    [anon_sym_typedef] = ACTIONS(4142),
    [anon_sym_enum] = ACTIONS(4142),
    [anon_sym_struct] = ACTIONS(4142),
    [anon_sym_union] = ACTIONS(4142),
    [anon_sym_nettype] = ACTIONS(4142),
    [anon_sym_automatic] = ACTIONS(4142),
    [anon_sym_string] = ACTIONS(4142),
    [anon_sym_chandle] = ACTIONS(4142),
    [anon_sym_event] = ACTIONS(4142),
    [anon_sym_byte] = ACTIONS(4142),
    [anon_sym_shortint] = ACTIONS(4142),
    [anon_sym_int] = ACTIONS(4142),
    [anon_sym_longint] = ACTIONS(4142),
    [anon_sym_integer] = ACTIONS(4142),
    [anon_sym_time] = ACTIONS(4142),
    [anon_sym_bit] = ACTIONS(4142),
    [anon_sym_logic] = ACTIONS(4142),
    [anon_sym_reg] = ACTIONS(4142),
    [anon_sym_shortreal] = ACTIONS(4142),
    [anon_sym_real] = ACTIONS(4142),
    [anon_sym_realtime] = ACTIONS(4142),
    [anon_sym_supply0] = ACTIONS(4142),
    [anon_sym_supply1] = ACTIONS(4142),
    [anon_sym_signed] = ACTIONS(4142),
    [anon_sym_unsigned] = ACTIONS(4142),
    [anon_sym_task] = ACTIONS(4142),
    [anon_sym_modport] = ACTIONS(4142),
    [anon_sym_assert] = ACTIONS(4142),
    [anon_sym_property] = ACTIONS(4142),
    [anon_sym_assume] = ACTIONS(4142),
    [anon_sym_cover] = ACTIONS(4142),
    [anon_sym_sequence] = ACTIONS(4142),
    [anon_sym_restrict] = ACTIONS(4142),
    [anon_sym_not] = ACTIONS(4142),
    [anon_sym_or] = ACTIONS(4142),
    [anon_sym_and] = ACTIONS(4142),
    [anon_sym_case] = ACTIONS(4142),
    [anon_sym_always] = ACTIONS(4142),
    [anon_sym_covergroup] = ACTIONS(4142),
    [anon_sym_let] = ACTIONS(4142),
    [anon_sym_pulldown] = ACTIONS(4142),
    [anon_sym_pullup] = ACTIONS(4142),
    [anon_sym_cmos] = ACTIONS(4142),
    [anon_sym_rcmos] = ACTIONS(4142),
    [anon_sym_bufif0] = ACTIONS(4142),
    [anon_sym_bufif1] = ACTIONS(4142),
    [anon_sym_notif0] = ACTIONS(4142),
    [anon_sym_notif1] = ACTIONS(4142),
    [anon_sym_nmos] = ACTIONS(4142),
    [anon_sym_pmos] = ACTIONS(4142),
    [anon_sym_rnmos] = ACTIONS(4142),
    [anon_sym_rpmos] = ACTIONS(4142),
    [anon_sym_nand] = ACTIONS(4142),
    [anon_sym_nor] = ACTIONS(4142),
    [anon_sym_xor] = ACTIONS(4142),
    [anon_sym_xnor] = ACTIONS(4142),
    [anon_sym_buf] = ACTIONS(4142),
    [anon_sym_tranif0] = ACTIONS(4142),
    [anon_sym_tranif1] = ACTIONS(4142),
    [anon_sym_rtranif1] = ACTIONS(4142),
    [anon_sym_rtranif0] = ACTIONS(4142),
    [anon_sym_tran] = ACTIONS(4142),
    [anon_sym_rtran] = ACTIONS(4142),
    [anon_sym_generate] = ACTIONS(4142),
    [anon_sym_for] = ACTIONS(4142),
    [anon_sym_primitive] = ACTIONS(4142),
    [anon_sym_initial] = ACTIONS(4142),
    [anon_sym_assign] = ACTIONS(4142),
    [anon_sym_alias] = ACTIONS(4142),
    [anon_sym_always_comb] = ACTIONS(4142),
    [anon_sym_always_latch] = ACTIONS(4142),
    [anon_sym_always_ff] = ACTIONS(4142),
    [anon_sym_final] = ACTIONS(4142),
    [anon_sym_global] = ACTIONS(4142),
    [anon_sym_specify] = ACTIONS(4142),
    [anon_sym_LPAREN_STAR] = ACTIONS(4140),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4140),
    [anon_sym_DOLLARunit] = ACTIONS(4140),
  },
  [647] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8624),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_SEMI] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(2648),
    [anon_sym_iff] = ACTIONS(2644),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_u2013_GT] = ACTIONS(2648),
    [anon_sym_RBRACK] = ACTIONS(2648),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_or] = ACTIONS(2644),
    [anon_sym_dist] = ACTIONS(2644),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [648] = {
    [ts_builtin_sym_end] = ACTIONS(4160),
    [sym_simple_identifier] = ACTIONS(4162),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4160),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4160),
    [anon_sym_BQUOTE] = ACTIONS(4162),
    [aux_sym_id_directive_token1] = ACTIONS(4160),
    [aux_sym_id_directive_token2] = ACTIONS(4160),
    [aux_sym_id_directive_token3] = ACTIONS(4160),
    [aux_sym_id_directive_token4] = ACTIONS(4162),
    [aux_sym_zero_directive_token1] = ACTIONS(4160),
    [aux_sym_zero_directive_token2] = ACTIONS(4160),
    [aux_sym_zero_directive_token3] = ACTIONS(4160),
    [aux_sym_zero_directive_token4] = ACTIONS(4160),
    [aux_sym_zero_directive_token5] = ACTIONS(4160),
    [aux_sym_zero_directive_token6] = ACTIONS(4160),
    [aux_sym_zero_directive_token7] = ACTIONS(4160),
    [aux_sym_zero_directive_token8] = ACTIONS(4160),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4160),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4160),
    [anon_sym_wire] = ACTIONS(4162),
    [anon_sym_tri] = ACTIONS(4162),
    [anon_sym_tri0] = ACTIONS(4162),
    [anon_sym_tri1] = ACTIONS(4162),
    [anon_sym_wand] = ACTIONS(4162),
    [anon_sym_triand] = ACTIONS(4162),
    [anon_sym_wor] = ACTIONS(4162),
    [anon_sym_trior] = ACTIONS(4162),
    [anon_sym_trireg] = ACTIONS(4162),
    [anon_sym_uwire] = ACTIONS(4162),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4160),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4160),
    [aux_sym_begin_keywords_token1] = ACTIONS(4160),
    [anon_sym_SEMI] = ACTIONS(4160),
    [anon_sym_endmodule] = ACTIONS(4162),
    [anon_sym_COLON] = ACTIONS(4164),
    [anon_sym_extern] = ACTIONS(4162),
    [anon_sym_module] = ACTIONS(4162),
    [anon_sym_macromodule] = ACTIONS(4162),
    [anon_sym_endinterface] = ACTIONS(4162),
    [anon_sym_interface] = ACTIONS(4162),
    [anon_sym_endprogram] = ACTIONS(4162),
    [anon_sym_program] = ACTIONS(4162),
    [anon_sym_checker] = ACTIONS(4162),
    [anon_sym_virtual] = ACTIONS(4162),
    [anon_sym_class] = ACTIONS(4162),
    [anon_sym_package] = ACTIONS(4162),
    [anon_sym_endpackage] = ACTIONS(4162),
    [anon_sym_timeunit] = ACTIONS(4162),
    [anon_sym_timeprecision] = ACTIONS(4162),
    [anon_sym_type] = ACTIONS(4162),
    [anon_sym_input] = ACTIONS(4162),
    [anon_sym_output] = ACTIONS(4162),
    [anon_sym_inout] = ACTIONS(4162),
    [anon_sym_ref] = ACTIONS(4162),
    [anon_sym_DOLLARfatal] = ACTIONS(4160),
    [anon_sym_DOLLARerror] = ACTIONS(4160),
    [anon_sym_DOLLARwarning] = ACTIONS(4160),
    [anon_sym_DOLLARinfo] = ACTIONS(4160),
    [anon_sym_default] = ACTIONS(4162),
    [anon_sym_clocking] = ACTIONS(4162),
    [anon_sym_defparam] = ACTIONS(4162),
    [anon_sym_bind] = ACTIONS(4162),
    [anon_sym_const] = ACTIONS(4162),
    [anon_sym_function] = ACTIONS(4162),
    [anon_sym_static] = ACTIONS(4162),
    [anon_sym_constraint] = ACTIONS(4162),
    [anon_sym_if] = ACTIONS(4162),
    [anon_sym_else] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4160),
    [anon_sym_localparam] = ACTIONS(4162),
    [anon_sym_parameter] = ACTIONS(4162),
    [anon_sym_specparam] = ACTIONS(4162),
    [anon_sym_var] = ACTIONS(4162),
    [anon_sym_import] = ACTIONS(4162),
    [anon_sym_export] = ACTIONS(4162),
    [anon_sym_genvar] = ACTIONS(4162),
    [anon_sym_interconnect] = ACTIONS(4162),
    [anon_sym_typedef] = ACTIONS(4162),
    [anon_sym_enum] = ACTIONS(4162),
    [anon_sym_struct] = ACTIONS(4162),
    [anon_sym_union] = ACTIONS(4162),
    [anon_sym_nettype] = ACTIONS(4162),
    [anon_sym_automatic] = ACTIONS(4162),
    [anon_sym_string] = ACTIONS(4162),
    [anon_sym_chandle] = ACTIONS(4162),
    [anon_sym_event] = ACTIONS(4162),
    [anon_sym_byte] = ACTIONS(4162),
    [anon_sym_shortint] = ACTIONS(4162),
    [anon_sym_int] = ACTIONS(4162),
    [anon_sym_longint] = ACTIONS(4162),
    [anon_sym_integer] = ACTIONS(4162),
    [anon_sym_time] = ACTIONS(4162),
    [anon_sym_bit] = ACTIONS(4162),
    [anon_sym_logic] = ACTIONS(4162),
    [anon_sym_reg] = ACTIONS(4162),
    [anon_sym_shortreal] = ACTIONS(4162),
    [anon_sym_real] = ACTIONS(4162),
    [anon_sym_realtime] = ACTIONS(4162),
    [anon_sym_supply0] = ACTIONS(4162),
    [anon_sym_supply1] = ACTIONS(4162),
    [anon_sym_signed] = ACTIONS(4162),
    [anon_sym_unsigned] = ACTIONS(4162),
    [anon_sym_task] = ACTIONS(4162),
    [anon_sym_modport] = ACTIONS(4162),
    [anon_sym_assert] = ACTIONS(4162),
    [anon_sym_property] = ACTIONS(4162),
    [anon_sym_assume] = ACTIONS(4162),
    [anon_sym_cover] = ACTIONS(4162),
    [anon_sym_sequence] = ACTIONS(4162),
    [anon_sym_restrict] = ACTIONS(4162),
    [anon_sym_not] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_case] = ACTIONS(4162),
    [anon_sym_always] = ACTIONS(4162),
    [anon_sym_covergroup] = ACTIONS(4162),
    [anon_sym_let] = ACTIONS(4162),
    [anon_sym_pulldown] = ACTIONS(4162),
    [anon_sym_pullup] = ACTIONS(4162),
    [anon_sym_cmos] = ACTIONS(4162),
    [anon_sym_rcmos] = ACTIONS(4162),
    [anon_sym_bufif0] = ACTIONS(4162),
    [anon_sym_bufif1] = ACTIONS(4162),
    [anon_sym_notif0] = ACTIONS(4162),
    [anon_sym_notif1] = ACTIONS(4162),
    [anon_sym_nmos] = ACTIONS(4162),
    [anon_sym_pmos] = ACTIONS(4162),
    [anon_sym_rnmos] = ACTIONS(4162),
    [anon_sym_rpmos] = ACTIONS(4162),
    [anon_sym_nand] = ACTIONS(4162),
    [anon_sym_nor] = ACTIONS(4162),
    [anon_sym_xor] = ACTIONS(4162),
    [anon_sym_xnor] = ACTIONS(4162),
    [anon_sym_buf] = ACTIONS(4162),
    [anon_sym_tranif0] = ACTIONS(4162),
    [anon_sym_tranif1] = ACTIONS(4162),
    [anon_sym_rtranif1] = ACTIONS(4162),
    [anon_sym_rtranif0] = ACTIONS(4162),
    [anon_sym_tran] = ACTIONS(4162),
    [anon_sym_rtran] = ACTIONS(4162),
    [anon_sym_generate] = ACTIONS(4162),
    [anon_sym_for] = ACTIONS(4162),
    [anon_sym_primitive] = ACTIONS(4162),
    [anon_sym_initial] = ACTIONS(4162),
    [anon_sym_assign] = ACTIONS(4162),
    [anon_sym_alias] = ACTIONS(4162),
    [anon_sym_always_comb] = ACTIONS(4162),
    [anon_sym_always_latch] = ACTIONS(4162),
    [anon_sym_always_ff] = ACTIONS(4162),
    [anon_sym_final] = ACTIONS(4162),
    [anon_sym_endclocking] = ACTIONS(4162),
    [anon_sym_global] = ACTIONS(4162),
    [anon_sym_specify] = ACTIONS(4162),
    [anon_sym_LPAREN_STAR] = ACTIONS(4160),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4160),
    [anon_sym_DOLLARunit] = ACTIONS(4160),
  },
  [649] = {
    [ts_builtin_sym_end] = ACTIONS(4166),
    [sym_simple_identifier] = ACTIONS(4168),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4166),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4166),
    [anon_sym_BQUOTE] = ACTIONS(4168),
    [aux_sym_id_directive_token1] = ACTIONS(4166),
    [aux_sym_id_directive_token2] = ACTIONS(4166),
    [aux_sym_id_directive_token3] = ACTIONS(4166),
    [aux_sym_id_directive_token4] = ACTIONS(4168),
    [aux_sym_zero_directive_token1] = ACTIONS(4166),
    [aux_sym_zero_directive_token2] = ACTIONS(4166),
    [aux_sym_zero_directive_token3] = ACTIONS(4166),
    [aux_sym_zero_directive_token4] = ACTIONS(4166),
    [aux_sym_zero_directive_token5] = ACTIONS(4166),
    [aux_sym_zero_directive_token6] = ACTIONS(4166),
    [aux_sym_zero_directive_token7] = ACTIONS(4166),
    [aux_sym_zero_directive_token8] = ACTIONS(4166),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4166),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4166),
    [anon_sym_wire] = ACTIONS(4168),
    [anon_sym_tri] = ACTIONS(4168),
    [anon_sym_tri0] = ACTIONS(4168),
    [anon_sym_tri1] = ACTIONS(4168),
    [anon_sym_wand] = ACTIONS(4168),
    [anon_sym_triand] = ACTIONS(4168),
    [anon_sym_wor] = ACTIONS(4168),
    [anon_sym_trior] = ACTIONS(4168),
    [anon_sym_trireg] = ACTIONS(4168),
    [anon_sym_uwire] = ACTIONS(4168),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4166),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4166),
    [aux_sym_begin_keywords_token1] = ACTIONS(4166),
    [anon_sym_SEMI] = ACTIONS(4166),
    [anon_sym_endmodule] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4170),
    [anon_sym_extern] = ACTIONS(4168),
    [anon_sym_module] = ACTIONS(4168),
    [anon_sym_macromodule] = ACTIONS(4168),
    [anon_sym_endinterface] = ACTIONS(4168),
    [anon_sym_interface] = ACTIONS(4168),
    [anon_sym_endprogram] = ACTIONS(4168),
    [anon_sym_program] = ACTIONS(4168),
    [anon_sym_checker] = ACTIONS(4168),
    [anon_sym_virtual] = ACTIONS(4168),
    [anon_sym_class] = ACTIONS(4168),
    [anon_sym_package] = ACTIONS(4168),
    [anon_sym_endpackage] = ACTIONS(4168),
    [anon_sym_timeunit] = ACTIONS(4168),
    [anon_sym_timeprecision] = ACTIONS(4168),
    [anon_sym_type] = ACTIONS(4168),
    [anon_sym_input] = ACTIONS(4168),
    [anon_sym_output] = ACTIONS(4168),
    [anon_sym_inout] = ACTIONS(4168),
    [anon_sym_ref] = ACTIONS(4168),
    [anon_sym_DOLLARfatal] = ACTIONS(4166),
    [anon_sym_DOLLARerror] = ACTIONS(4166),
    [anon_sym_DOLLARwarning] = ACTIONS(4166),
    [anon_sym_DOLLARinfo] = ACTIONS(4166),
    [anon_sym_default] = ACTIONS(4168),
    [anon_sym_clocking] = ACTIONS(4168),
    [anon_sym_defparam] = ACTIONS(4168),
    [anon_sym_bind] = ACTIONS(4168),
    [anon_sym_const] = ACTIONS(4168),
    [anon_sym_function] = ACTIONS(4168),
    [anon_sym_static] = ACTIONS(4168),
    [anon_sym_constraint] = ACTIONS(4168),
    [anon_sym_if] = ACTIONS(4168),
    [anon_sym_else] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4166),
    [anon_sym_localparam] = ACTIONS(4168),
    [anon_sym_parameter] = ACTIONS(4168),
    [anon_sym_specparam] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4168),
    [anon_sym_import] = ACTIONS(4168),
    [anon_sym_export] = ACTIONS(4168),
    [anon_sym_genvar] = ACTIONS(4168),
    [anon_sym_interconnect] = ACTIONS(4168),
    [anon_sym_typedef] = ACTIONS(4168),
    [anon_sym_enum] = ACTIONS(4168),
    [anon_sym_struct] = ACTIONS(4168),
    [anon_sym_union] = ACTIONS(4168),
    [anon_sym_nettype] = ACTIONS(4168),
    [anon_sym_automatic] = ACTIONS(4168),
    [anon_sym_string] = ACTIONS(4168),
    [anon_sym_chandle] = ACTIONS(4168),
    [anon_sym_event] = ACTIONS(4168),
    [anon_sym_byte] = ACTIONS(4168),
    [anon_sym_shortint] = ACTIONS(4168),
    [anon_sym_int] = ACTIONS(4168),
    [anon_sym_longint] = ACTIONS(4168),
    [anon_sym_integer] = ACTIONS(4168),
    [anon_sym_time] = ACTIONS(4168),
    [anon_sym_bit] = ACTIONS(4168),
    [anon_sym_logic] = ACTIONS(4168),
    [anon_sym_reg] = ACTIONS(4168),
    [anon_sym_shortreal] = ACTIONS(4168),
    [anon_sym_real] = ACTIONS(4168),
    [anon_sym_realtime] = ACTIONS(4168),
    [anon_sym_supply0] = ACTIONS(4168),
    [anon_sym_supply1] = ACTIONS(4168),
    [anon_sym_signed] = ACTIONS(4168),
    [anon_sym_unsigned] = ACTIONS(4168),
    [anon_sym_task] = ACTIONS(4168),
    [anon_sym_modport] = ACTIONS(4168),
    [anon_sym_assert] = ACTIONS(4168),
    [anon_sym_property] = ACTIONS(4168),
    [anon_sym_assume] = ACTIONS(4168),
    [anon_sym_cover] = ACTIONS(4168),
    [anon_sym_sequence] = ACTIONS(4168),
    [anon_sym_restrict] = ACTIONS(4168),
    [anon_sym_not] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_case] = ACTIONS(4168),
    [anon_sym_always] = ACTIONS(4168),
    [anon_sym_covergroup] = ACTIONS(4168),
    [anon_sym_let] = ACTIONS(4168),
    [anon_sym_pulldown] = ACTIONS(4168),
    [anon_sym_pullup] = ACTIONS(4168),
    [anon_sym_cmos] = ACTIONS(4168),
    [anon_sym_rcmos] = ACTIONS(4168),
    [anon_sym_bufif0] = ACTIONS(4168),
    [anon_sym_bufif1] = ACTIONS(4168),
    [anon_sym_notif0] = ACTIONS(4168),
    [anon_sym_notif1] = ACTIONS(4168),
    [anon_sym_nmos] = ACTIONS(4168),
    [anon_sym_pmos] = ACTIONS(4168),
    [anon_sym_rnmos] = ACTIONS(4168),
    [anon_sym_rpmos] = ACTIONS(4168),
    [anon_sym_nand] = ACTIONS(4168),
    [anon_sym_nor] = ACTIONS(4168),
    [anon_sym_xor] = ACTIONS(4168),
    [anon_sym_xnor] = ACTIONS(4168),
    [anon_sym_buf] = ACTIONS(4168),
    [anon_sym_tranif0] = ACTIONS(4168),
    [anon_sym_tranif1] = ACTIONS(4168),
    [anon_sym_rtranif1] = ACTIONS(4168),
    [anon_sym_rtranif0] = ACTIONS(4168),
    [anon_sym_tran] = ACTIONS(4168),
    [anon_sym_rtran] = ACTIONS(4168),
    [anon_sym_generate] = ACTIONS(4168),
    [anon_sym_for] = ACTIONS(4168),
    [anon_sym_primitive] = ACTIONS(4168),
    [anon_sym_initial] = ACTIONS(4168),
    [anon_sym_assign] = ACTIONS(4168),
    [anon_sym_alias] = ACTIONS(4168),
    [anon_sym_always_comb] = ACTIONS(4168),
    [anon_sym_always_latch] = ACTIONS(4168),
    [anon_sym_always_ff] = ACTIONS(4168),
    [anon_sym_final] = ACTIONS(4168),
    [anon_sym_endclocking] = ACTIONS(4168),
    [anon_sym_global] = ACTIONS(4168),
    [anon_sym_specify] = ACTIONS(4168),
    [anon_sym_LPAREN_STAR] = ACTIONS(4166),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4166),
    [anon_sym_DOLLARunit] = ACTIONS(4166),
  },
  [650] = {
    [ts_builtin_sym_end] = ACTIONS(4172),
    [sym_simple_identifier] = ACTIONS(4174),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4172),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4172),
    [anon_sym_BQUOTE] = ACTIONS(4174),
    [aux_sym_id_directive_token1] = ACTIONS(4172),
    [aux_sym_id_directive_token2] = ACTIONS(4172),
    [aux_sym_id_directive_token3] = ACTIONS(4172),
    [aux_sym_id_directive_token4] = ACTIONS(4174),
    [aux_sym_zero_directive_token1] = ACTIONS(4172),
    [aux_sym_zero_directive_token2] = ACTIONS(4172),
    [aux_sym_zero_directive_token3] = ACTIONS(4172),
    [aux_sym_zero_directive_token4] = ACTIONS(4172),
    [aux_sym_zero_directive_token5] = ACTIONS(4172),
    [aux_sym_zero_directive_token6] = ACTIONS(4172),
    [aux_sym_zero_directive_token7] = ACTIONS(4172),
    [aux_sym_zero_directive_token8] = ACTIONS(4172),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4172),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4172),
    [anon_sym_wire] = ACTIONS(4174),
    [anon_sym_tri] = ACTIONS(4174),
    [anon_sym_tri0] = ACTIONS(4174),
    [anon_sym_tri1] = ACTIONS(4174),
    [anon_sym_wand] = ACTIONS(4174),
    [anon_sym_triand] = ACTIONS(4174),
    [anon_sym_wor] = ACTIONS(4174),
    [anon_sym_trior] = ACTIONS(4174),
    [anon_sym_trireg] = ACTIONS(4174),
    [anon_sym_uwire] = ACTIONS(4174),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4172),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4172),
    [aux_sym_begin_keywords_token1] = ACTIONS(4172),
    [anon_sym_SEMI] = ACTIONS(4172),
    [anon_sym_endmodule] = ACTIONS(4174),
    [anon_sym_COLON] = ACTIONS(4176),
    [anon_sym_extern] = ACTIONS(4174),
    [anon_sym_module] = ACTIONS(4174),
    [anon_sym_macromodule] = ACTIONS(4174),
    [anon_sym_endinterface] = ACTIONS(4174),
    [anon_sym_interface] = ACTIONS(4174),
    [anon_sym_endprogram] = ACTIONS(4174),
    [anon_sym_program] = ACTIONS(4174),
    [anon_sym_checker] = ACTIONS(4174),
    [anon_sym_virtual] = ACTIONS(4174),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_package] = ACTIONS(4174),
    [anon_sym_endpackage] = ACTIONS(4174),
    [anon_sym_timeunit] = ACTIONS(4174),
    [anon_sym_timeprecision] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_input] = ACTIONS(4174),
    [anon_sym_output] = ACTIONS(4174),
    [anon_sym_inout] = ACTIONS(4174),
    [anon_sym_ref] = ACTIONS(4174),
    [anon_sym_DOLLARfatal] = ACTIONS(4172),
    [anon_sym_DOLLARerror] = ACTIONS(4172),
    [anon_sym_DOLLARwarning] = ACTIONS(4172),
    [anon_sym_DOLLARinfo] = ACTIONS(4172),
    [anon_sym_default] = ACTIONS(4174),
    [anon_sym_clocking] = ACTIONS(4174),
    [anon_sym_defparam] = ACTIONS(4174),
    [anon_sym_bind] = ACTIONS(4174),
    [anon_sym_const] = ACTIONS(4174),
    [anon_sym_function] = ACTIONS(4174),
    [anon_sym_static] = ACTIONS(4174),
    [anon_sym_constraint] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_else] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4172),
    [anon_sym_localparam] = ACTIONS(4174),
    [anon_sym_parameter] = ACTIONS(4174),
    [anon_sym_specparam] = ACTIONS(4174),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_import] = ACTIONS(4174),
    [anon_sym_export] = ACTIONS(4174),
    [anon_sym_genvar] = ACTIONS(4174),
    [anon_sym_interconnect] = ACTIONS(4174),
    [anon_sym_typedef] = ACTIONS(4174),
    [anon_sym_enum] = ACTIONS(4174),
    [anon_sym_struct] = ACTIONS(4174),
    [anon_sym_union] = ACTIONS(4174),
    [anon_sym_nettype] = ACTIONS(4174),
    [anon_sym_automatic] = ACTIONS(4174),
    [anon_sym_string] = ACTIONS(4174),
    [anon_sym_chandle] = ACTIONS(4174),
    [anon_sym_event] = ACTIONS(4174),
    [anon_sym_byte] = ACTIONS(4174),
    [anon_sym_shortint] = ACTIONS(4174),
    [anon_sym_int] = ACTIONS(4174),
    [anon_sym_longint] = ACTIONS(4174),
    [anon_sym_integer] = ACTIONS(4174),
    [anon_sym_time] = ACTIONS(4174),
    [anon_sym_bit] = ACTIONS(4174),
    [anon_sym_logic] = ACTIONS(4174),
    [anon_sym_reg] = ACTIONS(4174),
    [anon_sym_shortreal] = ACTIONS(4174),
    [anon_sym_real] = ACTIONS(4174),
    [anon_sym_realtime] = ACTIONS(4174),
    [anon_sym_supply0] = ACTIONS(4174),
    [anon_sym_supply1] = ACTIONS(4174),
    [anon_sym_signed] = ACTIONS(4174),
    [anon_sym_unsigned] = ACTIONS(4174),
    [anon_sym_task] = ACTIONS(4174),
    [anon_sym_modport] = ACTIONS(4174),
    [anon_sym_assert] = ACTIONS(4174),
    [anon_sym_property] = ACTIONS(4174),
    [anon_sym_assume] = ACTIONS(4174),
    [anon_sym_cover] = ACTIONS(4174),
    [anon_sym_sequence] = ACTIONS(4174),
    [anon_sym_restrict] = ACTIONS(4174),
    [anon_sym_not] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_always] = ACTIONS(4174),
    [anon_sym_covergroup] = ACTIONS(4174),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_pulldown] = ACTIONS(4174),
    [anon_sym_pullup] = ACTIONS(4174),
    [anon_sym_cmos] = ACTIONS(4174),
    [anon_sym_rcmos] = ACTIONS(4174),
    [anon_sym_bufif0] = ACTIONS(4174),
    [anon_sym_bufif1] = ACTIONS(4174),
    [anon_sym_notif0] = ACTIONS(4174),
    [anon_sym_notif1] = ACTIONS(4174),
    [anon_sym_nmos] = ACTIONS(4174),
    [anon_sym_pmos] = ACTIONS(4174),
    [anon_sym_rnmos] = ACTIONS(4174),
    [anon_sym_rpmos] = ACTIONS(4174),
    [anon_sym_nand] = ACTIONS(4174),
    [anon_sym_nor] = ACTIONS(4174),
    [anon_sym_xor] = ACTIONS(4174),
    [anon_sym_xnor] = ACTIONS(4174),
    [anon_sym_buf] = ACTIONS(4174),
    [anon_sym_tranif0] = ACTIONS(4174),
    [anon_sym_tranif1] = ACTIONS(4174),
    [anon_sym_rtranif1] = ACTIONS(4174),
    [anon_sym_rtranif0] = ACTIONS(4174),
    [anon_sym_tran] = ACTIONS(4174),
    [anon_sym_rtran] = ACTIONS(4174),
    [anon_sym_generate] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_primitive] = ACTIONS(4174),
    [anon_sym_initial] = ACTIONS(4174),
    [anon_sym_assign] = ACTIONS(4174),
    [anon_sym_alias] = ACTIONS(4174),
    [anon_sym_always_comb] = ACTIONS(4174),
    [anon_sym_always_latch] = ACTIONS(4174),
    [anon_sym_always_ff] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_endclocking] = ACTIONS(4174),
    [anon_sym_global] = ACTIONS(4174),
    [anon_sym_specify] = ACTIONS(4174),
    [anon_sym_LPAREN_STAR] = ACTIONS(4172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4172),
    [anon_sym_DOLLARunit] = ACTIONS(4172),
  },
  [651] = {
    [ts_builtin_sym_end] = ACTIONS(4178),
    [sym_simple_identifier] = ACTIONS(4180),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4178),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4178),
    [anon_sym_BQUOTE] = ACTIONS(4180),
    [aux_sym_id_directive_token1] = ACTIONS(4178),
    [aux_sym_id_directive_token2] = ACTIONS(4178),
    [aux_sym_id_directive_token3] = ACTIONS(4178),
    [aux_sym_id_directive_token4] = ACTIONS(4180),
    [aux_sym_zero_directive_token1] = ACTIONS(4178),
    [aux_sym_zero_directive_token2] = ACTIONS(4178),
    [aux_sym_zero_directive_token3] = ACTIONS(4178),
    [aux_sym_zero_directive_token4] = ACTIONS(4178),
    [aux_sym_zero_directive_token5] = ACTIONS(4178),
    [aux_sym_zero_directive_token6] = ACTIONS(4178),
    [aux_sym_zero_directive_token7] = ACTIONS(4178),
    [aux_sym_zero_directive_token8] = ACTIONS(4178),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4178),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4178),
    [anon_sym_wire] = ACTIONS(4180),
    [anon_sym_tri] = ACTIONS(4180),
    [anon_sym_tri0] = ACTIONS(4180),
    [anon_sym_tri1] = ACTIONS(4180),
    [anon_sym_wand] = ACTIONS(4180),
    [anon_sym_triand] = ACTIONS(4180),
    [anon_sym_wor] = ACTIONS(4180),
    [anon_sym_trior] = ACTIONS(4180),
    [anon_sym_trireg] = ACTIONS(4180),
    [anon_sym_uwire] = ACTIONS(4180),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4178),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4178),
    [aux_sym_begin_keywords_token1] = ACTIONS(4178),
    [anon_sym_SEMI] = ACTIONS(4178),
    [anon_sym_endmodule] = ACTIONS(4180),
    [anon_sym_extern] = ACTIONS(4180),
    [anon_sym_module] = ACTIONS(4180),
    [anon_sym_macromodule] = ACTIONS(4180),
    [anon_sym_endinterface] = ACTIONS(4180),
    [anon_sym_interface] = ACTIONS(4180),
    [anon_sym_endprogram] = ACTIONS(4180),
    [anon_sym_program] = ACTIONS(4180),
    [anon_sym_checker] = ACTIONS(4180),
    [anon_sym_virtual] = ACTIONS(4180),
    [anon_sym_class] = ACTIONS(4180),
    [anon_sym_endclass] = ACTIONS(4180),
    [anon_sym_pure] = ACTIONS(4180),
    [anon_sym_package] = ACTIONS(4180),
    [anon_sym_endpackage] = ACTIONS(4180),
    [anon_sym_timeunit] = ACTIONS(4180),
    [anon_sym_timeprecision] = ACTIONS(4180),
    [anon_sym_type] = ACTIONS(4180),
    [anon_sym_input] = ACTIONS(4180),
    [anon_sym_output] = ACTIONS(4180),
    [anon_sym_inout] = ACTIONS(4180),
    [anon_sym_ref] = ACTIONS(4180),
    [anon_sym_DOLLARfatal] = ACTIONS(4178),
    [anon_sym_DOLLARerror] = ACTIONS(4178),
    [anon_sym_DOLLARwarning] = ACTIONS(4178),
    [anon_sym_DOLLARinfo] = ACTIONS(4178),
    [anon_sym_default] = ACTIONS(4180),
    [anon_sym_clocking] = ACTIONS(4180),
    [anon_sym_defparam] = ACTIONS(4180),
    [anon_sym_bind] = ACTIONS(4180),
    [anon_sym_const] = ACTIONS(4180),
    [anon_sym_function] = ACTIONS(4180),
    [anon_sym_static] = ACTIONS(4180),
    [anon_sym_constraint] = ACTIONS(4180),
    [anon_sym_if] = ACTIONS(4180),
    [anon_sym_else] = ACTIONS(4180),
    [anon_sym_LBRACK] = ACTIONS(4178),
    [anon_sym_localparam] = ACTIONS(4180),
    [anon_sym_parameter] = ACTIONS(4180),
    [anon_sym_specparam] = ACTIONS(4180),
    [anon_sym_var] = ACTIONS(4180),
    [anon_sym_import] = ACTIONS(4180),
    [anon_sym_export] = ACTIONS(4180),
    [anon_sym_genvar] = ACTIONS(4180),
    [anon_sym_interconnect] = ACTIONS(4180),
    [anon_sym_typedef] = ACTIONS(4180),
    [anon_sym_enum] = ACTIONS(4180),
    [anon_sym_struct] = ACTIONS(4180),
    [anon_sym_union] = ACTIONS(4180),
    [anon_sym_nettype] = ACTIONS(4180),
    [anon_sym_automatic] = ACTIONS(4180),
    [anon_sym_string] = ACTIONS(4180),
    [anon_sym_chandle] = ACTIONS(4180),
    [anon_sym_event] = ACTIONS(4180),
    [anon_sym_byte] = ACTIONS(4180),
    [anon_sym_shortint] = ACTIONS(4180),
    [anon_sym_int] = ACTIONS(4180),
    [anon_sym_longint] = ACTIONS(4180),
    [anon_sym_integer] = ACTIONS(4180),
    [anon_sym_time] = ACTIONS(4180),
    [anon_sym_bit] = ACTIONS(4180),
    [anon_sym_logic] = ACTIONS(4180),
    [anon_sym_reg] = ACTIONS(4180),
    [anon_sym_shortreal] = ACTIONS(4180),
    [anon_sym_real] = ACTIONS(4180),
    [anon_sym_realtime] = ACTIONS(4180),
    [anon_sym_supply0] = ACTIONS(4180),
    [anon_sym_supply1] = ACTIONS(4180),
    [anon_sym_signed] = ACTIONS(4180),
    [anon_sym_unsigned] = ACTIONS(4180),
    [anon_sym_task] = ACTIONS(4180),
    [anon_sym_modport] = ACTIONS(4180),
    [anon_sym_assert] = ACTIONS(4180),
    [anon_sym_property] = ACTIONS(4180),
    [anon_sym_assume] = ACTIONS(4180),
    [anon_sym_cover] = ACTIONS(4180),
    [anon_sym_sequence] = ACTIONS(4180),
    [anon_sym_restrict] = ACTIONS(4180),
    [anon_sym_not] = ACTIONS(4180),
    [anon_sym_or] = ACTIONS(4180),
    [anon_sym_and] = ACTIONS(4180),
    [anon_sym_case] = ACTIONS(4180),
    [anon_sym_always] = ACTIONS(4180),
    [anon_sym_covergroup] = ACTIONS(4180),
    [anon_sym_let] = ACTIONS(4180),
    [anon_sym_pulldown] = ACTIONS(4180),
    [anon_sym_pullup] = ACTIONS(4180),
    [anon_sym_cmos] = ACTIONS(4180),
    [anon_sym_rcmos] = ACTIONS(4180),
    [anon_sym_bufif0] = ACTIONS(4180),
    [anon_sym_bufif1] = ACTIONS(4180),
    [anon_sym_notif0] = ACTIONS(4180),
    [anon_sym_notif1] = ACTIONS(4180),
    [anon_sym_nmos] = ACTIONS(4180),
    [anon_sym_pmos] = ACTIONS(4180),
    [anon_sym_rnmos] = ACTIONS(4180),
    [anon_sym_rpmos] = ACTIONS(4180),
    [anon_sym_nand] = ACTIONS(4180),
    [anon_sym_nor] = ACTIONS(4180),
    [anon_sym_xor] = ACTIONS(4180),
    [anon_sym_xnor] = ACTIONS(4180),
    [anon_sym_buf] = ACTIONS(4180),
    [anon_sym_tranif0] = ACTIONS(4180),
    [anon_sym_tranif1] = ACTIONS(4180),
    [anon_sym_rtranif1] = ACTIONS(4180),
    [anon_sym_rtranif0] = ACTIONS(4180),
    [anon_sym_tran] = ACTIONS(4180),
    [anon_sym_rtran] = ACTIONS(4180),
    [anon_sym_generate] = ACTIONS(4180),
    [anon_sym_for] = ACTIONS(4180),
    [anon_sym_primitive] = ACTIONS(4180),
    [anon_sym_initial] = ACTIONS(4180),
    [anon_sym_assign] = ACTIONS(4180),
    [anon_sym_alias] = ACTIONS(4180),
    [anon_sym_always_comb] = ACTIONS(4180),
    [anon_sym_always_latch] = ACTIONS(4180),
    [anon_sym_always_ff] = ACTIONS(4180),
    [anon_sym_final] = ACTIONS(4180),
    [anon_sym_global] = ACTIONS(4180),
    [anon_sym_specify] = ACTIONS(4180),
    [anon_sym_LPAREN_STAR] = ACTIONS(4178),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4178),
    [anon_sym_DOLLARunit] = ACTIONS(4178),
  },
  [652] = {
    [ts_builtin_sym_end] = ACTIONS(4182),
    [sym_simple_identifier] = ACTIONS(4184),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4182),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4182),
    [anon_sym_BQUOTE] = ACTIONS(4184),
    [aux_sym_id_directive_token1] = ACTIONS(4182),
    [aux_sym_id_directive_token2] = ACTIONS(4182),
    [aux_sym_id_directive_token3] = ACTIONS(4182),
    [aux_sym_id_directive_token4] = ACTIONS(4184),
    [aux_sym_zero_directive_token1] = ACTIONS(4182),
    [aux_sym_zero_directive_token2] = ACTIONS(4182),
    [aux_sym_zero_directive_token3] = ACTIONS(4182),
    [aux_sym_zero_directive_token4] = ACTIONS(4182),
    [aux_sym_zero_directive_token5] = ACTIONS(4182),
    [aux_sym_zero_directive_token6] = ACTIONS(4182),
    [aux_sym_zero_directive_token7] = ACTIONS(4182),
    [aux_sym_zero_directive_token8] = ACTIONS(4182),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4182),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4182),
    [anon_sym_wire] = ACTIONS(4184),
    [anon_sym_tri] = ACTIONS(4184),
    [anon_sym_tri0] = ACTIONS(4184),
    [anon_sym_tri1] = ACTIONS(4184),
    [anon_sym_wand] = ACTIONS(4184),
    [anon_sym_triand] = ACTIONS(4184),
    [anon_sym_wor] = ACTIONS(4184),
    [anon_sym_trior] = ACTIONS(4184),
    [anon_sym_trireg] = ACTIONS(4184),
    [anon_sym_uwire] = ACTIONS(4184),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4182),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4182),
    [aux_sym_begin_keywords_token1] = ACTIONS(4182),
    [anon_sym_SEMI] = ACTIONS(4182),
    [anon_sym_endmodule] = ACTIONS(4184),
    [anon_sym_COLON] = ACTIONS(4186),
    [anon_sym_extern] = ACTIONS(4184),
    [anon_sym_module] = ACTIONS(4184),
    [anon_sym_macromodule] = ACTIONS(4184),
    [anon_sym_endinterface] = ACTIONS(4184),
    [anon_sym_interface] = ACTIONS(4184),
    [anon_sym_endprogram] = ACTIONS(4184),
    [anon_sym_program] = ACTIONS(4184),
    [anon_sym_checker] = ACTIONS(4184),
    [anon_sym_virtual] = ACTIONS(4184),
    [anon_sym_class] = ACTIONS(4184),
    [anon_sym_package] = ACTIONS(4184),
    [anon_sym_endpackage] = ACTIONS(4184),
    [anon_sym_timeunit] = ACTIONS(4184),
    [anon_sym_timeprecision] = ACTIONS(4184),
    [anon_sym_type] = ACTIONS(4184),
    [anon_sym_input] = ACTIONS(4184),
    [anon_sym_output] = ACTIONS(4184),
    [anon_sym_inout] = ACTIONS(4184),
    [anon_sym_ref] = ACTIONS(4184),
    [anon_sym_DOLLARfatal] = ACTIONS(4182),
    [anon_sym_DOLLARerror] = ACTIONS(4182),
    [anon_sym_DOLLARwarning] = ACTIONS(4182),
    [anon_sym_DOLLARinfo] = ACTIONS(4182),
    [anon_sym_default] = ACTIONS(4184),
    [anon_sym_clocking] = ACTIONS(4184),
    [anon_sym_defparam] = ACTIONS(4184),
    [anon_sym_bind] = ACTIONS(4184),
    [anon_sym_const] = ACTIONS(4184),
    [anon_sym_function] = ACTIONS(4184),
    [anon_sym_static] = ACTIONS(4184),
    [anon_sym_constraint] = ACTIONS(4184),
    [anon_sym_if] = ACTIONS(4184),
    [anon_sym_else] = ACTIONS(4184),
    [anon_sym_LBRACK] = ACTIONS(4182),
    [anon_sym_localparam] = ACTIONS(4184),
    [anon_sym_parameter] = ACTIONS(4184),
    [anon_sym_specparam] = ACTIONS(4184),
    [anon_sym_var] = ACTIONS(4184),
    [anon_sym_import] = ACTIONS(4184),
    [anon_sym_export] = ACTIONS(4184),
    [anon_sym_genvar] = ACTIONS(4184),
    [anon_sym_interconnect] = ACTIONS(4184),
    [anon_sym_typedef] = ACTIONS(4184),
    [anon_sym_enum] = ACTIONS(4184),
    [anon_sym_struct] = ACTIONS(4184),
    [anon_sym_union] = ACTIONS(4184),
    [anon_sym_nettype] = ACTIONS(4184),
    [anon_sym_automatic] = ACTIONS(4184),
    [anon_sym_string] = ACTIONS(4184),
    [anon_sym_chandle] = ACTIONS(4184),
    [anon_sym_event] = ACTIONS(4184),
    [anon_sym_byte] = ACTIONS(4184),
    [anon_sym_shortint] = ACTIONS(4184),
    [anon_sym_int] = ACTIONS(4184),
    [anon_sym_longint] = ACTIONS(4184),
    [anon_sym_integer] = ACTIONS(4184),
    [anon_sym_time] = ACTIONS(4184),
    [anon_sym_bit] = ACTIONS(4184),
    [anon_sym_logic] = ACTIONS(4184),
    [anon_sym_reg] = ACTIONS(4184),
    [anon_sym_shortreal] = ACTIONS(4184),
    [anon_sym_real] = ACTIONS(4184),
    [anon_sym_realtime] = ACTIONS(4184),
    [anon_sym_supply0] = ACTIONS(4184),
    [anon_sym_supply1] = ACTIONS(4184),
    [anon_sym_signed] = ACTIONS(4184),
    [anon_sym_unsigned] = ACTIONS(4184),
    [anon_sym_task] = ACTIONS(4184),
    [anon_sym_modport] = ACTIONS(4184),
    [anon_sym_assert] = ACTIONS(4184),
    [anon_sym_property] = ACTIONS(4184),
    [anon_sym_assume] = ACTIONS(4184),
    [anon_sym_cover] = ACTIONS(4184),
    [anon_sym_sequence] = ACTIONS(4184),
    [anon_sym_restrict] = ACTIONS(4184),
    [anon_sym_not] = ACTIONS(4184),
    [anon_sym_or] = ACTIONS(4184),
    [anon_sym_and] = ACTIONS(4184),
    [anon_sym_case] = ACTIONS(4184),
    [anon_sym_always] = ACTIONS(4184),
    [anon_sym_covergroup] = ACTIONS(4184),
    [anon_sym_let] = ACTIONS(4184),
    [anon_sym_pulldown] = ACTIONS(4184),
    [anon_sym_pullup] = ACTIONS(4184),
    [anon_sym_cmos] = ACTIONS(4184),
    [anon_sym_rcmos] = ACTIONS(4184),
    [anon_sym_bufif0] = ACTIONS(4184),
    [anon_sym_bufif1] = ACTIONS(4184),
    [anon_sym_notif0] = ACTIONS(4184),
    [anon_sym_notif1] = ACTIONS(4184),
    [anon_sym_nmos] = ACTIONS(4184),
    [anon_sym_pmos] = ACTIONS(4184),
    [anon_sym_rnmos] = ACTIONS(4184),
    [anon_sym_rpmos] = ACTIONS(4184),
    [anon_sym_nand] = ACTIONS(4184),
    [anon_sym_nor] = ACTIONS(4184),
    [anon_sym_xor] = ACTIONS(4184),
    [anon_sym_xnor] = ACTIONS(4184),
    [anon_sym_buf] = ACTIONS(4184),
    [anon_sym_tranif0] = ACTIONS(4184),
    [anon_sym_tranif1] = ACTIONS(4184),
    [anon_sym_rtranif1] = ACTIONS(4184),
    [anon_sym_rtranif0] = ACTIONS(4184),
    [anon_sym_tran] = ACTIONS(4184),
    [anon_sym_rtran] = ACTIONS(4184),
    [anon_sym_generate] = ACTIONS(4184),
    [anon_sym_for] = ACTIONS(4184),
    [anon_sym_primitive] = ACTIONS(4184),
    [anon_sym_initial] = ACTIONS(4184),
    [anon_sym_assign] = ACTIONS(4184),
    [anon_sym_alias] = ACTIONS(4184),
    [anon_sym_always_comb] = ACTIONS(4184),
    [anon_sym_always_latch] = ACTIONS(4184),
    [anon_sym_always_ff] = ACTIONS(4184),
    [anon_sym_final] = ACTIONS(4184),
    [anon_sym_endclocking] = ACTIONS(4184),
    [anon_sym_global] = ACTIONS(4184),
    [anon_sym_specify] = ACTIONS(4184),
    [anon_sym_LPAREN_STAR] = ACTIONS(4182),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4182),
    [anon_sym_DOLLARunit] = ACTIONS(4182),
  },
  [653] = {
    [ts_builtin_sym_end] = ACTIONS(4188),
    [sym_simple_identifier] = ACTIONS(4190),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4188),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4188),
    [anon_sym_BQUOTE] = ACTIONS(4190),
    [aux_sym_id_directive_token1] = ACTIONS(4188),
    [aux_sym_id_directive_token2] = ACTIONS(4188),
    [aux_sym_id_directive_token3] = ACTIONS(4188),
    [aux_sym_id_directive_token4] = ACTIONS(4190),
    [aux_sym_zero_directive_token1] = ACTIONS(4188),
    [aux_sym_zero_directive_token2] = ACTIONS(4188),
    [aux_sym_zero_directive_token3] = ACTIONS(4188),
    [aux_sym_zero_directive_token4] = ACTIONS(4188),
    [aux_sym_zero_directive_token5] = ACTIONS(4188),
    [aux_sym_zero_directive_token6] = ACTIONS(4188),
    [aux_sym_zero_directive_token7] = ACTIONS(4188),
    [aux_sym_zero_directive_token8] = ACTIONS(4188),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4188),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4188),
    [anon_sym_wire] = ACTIONS(4190),
    [anon_sym_tri] = ACTIONS(4190),
    [anon_sym_tri0] = ACTIONS(4190),
    [anon_sym_tri1] = ACTIONS(4190),
    [anon_sym_wand] = ACTIONS(4190),
    [anon_sym_triand] = ACTIONS(4190),
    [anon_sym_wor] = ACTIONS(4190),
    [anon_sym_trior] = ACTIONS(4190),
    [anon_sym_trireg] = ACTIONS(4190),
    [anon_sym_uwire] = ACTIONS(4190),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4188),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4188),
    [aux_sym_begin_keywords_token1] = ACTIONS(4188),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_endmodule] = ACTIONS(4190),
    [anon_sym_COLON] = ACTIONS(4192),
    [anon_sym_extern] = ACTIONS(4190),
    [anon_sym_module] = ACTIONS(4190),
    [anon_sym_macromodule] = ACTIONS(4190),
    [anon_sym_endinterface] = ACTIONS(4190),
    [anon_sym_interface] = ACTIONS(4190),
    [anon_sym_endprogram] = ACTIONS(4190),
    [anon_sym_program] = ACTIONS(4190),
    [anon_sym_checker] = ACTIONS(4190),
    [anon_sym_virtual] = ACTIONS(4190),
    [anon_sym_class] = ACTIONS(4190),
    [anon_sym_package] = ACTIONS(4190),
    [anon_sym_endpackage] = ACTIONS(4190),
    [anon_sym_timeunit] = ACTIONS(4190),
    [anon_sym_timeprecision] = ACTIONS(4190),
    [anon_sym_type] = ACTIONS(4190),
    [anon_sym_input] = ACTIONS(4190),
    [anon_sym_output] = ACTIONS(4190),
    [anon_sym_inout] = ACTIONS(4190),
    [anon_sym_ref] = ACTIONS(4190),
    [anon_sym_DOLLARfatal] = ACTIONS(4188),
    [anon_sym_DOLLARerror] = ACTIONS(4188),
    [anon_sym_DOLLARwarning] = ACTIONS(4188),
    [anon_sym_DOLLARinfo] = ACTIONS(4188),
    [anon_sym_default] = ACTIONS(4190),
    [anon_sym_clocking] = ACTIONS(4190),
    [anon_sym_defparam] = ACTIONS(4190),
    [anon_sym_bind] = ACTIONS(4190),
    [anon_sym_const] = ACTIONS(4190),
    [anon_sym_function] = ACTIONS(4190),
    [anon_sym_static] = ACTIONS(4190),
    [anon_sym_constraint] = ACTIONS(4190),
    [anon_sym_if] = ACTIONS(4190),
    [anon_sym_else] = ACTIONS(4190),
    [anon_sym_LBRACK] = ACTIONS(4188),
    [anon_sym_localparam] = ACTIONS(4190),
    [anon_sym_parameter] = ACTIONS(4190),
    [anon_sym_specparam] = ACTIONS(4190),
    [anon_sym_var] = ACTIONS(4190),
    [anon_sym_import] = ACTIONS(4190),
    [anon_sym_export] = ACTIONS(4190),
    [anon_sym_genvar] = ACTIONS(4190),
    [anon_sym_interconnect] = ACTIONS(4190),
    [anon_sym_typedef] = ACTIONS(4190),
    [anon_sym_enum] = ACTIONS(4190),
    [anon_sym_struct] = ACTIONS(4190),
    [anon_sym_union] = ACTIONS(4190),
    [anon_sym_nettype] = ACTIONS(4190),
    [anon_sym_automatic] = ACTIONS(4190),
    [anon_sym_string] = ACTIONS(4190),
    [anon_sym_chandle] = ACTIONS(4190),
    [anon_sym_event] = ACTIONS(4190),
    [anon_sym_byte] = ACTIONS(4190),
    [anon_sym_shortint] = ACTIONS(4190),
    [anon_sym_int] = ACTIONS(4190),
    [anon_sym_longint] = ACTIONS(4190),
    [anon_sym_integer] = ACTIONS(4190),
    [anon_sym_time] = ACTIONS(4190),
    [anon_sym_bit] = ACTIONS(4190),
    [anon_sym_logic] = ACTIONS(4190),
    [anon_sym_reg] = ACTIONS(4190),
    [anon_sym_shortreal] = ACTIONS(4190),
    [anon_sym_real] = ACTIONS(4190),
    [anon_sym_realtime] = ACTIONS(4190),
    [anon_sym_supply0] = ACTIONS(4190),
    [anon_sym_supply1] = ACTIONS(4190),
    [anon_sym_signed] = ACTIONS(4190),
    [anon_sym_unsigned] = ACTIONS(4190),
    [anon_sym_task] = ACTIONS(4190),
    [anon_sym_modport] = ACTIONS(4190),
    [anon_sym_assert] = ACTIONS(4190),
    [anon_sym_property] = ACTIONS(4190),
    [anon_sym_assume] = ACTIONS(4190),
    [anon_sym_cover] = ACTIONS(4190),
    [anon_sym_sequence] = ACTIONS(4190),
    [anon_sym_restrict] = ACTIONS(4190),
    [anon_sym_not] = ACTIONS(4190),
    [anon_sym_or] = ACTIONS(4190),
    [anon_sym_and] = ACTIONS(4190),
    [anon_sym_case] = ACTIONS(4190),
    [anon_sym_always] = ACTIONS(4190),
    [anon_sym_covergroup] = ACTIONS(4190),
    [anon_sym_let] = ACTIONS(4190),
    [anon_sym_pulldown] = ACTIONS(4190),
    [anon_sym_pullup] = ACTIONS(4190),
    [anon_sym_cmos] = ACTIONS(4190),
    [anon_sym_rcmos] = ACTIONS(4190),
    [anon_sym_bufif0] = ACTIONS(4190),
    [anon_sym_bufif1] = ACTIONS(4190),
    [anon_sym_notif0] = ACTIONS(4190),
    [anon_sym_notif1] = ACTIONS(4190),
    [anon_sym_nmos] = ACTIONS(4190),
    [anon_sym_pmos] = ACTIONS(4190),
    [anon_sym_rnmos] = ACTIONS(4190),
    [anon_sym_rpmos] = ACTIONS(4190),
    [anon_sym_nand] = ACTIONS(4190),
    [anon_sym_nor] = ACTIONS(4190),
    [anon_sym_xor] = ACTIONS(4190),
    [anon_sym_xnor] = ACTIONS(4190),
    [anon_sym_buf] = ACTIONS(4190),
    [anon_sym_tranif0] = ACTIONS(4190),
    [anon_sym_tranif1] = ACTIONS(4190),
    [anon_sym_rtranif1] = ACTIONS(4190),
    [anon_sym_rtranif0] = ACTIONS(4190),
    [anon_sym_tran] = ACTIONS(4190),
    [anon_sym_rtran] = ACTIONS(4190),
    [anon_sym_generate] = ACTIONS(4190),
    [anon_sym_for] = ACTIONS(4190),
    [anon_sym_primitive] = ACTIONS(4190),
    [anon_sym_initial] = ACTIONS(4190),
    [anon_sym_assign] = ACTIONS(4190),
    [anon_sym_alias] = ACTIONS(4190),
    [anon_sym_always_comb] = ACTIONS(4190),
    [anon_sym_always_latch] = ACTIONS(4190),
    [anon_sym_always_ff] = ACTIONS(4190),
    [anon_sym_final] = ACTIONS(4190),
    [anon_sym_endclocking] = ACTIONS(4190),
    [anon_sym_global] = ACTIONS(4190),
    [anon_sym_specify] = ACTIONS(4190),
    [anon_sym_LPAREN_STAR] = ACTIONS(4188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4188),
    [anon_sym_DOLLARunit] = ACTIONS(4188),
  },
  [654] = {
    [ts_builtin_sym_end] = ACTIONS(4194),
    [sym_simple_identifier] = ACTIONS(4196),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4194),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4194),
    [anon_sym_BQUOTE] = ACTIONS(4196),
    [aux_sym_id_directive_token1] = ACTIONS(4194),
    [aux_sym_id_directive_token2] = ACTIONS(4194),
    [aux_sym_id_directive_token3] = ACTIONS(4194),
    [aux_sym_id_directive_token4] = ACTIONS(4196),
    [aux_sym_zero_directive_token1] = ACTIONS(4194),
    [aux_sym_zero_directive_token2] = ACTIONS(4194),
    [aux_sym_zero_directive_token3] = ACTIONS(4194),
    [aux_sym_zero_directive_token4] = ACTIONS(4194),
    [aux_sym_zero_directive_token5] = ACTIONS(4194),
    [aux_sym_zero_directive_token6] = ACTIONS(4194),
    [aux_sym_zero_directive_token7] = ACTIONS(4194),
    [aux_sym_zero_directive_token8] = ACTIONS(4194),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4194),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4194),
    [anon_sym_wire] = ACTIONS(4196),
    [anon_sym_tri] = ACTIONS(4196),
    [anon_sym_tri0] = ACTIONS(4196),
    [anon_sym_tri1] = ACTIONS(4196),
    [anon_sym_wand] = ACTIONS(4196),
    [anon_sym_triand] = ACTIONS(4196),
    [anon_sym_wor] = ACTIONS(4196),
    [anon_sym_trior] = ACTIONS(4196),
    [anon_sym_trireg] = ACTIONS(4196),
    [anon_sym_uwire] = ACTIONS(4196),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4194),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4194),
    [aux_sym_begin_keywords_token1] = ACTIONS(4194),
    [anon_sym_SEMI] = ACTIONS(4194),
    [anon_sym_endmodule] = ACTIONS(4196),
    [anon_sym_extern] = ACTIONS(4196),
    [anon_sym_module] = ACTIONS(4196),
    [anon_sym_macromodule] = ACTIONS(4196),
    [anon_sym_endinterface] = ACTIONS(4196),
    [anon_sym_interface] = ACTIONS(4196),
    [anon_sym_endprogram] = ACTIONS(4196),
    [anon_sym_program] = ACTIONS(4196),
    [anon_sym_checker] = ACTIONS(4196),
    [anon_sym_virtual] = ACTIONS(4196),
    [anon_sym_class] = ACTIONS(4196),
    [anon_sym_package] = ACTIONS(4196),
    [anon_sym_endpackage] = ACTIONS(4196),
    [anon_sym_timeunit] = ACTIONS(4196),
    [anon_sym_timeprecision] = ACTIONS(4196),
    [anon_sym_type] = ACTIONS(4196),
    [anon_sym_input] = ACTIONS(4196),
    [anon_sym_output] = ACTIONS(4196),
    [anon_sym_inout] = ACTIONS(4196),
    [anon_sym_ref] = ACTIONS(4196),
    [anon_sym_DOLLARfatal] = ACTIONS(4194),
    [anon_sym_DOLLARerror] = ACTIONS(4194),
    [anon_sym_DOLLARwarning] = ACTIONS(4194),
    [anon_sym_DOLLARinfo] = ACTIONS(4194),
    [anon_sym_default] = ACTIONS(4196),
    [anon_sym_clocking] = ACTIONS(4196),
    [anon_sym_defparam] = ACTIONS(4196),
    [anon_sym_bind] = ACTIONS(4196),
    [anon_sym_const] = ACTIONS(4196),
    [anon_sym_function] = ACTIONS(4196),
    [anon_sym_static] = ACTIONS(4196),
    [anon_sym_constraint] = ACTIONS(4196),
    [anon_sym_if] = ACTIONS(4196),
    [anon_sym_else] = ACTIONS(4196),
    [anon_sym_LBRACK] = ACTIONS(4194),
    [anon_sym_localparam] = ACTIONS(4196),
    [anon_sym_parameter] = ACTIONS(4196),
    [anon_sym_specparam] = ACTIONS(4196),
    [anon_sym_var] = ACTIONS(4196),
    [anon_sym_import] = ACTIONS(4196),
    [anon_sym_export] = ACTIONS(4196),
    [anon_sym_genvar] = ACTIONS(4196),
    [anon_sym_interconnect] = ACTIONS(4196),
    [anon_sym_typedef] = ACTIONS(4196),
    [anon_sym_enum] = ACTIONS(4196),
    [anon_sym_struct] = ACTIONS(4196),
    [anon_sym_union] = ACTIONS(4196),
    [anon_sym_nettype] = ACTIONS(4196),
    [anon_sym_automatic] = ACTIONS(4196),
    [anon_sym_string] = ACTIONS(4196),
    [anon_sym_chandle] = ACTIONS(4196),
    [anon_sym_event] = ACTIONS(4196),
    [anon_sym_byte] = ACTIONS(4196),
    [anon_sym_shortint] = ACTIONS(4196),
    [anon_sym_int] = ACTIONS(4196),
    [anon_sym_longint] = ACTIONS(4196),
    [anon_sym_integer] = ACTIONS(4196),
    [anon_sym_time] = ACTIONS(4196),
    [anon_sym_bit] = ACTIONS(4196),
    [anon_sym_logic] = ACTIONS(4196),
    [anon_sym_reg] = ACTIONS(4196),
    [anon_sym_shortreal] = ACTIONS(4196),
    [anon_sym_real] = ACTIONS(4196),
    [anon_sym_realtime] = ACTIONS(4196),
    [anon_sym_supply0] = ACTIONS(4196),
    [anon_sym_supply1] = ACTIONS(4196),
    [anon_sym_signed] = ACTIONS(4196),
    [anon_sym_unsigned] = ACTIONS(4196),
    [anon_sym_task] = ACTIONS(4196),
    [anon_sym_modport] = ACTIONS(4196),
    [anon_sym_assert] = ACTIONS(4196),
    [anon_sym_property] = ACTIONS(4196),
    [anon_sym_assume] = ACTIONS(4196),
    [anon_sym_cover] = ACTIONS(4196),
    [anon_sym_sequence] = ACTIONS(4196),
    [anon_sym_restrict] = ACTIONS(4196),
    [anon_sym_not] = ACTIONS(4196),
    [anon_sym_or] = ACTIONS(4196),
    [anon_sym_and] = ACTIONS(4196),
    [anon_sym_case] = ACTIONS(4196),
    [anon_sym_always] = ACTIONS(4196),
    [anon_sym_covergroup] = ACTIONS(4196),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_pulldown] = ACTIONS(4196),
    [anon_sym_pullup] = ACTIONS(4196),
    [anon_sym_cmos] = ACTIONS(4196),
    [anon_sym_rcmos] = ACTIONS(4196),
    [anon_sym_bufif0] = ACTIONS(4196),
    [anon_sym_bufif1] = ACTIONS(4196),
    [anon_sym_notif0] = ACTIONS(4196),
    [anon_sym_notif1] = ACTIONS(4196),
    [anon_sym_nmos] = ACTIONS(4196),
    [anon_sym_pmos] = ACTIONS(4196),
    [anon_sym_rnmos] = ACTIONS(4196),
    [anon_sym_rpmos] = ACTIONS(4196),
    [anon_sym_nand] = ACTIONS(4196),
    [anon_sym_nor] = ACTIONS(4196),
    [anon_sym_xor] = ACTIONS(4196),
    [anon_sym_xnor] = ACTIONS(4196),
    [anon_sym_buf] = ACTIONS(4196),
    [anon_sym_tranif0] = ACTIONS(4196),
    [anon_sym_tranif1] = ACTIONS(4196),
    [anon_sym_rtranif1] = ACTIONS(4196),
    [anon_sym_rtranif0] = ACTIONS(4196),
    [anon_sym_tran] = ACTIONS(4196),
    [anon_sym_rtran] = ACTIONS(4196),
    [anon_sym_generate] = ACTIONS(4196),
    [anon_sym_for] = ACTIONS(4196),
    [anon_sym_primitive] = ACTIONS(4196),
    [anon_sym_initial] = ACTIONS(4196),
    [anon_sym_assign] = ACTIONS(4196),
    [anon_sym_alias] = ACTIONS(4196),
    [anon_sym_always_comb] = ACTIONS(4196),
    [anon_sym_always_latch] = ACTIONS(4196),
    [anon_sym_always_ff] = ACTIONS(4196),
    [anon_sym_final] = ACTIONS(4196),
    [anon_sym_endclocking] = ACTIONS(4196),
    [anon_sym_global] = ACTIONS(4196),
    [anon_sym_specify] = ACTIONS(4196),
    [anon_sym_LPAREN_STAR] = ACTIONS(4194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4194),
    [anon_sym_DOLLARunit] = ACTIONS(4194),
  },
  [655] = {
    [ts_builtin_sym_end] = ACTIONS(4198),
    [sym_simple_identifier] = ACTIONS(4200),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4198),
    [anon_sym_BQUOTE] = ACTIONS(4200),
    [aux_sym_id_directive_token1] = ACTIONS(4198),
    [aux_sym_id_directive_token2] = ACTIONS(4198),
    [aux_sym_id_directive_token3] = ACTIONS(4198),
    [aux_sym_id_directive_token4] = ACTIONS(4200),
    [aux_sym_zero_directive_token1] = ACTIONS(4198),
    [aux_sym_zero_directive_token2] = ACTIONS(4198),
    [aux_sym_zero_directive_token3] = ACTIONS(4198),
    [aux_sym_zero_directive_token4] = ACTIONS(4198),
    [aux_sym_zero_directive_token5] = ACTIONS(4198),
    [aux_sym_zero_directive_token6] = ACTIONS(4198),
    [aux_sym_zero_directive_token7] = ACTIONS(4198),
    [aux_sym_zero_directive_token8] = ACTIONS(4198),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4198),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4198),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_begin_keywords_token1] = ACTIONS(4198),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_endmodule] = ACTIONS(4200),
    [anon_sym_COLON] = ACTIONS(4202),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_module] = ACTIONS(4200),
    [anon_sym_macromodule] = ACTIONS(4200),
    [anon_sym_endinterface] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_endprogram] = ACTIONS(4200),
    [anon_sym_program] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_package] = ACTIONS(4200),
    [anon_sym_endpackage] = ACTIONS(4200),
    [anon_sym_timeunit] = ACTIONS(4200),
    [anon_sym_timeprecision] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_input] = ACTIONS(4200),
    [anon_sym_output] = ACTIONS(4200),
    [anon_sym_inout] = ACTIONS(4200),
    [anon_sym_ref] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_specparam] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_modport] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_primitive] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_specify] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [656] = {
    [sym_simple_identifier] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_GT] = ACTIONS(1676),
    [anon_sym_COMMA] = ACTIONS(1674),
    [anon_sym_SLASH] = ACTIONS(1676),
    [anon_sym_wire] = ACTIONS(1676),
    [anon_sym_tri] = ACTIONS(1676),
    [anon_sym_tri0] = ACTIONS(1676),
    [anon_sym_tri1] = ACTIONS(1676),
    [anon_sym_wand] = ACTIONS(1676),
    [anon_sym_triand] = ACTIONS(1676),
    [anon_sym_wor] = ACTIONS(1676),
    [anon_sym_trior] = ACTIONS(1676),
    [anon_sym_trireg] = ACTIONS(1676),
    [anon_sym_uwire] = ACTIONS(1676),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_extern] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_checker] = ACTIONS(1676),
    [anon_sym_virtual] = ACTIONS(1676),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_DOT] = ACTIONS(1674),
    [anon_sym_RBRACE] = ACTIONS(1674),
    [anon_sym_DOLLARfatal] = ACTIONS(1674),
    [anon_sym_DOLLARerror] = ACTIONS(1674),
    [anon_sym_DOLLARwarning] = ACTIONS(1674),
    [anon_sym_DOLLARinfo] = ACTIONS(1674),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_clocking] = ACTIONS(1676),
    [anon_sym_defparam] = ACTIONS(1676),
    [anon_sym_bind] = ACTIONS(1676),
    [anon_sym_rand] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_constraint] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_COLON_EQ] = ACTIONS(1674),
    [anon_sym_COLON_SLASH] = ACTIONS(1674),
    [anon_sym_localparam] = ACTIONS(1676),
    [anon_sym_parameter] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_genvar] = ACTIONS(1676),
    [anon_sym_interconnect] = ACTIONS(1676),
    [anon_sym_typedef] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [anon_sym_struct] = ACTIONS(1676),
    [anon_sym_union] = ACTIONS(1676),
    [anon_sym_nettype] = ACTIONS(1676),
    [anon_sym_automatic] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_chandle] = ACTIONS(1676),
    [anon_sym_event] = ACTIONS(1676),
    [anon_sym_byte] = ACTIONS(1676),
    [anon_sym_shortint] = ACTIONS(1676),
    [anon_sym_int] = ACTIONS(1676),
    [anon_sym_longint] = ACTIONS(1676),
    [anon_sym_integer] = ACTIONS(1676),
    [anon_sym_time] = ACTIONS(1676),
    [anon_sym_bit] = ACTIONS(1676),
    [anon_sym_logic] = ACTIONS(1676),
    [anon_sym_reg] = ACTIONS(1676),
    [anon_sym_shortreal] = ACTIONS(1676),
    [anon_sym_real] = ACTIONS(1676),
    [anon_sym_realtime] = ACTIONS(1676),
    [anon_sym_supply0] = ACTIONS(1676),
    [anon_sym_supply1] = ACTIONS(1676),
    [anon_sym_signed] = ACTIONS(1676),
    [anon_sym_unsigned] = ACTIONS(1676),
    [anon_sym_task] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1674),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_assert] = ACTIONS(1676),
    [anon_sym_property] = ACTIONS(1676),
    [anon_sym_assume] = ACTIONS(1676),
    [anon_sym_cover] = ACTIONS(1676),
    [anon_sym_sequence] = ACTIONS(1676),
    [anon_sym_restrict] = ACTIONS(1676),
    [anon_sym_not] = ACTIONS(1676),
    [anon_sym_or] = ACTIONS(1676),
    [anon_sym_and] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_always] = ACTIONS(1676),
    [anon_sym_covergroup] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1676),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_matches] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_pulldown] = ACTIONS(1676),
    [anon_sym_pullup] = ACTIONS(1676),
    [anon_sym_cmos] = ACTIONS(1676),
    [anon_sym_rcmos] = ACTIONS(1676),
    [anon_sym_bufif0] = ACTIONS(1676),
    [anon_sym_bufif1] = ACTIONS(1676),
    [anon_sym_notif0] = ACTIONS(1676),
    [anon_sym_notif1] = ACTIONS(1676),
    [anon_sym_nmos] = ACTIONS(1676),
    [anon_sym_pmos] = ACTIONS(1676),
    [anon_sym_rnmos] = ACTIONS(1676),
    [anon_sym_rpmos] = ACTIONS(1676),
    [anon_sym_nand] = ACTIONS(1676),
    [anon_sym_nor] = ACTIONS(1676),
    [anon_sym_xor] = ACTIONS(1676),
    [anon_sym_xnor] = ACTIONS(1676),
    [anon_sym_buf] = ACTIONS(1676),
    [anon_sym_tranif0] = ACTIONS(1676),
    [anon_sym_tranif1] = ACTIONS(1676),
    [anon_sym_rtranif1] = ACTIONS(1676),
    [anon_sym_rtranif0] = ACTIONS(1676),
    [anon_sym_tran] = ACTIONS(1676),
    [anon_sym_rtran] = ACTIONS(1676),
    [anon_sym_generate] = ACTIONS(1676),
    [anon_sym_endgenerate] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_initial] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_assign] = ACTIONS(1676),
    [anon_sym_alias] = ACTIONS(1676),
    [anon_sym_always_comb] = ACTIONS(1676),
    [anon_sym_always_latch] = ACTIONS(1676),
    [anon_sym_always_ff] = ACTIONS(1676),
    [anon_sym_final] = ACTIONS(1676),
    [anon_sym_DASH_GT] = ACTIONS(1674),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1674),
    [anon_sym_inside] = ACTIONS(1676),
    [anon_sym_global] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_LT_LT] = ACTIONS(1676),
    [anon_sym_QMARK] = ACTIONS(1674),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1676),
    [anon_sym_CARET_TILDE] = ACTIONS(1674),
    [anon_sym_TILDE_CARET] = ACTIONS(1674),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT_LT] = ACTIONS(1674),
    [anon_sym_LT_DASH_GT] = ACTIONS(1674),
    [anon_sym_LPAREN_STAR] = ACTIONS(1674),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1674),
    [anon_sym_DOLLARunit] = ACTIONS(1674),
  },
  [657] = {
    [ts_builtin_sym_end] = ACTIONS(4204),
    [sym_simple_identifier] = ACTIONS(4206),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4204),
    [anon_sym_BQUOTE] = ACTIONS(4206),
    [aux_sym_id_directive_token1] = ACTIONS(4204),
    [aux_sym_id_directive_token2] = ACTIONS(4204),
    [aux_sym_id_directive_token3] = ACTIONS(4204),
    [aux_sym_id_directive_token4] = ACTIONS(4206),
    [aux_sym_zero_directive_token1] = ACTIONS(4204),
    [aux_sym_zero_directive_token2] = ACTIONS(4204),
    [aux_sym_zero_directive_token3] = ACTIONS(4204),
    [aux_sym_zero_directive_token4] = ACTIONS(4204),
    [aux_sym_zero_directive_token5] = ACTIONS(4204),
    [aux_sym_zero_directive_token6] = ACTIONS(4204),
    [aux_sym_zero_directive_token7] = ACTIONS(4204),
    [aux_sym_zero_directive_token8] = ACTIONS(4204),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4204),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4204),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_begin_keywords_token1] = ACTIONS(4204),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_endmodule] = ACTIONS(4206),
    [anon_sym_COLON] = ACTIONS(4208),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_module] = ACTIONS(4206),
    [anon_sym_macromodule] = ACTIONS(4206),
    [anon_sym_endinterface] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_endprogram] = ACTIONS(4206),
    [anon_sym_program] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_package] = ACTIONS(4206),
    [anon_sym_endpackage] = ACTIONS(4206),
    [anon_sym_timeunit] = ACTIONS(4206),
    [anon_sym_timeprecision] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_input] = ACTIONS(4206),
    [anon_sym_output] = ACTIONS(4206),
    [anon_sym_inout] = ACTIONS(4206),
    [anon_sym_ref] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_specparam] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_modport] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_primitive] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_specify] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [658] = {
    [ts_builtin_sym_end] = ACTIONS(4210),
    [sym_simple_identifier] = ACTIONS(4212),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4210),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4210),
    [anon_sym_BQUOTE] = ACTIONS(4212),
    [aux_sym_id_directive_token1] = ACTIONS(4210),
    [aux_sym_id_directive_token2] = ACTIONS(4210),
    [aux_sym_id_directive_token3] = ACTIONS(4210),
    [aux_sym_id_directive_token4] = ACTIONS(4212),
    [aux_sym_zero_directive_token1] = ACTIONS(4210),
    [aux_sym_zero_directive_token2] = ACTIONS(4210),
    [aux_sym_zero_directive_token3] = ACTIONS(4210),
    [aux_sym_zero_directive_token4] = ACTIONS(4210),
    [aux_sym_zero_directive_token5] = ACTIONS(4210),
    [aux_sym_zero_directive_token6] = ACTIONS(4210),
    [aux_sym_zero_directive_token7] = ACTIONS(4210),
    [aux_sym_zero_directive_token8] = ACTIONS(4210),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4210),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4210),
    [anon_sym_wire] = ACTIONS(4212),
    [anon_sym_tri] = ACTIONS(4212),
    [anon_sym_tri0] = ACTIONS(4212),
    [anon_sym_tri1] = ACTIONS(4212),
    [anon_sym_wand] = ACTIONS(4212),
    [anon_sym_triand] = ACTIONS(4212),
    [anon_sym_wor] = ACTIONS(4212),
    [anon_sym_trior] = ACTIONS(4212),
    [anon_sym_trireg] = ACTIONS(4212),
    [anon_sym_uwire] = ACTIONS(4212),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4210),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4210),
    [aux_sym_begin_keywords_token1] = ACTIONS(4210),
    [anon_sym_SEMI] = ACTIONS(4210),
    [anon_sym_endmodule] = ACTIONS(4212),
    [anon_sym_COLON] = ACTIONS(4214),
    [anon_sym_extern] = ACTIONS(4212),
    [anon_sym_module] = ACTIONS(4212),
    [anon_sym_macromodule] = ACTIONS(4212),
    [anon_sym_endinterface] = ACTIONS(4212),
    [anon_sym_interface] = ACTIONS(4212),
    [anon_sym_endprogram] = ACTIONS(4212),
    [anon_sym_program] = ACTIONS(4212),
    [anon_sym_checker] = ACTIONS(4212),
    [anon_sym_virtual] = ACTIONS(4212),
    [anon_sym_class] = ACTIONS(4212),
    [anon_sym_package] = ACTIONS(4212),
    [anon_sym_endpackage] = ACTIONS(4212),
    [anon_sym_timeunit] = ACTIONS(4212),
    [anon_sym_timeprecision] = ACTIONS(4212),
    [anon_sym_type] = ACTIONS(4212),
    [anon_sym_input] = ACTIONS(4212),
    [anon_sym_output] = ACTIONS(4212),
    [anon_sym_inout] = ACTIONS(4212),
    [anon_sym_ref] = ACTIONS(4212),
    [anon_sym_DOLLARfatal] = ACTIONS(4210),
    [anon_sym_DOLLARerror] = ACTIONS(4210),
    [anon_sym_DOLLARwarning] = ACTIONS(4210),
    [anon_sym_DOLLARinfo] = ACTIONS(4210),
    [anon_sym_default] = ACTIONS(4212),
    [anon_sym_clocking] = ACTIONS(4212),
    [anon_sym_defparam] = ACTIONS(4212),
    [anon_sym_bind] = ACTIONS(4212),
    [anon_sym_const] = ACTIONS(4212),
    [anon_sym_function] = ACTIONS(4212),
    [anon_sym_static] = ACTIONS(4212),
    [anon_sym_constraint] = ACTIONS(4212),
    [anon_sym_if] = ACTIONS(4212),
    [anon_sym_else] = ACTIONS(4212),
    [anon_sym_LBRACK] = ACTIONS(4210),
    [anon_sym_localparam] = ACTIONS(4212),
    [anon_sym_parameter] = ACTIONS(4212),
    [anon_sym_specparam] = ACTIONS(4212),
    [anon_sym_var] = ACTIONS(4212),
    [anon_sym_import] = ACTIONS(4212),
    [anon_sym_export] = ACTIONS(4212),
    [anon_sym_genvar] = ACTIONS(4212),
    [anon_sym_interconnect] = ACTIONS(4212),
    [anon_sym_typedef] = ACTIONS(4212),
    [anon_sym_enum] = ACTIONS(4212),
    [anon_sym_struct] = ACTIONS(4212),
    [anon_sym_union] = ACTIONS(4212),
    [anon_sym_nettype] = ACTIONS(4212),
    [anon_sym_automatic] = ACTIONS(4212),
    [anon_sym_string] = ACTIONS(4212),
    [anon_sym_chandle] = ACTIONS(4212),
    [anon_sym_event] = ACTIONS(4212),
    [anon_sym_byte] = ACTIONS(4212),
    [anon_sym_shortint] = ACTIONS(4212),
    [anon_sym_int] = ACTIONS(4212),
    [anon_sym_longint] = ACTIONS(4212),
    [anon_sym_integer] = ACTIONS(4212),
    [anon_sym_time] = ACTIONS(4212),
    [anon_sym_bit] = ACTIONS(4212),
    [anon_sym_logic] = ACTIONS(4212),
    [anon_sym_reg] = ACTIONS(4212),
    [anon_sym_shortreal] = ACTIONS(4212),
    [anon_sym_real] = ACTIONS(4212),
    [anon_sym_realtime] = ACTIONS(4212),
    [anon_sym_supply0] = ACTIONS(4212),
    [anon_sym_supply1] = ACTIONS(4212),
    [anon_sym_signed] = ACTIONS(4212),
    [anon_sym_unsigned] = ACTIONS(4212),
    [anon_sym_task] = ACTIONS(4212),
    [anon_sym_modport] = ACTIONS(4212),
    [anon_sym_assert] = ACTIONS(4212),
    [anon_sym_property] = ACTIONS(4212),
    [anon_sym_assume] = ACTIONS(4212),
    [anon_sym_cover] = ACTIONS(4212),
    [anon_sym_sequence] = ACTIONS(4212),
    [anon_sym_restrict] = ACTIONS(4212),
    [anon_sym_not] = ACTIONS(4212),
    [anon_sym_or] = ACTIONS(4212),
    [anon_sym_and] = ACTIONS(4212),
    [anon_sym_case] = ACTIONS(4212),
    [anon_sym_always] = ACTIONS(4212),
    [anon_sym_covergroup] = ACTIONS(4212),
    [anon_sym_let] = ACTIONS(4212),
    [anon_sym_pulldown] = ACTIONS(4212),
    [anon_sym_pullup] = ACTIONS(4212),
    [anon_sym_cmos] = ACTIONS(4212),
    [anon_sym_rcmos] = ACTIONS(4212),
    [anon_sym_bufif0] = ACTIONS(4212),
    [anon_sym_bufif1] = ACTIONS(4212),
    [anon_sym_notif0] = ACTIONS(4212),
    [anon_sym_notif1] = ACTIONS(4212),
    [anon_sym_nmos] = ACTIONS(4212),
    [anon_sym_pmos] = ACTIONS(4212),
    [anon_sym_rnmos] = ACTIONS(4212),
    [anon_sym_rpmos] = ACTIONS(4212),
    [anon_sym_nand] = ACTIONS(4212),
    [anon_sym_nor] = ACTIONS(4212),
    [anon_sym_xor] = ACTIONS(4212),
    [anon_sym_xnor] = ACTIONS(4212),
    [anon_sym_buf] = ACTIONS(4212),
    [anon_sym_tranif0] = ACTIONS(4212),
    [anon_sym_tranif1] = ACTIONS(4212),
    [anon_sym_rtranif1] = ACTIONS(4212),
    [anon_sym_rtranif0] = ACTIONS(4212),
    [anon_sym_tran] = ACTIONS(4212),
    [anon_sym_rtran] = ACTIONS(4212),
    [anon_sym_generate] = ACTIONS(4212),
    [anon_sym_for] = ACTIONS(4212),
    [anon_sym_primitive] = ACTIONS(4212),
    [anon_sym_initial] = ACTIONS(4212),
    [anon_sym_assign] = ACTIONS(4212),
    [anon_sym_alias] = ACTIONS(4212),
    [anon_sym_always_comb] = ACTIONS(4212),
    [anon_sym_always_latch] = ACTIONS(4212),
    [anon_sym_always_ff] = ACTIONS(4212),
    [anon_sym_final] = ACTIONS(4212),
    [anon_sym_global] = ACTIONS(4212),
    [anon_sym_specify] = ACTIONS(4212),
    [anon_sym_LPAREN_STAR] = ACTIONS(4210),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4210),
    [anon_sym_DOLLARunit] = ACTIONS(4210),
  },
  [659] = {
    [ts_builtin_sym_end] = ACTIONS(4216),
    [sym_simple_identifier] = ACTIONS(4218),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4216),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4216),
    [anon_sym_BQUOTE] = ACTIONS(4218),
    [aux_sym_id_directive_token1] = ACTIONS(4216),
    [aux_sym_id_directive_token2] = ACTIONS(4216),
    [aux_sym_id_directive_token3] = ACTIONS(4216),
    [aux_sym_id_directive_token4] = ACTIONS(4218),
    [aux_sym_zero_directive_token1] = ACTIONS(4216),
    [aux_sym_zero_directive_token2] = ACTIONS(4216),
    [aux_sym_zero_directive_token3] = ACTIONS(4216),
    [aux_sym_zero_directive_token4] = ACTIONS(4216),
    [aux_sym_zero_directive_token5] = ACTIONS(4216),
    [aux_sym_zero_directive_token6] = ACTIONS(4216),
    [aux_sym_zero_directive_token7] = ACTIONS(4216),
    [aux_sym_zero_directive_token8] = ACTIONS(4216),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4216),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4216),
    [anon_sym_wire] = ACTIONS(4218),
    [anon_sym_tri] = ACTIONS(4218),
    [anon_sym_tri0] = ACTIONS(4218),
    [anon_sym_tri1] = ACTIONS(4218),
    [anon_sym_wand] = ACTIONS(4218),
    [anon_sym_triand] = ACTIONS(4218),
    [anon_sym_wor] = ACTIONS(4218),
    [anon_sym_trior] = ACTIONS(4218),
    [anon_sym_trireg] = ACTIONS(4218),
    [anon_sym_uwire] = ACTIONS(4218),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4216),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4216),
    [aux_sym_begin_keywords_token1] = ACTIONS(4216),
    [anon_sym_SEMI] = ACTIONS(4216),
    [anon_sym_endmodule] = ACTIONS(4218),
    [anon_sym_COLON] = ACTIONS(4220),
    [anon_sym_extern] = ACTIONS(4218),
    [anon_sym_module] = ACTIONS(4218),
    [anon_sym_macromodule] = ACTIONS(4218),
    [anon_sym_endinterface] = ACTIONS(4218),
    [anon_sym_interface] = ACTIONS(4218),
    [anon_sym_endprogram] = ACTIONS(4218),
    [anon_sym_program] = ACTIONS(4218),
    [anon_sym_checker] = ACTIONS(4218),
    [anon_sym_virtual] = ACTIONS(4218),
    [anon_sym_class] = ACTIONS(4218),
    [anon_sym_package] = ACTIONS(4218),
    [anon_sym_endpackage] = ACTIONS(4218),
    [anon_sym_timeunit] = ACTIONS(4218),
    [anon_sym_timeprecision] = ACTIONS(4218),
    [anon_sym_type] = ACTIONS(4218),
    [anon_sym_input] = ACTIONS(4218),
    [anon_sym_output] = ACTIONS(4218),
    [anon_sym_inout] = ACTIONS(4218),
    [anon_sym_ref] = ACTIONS(4218),
    [anon_sym_DOLLARfatal] = ACTIONS(4216),
    [anon_sym_DOLLARerror] = ACTIONS(4216),
    [anon_sym_DOLLARwarning] = ACTIONS(4216),
    [anon_sym_DOLLARinfo] = ACTIONS(4216),
    [anon_sym_default] = ACTIONS(4218),
    [anon_sym_clocking] = ACTIONS(4218),
    [anon_sym_defparam] = ACTIONS(4218),
    [anon_sym_bind] = ACTIONS(4218),
    [anon_sym_const] = ACTIONS(4218),
    [anon_sym_function] = ACTIONS(4218),
    [anon_sym_static] = ACTIONS(4218),
    [anon_sym_constraint] = ACTIONS(4218),
    [anon_sym_if] = ACTIONS(4218),
    [anon_sym_else] = ACTIONS(4218),
    [anon_sym_LBRACK] = ACTIONS(4216),
    [anon_sym_localparam] = ACTIONS(4218),
    [anon_sym_parameter] = ACTIONS(4218),
    [anon_sym_specparam] = ACTIONS(4218),
    [anon_sym_var] = ACTIONS(4218),
    [anon_sym_import] = ACTIONS(4218),
    [anon_sym_export] = ACTIONS(4218),
    [anon_sym_genvar] = ACTIONS(4218),
    [anon_sym_interconnect] = ACTIONS(4218),
    [anon_sym_typedef] = ACTIONS(4218),
    [anon_sym_enum] = ACTIONS(4218),
    [anon_sym_struct] = ACTIONS(4218),
    [anon_sym_union] = ACTIONS(4218),
    [anon_sym_nettype] = ACTIONS(4218),
    [anon_sym_automatic] = ACTIONS(4218),
    [anon_sym_string] = ACTIONS(4218),
    [anon_sym_chandle] = ACTIONS(4218),
    [anon_sym_event] = ACTIONS(4218),
    [anon_sym_byte] = ACTIONS(4218),
    [anon_sym_shortint] = ACTIONS(4218),
    [anon_sym_int] = ACTIONS(4218),
    [anon_sym_longint] = ACTIONS(4218),
    [anon_sym_integer] = ACTIONS(4218),
    [anon_sym_time] = ACTIONS(4218),
    [anon_sym_bit] = ACTIONS(4218),
    [anon_sym_logic] = ACTIONS(4218),
    [anon_sym_reg] = ACTIONS(4218),
    [anon_sym_shortreal] = ACTIONS(4218),
    [anon_sym_real] = ACTIONS(4218),
    [anon_sym_realtime] = ACTIONS(4218),
    [anon_sym_supply0] = ACTIONS(4218),
    [anon_sym_supply1] = ACTIONS(4218),
    [anon_sym_signed] = ACTIONS(4218),
    [anon_sym_unsigned] = ACTIONS(4218),
    [anon_sym_task] = ACTIONS(4218),
    [anon_sym_modport] = ACTIONS(4218),
    [anon_sym_assert] = ACTIONS(4218),
    [anon_sym_property] = ACTIONS(4218),
    [anon_sym_assume] = ACTIONS(4218),
    [anon_sym_cover] = ACTIONS(4218),
    [anon_sym_sequence] = ACTIONS(4218),
    [anon_sym_restrict] = ACTIONS(4218),
    [anon_sym_not] = ACTIONS(4218),
    [anon_sym_or] = ACTIONS(4218),
    [anon_sym_and] = ACTIONS(4218),
    [anon_sym_case] = ACTIONS(4218),
    [anon_sym_always] = ACTIONS(4218),
    [anon_sym_covergroup] = ACTIONS(4218),
    [anon_sym_let] = ACTIONS(4218),
    [anon_sym_pulldown] = ACTIONS(4218),
    [anon_sym_pullup] = ACTIONS(4218),
    [anon_sym_cmos] = ACTIONS(4218),
    [anon_sym_rcmos] = ACTIONS(4218),
    [anon_sym_bufif0] = ACTIONS(4218),
    [anon_sym_bufif1] = ACTIONS(4218),
    [anon_sym_notif0] = ACTIONS(4218),
    [anon_sym_notif1] = ACTIONS(4218),
    [anon_sym_nmos] = ACTIONS(4218),
    [anon_sym_pmos] = ACTIONS(4218),
    [anon_sym_rnmos] = ACTIONS(4218),
    [anon_sym_rpmos] = ACTIONS(4218),
    [anon_sym_nand] = ACTIONS(4218),
    [anon_sym_nor] = ACTIONS(4218),
    [anon_sym_xor] = ACTIONS(4218),
    [anon_sym_xnor] = ACTIONS(4218),
    [anon_sym_buf] = ACTIONS(4218),
    [anon_sym_tranif0] = ACTIONS(4218),
    [anon_sym_tranif1] = ACTIONS(4218),
    [anon_sym_rtranif1] = ACTIONS(4218),
    [anon_sym_rtranif0] = ACTIONS(4218),
    [anon_sym_tran] = ACTIONS(4218),
    [anon_sym_rtran] = ACTIONS(4218),
    [anon_sym_generate] = ACTIONS(4218),
    [anon_sym_for] = ACTIONS(4218),
    [anon_sym_primitive] = ACTIONS(4218),
    [anon_sym_initial] = ACTIONS(4218),
    [anon_sym_assign] = ACTIONS(4218),
    [anon_sym_alias] = ACTIONS(4218),
    [anon_sym_always_comb] = ACTIONS(4218),
    [anon_sym_always_latch] = ACTIONS(4218),
    [anon_sym_always_ff] = ACTIONS(4218),
    [anon_sym_final] = ACTIONS(4218),
    [anon_sym_global] = ACTIONS(4218),
    [anon_sym_specify] = ACTIONS(4218),
    [anon_sym_LPAREN_STAR] = ACTIONS(4216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4216),
    [anon_sym_DOLLARunit] = ACTIONS(4216),
  },
  [660] = {
    [ts_builtin_sym_end] = ACTIONS(4222),
    [sym_simple_identifier] = ACTIONS(4224),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4222),
    [anon_sym_BQUOTE] = ACTIONS(4224),
    [aux_sym_id_directive_token1] = ACTIONS(4222),
    [aux_sym_id_directive_token2] = ACTIONS(4222),
    [aux_sym_id_directive_token3] = ACTIONS(4222),
    [aux_sym_id_directive_token4] = ACTIONS(4224),
    [aux_sym_zero_directive_token1] = ACTIONS(4222),
    [aux_sym_zero_directive_token2] = ACTIONS(4222),
    [aux_sym_zero_directive_token3] = ACTIONS(4222),
    [aux_sym_zero_directive_token4] = ACTIONS(4222),
    [aux_sym_zero_directive_token5] = ACTIONS(4222),
    [aux_sym_zero_directive_token6] = ACTIONS(4222),
    [aux_sym_zero_directive_token7] = ACTIONS(4222),
    [aux_sym_zero_directive_token8] = ACTIONS(4222),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4222),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4222),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_begin_keywords_token1] = ACTIONS(4222),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_endmodule] = ACTIONS(4224),
    [anon_sym_COLON] = ACTIONS(4226),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_module] = ACTIONS(4224),
    [anon_sym_macromodule] = ACTIONS(4224),
    [anon_sym_endinterface] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_endprogram] = ACTIONS(4224),
    [anon_sym_program] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_package] = ACTIONS(4224),
    [anon_sym_endpackage] = ACTIONS(4224),
    [anon_sym_timeunit] = ACTIONS(4224),
    [anon_sym_timeprecision] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_input] = ACTIONS(4224),
    [anon_sym_output] = ACTIONS(4224),
    [anon_sym_inout] = ACTIONS(4224),
    [anon_sym_ref] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_specparam] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_modport] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_primitive] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_specify] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [661] = {
    [ts_builtin_sym_end] = ACTIONS(4228),
    [sym_simple_identifier] = ACTIONS(4230),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4228),
    [anon_sym_BQUOTE] = ACTIONS(4230),
    [aux_sym_id_directive_token1] = ACTIONS(4228),
    [aux_sym_id_directive_token2] = ACTIONS(4228),
    [aux_sym_id_directive_token3] = ACTIONS(4228),
    [aux_sym_id_directive_token4] = ACTIONS(4230),
    [aux_sym_zero_directive_token1] = ACTIONS(4228),
    [aux_sym_zero_directive_token2] = ACTIONS(4228),
    [aux_sym_zero_directive_token3] = ACTIONS(4228),
    [aux_sym_zero_directive_token4] = ACTIONS(4228),
    [aux_sym_zero_directive_token5] = ACTIONS(4228),
    [aux_sym_zero_directive_token6] = ACTIONS(4228),
    [aux_sym_zero_directive_token7] = ACTIONS(4228),
    [aux_sym_zero_directive_token8] = ACTIONS(4228),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4228),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4228),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_begin_keywords_token1] = ACTIONS(4228),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_endmodule] = ACTIONS(4230),
    [anon_sym_COLON] = ACTIONS(4232),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_module] = ACTIONS(4230),
    [anon_sym_macromodule] = ACTIONS(4230),
    [anon_sym_endinterface] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_endprogram] = ACTIONS(4230),
    [anon_sym_program] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_package] = ACTIONS(4230),
    [anon_sym_endpackage] = ACTIONS(4230),
    [anon_sym_timeunit] = ACTIONS(4230),
    [anon_sym_timeprecision] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_input] = ACTIONS(4230),
    [anon_sym_output] = ACTIONS(4230),
    [anon_sym_inout] = ACTIONS(4230),
    [anon_sym_ref] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_specparam] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_modport] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_primitive] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_specify] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [662] = {
    [ts_builtin_sym_end] = ACTIONS(4234),
    [sym_simple_identifier] = ACTIONS(4236),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4234),
    [anon_sym_BQUOTE] = ACTIONS(4236),
    [aux_sym_id_directive_token1] = ACTIONS(4234),
    [aux_sym_id_directive_token2] = ACTIONS(4234),
    [aux_sym_id_directive_token3] = ACTIONS(4234),
    [aux_sym_id_directive_token4] = ACTIONS(4236),
    [aux_sym_zero_directive_token1] = ACTIONS(4234),
    [aux_sym_zero_directive_token2] = ACTIONS(4234),
    [aux_sym_zero_directive_token3] = ACTIONS(4234),
    [aux_sym_zero_directive_token4] = ACTIONS(4234),
    [aux_sym_zero_directive_token5] = ACTIONS(4234),
    [aux_sym_zero_directive_token6] = ACTIONS(4234),
    [aux_sym_zero_directive_token7] = ACTIONS(4234),
    [aux_sym_zero_directive_token8] = ACTIONS(4234),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4234),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4234),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_begin_keywords_token1] = ACTIONS(4234),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_endmodule] = ACTIONS(4236),
    [anon_sym_COLON] = ACTIONS(4238),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_module] = ACTIONS(4236),
    [anon_sym_macromodule] = ACTIONS(4236),
    [anon_sym_endinterface] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_endprogram] = ACTIONS(4236),
    [anon_sym_program] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_package] = ACTIONS(4236),
    [anon_sym_endpackage] = ACTIONS(4236),
    [anon_sym_timeunit] = ACTIONS(4236),
    [anon_sym_timeprecision] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_input] = ACTIONS(4236),
    [anon_sym_output] = ACTIONS(4236),
    [anon_sym_inout] = ACTIONS(4236),
    [anon_sym_ref] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_specparam] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_modport] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_primitive] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_specify] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [663] = {
    [ts_builtin_sym_end] = ACTIONS(4240),
    [sym_simple_identifier] = ACTIONS(4242),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4240),
    [anon_sym_BQUOTE] = ACTIONS(4242),
    [aux_sym_id_directive_token1] = ACTIONS(4240),
    [aux_sym_id_directive_token2] = ACTIONS(4240),
    [aux_sym_id_directive_token3] = ACTIONS(4240),
    [aux_sym_id_directive_token4] = ACTIONS(4242),
    [aux_sym_zero_directive_token1] = ACTIONS(4240),
    [aux_sym_zero_directive_token2] = ACTIONS(4240),
    [aux_sym_zero_directive_token3] = ACTIONS(4240),
    [aux_sym_zero_directive_token4] = ACTIONS(4240),
    [aux_sym_zero_directive_token5] = ACTIONS(4240),
    [aux_sym_zero_directive_token6] = ACTIONS(4240),
    [aux_sym_zero_directive_token7] = ACTIONS(4240),
    [aux_sym_zero_directive_token8] = ACTIONS(4240),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4240),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4240),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_begin_keywords_token1] = ACTIONS(4240),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_endmodule] = ACTIONS(4242),
    [anon_sym_COLON] = ACTIONS(4244),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_module] = ACTIONS(4242),
    [anon_sym_macromodule] = ACTIONS(4242),
    [anon_sym_endinterface] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_endprogram] = ACTIONS(4242),
    [anon_sym_program] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_package] = ACTIONS(4242),
    [anon_sym_endpackage] = ACTIONS(4242),
    [anon_sym_timeunit] = ACTIONS(4242),
    [anon_sym_timeprecision] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_input] = ACTIONS(4242),
    [anon_sym_output] = ACTIONS(4242),
    [anon_sym_inout] = ACTIONS(4242),
    [anon_sym_ref] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_specparam] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_modport] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_primitive] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_specify] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [664] = {
    [ts_builtin_sym_end] = ACTIONS(4246),
    [sym_simple_identifier] = ACTIONS(4248),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4246),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4246),
    [anon_sym_BQUOTE] = ACTIONS(4248),
    [aux_sym_id_directive_token1] = ACTIONS(4246),
    [aux_sym_id_directive_token2] = ACTIONS(4246),
    [aux_sym_id_directive_token3] = ACTIONS(4246),
    [aux_sym_id_directive_token4] = ACTIONS(4248),
    [aux_sym_zero_directive_token1] = ACTIONS(4246),
    [aux_sym_zero_directive_token2] = ACTIONS(4246),
    [aux_sym_zero_directive_token3] = ACTIONS(4246),
    [aux_sym_zero_directive_token4] = ACTIONS(4246),
    [aux_sym_zero_directive_token5] = ACTIONS(4246),
    [aux_sym_zero_directive_token6] = ACTIONS(4246),
    [aux_sym_zero_directive_token7] = ACTIONS(4246),
    [aux_sym_zero_directive_token8] = ACTIONS(4246),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4246),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4246),
    [anon_sym_wire] = ACTIONS(4248),
    [anon_sym_tri] = ACTIONS(4248),
    [anon_sym_tri0] = ACTIONS(4248),
    [anon_sym_tri1] = ACTIONS(4248),
    [anon_sym_wand] = ACTIONS(4248),
    [anon_sym_triand] = ACTIONS(4248),
    [anon_sym_wor] = ACTIONS(4248),
    [anon_sym_trior] = ACTIONS(4248),
    [anon_sym_trireg] = ACTIONS(4248),
    [anon_sym_uwire] = ACTIONS(4248),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4246),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4246),
    [aux_sym_begin_keywords_token1] = ACTIONS(4246),
    [anon_sym_SEMI] = ACTIONS(4246),
    [anon_sym_endmodule] = ACTIONS(4248),
    [anon_sym_COLON] = ACTIONS(4250),
    [anon_sym_extern] = ACTIONS(4248),
    [anon_sym_module] = ACTIONS(4248),
    [anon_sym_macromodule] = ACTIONS(4248),
    [anon_sym_endinterface] = ACTIONS(4248),
    [anon_sym_interface] = ACTIONS(4248),
    [anon_sym_endprogram] = ACTIONS(4248),
    [anon_sym_program] = ACTIONS(4248),
    [anon_sym_checker] = ACTIONS(4248),
    [anon_sym_virtual] = ACTIONS(4248),
    [anon_sym_class] = ACTIONS(4248),
    [anon_sym_package] = ACTIONS(4248),
    [anon_sym_endpackage] = ACTIONS(4248),
    [anon_sym_timeunit] = ACTIONS(4248),
    [anon_sym_timeprecision] = ACTIONS(4248),
    [anon_sym_type] = ACTIONS(4248),
    [anon_sym_input] = ACTIONS(4248),
    [anon_sym_output] = ACTIONS(4248),
    [anon_sym_inout] = ACTIONS(4248),
    [anon_sym_ref] = ACTIONS(4248),
    [anon_sym_DOLLARfatal] = ACTIONS(4246),
    [anon_sym_DOLLARerror] = ACTIONS(4246),
    [anon_sym_DOLLARwarning] = ACTIONS(4246),
    [anon_sym_DOLLARinfo] = ACTIONS(4246),
    [anon_sym_default] = ACTIONS(4248),
    [anon_sym_clocking] = ACTIONS(4248),
    [anon_sym_defparam] = ACTIONS(4248),
    [anon_sym_bind] = ACTIONS(4248),
    [anon_sym_const] = ACTIONS(4248),
    [anon_sym_function] = ACTIONS(4248),
    [anon_sym_static] = ACTIONS(4248),
    [anon_sym_constraint] = ACTIONS(4248),
    [anon_sym_if] = ACTIONS(4248),
    [anon_sym_else] = ACTIONS(4248),
    [anon_sym_LBRACK] = ACTIONS(4246),
    [anon_sym_localparam] = ACTIONS(4248),
    [anon_sym_parameter] = ACTIONS(4248),
    [anon_sym_specparam] = ACTIONS(4248),
    [anon_sym_var] = ACTIONS(4248),
    [anon_sym_import] = ACTIONS(4248),
    [anon_sym_export] = ACTIONS(4248),
    [anon_sym_genvar] = ACTIONS(4248),
    [anon_sym_interconnect] = ACTIONS(4248),
    [anon_sym_typedef] = ACTIONS(4248),
    [anon_sym_enum] = ACTIONS(4248),
    [anon_sym_struct] = ACTIONS(4248),
    [anon_sym_union] = ACTIONS(4248),
    [anon_sym_nettype] = ACTIONS(4248),
    [anon_sym_automatic] = ACTIONS(4248),
    [anon_sym_string] = ACTIONS(4248),
    [anon_sym_chandle] = ACTIONS(4248),
    [anon_sym_event] = ACTIONS(4248),
    [anon_sym_byte] = ACTIONS(4248),
    [anon_sym_shortint] = ACTIONS(4248),
    [anon_sym_int] = ACTIONS(4248),
    [anon_sym_longint] = ACTIONS(4248),
    [anon_sym_integer] = ACTIONS(4248),
    [anon_sym_time] = ACTIONS(4248),
    [anon_sym_bit] = ACTIONS(4248),
    [anon_sym_logic] = ACTIONS(4248),
    [anon_sym_reg] = ACTIONS(4248),
    [anon_sym_shortreal] = ACTIONS(4248),
    [anon_sym_real] = ACTIONS(4248),
    [anon_sym_realtime] = ACTIONS(4248),
    [anon_sym_supply0] = ACTIONS(4248),
    [anon_sym_supply1] = ACTIONS(4248),
    [anon_sym_signed] = ACTIONS(4248),
    [anon_sym_unsigned] = ACTIONS(4248),
    [anon_sym_task] = ACTIONS(4248),
    [anon_sym_modport] = ACTIONS(4248),
    [anon_sym_assert] = ACTIONS(4248),
    [anon_sym_property] = ACTIONS(4248),
    [anon_sym_assume] = ACTIONS(4248),
    [anon_sym_cover] = ACTIONS(4248),
    [anon_sym_sequence] = ACTIONS(4248),
    [anon_sym_restrict] = ACTIONS(4248),
    [anon_sym_not] = ACTIONS(4248),
    [anon_sym_or] = ACTIONS(4248),
    [anon_sym_and] = ACTIONS(4248),
    [anon_sym_case] = ACTIONS(4248),
    [anon_sym_always] = ACTIONS(4248),
    [anon_sym_covergroup] = ACTIONS(4248),
    [anon_sym_let] = ACTIONS(4248),
    [anon_sym_pulldown] = ACTIONS(4248),
    [anon_sym_pullup] = ACTIONS(4248),
    [anon_sym_cmos] = ACTIONS(4248),
    [anon_sym_rcmos] = ACTIONS(4248),
    [anon_sym_bufif0] = ACTIONS(4248),
    [anon_sym_bufif1] = ACTIONS(4248),
    [anon_sym_notif0] = ACTIONS(4248),
    [anon_sym_notif1] = ACTIONS(4248),
    [anon_sym_nmos] = ACTIONS(4248),
    [anon_sym_pmos] = ACTIONS(4248),
    [anon_sym_rnmos] = ACTIONS(4248),
    [anon_sym_rpmos] = ACTIONS(4248),
    [anon_sym_nand] = ACTIONS(4248),
    [anon_sym_nor] = ACTIONS(4248),
    [anon_sym_xor] = ACTIONS(4248),
    [anon_sym_xnor] = ACTIONS(4248),
    [anon_sym_buf] = ACTIONS(4248),
    [anon_sym_tranif0] = ACTIONS(4248),
    [anon_sym_tranif1] = ACTIONS(4248),
    [anon_sym_rtranif1] = ACTIONS(4248),
    [anon_sym_rtranif0] = ACTIONS(4248),
    [anon_sym_tran] = ACTIONS(4248),
    [anon_sym_rtran] = ACTIONS(4248),
    [anon_sym_generate] = ACTIONS(4248),
    [anon_sym_for] = ACTIONS(4248),
    [anon_sym_primitive] = ACTIONS(4248),
    [anon_sym_initial] = ACTIONS(4248),
    [anon_sym_assign] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4248),
    [anon_sym_always_comb] = ACTIONS(4248),
    [anon_sym_always_latch] = ACTIONS(4248),
    [anon_sym_always_ff] = ACTIONS(4248),
    [anon_sym_final] = ACTIONS(4248),
    [anon_sym_global] = ACTIONS(4248),
    [anon_sym_specify] = ACTIONS(4248),
    [anon_sym_LPAREN_STAR] = ACTIONS(4246),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4246),
    [anon_sym_DOLLARunit] = ACTIONS(4246),
  },
  [665] = {
    [ts_builtin_sym_end] = ACTIONS(4252),
    [sym_simple_identifier] = ACTIONS(4254),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4252),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4252),
    [anon_sym_BQUOTE] = ACTIONS(4254),
    [aux_sym_id_directive_token1] = ACTIONS(4252),
    [aux_sym_id_directive_token2] = ACTIONS(4252),
    [aux_sym_id_directive_token3] = ACTIONS(4252),
    [aux_sym_id_directive_token4] = ACTIONS(4254),
    [aux_sym_zero_directive_token1] = ACTIONS(4252),
    [aux_sym_zero_directive_token2] = ACTIONS(4252),
    [aux_sym_zero_directive_token3] = ACTIONS(4252),
    [aux_sym_zero_directive_token4] = ACTIONS(4252),
    [aux_sym_zero_directive_token5] = ACTIONS(4252),
    [aux_sym_zero_directive_token6] = ACTIONS(4252),
    [aux_sym_zero_directive_token7] = ACTIONS(4252),
    [aux_sym_zero_directive_token8] = ACTIONS(4252),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4252),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4252),
    [anon_sym_wire] = ACTIONS(4254),
    [anon_sym_tri] = ACTIONS(4254),
    [anon_sym_tri0] = ACTIONS(4254),
    [anon_sym_tri1] = ACTIONS(4254),
    [anon_sym_wand] = ACTIONS(4254),
    [anon_sym_triand] = ACTIONS(4254),
    [anon_sym_wor] = ACTIONS(4254),
    [anon_sym_trior] = ACTIONS(4254),
    [anon_sym_trireg] = ACTIONS(4254),
    [anon_sym_uwire] = ACTIONS(4254),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4252),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4252),
    [aux_sym_begin_keywords_token1] = ACTIONS(4252),
    [anon_sym_SEMI] = ACTIONS(4252),
    [anon_sym_endmodule] = ACTIONS(4254),
    [anon_sym_COLON] = ACTIONS(4256),
    [anon_sym_extern] = ACTIONS(4254),
    [anon_sym_module] = ACTIONS(4254),
    [anon_sym_macromodule] = ACTIONS(4254),
    [anon_sym_endinterface] = ACTIONS(4254),
    [anon_sym_interface] = ACTIONS(4254),
    [anon_sym_endprogram] = ACTIONS(4254),
    [anon_sym_program] = ACTIONS(4254),
    [anon_sym_checker] = ACTIONS(4254),
    [anon_sym_virtual] = ACTIONS(4254),
    [anon_sym_class] = ACTIONS(4254),
    [anon_sym_package] = ACTIONS(4254),
    [anon_sym_endpackage] = ACTIONS(4254),
    [anon_sym_timeunit] = ACTIONS(4254),
    [anon_sym_timeprecision] = ACTIONS(4254),
    [anon_sym_type] = ACTIONS(4254),
    [anon_sym_input] = ACTIONS(4254),
    [anon_sym_output] = ACTIONS(4254),
    [anon_sym_inout] = ACTIONS(4254),
    [anon_sym_ref] = ACTIONS(4254),
    [anon_sym_DOLLARfatal] = ACTIONS(4252),
    [anon_sym_DOLLARerror] = ACTIONS(4252),
    [anon_sym_DOLLARwarning] = ACTIONS(4252),
    [anon_sym_DOLLARinfo] = ACTIONS(4252),
    [anon_sym_default] = ACTIONS(4254),
    [anon_sym_clocking] = ACTIONS(4254),
    [anon_sym_defparam] = ACTIONS(4254),
    [anon_sym_bind] = ACTIONS(4254),
    [anon_sym_const] = ACTIONS(4254),
    [anon_sym_function] = ACTIONS(4254),
    [anon_sym_static] = ACTIONS(4254),
    [anon_sym_constraint] = ACTIONS(4254),
    [anon_sym_if] = ACTIONS(4254),
    [anon_sym_else] = ACTIONS(4254),
    [anon_sym_LBRACK] = ACTIONS(4252),
    [anon_sym_localparam] = ACTIONS(4254),
    [anon_sym_parameter] = ACTIONS(4254),
    [anon_sym_specparam] = ACTIONS(4254),
    [anon_sym_var] = ACTIONS(4254),
    [anon_sym_import] = ACTIONS(4254),
    [anon_sym_export] = ACTIONS(4254),
    [anon_sym_genvar] = ACTIONS(4254),
    [anon_sym_interconnect] = ACTIONS(4254),
    [anon_sym_typedef] = ACTIONS(4254),
    [anon_sym_enum] = ACTIONS(4254),
    [anon_sym_struct] = ACTIONS(4254),
    [anon_sym_union] = ACTIONS(4254),
    [anon_sym_nettype] = ACTIONS(4254),
    [anon_sym_automatic] = ACTIONS(4254),
    [anon_sym_string] = ACTIONS(4254),
    [anon_sym_chandle] = ACTIONS(4254),
    [anon_sym_event] = ACTIONS(4254),
    [anon_sym_byte] = ACTIONS(4254),
    [anon_sym_shortint] = ACTIONS(4254),
    [anon_sym_int] = ACTIONS(4254),
    [anon_sym_longint] = ACTIONS(4254),
    [anon_sym_integer] = ACTIONS(4254),
    [anon_sym_time] = ACTIONS(4254),
    [anon_sym_bit] = ACTIONS(4254),
    [anon_sym_logic] = ACTIONS(4254),
    [anon_sym_reg] = ACTIONS(4254),
    [anon_sym_shortreal] = ACTIONS(4254),
    [anon_sym_real] = ACTIONS(4254),
    [anon_sym_realtime] = ACTIONS(4254),
    [anon_sym_supply0] = ACTIONS(4254),
    [anon_sym_supply1] = ACTIONS(4254),
    [anon_sym_signed] = ACTIONS(4254),
    [anon_sym_unsigned] = ACTIONS(4254),
    [anon_sym_task] = ACTIONS(4254),
    [anon_sym_modport] = ACTIONS(4254),
    [anon_sym_assert] = ACTIONS(4254),
    [anon_sym_property] = ACTIONS(4254),
    [anon_sym_assume] = ACTIONS(4254),
    [anon_sym_cover] = ACTIONS(4254),
    [anon_sym_sequence] = ACTIONS(4254),
    [anon_sym_restrict] = ACTIONS(4254),
    [anon_sym_not] = ACTIONS(4254),
    [anon_sym_or] = ACTIONS(4254),
    [anon_sym_and] = ACTIONS(4254),
    [anon_sym_case] = ACTIONS(4254),
    [anon_sym_always] = ACTIONS(4254),
    [anon_sym_covergroup] = ACTIONS(4254),
    [anon_sym_let] = ACTIONS(4254),
    [anon_sym_pulldown] = ACTIONS(4254),
    [anon_sym_pullup] = ACTIONS(4254),
    [anon_sym_cmos] = ACTIONS(4254),
    [anon_sym_rcmos] = ACTIONS(4254),
    [anon_sym_bufif0] = ACTIONS(4254),
    [anon_sym_bufif1] = ACTIONS(4254),
    [anon_sym_notif0] = ACTIONS(4254),
    [anon_sym_notif1] = ACTIONS(4254),
    [anon_sym_nmos] = ACTIONS(4254),
    [anon_sym_pmos] = ACTIONS(4254),
    [anon_sym_rnmos] = ACTIONS(4254),
    [anon_sym_rpmos] = ACTIONS(4254),
    [anon_sym_nand] = ACTIONS(4254),
    [anon_sym_nor] = ACTIONS(4254),
    [anon_sym_xor] = ACTIONS(4254),
    [anon_sym_xnor] = ACTIONS(4254),
    [anon_sym_buf] = ACTIONS(4254),
    [anon_sym_tranif0] = ACTIONS(4254),
    [anon_sym_tranif1] = ACTIONS(4254),
    [anon_sym_rtranif1] = ACTIONS(4254),
    [anon_sym_rtranif0] = ACTIONS(4254),
    [anon_sym_tran] = ACTIONS(4254),
    [anon_sym_rtran] = ACTIONS(4254),
    [anon_sym_generate] = ACTIONS(4254),
    [anon_sym_for] = ACTIONS(4254),
    [anon_sym_primitive] = ACTIONS(4254),
    [anon_sym_initial] = ACTIONS(4254),
    [anon_sym_assign] = ACTIONS(4254),
    [anon_sym_alias] = ACTIONS(4254),
    [anon_sym_always_comb] = ACTIONS(4254),
    [anon_sym_always_latch] = ACTIONS(4254),
    [anon_sym_always_ff] = ACTIONS(4254),
    [anon_sym_final] = ACTIONS(4254),
    [anon_sym_global] = ACTIONS(4254),
    [anon_sym_specify] = ACTIONS(4254),
    [anon_sym_LPAREN_STAR] = ACTIONS(4252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4252),
    [anon_sym_DOLLARunit] = ACTIONS(4252),
  },
  [666] = {
    [ts_builtin_sym_end] = ACTIONS(4258),
    [sym_simple_identifier] = ACTIONS(4260),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4258),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4258),
    [anon_sym_BQUOTE] = ACTIONS(4260),
    [aux_sym_id_directive_token1] = ACTIONS(4258),
    [aux_sym_id_directive_token2] = ACTIONS(4258),
    [aux_sym_id_directive_token3] = ACTIONS(4258),
    [aux_sym_id_directive_token4] = ACTIONS(4260),
    [aux_sym_zero_directive_token1] = ACTIONS(4258),
    [aux_sym_zero_directive_token2] = ACTIONS(4258),
    [aux_sym_zero_directive_token3] = ACTIONS(4258),
    [aux_sym_zero_directive_token4] = ACTIONS(4258),
    [aux_sym_zero_directive_token5] = ACTIONS(4258),
    [aux_sym_zero_directive_token6] = ACTIONS(4258),
    [aux_sym_zero_directive_token7] = ACTIONS(4258),
    [aux_sym_zero_directive_token8] = ACTIONS(4258),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4258),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4258),
    [anon_sym_wire] = ACTIONS(4260),
    [anon_sym_tri] = ACTIONS(4260),
    [anon_sym_tri0] = ACTIONS(4260),
    [anon_sym_tri1] = ACTIONS(4260),
    [anon_sym_wand] = ACTIONS(4260),
    [anon_sym_triand] = ACTIONS(4260),
    [anon_sym_wor] = ACTIONS(4260),
    [anon_sym_trior] = ACTIONS(4260),
    [anon_sym_trireg] = ACTIONS(4260),
    [anon_sym_uwire] = ACTIONS(4260),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4258),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4258),
    [aux_sym_begin_keywords_token1] = ACTIONS(4258),
    [anon_sym_SEMI] = ACTIONS(4258),
    [anon_sym_endmodule] = ACTIONS(4260),
    [anon_sym_extern] = ACTIONS(4260),
    [anon_sym_module] = ACTIONS(4260),
    [anon_sym_macromodule] = ACTIONS(4260),
    [anon_sym_endinterface] = ACTIONS(4260),
    [anon_sym_interface] = ACTIONS(4260),
    [anon_sym_endprogram] = ACTIONS(4260),
    [anon_sym_program] = ACTIONS(4260),
    [anon_sym_checker] = ACTIONS(4260),
    [anon_sym_virtual] = ACTIONS(4260),
    [anon_sym_class] = ACTIONS(4260),
    [anon_sym_package] = ACTIONS(4260),
    [anon_sym_endpackage] = ACTIONS(4260),
    [anon_sym_timeunit] = ACTIONS(4260),
    [anon_sym_timeprecision] = ACTIONS(4260),
    [anon_sym_type] = ACTIONS(4260),
    [anon_sym_input] = ACTIONS(4260),
    [anon_sym_output] = ACTIONS(4260),
    [anon_sym_inout] = ACTIONS(4260),
    [anon_sym_ref] = ACTIONS(4260),
    [anon_sym_DOLLARfatal] = ACTIONS(4258),
    [anon_sym_DOLLARerror] = ACTIONS(4258),
    [anon_sym_DOLLARwarning] = ACTIONS(4258),
    [anon_sym_DOLLARinfo] = ACTIONS(4258),
    [anon_sym_default] = ACTIONS(4260),
    [anon_sym_clocking] = ACTIONS(4260),
    [anon_sym_defparam] = ACTIONS(4260),
    [anon_sym_bind] = ACTIONS(4260),
    [anon_sym_const] = ACTIONS(4260),
    [anon_sym_function] = ACTIONS(4260),
    [anon_sym_static] = ACTIONS(4260),
    [anon_sym_constraint] = ACTIONS(4260),
    [anon_sym_if] = ACTIONS(4260),
    [anon_sym_else] = ACTIONS(4260),
    [anon_sym_LBRACK] = ACTIONS(4258),
    [anon_sym_localparam] = ACTIONS(4260),
    [anon_sym_parameter] = ACTIONS(4260),
    [anon_sym_specparam] = ACTIONS(4260),
    [anon_sym_var] = ACTIONS(4260),
    [anon_sym_import] = ACTIONS(4260),
    [anon_sym_export] = ACTIONS(4260),
    [anon_sym_genvar] = ACTIONS(4260),
    [anon_sym_interconnect] = ACTIONS(4260),
    [anon_sym_typedef] = ACTIONS(4260),
    [anon_sym_enum] = ACTIONS(4260),
    [anon_sym_struct] = ACTIONS(4260),
    [anon_sym_union] = ACTIONS(4260),
    [anon_sym_nettype] = ACTIONS(4260),
    [anon_sym_automatic] = ACTIONS(4260),
    [anon_sym_string] = ACTIONS(4260),
    [anon_sym_chandle] = ACTIONS(4260),
    [anon_sym_event] = ACTIONS(4260),
    [anon_sym_byte] = ACTIONS(4260),
    [anon_sym_shortint] = ACTIONS(4260),
    [anon_sym_int] = ACTIONS(4260),
    [anon_sym_longint] = ACTIONS(4260),
    [anon_sym_integer] = ACTIONS(4260),
    [anon_sym_time] = ACTIONS(4260),
    [anon_sym_bit] = ACTIONS(4260),
    [anon_sym_logic] = ACTIONS(4260),
    [anon_sym_reg] = ACTIONS(4260),
    [anon_sym_shortreal] = ACTIONS(4260),
    [anon_sym_real] = ACTIONS(4260),
    [anon_sym_realtime] = ACTIONS(4260),
    [anon_sym_supply0] = ACTIONS(4260),
    [anon_sym_supply1] = ACTIONS(4260),
    [anon_sym_signed] = ACTIONS(4260),
    [anon_sym_unsigned] = ACTIONS(4260),
    [anon_sym_task] = ACTIONS(4260),
    [anon_sym_modport] = ACTIONS(4260),
    [anon_sym_assert] = ACTIONS(4260),
    [anon_sym_property] = ACTIONS(4260),
    [anon_sym_assume] = ACTIONS(4260),
    [anon_sym_cover] = ACTIONS(4260),
    [anon_sym_sequence] = ACTIONS(4260),
    [anon_sym_restrict] = ACTIONS(4260),
    [anon_sym_not] = ACTIONS(4260),
    [anon_sym_or] = ACTIONS(4260),
    [anon_sym_and] = ACTIONS(4260),
    [anon_sym_case] = ACTIONS(4260),
    [anon_sym_always] = ACTIONS(4260),
    [anon_sym_covergroup] = ACTIONS(4260),
    [anon_sym_let] = ACTIONS(4260),
    [anon_sym_pulldown] = ACTIONS(4260),
    [anon_sym_pullup] = ACTIONS(4260),
    [anon_sym_cmos] = ACTIONS(4260),
    [anon_sym_rcmos] = ACTIONS(4260),
    [anon_sym_bufif0] = ACTIONS(4260),
    [anon_sym_bufif1] = ACTIONS(4260),
    [anon_sym_notif0] = ACTIONS(4260),
    [anon_sym_notif1] = ACTIONS(4260),
    [anon_sym_nmos] = ACTIONS(4260),
    [anon_sym_pmos] = ACTIONS(4260),
    [anon_sym_rnmos] = ACTIONS(4260),
    [anon_sym_rpmos] = ACTIONS(4260),
    [anon_sym_nand] = ACTIONS(4260),
    [anon_sym_nor] = ACTIONS(4260),
    [anon_sym_xor] = ACTIONS(4260),
    [anon_sym_xnor] = ACTIONS(4260),
    [anon_sym_buf] = ACTIONS(4260),
    [anon_sym_tranif0] = ACTIONS(4260),
    [anon_sym_tranif1] = ACTIONS(4260),
    [anon_sym_rtranif1] = ACTIONS(4260),
    [anon_sym_rtranif0] = ACTIONS(4260),
    [anon_sym_tran] = ACTIONS(4260),
    [anon_sym_rtran] = ACTIONS(4260),
    [anon_sym_generate] = ACTIONS(4260),
    [anon_sym_for] = ACTIONS(4260),
    [anon_sym_primitive] = ACTIONS(4260),
    [anon_sym_initial] = ACTIONS(4260),
    [anon_sym_assign] = ACTIONS(4260),
    [anon_sym_alias] = ACTIONS(4260),
    [anon_sym_always_comb] = ACTIONS(4260),
    [anon_sym_always_latch] = ACTIONS(4260),
    [anon_sym_always_ff] = ACTIONS(4260),
    [anon_sym_final] = ACTIONS(4260),
    [anon_sym_endclocking] = ACTIONS(4260),
    [anon_sym_global] = ACTIONS(4260),
    [anon_sym_specify] = ACTIONS(4260),
    [anon_sym_LPAREN_STAR] = ACTIONS(4258),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4258),
    [anon_sym_DOLLARunit] = ACTIONS(4258),
  },
  [667] = {
    [ts_builtin_sym_end] = ACTIONS(4262),
    [sym_simple_identifier] = ACTIONS(4264),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4262),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4262),
    [anon_sym_BQUOTE] = ACTIONS(4264),
    [aux_sym_id_directive_token1] = ACTIONS(4262),
    [aux_sym_id_directive_token2] = ACTIONS(4262),
    [aux_sym_id_directive_token3] = ACTIONS(4262),
    [aux_sym_id_directive_token4] = ACTIONS(4264),
    [aux_sym_zero_directive_token1] = ACTIONS(4262),
    [aux_sym_zero_directive_token2] = ACTIONS(4262),
    [aux_sym_zero_directive_token3] = ACTIONS(4262),
    [aux_sym_zero_directive_token4] = ACTIONS(4262),
    [aux_sym_zero_directive_token5] = ACTIONS(4262),
    [aux_sym_zero_directive_token6] = ACTIONS(4262),
    [aux_sym_zero_directive_token7] = ACTIONS(4262),
    [aux_sym_zero_directive_token8] = ACTIONS(4262),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4262),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4262),
    [anon_sym_wire] = ACTIONS(4264),
    [anon_sym_tri] = ACTIONS(4264),
    [anon_sym_tri0] = ACTIONS(4264),
    [anon_sym_tri1] = ACTIONS(4264),
    [anon_sym_wand] = ACTIONS(4264),
    [anon_sym_triand] = ACTIONS(4264),
    [anon_sym_wor] = ACTIONS(4264),
    [anon_sym_trior] = ACTIONS(4264),
    [anon_sym_trireg] = ACTIONS(4264),
    [anon_sym_uwire] = ACTIONS(4264),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4262),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4262),
    [aux_sym_begin_keywords_token1] = ACTIONS(4262),
    [anon_sym_SEMI] = ACTIONS(4262),
    [anon_sym_endmodule] = ACTIONS(4264),
    [anon_sym_COLON] = ACTIONS(4266),
    [anon_sym_extern] = ACTIONS(4264),
    [anon_sym_module] = ACTIONS(4264),
    [anon_sym_macromodule] = ACTIONS(4264),
    [anon_sym_endinterface] = ACTIONS(4264),
    [anon_sym_interface] = ACTIONS(4264),
    [anon_sym_endprogram] = ACTIONS(4264),
    [anon_sym_program] = ACTIONS(4264),
    [anon_sym_checker] = ACTIONS(4264),
    [anon_sym_virtual] = ACTIONS(4264),
    [anon_sym_class] = ACTIONS(4264),
    [anon_sym_package] = ACTIONS(4264),
    [anon_sym_endpackage] = ACTIONS(4264),
    [anon_sym_timeunit] = ACTIONS(4264),
    [anon_sym_timeprecision] = ACTIONS(4264),
    [anon_sym_type] = ACTIONS(4264),
    [anon_sym_input] = ACTIONS(4264),
    [anon_sym_output] = ACTIONS(4264),
    [anon_sym_inout] = ACTIONS(4264),
    [anon_sym_ref] = ACTIONS(4264),
    [anon_sym_DOLLARfatal] = ACTIONS(4262),
    [anon_sym_DOLLARerror] = ACTIONS(4262),
    [anon_sym_DOLLARwarning] = ACTIONS(4262),
    [anon_sym_DOLLARinfo] = ACTIONS(4262),
    [anon_sym_default] = ACTIONS(4264),
    [anon_sym_clocking] = ACTIONS(4264),
    [anon_sym_defparam] = ACTIONS(4264),
    [anon_sym_bind] = ACTIONS(4264),
    [anon_sym_const] = ACTIONS(4264),
    [anon_sym_function] = ACTIONS(4264),
    [anon_sym_static] = ACTIONS(4264),
    [anon_sym_constraint] = ACTIONS(4264),
    [anon_sym_if] = ACTIONS(4264),
    [anon_sym_else] = ACTIONS(4264),
    [anon_sym_LBRACK] = ACTIONS(4262),
    [anon_sym_localparam] = ACTIONS(4264),
    [anon_sym_parameter] = ACTIONS(4264),
    [anon_sym_specparam] = ACTIONS(4264),
    [anon_sym_var] = ACTIONS(4264),
    [anon_sym_import] = ACTIONS(4264),
    [anon_sym_export] = ACTIONS(4264),
    [anon_sym_genvar] = ACTIONS(4264),
    [anon_sym_interconnect] = ACTIONS(4264),
    [anon_sym_typedef] = ACTIONS(4264),
    [anon_sym_enum] = ACTIONS(4264),
    [anon_sym_struct] = ACTIONS(4264),
    [anon_sym_union] = ACTIONS(4264),
    [anon_sym_nettype] = ACTIONS(4264),
    [anon_sym_automatic] = ACTIONS(4264),
    [anon_sym_string] = ACTIONS(4264),
    [anon_sym_chandle] = ACTIONS(4264),
    [anon_sym_event] = ACTIONS(4264),
    [anon_sym_byte] = ACTIONS(4264),
    [anon_sym_shortint] = ACTIONS(4264),
    [anon_sym_int] = ACTIONS(4264),
    [anon_sym_longint] = ACTIONS(4264),
    [anon_sym_integer] = ACTIONS(4264),
    [anon_sym_time] = ACTIONS(4264),
    [anon_sym_bit] = ACTIONS(4264),
    [anon_sym_logic] = ACTIONS(4264),
    [anon_sym_reg] = ACTIONS(4264),
    [anon_sym_shortreal] = ACTIONS(4264),
    [anon_sym_real] = ACTIONS(4264),
    [anon_sym_realtime] = ACTIONS(4264),
    [anon_sym_supply0] = ACTIONS(4264),
    [anon_sym_supply1] = ACTIONS(4264),
    [anon_sym_signed] = ACTIONS(4264),
    [anon_sym_unsigned] = ACTIONS(4264),
    [anon_sym_task] = ACTIONS(4264),
    [anon_sym_modport] = ACTIONS(4264),
    [anon_sym_assert] = ACTIONS(4264),
    [anon_sym_property] = ACTIONS(4264),
    [anon_sym_assume] = ACTIONS(4264),
    [anon_sym_cover] = ACTIONS(4264),
    [anon_sym_sequence] = ACTIONS(4264),
    [anon_sym_restrict] = ACTIONS(4264),
    [anon_sym_not] = ACTIONS(4264),
    [anon_sym_or] = ACTIONS(4264),
    [anon_sym_and] = ACTIONS(4264),
    [anon_sym_case] = ACTIONS(4264),
    [anon_sym_always] = ACTIONS(4264),
    [anon_sym_covergroup] = ACTIONS(4264),
    [anon_sym_let] = ACTIONS(4264),
    [anon_sym_pulldown] = ACTIONS(4264),
    [anon_sym_pullup] = ACTIONS(4264),
    [anon_sym_cmos] = ACTIONS(4264),
    [anon_sym_rcmos] = ACTIONS(4264),
    [anon_sym_bufif0] = ACTIONS(4264),
    [anon_sym_bufif1] = ACTIONS(4264),
    [anon_sym_notif0] = ACTIONS(4264),
    [anon_sym_notif1] = ACTIONS(4264),
    [anon_sym_nmos] = ACTIONS(4264),
    [anon_sym_pmos] = ACTIONS(4264),
    [anon_sym_rnmos] = ACTIONS(4264),
    [anon_sym_rpmos] = ACTIONS(4264),
    [anon_sym_nand] = ACTIONS(4264),
    [anon_sym_nor] = ACTIONS(4264),
    [anon_sym_xor] = ACTIONS(4264),
    [anon_sym_xnor] = ACTIONS(4264),
    [anon_sym_buf] = ACTIONS(4264),
    [anon_sym_tranif0] = ACTIONS(4264),
    [anon_sym_tranif1] = ACTIONS(4264),
    [anon_sym_rtranif1] = ACTIONS(4264),
    [anon_sym_rtranif0] = ACTIONS(4264),
    [anon_sym_tran] = ACTIONS(4264),
    [anon_sym_rtran] = ACTIONS(4264),
    [anon_sym_generate] = ACTIONS(4264),
    [anon_sym_for] = ACTIONS(4264),
    [anon_sym_primitive] = ACTIONS(4264),
    [anon_sym_initial] = ACTIONS(4264),
    [anon_sym_assign] = ACTIONS(4264),
    [anon_sym_alias] = ACTIONS(4264),
    [anon_sym_always_comb] = ACTIONS(4264),
    [anon_sym_always_latch] = ACTIONS(4264),
    [anon_sym_always_ff] = ACTIONS(4264),
    [anon_sym_final] = ACTIONS(4264),
    [anon_sym_global] = ACTIONS(4264),
    [anon_sym_specify] = ACTIONS(4264),
    [anon_sym_LPAREN_STAR] = ACTIONS(4262),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4262),
    [anon_sym_DOLLARunit] = ACTIONS(4262),
  },
  [668] = {
    [ts_builtin_sym_end] = ACTIONS(4268),
    [sym_simple_identifier] = ACTIONS(4270),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4268),
    [anon_sym_BQUOTE] = ACTIONS(4270),
    [aux_sym_id_directive_token1] = ACTIONS(4268),
    [aux_sym_id_directive_token2] = ACTIONS(4268),
    [aux_sym_id_directive_token3] = ACTIONS(4268),
    [aux_sym_id_directive_token4] = ACTIONS(4270),
    [aux_sym_zero_directive_token1] = ACTIONS(4268),
    [aux_sym_zero_directive_token2] = ACTIONS(4268),
    [aux_sym_zero_directive_token3] = ACTIONS(4268),
    [aux_sym_zero_directive_token4] = ACTIONS(4268),
    [aux_sym_zero_directive_token5] = ACTIONS(4268),
    [aux_sym_zero_directive_token6] = ACTIONS(4268),
    [aux_sym_zero_directive_token7] = ACTIONS(4268),
    [aux_sym_zero_directive_token8] = ACTIONS(4268),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4268),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4268),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_begin_keywords_token1] = ACTIONS(4268),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_endmodule] = ACTIONS(4270),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_module] = ACTIONS(4270),
    [anon_sym_macromodule] = ACTIONS(4270),
    [anon_sym_endinterface] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_endprogram] = ACTIONS(4270),
    [anon_sym_program] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_package] = ACTIONS(4270),
    [anon_sym_endpackage] = ACTIONS(4270),
    [anon_sym_timeunit] = ACTIONS(4270),
    [anon_sym_timeprecision] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_input] = ACTIONS(4270),
    [anon_sym_output] = ACTIONS(4270),
    [anon_sym_inout] = ACTIONS(4270),
    [anon_sym_ref] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_specparam] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_modport] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_primitive] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_endclocking] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_specify] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [669] = {
    [ts_builtin_sym_end] = ACTIONS(4272),
    [sym_simple_identifier] = ACTIONS(4274),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4272),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4272),
    [anon_sym_BQUOTE] = ACTIONS(4274),
    [aux_sym_id_directive_token1] = ACTIONS(4272),
    [aux_sym_id_directive_token2] = ACTIONS(4272),
    [aux_sym_id_directive_token3] = ACTIONS(4272),
    [aux_sym_id_directive_token4] = ACTIONS(4274),
    [aux_sym_zero_directive_token1] = ACTIONS(4272),
    [aux_sym_zero_directive_token2] = ACTIONS(4272),
    [aux_sym_zero_directive_token3] = ACTIONS(4272),
    [aux_sym_zero_directive_token4] = ACTIONS(4272),
    [aux_sym_zero_directive_token5] = ACTIONS(4272),
    [aux_sym_zero_directive_token6] = ACTIONS(4272),
    [aux_sym_zero_directive_token7] = ACTIONS(4272),
    [aux_sym_zero_directive_token8] = ACTIONS(4272),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4272),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4272),
    [anon_sym_wire] = ACTIONS(4274),
    [anon_sym_tri] = ACTIONS(4274),
    [anon_sym_tri0] = ACTIONS(4274),
    [anon_sym_tri1] = ACTIONS(4274),
    [anon_sym_wand] = ACTIONS(4274),
    [anon_sym_triand] = ACTIONS(4274),
    [anon_sym_wor] = ACTIONS(4274),
    [anon_sym_trior] = ACTIONS(4274),
    [anon_sym_trireg] = ACTIONS(4274),
    [anon_sym_uwire] = ACTIONS(4274),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4272),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4272),
    [aux_sym_begin_keywords_token1] = ACTIONS(4272),
    [anon_sym_SEMI] = ACTIONS(4272),
    [anon_sym_endmodule] = ACTIONS(4274),
    [anon_sym_COLON] = ACTIONS(4276),
    [anon_sym_extern] = ACTIONS(4274),
    [anon_sym_module] = ACTIONS(4274),
    [anon_sym_macromodule] = ACTIONS(4274),
    [anon_sym_endinterface] = ACTIONS(4274),
    [anon_sym_interface] = ACTIONS(4274),
    [anon_sym_endprogram] = ACTIONS(4274),
    [anon_sym_program] = ACTIONS(4274),
    [anon_sym_checker] = ACTIONS(4274),
    [anon_sym_virtual] = ACTIONS(4274),
    [anon_sym_class] = ACTIONS(4274),
    [anon_sym_package] = ACTIONS(4274),
    [anon_sym_endpackage] = ACTIONS(4274),
    [anon_sym_timeunit] = ACTIONS(4274),
    [anon_sym_timeprecision] = ACTIONS(4274),
    [anon_sym_type] = ACTIONS(4274),
    [anon_sym_input] = ACTIONS(4274),
    [anon_sym_output] = ACTIONS(4274),
    [anon_sym_inout] = ACTIONS(4274),
    [anon_sym_ref] = ACTIONS(4274),
    [anon_sym_DOLLARfatal] = ACTIONS(4272),
    [anon_sym_DOLLARerror] = ACTIONS(4272),
    [anon_sym_DOLLARwarning] = ACTIONS(4272),
    [anon_sym_DOLLARinfo] = ACTIONS(4272),
    [anon_sym_default] = ACTIONS(4274),
    [anon_sym_clocking] = ACTIONS(4274),
    [anon_sym_defparam] = ACTIONS(4274),
    [anon_sym_bind] = ACTIONS(4274),
    [anon_sym_const] = ACTIONS(4274),
    [anon_sym_function] = ACTIONS(4274),
    [anon_sym_static] = ACTIONS(4274),
    [anon_sym_constraint] = ACTIONS(4274),
    [anon_sym_if] = ACTIONS(4274),
    [anon_sym_else] = ACTIONS(4274),
    [anon_sym_LBRACK] = ACTIONS(4272),
    [anon_sym_localparam] = ACTIONS(4274),
    [anon_sym_parameter] = ACTIONS(4274),
    [anon_sym_specparam] = ACTIONS(4274),
    [anon_sym_var] = ACTIONS(4274),
    [anon_sym_import] = ACTIONS(4274),
    [anon_sym_export] = ACTIONS(4274),
    [anon_sym_genvar] = ACTIONS(4274),
    [anon_sym_interconnect] = ACTIONS(4274),
    [anon_sym_typedef] = ACTIONS(4274),
    [anon_sym_enum] = ACTIONS(4274),
    [anon_sym_struct] = ACTIONS(4274),
    [anon_sym_union] = ACTIONS(4274),
    [anon_sym_nettype] = ACTIONS(4274),
    [anon_sym_automatic] = ACTIONS(4274),
    [anon_sym_string] = ACTIONS(4274),
    [anon_sym_chandle] = ACTIONS(4274),
    [anon_sym_event] = ACTIONS(4274),
    [anon_sym_byte] = ACTIONS(4274),
    [anon_sym_shortint] = ACTIONS(4274),
    [anon_sym_int] = ACTIONS(4274),
    [anon_sym_longint] = ACTIONS(4274),
    [anon_sym_integer] = ACTIONS(4274),
    [anon_sym_time] = ACTIONS(4274),
    [anon_sym_bit] = ACTIONS(4274),
    [anon_sym_logic] = ACTIONS(4274),
    [anon_sym_reg] = ACTIONS(4274),
    [anon_sym_shortreal] = ACTIONS(4274),
    [anon_sym_real] = ACTIONS(4274),
    [anon_sym_realtime] = ACTIONS(4274),
    [anon_sym_supply0] = ACTIONS(4274),
    [anon_sym_supply1] = ACTIONS(4274),
    [anon_sym_signed] = ACTIONS(4274),
    [anon_sym_unsigned] = ACTIONS(4274),
    [anon_sym_task] = ACTIONS(4274),
    [anon_sym_modport] = ACTIONS(4274),
    [anon_sym_assert] = ACTIONS(4274),
    [anon_sym_property] = ACTIONS(4274),
    [anon_sym_assume] = ACTIONS(4274),
    [anon_sym_cover] = ACTIONS(4274),
    [anon_sym_sequence] = ACTIONS(4274),
    [anon_sym_restrict] = ACTIONS(4274),
    [anon_sym_not] = ACTIONS(4274),
    [anon_sym_or] = ACTIONS(4274),
    [anon_sym_and] = ACTIONS(4274),
    [anon_sym_case] = ACTIONS(4274),
    [anon_sym_always] = ACTIONS(4274),
    [anon_sym_covergroup] = ACTIONS(4274),
    [anon_sym_let] = ACTIONS(4274),
    [anon_sym_pulldown] = ACTIONS(4274),
    [anon_sym_pullup] = ACTIONS(4274),
    [anon_sym_cmos] = ACTIONS(4274),
    [anon_sym_rcmos] = ACTIONS(4274),
    [anon_sym_bufif0] = ACTIONS(4274),
    [anon_sym_bufif1] = ACTIONS(4274),
    [anon_sym_notif0] = ACTIONS(4274),
    [anon_sym_notif1] = ACTIONS(4274),
    [anon_sym_nmos] = ACTIONS(4274),
    [anon_sym_pmos] = ACTIONS(4274),
    [anon_sym_rnmos] = ACTIONS(4274),
    [anon_sym_rpmos] = ACTIONS(4274),
    [anon_sym_nand] = ACTIONS(4274),
    [anon_sym_nor] = ACTIONS(4274),
    [anon_sym_xor] = ACTIONS(4274),
    [anon_sym_xnor] = ACTIONS(4274),
    [anon_sym_buf] = ACTIONS(4274),
    [anon_sym_tranif0] = ACTIONS(4274),
    [anon_sym_tranif1] = ACTIONS(4274),
    [anon_sym_rtranif1] = ACTIONS(4274),
    [anon_sym_rtranif0] = ACTIONS(4274),
    [anon_sym_tran] = ACTIONS(4274),
    [anon_sym_rtran] = ACTIONS(4274),
    [anon_sym_generate] = ACTIONS(4274),
    [anon_sym_for] = ACTIONS(4274),
    [anon_sym_primitive] = ACTIONS(4274),
    [anon_sym_initial] = ACTIONS(4274),
    [anon_sym_assign] = ACTIONS(4274),
    [anon_sym_alias] = ACTIONS(4274),
    [anon_sym_always_comb] = ACTIONS(4274),
    [anon_sym_always_latch] = ACTIONS(4274),
    [anon_sym_always_ff] = ACTIONS(4274),
    [anon_sym_final] = ACTIONS(4274),
    [anon_sym_global] = ACTIONS(4274),
    [anon_sym_specify] = ACTIONS(4274),
    [anon_sym_LPAREN_STAR] = ACTIONS(4272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4272),
    [anon_sym_DOLLARunit] = ACTIONS(4272),
  },
  [670] = {
    [ts_builtin_sym_end] = ACTIONS(4278),
    [sym_simple_identifier] = ACTIONS(4280),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4278),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4278),
    [anon_sym_BQUOTE] = ACTIONS(4280),
    [aux_sym_id_directive_token1] = ACTIONS(4278),
    [aux_sym_id_directive_token2] = ACTIONS(4278),
    [aux_sym_id_directive_token3] = ACTIONS(4278),
    [aux_sym_id_directive_token4] = ACTIONS(4280),
    [aux_sym_zero_directive_token1] = ACTIONS(4278),
    [aux_sym_zero_directive_token2] = ACTIONS(4278),
    [aux_sym_zero_directive_token3] = ACTIONS(4278),
    [aux_sym_zero_directive_token4] = ACTIONS(4278),
    [aux_sym_zero_directive_token5] = ACTIONS(4278),
    [aux_sym_zero_directive_token6] = ACTIONS(4278),
    [aux_sym_zero_directive_token7] = ACTIONS(4278),
    [aux_sym_zero_directive_token8] = ACTIONS(4278),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4278),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4278),
    [anon_sym_wire] = ACTIONS(4280),
    [anon_sym_tri] = ACTIONS(4280),
    [anon_sym_tri0] = ACTIONS(4280),
    [anon_sym_tri1] = ACTIONS(4280),
    [anon_sym_wand] = ACTIONS(4280),
    [anon_sym_triand] = ACTIONS(4280),
    [anon_sym_wor] = ACTIONS(4280),
    [anon_sym_trior] = ACTIONS(4280),
    [anon_sym_trireg] = ACTIONS(4280),
    [anon_sym_uwire] = ACTIONS(4280),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4278),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4278),
    [aux_sym_begin_keywords_token1] = ACTIONS(4278),
    [anon_sym_SEMI] = ACTIONS(4278),
    [anon_sym_endmodule] = ACTIONS(4280),
    [anon_sym_COLON] = ACTIONS(4282),
    [anon_sym_extern] = ACTIONS(4280),
    [anon_sym_module] = ACTIONS(4280),
    [anon_sym_macromodule] = ACTIONS(4280),
    [anon_sym_endinterface] = ACTIONS(4280),
    [anon_sym_interface] = ACTIONS(4280),
    [anon_sym_endprogram] = ACTIONS(4280),
    [anon_sym_program] = ACTIONS(4280),
    [anon_sym_checker] = ACTIONS(4280),
    [anon_sym_virtual] = ACTIONS(4280),
    [anon_sym_class] = ACTIONS(4280),
    [anon_sym_package] = ACTIONS(4280),
    [anon_sym_endpackage] = ACTIONS(4280),
    [anon_sym_timeunit] = ACTIONS(4280),
    [anon_sym_timeprecision] = ACTIONS(4280),
    [anon_sym_type] = ACTIONS(4280),
    [anon_sym_input] = ACTIONS(4280),
    [anon_sym_output] = ACTIONS(4280),
    [anon_sym_inout] = ACTIONS(4280),
    [anon_sym_ref] = ACTIONS(4280),
    [anon_sym_DOLLARfatal] = ACTIONS(4278),
    [anon_sym_DOLLARerror] = ACTIONS(4278),
    [anon_sym_DOLLARwarning] = ACTIONS(4278),
    [anon_sym_DOLLARinfo] = ACTIONS(4278),
    [anon_sym_default] = ACTIONS(4280),
    [anon_sym_clocking] = ACTIONS(4280),
    [anon_sym_defparam] = ACTIONS(4280),
    [anon_sym_bind] = ACTIONS(4280),
    [anon_sym_const] = ACTIONS(4280),
    [anon_sym_function] = ACTIONS(4280),
    [anon_sym_static] = ACTIONS(4280),
    [anon_sym_constraint] = ACTIONS(4280),
    [anon_sym_if] = ACTIONS(4280),
    [anon_sym_else] = ACTIONS(4280),
    [anon_sym_LBRACK] = ACTIONS(4278),
    [anon_sym_localparam] = ACTIONS(4280),
    [anon_sym_parameter] = ACTIONS(4280),
    [anon_sym_specparam] = ACTIONS(4280),
    [anon_sym_var] = ACTIONS(4280),
    [anon_sym_import] = ACTIONS(4280),
    [anon_sym_export] = ACTIONS(4280),
    [anon_sym_genvar] = ACTIONS(4280),
    [anon_sym_interconnect] = ACTIONS(4280),
    [anon_sym_typedef] = ACTIONS(4280),
    [anon_sym_enum] = ACTIONS(4280),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_union] = ACTIONS(4280),
    [anon_sym_nettype] = ACTIONS(4280),
    [anon_sym_automatic] = ACTIONS(4280),
    [anon_sym_string] = ACTIONS(4280),
    [anon_sym_chandle] = ACTIONS(4280),
    [anon_sym_event] = ACTIONS(4280),
    [anon_sym_byte] = ACTIONS(4280),
    [anon_sym_shortint] = ACTIONS(4280),
    [anon_sym_int] = ACTIONS(4280),
    [anon_sym_longint] = ACTIONS(4280),
    [anon_sym_integer] = ACTIONS(4280),
    [anon_sym_time] = ACTIONS(4280),
    [anon_sym_bit] = ACTIONS(4280),
    [anon_sym_logic] = ACTIONS(4280),
    [anon_sym_reg] = ACTIONS(4280),
    [anon_sym_shortreal] = ACTIONS(4280),
    [anon_sym_real] = ACTIONS(4280),
    [anon_sym_realtime] = ACTIONS(4280),
    [anon_sym_supply0] = ACTIONS(4280),
    [anon_sym_supply1] = ACTIONS(4280),
    [anon_sym_signed] = ACTIONS(4280),
    [anon_sym_unsigned] = ACTIONS(4280),
    [anon_sym_task] = ACTIONS(4280),
    [anon_sym_modport] = ACTIONS(4280),
    [anon_sym_assert] = ACTIONS(4280),
    [anon_sym_property] = ACTIONS(4280),
    [anon_sym_assume] = ACTIONS(4280),
    [anon_sym_cover] = ACTIONS(4280),
    [anon_sym_sequence] = ACTIONS(4280),
    [anon_sym_restrict] = ACTIONS(4280),
    [anon_sym_not] = ACTIONS(4280),
    [anon_sym_or] = ACTIONS(4280),
    [anon_sym_and] = ACTIONS(4280),
    [anon_sym_case] = ACTIONS(4280),
    [anon_sym_always] = ACTIONS(4280),
    [anon_sym_covergroup] = ACTIONS(4280),
    [anon_sym_let] = ACTIONS(4280),
    [anon_sym_pulldown] = ACTIONS(4280),
    [anon_sym_pullup] = ACTIONS(4280),
    [anon_sym_cmos] = ACTIONS(4280),
    [anon_sym_rcmos] = ACTIONS(4280),
    [anon_sym_bufif0] = ACTIONS(4280),
    [anon_sym_bufif1] = ACTIONS(4280),
    [anon_sym_notif0] = ACTIONS(4280),
    [anon_sym_notif1] = ACTIONS(4280),
    [anon_sym_nmos] = ACTIONS(4280),
    [anon_sym_pmos] = ACTIONS(4280),
    [anon_sym_rnmos] = ACTIONS(4280),
    [anon_sym_rpmos] = ACTIONS(4280),
    [anon_sym_nand] = ACTIONS(4280),
    [anon_sym_nor] = ACTIONS(4280),
    [anon_sym_xor] = ACTIONS(4280),
    [anon_sym_xnor] = ACTIONS(4280),
    [anon_sym_buf] = ACTIONS(4280),
    [anon_sym_tranif0] = ACTIONS(4280),
    [anon_sym_tranif1] = ACTIONS(4280),
    [anon_sym_rtranif1] = ACTIONS(4280),
    [anon_sym_rtranif0] = ACTIONS(4280),
    [anon_sym_tran] = ACTIONS(4280),
    [anon_sym_rtran] = ACTIONS(4280),
    [anon_sym_generate] = ACTIONS(4280),
    [anon_sym_for] = ACTIONS(4280),
    [anon_sym_primitive] = ACTIONS(4280),
    [anon_sym_initial] = ACTIONS(4280),
    [anon_sym_assign] = ACTIONS(4280),
    [anon_sym_alias] = ACTIONS(4280),
    [anon_sym_always_comb] = ACTIONS(4280),
    [anon_sym_always_latch] = ACTIONS(4280),
    [anon_sym_always_ff] = ACTIONS(4280),
    [anon_sym_final] = ACTIONS(4280),
    [anon_sym_global] = ACTIONS(4280),
    [anon_sym_specify] = ACTIONS(4280),
    [anon_sym_LPAREN_STAR] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4278),
    [anon_sym_DOLLARunit] = ACTIONS(4278),
  },
  [671] = {
    [ts_builtin_sym_end] = ACTIONS(4284),
    [sym_simple_identifier] = ACTIONS(4286),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4284),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4284),
    [anon_sym_BQUOTE] = ACTIONS(4286),
    [aux_sym_id_directive_token1] = ACTIONS(4284),
    [aux_sym_id_directive_token2] = ACTIONS(4284),
    [aux_sym_id_directive_token3] = ACTIONS(4284),
    [aux_sym_id_directive_token4] = ACTIONS(4286),
    [aux_sym_zero_directive_token1] = ACTIONS(4284),
    [aux_sym_zero_directive_token2] = ACTIONS(4284),
    [aux_sym_zero_directive_token3] = ACTIONS(4284),
    [aux_sym_zero_directive_token4] = ACTIONS(4284),
    [aux_sym_zero_directive_token5] = ACTIONS(4284),
    [aux_sym_zero_directive_token6] = ACTIONS(4284),
    [aux_sym_zero_directive_token7] = ACTIONS(4284),
    [aux_sym_zero_directive_token8] = ACTIONS(4284),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4284),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4284),
    [anon_sym_wire] = ACTIONS(4286),
    [anon_sym_tri] = ACTIONS(4286),
    [anon_sym_tri0] = ACTIONS(4286),
    [anon_sym_tri1] = ACTIONS(4286),
    [anon_sym_wand] = ACTIONS(4286),
    [anon_sym_triand] = ACTIONS(4286),
    [anon_sym_wor] = ACTIONS(4286),
    [anon_sym_trior] = ACTIONS(4286),
    [anon_sym_trireg] = ACTIONS(4286),
    [anon_sym_uwire] = ACTIONS(4286),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4284),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4284),
    [aux_sym_begin_keywords_token1] = ACTIONS(4284),
    [anon_sym_SEMI] = ACTIONS(4284),
    [anon_sym_endmodule] = ACTIONS(4286),
    [anon_sym_COLON] = ACTIONS(4288),
    [anon_sym_extern] = ACTIONS(4286),
    [anon_sym_module] = ACTIONS(4286),
    [anon_sym_macromodule] = ACTIONS(4286),
    [anon_sym_endinterface] = ACTIONS(4286),
    [anon_sym_interface] = ACTIONS(4286),
    [anon_sym_endprogram] = ACTIONS(4286),
    [anon_sym_program] = ACTIONS(4286),
    [anon_sym_checker] = ACTIONS(4286),
    [anon_sym_virtual] = ACTIONS(4286),
    [anon_sym_class] = ACTIONS(4286),
    [anon_sym_package] = ACTIONS(4286),
    [anon_sym_endpackage] = ACTIONS(4286),
    [anon_sym_timeunit] = ACTIONS(4286),
    [anon_sym_timeprecision] = ACTIONS(4286),
    [anon_sym_type] = ACTIONS(4286),
    [anon_sym_input] = ACTIONS(4286),
    [anon_sym_output] = ACTIONS(4286),
    [anon_sym_inout] = ACTIONS(4286),
    [anon_sym_ref] = ACTIONS(4286),
    [anon_sym_DOLLARfatal] = ACTIONS(4284),
    [anon_sym_DOLLARerror] = ACTIONS(4284),
    [anon_sym_DOLLARwarning] = ACTIONS(4284),
    [anon_sym_DOLLARinfo] = ACTIONS(4284),
    [anon_sym_default] = ACTIONS(4286),
    [anon_sym_clocking] = ACTIONS(4286),
    [anon_sym_defparam] = ACTIONS(4286),
    [anon_sym_bind] = ACTIONS(4286),
    [anon_sym_const] = ACTIONS(4286),
    [anon_sym_function] = ACTIONS(4286),
    [anon_sym_static] = ACTIONS(4286),
    [anon_sym_constraint] = ACTIONS(4286),
    [anon_sym_if] = ACTIONS(4286),
    [anon_sym_else] = ACTIONS(4286),
    [anon_sym_LBRACK] = ACTIONS(4284),
    [anon_sym_localparam] = ACTIONS(4286),
    [anon_sym_parameter] = ACTIONS(4286),
    [anon_sym_specparam] = ACTIONS(4286),
    [anon_sym_var] = ACTIONS(4286),
    [anon_sym_import] = ACTIONS(4286),
    [anon_sym_export] = ACTIONS(4286),
    [anon_sym_genvar] = ACTIONS(4286),
    [anon_sym_interconnect] = ACTIONS(4286),
    [anon_sym_typedef] = ACTIONS(4286),
    [anon_sym_enum] = ACTIONS(4286),
    [anon_sym_struct] = ACTIONS(4286),
    [anon_sym_union] = ACTIONS(4286),
    [anon_sym_nettype] = ACTIONS(4286),
    [anon_sym_automatic] = ACTIONS(4286),
    [anon_sym_string] = ACTIONS(4286),
    [anon_sym_chandle] = ACTIONS(4286),
    [anon_sym_event] = ACTIONS(4286),
    [anon_sym_byte] = ACTIONS(4286),
    [anon_sym_shortint] = ACTIONS(4286),
    [anon_sym_int] = ACTIONS(4286),
    [anon_sym_longint] = ACTIONS(4286),
    [anon_sym_integer] = ACTIONS(4286),
    [anon_sym_time] = ACTIONS(4286),
    [anon_sym_bit] = ACTIONS(4286),
    [anon_sym_logic] = ACTIONS(4286),
    [anon_sym_reg] = ACTIONS(4286),
    [anon_sym_shortreal] = ACTIONS(4286),
    [anon_sym_real] = ACTIONS(4286),
    [anon_sym_realtime] = ACTIONS(4286),
    [anon_sym_supply0] = ACTIONS(4286),
    [anon_sym_supply1] = ACTIONS(4286),
    [anon_sym_signed] = ACTIONS(4286),
    [anon_sym_unsigned] = ACTIONS(4286),
    [anon_sym_task] = ACTIONS(4286),
    [anon_sym_modport] = ACTIONS(4286),
    [anon_sym_assert] = ACTIONS(4286),
    [anon_sym_property] = ACTIONS(4286),
    [anon_sym_assume] = ACTIONS(4286),
    [anon_sym_cover] = ACTIONS(4286),
    [anon_sym_sequence] = ACTIONS(4286),
    [anon_sym_restrict] = ACTIONS(4286),
    [anon_sym_not] = ACTIONS(4286),
    [anon_sym_or] = ACTIONS(4286),
    [anon_sym_and] = ACTIONS(4286),
    [anon_sym_case] = ACTIONS(4286),
    [anon_sym_always] = ACTIONS(4286),
    [anon_sym_covergroup] = ACTIONS(4286),
    [anon_sym_let] = ACTIONS(4286),
    [anon_sym_pulldown] = ACTIONS(4286),
    [anon_sym_pullup] = ACTIONS(4286),
    [anon_sym_cmos] = ACTIONS(4286),
    [anon_sym_rcmos] = ACTIONS(4286),
    [anon_sym_bufif0] = ACTIONS(4286),
    [anon_sym_bufif1] = ACTIONS(4286),
    [anon_sym_notif0] = ACTIONS(4286),
    [anon_sym_notif1] = ACTIONS(4286),
    [anon_sym_nmos] = ACTIONS(4286),
    [anon_sym_pmos] = ACTIONS(4286),
    [anon_sym_rnmos] = ACTIONS(4286),
    [anon_sym_rpmos] = ACTIONS(4286),
    [anon_sym_nand] = ACTIONS(4286),
    [anon_sym_nor] = ACTIONS(4286),
    [anon_sym_xor] = ACTIONS(4286),
    [anon_sym_xnor] = ACTIONS(4286),
    [anon_sym_buf] = ACTIONS(4286),
    [anon_sym_tranif0] = ACTIONS(4286),
    [anon_sym_tranif1] = ACTIONS(4286),
    [anon_sym_rtranif1] = ACTIONS(4286),
    [anon_sym_rtranif0] = ACTIONS(4286),
    [anon_sym_tran] = ACTIONS(4286),
    [anon_sym_rtran] = ACTIONS(4286),
    [anon_sym_generate] = ACTIONS(4286),
    [anon_sym_for] = ACTIONS(4286),
    [anon_sym_primitive] = ACTIONS(4286),
    [anon_sym_initial] = ACTIONS(4286),
    [anon_sym_assign] = ACTIONS(4286),
    [anon_sym_alias] = ACTIONS(4286),
    [anon_sym_always_comb] = ACTIONS(4286),
    [anon_sym_always_latch] = ACTIONS(4286),
    [anon_sym_always_ff] = ACTIONS(4286),
    [anon_sym_final] = ACTIONS(4286),
    [anon_sym_global] = ACTIONS(4286),
    [anon_sym_specify] = ACTIONS(4286),
    [anon_sym_LPAREN_STAR] = ACTIONS(4284),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4284),
    [anon_sym_DOLLARunit] = ACTIONS(4284),
  },
  [672] = {
    [ts_builtin_sym_end] = ACTIONS(4268),
    [sym_simple_identifier] = ACTIONS(4270),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4268),
    [anon_sym_BQUOTE] = ACTIONS(4270),
    [aux_sym_id_directive_token1] = ACTIONS(4268),
    [aux_sym_id_directive_token2] = ACTIONS(4268),
    [aux_sym_id_directive_token3] = ACTIONS(4268),
    [aux_sym_id_directive_token4] = ACTIONS(4270),
    [aux_sym_zero_directive_token1] = ACTIONS(4268),
    [aux_sym_zero_directive_token2] = ACTIONS(4268),
    [aux_sym_zero_directive_token3] = ACTIONS(4268),
    [aux_sym_zero_directive_token4] = ACTIONS(4268),
    [aux_sym_zero_directive_token5] = ACTIONS(4268),
    [aux_sym_zero_directive_token6] = ACTIONS(4268),
    [aux_sym_zero_directive_token7] = ACTIONS(4268),
    [aux_sym_zero_directive_token8] = ACTIONS(4268),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4268),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4268),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4268),
    [aux_sym_begin_keywords_token1] = ACTIONS(4268),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_endmodule] = ACTIONS(4270),
    [anon_sym_COLON] = ACTIONS(4290),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_module] = ACTIONS(4270),
    [anon_sym_macromodule] = ACTIONS(4270),
    [anon_sym_endinterface] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_endprogram] = ACTIONS(4270),
    [anon_sym_program] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_package] = ACTIONS(4270),
    [anon_sym_endpackage] = ACTIONS(4270),
    [anon_sym_timeunit] = ACTIONS(4270),
    [anon_sym_timeprecision] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_input] = ACTIONS(4270),
    [anon_sym_output] = ACTIONS(4270),
    [anon_sym_inout] = ACTIONS(4270),
    [anon_sym_ref] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_specparam] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_modport] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_primitive] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_specify] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [673] = {
    [ts_builtin_sym_end] = ACTIONS(4292),
    [sym_simple_identifier] = ACTIONS(4294),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4292),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4292),
    [anon_sym_BQUOTE] = ACTIONS(4294),
    [aux_sym_id_directive_token1] = ACTIONS(4292),
    [aux_sym_id_directive_token2] = ACTIONS(4292),
    [aux_sym_id_directive_token3] = ACTIONS(4292),
    [aux_sym_id_directive_token4] = ACTIONS(4294),
    [aux_sym_zero_directive_token1] = ACTIONS(4292),
    [aux_sym_zero_directive_token2] = ACTIONS(4292),
    [aux_sym_zero_directive_token3] = ACTIONS(4292),
    [aux_sym_zero_directive_token4] = ACTIONS(4292),
    [aux_sym_zero_directive_token5] = ACTIONS(4292),
    [aux_sym_zero_directive_token6] = ACTIONS(4292),
    [aux_sym_zero_directive_token7] = ACTIONS(4292),
    [aux_sym_zero_directive_token8] = ACTIONS(4292),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4292),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4292),
    [anon_sym_wire] = ACTIONS(4294),
    [anon_sym_tri] = ACTIONS(4294),
    [anon_sym_tri0] = ACTIONS(4294),
    [anon_sym_tri1] = ACTIONS(4294),
    [anon_sym_wand] = ACTIONS(4294),
    [anon_sym_triand] = ACTIONS(4294),
    [anon_sym_wor] = ACTIONS(4294),
    [anon_sym_trior] = ACTIONS(4294),
    [anon_sym_trireg] = ACTIONS(4294),
    [anon_sym_uwire] = ACTIONS(4294),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4292),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4292),
    [aux_sym_begin_keywords_token1] = ACTIONS(4292),
    [anon_sym_SEMI] = ACTIONS(4292),
    [anon_sym_endmodule] = ACTIONS(4294),
    [anon_sym_COLON] = ACTIONS(4296),
    [anon_sym_extern] = ACTIONS(4294),
    [anon_sym_module] = ACTIONS(4294),
    [anon_sym_macromodule] = ACTIONS(4294),
    [anon_sym_endinterface] = ACTIONS(4294),
    [anon_sym_interface] = ACTIONS(4294),
    [anon_sym_endprogram] = ACTIONS(4294),
    [anon_sym_program] = ACTIONS(4294),
    [anon_sym_checker] = ACTIONS(4294),
    [anon_sym_virtual] = ACTIONS(4294),
    [anon_sym_class] = ACTIONS(4294),
    [anon_sym_package] = ACTIONS(4294),
    [anon_sym_endpackage] = ACTIONS(4294),
    [anon_sym_timeunit] = ACTIONS(4294),
    [anon_sym_timeprecision] = ACTIONS(4294),
    [anon_sym_type] = ACTIONS(4294),
    [anon_sym_input] = ACTIONS(4294),
    [anon_sym_output] = ACTIONS(4294),
    [anon_sym_inout] = ACTIONS(4294),
    [anon_sym_ref] = ACTIONS(4294),
    [anon_sym_DOLLARfatal] = ACTIONS(4292),
    [anon_sym_DOLLARerror] = ACTIONS(4292),
    [anon_sym_DOLLARwarning] = ACTIONS(4292),
    [anon_sym_DOLLARinfo] = ACTIONS(4292),
    [anon_sym_default] = ACTIONS(4294),
    [anon_sym_clocking] = ACTIONS(4294),
    [anon_sym_defparam] = ACTIONS(4294),
    [anon_sym_bind] = ACTIONS(4294),
    [anon_sym_const] = ACTIONS(4294),
    [anon_sym_function] = ACTIONS(4294),
    [anon_sym_static] = ACTIONS(4294),
    [anon_sym_constraint] = ACTIONS(4294),
    [anon_sym_if] = ACTIONS(4294),
    [anon_sym_else] = ACTIONS(4294),
    [anon_sym_LBRACK] = ACTIONS(4292),
    [anon_sym_localparam] = ACTIONS(4294),
    [anon_sym_parameter] = ACTIONS(4294),
    [anon_sym_specparam] = ACTIONS(4294),
    [anon_sym_var] = ACTIONS(4294),
    [anon_sym_import] = ACTIONS(4294),
    [anon_sym_export] = ACTIONS(4294),
    [anon_sym_genvar] = ACTIONS(4294),
    [anon_sym_interconnect] = ACTIONS(4294),
    [anon_sym_typedef] = ACTIONS(4294),
    [anon_sym_enum] = ACTIONS(4294),
    [anon_sym_struct] = ACTIONS(4294),
    [anon_sym_union] = ACTIONS(4294),
    [anon_sym_nettype] = ACTIONS(4294),
    [anon_sym_automatic] = ACTIONS(4294),
    [anon_sym_string] = ACTIONS(4294),
    [anon_sym_chandle] = ACTIONS(4294),
    [anon_sym_event] = ACTIONS(4294),
    [anon_sym_byte] = ACTIONS(4294),
    [anon_sym_shortint] = ACTIONS(4294),
    [anon_sym_int] = ACTIONS(4294),
    [anon_sym_longint] = ACTIONS(4294),
    [anon_sym_integer] = ACTIONS(4294),
    [anon_sym_time] = ACTIONS(4294),
    [anon_sym_bit] = ACTIONS(4294),
    [anon_sym_logic] = ACTIONS(4294),
    [anon_sym_reg] = ACTIONS(4294),
    [anon_sym_shortreal] = ACTIONS(4294),
    [anon_sym_real] = ACTIONS(4294),
    [anon_sym_realtime] = ACTIONS(4294),
    [anon_sym_supply0] = ACTIONS(4294),
    [anon_sym_supply1] = ACTIONS(4294),
    [anon_sym_signed] = ACTIONS(4294),
    [anon_sym_unsigned] = ACTIONS(4294),
    [anon_sym_task] = ACTIONS(4294),
    [anon_sym_modport] = ACTIONS(4294),
    [anon_sym_assert] = ACTIONS(4294),
    [anon_sym_property] = ACTIONS(4294),
    [anon_sym_assume] = ACTIONS(4294),
    [anon_sym_cover] = ACTIONS(4294),
    [anon_sym_sequence] = ACTIONS(4294),
    [anon_sym_restrict] = ACTIONS(4294),
    [anon_sym_not] = ACTIONS(4294),
    [anon_sym_or] = ACTIONS(4294),
    [anon_sym_and] = ACTIONS(4294),
    [anon_sym_case] = ACTIONS(4294),
    [anon_sym_always] = ACTIONS(4294),
    [anon_sym_covergroup] = ACTIONS(4294),
    [anon_sym_let] = ACTIONS(4294),
    [anon_sym_pulldown] = ACTIONS(4294),
    [anon_sym_pullup] = ACTIONS(4294),
    [anon_sym_cmos] = ACTIONS(4294),
    [anon_sym_rcmos] = ACTIONS(4294),
    [anon_sym_bufif0] = ACTIONS(4294),
    [anon_sym_bufif1] = ACTIONS(4294),
    [anon_sym_notif0] = ACTIONS(4294),
    [anon_sym_notif1] = ACTIONS(4294),
    [anon_sym_nmos] = ACTIONS(4294),
    [anon_sym_pmos] = ACTIONS(4294),
    [anon_sym_rnmos] = ACTIONS(4294),
    [anon_sym_rpmos] = ACTIONS(4294),
    [anon_sym_nand] = ACTIONS(4294),
    [anon_sym_nor] = ACTIONS(4294),
    [anon_sym_xor] = ACTIONS(4294),
    [anon_sym_xnor] = ACTIONS(4294),
    [anon_sym_buf] = ACTIONS(4294),
    [anon_sym_tranif0] = ACTIONS(4294),
    [anon_sym_tranif1] = ACTIONS(4294),
    [anon_sym_rtranif1] = ACTIONS(4294),
    [anon_sym_rtranif0] = ACTIONS(4294),
    [anon_sym_tran] = ACTIONS(4294),
    [anon_sym_rtran] = ACTIONS(4294),
    [anon_sym_generate] = ACTIONS(4294),
    [anon_sym_for] = ACTIONS(4294),
    [anon_sym_primitive] = ACTIONS(4294),
    [anon_sym_initial] = ACTIONS(4294),
    [anon_sym_assign] = ACTIONS(4294),
    [anon_sym_alias] = ACTIONS(4294),
    [anon_sym_always_comb] = ACTIONS(4294),
    [anon_sym_always_latch] = ACTIONS(4294),
    [anon_sym_always_ff] = ACTIONS(4294),
    [anon_sym_final] = ACTIONS(4294),
    [anon_sym_global] = ACTIONS(4294),
    [anon_sym_specify] = ACTIONS(4294),
    [anon_sym_LPAREN_STAR] = ACTIONS(4292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4292),
    [anon_sym_DOLLARunit] = ACTIONS(4292),
  },
  [674] = {
    [ts_builtin_sym_end] = ACTIONS(4298),
    [sym_simple_identifier] = ACTIONS(4300),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4298),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4298),
    [anon_sym_BQUOTE] = ACTIONS(4300),
    [aux_sym_id_directive_token1] = ACTIONS(4298),
    [aux_sym_id_directive_token2] = ACTIONS(4298),
    [aux_sym_id_directive_token3] = ACTIONS(4298),
    [aux_sym_id_directive_token4] = ACTIONS(4300),
    [aux_sym_zero_directive_token1] = ACTIONS(4298),
    [aux_sym_zero_directive_token2] = ACTIONS(4298),
    [aux_sym_zero_directive_token3] = ACTIONS(4298),
    [aux_sym_zero_directive_token4] = ACTIONS(4298),
    [aux_sym_zero_directive_token5] = ACTIONS(4298),
    [aux_sym_zero_directive_token6] = ACTIONS(4298),
    [aux_sym_zero_directive_token7] = ACTIONS(4298),
    [aux_sym_zero_directive_token8] = ACTIONS(4298),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4298),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4298),
    [anon_sym_wire] = ACTIONS(4300),
    [anon_sym_tri] = ACTIONS(4300),
    [anon_sym_tri0] = ACTIONS(4300),
    [anon_sym_tri1] = ACTIONS(4300),
    [anon_sym_wand] = ACTIONS(4300),
    [anon_sym_triand] = ACTIONS(4300),
    [anon_sym_wor] = ACTIONS(4300),
    [anon_sym_trior] = ACTIONS(4300),
    [anon_sym_trireg] = ACTIONS(4300),
    [anon_sym_uwire] = ACTIONS(4300),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4298),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4298),
    [aux_sym_begin_keywords_token1] = ACTIONS(4298),
    [anon_sym_SEMI] = ACTIONS(4298),
    [anon_sym_endmodule] = ACTIONS(4300),
    [anon_sym_extern] = ACTIONS(4300),
    [anon_sym_module] = ACTIONS(4300),
    [anon_sym_macromodule] = ACTIONS(4300),
    [anon_sym_endinterface] = ACTIONS(4300),
    [anon_sym_interface] = ACTIONS(4300),
    [anon_sym_endprogram] = ACTIONS(4300),
    [anon_sym_program] = ACTIONS(4300),
    [anon_sym_checker] = ACTIONS(4300),
    [anon_sym_virtual] = ACTIONS(4300),
    [anon_sym_class] = ACTIONS(4300),
    [anon_sym_package] = ACTIONS(4300),
    [anon_sym_endpackage] = ACTIONS(4300),
    [anon_sym_timeunit] = ACTIONS(4300),
    [anon_sym_timeprecision] = ACTIONS(4300),
    [anon_sym_type] = ACTIONS(4300),
    [anon_sym_input] = ACTIONS(4300),
    [anon_sym_output] = ACTIONS(4300),
    [anon_sym_inout] = ACTIONS(4300),
    [anon_sym_ref] = ACTIONS(4300),
    [anon_sym_DOLLARfatal] = ACTIONS(4298),
    [anon_sym_DOLLARerror] = ACTIONS(4298),
    [anon_sym_DOLLARwarning] = ACTIONS(4298),
    [anon_sym_DOLLARinfo] = ACTIONS(4298),
    [anon_sym_default] = ACTIONS(4300),
    [anon_sym_clocking] = ACTIONS(4300),
    [anon_sym_defparam] = ACTIONS(4300),
    [anon_sym_bind] = ACTIONS(4300),
    [anon_sym_const] = ACTIONS(4300),
    [anon_sym_function] = ACTIONS(4300),
    [anon_sym_static] = ACTIONS(4300),
    [anon_sym_constraint] = ACTIONS(4300),
    [anon_sym_if] = ACTIONS(4300),
    [anon_sym_else] = ACTIONS(4300),
    [anon_sym_LBRACK] = ACTIONS(4298),
    [anon_sym_localparam] = ACTIONS(4300),
    [anon_sym_parameter] = ACTIONS(4300),
    [anon_sym_specparam] = ACTIONS(4300),
    [anon_sym_var] = ACTIONS(4300),
    [anon_sym_import] = ACTIONS(4300),
    [anon_sym_export] = ACTIONS(4300),
    [anon_sym_genvar] = ACTIONS(4300),
    [anon_sym_interconnect] = ACTIONS(4300),
    [anon_sym_typedef] = ACTIONS(4300),
    [anon_sym_enum] = ACTIONS(4300),
    [anon_sym_struct] = ACTIONS(4300),
    [anon_sym_union] = ACTIONS(4300),
    [anon_sym_nettype] = ACTIONS(4300),
    [anon_sym_automatic] = ACTIONS(4300),
    [anon_sym_string] = ACTIONS(4300),
    [anon_sym_chandle] = ACTIONS(4300),
    [anon_sym_event] = ACTIONS(4300),
    [anon_sym_byte] = ACTIONS(4300),
    [anon_sym_shortint] = ACTIONS(4300),
    [anon_sym_int] = ACTIONS(4300),
    [anon_sym_longint] = ACTIONS(4300),
    [anon_sym_integer] = ACTIONS(4300),
    [anon_sym_time] = ACTIONS(4300),
    [anon_sym_bit] = ACTIONS(4300),
    [anon_sym_logic] = ACTIONS(4300),
    [anon_sym_reg] = ACTIONS(4300),
    [anon_sym_shortreal] = ACTIONS(4300),
    [anon_sym_real] = ACTIONS(4300),
    [anon_sym_realtime] = ACTIONS(4300),
    [anon_sym_supply0] = ACTIONS(4300),
    [anon_sym_supply1] = ACTIONS(4300),
    [anon_sym_signed] = ACTIONS(4300),
    [anon_sym_unsigned] = ACTIONS(4300),
    [anon_sym_task] = ACTIONS(4300),
    [anon_sym_modport] = ACTIONS(4300),
    [anon_sym_assert] = ACTIONS(4300),
    [anon_sym_property] = ACTIONS(4300),
    [anon_sym_assume] = ACTIONS(4300),
    [anon_sym_cover] = ACTIONS(4300),
    [anon_sym_sequence] = ACTIONS(4300),
    [anon_sym_restrict] = ACTIONS(4300),
    [anon_sym_not] = ACTIONS(4300),
    [anon_sym_or] = ACTIONS(4300),
    [anon_sym_and] = ACTIONS(4300),
    [anon_sym_case] = ACTIONS(4300),
    [anon_sym_always] = ACTIONS(4300),
    [anon_sym_covergroup] = ACTIONS(4300),
    [anon_sym_let] = ACTIONS(4300),
    [anon_sym_pulldown] = ACTIONS(4300),
    [anon_sym_pullup] = ACTIONS(4300),
    [anon_sym_cmos] = ACTIONS(4300),
    [anon_sym_rcmos] = ACTIONS(4300),
    [anon_sym_bufif0] = ACTIONS(4300),
    [anon_sym_bufif1] = ACTIONS(4300),
    [anon_sym_notif0] = ACTIONS(4300),
    [anon_sym_notif1] = ACTIONS(4300),
    [anon_sym_nmos] = ACTIONS(4300),
    [anon_sym_pmos] = ACTIONS(4300),
    [anon_sym_rnmos] = ACTIONS(4300),
    [anon_sym_rpmos] = ACTIONS(4300),
    [anon_sym_nand] = ACTIONS(4300),
    [anon_sym_nor] = ACTIONS(4300),
    [anon_sym_xor] = ACTIONS(4300),
    [anon_sym_xnor] = ACTIONS(4300),
    [anon_sym_buf] = ACTIONS(4300),
    [anon_sym_tranif0] = ACTIONS(4300),
    [anon_sym_tranif1] = ACTIONS(4300),
    [anon_sym_rtranif1] = ACTIONS(4300),
    [anon_sym_rtranif0] = ACTIONS(4300),
    [anon_sym_tran] = ACTIONS(4300),
    [anon_sym_rtran] = ACTIONS(4300),
    [anon_sym_generate] = ACTIONS(4300),
    [anon_sym_for] = ACTIONS(4300),
    [anon_sym_primitive] = ACTIONS(4300),
    [anon_sym_initial] = ACTIONS(4300),
    [anon_sym_assign] = ACTIONS(4300),
    [anon_sym_alias] = ACTIONS(4300),
    [anon_sym_always_comb] = ACTIONS(4300),
    [anon_sym_always_latch] = ACTIONS(4300),
    [anon_sym_always_ff] = ACTIONS(4300),
    [anon_sym_final] = ACTIONS(4300),
    [anon_sym_endclocking] = ACTIONS(4300),
    [anon_sym_global] = ACTIONS(4300),
    [anon_sym_specify] = ACTIONS(4300),
    [anon_sym_LPAREN_STAR] = ACTIONS(4298),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4298),
    [anon_sym_DOLLARunit] = ACTIONS(4298),
  },
  [675] = {
    [ts_builtin_sym_end] = ACTIONS(4302),
    [sym_simple_identifier] = ACTIONS(4304),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4302),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4302),
    [anon_sym_BQUOTE] = ACTIONS(4304),
    [aux_sym_id_directive_token1] = ACTIONS(4302),
    [aux_sym_id_directive_token2] = ACTIONS(4302),
    [aux_sym_id_directive_token3] = ACTIONS(4302),
    [aux_sym_id_directive_token4] = ACTIONS(4304),
    [aux_sym_zero_directive_token1] = ACTIONS(4302),
    [aux_sym_zero_directive_token2] = ACTIONS(4302),
    [aux_sym_zero_directive_token3] = ACTIONS(4302),
    [aux_sym_zero_directive_token4] = ACTIONS(4302),
    [aux_sym_zero_directive_token5] = ACTIONS(4302),
    [aux_sym_zero_directive_token6] = ACTIONS(4302),
    [aux_sym_zero_directive_token7] = ACTIONS(4302),
    [aux_sym_zero_directive_token8] = ACTIONS(4302),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4302),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4302),
    [anon_sym_wire] = ACTIONS(4304),
    [anon_sym_tri] = ACTIONS(4304),
    [anon_sym_tri0] = ACTIONS(4304),
    [anon_sym_tri1] = ACTIONS(4304),
    [anon_sym_wand] = ACTIONS(4304),
    [anon_sym_triand] = ACTIONS(4304),
    [anon_sym_wor] = ACTIONS(4304),
    [anon_sym_trior] = ACTIONS(4304),
    [anon_sym_trireg] = ACTIONS(4304),
    [anon_sym_uwire] = ACTIONS(4304),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4302),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4302),
    [aux_sym_begin_keywords_token1] = ACTIONS(4302),
    [anon_sym_SEMI] = ACTIONS(4302),
    [anon_sym_endmodule] = ACTIONS(4304),
    [anon_sym_COLON] = ACTIONS(4306),
    [anon_sym_extern] = ACTIONS(4304),
    [anon_sym_module] = ACTIONS(4304),
    [anon_sym_macromodule] = ACTIONS(4304),
    [anon_sym_endinterface] = ACTIONS(4304),
    [anon_sym_interface] = ACTIONS(4304),
    [anon_sym_endprogram] = ACTIONS(4304),
    [anon_sym_program] = ACTIONS(4304),
    [anon_sym_checker] = ACTIONS(4304),
    [anon_sym_virtual] = ACTIONS(4304),
    [anon_sym_class] = ACTIONS(4304),
    [anon_sym_package] = ACTIONS(4304),
    [anon_sym_endpackage] = ACTIONS(4304),
    [anon_sym_timeunit] = ACTIONS(4304),
    [anon_sym_timeprecision] = ACTIONS(4304),
    [anon_sym_type] = ACTIONS(4304),
    [anon_sym_input] = ACTIONS(4304),
    [anon_sym_output] = ACTIONS(4304),
    [anon_sym_inout] = ACTIONS(4304),
    [anon_sym_ref] = ACTIONS(4304),
    [anon_sym_DOLLARfatal] = ACTIONS(4302),
    [anon_sym_DOLLARerror] = ACTIONS(4302),
    [anon_sym_DOLLARwarning] = ACTIONS(4302),
    [anon_sym_DOLLARinfo] = ACTIONS(4302),
    [anon_sym_default] = ACTIONS(4304),
    [anon_sym_clocking] = ACTIONS(4304),
    [anon_sym_defparam] = ACTIONS(4304),
    [anon_sym_bind] = ACTIONS(4304),
    [anon_sym_const] = ACTIONS(4304),
    [anon_sym_function] = ACTIONS(4304),
    [anon_sym_static] = ACTIONS(4304),
    [anon_sym_constraint] = ACTIONS(4304),
    [anon_sym_if] = ACTIONS(4304),
    [anon_sym_else] = ACTIONS(4304),
    [anon_sym_LBRACK] = ACTIONS(4302),
    [anon_sym_localparam] = ACTIONS(4304),
    [anon_sym_parameter] = ACTIONS(4304),
    [anon_sym_specparam] = ACTIONS(4304),
    [anon_sym_var] = ACTIONS(4304),
    [anon_sym_import] = ACTIONS(4304),
    [anon_sym_export] = ACTIONS(4304),
    [anon_sym_genvar] = ACTIONS(4304),
    [anon_sym_interconnect] = ACTIONS(4304),
    [anon_sym_typedef] = ACTIONS(4304),
    [anon_sym_enum] = ACTIONS(4304),
    [anon_sym_struct] = ACTIONS(4304),
    [anon_sym_union] = ACTIONS(4304),
    [anon_sym_nettype] = ACTIONS(4304),
    [anon_sym_automatic] = ACTIONS(4304),
    [anon_sym_string] = ACTIONS(4304),
    [anon_sym_chandle] = ACTIONS(4304),
    [anon_sym_event] = ACTIONS(4304),
    [anon_sym_byte] = ACTIONS(4304),
    [anon_sym_shortint] = ACTIONS(4304),
    [anon_sym_int] = ACTIONS(4304),
    [anon_sym_longint] = ACTIONS(4304),
    [anon_sym_integer] = ACTIONS(4304),
    [anon_sym_time] = ACTIONS(4304),
    [anon_sym_bit] = ACTIONS(4304),
    [anon_sym_logic] = ACTIONS(4304),
    [anon_sym_reg] = ACTIONS(4304),
    [anon_sym_shortreal] = ACTIONS(4304),
    [anon_sym_real] = ACTIONS(4304),
    [anon_sym_realtime] = ACTIONS(4304),
    [anon_sym_supply0] = ACTIONS(4304),
    [anon_sym_supply1] = ACTIONS(4304),
    [anon_sym_signed] = ACTIONS(4304),
    [anon_sym_unsigned] = ACTIONS(4304),
    [anon_sym_task] = ACTIONS(4304),
    [anon_sym_modport] = ACTIONS(4304),
    [anon_sym_assert] = ACTIONS(4304),
    [anon_sym_property] = ACTIONS(4304),
    [anon_sym_assume] = ACTIONS(4304),
    [anon_sym_cover] = ACTIONS(4304),
    [anon_sym_sequence] = ACTIONS(4304),
    [anon_sym_restrict] = ACTIONS(4304),
    [anon_sym_not] = ACTIONS(4304),
    [anon_sym_or] = ACTIONS(4304),
    [anon_sym_and] = ACTIONS(4304),
    [anon_sym_case] = ACTIONS(4304),
    [anon_sym_always] = ACTIONS(4304),
    [anon_sym_covergroup] = ACTIONS(4304),
    [anon_sym_let] = ACTIONS(4304),
    [anon_sym_pulldown] = ACTIONS(4304),
    [anon_sym_pullup] = ACTIONS(4304),
    [anon_sym_cmos] = ACTIONS(4304),
    [anon_sym_rcmos] = ACTIONS(4304),
    [anon_sym_bufif0] = ACTIONS(4304),
    [anon_sym_bufif1] = ACTIONS(4304),
    [anon_sym_notif0] = ACTIONS(4304),
    [anon_sym_notif1] = ACTIONS(4304),
    [anon_sym_nmos] = ACTIONS(4304),
    [anon_sym_pmos] = ACTIONS(4304),
    [anon_sym_rnmos] = ACTIONS(4304),
    [anon_sym_rpmos] = ACTIONS(4304),
    [anon_sym_nand] = ACTIONS(4304),
    [anon_sym_nor] = ACTIONS(4304),
    [anon_sym_xor] = ACTIONS(4304),
    [anon_sym_xnor] = ACTIONS(4304),
    [anon_sym_buf] = ACTIONS(4304),
    [anon_sym_tranif0] = ACTIONS(4304),
    [anon_sym_tranif1] = ACTIONS(4304),
    [anon_sym_rtranif1] = ACTIONS(4304),
    [anon_sym_rtranif0] = ACTIONS(4304),
    [anon_sym_tran] = ACTIONS(4304),
    [anon_sym_rtran] = ACTIONS(4304),
    [anon_sym_generate] = ACTIONS(4304),
    [anon_sym_for] = ACTIONS(4304),
    [anon_sym_primitive] = ACTIONS(4304),
    [anon_sym_initial] = ACTIONS(4304),
    [anon_sym_assign] = ACTIONS(4304),
    [anon_sym_alias] = ACTIONS(4304),
    [anon_sym_always_comb] = ACTIONS(4304),
    [anon_sym_always_latch] = ACTIONS(4304),
    [anon_sym_always_ff] = ACTIONS(4304),
    [anon_sym_final] = ACTIONS(4304),
    [anon_sym_global] = ACTIONS(4304),
    [anon_sym_specify] = ACTIONS(4304),
    [anon_sym_LPAREN_STAR] = ACTIONS(4302),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4302),
    [anon_sym_DOLLARunit] = ACTIONS(4302),
  },
  [676] = {
    [sym_simple_identifier] = ACTIONS(1680),
    [anon_sym_LT] = ACTIONS(1680),
    [anon_sym_GT] = ACTIONS(1680),
    [anon_sym_COMMA] = ACTIONS(1678),
    [anon_sym_SLASH] = ACTIONS(1680),
    [anon_sym_wire] = ACTIONS(1680),
    [anon_sym_tri] = ACTIONS(1680),
    [anon_sym_tri0] = ACTIONS(1680),
    [anon_sym_tri1] = ACTIONS(1680),
    [anon_sym_wand] = ACTIONS(1680),
    [anon_sym_triand] = ACTIONS(1680),
    [anon_sym_wor] = ACTIONS(1680),
    [anon_sym_trior] = ACTIONS(1680),
    [anon_sym_trireg] = ACTIONS(1680),
    [anon_sym_uwire] = ACTIONS(1680),
    [anon_sym_SEMI] = ACTIONS(1678),
    [anon_sym_extern] = ACTIONS(1680),
    [anon_sym_interface] = ACTIONS(1680),
    [anon_sym_checker] = ACTIONS(1680),
    [anon_sym_virtual] = ACTIONS(1680),
    [anon_sym_class] = ACTIONS(1680),
    [anon_sym_type] = ACTIONS(1680),
    [anon_sym_DOT] = ACTIONS(1678),
    [anon_sym_RBRACE] = ACTIONS(1678),
    [anon_sym_DOLLARfatal] = ACTIONS(1678),
    [anon_sym_DOLLARerror] = ACTIONS(1678),
    [anon_sym_DOLLARwarning] = ACTIONS(1678),
    [anon_sym_DOLLARinfo] = ACTIONS(1678),
    [anon_sym_default] = ACTIONS(1680),
    [anon_sym_clocking] = ACTIONS(1680),
    [anon_sym_defparam] = ACTIONS(1680),
    [anon_sym_bind] = ACTIONS(1680),
    [anon_sym_rand] = ACTIONS(1680),
    [anon_sym_const] = ACTIONS(1680),
    [anon_sym_function] = ACTIONS(1680),
    [anon_sym_static] = ACTIONS(1680),
    [anon_sym_constraint] = ACTIONS(1680),
    [anon_sym_if] = ACTIONS(1680),
    [anon_sym_else] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1678),
    [anon_sym_COLON_EQ] = ACTIONS(1678),
    [anon_sym_COLON_SLASH] = ACTIONS(1678),
    [anon_sym_localparam] = ACTIONS(1680),
    [anon_sym_parameter] = ACTIONS(1680),
    [anon_sym_var] = ACTIONS(1680),
    [anon_sym_import] = ACTIONS(1680),
    [anon_sym_STAR] = ACTIONS(1680),
    [anon_sym_export] = ACTIONS(1680),
    [anon_sym_genvar] = ACTIONS(1680),
    [anon_sym_interconnect] = ACTIONS(1680),
    [anon_sym_typedef] = ACTIONS(1680),
    [anon_sym_enum] = ACTIONS(1680),
    [anon_sym_struct] = ACTIONS(1680),
    [anon_sym_union] = ACTIONS(1680),
    [anon_sym_nettype] = ACTIONS(1680),
    [anon_sym_automatic] = ACTIONS(1680),
    [anon_sym_string] = ACTIONS(1680),
    [anon_sym_chandle] = ACTIONS(1680),
    [anon_sym_event] = ACTIONS(1680),
    [anon_sym_byte] = ACTIONS(1680),
    [anon_sym_shortint] = ACTIONS(1680),
    [anon_sym_int] = ACTIONS(1680),
    [anon_sym_longint] = ACTIONS(1680),
    [anon_sym_integer] = ACTIONS(1680),
    [anon_sym_time] = ACTIONS(1680),
    [anon_sym_bit] = ACTIONS(1680),
    [anon_sym_logic] = ACTIONS(1680),
    [anon_sym_reg] = ACTIONS(1680),
    [anon_sym_shortreal] = ACTIONS(1680),
    [anon_sym_real] = ACTIONS(1680),
    [anon_sym_realtime] = ACTIONS(1680),
    [anon_sym_supply0] = ACTIONS(1680),
    [anon_sym_supply1] = ACTIONS(1680),
    [anon_sym_signed] = ACTIONS(1680),
    [anon_sym_unsigned] = ACTIONS(1680),
    [anon_sym_task] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1678),
    [anon_sym_STAR_STAR] = ACTIONS(1678),
    [anon_sym_PERCENT] = ACTIONS(1678),
    [anon_sym_EQ_EQ] = ACTIONS(1680),
    [anon_sym_BANG_EQ] = ACTIONS(1680),
    [anon_sym_LT_EQ] = ACTIONS(1678),
    [anon_sym_GT_EQ] = ACTIONS(1678),
    [anon_sym_assert] = ACTIONS(1680),
    [anon_sym_property] = ACTIONS(1680),
    [anon_sym_assume] = ACTIONS(1680),
    [anon_sym_cover] = ACTIONS(1680),
    [anon_sym_sequence] = ACTIONS(1680),
    [anon_sym_restrict] = ACTIONS(1680),
    [anon_sym_not] = ACTIONS(1680),
    [anon_sym_or] = ACTIONS(1680),
    [anon_sym_and] = ACTIONS(1680),
    [anon_sym_case] = ACTIONS(1680),
    [anon_sym_always] = ACTIONS(1680),
    [anon_sym_covergroup] = ACTIONS(1680),
    [anon_sym_AMP_AMP] = ACTIONS(1680),
    [anon_sym_PIPE_PIPE] = ACTIONS(1678),
    [anon_sym_matches] = ACTIONS(1680),
    [anon_sym_let] = ACTIONS(1680),
    [anon_sym_pulldown] = ACTIONS(1680),
    [anon_sym_pullup] = ACTIONS(1680),
    [anon_sym_cmos] = ACTIONS(1680),
    [anon_sym_rcmos] = ACTIONS(1680),
    [anon_sym_bufif0] = ACTIONS(1680),
    [anon_sym_bufif1] = ACTIONS(1680),
    [anon_sym_notif0] = ACTIONS(1680),
    [anon_sym_notif1] = ACTIONS(1680),
    [anon_sym_nmos] = ACTIONS(1680),
    [anon_sym_pmos] = ACTIONS(1680),
    [anon_sym_rnmos] = ACTIONS(1680),
    [anon_sym_rpmos] = ACTIONS(1680),
    [anon_sym_nand] = ACTIONS(1680),
    [anon_sym_nor] = ACTIONS(1680),
    [anon_sym_xor] = ACTIONS(1680),
    [anon_sym_xnor] = ACTIONS(1680),
    [anon_sym_buf] = ACTIONS(1680),
    [anon_sym_tranif0] = ACTIONS(1680),
    [anon_sym_tranif1] = ACTIONS(1680),
    [anon_sym_rtranif1] = ACTIONS(1680),
    [anon_sym_rtranif0] = ACTIONS(1680),
    [anon_sym_tran] = ACTIONS(1680),
    [anon_sym_rtran] = ACTIONS(1680),
    [anon_sym_generate] = ACTIONS(1680),
    [anon_sym_endgenerate] = ACTIONS(1680),
    [anon_sym_for] = ACTIONS(1680),
    [anon_sym_initial] = ACTIONS(1680),
    [anon_sym_DASH] = ACTIONS(1680),
    [anon_sym_assign] = ACTIONS(1680),
    [anon_sym_alias] = ACTIONS(1680),
    [anon_sym_always_comb] = ACTIONS(1680),
    [anon_sym_always_latch] = ACTIONS(1680),
    [anon_sym_always_ff] = ACTIONS(1680),
    [anon_sym_final] = ACTIONS(1680),
    [anon_sym_DASH_GT] = ACTIONS(1678),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1678),
    [anon_sym_inside] = ACTIONS(1680),
    [anon_sym_global] = ACTIONS(1680),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1678),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1678),
    [anon_sym_GT_GT] = ACTIONS(1680),
    [anon_sym_LT_LT] = ACTIONS(1680),
    [anon_sym_QMARK] = ACTIONS(1678),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_AMP] = ACTIONS(1680),
    [anon_sym_PIPE] = ACTIONS(1680),
    [anon_sym_CARET] = ACTIONS(1680),
    [anon_sym_CARET_TILDE] = ACTIONS(1678),
    [anon_sym_TILDE_CARET] = ACTIONS(1678),
    [anon_sym_GT_GT_GT] = ACTIONS(1678),
    [anon_sym_LT_LT_LT] = ACTIONS(1678),
    [anon_sym_LT_DASH_GT] = ACTIONS(1678),
    [anon_sym_LPAREN_STAR] = ACTIONS(1678),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1678),
    [anon_sym_DOLLARunit] = ACTIONS(1678),
  },
  [677] = {
    [ts_builtin_sym_end] = ACTIONS(4308),
    [sym_simple_identifier] = ACTIONS(4310),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4308),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4308),
    [anon_sym_BQUOTE] = ACTIONS(4310),
    [aux_sym_id_directive_token1] = ACTIONS(4308),
    [aux_sym_id_directive_token2] = ACTIONS(4308),
    [aux_sym_id_directive_token3] = ACTIONS(4308),
    [aux_sym_id_directive_token4] = ACTIONS(4310),
    [aux_sym_zero_directive_token1] = ACTIONS(4308),
    [aux_sym_zero_directive_token2] = ACTIONS(4308),
    [aux_sym_zero_directive_token3] = ACTIONS(4308),
    [aux_sym_zero_directive_token4] = ACTIONS(4308),
    [aux_sym_zero_directive_token5] = ACTIONS(4308),
    [aux_sym_zero_directive_token6] = ACTIONS(4308),
    [aux_sym_zero_directive_token7] = ACTIONS(4308),
    [aux_sym_zero_directive_token8] = ACTIONS(4308),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4308),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4308),
    [anon_sym_wire] = ACTIONS(4310),
    [anon_sym_tri] = ACTIONS(4310),
    [anon_sym_tri0] = ACTIONS(4310),
    [anon_sym_tri1] = ACTIONS(4310),
    [anon_sym_wand] = ACTIONS(4310),
    [anon_sym_triand] = ACTIONS(4310),
    [anon_sym_wor] = ACTIONS(4310),
    [anon_sym_trior] = ACTIONS(4310),
    [anon_sym_trireg] = ACTIONS(4310),
    [anon_sym_uwire] = ACTIONS(4310),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4308),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4308),
    [aux_sym_begin_keywords_token1] = ACTIONS(4308),
    [anon_sym_SEMI] = ACTIONS(4308),
    [anon_sym_endmodule] = ACTIONS(4310),
    [anon_sym_COLON] = ACTIONS(4312),
    [anon_sym_extern] = ACTIONS(4310),
    [anon_sym_module] = ACTIONS(4310),
    [anon_sym_macromodule] = ACTIONS(4310),
    [anon_sym_endinterface] = ACTIONS(4310),
    [anon_sym_interface] = ACTIONS(4310),
    [anon_sym_endprogram] = ACTIONS(4310),
    [anon_sym_program] = ACTIONS(4310),
    [anon_sym_checker] = ACTIONS(4310),
    [anon_sym_virtual] = ACTIONS(4310),
    [anon_sym_class] = ACTIONS(4310),
    [anon_sym_package] = ACTIONS(4310),
    [anon_sym_endpackage] = ACTIONS(4310),
    [anon_sym_timeunit] = ACTIONS(4310),
    [anon_sym_timeprecision] = ACTIONS(4310),
    [anon_sym_type] = ACTIONS(4310),
    [anon_sym_input] = ACTIONS(4310),
    [anon_sym_output] = ACTIONS(4310),
    [anon_sym_inout] = ACTIONS(4310),
    [anon_sym_ref] = ACTIONS(4310),
    [anon_sym_DOLLARfatal] = ACTIONS(4308),
    [anon_sym_DOLLARerror] = ACTIONS(4308),
    [anon_sym_DOLLARwarning] = ACTIONS(4308),
    [anon_sym_DOLLARinfo] = ACTIONS(4308),
    [anon_sym_default] = ACTIONS(4310),
    [anon_sym_clocking] = ACTIONS(4310),
    [anon_sym_defparam] = ACTIONS(4310),
    [anon_sym_bind] = ACTIONS(4310),
    [anon_sym_const] = ACTIONS(4310),
    [anon_sym_function] = ACTIONS(4310),
    [anon_sym_static] = ACTIONS(4310),
    [anon_sym_constraint] = ACTIONS(4310),
    [anon_sym_if] = ACTIONS(4310),
    [anon_sym_else] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4308),
    [anon_sym_localparam] = ACTIONS(4310),
    [anon_sym_parameter] = ACTIONS(4310),
    [anon_sym_specparam] = ACTIONS(4310),
    [anon_sym_var] = ACTIONS(4310),
    [anon_sym_import] = ACTIONS(4310),
    [anon_sym_export] = ACTIONS(4310),
    [anon_sym_genvar] = ACTIONS(4310),
    [anon_sym_interconnect] = ACTIONS(4310),
    [anon_sym_typedef] = ACTIONS(4310),
    [anon_sym_enum] = ACTIONS(4310),
    [anon_sym_struct] = ACTIONS(4310),
    [anon_sym_union] = ACTIONS(4310),
    [anon_sym_nettype] = ACTIONS(4310),
    [anon_sym_automatic] = ACTIONS(4310),
    [anon_sym_string] = ACTIONS(4310),
    [anon_sym_chandle] = ACTIONS(4310),
    [anon_sym_event] = ACTIONS(4310),
    [anon_sym_byte] = ACTIONS(4310),
    [anon_sym_shortint] = ACTIONS(4310),
    [anon_sym_int] = ACTIONS(4310),
    [anon_sym_longint] = ACTIONS(4310),
    [anon_sym_integer] = ACTIONS(4310),
    [anon_sym_time] = ACTIONS(4310),
    [anon_sym_bit] = ACTIONS(4310),
    [anon_sym_logic] = ACTIONS(4310),
    [anon_sym_reg] = ACTIONS(4310),
    [anon_sym_shortreal] = ACTIONS(4310),
    [anon_sym_real] = ACTIONS(4310),
    [anon_sym_realtime] = ACTIONS(4310),
    [anon_sym_supply0] = ACTIONS(4310),
    [anon_sym_supply1] = ACTIONS(4310),
    [anon_sym_signed] = ACTIONS(4310),
    [anon_sym_unsigned] = ACTIONS(4310),
    [anon_sym_task] = ACTIONS(4310),
    [anon_sym_modport] = ACTIONS(4310),
    [anon_sym_assert] = ACTIONS(4310),
    [anon_sym_property] = ACTIONS(4310),
    [anon_sym_assume] = ACTIONS(4310),
    [anon_sym_cover] = ACTIONS(4310),
    [anon_sym_sequence] = ACTIONS(4310),
    [anon_sym_restrict] = ACTIONS(4310),
    [anon_sym_not] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_case] = ACTIONS(4310),
    [anon_sym_always] = ACTIONS(4310),
    [anon_sym_covergroup] = ACTIONS(4310),
    [anon_sym_let] = ACTIONS(4310),
    [anon_sym_pulldown] = ACTIONS(4310),
    [anon_sym_pullup] = ACTIONS(4310),
    [anon_sym_cmos] = ACTIONS(4310),
    [anon_sym_rcmos] = ACTIONS(4310),
    [anon_sym_bufif0] = ACTIONS(4310),
    [anon_sym_bufif1] = ACTIONS(4310),
    [anon_sym_notif0] = ACTIONS(4310),
    [anon_sym_notif1] = ACTIONS(4310),
    [anon_sym_nmos] = ACTIONS(4310),
    [anon_sym_pmos] = ACTIONS(4310),
    [anon_sym_rnmos] = ACTIONS(4310),
    [anon_sym_rpmos] = ACTIONS(4310),
    [anon_sym_nand] = ACTIONS(4310),
    [anon_sym_nor] = ACTIONS(4310),
    [anon_sym_xor] = ACTIONS(4310),
    [anon_sym_xnor] = ACTIONS(4310),
    [anon_sym_buf] = ACTIONS(4310),
    [anon_sym_tranif0] = ACTIONS(4310),
    [anon_sym_tranif1] = ACTIONS(4310),
    [anon_sym_rtranif1] = ACTIONS(4310),
    [anon_sym_rtranif0] = ACTIONS(4310),
    [anon_sym_tran] = ACTIONS(4310),
    [anon_sym_rtran] = ACTIONS(4310),
    [anon_sym_generate] = ACTIONS(4310),
    [anon_sym_for] = ACTIONS(4310),
    [anon_sym_primitive] = ACTIONS(4310),
    [anon_sym_initial] = ACTIONS(4310),
    [anon_sym_assign] = ACTIONS(4310),
    [anon_sym_alias] = ACTIONS(4310),
    [anon_sym_always_comb] = ACTIONS(4310),
    [anon_sym_always_latch] = ACTIONS(4310),
    [anon_sym_always_ff] = ACTIONS(4310),
    [anon_sym_final] = ACTIONS(4310),
    [anon_sym_global] = ACTIONS(4310),
    [anon_sym_specify] = ACTIONS(4310),
    [anon_sym_LPAREN_STAR] = ACTIONS(4308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4308),
    [anon_sym_DOLLARunit] = ACTIONS(4308),
  },
  [678] = {
    [ts_builtin_sym_end] = ACTIONS(4314),
    [sym_simple_identifier] = ACTIONS(4316),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4314),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4314),
    [anon_sym_BQUOTE] = ACTIONS(4316),
    [aux_sym_id_directive_token1] = ACTIONS(4314),
    [aux_sym_id_directive_token2] = ACTIONS(4314),
    [aux_sym_id_directive_token3] = ACTIONS(4314),
    [aux_sym_id_directive_token4] = ACTIONS(4316),
    [aux_sym_zero_directive_token1] = ACTIONS(4314),
    [aux_sym_zero_directive_token2] = ACTIONS(4314),
    [aux_sym_zero_directive_token3] = ACTIONS(4314),
    [aux_sym_zero_directive_token4] = ACTIONS(4314),
    [aux_sym_zero_directive_token5] = ACTIONS(4314),
    [aux_sym_zero_directive_token6] = ACTIONS(4314),
    [aux_sym_zero_directive_token7] = ACTIONS(4314),
    [aux_sym_zero_directive_token8] = ACTIONS(4314),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4314),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4314),
    [anon_sym_wire] = ACTIONS(4316),
    [anon_sym_tri] = ACTIONS(4316),
    [anon_sym_tri0] = ACTIONS(4316),
    [anon_sym_tri1] = ACTIONS(4316),
    [anon_sym_wand] = ACTIONS(4316),
    [anon_sym_triand] = ACTIONS(4316),
    [anon_sym_wor] = ACTIONS(4316),
    [anon_sym_trior] = ACTIONS(4316),
    [anon_sym_trireg] = ACTIONS(4316),
    [anon_sym_uwire] = ACTIONS(4316),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4314),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4314),
    [aux_sym_begin_keywords_token1] = ACTIONS(4314),
    [anon_sym_SEMI] = ACTIONS(4314),
    [anon_sym_endmodule] = ACTIONS(4316),
    [anon_sym_COLON] = ACTIONS(4318),
    [anon_sym_extern] = ACTIONS(4316),
    [anon_sym_module] = ACTIONS(4316),
    [anon_sym_macromodule] = ACTIONS(4316),
    [anon_sym_endinterface] = ACTIONS(4316),
    [anon_sym_interface] = ACTIONS(4316),
    [anon_sym_endprogram] = ACTIONS(4316),
    [anon_sym_program] = ACTIONS(4316),
    [anon_sym_checker] = ACTIONS(4316),
    [anon_sym_virtual] = ACTIONS(4316),
    [anon_sym_class] = ACTIONS(4316),
    [anon_sym_package] = ACTIONS(4316),
    [anon_sym_endpackage] = ACTIONS(4316),
    [anon_sym_timeunit] = ACTIONS(4316),
    [anon_sym_timeprecision] = ACTIONS(4316),
    [anon_sym_type] = ACTIONS(4316),
    [anon_sym_input] = ACTIONS(4316),
    [anon_sym_output] = ACTIONS(4316),
    [anon_sym_inout] = ACTIONS(4316),
    [anon_sym_ref] = ACTIONS(4316),
    [anon_sym_DOLLARfatal] = ACTIONS(4314),
    [anon_sym_DOLLARerror] = ACTIONS(4314),
    [anon_sym_DOLLARwarning] = ACTIONS(4314),
    [anon_sym_DOLLARinfo] = ACTIONS(4314),
    [anon_sym_default] = ACTIONS(4316),
    [anon_sym_clocking] = ACTIONS(4316),
    [anon_sym_defparam] = ACTIONS(4316),
    [anon_sym_bind] = ACTIONS(4316),
    [anon_sym_const] = ACTIONS(4316),
    [anon_sym_function] = ACTIONS(4316),
    [anon_sym_static] = ACTIONS(4316),
    [anon_sym_constraint] = ACTIONS(4316),
    [anon_sym_if] = ACTIONS(4316),
    [anon_sym_else] = ACTIONS(4316),
    [anon_sym_LBRACK] = ACTIONS(4314),
    [anon_sym_localparam] = ACTIONS(4316),
    [anon_sym_parameter] = ACTIONS(4316),
    [anon_sym_specparam] = ACTIONS(4316),
    [anon_sym_var] = ACTIONS(4316),
    [anon_sym_import] = ACTIONS(4316),
    [anon_sym_export] = ACTIONS(4316),
    [anon_sym_genvar] = ACTIONS(4316),
    [anon_sym_interconnect] = ACTIONS(4316),
    [anon_sym_typedef] = ACTIONS(4316),
    [anon_sym_enum] = ACTIONS(4316),
    [anon_sym_struct] = ACTIONS(4316),
    [anon_sym_union] = ACTIONS(4316),
    [anon_sym_nettype] = ACTIONS(4316),
    [anon_sym_automatic] = ACTIONS(4316),
    [anon_sym_string] = ACTIONS(4316),
    [anon_sym_chandle] = ACTIONS(4316),
    [anon_sym_event] = ACTIONS(4316),
    [anon_sym_byte] = ACTIONS(4316),
    [anon_sym_shortint] = ACTIONS(4316),
    [anon_sym_int] = ACTIONS(4316),
    [anon_sym_longint] = ACTIONS(4316),
    [anon_sym_integer] = ACTIONS(4316),
    [anon_sym_time] = ACTIONS(4316),
    [anon_sym_bit] = ACTIONS(4316),
    [anon_sym_logic] = ACTIONS(4316),
    [anon_sym_reg] = ACTIONS(4316),
    [anon_sym_shortreal] = ACTIONS(4316),
    [anon_sym_real] = ACTIONS(4316),
    [anon_sym_realtime] = ACTIONS(4316),
    [anon_sym_supply0] = ACTIONS(4316),
    [anon_sym_supply1] = ACTIONS(4316),
    [anon_sym_signed] = ACTIONS(4316),
    [anon_sym_unsigned] = ACTIONS(4316),
    [anon_sym_task] = ACTIONS(4316),
    [anon_sym_modport] = ACTIONS(4316),
    [anon_sym_assert] = ACTIONS(4316),
    [anon_sym_property] = ACTIONS(4316),
    [anon_sym_assume] = ACTIONS(4316),
    [anon_sym_cover] = ACTIONS(4316),
    [anon_sym_sequence] = ACTIONS(4316),
    [anon_sym_restrict] = ACTIONS(4316),
    [anon_sym_not] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4316),
    [anon_sym_and] = ACTIONS(4316),
    [anon_sym_case] = ACTIONS(4316),
    [anon_sym_always] = ACTIONS(4316),
    [anon_sym_covergroup] = ACTIONS(4316),
    [anon_sym_let] = ACTIONS(4316),
    [anon_sym_pulldown] = ACTIONS(4316),
    [anon_sym_pullup] = ACTIONS(4316),
    [anon_sym_cmos] = ACTIONS(4316),
    [anon_sym_rcmos] = ACTIONS(4316),
    [anon_sym_bufif0] = ACTIONS(4316),
    [anon_sym_bufif1] = ACTIONS(4316),
    [anon_sym_notif0] = ACTIONS(4316),
    [anon_sym_notif1] = ACTIONS(4316),
    [anon_sym_nmos] = ACTIONS(4316),
    [anon_sym_pmos] = ACTIONS(4316),
    [anon_sym_rnmos] = ACTIONS(4316),
    [anon_sym_rpmos] = ACTIONS(4316),
    [anon_sym_nand] = ACTIONS(4316),
    [anon_sym_nor] = ACTIONS(4316),
    [anon_sym_xor] = ACTIONS(4316),
    [anon_sym_xnor] = ACTIONS(4316),
    [anon_sym_buf] = ACTIONS(4316),
    [anon_sym_tranif0] = ACTIONS(4316),
    [anon_sym_tranif1] = ACTIONS(4316),
    [anon_sym_rtranif1] = ACTIONS(4316),
    [anon_sym_rtranif0] = ACTIONS(4316),
    [anon_sym_tran] = ACTIONS(4316),
    [anon_sym_rtran] = ACTIONS(4316),
    [anon_sym_generate] = ACTIONS(4316),
    [anon_sym_for] = ACTIONS(4316),
    [anon_sym_primitive] = ACTIONS(4316),
    [anon_sym_initial] = ACTIONS(4316),
    [anon_sym_assign] = ACTIONS(4316),
    [anon_sym_alias] = ACTIONS(4316),
    [anon_sym_always_comb] = ACTIONS(4316),
    [anon_sym_always_latch] = ACTIONS(4316),
    [anon_sym_always_ff] = ACTIONS(4316),
    [anon_sym_final] = ACTIONS(4316),
    [anon_sym_global] = ACTIONS(4316),
    [anon_sym_specify] = ACTIONS(4316),
    [anon_sym_LPAREN_STAR] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4314),
    [anon_sym_DOLLARunit] = ACTIONS(4314),
  },
  [679] = {
    [ts_builtin_sym_end] = ACTIONS(4320),
    [sym_simple_identifier] = ACTIONS(4322),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4320),
    [anon_sym_BQUOTE] = ACTIONS(4322),
    [aux_sym_id_directive_token1] = ACTIONS(4320),
    [aux_sym_id_directive_token2] = ACTIONS(4320),
    [aux_sym_id_directive_token3] = ACTIONS(4320),
    [aux_sym_id_directive_token4] = ACTIONS(4322),
    [aux_sym_zero_directive_token1] = ACTIONS(4320),
    [aux_sym_zero_directive_token2] = ACTIONS(4320),
    [aux_sym_zero_directive_token3] = ACTIONS(4320),
    [aux_sym_zero_directive_token4] = ACTIONS(4320),
    [aux_sym_zero_directive_token5] = ACTIONS(4320),
    [aux_sym_zero_directive_token6] = ACTIONS(4320),
    [aux_sym_zero_directive_token7] = ACTIONS(4320),
    [aux_sym_zero_directive_token8] = ACTIONS(4320),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4320),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4320),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_begin_keywords_token1] = ACTIONS(4320),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_endmodule] = ACTIONS(4322),
    [anon_sym_COLON] = ACTIONS(4324),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_module] = ACTIONS(4322),
    [anon_sym_macromodule] = ACTIONS(4322),
    [anon_sym_endinterface] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_endprogram] = ACTIONS(4322),
    [anon_sym_program] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_package] = ACTIONS(4322),
    [anon_sym_endpackage] = ACTIONS(4322),
    [anon_sym_timeunit] = ACTIONS(4322),
    [anon_sym_timeprecision] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_input] = ACTIONS(4322),
    [anon_sym_output] = ACTIONS(4322),
    [anon_sym_inout] = ACTIONS(4322),
    [anon_sym_ref] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_specparam] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_modport] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_primitive] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_specify] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [680] = {
    [ts_builtin_sym_end] = ACTIONS(4326),
    [sym_simple_identifier] = ACTIONS(4328),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4326),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4326),
    [anon_sym_BQUOTE] = ACTIONS(4328),
    [aux_sym_id_directive_token1] = ACTIONS(4326),
    [aux_sym_id_directive_token2] = ACTIONS(4326),
    [aux_sym_id_directive_token3] = ACTIONS(4326),
    [aux_sym_id_directive_token4] = ACTIONS(4328),
    [aux_sym_zero_directive_token1] = ACTIONS(4326),
    [aux_sym_zero_directive_token2] = ACTIONS(4326),
    [aux_sym_zero_directive_token3] = ACTIONS(4326),
    [aux_sym_zero_directive_token4] = ACTIONS(4326),
    [aux_sym_zero_directive_token5] = ACTIONS(4326),
    [aux_sym_zero_directive_token6] = ACTIONS(4326),
    [aux_sym_zero_directive_token7] = ACTIONS(4326),
    [aux_sym_zero_directive_token8] = ACTIONS(4326),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4326),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4326),
    [anon_sym_wire] = ACTIONS(4328),
    [anon_sym_tri] = ACTIONS(4328),
    [anon_sym_tri0] = ACTIONS(4328),
    [anon_sym_tri1] = ACTIONS(4328),
    [anon_sym_wand] = ACTIONS(4328),
    [anon_sym_triand] = ACTIONS(4328),
    [anon_sym_wor] = ACTIONS(4328),
    [anon_sym_trior] = ACTIONS(4328),
    [anon_sym_trireg] = ACTIONS(4328),
    [anon_sym_uwire] = ACTIONS(4328),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4326),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4326),
    [aux_sym_begin_keywords_token1] = ACTIONS(4326),
    [anon_sym_SEMI] = ACTIONS(4326),
    [anon_sym_endmodule] = ACTIONS(4328),
    [anon_sym_COLON] = ACTIONS(4330),
    [anon_sym_extern] = ACTIONS(4328),
    [anon_sym_module] = ACTIONS(4328),
    [anon_sym_macromodule] = ACTIONS(4328),
    [anon_sym_endinterface] = ACTIONS(4328),
    [anon_sym_interface] = ACTIONS(4328),
    [anon_sym_endprogram] = ACTIONS(4328),
    [anon_sym_program] = ACTIONS(4328),
    [anon_sym_checker] = ACTIONS(4328),
    [anon_sym_virtual] = ACTIONS(4328),
    [anon_sym_class] = ACTIONS(4328),
    [anon_sym_package] = ACTIONS(4328),
    [anon_sym_endpackage] = ACTIONS(4328),
    [anon_sym_timeunit] = ACTIONS(4328),
    [anon_sym_timeprecision] = ACTIONS(4328),
    [anon_sym_type] = ACTIONS(4328),
    [anon_sym_input] = ACTIONS(4328),
    [anon_sym_output] = ACTIONS(4328),
    [anon_sym_inout] = ACTIONS(4328),
    [anon_sym_ref] = ACTIONS(4328),
    [anon_sym_DOLLARfatal] = ACTIONS(4326),
    [anon_sym_DOLLARerror] = ACTIONS(4326),
    [anon_sym_DOLLARwarning] = ACTIONS(4326),
    [anon_sym_DOLLARinfo] = ACTIONS(4326),
    [anon_sym_default] = ACTIONS(4328),
    [anon_sym_clocking] = ACTIONS(4328),
    [anon_sym_defparam] = ACTIONS(4328),
    [anon_sym_bind] = ACTIONS(4328),
    [anon_sym_const] = ACTIONS(4328),
    [anon_sym_function] = ACTIONS(4328),
    [anon_sym_static] = ACTIONS(4328),
    [anon_sym_constraint] = ACTIONS(4328),
    [anon_sym_if] = ACTIONS(4328),
    [anon_sym_else] = ACTIONS(4328),
    [anon_sym_LBRACK] = ACTIONS(4326),
    [anon_sym_localparam] = ACTIONS(4328),
    [anon_sym_parameter] = ACTIONS(4328),
    [anon_sym_specparam] = ACTIONS(4328),
    [anon_sym_var] = ACTIONS(4328),
    [anon_sym_import] = ACTIONS(4328),
    [anon_sym_export] = ACTIONS(4328),
    [anon_sym_genvar] = ACTIONS(4328),
    [anon_sym_interconnect] = ACTIONS(4328),
    [anon_sym_typedef] = ACTIONS(4328),
    [anon_sym_enum] = ACTIONS(4328),
    [anon_sym_struct] = ACTIONS(4328),
    [anon_sym_union] = ACTIONS(4328),
    [anon_sym_nettype] = ACTIONS(4328),
    [anon_sym_automatic] = ACTIONS(4328),
    [anon_sym_string] = ACTIONS(4328),
    [anon_sym_chandle] = ACTIONS(4328),
    [anon_sym_event] = ACTIONS(4328),
    [anon_sym_byte] = ACTIONS(4328),
    [anon_sym_shortint] = ACTIONS(4328),
    [anon_sym_int] = ACTIONS(4328),
    [anon_sym_longint] = ACTIONS(4328),
    [anon_sym_integer] = ACTIONS(4328),
    [anon_sym_time] = ACTIONS(4328),
    [anon_sym_bit] = ACTIONS(4328),
    [anon_sym_logic] = ACTIONS(4328),
    [anon_sym_reg] = ACTIONS(4328),
    [anon_sym_shortreal] = ACTIONS(4328),
    [anon_sym_real] = ACTIONS(4328),
    [anon_sym_realtime] = ACTIONS(4328),
    [anon_sym_supply0] = ACTIONS(4328),
    [anon_sym_supply1] = ACTIONS(4328),
    [anon_sym_signed] = ACTIONS(4328),
    [anon_sym_unsigned] = ACTIONS(4328),
    [anon_sym_task] = ACTIONS(4328),
    [anon_sym_modport] = ACTIONS(4328),
    [anon_sym_assert] = ACTIONS(4328),
    [anon_sym_property] = ACTIONS(4328),
    [anon_sym_assume] = ACTIONS(4328),
    [anon_sym_cover] = ACTIONS(4328),
    [anon_sym_sequence] = ACTIONS(4328),
    [anon_sym_restrict] = ACTIONS(4328),
    [anon_sym_not] = ACTIONS(4328),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_and] = ACTIONS(4328),
    [anon_sym_case] = ACTIONS(4328),
    [anon_sym_always] = ACTIONS(4328),
    [anon_sym_covergroup] = ACTIONS(4328),
    [anon_sym_let] = ACTIONS(4328),
    [anon_sym_pulldown] = ACTIONS(4328),
    [anon_sym_pullup] = ACTIONS(4328),
    [anon_sym_cmos] = ACTIONS(4328),
    [anon_sym_rcmos] = ACTIONS(4328),
    [anon_sym_bufif0] = ACTIONS(4328),
    [anon_sym_bufif1] = ACTIONS(4328),
    [anon_sym_notif0] = ACTIONS(4328),
    [anon_sym_notif1] = ACTIONS(4328),
    [anon_sym_nmos] = ACTIONS(4328),
    [anon_sym_pmos] = ACTIONS(4328),
    [anon_sym_rnmos] = ACTIONS(4328),
    [anon_sym_rpmos] = ACTIONS(4328),
    [anon_sym_nand] = ACTIONS(4328),
    [anon_sym_nor] = ACTIONS(4328),
    [anon_sym_xor] = ACTIONS(4328),
    [anon_sym_xnor] = ACTIONS(4328),
    [anon_sym_buf] = ACTIONS(4328),
    [anon_sym_tranif0] = ACTIONS(4328),
    [anon_sym_tranif1] = ACTIONS(4328),
    [anon_sym_rtranif1] = ACTIONS(4328),
    [anon_sym_rtranif0] = ACTIONS(4328),
    [anon_sym_tran] = ACTIONS(4328),
    [anon_sym_rtran] = ACTIONS(4328),
    [anon_sym_generate] = ACTIONS(4328),
    [anon_sym_for] = ACTIONS(4328),
    [anon_sym_primitive] = ACTIONS(4328),
    [anon_sym_initial] = ACTIONS(4328),
    [anon_sym_assign] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4328),
    [anon_sym_always_comb] = ACTIONS(4328),
    [anon_sym_always_latch] = ACTIONS(4328),
    [anon_sym_always_ff] = ACTIONS(4328),
    [anon_sym_final] = ACTIONS(4328),
    [anon_sym_global] = ACTIONS(4328),
    [anon_sym_specify] = ACTIONS(4328),
    [anon_sym_LPAREN_STAR] = ACTIONS(4326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4326),
    [anon_sym_DOLLARunit] = ACTIONS(4326),
  },
  [681] = {
    [ts_builtin_sym_end] = ACTIONS(4332),
    [sym_simple_identifier] = ACTIONS(4334),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4332),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4332),
    [anon_sym_BQUOTE] = ACTIONS(4334),
    [aux_sym_id_directive_token1] = ACTIONS(4332),
    [aux_sym_id_directive_token2] = ACTIONS(4332),
    [aux_sym_id_directive_token3] = ACTIONS(4332),
    [aux_sym_id_directive_token4] = ACTIONS(4334),
    [aux_sym_zero_directive_token1] = ACTIONS(4332),
    [aux_sym_zero_directive_token2] = ACTIONS(4332),
    [aux_sym_zero_directive_token3] = ACTIONS(4332),
    [aux_sym_zero_directive_token4] = ACTIONS(4332),
    [aux_sym_zero_directive_token5] = ACTIONS(4332),
    [aux_sym_zero_directive_token6] = ACTIONS(4332),
    [aux_sym_zero_directive_token7] = ACTIONS(4332),
    [aux_sym_zero_directive_token8] = ACTIONS(4332),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4332),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4332),
    [anon_sym_wire] = ACTIONS(4334),
    [anon_sym_tri] = ACTIONS(4334),
    [anon_sym_tri0] = ACTIONS(4334),
    [anon_sym_tri1] = ACTIONS(4334),
    [anon_sym_wand] = ACTIONS(4334),
    [anon_sym_triand] = ACTIONS(4334),
    [anon_sym_wor] = ACTIONS(4334),
    [anon_sym_trior] = ACTIONS(4334),
    [anon_sym_trireg] = ACTIONS(4334),
    [anon_sym_uwire] = ACTIONS(4334),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4332),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4332),
    [aux_sym_begin_keywords_token1] = ACTIONS(4332),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym_endmodule] = ACTIONS(4334),
    [anon_sym_COLON] = ACTIONS(4336),
    [anon_sym_extern] = ACTIONS(4334),
    [anon_sym_module] = ACTIONS(4334),
    [anon_sym_macromodule] = ACTIONS(4334),
    [anon_sym_endinterface] = ACTIONS(4334),
    [anon_sym_interface] = ACTIONS(4334),
    [anon_sym_endprogram] = ACTIONS(4334),
    [anon_sym_program] = ACTIONS(4334),
    [anon_sym_checker] = ACTIONS(4334),
    [anon_sym_virtual] = ACTIONS(4334),
    [anon_sym_class] = ACTIONS(4334),
    [anon_sym_package] = ACTIONS(4334),
    [anon_sym_endpackage] = ACTIONS(4334),
    [anon_sym_timeunit] = ACTIONS(4334),
    [anon_sym_timeprecision] = ACTIONS(4334),
    [anon_sym_type] = ACTIONS(4334),
    [anon_sym_input] = ACTIONS(4334),
    [anon_sym_output] = ACTIONS(4334),
    [anon_sym_inout] = ACTIONS(4334),
    [anon_sym_ref] = ACTIONS(4334),
    [anon_sym_DOLLARfatal] = ACTIONS(4332),
    [anon_sym_DOLLARerror] = ACTIONS(4332),
    [anon_sym_DOLLARwarning] = ACTIONS(4332),
    [anon_sym_DOLLARinfo] = ACTIONS(4332),
    [anon_sym_default] = ACTIONS(4334),
    [anon_sym_clocking] = ACTIONS(4334),
    [anon_sym_defparam] = ACTIONS(4334),
    [anon_sym_bind] = ACTIONS(4334),
    [anon_sym_const] = ACTIONS(4334),
    [anon_sym_function] = ACTIONS(4334),
    [anon_sym_static] = ACTIONS(4334),
    [anon_sym_constraint] = ACTIONS(4334),
    [anon_sym_if] = ACTIONS(4334),
    [anon_sym_else] = ACTIONS(4334),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_localparam] = ACTIONS(4334),
    [anon_sym_parameter] = ACTIONS(4334),
    [anon_sym_specparam] = ACTIONS(4334),
    [anon_sym_var] = ACTIONS(4334),
    [anon_sym_import] = ACTIONS(4334),
    [anon_sym_export] = ACTIONS(4334),
    [anon_sym_genvar] = ACTIONS(4334),
    [anon_sym_interconnect] = ACTIONS(4334),
    [anon_sym_typedef] = ACTIONS(4334),
    [anon_sym_enum] = ACTIONS(4334),
    [anon_sym_struct] = ACTIONS(4334),
    [anon_sym_union] = ACTIONS(4334),
    [anon_sym_nettype] = ACTIONS(4334),
    [anon_sym_automatic] = ACTIONS(4334),
    [anon_sym_string] = ACTIONS(4334),
    [anon_sym_chandle] = ACTIONS(4334),
    [anon_sym_event] = ACTIONS(4334),
    [anon_sym_byte] = ACTIONS(4334),
    [anon_sym_shortint] = ACTIONS(4334),
    [anon_sym_int] = ACTIONS(4334),
    [anon_sym_longint] = ACTIONS(4334),
    [anon_sym_integer] = ACTIONS(4334),
    [anon_sym_time] = ACTIONS(4334),
    [anon_sym_bit] = ACTIONS(4334),
    [anon_sym_logic] = ACTIONS(4334),
    [anon_sym_reg] = ACTIONS(4334),
    [anon_sym_shortreal] = ACTIONS(4334),
    [anon_sym_real] = ACTIONS(4334),
    [anon_sym_realtime] = ACTIONS(4334),
    [anon_sym_supply0] = ACTIONS(4334),
    [anon_sym_supply1] = ACTIONS(4334),
    [anon_sym_signed] = ACTIONS(4334),
    [anon_sym_unsigned] = ACTIONS(4334),
    [anon_sym_task] = ACTIONS(4334),
    [anon_sym_modport] = ACTIONS(4334),
    [anon_sym_assert] = ACTIONS(4334),
    [anon_sym_property] = ACTIONS(4334),
    [anon_sym_assume] = ACTIONS(4334),
    [anon_sym_cover] = ACTIONS(4334),
    [anon_sym_sequence] = ACTIONS(4334),
    [anon_sym_restrict] = ACTIONS(4334),
    [anon_sym_not] = ACTIONS(4334),
    [anon_sym_or] = ACTIONS(4334),
    [anon_sym_and] = ACTIONS(4334),
    [anon_sym_case] = ACTIONS(4334),
    [anon_sym_always] = ACTIONS(4334),
    [anon_sym_covergroup] = ACTIONS(4334),
    [anon_sym_let] = ACTIONS(4334),
    [anon_sym_pulldown] = ACTIONS(4334),
    [anon_sym_pullup] = ACTIONS(4334),
    [anon_sym_cmos] = ACTIONS(4334),
    [anon_sym_rcmos] = ACTIONS(4334),
    [anon_sym_bufif0] = ACTIONS(4334),
    [anon_sym_bufif1] = ACTIONS(4334),
    [anon_sym_notif0] = ACTIONS(4334),
    [anon_sym_notif1] = ACTIONS(4334),
    [anon_sym_nmos] = ACTIONS(4334),
    [anon_sym_pmos] = ACTIONS(4334),
    [anon_sym_rnmos] = ACTIONS(4334),
    [anon_sym_rpmos] = ACTIONS(4334),
    [anon_sym_nand] = ACTIONS(4334),
    [anon_sym_nor] = ACTIONS(4334),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_xnor] = ACTIONS(4334),
    [anon_sym_buf] = ACTIONS(4334),
    [anon_sym_tranif0] = ACTIONS(4334),
    [anon_sym_tranif1] = ACTIONS(4334),
    [anon_sym_rtranif1] = ACTIONS(4334),
    [anon_sym_rtranif0] = ACTIONS(4334),
    [anon_sym_tran] = ACTIONS(4334),
    [anon_sym_rtran] = ACTIONS(4334),
    [anon_sym_generate] = ACTIONS(4334),
    [anon_sym_for] = ACTIONS(4334),
    [anon_sym_primitive] = ACTIONS(4334),
    [anon_sym_initial] = ACTIONS(4334),
    [anon_sym_assign] = ACTIONS(4334),
    [anon_sym_alias] = ACTIONS(4334),
    [anon_sym_always_comb] = ACTIONS(4334),
    [anon_sym_always_latch] = ACTIONS(4334),
    [anon_sym_always_ff] = ACTIONS(4334),
    [anon_sym_final] = ACTIONS(4334),
    [anon_sym_global] = ACTIONS(4334),
    [anon_sym_specify] = ACTIONS(4334),
    [anon_sym_LPAREN_STAR] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4332),
    [anon_sym_DOLLARunit] = ACTIONS(4332),
  },
  [682] = {
    [ts_builtin_sym_end] = ACTIONS(4338),
    [sym_simple_identifier] = ACTIONS(4340),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4338),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4338),
    [anon_sym_BQUOTE] = ACTIONS(4340),
    [aux_sym_id_directive_token1] = ACTIONS(4338),
    [aux_sym_id_directive_token2] = ACTIONS(4338),
    [aux_sym_id_directive_token3] = ACTIONS(4338),
    [aux_sym_id_directive_token4] = ACTIONS(4340),
    [aux_sym_zero_directive_token1] = ACTIONS(4338),
    [aux_sym_zero_directive_token2] = ACTIONS(4338),
    [aux_sym_zero_directive_token3] = ACTIONS(4338),
    [aux_sym_zero_directive_token4] = ACTIONS(4338),
    [aux_sym_zero_directive_token5] = ACTIONS(4338),
    [aux_sym_zero_directive_token6] = ACTIONS(4338),
    [aux_sym_zero_directive_token7] = ACTIONS(4338),
    [aux_sym_zero_directive_token8] = ACTIONS(4338),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4338),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4338),
    [anon_sym_wire] = ACTIONS(4340),
    [anon_sym_tri] = ACTIONS(4340),
    [anon_sym_tri0] = ACTIONS(4340),
    [anon_sym_tri1] = ACTIONS(4340),
    [anon_sym_wand] = ACTIONS(4340),
    [anon_sym_triand] = ACTIONS(4340),
    [anon_sym_wor] = ACTIONS(4340),
    [anon_sym_trior] = ACTIONS(4340),
    [anon_sym_trireg] = ACTIONS(4340),
    [anon_sym_uwire] = ACTIONS(4340),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4338),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4338),
    [aux_sym_begin_keywords_token1] = ACTIONS(4338),
    [anon_sym_SEMI] = ACTIONS(4338),
    [anon_sym_endmodule] = ACTIONS(4340),
    [anon_sym_COLON] = ACTIONS(4342),
    [anon_sym_extern] = ACTIONS(4340),
    [anon_sym_module] = ACTIONS(4340),
    [anon_sym_macromodule] = ACTIONS(4340),
    [anon_sym_endinterface] = ACTIONS(4340),
    [anon_sym_interface] = ACTIONS(4340),
    [anon_sym_endprogram] = ACTIONS(4340),
    [anon_sym_program] = ACTIONS(4340),
    [anon_sym_checker] = ACTIONS(4340),
    [anon_sym_virtual] = ACTIONS(4340),
    [anon_sym_class] = ACTIONS(4340),
    [anon_sym_package] = ACTIONS(4340),
    [anon_sym_endpackage] = ACTIONS(4340),
    [anon_sym_timeunit] = ACTIONS(4340),
    [anon_sym_timeprecision] = ACTIONS(4340),
    [anon_sym_type] = ACTIONS(4340),
    [anon_sym_input] = ACTIONS(4340),
    [anon_sym_output] = ACTIONS(4340),
    [anon_sym_inout] = ACTIONS(4340),
    [anon_sym_ref] = ACTIONS(4340),
    [anon_sym_DOLLARfatal] = ACTIONS(4338),
    [anon_sym_DOLLARerror] = ACTIONS(4338),
    [anon_sym_DOLLARwarning] = ACTIONS(4338),
    [anon_sym_DOLLARinfo] = ACTIONS(4338),
    [anon_sym_default] = ACTIONS(4340),
    [anon_sym_clocking] = ACTIONS(4340),
    [anon_sym_defparam] = ACTIONS(4340),
    [anon_sym_bind] = ACTIONS(4340),
    [anon_sym_const] = ACTIONS(4340),
    [anon_sym_function] = ACTIONS(4340),
    [anon_sym_static] = ACTIONS(4340),
    [anon_sym_constraint] = ACTIONS(4340),
    [anon_sym_if] = ACTIONS(4340),
    [anon_sym_else] = ACTIONS(4340),
    [anon_sym_LBRACK] = ACTIONS(4338),
    [anon_sym_localparam] = ACTIONS(4340),
    [anon_sym_parameter] = ACTIONS(4340),
    [anon_sym_specparam] = ACTIONS(4340),
    [anon_sym_var] = ACTIONS(4340),
    [anon_sym_import] = ACTIONS(4340),
    [anon_sym_export] = ACTIONS(4340),
    [anon_sym_genvar] = ACTIONS(4340),
    [anon_sym_interconnect] = ACTIONS(4340),
    [anon_sym_typedef] = ACTIONS(4340),
    [anon_sym_enum] = ACTIONS(4340),
    [anon_sym_struct] = ACTIONS(4340),
    [anon_sym_union] = ACTIONS(4340),
    [anon_sym_nettype] = ACTIONS(4340),
    [anon_sym_automatic] = ACTIONS(4340),
    [anon_sym_string] = ACTIONS(4340),
    [anon_sym_chandle] = ACTIONS(4340),
    [anon_sym_event] = ACTIONS(4340),
    [anon_sym_byte] = ACTIONS(4340),
    [anon_sym_shortint] = ACTIONS(4340),
    [anon_sym_int] = ACTIONS(4340),
    [anon_sym_longint] = ACTIONS(4340),
    [anon_sym_integer] = ACTIONS(4340),
    [anon_sym_time] = ACTIONS(4340),
    [anon_sym_bit] = ACTIONS(4340),
    [anon_sym_logic] = ACTIONS(4340),
    [anon_sym_reg] = ACTIONS(4340),
    [anon_sym_shortreal] = ACTIONS(4340),
    [anon_sym_real] = ACTIONS(4340),
    [anon_sym_realtime] = ACTIONS(4340),
    [anon_sym_supply0] = ACTIONS(4340),
    [anon_sym_supply1] = ACTIONS(4340),
    [anon_sym_signed] = ACTIONS(4340),
    [anon_sym_unsigned] = ACTIONS(4340),
    [anon_sym_task] = ACTIONS(4340),
    [anon_sym_modport] = ACTIONS(4340),
    [anon_sym_assert] = ACTIONS(4340),
    [anon_sym_property] = ACTIONS(4340),
    [anon_sym_assume] = ACTIONS(4340),
    [anon_sym_cover] = ACTIONS(4340),
    [anon_sym_sequence] = ACTIONS(4340),
    [anon_sym_restrict] = ACTIONS(4340),
    [anon_sym_not] = ACTIONS(4340),
    [anon_sym_or] = ACTIONS(4340),
    [anon_sym_and] = ACTIONS(4340),
    [anon_sym_case] = ACTIONS(4340),
    [anon_sym_always] = ACTIONS(4340),
    [anon_sym_covergroup] = ACTIONS(4340),
    [anon_sym_let] = ACTIONS(4340),
    [anon_sym_pulldown] = ACTIONS(4340),
    [anon_sym_pullup] = ACTIONS(4340),
    [anon_sym_cmos] = ACTIONS(4340),
    [anon_sym_rcmos] = ACTIONS(4340),
    [anon_sym_bufif0] = ACTIONS(4340),
    [anon_sym_bufif1] = ACTIONS(4340),
    [anon_sym_notif0] = ACTIONS(4340),
    [anon_sym_notif1] = ACTIONS(4340),
    [anon_sym_nmos] = ACTIONS(4340),
    [anon_sym_pmos] = ACTIONS(4340),
    [anon_sym_rnmos] = ACTIONS(4340),
    [anon_sym_rpmos] = ACTIONS(4340),
    [anon_sym_nand] = ACTIONS(4340),
    [anon_sym_nor] = ACTIONS(4340),
    [anon_sym_xor] = ACTIONS(4340),
    [anon_sym_xnor] = ACTIONS(4340),
    [anon_sym_buf] = ACTIONS(4340),
    [anon_sym_tranif0] = ACTIONS(4340),
    [anon_sym_tranif1] = ACTIONS(4340),
    [anon_sym_rtranif1] = ACTIONS(4340),
    [anon_sym_rtranif0] = ACTIONS(4340),
    [anon_sym_tran] = ACTIONS(4340),
    [anon_sym_rtran] = ACTIONS(4340),
    [anon_sym_generate] = ACTIONS(4340),
    [anon_sym_for] = ACTIONS(4340),
    [anon_sym_primitive] = ACTIONS(4340),
    [anon_sym_initial] = ACTIONS(4340),
    [anon_sym_assign] = ACTIONS(4340),
    [anon_sym_alias] = ACTIONS(4340),
    [anon_sym_always_comb] = ACTIONS(4340),
    [anon_sym_always_latch] = ACTIONS(4340),
    [anon_sym_always_ff] = ACTIONS(4340),
    [anon_sym_final] = ACTIONS(4340),
    [anon_sym_global] = ACTIONS(4340),
    [anon_sym_specify] = ACTIONS(4340),
    [anon_sym_LPAREN_STAR] = ACTIONS(4338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4338),
    [anon_sym_DOLLARunit] = ACTIONS(4338),
  },
  [683] = {
    [ts_builtin_sym_end] = ACTIONS(4344),
    [sym_simple_identifier] = ACTIONS(4346),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4344),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4344),
    [anon_sym_BQUOTE] = ACTIONS(4346),
    [aux_sym_id_directive_token1] = ACTIONS(4344),
    [aux_sym_id_directive_token2] = ACTIONS(4344),
    [aux_sym_id_directive_token3] = ACTIONS(4344),
    [aux_sym_id_directive_token4] = ACTIONS(4346),
    [aux_sym_zero_directive_token1] = ACTIONS(4344),
    [aux_sym_zero_directive_token2] = ACTIONS(4344),
    [aux_sym_zero_directive_token3] = ACTIONS(4344),
    [aux_sym_zero_directive_token4] = ACTIONS(4344),
    [aux_sym_zero_directive_token5] = ACTIONS(4344),
    [aux_sym_zero_directive_token6] = ACTIONS(4344),
    [aux_sym_zero_directive_token7] = ACTIONS(4344),
    [aux_sym_zero_directive_token8] = ACTIONS(4344),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4344),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4344),
    [anon_sym_wire] = ACTIONS(4346),
    [anon_sym_tri] = ACTIONS(4346),
    [anon_sym_tri0] = ACTIONS(4346),
    [anon_sym_tri1] = ACTIONS(4346),
    [anon_sym_wand] = ACTIONS(4346),
    [anon_sym_triand] = ACTIONS(4346),
    [anon_sym_wor] = ACTIONS(4346),
    [anon_sym_trior] = ACTIONS(4346),
    [anon_sym_trireg] = ACTIONS(4346),
    [anon_sym_uwire] = ACTIONS(4346),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4344),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4344),
    [aux_sym_begin_keywords_token1] = ACTIONS(4344),
    [anon_sym_SEMI] = ACTIONS(4344),
    [anon_sym_endmodule] = ACTIONS(4346),
    [anon_sym_COLON] = ACTIONS(4348),
    [anon_sym_extern] = ACTIONS(4346),
    [anon_sym_module] = ACTIONS(4346),
    [anon_sym_macromodule] = ACTIONS(4346),
    [anon_sym_endinterface] = ACTIONS(4346),
    [anon_sym_interface] = ACTIONS(4346),
    [anon_sym_endprogram] = ACTIONS(4346),
    [anon_sym_program] = ACTIONS(4346),
    [anon_sym_checker] = ACTIONS(4346),
    [anon_sym_virtual] = ACTIONS(4346),
    [anon_sym_class] = ACTIONS(4346),
    [anon_sym_package] = ACTIONS(4346),
    [anon_sym_endpackage] = ACTIONS(4346),
    [anon_sym_timeunit] = ACTIONS(4346),
    [anon_sym_timeprecision] = ACTIONS(4346),
    [anon_sym_type] = ACTIONS(4346),
    [anon_sym_input] = ACTIONS(4346),
    [anon_sym_output] = ACTIONS(4346),
    [anon_sym_inout] = ACTIONS(4346),
    [anon_sym_ref] = ACTIONS(4346),
    [anon_sym_DOLLARfatal] = ACTIONS(4344),
    [anon_sym_DOLLARerror] = ACTIONS(4344),
    [anon_sym_DOLLARwarning] = ACTIONS(4344),
    [anon_sym_DOLLARinfo] = ACTIONS(4344),
    [anon_sym_default] = ACTIONS(4346),
    [anon_sym_clocking] = ACTIONS(4346),
    [anon_sym_defparam] = ACTIONS(4346),
    [anon_sym_bind] = ACTIONS(4346),
    [anon_sym_const] = ACTIONS(4346),
    [anon_sym_function] = ACTIONS(4346),
    [anon_sym_static] = ACTIONS(4346),
    [anon_sym_constraint] = ACTIONS(4346),
    [anon_sym_if] = ACTIONS(4346),
    [anon_sym_else] = ACTIONS(4346),
    [anon_sym_LBRACK] = ACTIONS(4344),
    [anon_sym_localparam] = ACTIONS(4346),
    [anon_sym_parameter] = ACTIONS(4346),
    [anon_sym_specparam] = ACTIONS(4346),
    [anon_sym_var] = ACTIONS(4346),
    [anon_sym_import] = ACTIONS(4346),
    [anon_sym_export] = ACTIONS(4346),
    [anon_sym_genvar] = ACTIONS(4346),
    [anon_sym_interconnect] = ACTIONS(4346),
    [anon_sym_typedef] = ACTIONS(4346),
    [anon_sym_enum] = ACTIONS(4346),
    [anon_sym_struct] = ACTIONS(4346),
    [anon_sym_union] = ACTIONS(4346),
    [anon_sym_nettype] = ACTIONS(4346),
    [anon_sym_automatic] = ACTIONS(4346),
    [anon_sym_string] = ACTIONS(4346),
    [anon_sym_chandle] = ACTIONS(4346),
    [anon_sym_event] = ACTIONS(4346),
    [anon_sym_byte] = ACTIONS(4346),
    [anon_sym_shortint] = ACTIONS(4346),
    [anon_sym_int] = ACTIONS(4346),
    [anon_sym_longint] = ACTIONS(4346),
    [anon_sym_integer] = ACTIONS(4346),
    [anon_sym_time] = ACTIONS(4346),
    [anon_sym_bit] = ACTIONS(4346),
    [anon_sym_logic] = ACTIONS(4346),
    [anon_sym_reg] = ACTIONS(4346),
    [anon_sym_shortreal] = ACTIONS(4346),
    [anon_sym_real] = ACTIONS(4346),
    [anon_sym_realtime] = ACTIONS(4346),
    [anon_sym_supply0] = ACTIONS(4346),
    [anon_sym_supply1] = ACTIONS(4346),
    [anon_sym_signed] = ACTIONS(4346),
    [anon_sym_unsigned] = ACTIONS(4346),
    [anon_sym_task] = ACTIONS(4346),
    [anon_sym_modport] = ACTIONS(4346),
    [anon_sym_assert] = ACTIONS(4346),
    [anon_sym_property] = ACTIONS(4346),
    [anon_sym_assume] = ACTIONS(4346),
    [anon_sym_cover] = ACTIONS(4346),
    [anon_sym_sequence] = ACTIONS(4346),
    [anon_sym_restrict] = ACTIONS(4346),
    [anon_sym_not] = ACTIONS(4346),
    [anon_sym_or] = ACTIONS(4346),
    [anon_sym_and] = ACTIONS(4346),
    [anon_sym_case] = ACTIONS(4346),
    [anon_sym_always] = ACTIONS(4346),
    [anon_sym_covergroup] = ACTIONS(4346),
    [anon_sym_let] = ACTIONS(4346),
    [anon_sym_pulldown] = ACTIONS(4346),
    [anon_sym_pullup] = ACTIONS(4346),
    [anon_sym_cmos] = ACTIONS(4346),
    [anon_sym_rcmos] = ACTIONS(4346),
    [anon_sym_bufif0] = ACTIONS(4346),
    [anon_sym_bufif1] = ACTIONS(4346),
    [anon_sym_notif0] = ACTIONS(4346),
    [anon_sym_notif1] = ACTIONS(4346),
    [anon_sym_nmos] = ACTIONS(4346),
    [anon_sym_pmos] = ACTIONS(4346),
    [anon_sym_rnmos] = ACTIONS(4346),
    [anon_sym_rpmos] = ACTIONS(4346),
    [anon_sym_nand] = ACTIONS(4346),
    [anon_sym_nor] = ACTIONS(4346),
    [anon_sym_xor] = ACTIONS(4346),
    [anon_sym_xnor] = ACTIONS(4346),
    [anon_sym_buf] = ACTIONS(4346),
    [anon_sym_tranif0] = ACTIONS(4346),
    [anon_sym_tranif1] = ACTIONS(4346),
    [anon_sym_rtranif1] = ACTIONS(4346),
    [anon_sym_rtranif0] = ACTIONS(4346),
    [anon_sym_tran] = ACTIONS(4346),
    [anon_sym_rtran] = ACTIONS(4346),
    [anon_sym_generate] = ACTIONS(4346),
    [anon_sym_for] = ACTIONS(4346),
    [anon_sym_primitive] = ACTIONS(4346),
    [anon_sym_initial] = ACTIONS(4346),
    [anon_sym_assign] = ACTIONS(4346),
    [anon_sym_alias] = ACTIONS(4346),
    [anon_sym_always_comb] = ACTIONS(4346),
    [anon_sym_always_latch] = ACTIONS(4346),
    [anon_sym_always_ff] = ACTIONS(4346),
    [anon_sym_final] = ACTIONS(4346),
    [anon_sym_global] = ACTIONS(4346),
    [anon_sym_specify] = ACTIONS(4346),
    [anon_sym_LPAREN_STAR] = ACTIONS(4344),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4344),
    [anon_sym_DOLLARunit] = ACTIONS(4344),
  },
  [684] = {
    [ts_builtin_sym_end] = ACTIONS(4350),
    [sym_simple_identifier] = ACTIONS(4352),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4350),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4350),
    [anon_sym_BQUOTE] = ACTIONS(4352),
    [aux_sym_id_directive_token1] = ACTIONS(4350),
    [aux_sym_id_directive_token2] = ACTIONS(4350),
    [aux_sym_id_directive_token3] = ACTIONS(4350),
    [aux_sym_id_directive_token4] = ACTIONS(4352),
    [aux_sym_zero_directive_token1] = ACTIONS(4350),
    [aux_sym_zero_directive_token2] = ACTIONS(4350),
    [aux_sym_zero_directive_token3] = ACTIONS(4350),
    [aux_sym_zero_directive_token4] = ACTIONS(4350),
    [aux_sym_zero_directive_token5] = ACTIONS(4350),
    [aux_sym_zero_directive_token6] = ACTIONS(4350),
    [aux_sym_zero_directive_token7] = ACTIONS(4350),
    [aux_sym_zero_directive_token8] = ACTIONS(4350),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4350),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4350),
    [anon_sym_wire] = ACTIONS(4352),
    [anon_sym_tri] = ACTIONS(4352),
    [anon_sym_tri0] = ACTIONS(4352),
    [anon_sym_tri1] = ACTIONS(4352),
    [anon_sym_wand] = ACTIONS(4352),
    [anon_sym_triand] = ACTIONS(4352),
    [anon_sym_wor] = ACTIONS(4352),
    [anon_sym_trior] = ACTIONS(4352),
    [anon_sym_trireg] = ACTIONS(4352),
    [anon_sym_uwire] = ACTIONS(4352),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4350),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4350),
    [aux_sym_begin_keywords_token1] = ACTIONS(4350),
    [anon_sym_SEMI] = ACTIONS(4350),
    [anon_sym_endmodule] = ACTIONS(4352),
    [anon_sym_COLON] = ACTIONS(4354),
    [anon_sym_extern] = ACTIONS(4352),
    [anon_sym_module] = ACTIONS(4352),
    [anon_sym_macromodule] = ACTIONS(4352),
    [anon_sym_endinterface] = ACTIONS(4352),
    [anon_sym_interface] = ACTIONS(4352),
    [anon_sym_endprogram] = ACTIONS(4352),
    [anon_sym_program] = ACTIONS(4352),
    [anon_sym_checker] = ACTIONS(4352),
    [anon_sym_virtual] = ACTIONS(4352),
    [anon_sym_class] = ACTIONS(4352),
    [anon_sym_package] = ACTIONS(4352),
    [anon_sym_endpackage] = ACTIONS(4352),
    [anon_sym_timeunit] = ACTIONS(4352),
    [anon_sym_timeprecision] = ACTIONS(4352),
    [anon_sym_type] = ACTIONS(4352),
    [anon_sym_input] = ACTIONS(4352),
    [anon_sym_output] = ACTIONS(4352),
    [anon_sym_inout] = ACTIONS(4352),
    [anon_sym_ref] = ACTIONS(4352),
    [anon_sym_DOLLARfatal] = ACTIONS(4350),
    [anon_sym_DOLLARerror] = ACTIONS(4350),
    [anon_sym_DOLLARwarning] = ACTIONS(4350),
    [anon_sym_DOLLARinfo] = ACTIONS(4350),
    [anon_sym_default] = ACTIONS(4352),
    [anon_sym_clocking] = ACTIONS(4352),
    [anon_sym_defparam] = ACTIONS(4352),
    [anon_sym_bind] = ACTIONS(4352),
    [anon_sym_const] = ACTIONS(4352),
    [anon_sym_function] = ACTIONS(4352),
    [anon_sym_static] = ACTIONS(4352),
    [anon_sym_constraint] = ACTIONS(4352),
    [anon_sym_if] = ACTIONS(4352),
    [anon_sym_else] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_localparam] = ACTIONS(4352),
    [anon_sym_parameter] = ACTIONS(4352),
    [anon_sym_specparam] = ACTIONS(4352),
    [anon_sym_var] = ACTIONS(4352),
    [anon_sym_import] = ACTIONS(4352),
    [anon_sym_export] = ACTIONS(4352),
    [anon_sym_genvar] = ACTIONS(4352),
    [anon_sym_interconnect] = ACTIONS(4352),
    [anon_sym_typedef] = ACTIONS(4352),
    [anon_sym_enum] = ACTIONS(4352),
    [anon_sym_struct] = ACTIONS(4352),
    [anon_sym_union] = ACTIONS(4352),
    [anon_sym_nettype] = ACTIONS(4352),
    [anon_sym_automatic] = ACTIONS(4352),
    [anon_sym_string] = ACTIONS(4352),
    [anon_sym_chandle] = ACTIONS(4352),
    [anon_sym_event] = ACTIONS(4352),
    [anon_sym_byte] = ACTIONS(4352),
    [anon_sym_shortint] = ACTIONS(4352),
    [anon_sym_int] = ACTIONS(4352),
    [anon_sym_longint] = ACTIONS(4352),
    [anon_sym_integer] = ACTIONS(4352),
    [anon_sym_time] = ACTIONS(4352),
    [anon_sym_bit] = ACTIONS(4352),
    [anon_sym_logic] = ACTIONS(4352),
    [anon_sym_reg] = ACTIONS(4352),
    [anon_sym_shortreal] = ACTIONS(4352),
    [anon_sym_real] = ACTIONS(4352),
    [anon_sym_realtime] = ACTIONS(4352),
    [anon_sym_supply0] = ACTIONS(4352),
    [anon_sym_supply1] = ACTIONS(4352),
    [anon_sym_signed] = ACTIONS(4352),
    [anon_sym_unsigned] = ACTIONS(4352),
    [anon_sym_task] = ACTIONS(4352),
    [anon_sym_modport] = ACTIONS(4352),
    [anon_sym_assert] = ACTIONS(4352),
    [anon_sym_property] = ACTIONS(4352),
    [anon_sym_assume] = ACTIONS(4352),
    [anon_sym_cover] = ACTIONS(4352),
    [anon_sym_sequence] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym_not] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4352),
    [anon_sym_and] = ACTIONS(4352),
    [anon_sym_case] = ACTIONS(4352),
    [anon_sym_always] = ACTIONS(4352),
    [anon_sym_covergroup] = ACTIONS(4352),
    [anon_sym_let] = ACTIONS(4352),
    [anon_sym_pulldown] = ACTIONS(4352),
    [anon_sym_pullup] = ACTIONS(4352),
    [anon_sym_cmos] = ACTIONS(4352),
    [anon_sym_rcmos] = ACTIONS(4352),
    [anon_sym_bufif0] = ACTIONS(4352),
    [anon_sym_bufif1] = ACTIONS(4352),
    [anon_sym_notif0] = ACTIONS(4352),
    [anon_sym_notif1] = ACTIONS(4352),
    [anon_sym_nmos] = ACTIONS(4352),
    [anon_sym_pmos] = ACTIONS(4352),
    [anon_sym_rnmos] = ACTIONS(4352),
    [anon_sym_rpmos] = ACTIONS(4352),
    [anon_sym_nand] = ACTIONS(4352),
    [anon_sym_nor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4352),
    [anon_sym_xnor] = ACTIONS(4352),
    [anon_sym_buf] = ACTIONS(4352),
    [anon_sym_tranif0] = ACTIONS(4352),
    [anon_sym_tranif1] = ACTIONS(4352),
    [anon_sym_rtranif1] = ACTIONS(4352),
    [anon_sym_rtranif0] = ACTIONS(4352),
    [anon_sym_tran] = ACTIONS(4352),
    [anon_sym_rtran] = ACTIONS(4352),
    [anon_sym_generate] = ACTIONS(4352),
    [anon_sym_for] = ACTIONS(4352),
    [anon_sym_primitive] = ACTIONS(4352),
    [anon_sym_initial] = ACTIONS(4352),
    [anon_sym_assign] = ACTIONS(4352),
    [anon_sym_alias] = ACTIONS(4352),
    [anon_sym_always_comb] = ACTIONS(4352),
    [anon_sym_always_latch] = ACTIONS(4352),
    [anon_sym_always_ff] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_global] = ACTIONS(4352),
    [anon_sym_specify] = ACTIONS(4352),
    [anon_sym_LPAREN_STAR] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4350),
    [anon_sym_DOLLARunit] = ACTIONS(4350),
  },
  [685] = {
    [ts_builtin_sym_end] = ACTIONS(4356),
    [sym_simple_identifier] = ACTIONS(4358),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4356),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4356),
    [anon_sym_BQUOTE] = ACTIONS(4358),
    [aux_sym_id_directive_token1] = ACTIONS(4356),
    [aux_sym_id_directive_token2] = ACTIONS(4356),
    [aux_sym_id_directive_token3] = ACTIONS(4356),
    [aux_sym_id_directive_token4] = ACTIONS(4358),
    [aux_sym_zero_directive_token1] = ACTIONS(4356),
    [aux_sym_zero_directive_token2] = ACTIONS(4356),
    [aux_sym_zero_directive_token3] = ACTIONS(4356),
    [aux_sym_zero_directive_token4] = ACTIONS(4356),
    [aux_sym_zero_directive_token5] = ACTIONS(4356),
    [aux_sym_zero_directive_token6] = ACTIONS(4356),
    [aux_sym_zero_directive_token7] = ACTIONS(4356),
    [aux_sym_zero_directive_token8] = ACTIONS(4356),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4356),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4356),
    [anon_sym_wire] = ACTIONS(4358),
    [anon_sym_tri] = ACTIONS(4358),
    [anon_sym_tri0] = ACTIONS(4358),
    [anon_sym_tri1] = ACTIONS(4358),
    [anon_sym_wand] = ACTIONS(4358),
    [anon_sym_triand] = ACTIONS(4358),
    [anon_sym_wor] = ACTIONS(4358),
    [anon_sym_trior] = ACTIONS(4358),
    [anon_sym_trireg] = ACTIONS(4358),
    [anon_sym_uwire] = ACTIONS(4358),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4356),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4356),
    [aux_sym_begin_keywords_token1] = ACTIONS(4356),
    [anon_sym_SEMI] = ACTIONS(4356),
    [anon_sym_endmodule] = ACTIONS(4358),
    [anon_sym_COLON] = ACTIONS(4360),
    [anon_sym_extern] = ACTIONS(4358),
    [anon_sym_module] = ACTIONS(4358),
    [anon_sym_macromodule] = ACTIONS(4358),
    [anon_sym_endinterface] = ACTIONS(4358),
    [anon_sym_interface] = ACTIONS(4358),
    [anon_sym_endprogram] = ACTIONS(4358),
    [anon_sym_program] = ACTIONS(4358),
    [anon_sym_checker] = ACTIONS(4358),
    [anon_sym_virtual] = ACTIONS(4358),
    [anon_sym_class] = ACTIONS(4358),
    [anon_sym_package] = ACTIONS(4358),
    [anon_sym_endpackage] = ACTIONS(4358),
    [anon_sym_timeunit] = ACTIONS(4358),
    [anon_sym_timeprecision] = ACTIONS(4358),
    [anon_sym_type] = ACTIONS(4358),
    [anon_sym_input] = ACTIONS(4358),
    [anon_sym_output] = ACTIONS(4358),
    [anon_sym_inout] = ACTIONS(4358),
    [anon_sym_ref] = ACTIONS(4358),
    [anon_sym_DOLLARfatal] = ACTIONS(4356),
    [anon_sym_DOLLARerror] = ACTIONS(4356),
    [anon_sym_DOLLARwarning] = ACTIONS(4356),
    [anon_sym_DOLLARinfo] = ACTIONS(4356),
    [anon_sym_default] = ACTIONS(4358),
    [anon_sym_clocking] = ACTIONS(4358),
    [anon_sym_defparam] = ACTIONS(4358),
    [anon_sym_bind] = ACTIONS(4358),
    [anon_sym_const] = ACTIONS(4358),
    [anon_sym_function] = ACTIONS(4358),
    [anon_sym_static] = ACTIONS(4358),
    [anon_sym_constraint] = ACTIONS(4358),
    [anon_sym_if] = ACTIONS(4358),
    [anon_sym_else] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_localparam] = ACTIONS(4358),
    [anon_sym_parameter] = ACTIONS(4358),
    [anon_sym_specparam] = ACTIONS(4358),
    [anon_sym_var] = ACTIONS(4358),
    [anon_sym_import] = ACTIONS(4358),
    [anon_sym_export] = ACTIONS(4358),
    [anon_sym_genvar] = ACTIONS(4358),
    [anon_sym_interconnect] = ACTIONS(4358),
    [anon_sym_typedef] = ACTIONS(4358),
    [anon_sym_enum] = ACTIONS(4358),
    [anon_sym_struct] = ACTIONS(4358),
    [anon_sym_union] = ACTIONS(4358),
    [anon_sym_nettype] = ACTIONS(4358),
    [anon_sym_automatic] = ACTIONS(4358),
    [anon_sym_string] = ACTIONS(4358),
    [anon_sym_chandle] = ACTIONS(4358),
    [anon_sym_event] = ACTIONS(4358),
    [anon_sym_byte] = ACTIONS(4358),
    [anon_sym_shortint] = ACTIONS(4358),
    [anon_sym_int] = ACTIONS(4358),
    [anon_sym_longint] = ACTIONS(4358),
    [anon_sym_integer] = ACTIONS(4358),
    [anon_sym_time] = ACTIONS(4358),
    [anon_sym_bit] = ACTIONS(4358),
    [anon_sym_logic] = ACTIONS(4358),
    [anon_sym_reg] = ACTIONS(4358),
    [anon_sym_shortreal] = ACTIONS(4358),
    [anon_sym_real] = ACTIONS(4358),
    [anon_sym_realtime] = ACTIONS(4358),
    [anon_sym_supply0] = ACTIONS(4358),
    [anon_sym_supply1] = ACTIONS(4358),
    [anon_sym_signed] = ACTIONS(4358),
    [anon_sym_unsigned] = ACTIONS(4358),
    [anon_sym_task] = ACTIONS(4358),
    [anon_sym_modport] = ACTIONS(4358),
    [anon_sym_assert] = ACTIONS(4358),
    [anon_sym_property] = ACTIONS(4358),
    [anon_sym_assume] = ACTIONS(4358),
    [anon_sym_cover] = ACTIONS(4358),
    [anon_sym_sequence] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym_not] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4358),
    [anon_sym_and] = ACTIONS(4358),
    [anon_sym_case] = ACTIONS(4358),
    [anon_sym_always] = ACTIONS(4358),
    [anon_sym_covergroup] = ACTIONS(4358),
    [anon_sym_let] = ACTIONS(4358),
    [anon_sym_pulldown] = ACTIONS(4358),
    [anon_sym_pullup] = ACTIONS(4358),
    [anon_sym_cmos] = ACTIONS(4358),
    [anon_sym_rcmos] = ACTIONS(4358),
    [anon_sym_bufif0] = ACTIONS(4358),
    [anon_sym_bufif1] = ACTIONS(4358),
    [anon_sym_notif0] = ACTIONS(4358),
    [anon_sym_notif1] = ACTIONS(4358),
    [anon_sym_nmos] = ACTIONS(4358),
    [anon_sym_pmos] = ACTIONS(4358),
    [anon_sym_rnmos] = ACTIONS(4358),
    [anon_sym_rpmos] = ACTIONS(4358),
    [anon_sym_nand] = ACTIONS(4358),
    [anon_sym_nor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4358),
    [anon_sym_xnor] = ACTIONS(4358),
    [anon_sym_buf] = ACTIONS(4358),
    [anon_sym_tranif0] = ACTIONS(4358),
    [anon_sym_tranif1] = ACTIONS(4358),
    [anon_sym_rtranif1] = ACTIONS(4358),
    [anon_sym_rtranif0] = ACTIONS(4358),
    [anon_sym_tran] = ACTIONS(4358),
    [anon_sym_rtran] = ACTIONS(4358),
    [anon_sym_generate] = ACTIONS(4358),
    [anon_sym_for] = ACTIONS(4358),
    [anon_sym_primitive] = ACTIONS(4358),
    [anon_sym_initial] = ACTIONS(4358),
    [anon_sym_assign] = ACTIONS(4358),
    [anon_sym_alias] = ACTIONS(4358),
    [anon_sym_always_comb] = ACTIONS(4358),
    [anon_sym_always_latch] = ACTIONS(4358),
    [anon_sym_always_ff] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_global] = ACTIONS(4358),
    [anon_sym_specify] = ACTIONS(4358),
    [anon_sym_LPAREN_STAR] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4356),
    [anon_sym_DOLLARunit] = ACTIONS(4356),
  },
  [686] = {
    [ts_builtin_sym_end] = ACTIONS(4362),
    [sym_simple_identifier] = ACTIONS(4364),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4362),
    [anon_sym_BQUOTE] = ACTIONS(4364),
    [aux_sym_id_directive_token1] = ACTIONS(4362),
    [aux_sym_id_directive_token2] = ACTIONS(4362),
    [aux_sym_id_directive_token3] = ACTIONS(4362),
    [aux_sym_id_directive_token4] = ACTIONS(4364),
    [aux_sym_zero_directive_token1] = ACTIONS(4362),
    [aux_sym_zero_directive_token2] = ACTIONS(4362),
    [aux_sym_zero_directive_token3] = ACTIONS(4362),
    [aux_sym_zero_directive_token4] = ACTIONS(4362),
    [aux_sym_zero_directive_token5] = ACTIONS(4362),
    [aux_sym_zero_directive_token6] = ACTIONS(4362),
    [aux_sym_zero_directive_token7] = ACTIONS(4362),
    [aux_sym_zero_directive_token8] = ACTIONS(4362),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4362),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4362),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_begin_keywords_token1] = ACTIONS(4362),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_endmodule] = ACTIONS(4364),
    [anon_sym_COLON] = ACTIONS(4366),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_module] = ACTIONS(4364),
    [anon_sym_macromodule] = ACTIONS(4364),
    [anon_sym_endinterface] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_endprogram] = ACTIONS(4364),
    [anon_sym_program] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_package] = ACTIONS(4364),
    [anon_sym_endpackage] = ACTIONS(4364),
    [anon_sym_timeunit] = ACTIONS(4364),
    [anon_sym_timeprecision] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_input] = ACTIONS(4364),
    [anon_sym_output] = ACTIONS(4364),
    [anon_sym_inout] = ACTIONS(4364),
    [anon_sym_ref] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_specparam] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_modport] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_primitive] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_specify] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [687] = {
    [ts_builtin_sym_end] = ACTIONS(4368),
    [sym_simple_identifier] = ACTIONS(4370),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4368),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4368),
    [anon_sym_BQUOTE] = ACTIONS(4370),
    [aux_sym_id_directive_token1] = ACTIONS(4368),
    [aux_sym_id_directive_token2] = ACTIONS(4368),
    [aux_sym_id_directive_token3] = ACTIONS(4368),
    [aux_sym_id_directive_token4] = ACTIONS(4370),
    [aux_sym_zero_directive_token1] = ACTIONS(4368),
    [aux_sym_zero_directive_token2] = ACTIONS(4368),
    [aux_sym_zero_directive_token3] = ACTIONS(4368),
    [aux_sym_zero_directive_token4] = ACTIONS(4368),
    [aux_sym_zero_directive_token5] = ACTIONS(4368),
    [aux_sym_zero_directive_token6] = ACTIONS(4368),
    [aux_sym_zero_directive_token7] = ACTIONS(4368),
    [aux_sym_zero_directive_token8] = ACTIONS(4368),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4368),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4368),
    [anon_sym_wire] = ACTIONS(4370),
    [anon_sym_tri] = ACTIONS(4370),
    [anon_sym_tri0] = ACTIONS(4370),
    [anon_sym_tri1] = ACTIONS(4370),
    [anon_sym_wand] = ACTIONS(4370),
    [anon_sym_triand] = ACTIONS(4370),
    [anon_sym_wor] = ACTIONS(4370),
    [anon_sym_trior] = ACTIONS(4370),
    [anon_sym_trireg] = ACTIONS(4370),
    [anon_sym_uwire] = ACTIONS(4370),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4368),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4368),
    [aux_sym_begin_keywords_token1] = ACTIONS(4368),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym_endmodule] = ACTIONS(4370),
    [anon_sym_COLON] = ACTIONS(4372),
    [anon_sym_extern] = ACTIONS(4370),
    [anon_sym_module] = ACTIONS(4370),
    [anon_sym_macromodule] = ACTIONS(4370),
    [anon_sym_endinterface] = ACTIONS(4370),
    [anon_sym_interface] = ACTIONS(4370),
    [anon_sym_endprogram] = ACTIONS(4370),
    [anon_sym_program] = ACTIONS(4370),
    [anon_sym_checker] = ACTIONS(4370),
    [anon_sym_virtual] = ACTIONS(4370),
    [anon_sym_class] = ACTIONS(4370),
    [anon_sym_package] = ACTIONS(4370),
    [anon_sym_endpackage] = ACTIONS(4370),
    [anon_sym_timeunit] = ACTIONS(4370),
    [anon_sym_timeprecision] = ACTIONS(4370),
    [anon_sym_type] = ACTIONS(4370),
    [anon_sym_input] = ACTIONS(4370),
    [anon_sym_output] = ACTIONS(4370),
    [anon_sym_inout] = ACTIONS(4370),
    [anon_sym_ref] = ACTIONS(4370),
    [anon_sym_DOLLARfatal] = ACTIONS(4368),
    [anon_sym_DOLLARerror] = ACTIONS(4368),
    [anon_sym_DOLLARwarning] = ACTIONS(4368),
    [anon_sym_DOLLARinfo] = ACTIONS(4368),
    [anon_sym_default] = ACTIONS(4370),
    [anon_sym_clocking] = ACTIONS(4370),
    [anon_sym_defparam] = ACTIONS(4370),
    [anon_sym_bind] = ACTIONS(4370),
    [anon_sym_const] = ACTIONS(4370),
    [anon_sym_function] = ACTIONS(4370),
    [anon_sym_static] = ACTIONS(4370),
    [anon_sym_constraint] = ACTIONS(4370),
    [anon_sym_if] = ACTIONS(4370),
    [anon_sym_else] = ACTIONS(4370),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_localparam] = ACTIONS(4370),
    [anon_sym_parameter] = ACTIONS(4370),
    [anon_sym_specparam] = ACTIONS(4370),
    [anon_sym_var] = ACTIONS(4370),
    [anon_sym_import] = ACTIONS(4370),
    [anon_sym_export] = ACTIONS(4370),
    [anon_sym_genvar] = ACTIONS(4370),
    [anon_sym_interconnect] = ACTIONS(4370),
    [anon_sym_typedef] = ACTIONS(4370),
    [anon_sym_enum] = ACTIONS(4370),
    [anon_sym_struct] = ACTIONS(4370),
    [anon_sym_union] = ACTIONS(4370),
    [anon_sym_nettype] = ACTIONS(4370),
    [anon_sym_automatic] = ACTIONS(4370),
    [anon_sym_string] = ACTIONS(4370),
    [anon_sym_chandle] = ACTIONS(4370),
    [anon_sym_event] = ACTIONS(4370),
    [anon_sym_byte] = ACTIONS(4370),
    [anon_sym_shortint] = ACTIONS(4370),
    [anon_sym_int] = ACTIONS(4370),
    [anon_sym_longint] = ACTIONS(4370),
    [anon_sym_integer] = ACTIONS(4370),
    [anon_sym_time] = ACTIONS(4370),
    [anon_sym_bit] = ACTIONS(4370),
    [anon_sym_logic] = ACTIONS(4370),
    [anon_sym_reg] = ACTIONS(4370),
    [anon_sym_shortreal] = ACTIONS(4370),
    [anon_sym_real] = ACTIONS(4370),
    [anon_sym_realtime] = ACTIONS(4370),
    [anon_sym_supply0] = ACTIONS(4370),
    [anon_sym_supply1] = ACTIONS(4370),
    [anon_sym_signed] = ACTIONS(4370),
    [anon_sym_unsigned] = ACTIONS(4370),
    [anon_sym_task] = ACTIONS(4370),
    [anon_sym_modport] = ACTIONS(4370),
    [anon_sym_assert] = ACTIONS(4370),
    [anon_sym_property] = ACTIONS(4370),
    [anon_sym_assume] = ACTIONS(4370),
    [anon_sym_cover] = ACTIONS(4370),
    [anon_sym_sequence] = ACTIONS(4370),
    [anon_sym_restrict] = ACTIONS(4370),
    [anon_sym_not] = ACTIONS(4370),
    [anon_sym_or] = ACTIONS(4370),
    [anon_sym_and] = ACTIONS(4370),
    [anon_sym_case] = ACTIONS(4370),
    [anon_sym_always] = ACTIONS(4370),
    [anon_sym_covergroup] = ACTIONS(4370),
    [anon_sym_let] = ACTIONS(4370),
    [anon_sym_pulldown] = ACTIONS(4370),
    [anon_sym_pullup] = ACTIONS(4370),
    [anon_sym_cmos] = ACTIONS(4370),
    [anon_sym_rcmos] = ACTIONS(4370),
    [anon_sym_bufif0] = ACTIONS(4370),
    [anon_sym_bufif1] = ACTIONS(4370),
    [anon_sym_notif0] = ACTIONS(4370),
    [anon_sym_notif1] = ACTIONS(4370),
    [anon_sym_nmos] = ACTIONS(4370),
    [anon_sym_pmos] = ACTIONS(4370),
    [anon_sym_rnmos] = ACTIONS(4370),
    [anon_sym_rpmos] = ACTIONS(4370),
    [anon_sym_nand] = ACTIONS(4370),
    [anon_sym_nor] = ACTIONS(4370),
    [anon_sym_xor] = ACTIONS(4370),
    [anon_sym_xnor] = ACTIONS(4370),
    [anon_sym_buf] = ACTIONS(4370),
    [anon_sym_tranif0] = ACTIONS(4370),
    [anon_sym_tranif1] = ACTIONS(4370),
    [anon_sym_rtranif1] = ACTIONS(4370),
    [anon_sym_rtranif0] = ACTIONS(4370),
    [anon_sym_tran] = ACTIONS(4370),
    [anon_sym_rtran] = ACTIONS(4370),
    [anon_sym_generate] = ACTIONS(4370),
    [anon_sym_for] = ACTIONS(4370),
    [anon_sym_primitive] = ACTIONS(4370),
    [anon_sym_initial] = ACTIONS(4370),
    [anon_sym_assign] = ACTIONS(4370),
    [anon_sym_alias] = ACTIONS(4370),
    [anon_sym_always_comb] = ACTIONS(4370),
    [anon_sym_always_latch] = ACTIONS(4370),
    [anon_sym_always_ff] = ACTIONS(4370),
    [anon_sym_final] = ACTIONS(4370),
    [anon_sym_global] = ACTIONS(4370),
    [anon_sym_specify] = ACTIONS(4370),
    [anon_sym_LPAREN_STAR] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4368),
    [anon_sym_DOLLARunit] = ACTIONS(4368),
  },
  [688] = {
    [ts_builtin_sym_end] = ACTIONS(4374),
    [sym_simple_identifier] = ACTIONS(4376),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4374),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4374),
    [anon_sym_BQUOTE] = ACTIONS(4376),
    [aux_sym_id_directive_token1] = ACTIONS(4374),
    [aux_sym_id_directive_token2] = ACTIONS(4374),
    [aux_sym_id_directive_token3] = ACTIONS(4374),
    [aux_sym_id_directive_token4] = ACTIONS(4376),
    [aux_sym_zero_directive_token1] = ACTIONS(4374),
    [aux_sym_zero_directive_token2] = ACTIONS(4374),
    [aux_sym_zero_directive_token3] = ACTIONS(4374),
    [aux_sym_zero_directive_token4] = ACTIONS(4374),
    [aux_sym_zero_directive_token5] = ACTIONS(4374),
    [aux_sym_zero_directive_token6] = ACTIONS(4374),
    [aux_sym_zero_directive_token7] = ACTIONS(4374),
    [aux_sym_zero_directive_token8] = ACTIONS(4374),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4374),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4374),
    [anon_sym_wire] = ACTIONS(4376),
    [anon_sym_tri] = ACTIONS(4376),
    [anon_sym_tri0] = ACTIONS(4376),
    [anon_sym_tri1] = ACTIONS(4376),
    [anon_sym_wand] = ACTIONS(4376),
    [anon_sym_triand] = ACTIONS(4376),
    [anon_sym_wor] = ACTIONS(4376),
    [anon_sym_trior] = ACTIONS(4376),
    [anon_sym_trireg] = ACTIONS(4376),
    [anon_sym_uwire] = ACTIONS(4376),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4374),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4374),
    [aux_sym_begin_keywords_token1] = ACTIONS(4374),
    [anon_sym_SEMI] = ACTIONS(4374),
    [anon_sym_endmodule] = ACTIONS(4376),
    [anon_sym_COLON] = ACTIONS(4378),
    [anon_sym_extern] = ACTIONS(4376),
    [anon_sym_module] = ACTIONS(4376),
    [anon_sym_macromodule] = ACTIONS(4376),
    [anon_sym_endinterface] = ACTIONS(4376),
    [anon_sym_interface] = ACTIONS(4376),
    [anon_sym_endprogram] = ACTIONS(4376),
    [anon_sym_program] = ACTIONS(4376),
    [anon_sym_checker] = ACTIONS(4376),
    [anon_sym_virtual] = ACTIONS(4376),
    [anon_sym_class] = ACTIONS(4376),
    [anon_sym_package] = ACTIONS(4376),
    [anon_sym_endpackage] = ACTIONS(4376),
    [anon_sym_timeunit] = ACTIONS(4376),
    [anon_sym_timeprecision] = ACTIONS(4376),
    [anon_sym_type] = ACTIONS(4376),
    [anon_sym_input] = ACTIONS(4376),
    [anon_sym_output] = ACTIONS(4376),
    [anon_sym_inout] = ACTIONS(4376),
    [anon_sym_ref] = ACTIONS(4376),
    [anon_sym_DOLLARfatal] = ACTIONS(4374),
    [anon_sym_DOLLARerror] = ACTIONS(4374),
    [anon_sym_DOLLARwarning] = ACTIONS(4374),
    [anon_sym_DOLLARinfo] = ACTIONS(4374),
    [anon_sym_default] = ACTIONS(4376),
    [anon_sym_clocking] = ACTIONS(4376),
    [anon_sym_defparam] = ACTIONS(4376),
    [anon_sym_bind] = ACTIONS(4376),
    [anon_sym_const] = ACTIONS(4376),
    [anon_sym_function] = ACTIONS(4376),
    [anon_sym_static] = ACTIONS(4376),
    [anon_sym_constraint] = ACTIONS(4376),
    [anon_sym_if] = ACTIONS(4376),
    [anon_sym_else] = ACTIONS(4376),
    [anon_sym_LBRACK] = ACTIONS(4374),
    [anon_sym_localparam] = ACTIONS(4376),
    [anon_sym_parameter] = ACTIONS(4376),
    [anon_sym_specparam] = ACTIONS(4376),
    [anon_sym_var] = ACTIONS(4376),
    [anon_sym_import] = ACTIONS(4376),
    [anon_sym_export] = ACTIONS(4376),
    [anon_sym_genvar] = ACTIONS(4376),
    [anon_sym_interconnect] = ACTIONS(4376),
    [anon_sym_typedef] = ACTIONS(4376),
    [anon_sym_enum] = ACTIONS(4376),
    [anon_sym_struct] = ACTIONS(4376),
    [anon_sym_union] = ACTIONS(4376),
    [anon_sym_nettype] = ACTIONS(4376),
    [anon_sym_automatic] = ACTIONS(4376),
    [anon_sym_string] = ACTIONS(4376),
    [anon_sym_chandle] = ACTIONS(4376),
    [anon_sym_event] = ACTIONS(4376),
    [anon_sym_byte] = ACTIONS(4376),
    [anon_sym_shortint] = ACTIONS(4376),
    [anon_sym_int] = ACTIONS(4376),
    [anon_sym_longint] = ACTIONS(4376),
    [anon_sym_integer] = ACTIONS(4376),
    [anon_sym_time] = ACTIONS(4376),
    [anon_sym_bit] = ACTIONS(4376),
    [anon_sym_logic] = ACTIONS(4376),
    [anon_sym_reg] = ACTIONS(4376),
    [anon_sym_shortreal] = ACTIONS(4376),
    [anon_sym_real] = ACTIONS(4376),
    [anon_sym_realtime] = ACTIONS(4376),
    [anon_sym_supply0] = ACTIONS(4376),
    [anon_sym_supply1] = ACTIONS(4376),
    [anon_sym_signed] = ACTIONS(4376),
    [anon_sym_unsigned] = ACTIONS(4376),
    [anon_sym_task] = ACTIONS(4376),
    [anon_sym_modport] = ACTIONS(4376),
    [anon_sym_assert] = ACTIONS(4376),
    [anon_sym_property] = ACTIONS(4376),
    [anon_sym_assume] = ACTIONS(4376),
    [anon_sym_cover] = ACTIONS(4376),
    [anon_sym_sequence] = ACTIONS(4376),
    [anon_sym_restrict] = ACTIONS(4376),
    [anon_sym_not] = ACTIONS(4376),
    [anon_sym_or] = ACTIONS(4376),
    [anon_sym_and] = ACTIONS(4376),
    [anon_sym_case] = ACTIONS(4376),
    [anon_sym_always] = ACTIONS(4376),
    [anon_sym_covergroup] = ACTIONS(4376),
    [anon_sym_let] = ACTIONS(4376),
    [anon_sym_pulldown] = ACTIONS(4376),
    [anon_sym_pullup] = ACTIONS(4376),
    [anon_sym_cmos] = ACTIONS(4376),
    [anon_sym_rcmos] = ACTIONS(4376),
    [anon_sym_bufif0] = ACTIONS(4376),
    [anon_sym_bufif1] = ACTIONS(4376),
    [anon_sym_notif0] = ACTIONS(4376),
    [anon_sym_notif1] = ACTIONS(4376),
    [anon_sym_nmos] = ACTIONS(4376),
    [anon_sym_pmos] = ACTIONS(4376),
    [anon_sym_rnmos] = ACTIONS(4376),
    [anon_sym_rpmos] = ACTIONS(4376),
    [anon_sym_nand] = ACTIONS(4376),
    [anon_sym_nor] = ACTIONS(4376),
    [anon_sym_xor] = ACTIONS(4376),
    [anon_sym_xnor] = ACTIONS(4376),
    [anon_sym_buf] = ACTIONS(4376),
    [anon_sym_tranif0] = ACTIONS(4376),
    [anon_sym_tranif1] = ACTIONS(4376),
    [anon_sym_rtranif1] = ACTIONS(4376),
    [anon_sym_rtranif0] = ACTIONS(4376),
    [anon_sym_tran] = ACTIONS(4376),
    [anon_sym_rtran] = ACTIONS(4376),
    [anon_sym_generate] = ACTIONS(4376),
    [anon_sym_for] = ACTIONS(4376),
    [anon_sym_primitive] = ACTIONS(4376),
    [anon_sym_initial] = ACTIONS(4376),
    [anon_sym_assign] = ACTIONS(4376),
    [anon_sym_alias] = ACTIONS(4376),
    [anon_sym_always_comb] = ACTIONS(4376),
    [anon_sym_always_latch] = ACTIONS(4376),
    [anon_sym_always_ff] = ACTIONS(4376),
    [anon_sym_final] = ACTIONS(4376),
    [anon_sym_global] = ACTIONS(4376),
    [anon_sym_specify] = ACTIONS(4376),
    [anon_sym_LPAREN_STAR] = ACTIONS(4374),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4374),
    [anon_sym_DOLLARunit] = ACTIONS(4374),
  },
  [689] = {
    [ts_builtin_sym_end] = ACTIONS(4380),
    [sym_simple_identifier] = ACTIONS(4382),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4380),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4380),
    [anon_sym_BQUOTE] = ACTIONS(4382),
    [aux_sym_id_directive_token1] = ACTIONS(4380),
    [aux_sym_id_directive_token2] = ACTIONS(4380),
    [aux_sym_id_directive_token3] = ACTIONS(4380),
    [aux_sym_id_directive_token4] = ACTIONS(4382),
    [aux_sym_zero_directive_token1] = ACTIONS(4380),
    [aux_sym_zero_directive_token2] = ACTIONS(4380),
    [aux_sym_zero_directive_token3] = ACTIONS(4380),
    [aux_sym_zero_directive_token4] = ACTIONS(4380),
    [aux_sym_zero_directive_token5] = ACTIONS(4380),
    [aux_sym_zero_directive_token6] = ACTIONS(4380),
    [aux_sym_zero_directive_token7] = ACTIONS(4380),
    [aux_sym_zero_directive_token8] = ACTIONS(4380),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4380),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4380),
    [anon_sym_wire] = ACTIONS(4382),
    [anon_sym_tri] = ACTIONS(4382),
    [anon_sym_tri0] = ACTIONS(4382),
    [anon_sym_tri1] = ACTIONS(4382),
    [anon_sym_wand] = ACTIONS(4382),
    [anon_sym_triand] = ACTIONS(4382),
    [anon_sym_wor] = ACTIONS(4382),
    [anon_sym_trior] = ACTIONS(4382),
    [anon_sym_trireg] = ACTIONS(4382),
    [anon_sym_uwire] = ACTIONS(4382),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4380),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4380),
    [aux_sym_begin_keywords_token1] = ACTIONS(4380),
    [anon_sym_SEMI] = ACTIONS(4380),
    [anon_sym_endmodule] = ACTIONS(4382),
    [anon_sym_COLON] = ACTIONS(4384),
    [anon_sym_extern] = ACTIONS(4382),
    [anon_sym_module] = ACTIONS(4382),
    [anon_sym_macromodule] = ACTIONS(4382),
    [anon_sym_endinterface] = ACTIONS(4382),
    [anon_sym_interface] = ACTIONS(4382),
    [anon_sym_endprogram] = ACTIONS(4382),
    [anon_sym_program] = ACTIONS(4382),
    [anon_sym_checker] = ACTIONS(4382),
    [anon_sym_virtual] = ACTIONS(4382),
    [anon_sym_class] = ACTIONS(4382),
    [anon_sym_package] = ACTIONS(4382),
    [anon_sym_endpackage] = ACTIONS(4382),
    [anon_sym_timeunit] = ACTIONS(4382),
    [anon_sym_timeprecision] = ACTIONS(4382),
    [anon_sym_type] = ACTIONS(4382),
    [anon_sym_input] = ACTIONS(4382),
    [anon_sym_output] = ACTIONS(4382),
    [anon_sym_inout] = ACTIONS(4382),
    [anon_sym_ref] = ACTIONS(4382),
    [anon_sym_DOLLARfatal] = ACTIONS(4380),
    [anon_sym_DOLLARerror] = ACTIONS(4380),
    [anon_sym_DOLLARwarning] = ACTIONS(4380),
    [anon_sym_DOLLARinfo] = ACTIONS(4380),
    [anon_sym_default] = ACTIONS(4382),
    [anon_sym_clocking] = ACTIONS(4382),
    [anon_sym_defparam] = ACTIONS(4382),
    [anon_sym_bind] = ACTIONS(4382),
    [anon_sym_const] = ACTIONS(4382),
    [anon_sym_function] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(4382),
    [anon_sym_constraint] = ACTIONS(4382),
    [anon_sym_if] = ACTIONS(4382),
    [anon_sym_else] = ACTIONS(4382),
    [anon_sym_LBRACK] = ACTIONS(4380),
    [anon_sym_localparam] = ACTIONS(4382),
    [anon_sym_parameter] = ACTIONS(4382),
    [anon_sym_specparam] = ACTIONS(4382),
    [anon_sym_var] = ACTIONS(4382),
    [anon_sym_import] = ACTIONS(4382),
    [anon_sym_export] = ACTIONS(4382),
    [anon_sym_genvar] = ACTIONS(4382),
    [anon_sym_interconnect] = ACTIONS(4382),
    [anon_sym_typedef] = ACTIONS(4382),
    [anon_sym_enum] = ACTIONS(4382),
    [anon_sym_struct] = ACTIONS(4382),
    [anon_sym_union] = ACTIONS(4382),
    [anon_sym_nettype] = ACTIONS(4382),
    [anon_sym_automatic] = ACTIONS(4382),
    [anon_sym_string] = ACTIONS(4382),
    [anon_sym_chandle] = ACTIONS(4382),
    [anon_sym_event] = ACTIONS(4382),
    [anon_sym_byte] = ACTIONS(4382),
    [anon_sym_shortint] = ACTIONS(4382),
    [anon_sym_int] = ACTIONS(4382),
    [anon_sym_longint] = ACTIONS(4382),
    [anon_sym_integer] = ACTIONS(4382),
    [anon_sym_time] = ACTIONS(4382),
    [anon_sym_bit] = ACTIONS(4382),
    [anon_sym_logic] = ACTIONS(4382),
    [anon_sym_reg] = ACTIONS(4382),
    [anon_sym_shortreal] = ACTIONS(4382),
    [anon_sym_real] = ACTIONS(4382),
    [anon_sym_realtime] = ACTIONS(4382),
    [anon_sym_supply0] = ACTIONS(4382),
    [anon_sym_supply1] = ACTIONS(4382),
    [anon_sym_signed] = ACTIONS(4382),
    [anon_sym_unsigned] = ACTIONS(4382),
    [anon_sym_task] = ACTIONS(4382),
    [anon_sym_modport] = ACTIONS(4382),
    [anon_sym_assert] = ACTIONS(4382),
    [anon_sym_property] = ACTIONS(4382),
    [anon_sym_assume] = ACTIONS(4382),
    [anon_sym_cover] = ACTIONS(4382),
    [anon_sym_sequence] = ACTIONS(4382),
    [anon_sym_restrict] = ACTIONS(4382),
    [anon_sym_not] = ACTIONS(4382),
    [anon_sym_or] = ACTIONS(4382),
    [anon_sym_and] = ACTIONS(4382),
    [anon_sym_case] = ACTIONS(4382),
    [anon_sym_always] = ACTIONS(4382),
    [anon_sym_covergroup] = ACTIONS(4382),
    [anon_sym_let] = ACTIONS(4382),
    [anon_sym_pulldown] = ACTIONS(4382),
    [anon_sym_pullup] = ACTIONS(4382),
    [anon_sym_cmos] = ACTIONS(4382),
    [anon_sym_rcmos] = ACTIONS(4382),
    [anon_sym_bufif0] = ACTIONS(4382),
    [anon_sym_bufif1] = ACTIONS(4382),
    [anon_sym_notif0] = ACTIONS(4382),
    [anon_sym_notif1] = ACTIONS(4382),
    [anon_sym_nmos] = ACTIONS(4382),
    [anon_sym_pmos] = ACTIONS(4382),
    [anon_sym_rnmos] = ACTIONS(4382),
    [anon_sym_rpmos] = ACTIONS(4382),
    [anon_sym_nand] = ACTIONS(4382),
    [anon_sym_nor] = ACTIONS(4382),
    [anon_sym_xor] = ACTIONS(4382),
    [anon_sym_xnor] = ACTIONS(4382),
    [anon_sym_buf] = ACTIONS(4382),
    [anon_sym_tranif0] = ACTIONS(4382),
    [anon_sym_tranif1] = ACTIONS(4382),
    [anon_sym_rtranif1] = ACTIONS(4382),
    [anon_sym_rtranif0] = ACTIONS(4382),
    [anon_sym_tran] = ACTIONS(4382),
    [anon_sym_rtran] = ACTIONS(4382),
    [anon_sym_generate] = ACTIONS(4382),
    [anon_sym_for] = ACTIONS(4382),
    [anon_sym_primitive] = ACTIONS(4382),
    [anon_sym_initial] = ACTIONS(4382),
    [anon_sym_assign] = ACTIONS(4382),
    [anon_sym_alias] = ACTIONS(4382),
    [anon_sym_always_comb] = ACTIONS(4382),
    [anon_sym_always_latch] = ACTIONS(4382),
    [anon_sym_always_ff] = ACTIONS(4382),
    [anon_sym_final] = ACTIONS(4382),
    [anon_sym_global] = ACTIONS(4382),
    [anon_sym_specify] = ACTIONS(4382),
    [anon_sym_LPAREN_STAR] = ACTIONS(4380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4380),
    [anon_sym_DOLLARunit] = ACTIONS(4380),
  },
  [690] = {
    [ts_builtin_sym_end] = ACTIONS(4386),
    [sym_simple_identifier] = ACTIONS(4388),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4386),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4386),
    [anon_sym_BQUOTE] = ACTIONS(4388),
    [aux_sym_id_directive_token1] = ACTIONS(4386),
    [aux_sym_id_directive_token2] = ACTIONS(4386),
    [aux_sym_id_directive_token3] = ACTIONS(4386),
    [aux_sym_id_directive_token4] = ACTIONS(4388),
    [aux_sym_zero_directive_token1] = ACTIONS(4386),
    [aux_sym_zero_directive_token2] = ACTIONS(4386),
    [aux_sym_zero_directive_token3] = ACTIONS(4386),
    [aux_sym_zero_directive_token4] = ACTIONS(4386),
    [aux_sym_zero_directive_token5] = ACTIONS(4386),
    [aux_sym_zero_directive_token6] = ACTIONS(4386),
    [aux_sym_zero_directive_token7] = ACTIONS(4386),
    [aux_sym_zero_directive_token8] = ACTIONS(4386),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4386),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4386),
    [anon_sym_wire] = ACTIONS(4388),
    [anon_sym_tri] = ACTIONS(4388),
    [anon_sym_tri0] = ACTIONS(4388),
    [anon_sym_tri1] = ACTIONS(4388),
    [anon_sym_wand] = ACTIONS(4388),
    [anon_sym_triand] = ACTIONS(4388),
    [anon_sym_wor] = ACTIONS(4388),
    [anon_sym_trior] = ACTIONS(4388),
    [anon_sym_trireg] = ACTIONS(4388),
    [anon_sym_uwire] = ACTIONS(4388),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4386),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4386),
    [aux_sym_begin_keywords_token1] = ACTIONS(4386),
    [anon_sym_SEMI] = ACTIONS(4386),
    [anon_sym_endmodule] = ACTIONS(4388),
    [anon_sym_COLON] = ACTIONS(4390),
    [anon_sym_extern] = ACTIONS(4388),
    [anon_sym_module] = ACTIONS(4388),
    [anon_sym_macromodule] = ACTIONS(4388),
    [anon_sym_endinterface] = ACTIONS(4388),
    [anon_sym_interface] = ACTIONS(4388),
    [anon_sym_endprogram] = ACTIONS(4388),
    [anon_sym_program] = ACTIONS(4388),
    [anon_sym_checker] = ACTIONS(4388),
    [anon_sym_virtual] = ACTIONS(4388),
    [anon_sym_class] = ACTIONS(4388),
    [anon_sym_package] = ACTIONS(4388),
    [anon_sym_endpackage] = ACTIONS(4388),
    [anon_sym_timeunit] = ACTIONS(4388),
    [anon_sym_timeprecision] = ACTIONS(4388),
    [anon_sym_type] = ACTIONS(4388),
    [anon_sym_input] = ACTIONS(4388),
    [anon_sym_output] = ACTIONS(4388),
    [anon_sym_inout] = ACTIONS(4388),
    [anon_sym_ref] = ACTIONS(4388),
    [anon_sym_DOLLARfatal] = ACTIONS(4386),
    [anon_sym_DOLLARerror] = ACTIONS(4386),
    [anon_sym_DOLLARwarning] = ACTIONS(4386),
    [anon_sym_DOLLARinfo] = ACTIONS(4386),
    [anon_sym_default] = ACTIONS(4388),
    [anon_sym_clocking] = ACTIONS(4388),
    [anon_sym_defparam] = ACTIONS(4388),
    [anon_sym_bind] = ACTIONS(4388),
    [anon_sym_const] = ACTIONS(4388),
    [anon_sym_function] = ACTIONS(4388),
    [anon_sym_static] = ACTIONS(4388),
    [anon_sym_constraint] = ACTIONS(4388),
    [anon_sym_if] = ACTIONS(4388),
    [anon_sym_else] = ACTIONS(4388),
    [anon_sym_LBRACK] = ACTIONS(4386),
    [anon_sym_localparam] = ACTIONS(4388),
    [anon_sym_parameter] = ACTIONS(4388),
    [anon_sym_specparam] = ACTIONS(4388),
    [anon_sym_var] = ACTIONS(4388),
    [anon_sym_import] = ACTIONS(4388),
    [anon_sym_export] = ACTIONS(4388),
    [anon_sym_genvar] = ACTIONS(4388),
    [anon_sym_interconnect] = ACTIONS(4388),
    [anon_sym_typedef] = ACTIONS(4388),
    [anon_sym_enum] = ACTIONS(4388),
    [anon_sym_struct] = ACTIONS(4388),
    [anon_sym_union] = ACTIONS(4388),
    [anon_sym_nettype] = ACTIONS(4388),
    [anon_sym_automatic] = ACTIONS(4388),
    [anon_sym_string] = ACTIONS(4388),
    [anon_sym_chandle] = ACTIONS(4388),
    [anon_sym_event] = ACTIONS(4388),
    [anon_sym_byte] = ACTIONS(4388),
    [anon_sym_shortint] = ACTIONS(4388),
    [anon_sym_int] = ACTIONS(4388),
    [anon_sym_longint] = ACTIONS(4388),
    [anon_sym_integer] = ACTIONS(4388),
    [anon_sym_time] = ACTIONS(4388),
    [anon_sym_bit] = ACTIONS(4388),
    [anon_sym_logic] = ACTIONS(4388),
    [anon_sym_reg] = ACTIONS(4388),
    [anon_sym_shortreal] = ACTIONS(4388),
    [anon_sym_real] = ACTIONS(4388),
    [anon_sym_realtime] = ACTIONS(4388),
    [anon_sym_supply0] = ACTIONS(4388),
    [anon_sym_supply1] = ACTIONS(4388),
    [anon_sym_signed] = ACTIONS(4388),
    [anon_sym_unsigned] = ACTIONS(4388),
    [anon_sym_task] = ACTIONS(4388),
    [anon_sym_modport] = ACTIONS(4388),
    [anon_sym_assert] = ACTIONS(4388),
    [anon_sym_property] = ACTIONS(4388),
    [anon_sym_assume] = ACTIONS(4388),
    [anon_sym_cover] = ACTIONS(4388),
    [anon_sym_sequence] = ACTIONS(4388),
    [anon_sym_restrict] = ACTIONS(4388),
    [anon_sym_not] = ACTIONS(4388),
    [anon_sym_or] = ACTIONS(4388),
    [anon_sym_and] = ACTIONS(4388),
    [anon_sym_case] = ACTIONS(4388),
    [anon_sym_always] = ACTIONS(4388),
    [anon_sym_covergroup] = ACTIONS(4388),
    [anon_sym_let] = ACTIONS(4388),
    [anon_sym_pulldown] = ACTIONS(4388),
    [anon_sym_pullup] = ACTIONS(4388),
    [anon_sym_cmos] = ACTIONS(4388),
    [anon_sym_rcmos] = ACTIONS(4388),
    [anon_sym_bufif0] = ACTIONS(4388),
    [anon_sym_bufif1] = ACTIONS(4388),
    [anon_sym_notif0] = ACTIONS(4388),
    [anon_sym_notif1] = ACTIONS(4388),
    [anon_sym_nmos] = ACTIONS(4388),
    [anon_sym_pmos] = ACTIONS(4388),
    [anon_sym_rnmos] = ACTIONS(4388),
    [anon_sym_rpmos] = ACTIONS(4388),
    [anon_sym_nand] = ACTIONS(4388),
    [anon_sym_nor] = ACTIONS(4388),
    [anon_sym_xor] = ACTIONS(4388),
    [anon_sym_xnor] = ACTIONS(4388),
    [anon_sym_buf] = ACTIONS(4388),
    [anon_sym_tranif0] = ACTIONS(4388),
    [anon_sym_tranif1] = ACTIONS(4388),
    [anon_sym_rtranif1] = ACTIONS(4388),
    [anon_sym_rtranif0] = ACTIONS(4388),
    [anon_sym_tran] = ACTIONS(4388),
    [anon_sym_rtran] = ACTIONS(4388),
    [anon_sym_generate] = ACTIONS(4388),
    [anon_sym_for] = ACTIONS(4388),
    [anon_sym_primitive] = ACTIONS(4388),
    [anon_sym_initial] = ACTIONS(4388),
    [anon_sym_assign] = ACTIONS(4388),
    [anon_sym_alias] = ACTIONS(4388),
    [anon_sym_always_comb] = ACTIONS(4388),
    [anon_sym_always_latch] = ACTIONS(4388),
    [anon_sym_always_ff] = ACTIONS(4388),
    [anon_sym_final] = ACTIONS(4388),
    [anon_sym_global] = ACTIONS(4388),
    [anon_sym_specify] = ACTIONS(4388),
    [anon_sym_LPAREN_STAR] = ACTIONS(4386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4386),
    [anon_sym_DOLLARunit] = ACTIONS(4386),
  },
  [691] = {
    [ts_builtin_sym_end] = ACTIONS(4392),
    [sym_simple_identifier] = ACTIONS(4394),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4392),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4392),
    [anon_sym_BQUOTE] = ACTIONS(4394),
    [aux_sym_id_directive_token1] = ACTIONS(4392),
    [aux_sym_id_directive_token2] = ACTIONS(4392),
    [aux_sym_id_directive_token3] = ACTIONS(4392),
    [aux_sym_id_directive_token4] = ACTIONS(4394),
    [aux_sym_zero_directive_token1] = ACTIONS(4392),
    [aux_sym_zero_directive_token2] = ACTIONS(4392),
    [aux_sym_zero_directive_token3] = ACTIONS(4392),
    [aux_sym_zero_directive_token4] = ACTIONS(4392),
    [aux_sym_zero_directive_token5] = ACTIONS(4392),
    [aux_sym_zero_directive_token6] = ACTIONS(4392),
    [aux_sym_zero_directive_token7] = ACTIONS(4392),
    [aux_sym_zero_directive_token8] = ACTIONS(4392),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4392),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4392),
    [anon_sym_wire] = ACTIONS(4394),
    [anon_sym_tri] = ACTIONS(4394),
    [anon_sym_tri0] = ACTIONS(4394),
    [anon_sym_tri1] = ACTIONS(4394),
    [anon_sym_wand] = ACTIONS(4394),
    [anon_sym_triand] = ACTIONS(4394),
    [anon_sym_wor] = ACTIONS(4394),
    [anon_sym_trior] = ACTIONS(4394),
    [anon_sym_trireg] = ACTIONS(4394),
    [anon_sym_uwire] = ACTIONS(4394),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4392),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4392),
    [aux_sym_begin_keywords_token1] = ACTIONS(4392),
    [anon_sym_SEMI] = ACTIONS(4392),
    [anon_sym_endmodule] = ACTIONS(4394),
    [anon_sym_COLON] = ACTIONS(4396),
    [anon_sym_extern] = ACTIONS(4394),
    [anon_sym_module] = ACTIONS(4394),
    [anon_sym_macromodule] = ACTIONS(4394),
    [anon_sym_endinterface] = ACTIONS(4394),
    [anon_sym_interface] = ACTIONS(4394),
    [anon_sym_endprogram] = ACTIONS(4394),
    [anon_sym_program] = ACTIONS(4394),
    [anon_sym_checker] = ACTIONS(4394),
    [anon_sym_virtual] = ACTIONS(4394),
    [anon_sym_class] = ACTIONS(4394),
    [anon_sym_package] = ACTIONS(4394),
    [anon_sym_endpackage] = ACTIONS(4394),
    [anon_sym_timeunit] = ACTIONS(4394),
    [anon_sym_timeprecision] = ACTIONS(4394),
    [anon_sym_type] = ACTIONS(4394),
    [anon_sym_input] = ACTIONS(4394),
    [anon_sym_output] = ACTIONS(4394),
    [anon_sym_inout] = ACTIONS(4394),
    [anon_sym_ref] = ACTIONS(4394),
    [anon_sym_DOLLARfatal] = ACTIONS(4392),
    [anon_sym_DOLLARerror] = ACTIONS(4392),
    [anon_sym_DOLLARwarning] = ACTIONS(4392),
    [anon_sym_DOLLARinfo] = ACTIONS(4392),
    [anon_sym_default] = ACTIONS(4394),
    [anon_sym_clocking] = ACTIONS(4394),
    [anon_sym_defparam] = ACTIONS(4394),
    [anon_sym_bind] = ACTIONS(4394),
    [anon_sym_const] = ACTIONS(4394),
    [anon_sym_function] = ACTIONS(4394),
    [anon_sym_static] = ACTIONS(4394),
    [anon_sym_constraint] = ACTIONS(4394),
    [anon_sym_if] = ACTIONS(4394),
    [anon_sym_else] = ACTIONS(4394),
    [anon_sym_LBRACK] = ACTIONS(4392),
    [anon_sym_localparam] = ACTIONS(4394),
    [anon_sym_parameter] = ACTIONS(4394),
    [anon_sym_specparam] = ACTIONS(4394),
    [anon_sym_var] = ACTIONS(4394),
    [anon_sym_import] = ACTIONS(4394),
    [anon_sym_export] = ACTIONS(4394),
    [anon_sym_genvar] = ACTIONS(4394),
    [anon_sym_interconnect] = ACTIONS(4394),
    [anon_sym_typedef] = ACTIONS(4394),
    [anon_sym_enum] = ACTIONS(4394),
    [anon_sym_struct] = ACTIONS(4394),
    [anon_sym_union] = ACTIONS(4394),
    [anon_sym_nettype] = ACTIONS(4394),
    [anon_sym_automatic] = ACTIONS(4394),
    [anon_sym_string] = ACTIONS(4394),
    [anon_sym_chandle] = ACTIONS(4394),
    [anon_sym_event] = ACTIONS(4394),
    [anon_sym_byte] = ACTIONS(4394),
    [anon_sym_shortint] = ACTIONS(4394),
    [anon_sym_int] = ACTIONS(4394),
    [anon_sym_longint] = ACTIONS(4394),
    [anon_sym_integer] = ACTIONS(4394),
    [anon_sym_time] = ACTIONS(4394),
    [anon_sym_bit] = ACTIONS(4394),
    [anon_sym_logic] = ACTIONS(4394),
    [anon_sym_reg] = ACTIONS(4394),
    [anon_sym_shortreal] = ACTIONS(4394),
    [anon_sym_real] = ACTIONS(4394),
    [anon_sym_realtime] = ACTIONS(4394),
    [anon_sym_supply0] = ACTIONS(4394),
    [anon_sym_supply1] = ACTIONS(4394),
    [anon_sym_signed] = ACTIONS(4394),
    [anon_sym_unsigned] = ACTIONS(4394),
    [anon_sym_task] = ACTIONS(4394),
    [anon_sym_modport] = ACTIONS(4394),
    [anon_sym_assert] = ACTIONS(4394),
    [anon_sym_property] = ACTIONS(4394),
    [anon_sym_assume] = ACTIONS(4394),
    [anon_sym_cover] = ACTIONS(4394),
    [anon_sym_sequence] = ACTIONS(4394),
    [anon_sym_restrict] = ACTIONS(4394),
    [anon_sym_not] = ACTIONS(4394),
    [anon_sym_or] = ACTIONS(4394),
    [anon_sym_and] = ACTIONS(4394),
    [anon_sym_case] = ACTIONS(4394),
    [anon_sym_always] = ACTIONS(4394),
    [anon_sym_covergroup] = ACTIONS(4394),
    [anon_sym_let] = ACTIONS(4394),
    [anon_sym_pulldown] = ACTIONS(4394),
    [anon_sym_pullup] = ACTIONS(4394),
    [anon_sym_cmos] = ACTIONS(4394),
    [anon_sym_rcmos] = ACTIONS(4394),
    [anon_sym_bufif0] = ACTIONS(4394),
    [anon_sym_bufif1] = ACTIONS(4394),
    [anon_sym_notif0] = ACTIONS(4394),
    [anon_sym_notif1] = ACTIONS(4394),
    [anon_sym_nmos] = ACTIONS(4394),
    [anon_sym_pmos] = ACTIONS(4394),
    [anon_sym_rnmos] = ACTIONS(4394),
    [anon_sym_rpmos] = ACTIONS(4394),
    [anon_sym_nand] = ACTIONS(4394),
    [anon_sym_nor] = ACTIONS(4394),
    [anon_sym_xor] = ACTIONS(4394),
    [anon_sym_xnor] = ACTIONS(4394),
    [anon_sym_buf] = ACTIONS(4394),
    [anon_sym_tranif0] = ACTIONS(4394),
    [anon_sym_tranif1] = ACTIONS(4394),
    [anon_sym_rtranif1] = ACTIONS(4394),
    [anon_sym_rtranif0] = ACTIONS(4394),
    [anon_sym_tran] = ACTIONS(4394),
    [anon_sym_rtran] = ACTIONS(4394),
    [anon_sym_generate] = ACTIONS(4394),
    [anon_sym_for] = ACTIONS(4394),
    [anon_sym_primitive] = ACTIONS(4394),
    [anon_sym_initial] = ACTIONS(4394),
    [anon_sym_assign] = ACTIONS(4394),
    [anon_sym_alias] = ACTIONS(4394),
    [anon_sym_always_comb] = ACTIONS(4394),
    [anon_sym_always_latch] = ACTIONS(4394),
    [anon_sym_always_ff] = ACTIONS(4394),
    [anon_sym_final] = ACTIONS(4394),
    [anon_sym_global] = ACTIONS(4394),
    [anon_sym_specify] = ACTIONS(4394),
    [anon_sym_LPAREN_STAR] = ACTIONS(4392),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4392),
    [anon_sym_DOLLARunit] = ACTIONS(4392),
  },
  [692] = {
    [ts_builtin_sym_end] = ACTIONS(4398),
    [sym_simple_identifier] = ACTIONS(4400),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4398),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4398),
    [anon_sym_BQUOTE] = ACTIONS(4400),
    [aux_sym_id_directive_token1] = ACTIONS(4398),
    [aux_sym_id_directive_token2] = ACTIONS(4398),
    [aux_sym_id_directive_token3] = ACTIONS(4398),
    [aux_sym_id_directive_token4] = ACTIONS(4400),
    [aux_sym_zero_directive_token1] = ACTIONS(4398),
    [aux_sym_zero_directive_token2] = ACTIONS(4398),
    [aux_sym_zero_directive_token3] = ACTIONS(4398),
    [aux_sym_zero_directive_token4] = ACTIONS(4398),
    [aux_sym_zero_directive_token5] = ACTIONS(4398),
    [aux_sym_zero_directive_token6] = ACTIONS(4398),
    [aux_sym_zero_directive_token7] = ACTIONS(4398),
    [aux_sym_zero_directive_token8] = ACTIONS(4398),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4398),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4398),
    [anon_sym_wire] = ACTIONS(4400),
    [anon_sym_tri] = ACTIONS(4400),
    [anon_sym_tri0] = ACTIONS(4400),
    [anon_sym_tri1] = ACTIONS(4400),
    [anon_sym_wand] = ACTIONS(4400),
    [anon_sym_triand] = ACTIONS(4400),
    [anon_sym_wor] = ACTIONS(4400),
    [anon_sym_trior] = ACTIONS(4400),
    [anon_sym_trireg] = ACTIONS(4400),
    [anon_sym_uwire] = ACTIONS(4400),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4398),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4398),
    [aux_sym_begin_keywords_token1] = ACTIONS(4398),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym_endmodule] = ACTIONS(4400),
    [anon_sym_COLON] = ACTIONS(4402),
    [anon_sym_extern] = ACTIONS(4400),
    [anon_sym_module] = ACTIONS(4400),
    [anon_sym_macromodule] = ACTIONS(4400),
    [anon_sym_endinterface] = ACTIONS(4400),
    [anon_sym_interface] = ACTIONS(4400),
    [anon_sym_endprogram] = ACTIONS(4400),
    [anon_sym_program] = ACTIONS(4400),
    [anon_sym_checker] = ACTIONS(4400),
    [anon_sym_virtual] = ACTIONS(4400),
    [anon_sym_class] = ACTIONS(4400),
    [anon_sym_package] = ACTIONS(4400),
    [anon_sym_endpackage] = ACTIONS(4400),
    [anon_sym_timeunit] = ACTIONS(4400),
    [anon_sym_timeprecision] = ACTIONS(4400),
    [anon_sym_type] = ACTIONS(4400),
    [anon_sym_input] = ACTIONS(4400),
    [anon_sym_output] = ACTIONS(4400),
    [anon_sym_inout] = ACTIONS(4400),
    [anon_sym_ref] = ACTIONS(4400),
    [anon_sym_DOLLARfatal] = ACTIONS(4398),
    [anon_sym_DOLLARerror] = ACTIONS(4398),
    [anon_sym_DOLLARwarning] = ACTIONS(4398),
    [anon_sym_DOLLARinfo] = ACTIONS(4398),
    [anon_sym_default] = ACTIONS(4400),
    [anon_sym_clocking] = ACTIONS(4400),
    [anon_sym_defparam] = ACTIONS(4400),
    [anon_sym_bind] = ACTIONS(4400),
    [anon_sym_const] = ACTIONS(4400),
    [anon_sym_function] = ACTIONS(4400),
    [anon_sym_static] = ACTIONS(4400),
    [anon_sym_constraint] = ACTIONS(4400),
    [anon_sym_if] = ACTIONS(4400),
    [anon_sym_else] = ACTIONS(4400),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_localparam] = ACTIONS(4400),
    [anon_sym_parameter] = ACTIONS(4400),
    [anon_sym_specparam] = ACTIONS(4400),
    [anon_sym_var] = ACTIONS(4400),
    [anon_sym_import] = ACTIONS(4400),
    [anon_sym_export] = ACTIONS(4400),
    [anon_sym_genvar] = ACTIONS(4400),
    [anon_sym_interconnect] = ACTIONS(4400),
    [anon_sym_typedef] = ACTIONS(4400),
    [anon_sym_enum] = ACTIONS(4400),
    [anon_sym_struct] = ACTIONS(4400),
    [anon_sym_union] = ACTIONS(4400),
    [anon_sym_nettype] = ACTIONS(4400),
    [anon_sym_automatic] = ACTIONS(4400),
    [anon_sym_string] = ACTIONS(4400),
    [anon_sym_chandle] = ACTIONS(4400),
    [anon_sym_event] = ACTIONS(4400),
    [anon_sym_byte] = ACTIONS(4400),
    [anon_sym_shortint] = ACTIONS(4400),
    [anon_sym_int] = ACTIONS(4400),
    [anon_sym_longint] = ACTIONS(4400),
    [anon_sym_integer] = ACTIONS(4400),
    [anon_sym_time] = ACTIONS(4400),
    [anon_sym_bit] = ACTIONS(4400),
    [anon_sym_logic] = ACTIONS(4400),
    [anon_sym_reg] = ACTIONS(4400),
    [anon_sym_shortreal] = ACTIONS(4400),
    [anon_sym_real] = ACTIONS(4400),
    [anon_sym_realtime] = ACTIONS(4400),
    [anon_sym_supply0] = ACTIONS(4400),
    [anon_sym_supply1] = ACTIONS(4400),
    [anon_sym_signed] = ACTIONS(4400),
    [anon_sym_unsigned] = ACTIONS(4400),
    [anon_sym_task] = ACTIONS(4400),
    [anon_sym_modport] = ACTIONS(4400),
    [anon_sym_assert] = ACTIONS(4400),
    [anon_sym_property] = ACTIONS(4400),
    [anon_sym_assume] = ACTIONS(4400),
    [anon_sym_cover] = ACTIONS(4400),
    [anon_sym_sequence] = ACTIONS(4400),
    [anon_sym_restrict] = ACTIONS(4400),
    [anon_sym_not] = ACTIONS(4400),
    [anon_sym_or] = ACTIONS(4400),
    [anon_sym_and] = ACTIONS(4400),
    [anon_sym_case] = ACTIONS(4400),
    [anon_sym_always] = ACTIONS(4400),
    [anon_sym_covergroup] = ACTIONS(4400),
    [anon_sym_let] = ACTIONS(4400),
    [anon_sym_pulldown] = ACTIONS(4400),
    [anon_sym_pullup] = ACTIONS(4400),
    [anon_sym_cmos] = ACTIONS(4400),
    [anon_sym_rcmos] = ACTIONS(4400),
    [anon_sym_bufif0] = ACTIONS(4400),
    [anon_sym_bufif1] = ACTIONS(4400),
    [anon_sym_notif0] = ACTIONS(4400),
    [anon_sym_notif1] = ACTIONS(4400),
    [anon_sym_nmos] = ACTIONS(4400),
    [anon_sym_pmos] = ACTIONS(4400),
    [anon_sym_rnmos] = ACTIONS(4400),
    [anon_sym_rpmos] = ACTIONS(4400),
    [anon_sym_nand] = ACTIONS(4400),
    [anon_sym_nor] = ACTIONS(4400),
    [anon_sym_xor] = ACTIONS(4400),
    [anon_sym_xnor] = ACTIONS(4400),
    [anon_sym_buf] = ACTIONS(4400),
    [anon_sym_tranif0] = ACTIONS(4400),
    [anon_sym_tranif1] = ACTIONS(4400),
    [anon_sym_rtranif1] = ACTIONS(4400),
    [anon_sym_rtranif0] = ACTIONS(4400),
    [anon_sym_tran] = ACTIONS(4400),
    [anon_sym_rtran] = ACTIONS(4400),
    [anon_sym_generate] = ACTIONS(4400),
    [anon_sym_for] = ACTIONS(4400),
    [anon_sym_primitive] = ACTIONS(4400),
    [anon_sym_initial] = ACTIONS(4400),
    [anon_sym_assign] = ACTIONS(4400),
    [anon_sym_alias] = ACTIONS(4400),
    [anon_sym_always_comb] = ACTIONS(4400),
    [anon_sym_always_latch] = ACTIONS(4400),
    [anon_sym_always_ff] = ACTIONS(4400),
    [anon_sym_final] = ACTIONS(4400),
    [anon_sym_global] = ACTIONS(4400),
    [anon_sym_specify] = ACTIONS(4400),
    [anon_sym_LPAREN_STAR] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4398),
    [anon_sym_DOLLARunit] = ACTIONS(4398),
  },
  [693] = {
    [ts_builtin_sym_end] = ACTIONS(4404),
    [sym_simple_identifier] = ACTIONS(4406),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4404),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4404),
    [anon_sym_BQUOTE] = ACTIONS(4406),
    [aux_sym_id_directive_token1] = ACTIONS(4404),
    [aux_sym_id_directive_token2] = ACTIONS(4404),
    [aux_sym_id_directive_token3] = ACTIONS(4404),
    [aux_sym_id_directive_token4] = ACTIONS(4406),
    [aux_sym_zero_directive_token1] = ACTIONS(4404),
    [aux_sym_zero_directive_token2] = ACTIONS(4404),
    [aux_sym_zero_directive_token3] = ACTIONS(4404),
    [aux_sym_zero_directive_token4] = ACTIONS(4404),
    [aux_sym_zero_directive_token5] = ACTIONS(4404),
    [aux_sym_zero_directive_token6] = ACTIONS(4404),
    [aux_sym_zero_directive_token7] = ACTIONS(4404),
    [aux_sym_zero_directive_token8] = ACTIONS(4404),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4404),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4404),
    [anon_sym_wire] = ACTIONS(4406),
    [anon_sym_tri] = ACTIONS(4406),
    [anon_sym_tri0] = ACTIONS(4406),
    [anon_sym_tri1] = ACTIONS(4406),
    [anon_sym_wand] = ACTIONS(4406),
    [anon_sym_triand] = ACTIONS(4406),
    [anon_sym_wor] = ACTIONS(4406),
    [anon_sym_trior] = ACTIONS(4406),
    [anon_sym_trireg] = ACTIONS(4406),
    [anon_sym_uwire] = ACTIONS(4406),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4404),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4404),
    [aux_sym_begin_keywords_token1] = ACTIONS(4404),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym_endmodule] = ACTIONS(4406),
    [anon_sym_COLON] = ACTIONS(4408),
    [anon_sym_extern] = ACTIONS(4406),
    [anon_sym_module] = ACTIONS(4406),
    [anon_sym_macromodule] = ACTIONS(4406),
    [anon_sym_endinterface] = ACTIONS(4406),
    [anon_sym_interface] = ACTIONS(4406),
    [anon_sym_endprogram] = ACTIONS(4406),
    [anon_sym_program] = ACTIONS(4406),
    [anon_sym_checker] = ACTIONS(4406),
    [anon_sym_virtual] = ACTIONS(4406),
    [anon_sym_class] = ACTIONS(4406),
    [anon_sym_package] = ACTIONS(4406),
    [anon_sym_endpackage] = ACTIONS(4406),
    [anon_sym_timeunit] = ACTIONS(4406),
    [anon_sym_timeprecision] = ACTIONS(4406),
    [anon_sym_type] = ACTIONS(4406),
    [anon_sym_input] = ACTIONS(4406),
    [anon_sym_output] = ACTIONS(4406),
    [anon_sym_inout] = ACTIONS(4406),
    [anon_sym_ref] = ACTIONS(4406),
    [anon_sym_DOLLARfatal] = ACTIONS(4404),
    [anon_sym_DOLLARerror] = ACTIONS(4404),
    [anon_sym_DOLLARwarning] = ACTIONS(4404),
    [anon_sym_DOLLARinfo] = ACTIONS(4404),
    [anon_sym_default] = ACTIONS(4406),
    [anon_sym_clocking] = ACTIONS(4406),
    [anon_sym_defparam] = ACTIONS(4406),
    [anon_sym_bind] = ACTIONS(4406),
    [anon_sym_const] = ACTIONS(4406),
    [anon_sym_function] = ACTIONS(4406),
    [anon_sym_static] = ACTIONS(4406),
    [anon_sym_constraint] = ACTIONS(4406),
    [anon_sym_if] = ACTIONS(4406),
    [anon_sym_else] = ACTIONS(4406),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_localparam] = ACTIONS(4406),
    [anon_sym_parameter] = ACTIONS(4406),
    [anon_sym_specparam] = ACTIONS(4406),
    [anon_sym_var] = ACTIONS(4406),
    [anon_sym_import] = ACTIONS(4406),
    [anon_sym_export] = ACTIONS(4406),
    [anon_sym_genvar] = ACTIONS(4406),
    [anon_sym_interconnect] = ACTIONS(4406),
    [anon_sym_typedef] = ACTIONS(4406),
    [anon_sym_enum] = ACTIONS(4406),
    [anon_sym_struct] = ACTIONS(4406),
    [anon_sym_union] = ACTIONS(4406),
    [anon_sym_nettype] = ACTIONS(4406),
    [anon_sym_automatic] = ACTIONS(4406),
    [anon_sym_string] = ACTIONS(4406),
    [anon_sym_chandle] = ACTIONS(4406),
    [anon_sym_event] = ACTIONS(4406),
    [anon_sym_byte] = ACTIONS(4406),
    [anon_sym_shortint] = ACTIONS(4406),
    [anon_sym_int] = ACTIONS(4406),
    [anon_sym_longint] = ACTIONS(4406),
    [anon_sym_integer] = ACTIONS(4406),
    [anon_sym_time] = ACTIONS(4406),
    [anon_sym_bit] = ACTIONS(4406),
    [anon_sym_logic] = ACTIONS(4406),
    [anon_sym_reg] = ACTIONS(4406),
    [anon_sym_shortreal] = ACTIONS(4406),
    [anon_sym_real] = ACTIONS(4406),
    [anon_sym_realtime] = ACTIONS(4406),
    [anon_sym_supply0] = ACTIONS(4406),
    [anon_sym_supply1] = ACTIONS(4406),
    [anon_sym_signed] = ACTIONS(4406),
    [anon_sym_unsigned] = ACTIONS(4406),
    [anon_sym_task] = ACTIONS(4406),
    [anon_sym_modport] = ACTIONS(4406),
    [anon_sym_assert] = ACTIONS(4406),
    [anon_sym_property] = ACTIONS(4406),
    [anon_sym_assume] = ACTIONS(4406),
    [anon_sym_cover] = ACTIONS(4406),
    [anon_sym_sequence] = ACTIONS(4406),
    [anon_sym_restrict] = ACTIONS(4406),
    [anon_sym_not] = ACTIONS(4406),
    [anon_sym_or] = ACTIONS(4406),
    [anon_sym_and] = ACTIONS(4406),
    [anon_sym_case] = ACTIONS(4406),
    [anon_sym_always] = ACTIONS(4406),
    [anon_sym_covergroup] = ACTIONS(4406),
    [anon_sym_let] = ACTIONS(4406),
    [anon_sym_pulldown] = ACTIONS(4406),
    [anon_sym_pullup] = ACTIONS(4406),
    [anon_sym_cmos] = ACTIONS(4406),
    [anon_sym_rcmos] = ACTIONS(4406),
    [anon_sym_bufif0] = ACTIONS(4406),
    [anon_sym_bufif1] = ACTIONS(4406),
    [anon_sym_notif0] = ACTIONS(4406),
    [anon_sym_notif1] = ACTIONS(4406),
    [anon_sym_nmos] = ACTIONS(4406),
    [anon_sym_pmos] = ACTIONS(4406),
    [anon_sym_rnmos] = ACTIONS(4406),
    [anon_sym_rpmos] = ACTIONS(4406),
    [anon_sym_nand] = ACTIONS(4406),
    [anon_sym_nor] = ACTIONS(4406),
    [anon_sym_xor] = ACTIONS(4406),
    [anon_sym_xnor] = ACTIONS(4406),
    [anon_sym_buf] = ACTIONS(4406),
    [anon_sym_tranif0] = ACTIONS(4406),
    [anon_sym_tranif1] = ACTIONS(4406),
    [anon_sym_rtranif1] = ACTIONS(4406),
    [anon_sym_rtranif0] = ACTIONS(4406),
    [anon_sym_tran] = ACTIONS(4406),
    [anon_sym_rtran] = ACTIONS(4406),
    [anon_sym_generate] = ACTIONS(4406),
    [anon_sym_for] = ACTIONS(4406),
    [anon_sym_primitive] = ACTIONS(4406),
    [anon_sym_initial] = ACTIONS(4406),
    [anon_sym_assign] = ACTIONS(4406),
    [anon_sym_alias] = ACTIONS(4406),
    [anon_sym_always_comb] = ACTIONS(4406),
    [anon_sym_always_latch] = ACTIONS(4406),
    [anon_sym_always_ff] = ACTIONS(4406),
    [anon_sym_final] = ACTIONS(4406),
    [anon_sym_global] = ACTIONS(4406),
    [anon_sym_specify] = ACTIONS(4406),
    [anon_sym_LPAREN_STAR] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4404),
    [anon_sym_DOLLARunit] = ACTIONS(4404),
  },
  [694] = {
    [ts_builtin_sym_end] = ACTIONS(4410),
    [sym_simple_identifier] = ACTIONS(4412),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4410),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4410),
    [anon_sym_BQUOTE] = ACTIONS(4412),
    [aux_sym_id_directive_token1] = ACTIONS(4410),
    [aux_sym_id_directive_token2] = ACTIONS(4410),
    [aux_sym_id_directive_token3] = ACTIONS(4410),
    [aux_sym_id_directive_token4] = ACTIONS(4412),
    [aux_sym_zero_directive_token1] = ACTIONS(4410),
    [aux_sym_zero_directive_token2] = ACTIONS(4410),
    [aux_sym_zero_directive_token3] = ACTIONS(4410),
    [aux_sym_zero_directive_token4] = ACTIONS(4410),
    [aux_sym_zero_directive_token5] = ACTIONS(4410),
    [aux_sym_zero_directive_token6] = ACTIONS(4410),
    [aux_sym_zero_directive_token7] = ACTIONS(4410),
    [aux_sym_zero_directive_token8] = ACTIONS(4410),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4410),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4410),
    [anon_sym_wire] = ACTIONS(4412),
    [anon_sym_tri] = ACTIONS(4412),
    [anon_sym_tri0] = ACTIONS(4412),
    [anon_sym_tri1] = ACTIONS(4412),
    [anon_sym_wand] = ACTIONS(4412),
    [anon_sym_triand] = ACTIONS(4412),
    [anon_sym_wor] = ACTIONS(4412),
    [anon_sym_trior] = ACTIONS(4412),
    [anon_sym_trireg] = ACTIONS(4412),
    [anon_sym_uwire] = ACTIONS(4412),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4410),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4410),
    [aux_sym_begin_keywords_token1] = ACTIONS(4410),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym_endmodule] = ACTIONS(4412),
    [anon_sym_COLON] = ACTIONS(4414),
    [anon_sym_extern] = ACTIONS(4412),
    [anon_sym_module] = ACTIONS(4412),
    [anon_sym_macromodule] = ACTIONS(4412),
    [anon_sym_endinterface] = ACTIONS(4412),
    [anon_sym_interface] = ACTIONS(4412),
    [anon_sym_endprogram] = ACTIONS(4412),
    [anon_sym_program] = ACTIONS(4412),
    [anon_sym_checker] = ACTIONS(4412),
    [anon_sym_virtual] = ACTIONS(4412),
    [anon_sym_class] = ACTIONS(4412),
    [anon_sym_package] = ACTIONS(4412),
    [anon_sym_endpackage] = ACTIONS(4412),
    [anon_sym_timeunit] = ACTIONS(4412),
    [anon_sym_timeprecision] = ACTIONS(4412),
    [anon_sym_type] = ACTIONS(4412),
    [anon_sym_input] = ACTIONS(4412),
    [anon_sym_output] = ACTIONS(4412),
    [anon_sym_inout] = ACTIONS(4412),
    [anon_sym_ref] = ACTIONS(4412),
    [anon_sym_DOLLARfatal] = ACTIONS(4410),
    [anon_sym_DOLLARerror] = ACTIONS(4410),
    [anon_sym_DOLLARwarning] = ACTIONS(4410),
    [anon_sym_DOLLARinfo] = ACTIONS(4410),
    [anon_sym_default] = ACTIONS(4412),
    [anon_sym_clocking] = ACTIONS(4412),
    [anon_sym_defparam] = ACTIONS(4412),
    [anon_sym_bind] = ACTIONS(4412),
    [anon_sym_const] = ACTIONS(4412),
    [anon_sym_function] = ACTIONS(4412),
    [anon_sym_static] = ACTIONS(4412),
    [anon_sym_constraint] = ACTIONS(4412),
    [anon_sym_if] = ACTIONS(4412),
    [anon_sym_else] = ACTIONS(4412),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_localparam] = ACTIONS(4412),
    [anon_sym_parameter] = ACTIONS(4412),
    [anon_sym_specparam] = ACTIONS(4412),
    [anon_sym_var] = ACTIONS(4412),
    [anon_sym_import] = ACTIONS(4412),
    [anon_sym_export] = ACTIONS(4412),
    [anon_sym_genvar] = ACTIONS(4412),
    [anon_sym_interconnect] = ACTIONS(4412),
    [anon_sym_typedef] = ACTIONS(4412),
    [anon_sym_enum] = ACTIONS(4412),
    [anon_sym_struct] = ACTIONS(4412),
    [anon_sym_union] = ACTIONS(4412),
    [anon_sym_nettype] = ACTIONS(4412),
    [anon_sym_automatic] = ACTIONS(4412),
    [anon_sym_string] = ACTIONS(4412),
    [anon_sym_chandle] = ACTIONS(4412),
    [anon_sym_event] = ACTIONS(4412),
    [anon_sym_byte] = ACTIONS(4412),
    [anon_sym_shortint] = ACTIONS(4412),
    [anon_sym_int] = ACTIONS(4412),
    [anon_sym_longint] = ACTIONS(4412),
    [anon_sym_integer] = ACTIONS(4412),
    [anon_sym_time] = ACTIONS(4412),
    [anon_sym_bit] = ACTIONS(4412),
    [anon_sym_logic] = ACTIONS(4412),
    [anon_sym_reg] = ACTIONS(4412),
    [anon_sym_shortreal] = ACTIONS(4412),
    [anon_sym_real] = ACTIONS(4412),
    [anon_sym_realtime] = ACTIONS(4412),
    [anon_sym_supply0] = ACTIONS(4412),
    [anon_sym_supply1] = ACTIONS(4412),
    [anon_sym_signed] = ACTIONS(4412),
    [anon_sym_unsigned] = ACTIONS(4412),
    [anon_sym_task] = ACTIONS(4412),
    [anon_sym_modport] = ACTIONS(4412),
    [anon_sym_assert] = ACTIONS(4412),
    [anon_sym_property] = ACTIONS(4412),
    [anon_sym_assume] = ACTIONS(4412),
    [anon_sym_cover] = ACTIONS(4412),
    [anon_sym_sequence] = ACTIONS(4412),
    [anon_sym_restrict] = ACTIONS(4412),
    [anon_sym_not] = ACTIONS(4412),
    [anon_sym_or] = ACTIONS(4412),
    [anon_sym_and] = ACTIONS(4412),
    [anon_sym_case] = ACTIONS(4412),
    [anon_sym_always] = ACTIONS(4412),
    [anon_sym_covergroup] = ACTIONS(4412),
    [anon_sym_let] = ACTIONS(4412),
    [anon_sym_pulldown] = ACTIONS(4412),
    [anon_sym_pullup] = ACTIONS(4412),
    [anon_sym_cmos] = ACTIONS(4412),
    [anon_sym_rcmos] = ACTIONS(4412),
    [anon_sym_bufif0] = ACTIONS(4412),
    [anon_sym_bufif1] = ACTIONS(4412),
    [anon_sym_notif0] = ACTIONS(4412),
    [anon_sym_notif1] = ACTIONS(4412),
    [anon_sym_nmos] = ACTIONS(4412),
    [anon_sym_pmos] = ACTIONS(4412),
    [anon_sym_rnmos] = ACTIONS(4412),
    [anon_sym_rpmos] = ACTIONS(4412),
    [anon_sym_nand] = ACTIONS(4412),
    [anon_sym_nor] = ACTIONS(4412),
    [anon_sym_xor] = ACTIONS(4412),
    [anon_sym_xnor] = ACTIONS(4412),
    [anon_sym_buf] = ACTIONS(4412),
    [anon_sym_tranif0] = ACTIONS(4412),
    [anon_sym_tranif1] = ACTIONS(4412),
    [anon_sym_rtranif1] = ACTIONS(4412),
    [anon_sym_rtranif0] = ACTIONS(4412),
    [anon_sym_tran] = ACTIONS(4412),
    [anon_sym_rtran] = ACTIONS(4412),
    [anon_sym_generate] = ACTIONS(4412),
    [anon_sym_for] = ACTIONS(4412),
    [anon_sym_primitive] = ACTIONS(4412),
    [anon_sym_initial] = ACTIONS(4412),
    [anon_sym_assign] = ACTIONS(4412),
    [anon_sym_alias] = ACTIONS(4412),
    [anon_sym_always_comb] = ACTIONS(4412),
    [anon_sym_always_latch] = ACTIONS(4412),
    [anon_sym_always_ff] = ACTIONS(4412),
    [anon_sym_final] = ACTIONS(4412),
    [anon_sym_global] = ACTIONS(4412),
    [anon_sym_specify] = ACTIONS(4412),
    [anon_sym_LPAREN_STAR] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4410),
    [anon_sym_DOLLARunit] = ACTIONS(4410),
  },
  [695] = {
    [ts_builtin_sym_end] = ACTIONS(4416),
    [sym_simple_identifier] = ACTIONS(4418),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4416),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4416),
    [anon_sym_BQUOTE] = ACTIONS(4418),
    [aux_sym_id_directive_token1] = ACTIONS(4416),
    [aux_sym_id_directive_token2] = ACTIONS(4416),
    [aux_sym_id_directive_token3] = ACTIONS(4416),
    [aux_sym_id_directive_token4] = ACTIONS(4418),
    [aux_sym_zero_directive_token1] = ACTIONS(4416),
    [aux_sym_zero_directive_token2] = ACTIONS(4416),
    [aux_sym_zero_directive_token3] = ACTIONS(4416),
    [aux_sym_zero_directive_token4] = ACTIONS(4416),
    [aux_sym_zero_directive_token5] = ACTIONS(4416),
    [aux_sym_zero_directive_token6] = ACTIONS(4416),
    [aux_sym_zero_directive_token7] = ACTIONS(4416),
    [aux_sym_zero_directive_token8] = ACTIONS(4416),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4416),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4416),
    [anon_sym_wire] = ACTIONS(4418),
    [anon_sym_tri] = ACTIONS(4418),
    [anon_sym_tri0] = ACTIONS(4418),
    [anon_sym_tri1] = ACTIONS(4418),
    [anon_sym_wand] = ACTIONS(4418),
    [anon_sym_triand] = ACTIONS(4418),
    [anon_sym_wor] = ACTIONS(4418),
    [anon_sym_trior] = ACTIONS(4418),
    [anon_sym_trireg] = ACTIONS(4418),
    [anon_sym_uwire] = ACTIONS(4418),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4416),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4416),
    [aux_sym_begin_keywords_token1] = ACTIONS(4416),
    [anon_sym_SEMI] = ACTIONS(4416),
    [anon_sym_endmodule] = ACTIONS(4418),
    [anon_sym_COLON] = ACTIONS(4420),
    [anon_sym_extern] = ACTIONS(4418),
    [anon_sym_module] = ACTIONS(4418),
    [anon_sym_macromodule] = ACTIONS(4418),
    [anon_sym_endinterface] = ACTIONS(4418),
    [anon_sym_interface] = ACTIONS(4418),
    [anon_sym_endprogram] = ACTIONS(4418),
    [anon_sym_program] = ACTIONS(4418),
    [anon_sym_checker] = ACTIONS(4418),
    [anon_sym_virtual] = ACTIONS(4418),
    [anon_sym_class] = ACTIONS(4418),
    [anon_sym_package] = ACTIONS(4418),
    [anon_sym_endpackage] = ACTIONS(4418),
    [anon_sym_timeunit] = ACTIONS(4418),
    [anon_sym_timeprecision] = ACTIONS(4418),
    [anon_sym_type] = ACTIONS(4418),
    [anon_sym_input] = ACTIONS(4418),
    [anon_sym_output] = ACTIONS(4418),
    [anon_sym_inout] = ACTIONS(4418),
    [anon_sym_ref] = ACTIONS(4418),
    [anon_sym_DOLLARfatal] = ACTIONS(4416),
    [anon_sym_DOLLARerror] = ACTIONS(4416),
    [anon_sym_DOLLARwarning] = ACTIONS(4416),
    [anon_sym_DOLLARinfo] = ACTIONS(4416),
    [anon_sym_default] = ACTIONS(4418),
    [anon_sym_clocking] = ACTIONS(4418),
    [anon_sym_defparam] = ACTIONS(4418),
    [anon_sym_bind] = ACTIONS(4418),
    [anon_sym_const] = ACTIONS(4418),
    [anon_sym_function] = ACTIONS(4418),
    [anon_sym_static] = ACTIONS(4418),
    [anon_sym_constraint] = ACTIONS(4418),
    [anon_sym_if] = ACTIONS(4418),
    [anon_sym_else] = ACTIONS(4418),
    [anon_sym_LBRACK] = ACTIONS(4416),
    [anon_sym_localparam] = ACTIONS(4418),
    [anon_sym_parameter] = ACTIONS(4418),
    [anon_sym_specparam] = ACTIONS(4418),
    [anon_sym_var] = ACTIONS(4418),
    [anon_sym_import] = ACTIONS(4418),
    [anon_sym_export] = ACTIONS(4418),
    [anon_sym_genvar] = ACTIONS(4418),
    [anon_sym_interconnect] = ACTIONS(4418),
    [anon_sym_typedef] = ACTIONS(4418),
    [anon_sym_enum] = ACTIONS(4418),
    [anon_sym_struct] = ACTIONS(4418),
    [anon_sym_union] = ACTIONS(4418),
    [anon_sym_nettype] = ACTIONS(4418),
    [anon_sym_automatic] = ACTIONS(4418),
    [anon_sym_string] = ACTIONS(4418),
    [anon_sym_chandle] = ACTIONS(4418),
    [anon_sym_event] = ACTIONS(4418),
    [anon_sym_byte] = ACTIONS(4418),
    [anon_sym_shortint] = ACTIONS(4418),
    [anon_sym_int] = ACTIONS(4418),
    [anon_sym_longint] = ACTIONS(4418),
    [anon_sym_integer] = ACTIONS(4418),
    [anon_sym_time] = ACTIONS(4418),
    [anon_sym_bit] = ACTIONS(4418),
    [anon_sym_logic] = ACTIONS(4418),
    [anon_sym_reg] = ACTIONS(4418),
    [anon_sym_shortreal] = ACTIONS(4418),
    [anon_sym_real] = ACTIONS(4418),
    [anon_sym_realtime] = ACTIONS(4418),
    [anon_sym_supply0] = ACTIONS(4418),
    [anon_sym_supply1] = ACTIONS(4418),
    [anon_sym_signed] = ACTIONS(4418),
    [anon_sym_unsigned] = ACTIONS(4418),
    [anon_sym_task] = ACTIONS(4418),
    [anon_sym_modport] = ACTIONS(4418),
    [anon_sym_assert] = ACTIONS(4418),
    [anon_sym_property] = ACTIONS(4418),
    [anon_sym_assume] = ACTIONS(4418),
    [anon_sym_cover] = ACTIONS(4418),
    [anon_sym_sequence] = ACTIONS(4418),
    [anon_sym_restrict] = ACTIONS(4418),
    [anon_sym_not] = ACTIONS(4418),
    [anon_sym_or] = ACTIONS(4418),
    [anon_sym_and] = ACTIONS(4418),
    [anon_sym_case] = ACTIONS(4418),
    [anon_sym_always] = ACTIONS(4418),
    [anon_sym_covergroup] = ACTIONS(4418),
    [anon_sym_let] = ACTIONS(4418),
    [anon_sym_pulldown] = ACTIONS(4418),
    [anon_sym_pullup] = ACTIONS(4418),
    [anon_sym_cmos] = ACTIONS(4418),
    [anon_sym_rcmos] = ACTIONS(4418),
    [anon_sym_bufif0] = ACTIONS(4418),
    [anon_sym_bufif1] = ACTIONS(4418),
    [anon_sym_notif0] = ACTIONS(4418),
    [anon_sym_notif1] = ACTIONS(4418),
    [anon_sym_nmos] = ACTIONS(4418),
    [anon_sym_pmos] = ACTIONS(4418),
    [anon_sym_rnmos] = ACTIONS(4418),
    [anon_sym_rpmos] = ACTIONS(4418),
    [anon_sym_nand] = ACTIONS(4418),
    [anon_sym_nor] = ACTIONS(4418),
    [anon_sym_xor] = ACTIONS(4418),
    [anon_sym_xnor] = ACTIONS(4418),
    [anon_sym_buf] = ACTIONS(4418),
    [anon_sym_tranif0] = ACTIONS(4418),
    [anon_sym_tranif1] = ACTIONS(4418),
    [anon_sym_rtranif1] = ACTIONS(4418),
    [anon_sym_rtranif0] = ACTIONS(4418),
    [anon_sym_tran] = ACTIONS(4418),
    [anon_sym_rtran] = ACTIONS(4418),
    [anon_sym_generate] = ACTIONS(4418),
    [anon_sym_for] = ACTIONS(4418),
    [anon_sym_primitive] = ACTIONS(4418),
    [anon_sym_initial] = ACTIONS(4418),
    [anon_sym_assign] = ACTIONS(4418),
    [anon_sym_alias] = ACTIONS(4418),
    [anon_sym_always_comb] = ACTIONS(4418),
    [anon_sym_always_latch] = ACTIONS(4418),
    [anon_sym_always_ff] = ACTIONS(4418),
    [anon_sym_final] = ACTIONS(4418),
    [anon_sym_global] = ACTIONS(4418),
    [anon_sym_specify] = ACTIONS(4418),
    [anon_sym_LPAREN_STAR] = ACTIONS(4416),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4416),
    [anon_sym_DOLLARunit] = ACTIONS(4416),
  },
  [696] = {
    [ts_builtin_sym_end] = ACTIONS(4422),
    [sym_simple_identifier] = ACTIONS(4424),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4422),
    [anon_sym_BQUOTE] = ACTIONS(4424),
    [aux_sym_id_directive_token1] = ACTIONS(4422),
    [aux_sym_id_directive_token2] = ACTIONS(4422),
    [aux_sym_id_directive_token3] = ACTIONS(4422),
    [aux_sym_id_directive_token4] = ACTIONS(4424),
    [aux_sym_zero_directive_token1] = ACTIONS(4422),
    [aux_sym_zero_directive_token2] = ACTIONS(4422),
    [aux_sym_zero_directive_token3] = ACTIONS(4422),
    [aux_sym_zero_directive_token4] = ACTIONS(4422),
    [aux_sym_zero_directive_token5] = ACTIONS(4422),
    [aux_sym_zero_directive_token6] = ACTIONS(4422),
    [aux_sym_zero_directive_token7] = ACTIONS(4422),
    [aux_sym_zero_directive_token8] = ACTIONS(4422),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4422),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4422),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_begin_keywords_token1] = ACTIONS(4422),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_endmodule] = ACTIONS(4424),
    [anon_sym_COLON] = ACTIONS(4426),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_module] = ACTIONS(4424),
    [anon_sym_macromodule] = ACTIONS(4424),
    [anon_sym_endinterface] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_endprogram] = ACTIONS(4424),
    [anon_sym_program] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_package] = ACTIONS(4424),
    [anon_sym_endpackage] = ACTIONS(4424),
    [anon_sym_timeunit] = ACTIONS(4424),
    [anon_sym_timeprecision] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_input] = ACTIONS(4424),
    [anon_sym_output] = ACTIONS(4424),
    [anon_sym_inout] = ACTIONS(4424),
    [anon_sym_ref] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_specparam] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_modport] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_primitive] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_specify] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [697] = {
    [ts_builtin_sym_end] = ACTIONS(4428),
    [sym_simple_identifier] = ACTIONS(4430),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4428),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4428),
    [anon_sym_BQUOTE] = ACTIONS(4430),
    [aux_sym_id_directive_token1] = ACTIONS(4428),
    [aux_sym_id_directive_token2] = ACTIONS(4428),
    [aux_sym_id_directive_token3] = ACTIONS(4428),
    [aux_sym_id_directive_token4] = ACTIONS(4430),
    [aux_sym_zero_directive_token1] = ACTIONS(4428),
    [aux_sym_zero_directive_token2] = ACTIONS(4428),
    [aux_sym_zero_directive_token3] = ACTIONS(4428),
    [aux_sym_zero_directive_token4] = ACTIONS(4428),
    [aux_sym_zero_directive_token5] = ACTIONS(4428),
    [aux_sym_zero_directive_token6] = ACTIONS(4428),
    [aux_sym_zero_directive_token7] = ACTIONS(4428),
    [aux_sym_zero_directive_token8] = ACTIONS(4428),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4428),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4428),
    [anon_sym_wire] = ACTIONS(4430),
    [anon_sym_tri] = ACTIONS(4430),
    [anon_sym_tri0] = ACTIONS(4430),
    [anon_sym_tri1] = ACTIONS(4430),
    [anon_sym_wand] = ACTIONS(4430),
    [anon_sym_triand] = ACTIONS(4430),
    [anon_sym_wor] = ACTIONS(4430),
    [anon_sym_trior] = ACTIONS(4430),
    [anon_sym_trireg] = ACTIONS(4430),
    [anon_sym_uwire] = ACTIONS(4430),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4428),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4428),
    [aux_sym_begin_keywords_token1] = ACTIONS(4428),
    [anon_sym_SEMI] = ACTIONS(4428),
    [anon_sym_endmodule] = ACTIONS(4430),
    [anon_sym_COLON] = ACTIONS(4432),
    [anon_sym_extern] = ACTIONS(4430),
    [anon_sym_module] = ACTIONS(4430),
    [anon_sym_macromodule] = ACTIONS(4430),
    [anon_sym_endinterface] = ACTIONS(4430),
    [anon_sym_interface] = ACTIONS(4430),
    [anon_sym_endprogram] = ACTIONS(4430),
    [anon_sym_program] = ACTIONS(4430),
    [anon_sym_checker] = ACTIONS(4430),
    [anon_sym_virtual] = ACTIONS(4430),
    [anon_sym_class] = ACTIONS(4430),
    [anon_sym_package] = ACTIONS(4430),
    [anon_sym_endpackage] = ACTIONS(4430),
    [anon_sym_timeunit] = ACTIONS(4430),
    [anon_sym_timeprecision] = ACTIONS(4430),
    [anon_sym_type] = ACTIONS(4430),
    [anon_sym_input] = ACTIONS(4430),
    [anon_sym_output] = ACTIONS(4430),
    [anon_sym_inout] = ACTIONS(4430),
    [anon_sym_ref] = ACTIONS(4430),
    [anon_sym_DOLLARfatal] = ACTIONS(4428),
    [anon_sym_DOLLARerror] = ACTIONS(4428),
    [anon_sym_DOLLARwarning] = ACTIONS(4428),
    [anon_sym_DOLLARinfo] = ACTIONS(4428),
    [anon_sym_default] = ACTIONS(4430),
    [anon_sym_clocking] = ACTIONS(4430),
    [anon_sym_defparam] = ACTIONS(4430),
    [anon_sym_bind] = ACTIONS(4430),
    [anon_sym_const] = ACTIONS(4430),
    [anon_sym_function] = ACTIONS(4430),
    [anon_sym_static] = ACTIONS(4430),
    [anon_sym_constraint] = ACTIONS(4430),
    [anon_sym_if] = ACTIONS(4430),
    [anon_sym_else] = ACTIONS(4430),
    [anon_sym_LBRACK] = ACTIONS(4428),
    [anon_sym_localparam] = ACTIONS(4430),
    [anon_sym_parameter] = ACTIONS(4430),
    [anon_sym_specparam] = ACTIONS(4430),
    [anon_sym_var] = ACTIONS(4430),
    [anon_sym_import] = ACTIONS(4430),
    [anon_sym_export] = ACTIONS(4430),
    [anon_sym_genvar] = ACTIONS(4430),
    [anon_sym_interconnect] = ACTIONS(4430),
    [anon_sym_typedef] = ACTIONS(4430),
    [anon_sym_enum] = ACTIONS(4430),
    [anon_sym_struct] = ACTIONS(4430),
    [anon_sym_union] = ACTIONS(4430),
    [anon_sym_nettype] = ACTIONS(4430),
    [anon_sym_automatic] = ACTIONS(4430),
    [anon_sym_string] = ACTIONS(4430),
    [anon_sym_chandle] = ACTIONS(4430),
    [anon_sym_event] = ACTIONS(4430),
    [anon_sym_byte] = ACTIONS(4430),
    [anon_sym_shortint] = ACTIONS(4430),
    [anon_sym_int] = ACTIONS(4430),
    [anon_sym_longint] = ACTIONS(4430),
    [anon_sym_integer] = ACTIONS(4430),
    [anon_sym_time] = ACTIONS(4430),
    [anon_sym_bit] = ACTIONS(4430),
    [anon_sym_logic] = ACTIONS(4430),
    [anon_sym_reg] = ACTIONS(4430),
    [anon_sym_shortreal] = ACTIONS(4430),
    [anon_sym_real] = ACTIONS(4430),
    [anon_sym_realtime] = ACTIONS(4430),
    [anon_sym_supply0] = ACTIONS(4430),
    [anon_sym_supply1] = ACTIONS(4430),
    [anon_sym_signed] = ACTIONS(4430),
    [anon_sym_unsigned] = ACTIONS(4430),
    [anon_sym_task] = ACTIONS(4430),
    [anon_sym_modport] = ACTIONS(4430),
    [anon_sym_assert] = ACTIONS(4430),
    [anon_sym_property] = ACTIONS(4430),
    [anon_sym_assume] = ACTIONS(4430),
    [anon_sym_cover] = ACTIONS(4430),
    [anon_sym_sequence] = ACTIONS(4430),
    [anon_sym_restrict] = ACTIONS(4430),
    [anon_sym_not] = ACTIONS(4430),
    [anon_sym_or] = ACTIONS(4430),
    [anon_sym_and] = ACTIONS(4430),
    [anon_sym_case] = ACTIONS(4430),
    [anon_sym_always] = ACTIONS(4430),
    [anon_sym_covergroup] = ACTIONS(4430),
    [anon_sym_let] = ACTIONS(4430),
    [anon_sym_pulldown] = ACTIONS(4430),
    [anon_sym_pullup] = ACTIONS(4430),
    [anon_sym_cmos] = ACTIONS(4430),
    [anon_sym_rcmos] = ACTIONS(4430),
    [anon_sym_bufif0] = ACTIONS(4430),
    [anon_sym_bufif1] = ACTIONS(4430),
    [anon_sym_notif0] = ACTIONS(4430),
    [anon_sym_notif1] = ACTIONS(4430),
    [anon_sym_nmos] = ACTIONS(4430),
    [anon_sym_pmos] = ACTIONS(4430),
    [anon_sym_rnmos] = ACTIONS(4430),
    [anon_sym_rpmos] = ACTIONS(4430),
    [anon_sym_nand] = ACTIONS(4430),
    [anon_sym_nor] = ACTIONS(4430),
    [anon_sym_xor] = ACTIONS(4430),
    [anon_sym_xnor] = ACTIONS(4430),
    [anon_sym_buf] = ACTIONS(4430),
    [anon_sym_tranif0] = ACTIONS(4430),
    [anon_sym_tranif1] = ACTIONS(4430),
    [anon_sym_rtranif1] = ACTIONS(4430),
    [anon_sym_rtranif0] = ACTIONS(4430),
    [anon_sym_tran] = ACTIONS(4430),
    [anon_sym_rtran] = ACTIONS(4430),
    [anon_sym_generate] = ACTIONS(4430),
    [anon_sym_for] = ACTIONS(4430),
    [anon_sym_primitive] = ACTIONS(4430),
    [anon_sym_initial] = ACTIONS(4430),
    [anon_sym_assign] = ACTIONS(4430),
    [anon_sym_alias] = ACTIONS(4430),
    [anon_sym_always_comb] = ACTIONS(4430),
    [anon_sym_always_latch] = ACTIONS(4430),
    [anon_sym_always_ff] = ACTIONS(4430),
    [anon_sym_final] = ACTIONS(4430),
    [anon_sym_global] = ACTIONS(4430),
    [anon_sym_specify] = ACTIONS(4430),
    [anon_sym_LPAREN_STAR] = ACTIONS(4428),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4428),
    [anon_sym_DOLLARunit] = ACTIONS(4428),
  },
  [698] = {
    [ts_builtin_sym_end] = ACTIONS(4434),
    [sym_simple_identifier] = ACTIONS(4436),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4434),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4434),
    [anon_sym_BQUOTE] = ACTIONS(4436),
    [aux_sym_id_directive_token1] = ACTIONS(4434),
    [aux_sym_id_directive_token2] = ACTIONS(4434),
    [aux_sym_id_directive_token3] = ACTIONS(4434),
    [aux_sym_id_directive_token4] = ACTIONS(4436),
    [aux_sym_zero_directive_token1] = ACTIONS(4434),
    [aux_sym_zero_directive_token2] = ACTIONS(4434),
    [aux_sym_zero_directive_token3] = ACTIONS(4434),
    [aux_sym_zero_directive_token4] = ACTIONS(4434),
    [aux_sym_zero_directive_token5] = ACTIONS(4434),
    [aux_sym_zero_directive_token6] = ACTIONS(4434),
    [aux_sym_zero_directive_token7] = ACTIONS(4434),
    [aux_sym_zero_directive_token8] = ACTIONS(4434),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4434),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4434),
    [anon_sym_wire] = ACTIONS(4436),
    [anon_sym_tri] = ACTIONS(4436),
    [anon_sym_tri0] = ACTIONS(4436),
    [anon_sym_tri1] = ACTIONS(4436),
    [anon_sym_wand] = ACTIONS(4436),
    [anon_sym_triand] = ACTIONS(4436),
    [anon_sym_wor] = ACTIONS(4436),
    [anon_sym_trior] = ACTIONS(4436),
    [anon_sym_trireg] = ACTIONS(4436),
    [anon_sym_uwire] = ACTIONS(4436),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4434),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4434),
    [aux_sym_begin_keywords_token1] = ACTIONS(4434),
    [anon_sym_SEMI] = ACTIONS(4434),
    [anon_sym_endmodule] = ACTIONS(4436),
    [anon_sym_COLON] = ACTIONS(4438),
    [anon_sym_extern] = ACTIONS(4436),
    [anon_sym_module] = ACTIONS(4436),
    [anon_sym_macromodule] = ACTIONS(4436),
    [anon_sym_endinterface] = ACTIONS(4436),
    [anon_sym_interface] = ACTIONS(4436),
    [anon_sym_endprogram] = ACTIONS(4436),
    [anon_sym_program] = ACTIONS(4436),
    [anon_sym_checker] = ACTIONS(4436),
    [anon_sym_virtual] = ACTIONS(4436),
    [anon_sym_class] = ACTIONS(4436),
    [anon_sym_package] = ACTIONS(4436),
    [anon_sym_endpackage] = ACTIONS(4436),
    [anon_sym_timeunit] = ACTIONS(4436),
    [anon_sym_timeprecision] = ACTIONS(4436),
    [anon_sym_type] = ACTIONS(4436),
    [anon_sym_input] = ACTIONS(4436),
    [anon_sym_output] = ACTIONS(4436),
    [anon_sym_inout] = ACTIONS(4436),
    [anon_sym_ref] = ACTIONS(4436),
    [anon_sym_DOLLARfatal] = ACTIONS(4434),
    [anon_sym_DOLLARerror] = ACTIONS(4434),
    [anon_sym_DOLLARwarning] = ACTIONS(4434),
    [anon_sym_DOLLARinfo] = ACTIONS(4434),
    [anon_sym_default] = ACTIONS(4436),
    [anon_sym_clocking] = ACTIONS(4436),
    [anon_sym_defparam] = ACTIONS(4436),
    [anon_sym_bind] = ACTIONS(4436),
    [anon_sym_const] = ACTIONS(4436),
    [anon_sym_function] = ACTIONS(4436),
    [anon_sym_static] = ACTIONS(4436),
    [anon_sym_constraint] = ACTIONS(4436),
    [anon_sym_if] = ACTIONS(4436),
    [anon_sym_else] = ACTIONS(4436),
    [anon_sym_LBRACK] = ACTIONS(4434),
    [anon_sym_localparam] = ACTIONS(4436),
    [anon_sym_parameter] = ACTIONS(4436),
    [anon_sym_specparam] = ACTIONS(4436),
    [anon_sym_var] = ACTIONS(4436),
    [anon_sym_import] = ACTIONS(4436),
    [anon_sym_export] = ACTIONS(4436),
    [anon_sym_genvar] = ACTIONS(4436),
    [anon_sym_interconnect] = ACTIONS(4436),
    [anon_sym_typedef] = ACTIONS(4436),
    [anon_sym_enum] = ACTIONS(4436),
    [anon_sym_struct] = ACTIONS(4436),
    [anon_sym_union] = ACTIONS(4436),
    [anon_sym_nettype] = ACTIONS(4436),
    [anon_sym_automatic] = ACTIONS(4436),
    [anon_sym_string] = ACTIONS(4436),
    [anon_sym_chandle] = ACTIONS(4436),
    [anon_sym_event] = ACTIONS(4436),
    [anon_sym_byte] = ACTIONS(4436),
    [anon_sym_shortint] = ACTIONS(4436),
    [anon_sym_int] = ACTIONS(4436),
    [anon_sym_longint] = ACTIONS(4436),
    [anon_sym_integer] = ACTIONS(4436),
    [anon_sym_time] = ACTIONS(4436),
    [anon_sym_bit] = ACTIONS(4436),
    [anon_sym_logic] = ACTIONS(4436),
    [anon_sym_reg] = ACTIONS(4436),
    [anon_sym_shortreal] = ACTIONS(4436),
    [anon_sym_real] = ACTIONS(4436),
    [anon_sym_realtime] = ACTIONS(4436),
    [anon_sym_supply0] = ACTIONS(4436),
    [anon_sym_supply1] = ACTIONS(4436),
    [anon_sym_signed] = ACTIONS(4436),
    [anon_sym_unsigned] = ACTIONS(4436),
    [anon_sym_task] = ACTIONS(4436),
    [anon_sym_modport] = ACTIONS(4436),
    [anon_sym_assert] = ACTIONS(4436),
    [anon_sym_property] = ACTIONS(4436),
    [anon_sym_assume] = ACTIONS(4436),
    [anon_sym_cover] = ACTIONS(4436),
    [anon_sym_sequence] = ACTIONS(4436),
    [anon_sym_restrict] = ACTIONS(4436),
    [anon_sym_not] = ACTIONS(4436),
    [anon_sym_or] = ACTIONS(4436),
    [anon_sym_and] = ACTIONS(4436),
    [anon_sym_case] = ACTIONS(4436),
    [anon_sym_always] = ACTIONS(4436),
    [anon_sym_covergroup] = ACTIONS(4436),
    [anon_sym_let] = ACTIONS(4436),
    [anon_sym_pulldown] = ACTIONS(4436),
    [anon_sym_pullup] = ACTIONS(4436),
    [anon_sym_cmos] = ACTIONS(4436),
    [anon_sym_rcmos] = ACTIONS(4436),
    [anon_sym_bufif0] = ACTIONS(4436),
    [anon_sym_bufif1] = ACTIONS(4436),
    [anon_sym_notif0] = ACTIONS(4436),
    [anon_sym_notif1] = ACTIONS(4436),
    [anon_sym_nmos] = ACTIONS(4436),
    [anon_sym_pmos] = ACTIONS(4436),
    [anon_sym_rnmos] = ACTIONS(4436),
    [anon_sym_rpmos] = ACTIONS(4436),
    [anon_sym_nand] = ACTIONS(4436),
    [anon_sym_nor] = ACTIONS(4436),
    [anon_sym_xor] = ACTIONS(4436),
    [anon_sym_xnor] = ACTIONS(4436),
    [anon_sym_buf] = ACTIONS(4436),
    [anon_sym_tranif0] = ACTIONS(4436),
    [anon_sym_tranif1] = ACTIONS(4436),
    [anon_sym_rtranif1] = ACTIONS(4436),
    [anon_sym_rtranif0] = ACTIONS(4436),
    [anon_sym_tran] = ACTIONS(4436),
    [anon_sym_rtran] = ACTIONS(4436),
    [anon_sym_generate] = ACTIONS(4436),
    [anon_sym_for] = ACTIONS(4436),
    [anon_sym_primitive] = ACTIONS(4436),
    [anon_sym_initial] = ACTIONS(4436),
    [anon_sym_assign] = ACTIONS(4436),
    [anon_sym_alias] = ACTIONS(4436),
    [anon_sym_always_comb] = ACTIONS(4436),
    [anon_sym_always_latch] = ACTIONS(4436),
    [anon_sym_always_ff] = ACTIONS(4436),
    [anon_sym_final] = ACTIONS(4436),
    [anon_sym_global] = ACTIONS(4436),
    [anon_sym_specify] = ACTIONS(4436),
    [anon_sym_LPAREN_STAR] = ACTIONS(4434),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4434),
    [anon_sym_DOLLARunit] = ACTIONS(4434),
  },
  [699] = {
    [ts_builtin_sym_end] = ACTIONS(4440),
    [sym_simple_identifier] = ACTIONS(4442),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4440),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4440),
    [anon_sym_BQUOTE] = ACTIONS(4442),
    [aux_sym_id_directive_token1] = ACTIONS(4440),
    [aux_sym_id_directive_token2] = ACTIONS(4440),
    [aux_sym_id_directive_token3] = ACTIONS(4440),
    [aux_sym_id_directive_token4] = ACTIONS(4442),
    [aux_sym_zero_directive_token1] = ACTIONS(4440),
    [aux_sym_zero_directive_token2] = ACTIONS(4440),
    [aux_sym_zero_directive_token3] = ACTIONS(4440),
    [aux_sym_zero_directive_token4] = ACTIONS(4440),
    [aux_sym_zero_directive_token5] = ACTIONS(4440),
    [aux_sym_zero_directive_token6] = ACTIONS(4440),
    [aux_sym_zero_directive_token7] = ACTIONS(4440),
    [aux_sym_zero_directive_token8] = ACTIONS(4440),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4440),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4440),
    [anon_sym_wire] = ACTIONS(4442),
    [anon_sym_tri] = ACTIONS(4442),
    [anon_sym_tri0] = ACTIONS(4442),
    [anon_sym_tri1] = ACTIONS(4442),
    [anon_sym_wand] = ACTIONS(4442),
    [anon_sym_triand] = ACTIONS(4442),
    [anon_sym_wor] = ACTIONS(4442),
    [anon_sym_trior] = ACTIONS(4442),
    [anon_sym_trireg] = ACTIONS(4442),
    [anon_sym_uwire] = ACTIONS(4442),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4440),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4440),
    [aux_sym_begin_keywords_token1] = ACTIONS(4440),
    [anon_sym_SEMI] = ACTIONS(4440),
    [anon_sym_endmodule] = ACTIONS(4442),
    [anon_sym_COLON] = ACTIONS(4444),
    [anon_sym_extern] = ACTIONS(4442),
    [anon_sym_module] = ACTIONS(4442),
    [anon_sym_macromodule] = ACTIONS(4442),
    [anon_sym_endinterface] = ACTIONS(4442),
    [anon_sym_interface] = ACTIONS(4442),
    [anon_sym_endprogram] = ACTIONS(4442),
    [anon_sym_program] = ACTIONS(4442),
    [anon_sym_checker] = ACTIONS(4442),
    [anon_sym_virtual] = ACTIONS(4442),
    [anon_sym_class] = ACTIONS(4442),
    [anon_sym_package] = ACTIONS(4442),
    [anon_sym_endpackage] = ACTIONS(4442),
    [anon_sym_timeunit] = ACTIONS(4442),
    [anon_sym_timeprecision] = ACTIONS(4442),
    [anon_sym_type] = ACTIONS(4442),
    [anon_sym_input] = ACTIONS(4442),
    [anon_sym_output] = ACTIONS(4442),
    [anon_sym_inout] = ACTIONS(4442),
    [anon_sym_ref] = ACTIONS(4442),
    [anon_sym_DOLLARfatal] = ACTIONS(4440),
    [anon_sym_DOLLARerror] = ACTIONS(4440),
    [anon_sym_DOLLARwarning] = ACTIONS(4440),
    [anon_sym_DOLLARinfo] = ACTIONS(4440),
    [anon_sym_default] = ACTIONS(4442),
    [anon_sym_clocking] = ACTIONS(4442),
    [anon_sym_defparam] = ACTIONS(4442),
    [anon_sym_bind] = ACTIONS(4442),
    [anon_sym_const] = ACTIONS(4442),
    [anon_sym_function] = ACTIONS(4442),
    [anon_sym_static] = ACTIONS(4442),
    [anon_sym_constraint] = ACTIONS(4442),
    [anon_sym_if] = ACTIONS(4442),
    [anon_sym_else] = ACTIONS(4442),
    [anon_sym_LBRACK] = ACTIONS(4440),
    [anon_sym_localparam] = ACTIONS(4442),
    [anon_sym_parameter] = ACTIONS(4442),
    [anon_sym_specparam] = ACTIONS(4442),
    [anon_sym_var] = ACTIONS(4442),
    [anon_sym_import] = ACTIONS(4442),
    [anon_sym_export] = ACTIONS(4442),
    [anon_sym_genvar] = ACTIONS(4442),
    [anon_sym_interconnect] = ACTIONS(4442),
    [anon_sym_typedef] = ACTIONS(4442),
    [anon_sym_enum] = ACTIONS(4442),
    [anon_sym_struct] = ACTIONS(4442),
    [anon_sym_union] = ACTIONS(4442),
    [anon_sym_nettype] = ACTIONS(4442),
    [anon_sym_automatic] = ACTIONS(4442),
    [anon_sym_string] = ACTIONS(4442),
    [anon_sym_chandle] = ACTIONS(4442),
    [anon_sym_event] = ACTIONS(4442),
    [anon_sym_byte] = ACTIONS(4442),
    [anon_sym_shortint] = ACTIONS(4442),
    [anon_sym_int] = ACTIONS(4442),
    [anon_sym_longint] = ACTIONS(4442),
    [anon_sym_integer] = ACTIONS(4442),
    [anon_sym_time] = ACTIONS(4442),
    [anon_sym_bit] = ACTIONS(4442),
    [anon_sym_logic] = ACTIONS(4442),
    [anon_sym_reg] = ACTIONS(4442),
    [anon_sym_shortreal] = ACTIONS(4442),
    [anon_sym_real] = ACTIONS(4442),
    [anon_sym_realtime] = ACTIONS(4442),
    [anon_sym_supply0] = ACTIONS(4442),
    [anon_sym_supply1] = ACTIONS(4442),
    [anon_sym_signed] = ACTIONS(4442),
    [anon_sym_unsigned] = ACTIONS(4442),
    [anon_sym_task] = ACTIONS(4442),
    [anon_sym_modport] = ACTIONS(4442),
    [anon_sym_assert] = ACTIONS(4442),
    [anon_sym_property] = ACTIONS(4442),
    [anon_sym_assume] = ACTIONS(4442),
    [anon_sym_cover] = ACTIONS(4442),
    [anon_sym_sequence] = ACTIONS(4442),
    [anon_sym_restrict] = ACTIONS(4442),
    [anon_sym_not] = ACTIONS(4442),
    [anon_sym_or] = ACTIONS(4442),
    [anon_sym_and] = ACTIONS(4442),
    [anon_sym_case] = ACTIONS(4442),
    [anon_sym_always] = ACTIONS(4442),
    [anon_sym_covergroup] = ACTIONS(4442),
    [anon_sym_let] = ACTIONS(4442),
    [anon_sym_pulldown] = ACTIONS(4442),
    [anon_sym_pullup] = ACTIONS(4442),
    [anon_sym_cmos] = ACTIONS(4442),
    [anon_sym_rcmos] = ACTIONS(4442),
    [anon_sym_bufif0] = ACTIONS(4442),
    [anon_sym_bufif1] = ACTIONS(4442),
    [anon_sym_notif0] = ACTIONS(4442),
    [anon_sym_notif1] = ACTIONS(4442),
    [anon_sym_nmos] = ACTIONS(4442),
    [anon_sym_pmos] = ACTIONS(4442),
    [anon_sym_rnmos] = ACTIONS(4442),
    [anon_sym_rpmos] = ACTIONS(4442),
    [anon_sym_nand] = ACTIONS(4442),
    [anon_sym_nor] = ACTIONS(4442),
    [anon_sym_xor] = ACTIONS(4442),
    [anon_sym_xnor] = ACTIONS(4442),
    [anon_sym_buf] = ACTIONS(4442),
    [anon_sym_tranif0] = ACTIONS(4442),
    [anon_sym_tranif1] = ACTIONS(4442),
    [anon_sym_rtranif1] = ACTIONS(4442),
    [anon_sym_rtranif0] = ACTIONS(4442),
    [anon_sym_tran] = ACTIONS(4442),
    [anon_sym_rtran] = ACTIONS(4442),
    [anon_sym_generate] = ACTIONS(4442),
    [anon_sym_for] = ACTIONS(4442),
    [anon_sym_primitive] = ACTIONS(4442),
    [anon_sym_initial] = ACTIONS(4442),
    [anon_sym_assign] = ACTIONS(4442),
    [anon_sym_alias] = ACTIONS(4442),
    [anon_sym_always_comb] = ACTIONS(4442),
    [anon_sym_always_latch] = ACTIONS(4442),
    [anon_sym_always_ff] = ACTIONS(4442),
    [anon_sym_final] = ACTIONS(4442),
    [anon_sym_global] = ACTIONS(4442),
    [anon_sym_specify] = ACTIONS(4442),
    [anon_sym_LPAREN_STAR] = ACTIONS(4440),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4440),
    [anon_sym_DOLLARunit] = ACTIONS(4440),
  },
  [700] = {
    [ts_builtin_sym_end] = ACTIONS(4446),
    [sym_simple_identifier] = ACTIONS(4448),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4446),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4446),
    [anon_sym_BQUOTE] = ACTIONS(4448),
    [aux_sym_id_directive_token1] = ACTIONS(4446),
    [aux_sym_id_directive_token2] = ACTIONS(4446),
    [aux_sym_id_directive_token3] = ACTIONS(4446),
    [aux_sym_id_directive_token4] = ACTIONS(4448),
    [aux_sym_zero_directive_token1] = ACTIONS(4446),
    [aux_sym_zero_directive_token2] = ACTIONS(4446),
    [aux_sym_zero_directive_token3] = ACTIONS(4446),
    [aux_sym_zero_directive_token4] = ACTIONS(4446),
    [aux_sym_zero_directive_token5] = ACTIONS(4446),
    [aux_sym_zero_directive_token6] = ACTIONS(4446),
    [aux_sym_zero_directive_token7] = ACTIONS(4446),
    [aux_sym_zero_directive_token8] = ACTIONS(4446),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4446),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4446),
    [anon_sym_wire] = ACTIONS(4448),
    [anon_sym_tri] = ACTIONS(4448),
    [anon_sym_tri0] = ACTIONS(4448),
    [anon_sym_tri1] = ACTIONS(4448),
    [anon_sym_wand] = ACTIONS(4448),
    [anon_sym_triand] = ACTIONS(4448),
    [anon_sym_wor] = ACTIONS(4448),
    [anon_sym_trior] = ACTIONS(4448),
    [anon_sym_trireg] = ACTIONS(4448),
    [anon_sym_uwire] = ACTIONS(4448),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4446),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4446),
    [aux_sym_begin_keywords_token1] = ACTIONS(4446),
    [anon_sym_SEMI] = ACTIONS(4446),
    [anon_sym_endmodule] = ACTIONS(4448),
    [anon_sym_COLON] = ACTIONS(4450),
    [anon_sym_extern] = ACTIONS(4448),
    [anon_sym_module] = ACTIONS(4448),
    [anon_sym_macromodule] = ACTIONS(4448),
    [anon_sym_endinterface] = ACTIONS(4448),
    [anon_sym_interface] = ACTIONS(4448),
    [anon_sym_endprogram] = ACTIONS(4448),
    [anon_sym_program] = ACTIONS(4448),
    [anon_sym_checker] = ACTIONS(4448),
    [anon_sym_virtual] = ACTIONS(4448),
    [anon_sym_class] = ACTIONS(4448),
    [anon_sym_package] = ACTIONS(4448),
    [anon_sym_endpackage] = ACTIONS(4448),
    [anon_sym_timeunit] = ACTIONS(4448),
    [anon_sym_timeprecision] = ACTIONS(4448),
    [anon_sym_type] = ACTIONS(4448),
    [anon_sym_input] = ACTIONS(4448),
    [anon_sym_output] = ACTIONS(4448),
    [anon_sym_inout] = ACTIONS(4448),
    [anon_sym_ref] = ACTIONS(4448),
    [anon_sym_DOLLARfatal] = ACTIONS(4446),
    [anon_sym_DOLLARerror] = ACTIONS(4446),
    [anon_sym_DOLLARwarning] = ACTIONS(4446),
    [anon_sym_DOLLARinfo] = ACTIONS(4446),
    [anon_sym_default] = ACTIONS(4448),
    [anon_sym_clocking] = ACTIONS(4448),
    [anon_sym_defparam] = ACTIONS(4448),
    [anon_sym_bind] = ACTIONS(4448),
    [anon_sym_const] = ACTIONS(4448),
    [anon_sym_function] = ACTIONS(4448),
    [anon_sym_static] = ACTIONS(4448),
    [anon_sym_constraint] = ACTIONS(4448),
    [anon_sym_if] = ACTIONS(4448),
    [anon_sym_else] = ACTIONS(4448),
    [anon_sym_LBRACK] = ACTIONS(4446),
    [anon_sym_localparam] = ACTIONS(4448),
    [anon_sym_parameter] = ACTIONS(4448),
    [anon_sym_specparam] = ACTIONS(4448),
    [anon_sym_var] = ACTIONS(4448),
    [anon_sym_import] = ACTIONS(4448),
    [anon_sym_export] = ACTIONS(4448),
    [anon_sym_genvar] = ACTIONS(4448),
    [anon_sym_interconnect] = ACTIONS(4448),
    [anon_sym_typedef] = ACTIONS(4448),
    [anon_sym_enum] = ACTIONS(4448),
    [anon_sym_struct] = ACTIONS(4448),
    [anon_sym_union] = ACTIONS(4448),
    [anon_sym_nettype] = ACTIONS(4448),
    [anon_sym_automatic] = ACTIONS(4448),
    [anon_sym_string] = ACTIONS(4448),
    [anon_sym_chandle] = ACTIONS(4448),
    [anon_sym_event] = ACTIONS(4448),
    [anon_sym_byte] = ACTIONS(4448),
    [anon_sym_shortint] = ACTIONS(4448),
    [anon_sym_int] = ACTIONS(4448),
    [anon_sym_longint] = ACTIONS(4448),
    [anon_sym_integer] = ACTIONS(4448),
    [anon_sym_time] = ACTIONS(4448),
    [anon_sym_bit] = ACTIONS(4448),
    [anon_sym_logic] = ACTIONS(4448),
    [anon_sym_reg] = ACTIONS(4448),
    [anon_sym_shortreal] = ACTIONS(4448),
    [anon_sym_real] = ACTIONS(4448),
    [anon_sym_realtime] = ACTIONS(4448),
    [anon_sym_supply0] = ACTIONS(4448),
    [anon_sym_supply1] = ACTIONS(4448),
    [anon_sym_signed] = ACTIONS(4448),
    [anon_sym_unsigned] = ACTIONS(4448),
    [anon_sym_task] = ACTIONS(4448),
    [anon_sym_modport] = ACTIONS(4448),
    [anon_sym_assert] = ACTIONS(4448),
    [anon_sym_property] = ACTIONS(4448),
    [anon_sym_assume] = ACTIONS(4448),
    [anon_sym_cover] = ACTIONS(4448),
    [anon_sym_sequence] = ACTIONS(4448),
    [anon_sym_restrict] = ACTIONS(4448),
    [anon_sym_not] = ACTIONS(4448),
    [anon_sym_or] = ACTIONS(4448),
    [anon_sym_and] = ACTIONS(4448),
    [anon_sym_case] = ACTIONS(4448),
    [anon_sym_always] = ACTIONS(4448),
    [anon_sym_covergroup] = ACTIONS(4448),
    [anon_sym_let] = ACTIONS(4448),
    [anon_sym_pulldown] = ACTIONS(4448),
    [anon_sym_pullup] = ACTIONS(4448),
    [anon_sym_cmos] = ACTIONS(4448),
    [anon_sym_rcmos] = ACTIONS(4448),
    [anon_sym_bufif0] = ACTIONS(4448),
    [anon_sym_bufif1] = ACTIONS(4448),
    [anon_sym_notif0] = ACTIONS(4448),
    [anon_sym_notif1] = ACTIONS(4448),
    [anon_sym_nmos] = ACTIONS(4448),
    [anon_sym_pmos] = ACTIONS(4448),
    [anon_sym_rnmos] = ACTIONS(4448),
    [anon_sym_rpmos] = ACTIONS(4448),
    [anon_sym_nand] = ACTIONS(4448),
    [anon_sym_nor] = ACTIONS(4448),
    [anon_sym_xor] = ACTIONS(4448),
    [anon_sym_xnor] = ACTIONS(4448),
    [anon_sym_buf] = ACTIONS(4448),
    [anon_sym_tranif0] = ACTIONS(4448),
    [anon_sym_tranif1] = ACTIONS(4448),
    [anon_sym_rtranif1] = ACTIONS(4448),
    [anon_sym_rtranif0] = ACTIONS(4448),
    [anon_sym_tran] = ACTIONS(4448),
    [anon_sym_rtran] = ACTIONS(4448),
    [anon_sym_generate] = ACTIONS(4448),
    [anon_sym_for] = ACTIONS(4448),
    [anon_sym_primitive] = ACTIONS(4448),
    [anon_sym_initial] = ACTIONS(4448),
    [anon_sym_assign] = ACTIONS(4448),
    [anon_sym_alias] = ACTIONS(4448),
    [anon_sym_always_comb] = ACTIONS(4448),
    [anon_sym_always_latch] = ACTIONS(4448),
    [anon_sym_always_ff] = ACTIONS(4448),
    [anon_sym_final] = ACTIONS(4448),
    [anon_sym_global] = ACTIONS(4448),
    [anon_sym_specify] = ACTIONS(4448),
    [anon_sym_LPAREN_STAR] = ACTIONS(4446),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4446),
    [anon_sym_DOLLARunit] = ACTIONS(4446),
  },
  [701] = {
    [ts_builtin_sym_end] = ACTIONS(4452),
    [sym_simple_identifier] = ACTIONS(4454),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4452),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4452),
    [anon_sym_BQUOTE] = ACTIONS(4454),
    [aux_sym_id_directive_token1] = ACTIONS(4452),
    [aux_sym_id_directive_token2] = ACTIONS(4452),
    [aux_sym_id_directive_token3] = ACTIONS(4452),
    [aux_sym_id_directive_token4] = ACTIONS(4454),
    [aux_sym_zero_directive_token1] = ACTIONS(4452),
    [aux_sym_zero_directive_token2] = ACTIONS(4452),
    [aux_sym_zero_directive_token3] = ACTIONS(4452),
    [aux_sym_zero_directive_token4] = ACTIONS(4452),
    [aux_sym_zero_directive_token5] = ACTIONS(4452),
    [aux_sym_zero_directive_token6] = ACTIONS(4452),
    [aux_sym_zero_directive_token7] = ACTIONS(4452),
    [aux_sym_zero_directive_token8] = ACTIONS(4452),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4452),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4452),
    [anon_sym_wire] = ACTIONS(4454),
    [anon_sym_tri] = ACTIONS(4454),
    [anon_sym_tri0] = ACTIONS(4454),
    [anon_sym_tri1] = ACTIONS(4454),
    [anon_sym_wand] = ACTIONS(4454),
    [anon_sym_triand] = ACTIONS(4454),
    [anon_sym_wor] = ACTIONS(4454),
    [anon_sym_trior] = ACTIONS(4454),
    [anon_sym_trireg] = ACTIONS(4454),
    [anon_sym_uwire] = ACTIONS(4454),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4452),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4452),
    [aux_sym_begin_keywords_token1] = ACTIONS(4452),
    [anon_sym_SEMI] = ACTIONS(4452),
    [anon_sym_endmodule] = ACTIONS(4454),
    [anon_sym_COLON] = ACTIONS(4456),
    [anon_sym_extern] = ACTIONS(4454),
    [anon_sym_module] = ACTIONS(4454),
    [anon_sym_macromodule] = ACTIONS(4454),
    [anon_sym_endinterface] = ACTIONS(4454),
    [anon_sym_interface] = ACTIONS(4454),
    [anon_sym_endprogram] = ACTIONS(4454),
    [anon_sym_program] = ACTIONS(4454),
    [anon_sym_checker] = ACTIONS(4454),
    [anon_sym_virtual] = ACTIONS(4454),
    [anon_sym_class] = ACTIONS(4454),
    [anon_sym_package] = ACTIONS(4454),
    [anon_sym_endpackage] = ACTIONS(4454),
    [anon_sym_timeunit] = ACTIONS(4454),
    [anon_sym_timeprecision] = ACTIONS(4454),
    [anon_sym_type] = ACTIONS(4454),
    [anon_sym_input] = ACTIONS(4454),
    [anon_sym_output] = ACTIONS(4454),
    [anon_sym_inout] = ACTIONS(4454),
    [anon_sym_ref] = ACTIONS(4454),
    [anon_sym_DOLLARfatal] = ACTIONS(4452),
    [anon_sym_DOLLARerror] = ACTIONS(4452),
    [anon_sym_DOLLARwarning] = ACTIONS(4452),
    [anon_sym_DOLLARinfo] = ACTIONS(4452),
    [anon_sym_default] = ACTIONS(4454),
    [anon_sym_clocking] = ACTIONS(4454),
    [anon_sym_defparam] = ACTIONS(4454),
    [anon_sym_bind] = ACTIONS(4454),
    [anon_sym_const] = ACTIONS(4454),
    [anon_sym_function] = ACTIONS(4454),
    [anon_sym_static] = ACTIONS(4454),
    [anon_sym_constraint] = ACTIONS(4454),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_else] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4452),
    [anon_sym_localparam] = ACTIONS(4454),
    [anon_sym_parameter] = ACTIONS(4454),
    [anon_sym_specparam] = ACTIONS(4454),
    [anon_sym_var] = ACTIONS(4454),
    [anon_sym_import] = ACTIONS(4454),
    [anon_sym_export] = ACTIONS(4454),
    [anon_sym_genvar] = ACTIONS(4454),
    [anon_sym_interconnect] = ACTIONS(4454),
    [anon_sym_typedef] = ACTIONS(4454),
    [anon_sym_enum] = ACTIONS(4454),
    [anon_sym_struct] = ACTIONS(4454),
    [anon_sym_union] = ACTIONS(4454),
    [anon_sym_nettype] = ACTIONS(4454),
    [anon_sym_automatic] = ACTIONS(4454),
    [anon_sym_string] = ACTIONS(4454),
    [anon_sym_chandle] = ACTIONS(4454),
    [anon_sym_event] = ACTIONS(4454),
    [anon_sym_byte] = ACTIONS(4454),
    [anon_sym_shortint] = ACTIONS(4454),
    [anon_sym_int] = ACTIONS(4454),
    [anon_sym_longint] = ACTIONS(4454),
    [anon_sym_integer] = ACTIONS(4454),
    [anon_sym_time] = ACTIONS(4454),
    [anon_sym_bit] = ACTIONS(4454),
    [anon_sym_logic] = ACTIONS(4454),
    [anon_sym_reg] = ACTIONS(4454),
    [anon_sym_shortreal] = ACTIONS(4454),
    [anon_sym_real] = ACTIONS(4454),
    [anon_sym_realtime] = ACTIONS(4454),
    [anon_sym_supply0] = ACTIONS(4454),
    [anon_sym_supply1] = ACTIONS(4454),
    [anon_sym_signed] = ACTIONS(4454),
    [anon_sym_unsigned] = ACTIONS(4454),
    [anon_sym_task] = ACTIONS(4454),
    [anon_sym_modport] = ACTIONS(4454),
    [anon_sym_assert] = ACTIONS(4454),
    [anon_sym_property] = ACTIONS(4454),
    [anon_sym_assume] = ACTIONS(4454),
    [anon_sym_cover] = ACTIONS(4454),
    [anon_sym_sequence] = ACTIONS(4454),
    [anon_sym_restrict] = ACTIONS(4454),
    [anon_sym_not] = ACTIONS(4454),
    [anon_sym_or] = ACTIONS(4454),
    [anon_sym_and] = ACTIONS(4454),
    [anon_sym_case] = ACTIONS(4454),
    [anon_sym_always] = ACTIONS(4454),
    [anon_sym_covergroup] = ACTIONS(4454),
    [anon_sym_let] = ACTIONS(4454),
    [anon_sym_pulldown] = ACTIONS(4454),
    [anon_sym_pullup] = ACTIONS(4454),
    [anon_sym_cmos] = ACTIONS(4454),
    [anon_sym_rcmos] = ACTIONS(4454),
    [anon_sym_bufif0] = ACTIONS(4454),
    [anon_sym_bufif1] = ACTIONS(4454),
    [anon_sym_notif0] = ACTIONS(4454),
    [anon_sym_notif1] = ACTIONS(4454),
    [anon_sym_nmos] = ACTIONS(4454),
    [anon_sym_pmos] = ACTIONS(4454),
    [anon_sym_rnmos] = ACTIONS(4454),
    [anon_sym_rpmos] = ACTIONS(4454),
    [anon_sym_nand] = ACTIONS(4454),
    [anon_sym_nor] = ACTIONS(4454),
    [anon_sym_xor] = ACTIONS(4454),
    [anon_sym_xnor] = ACTIONS(4454),
    [anon_sym_buf] = ACTIONS(4454),
    [anon_sym_tranif0] = ACTIONS(4454),
    [anon_sym_tranif1] = ACTIONS(4454),
    [anon_sym_rtranif1] = ACTIONS(4454),
    [anon_sym_rtranif0] = ACTIONS(4454),
    [anon_sym_tran] = ACTIONS(4454),
    [anon_sym_rtran] = ACTIONS(4454),
    [anon_sym_generate] = ACTIONS(4454),
    [anon_sym_for] = ACTIONS(4454),
    [anon_sym_primitive] = ACTIONS(4454),
    [anon_sym_initial] = ACTIONS(4454),
    [anon_sym_assign] = ACTIONS(4454),
    [anon_sym_alias] = ACTIONS(4454),
    [anon_sym_always_comb] = ACTIONS(4454),
    [anon_sym_always_latch] = ACTIONS(4454),
    [anon_sym_always_ff] = ACTIONS(4454),
    [anon_sym_final] = ACTIONS(4454),
    [anon_sym_global] = ACTIONS(4454),
    [anon_sym_specify] = ACTIONS(4454),
    [anon_sym_LPAREN_STAR] = ACTIONS(4452),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4452),
    [anon_sym_DOLLARunit] = ACTIONS(4452),
  },
  [702] = {
    [ts_builtin_sym_end] = ACTIONS(4458),
    [sym_simple_identifier] = ACTIONS(4460),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4458),
    [anon_sym_BQUOTE] = ACTIONS(4460),
    [aux_sym_id_directive_token1] = ACTIONS(4458),
    [aux_sym_id_directive_token2] = ACTIONS(4458),
    [aux_sym_id_directive_token3] = ACTIONS(4458),
    [aux_sym_id_directive_token4] = ACTIONS(4460),
    [aux_sym_zero_directive_token1] = ACTIONS(4458),
    [aux_sym_zero_directive_token2] = ACTIONS(4458),
    [aux_sym_zero_directive_token3] = ACTIONS(4458),
    [aux_sym_zero_directive_token4] = ACTIONS(4458),
    [aux_sym_zero_directive_token5] = ACTIONS(4458),
    [aux_sym_zero_directive_token6] = ACTIONS(4458),
    [aux_sym_zero_directive_token7] = ACTIONS(4458),
    [aux_sym_zero_directive_token8] = ACTIONS(4458),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4458),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4458),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_begin_keywords_token1] = ACTIONS(4458),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_endmodule] = ACTIONS(4460),
    [anon_sym_COLON] = ACTIONS(4462),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_module] = ACTIONS(4460),
    [anon_sym_macromodule] = ACTIONS(4460),
    [anon_sym_endinterface] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_endprogram] = ACTIONS(4460),
    [anon_sym_program] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_package] = ACTIONS(4460),
    [anon_sym_endpackage] = ACTIONS(4460),
    [anon_sym_timeunit] = ACTIONS(4460),
    [anon_sym_timeprecision] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_input] = ACTIONS(4460),
    [anon_sym_output] = ACTIONS(4460),
    [anon_sym_inout] = ACTIONS(4460),
    [anon_sym_ref] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_specparam] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_modport] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_primitive] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_specify] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [703] = {
    [ts_builtin_sym_end] = ACTIONS(4464),
    [sym_simple_identifier] = ACTIONS(4466),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4464),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4464),
    [anon_sym_BQUOTE] = ACTIONS(4466),
    [aux_sym_id_directive_token1] = ACTIONS(4464),
    [aux_sym_id_directive_token2] = ACTIONS(4464),
    [aux_sym_id_directive_token3] = ACTIONS(4464),
    [aux_sym_id_directive_token4] = ACTIONS(4466),
    [aux_sym_zero_directive_token1] = ACTIONS(4464),
    [aux_sym_zero_directive_token2] = ACTIONS(4464),
    [aux_sym_zero_directive_token3] = ACTIONS(4464),
    [aux_sym_zero_directive_token4] = ACTIONS(4464),
    [aux_sym_zero_directive_token5] = ACTIONS(4464),
    [aux_sym_zero_directive_token6] = ACTIONS(4464),
    [aux_sym_zero_directive_token7] = ACTIONS(4464),
    [aux_sym_zero_directive_token8] = ACTIONS(4464),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4464),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4464),
    [anon_sym_wire] = ACTIONS(4466),
    [anon_sym_tri] = ACTIONS(4466),
    [anon_sym_tri0] = ACTIONS(4466),
    [anon_sym_tri1] = ACTIONS(4466),
    [anon_sym_wand] = ACTIONS(4466),
    [anon_sym_triand] = ACTIONS(4466),
    [anon_sym_wor] = ACTIONS(4466),
    [anon_sym_trior] = ACTIONS(4466),
    [anon_sym_trireg] = ACTIONS(4466),
    [anon_sym_uwire] = ACTIONS(4466),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4464),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4464),
    [aux_sym_begin_keywords_token1] = ACTIONS(4464),
    [anon_sym_SEMI] = ACTIONS(4464),
    [anon_sym_endmodule] = ACTIONS(4466),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_extern] = ACTIONS(4466),
    [anon_sym_module] = ACTIONS(4466),
    [anon_sym_macromodule] = ACTIONS(4466),
    [anon_sym_endinterface] = ACTIONS(4466),
    [anon_sym_interface] = ACTIONS(4466),
    [anon_sym_endprogram] = ACTIONS(4466),
    [anon_sym_program] = ACTIONS(4466),
    [anon_sym_checker] = ACTIONS(4466),
    [anon_sym_virtual] = ACTIONS(4466),
    [anon_sym_class] = ACTIONS(4466),
    [anon_sym_package] = ACTIONS(4466),
    [anon_sym_endpackage] = ACTIONS(4466),
    [anon_sym_timeunit] = ACTIONS(4466),
    [anon_sym_timeprecision] = ACTIONS(4466),
    [anon_sym_type] = ACTIONS(4466),
    [anon_sym_input] = ACTIONS(4466),
    [anon_sym_output] = ACTIONS(4466),
    [anon_sym_inout] = ACTIONS(4466),
    [anon_sym_ref] = ACTIONS(4466),
    [anon_sym_DOLLARfatal] = ACTIONS(4464),
    [anon_sym_DOLLARerror] = ACTIONS(4464),
    [anon_sym_DOLLARwarning] = ACTIONS(4464),
    [anon_sym_DOLLARinfo] = ACTIONS(4464),
    [anon_sym_default] = ACTIONS(4466),
    [anon_sym_clocking] = ACTIONS(4466),
    [anon_sym_defparam] = ACTIONS(4466),
    [anon_sym_bind] = ACTIONS(4466),
    [anon_sym_const] = ACTIONS(4466),
    [anon_sym_function] = ACTIONS(4466),
    [anon_sym_static] = ACTIONS(4466),
    [anon_sym_constraint] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_else] = ACTIONS(4466),
    [anon_sym_LBRACK] = ACTIONS(4464),
    [anon_sym_localparam] = ACTIONS(4466),
    [anon_sym_parameter] = ACTIONS(4466),
    [anon_sym_specparam] = ACTIONS(4466),
    [anon_sym_var] = ACTIONS(4466),
    [anon_sym_import] = ACTIONS(4466),
    [anon_sym_export] = ACTIONS(4466),
    [anon_sym_genvar] = ACTIONS(4466),
    [anon_sym_interconnect] = ACTIONS(4466),
    [anon_sym_typedef] = ACTIONS(4466),
    [anon_sym_enum] = ACTIONS(4466),
    [anon_sym_struct] = ACTIONS(4466),
    [anon_sym_union] = ACTIONS(4466),
    [anon_sym_nettype] = ACTIONS(4466),
    [anon_sym_automatic] = ACTIONS(4466),
    [anon_sym_string] = ACTIONS(4466),
    [anon_sym_chandle] = ACTIONS(4466),
    [anon_sym_event] = ACTIONS(4466),
    [anon_sym_byte] = ACTIONS(4466),
    [anon_sym_shortint] = ACTIONS(4466),
    [anon_sym_int] = ACTIONS(4466),
    [anon_sym_longint] = ACTIONS(4466),
    [anon_sym_integer] = ACTIONS(4466),
    [anon_sym_time] = ACTIONS(4466),
    [anon_sym_bit] = ACTIONS(4466),
    [anon_sym_logic] = ACTIONS(4466),
    [anon_sym_reg] = ACTIONS(4466),
    [anon_sym_shortreal] = ACTIONS(4466),
    [anon_sym_real] = ACTIONS(4466),
    [anon_sym_realtime] = ACTIONS(4466),
    [anon_sym_supply0] = ACTIONS(4466),
    [anon_sym_supply1] = ACTIONS(4466),
    [anon_sym_signed] = ACTIONS(4466),
    [anon_sym_unsigned] = ACTIONS(4466),
    [anon_sym_task] = ACTIONS(4466),
    [anon_sym_modport] = ACTIONS(4466),
    [anon_sym_assert] = ACTIONS(4466),
    [anon_sym_property] = ACTIONS(4466),
    [anon_sym_assume] = ACTIONS(4466),
    [anon_sym_cover] = ACTIONS(4466),
    [anon_sym_sequence] = ACTIONS(4466),
    [anon_sym_restrict] = ACTIONS(4466),
    [anon_sym_not] = ACTIONS(4466),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_and] = ACTIONS(4466),
    [anon_sym_case] = ACTIONS(4466),
    [anon_sym_always] = ACTIONS(4466),
    [anon_sym_covergroup] = ACTIONS(4466),
    [anon_sym_let] = ACTIONS(4466),
    [anon_sym_pulldown] = ACTIONS(4466),
    [anon_sym_pullup] = ACTIONS(4466),
    [anon_sym_cmos] = ACTIONS(4466),
    [anon_sym_rcmos] = ACTIONS(4466),
    [anon_sym_bufif0] = ACTIONS(4466),
    [anon_sym_bufif1] = ACTIONS(4466),
    [anon_sym_notif0] = ACTIONS(4466),
    [anon_sym_notif1] = ACTIONS(4466),
    [anon_sym_nmos] = ACTIONS(4466),
    [anon_sym_pmos] = ACTIONS(4466),
    [anon_sym_rnmos] = ACTIONS(4466),
    [anon_sym_rpmos] = ACTIONS(4466),
    [anon_sym_nand] = ACTIONS(4466),
    [anon_sym_nor] = ACTIONS(4466),
    [anon_sym_xor] = ACTIONS(4466),
    [anon_sym_xnor] = ACTIONS(4466),
    [anon_sym_buf] = ACTIONS(4466),
    [anon_sym_tranif0] = ACTIONS(4466),
    [anon_sym_tranif1] = ACTIONS(4466),
    [anon_sym_rtranif1] = ACTIONS(4466),
    [anon_sym_rtranif0] = ACTIONS(4466),
    [anon_sym_tran] = ACTIONS(4466),
    [anon_sym_rtran] = ACTIONS(4466),
    [anon_sym_generate] = ACTIONS(4466),
    [anon_sym_for] = ACTIONS(4466),
    [anon_sym_primitive] = ACTIONS(4466),
    [anon_sym_initial] = ACTIONS(4466),
    [anon_sym_assign] = ACTIONS(4466),
    [anon_sym_alias] = ACTIONS(4466),
    [anon_sym_always_comb] = ACTIONS(4466),
    [anon_sym_always_latch] = ACTIONS(4466),
    [anon_sym_always_ff] = ACTIONS(4466),
    [anon_sym_final] = ACTIONS(4466),
    [anon_sym_global] = ACTIONS(4466),
    [anon_sym_specify] = ACTIONS(4466),
    [anon_sym_LPAREN_STAR] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4464),
    [anon_sym_DOLLARunit] = ACTIONS(4464),
  },
  [704] = {
    [ts_builtin_sym_end] = ACTIONS(4470),
    [sym_simple_identifier] = ACTIONS(4472),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4470),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4470),
    [anon_sym_BQUOTE] = ACTIONS(4472),
    [aux_sym_id_directive_token1] = ACTIONS(4470),
    [aux_sym_id_directive_token2] = ACTIONS(4470),
    [aux_sym_id_directive_token3] = ACTIONS(4470),
    [aux_sym_id_directive_token4] = ACTIONS(4472),
    [aux_sym_zero_directive_token1] = ACTIONS(4470),
    [aux_sym_zero_directive_token2] = ACTIONS(4470),
    [aux_sym_zero_directive_token3] = ACTIONS(4470),
    [aux_sym_zero_directive_token4] = ACTIONS(4470),
    [aux_sym_zero_directive_token5] = ACTIONS(4470),
    [aux_sym_zero_directive_token6] = ACTIONS(4470),
    [aux_sym_zero_directive_token7] = ACTIONS(4470),
    [aux_sym_zero_directive_token8] = ACTIONS(4470),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4470),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4470),
    [anon_sym_wire] = ACTIONS(4472),
    [anon_sym_tri] = ACTIONS(4472),
    [anon_sym_tri0] = ACTIONS(4472),
    [anon_sym_tri1] = ACTIONS(4472),
    [anon_sym_wand] = ACTIONS(4472),
    [anon_sym_triand] = ACTIONS(4472),
    [anon_sym_wor] = ACTIONS(4472),
    [anon_sym_trior] = ACTIONS(4472),
    [anon_sym_trireg] = ACTIONS(4472),
    [anon_sym_uwire] = ACTIONS(4472),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4470),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4470),
    [aux_sym_begin_keywords_token1] = ACTIONS(4470),
    [anon_sym_SEMI] = ACTIONS(4470),
    [anon_sym_endmodule] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4474),
    [anon_sym_extern] = ACTIONS(4472),
    [anon_sym_module] = ACTIONS(4472),
    [anon_sym_macromodule] = ACTIONS(4472),
    [anon_sym_endinterface] = ACTIONS(4472),
    [anon_sym_interface] = ACTIONS(4472),
    [anon_sym_endprogram] = ACTIONS(4472),
    [anon_sym_program] = ACTIONS(4472),
    [anon_sym_checker] = ACTIONS(4472),
    [anon_sym_virtual] = ACTIONS(4472),
    [anon_sym_class] = ACTIONS(4472),
    [anon_sym_package] = ACTIONS(4472),
    [anon_sym_endpackage] = ACTIONS(4472),
    [anon_sym_timeunit] = ACTIONS(4472),
    [anon_sym_timeprecision] = ACTIONS(4472),
    [anon_sym_type] = ACTIONS(4472),
    [anon_sym_input] = ACTIONS(4472),
    [anon_sym_output] = ACTIONS(4472),
    [anon_sym_inout] = ACTIONS(4472),
    [anon_sym_ref] = ACTIONS(4472),
    [anon_sym_DOLLARfatal] = ACTIONS(4470),
    [anon_sym_DOLLARerror] = ACTIONS(4470),
    [anon_sym_DOLLARwarning] = ACTIONS(4470),
    [anon_sym_DOLLARinfo] = ACTIONS(4470),
    [anon_sym_default] = ACTIONS(4472),
    [anon_sym_clocking] = ACTIONS(4472),
    [anon_sym_defparam] = ACTIONS(4472),
    [anon_sym_bind] = ACTIONS(4472),
    [anon_sym_const] = ACTIONS(4472),
    [anon_sym_function] = ACTIONS(4472),
    [anon_sym_static] = ACTIONS(4472),
    [anon_sym_constraint] = ACTIONS(4472),
    [anon_sym_if] = ACTIONS(4472),
    [anon_sym_else] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4470),
    [anon_sym_localparam] = ACTIONS(4472),
    [anon_sym_parameter] = ACTIONS(4472),
    [anon_sym_specparam] = ACTIONS(4472),
    [anon_sym_var] = ACTIONS(4472),
    [anon_sym_import] = ACTIONS(4472),
    [anon_sym_export] = ACTIONS(4472),
    [anon_sym_genvar] = ACTIONS(4472),
    [anon_sym_interconnect] = ACTIONS(4472),
    [anon_sym_typedef] = ACTIONS(4472),
    [anon_sym_enum] = ACTIONS(4472),
    [anon_sym_struct] = ACTIONS(4472),
    [anon_sym_union] = ACTIONS(4472),
    [anon_sym_nettype] = ACTIONS(4472),
    [anon_sym_automatic] = ACTIONS(4472),
    [anon_sym_string] = ACTIONS(4472),
    [anon_sym_chandle] = ACTIONS(4472),
    [anon_sym_event] = ACTIONS(4472),
    [anon_sym_byte] = ACTIONS(4472),
    [anon_sym_shortint] = ACTIONS(4472),
    [anon_sym_int] = ACTIONS(4472),
    [anon_sym_longint] = ACTIONS(4472),
    [anon_sym_integer] = ACTIONS(4472),
    [anon_sym_time] = ACTIONS(4472),
    [anon_sym_bit] = ACTIONS(4472),
    [anon_sym_logic] = ACTIONS(4472),
    [anon_sym_reg] = ACTIONS(4472),
    [anon_sym_shortreal] = ACTIONS(4472),
    [anon_sym_real] = ACTIONS(4472),
    [anon_sym_realtime] = ACTIONS(4472),
    [anon_sym_supply0] = ACTIONS(4472),
    [anon_sym_supply1] = ACTIONS(4472),
    [anon_sym_signed] = ACTIONS(4472),
    [anon_sym_unsigned] = ACTIONS(4472),
    [anon_sym_task] = ACTIONS(4472),
    [anon_sym_modport] = ACTIONS(4472),
    [anon_sym_assert] = ACTIONS(4472),
    [anon_sym_property] = ACTIONS(4472),
    [anon_sym_assume] = ACTIONS(4472),
    [anon_sym_cover] = ACTIONS(4472),
    [anon_sym_sequence] = ACTIONS(4472),
    [anon_sym_restrict] = ACTIONS(4472),
    [anon_sym_not] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_case] = ACTIONS(4472),
    [anon_sym_always] = ACTIONS(4472),
    [anon_sym_covergroup] = ACTIONS(4472),
    [anon_sym_let] = ACTIONS(4472),
    [anon_sym_pulldown] = ACTIONS(4472),
    [anon_sym_pullup] = ACTIONS(4472),
    [anon_sym_cmos] = ACTIONS(4472),
    [anon_sym_rcmos] = ACTIONS(4472),
    [anon_sym_bufif0] = ACTIONS(4472),
    [anon_sym_bufif1] = ACTIONS(4472),
    [anon_sym_notif0] = ACTIONS(4472),
    [anon_sym_notif1] = ACTIONS(4472),
    [anon_sym_nmos] = ACTIONS(4472),
    [anon_sym_pmos] = ACTIONS(4472),
    [anon_sym_rnmos] = ACTIONS(4472),
    [anon_sym_rpmos] = ACTIONS(4472),
    [anon_sym_nand] = ACTIONS(4472),
    [anon_sym_nor] = ACTIONS(4472),
    [anon_sym_xor] = ACTIONS(4472),
    [anon_sym_xnor] = ACTIONS(4472),
    [anon_sym_buf] = ACTIONS(4472),
    [anon_sym_tranif0] = ACTIONS(4472),
    [anon_sym_tranif1] = ACTIONS(4472),
    [anon_sym_rtranif1] = ACTIONS(4472),
    [anon_sym_rtranif0] = ACTIONS(4472),
    [anon_sym_tran] = ACTIONS(4472),
    [anon_sym_rtran] = ACTIONS(4472),
    [anon_sym_generate] = ACTIONS(4472),
    [anon_sym_for] = ACTIONS(4472),
    [anon_sym_primitive] = ACTIONS(4472),
    [anon_sym_initial] = ACTIONS(4472),
    [anon_sym_assign] = ACTIONS(4472),
    [anon_sym_alias] = ACTIONS(4472),
    [anon_sym_always_comb] = ACTIONS(4472),
    [anon_sym_always_latch] = ACTIONS(4472),
    [anon_sym_always_ff] = ACTIONS(4472),
    [anon_sym_final] = ACTIONS(4472),
    [anon_sym_global] = ACTIONS(4472),
    [anon_sym_specify] = ACTIONS(4472),
    [anon_sym_LPAREN_STAR] = ACTIONS(4470),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4470),
    [anon_sym_DOLLARunit] = ACTIONS(4470),
  },
  [705] = {
    [ts_builtin_sym_end] = ACTIONS(4476),
    [sym_simple_identifier] = ACTIONS(4478),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4476),
    [anon_sym_BQUOTE] = ACTIONS(4478),
    [aux_sym_id_directive_token1] = ACTIONS(4476),
    [aux_sym_id_directive_token2] = ACTIONS(4476),
    [aux_sym_id_directive_token3] = ACTIONS(4476),
    [aux_sym_id_directive_token4] = ACTIONS(4478),
    [aux_sym_zero_directive_token1] = ACTIONS(4476),
    [aux_sym_zero_directive_token2] = ACTIONS(4476),
    [aux_sym_zero_directive_token3] = ACTIONS(4476),
    [aux_sym_zero_directive_token4] = ACTIONS(4476),
    [aux_sym_zero_directive_token5] = ACTIONS(4476),
    [aux_sym_zero_directive_token6] = ACTIONS(4476),
    [aux_sym_zero_directive_token7] = ACTIONS(4476),
    [aux_sym_zero_directive_token8] = ACTIONS(4476),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4476),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4476),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_begin_keywords_token1] = ACTIONS(4476),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_endmodule] = ACTIONS(4478),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_module] = ACTIONS(4478),
    [anon_sym_macromodule] = ACTIONS(4478),
    [anon_sym_endinterface] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_endprogram] = ACTIONS(4478),
    [anon_sym_program] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_package] = ACTIONS(4478),
    [anon_sym_endpackage] = ACTIONS(4478),
    [anon_sym_timeunit] = ACTIONS(4478),
    [anon_sym_timeprecision] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_input] = ACTIONS(4478),
    [anon_sym_output] = ACTIONS(4478),
    [anon_sym_inout] = ACTIONS(4478),
    [anon_sym_ref] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_specparam] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_modport] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_primitive] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_specify] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [706] = {
    [ts_builtin_sym_end] = ACTIONS(4482),
    [sym_simple_identifier] = ACTIONS(4484),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4482),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4482),
    [anon_sym_BQUOTE] = ACTIONS(4484),
    [aux_sym_id_directive_token1] = ACTIONS(4482),
    [aux_sym_id_directive_token2] = ACTIONS(4482),
    [aux_sym_id_directive_token3] = ACTIONS(4482),
    [aux_sym_id_directive_token4] = ACTIONS(4484),
    [aux_sym_zero_directive_token1] = ACTIONS(4482),
    [aux_sym_zero_directive_token2] = ACTIONS(4482),
    [aux_sym_zero_directive_token3] = ACTIONS(4482),
    [aux_sym_zero_directive_token4] = ACTIONS(4482),
    [aux_sym_zero_directive_token5] = ACTIONS(4482),
    [aux_sym_zero_directive_token6] = ACTIONS(4482),
    [aux_sym_zero_directive_token7] = ACTIONS(4482),
    [aux_sym_zero_directive_token8] = ACTIONS(4482),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4482),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4482),
    [anon_sym_wire] = ACTIONS(4484),
    [anon_sym_tri] = ACTIONS(4484),
    [anon_sym_tri0] = ACTIONS(4484),
    [anon_sym_tri1] = ACTIONS(4484),
    [anon_sym_wand] = ACTIONS(4484),
    [anon_sym_triand] = ACTIONS(4484),
    [anon_sym_wor] = ACTIONS(4484),
    [anon_sym_trior] = ACTIONS(4484),
    [anon_sym_trireg] = ACTIONS(4484),
    [anon_sym_uwire] = ACTIONS(4484),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4482),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4482),
    [aux_sym_begin_keywords_token1] = ACTIONS(4482),
    [anon_sym_SEMI] = ACTIONS(4482),
    [anon_sym_endmodule] = ACTIONS(4484),
    [anon_sym_extern] = ACTIONS(4484),
    [anon_sym_module] = ACTIONS(4484),
    [anon_sym_macromodule] = ACTIONS(4484),
    [anon_sym_endinterface] = ACTIONS(4484),
    [anon_sym_interface] = ACTIONS(4484),
    [anon_sym_endprogram] = ACTIONS(4484),
    [anon_sym_program] = ACTIONS(4484),
    [anon_sym_checker] = ACTIONS(4484),
    [anon_sym_virtual] = ACTIONS(4484),
    [anon_sym_class] = ACTIONS(4484),
    [anon_sym_package] = ACTIONS(4484),
    [anon_sym_endpackage] = ACTIONS(4484),
    [anon_sym_timeunit] = ACTIONS(4484),
    [anon_sym_timeprecision] = ACTIONS(4484),
    [anon_sym_type] = ACTIONS(4484),
    [anon_sym_input] = ACTIONS(4484),
    [anon_sym_output] = ACTIONS(4484),
    [anon_sym_inout] = ACTIONS(4484),
    [anon_sym_ref] = ACTIONS(4484),
    [anon_sym_DOLLARfatal] = ACTIONS(4482),
    [anon_sym_DOLLARerror] = ACTIONS(4482),
    [anon_sym_DOLLARwarning] = ACTIONS(4482),
    [anon_sym_DOLLARinfo] = ACTIONS(4482),
    [anon_sym_default] = ACTIONS(4484),
    [anon_sym_clocking] = ACTIONS(4484),
    [anon_sym_defparam] = ACTIONS(4484),
    [anon_sym_bind] = ACTIONS(4484),
    [anon_sym_const] = ACTIONS(4484),
    [anon_sym_function] = ACTIONS(4484),
    [anon_sym_static] = ACTIONS(4484),
    [anon_sym_constraint] = ACTIONS(4484),
    [anon_sym_if] = ACTIONS(4484),
    [anon_sym_else] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4482),
    [anon_sym_localparam] = ACTIONS(4484),
    [anon_sym_parameter] = ACTIONS(4484),
    [anon_sym_specparam] = ACTIONS(4484),
    [anon_sym_var] = ACTIONS(4484),
    [anon_sym_import] = ACTIONS(4484),
    [anon_sym_export] = ACTIONS(4484),
    [anon_sym_genvar] = ACTIONS(4484),
    [anon_sym_interconnect] = ACTIONS(4484),
    [anon_sym_typedef] = ACTIONS(4484),
    [anon_sym_enum] = ACTIONS(4484),
    [anon_sym_struct] = ACTIONS(4484),
    [anon_sym_union] = ACTIONS(4484),
    [anon_sym_nettype] = ACTIONS(4484),
    [anon_sym_automatic] = ACTIONS(4484),
    [anon_sym_string] = ACTIONS(4484),
    [anon_sym_chandle] = ACTIONS(4484),
    [anon_sym_event] = ACTIONS(4484),
    [anon_sym_byte] = ACTIONS(4484),
    [anon_sym_shortint] = ACTIONS(4484),
    [anon_sym_int] = ACTIONS(4484),
    [anon_sym_longint] = ACTIONS(4484),
    [anon_sym_integer] = ACTIONS(4484),
    [anon_sym_time] = ACTIONS(4484),
    [anon_sym_bit] = ACTIONS(4484),
    [anon_sym_logic] = ACTIONS(4484),
    [anon_sym_reg] = ACTIONS(4484),
    [anon_sym_shortreal] = ACTIONS(4484),
    [anon_sym_real] = ACTIONS(4484),
    [anon_sym_realtime] = ACTIONS(4484),
    [anon_sym_supply0] = ACTIONS(4484),
    [anon_sym_supply1] = ACTIONS(4484),
    [anon_sym_signed] = ACTIONS(4484),
    [anon_sym_unsigned] = ACTIONS(4484),
    [anon_sym_task] = ACTIONS(4484),
    [anon_sym_modport] = ACTIONS(4484),
    [anon_sym_assert] = ACTIONS(4484),
    [anon_sym_property] = ACTIONS(4484),
    [anon_sym_assume] = ACTIONS(4484),
    [anon_sym_cover] = ACTIONS(4484),
    [anon_sym_sequence] = ACTIONS(4484),
    [anon_sym_restrict] = ACTIONS(4484),
    [anon_sym_not] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_case] = ACTIONS(4484),
    [anon_sym_always] = ACTIONS(4484),
    [anon_sym_covergroup] = ACTIONS(4484),
    [anon_sym_let] = ACTIONS(4484),
    [anon_sym_pulldown] = ACTIONS(4484),
    [anon_sym_pullup] = ACTIONS(4484),
    [anon_sym_cmos] = ACTIONS(4484),
    [anon_sym_rcmos] = ACTIONS(4484),
    [anon_sym_bufif0] = ACTIONS(4484),
    [anon_sym_bufif1] = ACTIONS(4484),
    [anon_sym_notif0] = ACTIONS(4484),
    [anon_sym_notif1] = ACTIONS(4484),
    [anon_sym_nmos] = ACTIONS(4484),
    [anon_sym_pmos] = ACTIONS(4484),
    [anon_sym_rnmos] = ACTIONS(4484),
    [anon_sym_rpmos] = ACTIONS(4484),
    [anon_sym_nand] = ACTIONS(4484),
    [anon_sym_nor] = ACTIONS(4484),
    [anon_sym_xor] = ACTIONS(4484),
    [anon_sym_xnor] = ACTIONS(4484),
    [anon_sym_buf] = ACTIONS(4484),
    [anon_sym_tranif0] = ACTIONS(4484),
    [anon_sym_tranif1] = ACTIONS(4484),
    [anon_sym_rtranif1] = ACTIONS(4484),
    [anon_sym_rtranif0] = ACTIONS(4484),
    [anon_sym_tran] = ACTIONS(4484),
    [anon_sym_rtran] = ACTIONS(4484),
    [anon_sym_generate] = ACTIONS(4484),
    [anon_sym_for] = ACTIONS(4484),
    [anon_sym_primitive] = ACTIONS(4484),
    [anon_sym_initial] = ACTIONS(4484),
    [anon_sym_assign] = ACTIONS(4484),
    [anon_sym_alias] = ACTIONS(4484),
    [anon_sym_always_comb] = ACTIONS(4484),
    [anon_sym_always_latch] = ACTIONS(4484),
    [anon_sym_always_ff] = ACTIONS(4484),
    [anon_sym_final] = ACTIONS(4484),
    [anon_sym_endclocking] = ACTIONS(4484),
    [anon_sym_global] = ACTIONS(4484),
    [anon_sym_specify] = ACTIONS(4484),
    [anon_sym_LPAREN_STAR] = ACTIONS(4482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4482),
    [anon_sym_DOLLARunit] = ACTIONS(4482),
  },
  [707] = {
    [ts_builtin_sym_end] = ACTIONS(4486),
    [sym_simple_identifier] = ACTIONS(4488),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4486),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4486),
    [anon_sym_BQUOTE] = ACTIONS(4488),
    [aux_sym_id_directive_token1] = ACTIONS(4486),
    [aux_sym_id_directive_token2] = ACTIONS(4486),
    [aux_sym_id_directive_token3] = ACTIONS(4486),
    [aux_sym_id_directive_token4] = ACTIONS(4488),
    [aux_sym_zero_directive_token1] = ACTIONS(4486),
    [aux_sym_zero_directive_token2] = ACTIONS(4486),
    [aux_sym_zero_directive_token3] = ACTIONS(4486),
    [aux_sym_zero_directive_token4] = ACTIONS(4486),
    [aux_sym_zero_directive_token5] = ACTIONS(4486),
    [aux_sym_zero_directive_token6] = ACTIONS(4486),
    [aux_sym_zero_directive_token7] = ACTIONS(4486),
    [aux_sym_zero_directive_token8] = ACTIONS(4486),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4486),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4486),
    [anon_sym_wire] = ACTIONS(4488),
    [anon_sym_tri] = ACTIONS(4488),
    [anon_sym_tri0] = ACTIONS(4488),
    [anon_sym_tri1] = ACTIONS(4488),
    [anon_sym_wand] = ACTIONS(4488),
    [anon_sym_triand] = ACTIONS(4488),
    [anon_sym_wor] = ACTIONS(4488),
    [anon_sym_trior] = ACTIONS(4488),
    [anon_sym_trireg] = ACTIONS(4488),
    [anon_sym_uwire] = ACTIONS(4488),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4486),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4486),
    [aux_sym_begin_keywords_token1] = ACTIONS(4486),
    [anon_sym_SEMI] = ACTIONS(4486),
    [anon_sym_endmodule] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4490),
    [anon_sym_extern] = ACTIONS(4488),
    [anon_sym_module] = ACTIONS(4488),
    [anon_sym_macromodule] = ACTIONS(4488),
    [anon_sym_endinterface] = ACTIONS(4488),
    [anon_sym_interface] = ACTIONS(4488),
    [anon_sym_endprogram] = ACTIONS(4488),
    [anon_sym_program] = ACTIONS(4488),
    [anon_sym_checker] = ACTIONS(4488),
    [anon_sym_virtual] = ACTIONS(4488),
    [anon_sym_class] = ACTIONS(4488),
    [anon_sym_package] = ACTIONS(4488),
    [anon_sym_endpackage] = ACTIONS(4488),
    [anon_sym_timeunit] = ACTIONS(4488),
    [anon_sym_timeprecision] = ACTIONS(4488),
    [anon_sym_type] = ACTIONS(4488),
    [anon_sym_input] = ACTIONS(4488),
    [anon_sym_output] = ACTIONS(4488),
    [anon_sym_inout] = ACTIONS(4488),
    [anon_sym_ref] = ACTIONS(4488),
    [anon_sym_DOLLARfatal] = ACTIONS(4486),
    [anon_sym_DOLLARerror] = ACTIONS(4486),
    [anon_sym_DOLLARwarning] = ACTIONS(4486),
    [anon_sym_DOLLARinfo] = ACTIONS(4486),
    [anon_sym_default] = ACTIONS(4488),
    [anon_sym_clocking] = ACTIONS(4488),
    [anon_sym_defparam] = ACTIONS(4488),
    [anon_sym_bind] = ACTIONS(4488),
    [anon_sym_const] = ACTIONS(4488),
    [anon_sym_function] = ACTIONS(4488),
    [anon_sym_static] = ACTIONS(4488),
    [anon_sym_constraint] = ACTIONS(4488),
    [anon_sym_if] = ACTIONS(4488),
    [anon_sym_else] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4486),
    [anon_sym_localparam] = ACTIONS(4488),
    [anon_sym_parameter] = ACTIONS(4488),
    [anon_sym_specparam] = ACTIONS(4488),
    [anon_sym_var] = ACTIONS(4488),
    [anon_sym_import] = ACTIONS(4488),
    [anon_sym_export] = ACTIONS(4488),
    [anon_sym_genvar] = ACTIONS(4488),
    [anon_sym_interconnect] = ACTIONS(4488),
    [anon_sym_typedef] = ACTIONS(4488),
    [anon_sym_enum] = ACTIONS(4488),
    [anon_sym_struct] = ACTIONS(4488),
    [anon_sym_union] = ACTIONS(4488),
    [anon_sym_nettype] = ACTIONS(4488),
    [anon_sym_automatic] = ACTIONS(4488),
    [anon_sym_string] = ACTIONS(4488),
    [anon_sym_chandle] = ACTIONS(4488),
    [anon_sym_event] = ACTIONS(4488),
    [anon_sym_byte] = ACTIONS(4488),
    [anon_sym_shortint] = ACTIONS(4488),
    [anon_sym_int] = ACTIONS(4488),
    [anon_sym_longint] = ACTIONS(4488),
    [anon_sym_integer] = ACTIONS(4488),
    [anon_sym_time] = ACTIONS(4488),
    [anon_sym_bit] = ACTIONS(4488),
    [anon_sym_logic] = ACTIONS(4488),
    [anon_sym_reg] = ACTIONS(4488),
    [anon_sym_shortreal] = ACTIONS(4488),
    [anon_sym_real] = ACTIONS(4488),
    [anon_sym_realtime] = ACTIONS(4488),
    [anon_sym_supply0] = ACTIONS(4488),
    [anon_sym_supply1] = ACTIONS(4488),
    [anon_sym_signed] = ACTIONS(4488),
    [anon_sym_unsigned] = ACTIONS(4488),
    [anon_sym_task] = ACTIONS(4488),
    [anon_sym_modport] = ACTIONS(4488),
    [anon_sym_assert] = ACTIONS(4488),
    [anon_sym_property] = ACTIONS(4488),
    [anon_sym_assume] = ACTIONS(4488),
    [anon_sym_cover] = ACTIONS(4488),
    [anon_sym_sequence] = ACTIONS(4488),
    [anon_sym_restrict] = ACTIONS(4488),
    [anon_sym_not] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_case] = ACTIONS(4488),
    [anon_sym_always] = ACTIONS(4488),
    [anon_sym_covergroup] = ACTIONS(4488),
    [anon_sym_let] = ACTIONS(4488),
    [anon_sym_pulldown] = ACTIONS(4488),
    [anon_sym_pullup] = ACTIONS(4488),
    [anon_sym_cmos] = ACTIONS(4488),
    [anon_sym_rcmos] = ACTIONS(4488),
    [anon_sym_bufif0] = ACTIONS(4488),
    [anon_sym_bufif1] = ACTIONS(4488),
    [anon_sym_notif0] = ACTIONS(4488),
    [anon_sym_notif1] = ACTIONS(4488),
    [anon_sym_nmos] = ACTIONS(4488),
    [anon_sym_pmos] = ACTIONS(4488),
    [anon_sym_rnmos] = ACTIONS(4488),
    [anon_sym_rpmos] = ACTIONS(4488),
    [anon_sym_nand] = ACTIONS(4488),
    [anon_sym_nor] = ACTIONS(4488),
    [anon_sym_xor] = ACTIONS(4488),
    [anon_sym_xnor] = ACTIONS(4488),
    [anon_sym_buf] = ACTIONS(4488),
    [anon_sym_tranif0] = ACTIONS(4488),
    [anon_sym_tranif1] = ACTIONS(4488),
    [anon_sym_rtranif1] = ACTIONS(4488),
    [anon_sym_rtranif0] = ACTIONS(4488),
    [anon_sym_tran] = ACTIONS(4488),
    [anon_sym_rtran] = ACTIONS(4488),
    [anon_sym_generate] = ACTIONS(4488),
    [anon_sym_for] = ACTIONS(4488),
    [anon_sym_primitive] = ACTIONS(4488),
    [anon_sym_initial] = ACTIONS(4488),
    [anon_sym_assign] = ACTIONS(4488),
    [anon_sym_alias] = ACTIONS(4488),
    [anon_sym_always_comb] = ACTIONS(4488),
    [anon_sym_always_latch] = ACTIONS(4488),
    [anon_sym_always_ff] = ACTIONS(4488),
    [anon_sym_final] = ACTIONS(4488),
    [anon_sym_global] = ACTIONS(4488),
    [anon_sym_specify] = ACTIONS(4488),
    [anon_sym_LPAREN_STAR] = ACTIONS(4486),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4486),
    [anon_sym_DOLLARunit] = ACTIONS(4486),
  },
  [708] = {
    [ts_builtin_sym_end] = ACTIONS(4492),
    [sym_simple_identifier] = ACTIONS(4494),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4492),
    [anon_sym_BQUOTE] = ACTIONS(4494),
    [aux_sym_id_directive_token1] = ACTIONS(4492),
    [aux_sym_id_directive_token2] = ACTIONS(4492),
    [aux_sym_id_directive_token3] = ACTIONS(4492),
    [aux_sym_id_directive_token4] = ACTIONS(4494),
    [aux_sym_zero_directive_token1] = ACTIONS(4492),
    [aux_sym_zero_directive_token2] = ACTIONS(4492),
    [aux_sym_zero_directive_token3] = ACTIONS(4492),
    [aux_sym_zero_directive_token4] = ACTIONS(4492),
    [aux_sym_zero_directive_token5] = ACTIONS(4492),
    [aux_sym_zero_directive_token6] = ACTIONS(4492),
    [aux_sym_zero_directive_token7] = ACTIONS(4492),
    [aux_sym_zero_directive_token8] = ACTIONS(4492),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4492),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4492),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_begin_keywords_token1] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_endmodule] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4496),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_module] = ACTIONS(4494),
    [anon_sym_macromodule] = ACTIONS(4494),
    [anon_sym_endinterface] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_endprogram] = ACTIONS(4494),
    [anon_sym_program] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_package] = ACTIONS(4494),
    [anon_sym_endpackage] = ACTIONS(4494),
    [anon_sym_timeunit] = ACTIONS(4494),
    [anon_sym_timeprecision] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_input] = ACTIONS(4494),
    [anon_sym_output] = ACTIONS(4494),
    [anon_sym_inout] = ACTIONS(4494),
    [anon_sym_ref] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_specparam] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_modport] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_primitive] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_specify] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [709] = {
    [ts_builtin_sym_end] = ACTIONS(4498),
    [sym_simple_identifier] = ACTIONS(4500),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4498),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4498),
    [anon_sym_BQUOTE] = ACTIONS(4500),
    [aux_sym_id_directive_token1] = ACTIONS(4498),
    [aux_sym_id_directive_token2] = ACTIONS(4498),
    [aux_sym_id_directive_token3] = ACTIONS(4498),
    [aux_sym_id_directive_token4] = ACTIONS(4500),
    [aux_sym_zero_directive_token1] = ACTIONS(4498),
    [aux_sym_zero_directive_token2] = ACTIONS(4498),
    [aux_sym_zero_directive_token3] = ACTIONS(4498),
    [aux_sym_zero_directive_token4] = ACTIONS(4498),
    [aux_sym_zero_directive_token5] = ACTIONS(4498),
    [aux_sym_zero_directive_token6] = ACTIONS(4498),
    [aux_sym_zero_directive_token7] = ACTIONS(4498),
    [aux_sym_zero_directive_token8] = ACTIONS(4498),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4498),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4498),
    [anon_sym_wire] = ACTIONS(4500),
    [anon_sym_tri] = ACTIONS(4500),
    [anon_sym_tri0] = ACTIONS(4500),
    [anon_sym_tri1] = ACTIONS(4500),
    [anon_sym_wand] = ACTIONS(4500),
    [anon_sym_triand] = ACTIONS(4500),
    [anon_sym_wor] = ACTIONS(4500),
    [anon_sym_trior] = ACTIONS(4500),
    [anon_sym_trireg] = ACTIONS(4500),
    [anon_sym_uwire] = ACTIONS(4500),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4498),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4498),
    [aux_sym_begin_keywords_token1] = ACTIONS(4498),
    [anon_sym_SEMI] = ACTIONS(4498),
    [anon_sym_endmodule] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4502),
    [anon_sym_extern] = ACTIONS(4500),
    [anon_sym_module] = ACTIONS(4500),
    [anon_sym_macromodule] = ACTIONS(4500),
    [anon_sym_endinterface] = ACTIONS(4500),
    [anon_sym_interface] = ACTIONS(4500),
    [anon_sym_endprogram] = ACTIONS(4500),
    [anon_sym_program] = ACTIONS(4500),
    [anon_sym_checker] = ACTIONS(4500),
    [anon_sym_virtual] = ACTIONS(4500),
    [anon_sym_class] = ACTIONS(4500),
    [anon_sym_package] = ACTIONS(4500),
    [anon_sym_endpackage] = ACTIONS(4500),
    [anon_sym_timeunit] = ACTIONS(4500),
    [anon_sym_timeprecision] = ACTIONS(4500),
    [anon_sym_type] = ACTIONS(4500),
    [anon_sym_input] = ACTIONS(4500),
    [anon_sym_output] = ACTIONS(4500),
    [anon_sym_inout] = ACTIONS(4500),
    [anon_sym_ref] = ACTIONS(4500),
    [anon_sym_DOLLARfatal] = ACTIONS(4498),
    [anon_sym_DOLLARerror] = ACTIONS(4498),
    [anon_sym_DOLLARwarning] = ACTIONS(4498),
    [anon_sym_DOLLARinfo] = ACTIONS(4498),
    [anon_sym_default] = ACTIONS(4500),
    [anon_sym_clocking] = ACTIONS(4500),
    [anon_sym_defparam] = ACTIONS(4500),
    [anon_sym_bind] = ACTIONS(4500),
    [anon_sym_const] = ACTIONS(4500),
    [anon_sym_function] = ACTIONS(4500),
    [anon_sym_static] = ACTIONS(4500),
    [anon_sym_constraint] = ACTIONS(4500),
    [anon_sym_if] = ACTIONS(4500),
    [anon_sym_else] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4498),
    [anon_sym_localparam] = ACTIONS(4500),
    [anon_sym_parameter] = ACTIONS(4500),
    [anon_sym_specparam] = ACTIONS(4500),
    [anon_sym_var] = ACTIONS(4500),
    [anon_sym_import] = ACTIONS(4500),
    [anon_sym_export] = ACTIONS(4500),
    [anon_sym_genvar] = ACTIONS(4500),
    [anon_sym_interconnect] = ACTIONS(4500),
    [anon_sym_typedef] = ACTIONS(4500),
    [anon_sym_enum] = ACTIONS(4500),
    [anon_sym_struct] = ACTIONS(4500),
    [anon_sym_union] = ACTIONS(4500),
    [anon_sym_nettype] = ACTIONS(4500),
    [anon_sym_automatic] = ACTIONS(4500),
    [anon_sym_string] = ACTIONS(4500),
    [anon_sym_chandle] = ACTIONS(4500),
    [anon_sym_event] = ACTIONS(4500),
    [anon_sym_byte] = ACTIONS(4500),
    [anon_sym_shortint] = ACTIONS(4500),
    [anon_sym_int] = ACTIONS(4500),
    [anon_sym_longint] = ACTIONS(4500),
    [anon_sym_integer] = ACTIONS(4500),
    [anon_sym_time] = ACTIONS(4500),
    [anon_sym_bit] = ACTIONS(4500),
    [anon_sym_logic] = ACTIONS(4500),
    [anon_sym_reg] = ACTIONS(4500),
    [anon_sym_shortreal] = ACTIONS(4500),
    [anon_sym_real] = ACTIONS(4500),
    [anon_sym_realtime] = ACTIONS(4500),
    [anon_sym_supply0] = ACTIONS(4500),
    [anon_sym_supply1] = ACTIONS(4500),
    [anon_sym_signed] = ACTIONS(4500),
    [anon_sym_unsigned] = ACTIONS(4500),
    [anon_sym_task] = ACTIONS(4500),
    [anon_sym_modport] = ACTIONS(4500),
    [anon_sym_assert] = ACTIONS(4500),
    [anon_sym_property] = ACTIONS(4500),
    [anon_sym_assume] = ACTIONS(4500),
    [anon_sym_cover] = ACTIONS(4500),
    [anon_sym_sequence] = ACTIONS(4500),
    [anon_sym_restrict] = ACTIONS(4500),
    [anon_sym_not] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_case] = ACTIONS(4500),
    [anon_sym_always] = ACTIONS(4500),
    [anon_sym_covergroup] = ACTIONS(4500),
    [anon_sym_let] = ACTIONS(4500),
    [anon_sym_pulldown] = ACTIONS(4500),
    [anon_sym_pullup] = ACTIONS(4500),
    [anon_sym_cmos] = ACTIONS(4500),
    [anon_sym_rcmos] = ACTIONS(4500),
    [anon_sym_bufif0] = ACTIONS(4500),
    [anon_sym_bufif1] = ACTIONS(4500),
    [anon_sym_notif0] = ACTIONS(4500),
    [anon_sym_notif1] = ACTIONS(4500),
    [anon_sym_nmos] = ACTIONS(4500),
    [anon_sym_pmos] = ACTIONS(4500),
    [anon_sym_rnmos] = ACTIONS(4500),
    [anon_sym_rpmos] = ACTIONS(4500),
    [anon_sym_nand] = ACTIONS(4500),
    [anon_sym_nor] = ACTIONS(4500),
    [anon_sym_xor] = ACTIONS(4500),
    [anon_sym_xnor] = ACTIONS(4500),
    [anon_sym_buf] = ACTIONS(4500),
    [anon_sym_tranif0] = ACTIONS(4500),
    [anon_sym_tranif1] = ACTIONS(4500),
    [anon_sym_rtranif1] = ACTIONS(4500),
    [anon_sym_rtranif0] = ACTIONS(4500),
    [anon_sym_tran] = ACTIONS(4500),
    [anon_sym_rtran] = ACTIONS(4500),
    [anon_sym_generate] = ACTIONS(4500),
    [anon_sym_for] = ACTIONS(4500),
    [anon_sym_primitive] = ACTIONS(4500),
    [anon_sym_initial] = ACTIONS(4500),
    [anon_sym_assign] = ACTIONS(4500),
    [anon_sym_alias] = ACTIONS(4500),
    [anon_sym_always_comb] = ACTIONS(4500),
    [anon_sym_always_latch] = ACTIONS(4500),
    [anon_sym_always_ff] = ACTIONS(4500),
    [anon_sym_final] = ACTIONS(4500),
    [anon_sym_global] = ACTIONS(4500),
    [anon_sym_specify] = ACTIONS(4500),
    [anon_sym_LPAREN_STAR] = ACTIONS(4498),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4498),
    [anon_sym_DOLLARunit] = ACTIONS(4498),
  },
  [710] = {
    [ts_builtin_sym_end] = ACTIONS(4504),
    [sym_simple_identifier] = ACTIONS(4506),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4504),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4504),
    [anon_sym_BQUOTE] = ACTIONS(4506),
    [aux_sym_id_directive_token1] = ACTIONS(4504),
    [aux_sym_id_directive_token2] = ACTIONS(4504),
    [aux_sym_id_directive_token3] = ACTIONS(4504),
    [aux_sym_id_directive_token4] = ACTIONS(4506),
    [aux_sym_zero_directive_token1] = ACTIONS(4504),
    [aux_sym_zero_directive_token2] = ACTIONS(4504),
    [aux_sym_zero_directive_token3] = ACTIONS(4504),
    [aux_sym_zero_directive_token4] = ACTIONS(4504),
    [aux_sym_zero_directive_token5] = ACTIONS(4504),
    [aux_sym_zero_directive_token6] = ACTIONS(4504),
    [aux_sym_zero_directive_token7] = ACTIONS(4504),
    [aux_sym_zero_directive_token8] = ACTIONS(4504),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4504),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4504),
    [anon_sym_wire] = ACTIONS(4506),
    [anon_sym_tri] = ACTIONS(4506),
    [anon_sym_tri0] = ACTIONS(4506),
    [anon_sym_tri1] = ACTIONS(4506),
    [anon_sym_wand] = ACTIONS(4506),
    [anon_sym_triand] = ACTIONS(4506),
    [anon_sym_wor] = ACTIONS(4506),
    [anon_sym_trior] = ACTIONS(4506),
    [anon_sym_trireg] = ACTIONS(4506),
    [anon_sym_uwire] = ACTIONS(4506),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4504),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4504),
    [aux_sym_begin_keywords_token1] = ACTIONS(4504),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_endmodule] = ACTIONS(4506),
    [anon_sym_COLON] = ACTIONS(4508),
    [anon_sym_extern] = ACTIONS(4506),
    [anon_sym_module] = ACTIONS(4506),
    [anon_sym_macromodule] = ACTIONS(4506),
    [anon_sym_endinterface] = ACTIONS(4506),
    [anon_sym_interface] = ACTIONS(4506),
    [anon_sym_endprogram] = ACTIONS(4506),
    [anon_sym_program] = ACTIONS(4506),
    [anon_sym_checker] = ACTIONS(4506),
    [anon_sym_virtual] = ACTIONS(4506),
    [anon_sym_class] = ACTIONS(4506),
    [anon_sym_package] = ACTIONS(4506),
    [anon_sym_endpackage] = ACTIONS(4506),
    [anon_sym_timeunit] = ACTIONS(4506),
    [anon_sym_timeprecision] = ACTIONS(4506),
    [anon_sym_type] = ACTIONS(4506),
    [anon_sym_input] = ACTIONS(4506),
    [anon_sym_output] = ACTIONS(4506),
    [anon_sym_inout] = ACTIONS(4506),
    [anon_sym_ref] = ACTIONS(4506),
    [anon_sym_DOLLARfatal] = ACTIONS(4504),
    [anon_sym_DOLLARerror] = ACTIONS(4504),
    [anon_sym_DOLLARwarning] = ACTIONS(4504),
    [anon_sym_DOLLARinfo] = ACTIONS(4504),
    [anon_sym_default] = ACTIONS(4506),
    [anon_sym_clocking] = ACTIONS(4506),
    [anon_sym_defparam] = ACTIONS(4506),
    [anon_sym_bind] = ACTIONS(4506),
    [anon_sym_const] = ACTIONS(4506),
    [anon_sym_function] = ACTIONS(4506),
    [anon_sym_static] = ACTIONS(4506),
    [anon_sym_constraint] = ACTIONS(4506),
    [anon_sym_if] = ACTIONS(4506),
    [anon_sym_else] = ACTIONS(4506),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_localparam] = ACTIONS(4506),
    [anon_sym_parameter] = ACTIONS(4506),
    [anon_sym_specparam] = ACTIONS(4506),
    [anon_sym_var] = ACTIONS(4506),
    [anon_sym_import] = ACTIONS(4506),
    [anon_sym_export] = ACTIONS(4506),
    [anon_sym_genvar] = ACTIONS(4506),
    [anon_sym_interconnect] = ACTIONS(4506),
    [anon_sym_typedef] = ACTIONS(4506),
    [anon_sym_enum] = ACTIONS(4506),
    [anon_sym_struct] = ACTIONS(4506),
    [anon_sym_union] = ACTIONS(4506),
    [anon_sym_nettype] = ACTIONS(4506),
    [anon_sym_automatic] = ACTIONS(4506),
    [anon_sym_string] = ACTIONS(4506),
    [anon_sym_chandle] = ACTIONS(4506),
    [anon_sym_event] = ACTIONS(4506),
    [anon_sym_byte] = ACTIONS(4506),
    [anon_sym_shortint] = ACTIONS(4506),
    [anon_sym_int] = ACTIONS(4506),
    [anon_sym_longint] = ACTIONS(4506),
    [anon_sym_integer] = ACTIONS(4506),
    [anon_sym_time] = ACTIONS(4506),
    [anon_sym_bit] = ACTIONS(4506),
    [anon_sym_logic] = ACTIONS(4506),
    [anon_sym_reg] = ACTIONS(4506),
    [anon_sym_shortreal] = ACTIONS(4506),
    [anon_sym_real] = ACTIONS(4506),
    [anon_sym_realtime] = ACTIONS(4506),
    [anon_sym_supply0] = ACTIONS(4506),
    [anon_sym_supply1] = ACTIONS(4506),
    [anon_sym_signed] = ACTIONS(4506),
    [anon_sym_unsigned] = ACTIONS(4506),
    [anon_sym_task] = ACTIONS(4506),
    [anon_sym_modport] = ACTIONS(4506),
    [anon_sym_assert] = ACTIONS(4506),
    [anon_sym_property] = ACTIONS(4506),
    [anon_sym_assume] = ACTIONS(4506),
    [anon_sym_cover] = ACTIONS(4506),
    [anon_sym_sequence] = ACTIONS(4506),
    [anon_sym_restrict] = ACTIONS(4506),
    [anon_sym_not] = ACTIONS(4506),
    [anon_sym_or] = ACTIONS(4506),
    [anon_sym_and] = ACTIONS(4506),
    [anon_sym_case] = ACTIONS(4506),
    [anon_sym_always] = ACTIONS(4506),
    [anon_sym_covergroup] = ACTIONS(4506),
    [anon_sym_let] = ACTIONS(4506),
    [anon_sym_pulldown] = ACTIONS(4506),
    [anon_sym_pullup] = ACTIONS(4506),
    [anon_sym_cmos] = ACTIONS(4506),
    [anon_sym_rcmos] = ACTIONS(4506),
    [anon_sym_bufif0] = ACTIONS(4506),
    [anon_sym_bufif1] = ACTIONS(4506),
    [anon_sym_notif0] = ACTIONS(4506),
    [anon_sym_notif1] = ACTIONS(4506),
    [anon_sym_nmos] = ACTIONS(4506),
    [anon_sym_pmos] = ACTIONS(4506),
    [anon_sym_rnmos] = ACTIONS(4506),
    [anon_sym_rpmos] = ACTIONS(4506),
    [anon_sym_nand] = ACTIONS(4506),
    [anon_sym_nor] = ACTIONS(4506),
    [anon_sym_xor] = ACTIONS(4506),
    [anon_sym_xnor] = ACTIONS(4506),
    [anon_sym_buf] = ACTIONS(4506),
    [anon_sym_tranif0] = ACTIONS(4506),
    [anon_sym_tranif1] = ACTIONS(4506),
    [anon_sym_rtranif1] = ACTIONS(4506),
    [anon_sym_rtranif0] = ACTIONS(4506),
    [anon_sym_tran] = ACTIONS(4506),
    [anon_sym_rtran] = ACTIONS(4506),
    [anon_sym_generate] = ACTIONS(4506),
    [anon_sym_for] = ACTIONS(4506),
    [anon_sym_primitive] = ACTIONS(4506),
    [anon_sym_initial] = ACTIONS(4506),
    [anon_sym_assign] = ACTIONS(4506),
    [anon_sym_alias] = ACTIONS(4506),
    [anon_sym_always_comb] = ACTIONS(4506),
    [anon_sym_always_latch] = ACTIONS(4506),
    [anon_sym_always_ff] = ACTIONS(4506),
    [anon_sym_final] = ACTIONS(4506),
    [anon_sym_global] = ACTIONS(4506),
    [anon_sym_specify] = ACTIONS(4506),
    [anon_sym_LPAREN_STAR] = ACTIONS(4504),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4504),
    [anon_sym_DOLLARunit] = ACTIONS(4504),
  },
  [711] = {
    [ts_builtin_sym_end] = ACTIONS(4510),
    [sym_simple_identifier] = ACTIONS(4512),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4510),
    [anon_sym_BQUOTE] = ACTIONS(4512),
    [aux_sym_id_directive_token1] = ACTIONS(4510),
    [aux_sym_id_directive_token2] = ACTIONS(4510),
    [aux_sym_id_directive_token3] = ACTIONS(4510),
    [aux_sym_id_directive_token4] = ACTIONS(4512),
    [aux_sym_zero_directive_token1] = ACTIONS(4510),
    [aux_sym_zero_directive_token2] = ACTIONS(4510),
    [aux_sym_zero_directive_token3] = ACTIONS(4510),
    [aux_sym_zero_directive_token4] = ACTIONS(4510),
    [aux_sym_zero_directive_token5] = ACTIONS(4510),
    [aux_sym_zero_directive_token6] = ACTIONS(4510),
    [aux_sym_zero_directive_token7] = ACTIONS(4510),
    [aux_sym_zero_directive_token8] = ACTIONS(4510),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4510),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4510),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_begin_keywords_token1] = ACTIONS(4510),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_endmodule] = ACTIONS(4512),
    [anon_sym_COLON] = ACTIONS(4514),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_module] = ACTIONS(4512),
    [anon_sym_macromodule] = ACTIONS(4512),
    [anon_sym_endinterface] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_endprogram] = ACTIONS(4512),
    [anon_sym_program] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_package] = ACTIONS(4512),
    [anon_sym_endpackage] = ACTIONS(4512),
    [anon_sym_timeunit] = ACTIONS(4512),
    [anon_sym_timeprecision] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_input] = ACTIONS(4512),
    [anon_sym_output] = ACTIONS(4512),
    [anon_sym_inout] = ACTIONS(4512),
    [anon_sym_ref] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_specparam] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_modport] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_primitive] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_specify] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [712] = {
    [ts_builtin_sym_end] = ACTIONS(4516),
    [sym_simple_identifier] = ACTIONS(4518),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4516),
    [anon_sym_BQUOTE] = ACTIONS(4518),
    [aux_sym_id_directive_token1] = ACTIONS(4516),
    [aux_sym_id_directive_token2] = ACTIONS(4516),
    [aux_sym_id_directive_token3] = ACTIONS(4516),
    [aux_sym_id_directive_token4] = ACTIONS(4518),
    [aux_sym_zero_directive_token1] = ACTIONS(4516),
    [aux_sym_zero_directive_token2] = ACTIONS(4516),
    [aux_sym_zero_directive_token3] = ACTIONS(4516),
    [aux_sym_zero_directive_token4] = ACTIONS(4516),
    [aux_sym_zero_directive_token5] = ACTIONS(4516),
    [aux_sym_zero_directive_token6] = ACTIONS(4516),
    [aux_sym_zero_directive_token7] = ACTIONS(4516),
    [aux_sym_zero_directive_token8] = ACTIONS(4516),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4516),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4516),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_begin_keywords_token1] = ACTIONS(4516),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_endmodule] = ACTIONS(4518),
    [anon_sym_COLON] = ACTIONS(4520),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_module] = ACTIONS(4518),
    [anon_sym_macromodule] = ACTIONS(4518),
    [anon_sym_endinterface] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_endprogram] = ACTIONS(4518),
    [anon_sym_program] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_package] = ACTIONS(4518),
    [anon_sym_endpackage] = ACTIONS(4518),
    [anon_sym_timeunit] = ACTIONS(4518),
    [anon_sym_timeprecision] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_input] = ACTIONS(4518),
    [anon_sym_output] = ACTIONS(4518),
    [anon_sym_inout] = ACTIONS(4518),
    [anon_sym_ref] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_specparam] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_modport] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_primitive] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_specify] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [713] = {
    [ts_builtin_sym_end] = ACTIONS(4522),
    [sym_simple_identifier] = ACTIONS(4524),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4522),
    [anon_sym_BQUOTE] = ACTIONS(4524),
    [aux_sym_id_directive_token1] = ACTIONS(4522),
    [aux_sym_id_directive_token2] = ACTIONS(4522),
    [aux_sym_id_directive_token3] = ACTIONS(4522),
    [aux_sym_id_directive_token4] = ACTIONS(4524),
    [aux_sym_zero_directive_token1] = ACTIONS(4522),
    [aux_sym_zero_directive_token2] = ACTIONS(4522),
    [aux_sym_zero_directive_token3] = ACTIONS(4522),
    [aux_sym_zero_directive_token4] = ACTIONS(4522),
    [aux_sym_zero_directive_token5] = ACTIONS(4522),
    [aux_sym_zero_directive_token6] = ACTIONS(4522),
    [aux_sym_zero_directive_token7] = ACTIONS(4522),
    [aux_sym_zero_directive_token8] = ACTIONS(4522),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4522),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4522),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_begin_keywords_token1] = ACTIONS(4522),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_endmodule] = ACTIONS(4524),
    [anon_sym_COLON] = ACTIONS(4526),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_module] = ACTIONS(4524),
    [anon_sym_macromodule] = ACTIONS(4524),
    [anon_sym_endinterface] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_endprogram] = ACTIONS(4524),
    [anon_sym_program] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_package] = ACTIONS(4524),
    [anon_sym_endpackage] = ACTIONS(4524),
    [anon_sym_timeunit] = ACTIONS(4524),
    [anon_sym_timeprecision] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_input] = ACTIONS(4524),
    [anon_sym_output] = ACTIONS(4524),
    [anon_sym_inout] = ACTIONS(4524),
    [anon_sym_ref] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_specparam] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_modport] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_primitive] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_specify] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [714] = {
    [ts_builtin_sym_end] = ACTIONS(4528),
    [sym_simple_identifier] = ACTIONS(4530),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4528),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4528),
    [anon_sym_BQUOTE] = ACTIONS(4530),
    [aux_sym_id_directive_token1] = ACTIONS(4528),
    [aux_sym_id_directive_token2] = ACTIONS(4528),
    [aux_sym_id_directive_token3] = ACTIONS(4528),
    [aux_sym_id_directive_token4] = ACTIONS(4530),
    [aux_sym_zero_directive_token1] = ACTIONS(4528),
    [aux_sym_zero_directive_token2] = ACTIONS(4528),
    [aux_sym_zero_directive_token3] = ACTIONS(4528),
    [aux_sym_zero_directive_token4] = ACTIONS(4528),
    [aux_sym_zero_directive_token5] = ACTIONS(4528),
    [aux_sym_zero_directive_token6] = ACTIONS(4528),
    [aux_sym_zero_directive_token7] = ACTIONS(4528),
    [aux_sym_zero_directive_token8] = ACTIONS(4528),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4528),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4528),
    [anon_sym_wire] = ACTIONS(4530),
    [anon_sym_tri] = ACTIONS(4530),
    [anon_sym_tri0] = ACTIONS(4530),
    [anon_sym_tri1] = ACTIONS(4530),
    [anon_sym_wand] = ACTIONS(4530),
    [anon_sym_triand] = ACTIONS(4530),
    [anon_sym_wor] = ACTIONS(4530),
    [anon_sym_trior] = ACTIONS(4530),
    [anon_sym_trireg] = ACTIONS(4530),
    [anon_sym_uwire] = ACTIONS(4530),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4528),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4528),
    [aux_sym_begin_keywords_token1] = ACTIONS(4528),
    [anon_sym_SEMI] = ACTIONS(4528),
    [anon_sym_endmodule] = ACTIONS(4530),
    [anon_sym_COLON] = ACTIONS(4532),
    [anon_sym_extern] = ACTIONS(4530),
    [anon_sym_module] = ACTIONS(4530),
    [anon_sym_macromodule] = ACTIONS(4530),
    [anon_sym_endinterface] = ACTIONS(4530),
    [anon_sym_interface] = ACTIONS(4530),
    [anon_sym_endprogram] = ACTIONS(4530),
    [anon_sym_program] = ACTIONS(4530),
    [anon_sym_checker] = ACTIONS(4530),
    [anon_sym_virtual] = ACTIONS(4530),
    [anon_sym_class] = ACTIONS(4530),
    [anon_sym_package] = ACTIONS(4530),
    [anon_sym_endpackage] = ACTIONS(4530),
    [anon_sym_timeunit] = ACTIONS(4530),
    [anon_sym_timeprecision] = ACTIONS(4530),
    [anon_sym_type] = ACTIONS(4530),
    [anon_sym_input] = ACTIONS(4530),
    [anon_sym_output] = ACTIONS(4530),
    [anon_sym_inout] = ACTIONS(4530),
    [anon_sym_ref] = ACTIONS(4530),
    [anon_sym_DOLLARfatal] = ACTIONS(4528),
    [anon_sym_DOLLARerror] = ACTIONS(4528),
    [anon_sym_DOLLARwarning] = ACTIONS(4528),
    [anon_sym_DOLLARinfo] = ACTIONS(4528),
    [anon_sym_default] = ACTIONS(4530),
    [anon_sym_clocking] = ACTIONS(4530),
    [anon_sym_defparam] = ACTIONS(4530),
    [anon_sym_bind] = ACTIONS(4530),
    [anon_sym_const] = ACTIONS(4530),
    [anon_sym_function] = ACTIONS(4530),
    [anon_sym_static] = ACTIONS(4530),
    [anon_sym_constraint] = ACTIONS(4530),
    [anon_sym_if] = ACTIONS(4530),
    [anon_sym_else] = ACTIONS(4530),
    [anon_sym_LBRACK] = ACTIONS(4528),
    [anon_sym_localparam] = ACTIONS(4530),
    [anon_sym_parameter] = ACTIONS(4530),
    [anon_sym_specparam] = ACTIONS(4530),
    [anon_sym_var] = ACTIONS(4530),
    [anon_sym_import] = ACTIONS(4530),
    [anon_sym_export] = ACTIONS(4530),
    [anon_sym_genvar] = ACTIONS(4530),
    [anon_sym_interconnect] = ACTIONS(4530),
    [anon_sym_typedef] = ACTIONS(4530),
    [anon_sym_enum] = ACTIONS(4530),
    [anon_sym_struct] = ACTIONS(4530),
    [anon_sym_union] = ACTIONS(4530),
    [anon_sym_nettype] = ACTIONS(4530),
    [anon_sym_automatic] = ACTIONS(4530),
    [anon_sym_string] = ACTIONS(4530),
    [anon_sym_chandle] = ACTIONS(4530),
    [anon_sym_event] = ACTIONS(4530),
    [anon_sym_byte] = ACTIONS(4530),
    [anon_sym_shortint] = ACTIONS(4530),
    [anon_sym_int] = ACTIONS(4530),
    [anon_sym_longint] = ACTIONS(4530),
    [anon_sym_integer] = ACTIONS(4530),
    [anon_sym_time] = ACTIONS(4530),
    [anon_sym_bit] = ACTIONS(4530),
    [anon_sym_logic] = ACTIONS(4530),
    [anon_sym_reg] = ACTIONS(4530),
    [anon_sym_shortreal] = ACTIONS(4530),
    [anon_sym_real] = ACTIONS(4530),
    [anon_sym_realtime] = ACTIONS(4530),
    [anon_sym_supply0] = ACTIONS(4530),
    [anon_sym_supply1] = ACTIONS(4530),
    [anon_sym_signed] = ACTIONS(4530),
    [anon_sym_unsigned] = ACTIONS(4530),
    [anon_sym_task] = ACTIONS(4530),
    [anon_sym_modport] = ACTIONS(4530),
    [anon_sym_assert] = ACTIONS(4530),
    [anon_sym_property] = ACTIONS(4530),
    [anon_sym_assume] = ACTIONS(4530),
    [anon_sym_cover] = ACTIONS(4530),
    [anon_sym_sequence] = ACTIONS(4530),
    [anon_sym_restrict] = ACTIONS(4530),
    [anon_sym_not] = ACTIONS(4530),
    [anon_sym_or] = ACTIONS(4530),
    [anon_sym_and] = ACTIONS(4530),
    [anon_sym_case] = ACTIONS(4530),
    [anon_sym_always] = ACTIONS(4530),
    [anon_sym_covergroup] = ACTIONS(4530),
    [anon_sym_let] = ACTIONS(4530),
    [anon_sym_pulldown] = ACTIONS(4530),
    [anon_sym_pullup] = ACTIONS(4530),
    [anon_sym_cmos] = ACTIONS(4530),
    [anon_sym_rcmos] = ACTIONS(4530),
    [anon_sym_bufif0] = ACTIONS(4530),
    [anon_sym_bufif1] = ACTIONS(4530),
    [anon_sym_notif0] = ACTIONS(4530),
    [anon_sym_notif1] = ACTIONS(4530),
    [anon_sym_nmos] = ACTIONS(4530),
    [anon_sym_pmos] = ACTIONS(4530),
    [anon_sym_rnmos] = ACTIONS(4530),
    [anon_sym_rpmos] = ACTIONS(4530),
    [anon_sym_nand] = ACTIONS(4530),
    [anon_sym_nor] = ACTIONS(4530),
    [anon_sym_xor] = ACTIONS(4530),
    [anon_sym_xnor] = ACTIONS(4530),
    [anon_sym_buf] = ACTIONS(4530),
    [anon_sym_tranif0] = ACTIONS(4530),
    [anon_sym_tranif1] = ACTIONS(4530),
    [anon_sym_rtranif1] = ACTIONS(4530),
    [anon_sym_rtranif0] = ACTIONS(4530),
    [anon_sym_tran] = ACTIONS(4530),
    [anon_sym_rtran] = ACTIONS(4530),
    [anon_sym_generate] = ACTIONS(4530),
    [anon_sym_for] = ACTIONS(4530),
    [anon_sym_primitive] = ACTIONS(4530),
    [anon_sym_initial] = ACTIONS(4530),
    [anon_sym_assign] = ACTIONS(4530),
    [anon_sym_alias] = ACTIONS(4530),
    [anon_sym_always_comb] = ACTIONS(4530),
    [anon_sym_always_latch] = ACTIONS(4530),
    [anon_sym_always_ff] = ACTIONS(4530),
    [anon_sym_final] = ACTIONS(4530),
    [anon_sym_global] = ACTIONS(4530),
    [anon_sym_specify] = ACTIONS(4530),
    [anon_sym_LPAREN_STAR] = ACTIONS(4528),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4528),
    [anon_sym_DOLLARunit] = ACTIONS(4528),
  },
  [715] = {
    [ts_builtin_sym_end] = ACTIONS(4534),
    [sym_simple_identifier] = ACTIONS(4536),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4534),
    [anon_sym_BQUOTE] = ACTIONS(4536),
    [aux_sym_id_directive_token1] = ACTIONS(4534),
    [aux_sym_id_directive_token2] = ACTIONS(4534),
    [aux_sym_id_directive_token3] = ACTIONS(4534),
    [aux_sym_id_directive_token4] = ACTIONS(4536),
    [aux_sym_zero_directive_token1] = ACTIONS(4534),
    [aux_sym_zero_directive_token2] = ACTIONS(4534),
    [aux_sym_zero_directive_token3] = ACTIONS(4534),
    [aux_sym_zero_directive_token4] = ACTIONS(4534),
    [aux_sym_zero_directive_token5] = ACTIONS(4534),
    [aux_sym_zero_directive_token6] = ACTIONS(4534),
    [aux_sym_zero_directive_token7] = ACTIONS(4534),
    [aux_sym_zero_directive_token8] = ACTIONS(4534),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4534),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4534),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_begin_keywords_token1] = ACTIONS(4534),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_endmodule] = ACTIONS(4536),
    [anon_sym_COLON] = ACTIONS(4538),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_module] = ACTIONS(4536),
    [anon_sym_macromodule] = ACTIONS(4536),
    [anon_sym_endinterface] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_endprogram] = ACTIONS(4536),
    [anon_sym_program] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_package] = ACTIONS(4536),
    [anon_sym_endpackage] = ACTIONS(4536),
    [anon_sym_timeunit] = ACTIONS(4536),
    [anon_sym_timeprecision] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_input] = ACTIONS(4536),
    [anon_sym_output] = ACTIONS(4536),
    [anon_sym_inout] = ACTIONS(4536),
    [anon_sym_ref] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_specparam] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_modport] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_primitive] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_specify] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [716] = {
    [ts_builtin_sym_end] = ACTIONS(4540),
    [sym_simple_identifier] = ACTIONS(4542),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4540),
    [anon_sym_BQUOTE] = ACTIONS(4542),
    [aux_sym_id_directive_token1] = ACTIONS(4540),
    [aux_sym_id_directive_token2] = ACTIONS(4540),
    [aux_sym_id_directive_token3] = ACTIONS(4540),
    [aux_sym_id_directive_token4] = ACTIONS(4542),
    [aux_sym_zero_directive_token1] = ACTIONS(4540),
    [aux_sym_zero_directive_token2] = ACTIONS(4540),
    [aux_sym_zero_directive_token3] = ACTIONS(4540),
    [aux_sym_zero_directive_token4] = ACTIONS(4540),
    [aux_sym_zero_directive_token5] = ACTIONS(4540),
    [aux_sym_zero_directive_token6] = ACTIONS(4540),
    [aux_sym_zero_directive_token7] = ACTIONS(4540),
    [aux_sym_zero_directive_token8] = ACTIONS(4540),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4540),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4540),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_begin_keywords_token1] = ACTIONS(4540),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_endmodule] = ACTIONS(4542),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_module] = ACTIONS(4542),
    [anon_sym_macromodule] = ACTIONS(4542),
    [anon_sym_endinterface] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_endprogram] = ACTIONS(4542),
    [anon_sym_program] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_package] = ACTIONS(4542),
    [anon_sym_endpackage] = ACTIONS(4542),
    [anon_sym_timeunit] = ACTIONS(4542),
    [anon_sym_timeprecision] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_input] = ACTIONS(4542),
    [anon_sym_output] = ACTIONS(4542),
    [anon_sym_inout] = ACTIONS(4542),
    [anon_sym_ref] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_specparam] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_modport] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_primitive] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_endclocking] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_specify] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [717] = {
    [ts_builtin_sym_end] = ACTIONS(4540),
    [sym_simple_identifier] = ACTIONS(4542),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4540),
    [anon_sym_BQUOTE] = ACTIONS(4542),
    [aux_sym_id_directive_token1] = ACTIONS(4540),
    [aux_sym_id_directive_token2] = ACTIONS(4540),
    [aux_sym_id_directive_token3] = ACTIONS(4540),
    [aux_sym_id_directive_token4] = ACTIONS(4542),
    [aux_sym_zero_directive_token1] = ACTIONS(4540),
    [aux_sym_zero_directive_token2] = ACTIONS(4540),
    [aux_sym_zero_directive_token3] = ACTIONS(4540),
    [aux_sym_zero_directive_token4] = ACTIONS(4540),
    [aux_sym_zero_directive_token5] = ACTIONS(4540),
    [aux_sym_zero_directive_token6] = ACTIONS(4540),
    [aux_sym_zero_directive_token7] = ACTIONS(4540),
    [aux_sym_zero_directive_token8] = ACTIONS(4540),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4540),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4540),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4540),
    [aux_sym_begin_keywords_token1] = ACTIONS(4540),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_endmodule] = ACTIONS(4542),
    [anon_sym_COLON] = ACTIONS(4544),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_module] = ACTIONS(4542),
    [anon_sym_macromodule] = ACTIONS(4542),
    [anon_sym_endinterface] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_endprogram] = ACTIONS(4542),
    [anon_sym_program] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_package] = ACTIONS(4542),
    [anon_sym_endpackage] = ACTIONS(4542),
    [anon_sym_timeunit] = ACTIONS(4542),
    [anon_sym_timeprecision] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_input] = ACTIONS(4542),
    [anon_sym_output] = ACTIONS(4542),
    [anon_sym_inout] = ACTIONS(4542),
    [anon_sym_ref] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_specparam] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_modport] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_primitive] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_specify] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [718] = {
    [ts_builtin_sym_end] = ACTIONS(4546),
    [sym_simple_identifier] = ACTIONS(4548),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4546),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4546),
    [anon_sym_BQUOTE] = ACTIONS(4548),
    [aux_sym_id_directive_token1] = ACTIONS(4546),
    [aux_sym_id_directive_token2] = ACTIONS(4546),
    [aux_sym_id_directive_token3] = ACTIONS(4546),
    [aux_sym_id_directive_token4] = ACTIONS(4548),
    [aux_sym_zero_directive_token1] = ACTIONS(4546),
    [aux_sym_zero_directive_token2] = ACTIONS(4546),
    [aux_sym_zero_directive_token3] = ACTIONS(4546),
    [aux_sym_zero_directive_token4] = ACTIONS(4546),
    [aux_sym_zero_directive_token5] = ACTIONS(4546),
    [aux_sym_zero_directive_token6] = ACTIONS(4546),
    [aux_sym_zero_directive_token7] = ACTIONS(4546),
    [aux_sym_zero_directive_token8] = ACTIONS(4546),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4546),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4546),
    [anon_sym_wire] = ACTIONS(4548),
    [anon_sym_tri] = ACTIONS(4548),
    [anon_sym_tri0] = ACTIONS(4548),
    [anon_sym_tri1] = ACTIONS(4548),
    [anon_sym_wand] = ACTIONS(4548),
    [anon_sym_triand] = ACTIONS(4548),
    [anon_sym_wor] = ACTIONS(4548),
    [anon_sym_trior] = ACTIONS(4548),
    [anon_sym_trireg] = ACTIONS(4548),
    [anon_sym_uwire] = ACTIONS(4548),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4546),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4546),
    [aux_sym_begin_keywords_token1] = ACTIONS(4546),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_endmodule] = ACTIONS(4548),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_extern] = ACTIONS(4548),
    [anon_sym_module] = ACTIONS(4548),
    [anon_sym_macromodule] = ACTIONS(4548),
    [anon_sym_endinterface] = ACTIONS(4548),
    [anon_sym_interface] = ACTIONS(4548),
    [anon_sym_endprogram] = ACTIONS(4548),
    [anon_sym_program] = ACTIONS(4548),
    [anon_sym_checker] = ACTIONS(4548),
    [anon_sym_virtual] = ACTIONS(4548),
    [anon_sym_class] = ACTIONS(4548),
    [anon_sym_package] = ACTIONS(4548),
    [anon_sym_endpackage] = ACTIONS(4548),
    [anon_sym_timeunit] = ACTIONS(4548),
    [anon_sym_timeprecision] = ACTIONS(4548),
    [anon_sym_type] = ACTIONS(4548),
    [anon_sym_input] = ACTIONS(4548),
    [anon_sym_output] = ACTIONS(4548),
    [anon_sym_inout] = ACTIONS(4548),
    [anon_sym_ref] = ACTIONS(4548),
    [anon_sym_DOLLARfatal] = ACTIONS(4546),
    [anon_sym_DOLLARerror] = ACTIONS(4546),
    [anon_sym_DOLLARwarning] = ACTIONS(4546),
    [anon_sym_DOLLARinfo] = ACTIONS(4546),
    [anon_sym_default] = ACTIONS(4548),
    [anon_sym_clocking] = ACTIONS(4548),
    [anon_sym_defparam] = ACTIONS(4548),
    [anon_sym_bind] = ACTIONS(4548),
    [anon_sym_const] = ACTIONS(4548),
    [anon_sym_function] = ACTIONS(4548),
    [anon_sym_static] = ACTIONS(4548),
    [anon_sym_constraint] = ACTIONS(4548),
    [anon_sym_if] = ACTIONS(4548),
    [anon_sym_else] = ACTIONS(4548),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_localparam] = ACTIONS(4548),
    [anon_sym_parameter] = ACTIONS(4548),
    [anon_sym_specparam] = ACTIONS(4548),
    [anon_sym_var] = ACTIONS(4548),
    [anon_sym_import] = ACTIONS(4548),
    [anon_sym_export] = ACTIONS(4548),
    [anon_sym_genvar] = ACTIONS(4548),
    [anon_sym_interconnect] = ACTIONS(4548),
    [anon_sym_typedef] = ACTIONS(4548),
    [anon_sym_enum] = ACTIONS(4548),
    [anon_sym_struct] = ACTIONS(4548),
    [anon_sym_union] = ACTIONS(4548),
    [anon_sym_nettype] = ACTIONS(4548),
    [anon_sym_automatic] = ACTIONS(4548),
    [anon_sym_string] = ACTIONS(4548),
    [anon_sym_chandle] = ACTIONS(4548),
    [anon_sym_event] = ACTIONS(4548),
    [anon_sym_byte] = ACTIONS(4548),
    [anon_sym_shortint] = ACTIONS(4548),
    [anon_sym_int] = ACTIONS(4548),
    [anon_sym_longint] = ACTIONS(4548),
    [anon_sym_integer] = ACTIONS(4548),
    [anon_sym_time] = ACTIONS(4548),
    [anon_sym_bit] = ACTIONS(4548),
    [anon_sym_logic] = ACTIONS(4548),
    [anon_sym_reg] = ACTIONS(4548),
    [anon_sym_shortreal] = ACTIONS(4548),
    [anon_sym_real] = ACTIONS(4548),
    [anon_sym_realtime] = ACTIONS(4548),
    [anon_sym_supply0] = ACTIONS(4548),
    [anon_sym_supply1] = ACTIONS(4548),
    [anon_sym_signed] = ACTIONS(4548),
    [anon_sym_unsigned] = ACTIONS(4548),
    [anon_sym_task] = ACTIONS(4548),
    [anon_sym_modport] = ACTIONS(4548),
    [anon_sym_assert] = ACTIONS(4548),
    [anon_sym_property] = ACTIONS(4548),
    [anon_sym_assume] = ACTIONS(4548),
    [anon_sym_cover] = ACTIONS(4548),
    [anon_sym_sequence] = ACTIONS(4548),
    [anon_sym_restrict] = ACTIONS(4548),
    [anon_sym_not] = ACTIONS(4548),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_and] = ACTIONS(4548),
    [anon_sym_case] = ACTIONS(4548),
    [anon_sym_always] = ACTIONS(4548),
    [anon_sym_covergroup] = ACTIONS(4548),
    [anon_sym_let] = ACTIONS(4548),
    [anon_sym_pulldown] = ACTIONS(4548),
    [anon_sym_pullup] = ACTIONS(4548),
    [anon_sym_cmos] = ACTIONS(4548),
    [anon_sym_rcmos] = ACTIONS(4548),
    [anon_sym_bufif0] = ACTIONS(4548),
    [anon_sym_bufif1] = ACTIONS(4548),
    [anon_sym_notif0] = ACTIONS(4548),
    [anon_sym_notif1] = ACTIONS(4548),
    [anon_sym_nmos] = ACTIONS(4548),
    [anon_sym_pmos] = ACTIONS(4548),
    [anon_sym_rnmos] = ACTIONS(4548),
    [anon_sym_rpmos] = ACTIONS(4548),
    [anon_sym_nand] = ACTIONS(4548),
    [anon_sym_nor] = ACTIONS(4548),
    [anon_sym_xor] = ACTIONS(4548),
    [anon_sym_xnor] = ACTIONS(4548),
    [anon_sym_buf] = ACTIONS(4548),
    [anon_sym_tranif0] = ACTIONS(4548),
    [anon_sym_tranif1] = ACTIONS(4548),
    [anon_sym_rtranif1] = ACTIONS(4548),
    [anon_sym_rtranif0] = ACTIONS(4548),
    [anon_sym_tran] = ACTIONS(4548),
    [anon_sym_rtran] = ACTIONS(4548),
    [anon_sym_generate] = ACTIONS(4548),
    [anon_sym_for] = ACTIONS(4548),
    [anon_sym_primitive] = ACTIONS(4548),
    [anon_sym_initial] = ACTIONS(4548),
    [anon_sym_assign] = ACTIONS(4548),
    [anon_sym_alias] = ACTIONS(4548),
    [anon_sym_always_comb] = ACTIONS(4548),
    [anon_sym_always_latch] = ACTIONS(4548),
    [anon_sym_always_ff] = ACTIONS(4548),
    [anon_sym_final] = ACTIONS(4548),
    [anon_sym_global] = ACTIONS(4548),
    [anon_sym_specify] = ACTIONS(4548),
    [anon_sym_LPAREN_STAR] = ACTIONS(4546),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4546),
    [anon_sym_DOLLARunit] = ACTIONS(4546),
  },
  [719] = {
    [ts_builtin_sym_end] = ACTIONS(4552),
    [sym_simple_identifier] = ACTIONS(4554),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4552),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4552),
    [anon_sym_BQUOTE] = ACTIONS(4554),
    [aux_sym_id_directive_token1] = ACTIONS(4552),
    [aux_sym_id_directive_token2] = ACTIONS(4552),
    [aux_sym_id_directive_token3] = ACTIONS(4552),
    [aux_sym_id_directive_token4] = ACTIONS(4554),
    [aux_sym_zero_directive_token1] = ACTIONS(4552),
    [aux_sym_zero_directive_token2] = ACTIONS(4552),
    [aux_sym_zero_directive_token3] = ACTIONS(4552),
    [aux_sym_zero_directive_token4] = ACTIONS(4552),
    [aux_sym_zero_directive_token5] = ACTIONS(4552),
    [aux_sym_zero_directive_token6] = ACTIONS(4552),
    [aux_sym_zero_directive_token7] = ACTIONS(4552),
    [aux_sym_zero_directive_token8] = ACTIONS(4552),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4552),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4552),
    [anon_sym_wire] = ACTIONS(4554),
    [anon_sym_tri] = ACTIONS(4554),
    [anon_sym_tri0] = ACTIONS(4554),
    [anon_sym_tri1] = ACTIONS(4554),
    [anon_sym_wand] = ACTIONS(4554),
    [anon_sym_triand] = ACTIONS(4554),
    [anon_sym_wor] = ACTIONS(4554),
    [anon_sym_trior] = ACTIONS(4554),
    [anon_sym_trireg] = ACTIONS(4554),
    [anon_sym_uwire] = ACTIONS(4554),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4552),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4552),
    [aux_sym_begin_keywords_token1] = ACTIONS(4552),
    [anon_sym_SEMI] = ACTIONS(4552),
    [anon_sym_endmodule] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4556),
    [anon_sym_extern] = ACTIONS(4554),
    [anon_sym_module] = ACTIONS(4554),
    [anon_sym_macromodule] = ACTIONS(4554),
    [anon_sym_endinterface] = ACTIONS(4554),
    [anon_sym_interface] = ACTIONS(4554),
    [anon_sym_endprogram] = ACTIONS(4554),
    [anon_sym_program] = ACTIONS(4554),
    [anon_sym_checker] = ACTIONS(4554),
    [anon_sym_virtual] = ACTIONS(4554),
    [anon_sym_class] = ACTIONS(4554),
    [anon_sym_package] = ACTIONS(4554),
    [anon_sym_endpackage] = ACTIONS(4554),
    [anon_sym_timeunit] = ACTIONS(4554),
    [anon_sym_timeprecision] = ACTIONS(4554),
    [anon_sym_type] = ACTIONS(4554),
    [anon_sym_input] = ACTIONS(4554),
    [anon_sym_output] = ACTIONS(4554),
    [anon_sym_inout] = ACTIONS(4554),
    [anon_sym_ref] = ACTIONS(4554),
    [anon_sym_DOLLARfatal] = ACTIONS(4552),
    [anon_sym_DOLLARerror] = ACTIONS(4552),
    [anon_sym_DOLLARwarning] = ACTIONS(4552),
    [anon_sym_DOLLARinfo] = ACTIONS(4552),
    [anon_sym_default] = ACTIONS(4554),
    [anon_sym_clocking] = ACTIONS(4554),
    [anon_sym_defparam] = ACTIONS(4554),
    [anon_sym_bind] = ACTIONS(4554),
    [anon_sym_const] = ACTIONS(4554),
    [anon_sym_function] = ACTIONS(4554),
    [anon_sym_static] = ACTIONS(4554),
    [anon_sym_constraint] = ACTIONS(4554),
    [anon_sym_if] = ACTIONS(4554),
    [anon_sym_else] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4552),
    [anon_sym_localparam] = ACTIONS(4554),
    [anon_sym_parameter] = ACTIONS(4554),
    [anon_sym_specparam] = ACTIONS(4554),
    [anon_sym_var] = ACTIONS(4554),
    [anon_sym_import] = ACTIONS(4554),
    [anon_sym_export] = ACTIONS(4554),
    [anon_sym_genvar] = ACTIONS(4554),
    [anon_sym_interconnect] = ACTIONS(4554),
    [anon_sym_typedef] = ACTIONS(4554),
    [anon_sym_enum] = ACTIONS(4554),
    [anon_sym_struct] = ACTIONS(4554),
    [anon_sym_union] = ACTIONS(4554),
    [anon_sym_nettype] = ACTIONS(4554),
    [anon_sym_automatic] = ACTIONS(4554),
    [anon_sym_string] = ACTIONS(4554),
    [anon_sym_chandle] = ACTIONS(4554),
    [anon_sym_event] = ACTIONS(4554),
    [anon_sym_byte] = ACTIONS(4554),
    [anon_sym_shortint] = ACTIONS(4554),
    [anon_sym_int] = ACTIONS(4554),
    [anon_sym_longint] = ACTIONS(4554),
    [anon_sym_integer] = ACTIONS(4554),
    [anon_sym_time] = ACTIONS(4554),
    [anon_sym_bit] = ACTIONS(4554),
    [anon_sym_logic] = ACTIONS(4554),
    [anon_sym_reg] = ACTIONS(4554),
    [anon_sym_shortreal] = ACTIONS(4554),
    [anon_sym_real] = ACTIONS(4554),
    [anon_sym_realtime] = ACTIONS(4554),
    [anon_sym_supply0] = ACTIONS(4554),
    [anon_sym_supply1] = ACTIONS(4554),
    [anon_sym_signed] = ACTIONS(4554),
    [anon_sym_unsigned] = ACTIONS(4554),
    [anon_sym_task] = ACTIONS(4554),
    [anon_sym_modport] = ACTIONS(4554),
    [anon_sym_assert] = ACTIONS(4554),
    [anon_sym_property] = ACTIONS(4554),
    [anon_sym_assume] = ACTIONS(4554),
    [anon_sym_cover] = ACTIONS(4554),
    [anon_sym_sequence] = ACTIONS(4554),
    [anon_sym_restrict] = ACTIONS(4554),
    [anon_sym_not] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_case] = ACTIONS(4554),
    [anon_sym_always] = ACTIONS(4554),
    [anon_sym_covergroup] = ACTIONS(4554),
    [anon_sym_let] = ACTIONS(4554),
    [anon_sym_pulldown] = ACTIONS(4554),
    [anon_sym_pullup] = ACTIONS(4554),
    [anon_sym_cmos] = ACTIONS(4554),
    [anon_sym_rcmos] = ACTIONS(4554),
    [anon_sym_bufif0] = ACTIONS(4554),
    [anon_sym_bufif1] = ACTIONS(4554),
    [anon_sym_notif0] = ACTIONS(4554),
    [anon_sym_notif1] = ACTIONS(4554),
    [anon_sym_nmos] = ACTIONS(4554),
    [anon_sym_pmos] = ACTIONS(4554),
    [anon_sym_rnmos] = ACTIONS(4554),
    [anon_sym_rpmos] = ACTIONS(4554),
    [anon_sym_nand] = ACTIONS(4554),
    [anon_sym_nor] = ACTIONS(4554),
    [anon_sym_xor] = ACTIONS(4554),
    [anon_sym_xnor] = ACTIONS(4554),
    [anon_sym_buf] = ACTIONS(4554),
    [anon_sym_tranif0] = ACTIONS(4554),
    [anon_sym_tranif1] = ACTIONS(4554),
    [anon_sym_rtranif1] = ACTIONS(4554),
    [anon_sym_rtranif0] = ACTIONS(4554),
    [anon_sym_tran] = ACTIONS(4554),
    [anon_sym_rtran] = ACTIONS(4554),
    [anon_sym_generate] = ACTIONS(4554),
    [anon_sym_for] = ACTIONS(4554),
    [anon_sym_primitive] = ACTIONS(4554),
    [anon_sym_initial] = ACTIONS(4554),
    [anon_sym_assign] = ACTIONS(4554),
    [anon_sym_alias] = ACTIONS(4554),
    [anon_sym_always_comb] = ACTIONS(4554),
    [anon_sym_always_latch] = ACTIONS(4554),
    [anon_sym_always_ff] = ACTIONS(4554),
    [anon_sym_final] = ACTIONS(4554),
    [anon_sym_global] = ACTIONS(4554),
    [anon_sym_specify] = ACTIONS(4554),
    [anon_sym_LPAREN_STAR] = ACTIONS(4552),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4552),
    [anon_sym_DOLLARunit] = ACTIONS(4552),
  },
  [720] = {
    [ts_builtin_sym_end] = ACTIONS(4558),
    [sym_simple_identifier] = ACTIONS(4560),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4558),
    [anon_sym_BQUOTE] = ACTIONS(4560),
    [aux_sym_id_directive_token1] = ACTIONS(4558),
    [aux_sym_id_directive_token2] = ACTIONS(4558),
    [aux_sym_id_directive_token3] = ACTIONS(4558),
    [aux_sym_id_directive_token4] = ACTIONS(4560),
    [aux_sym_zero_directive_token1] = ACTIONS(4558),
    [aux_sym_zero_directive_token2] = ACTIONS(4558),
    [aux_sym_zero_directive_token3] = ACTIONS(4558),
    [aux_sym_zero_directive_token4] = ACTIONS(4558),
    [aux_sym_zero_directive_token5] = ACTIONS(4558),
    [aux_sym_zero_directive_token6] = ACTIONS(4558),
    [aux_sym_zero_directive_token7] = ACTIONS(4558),
    [aux_sym_zero_directive_token8] = ACTIONS(4558),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4558),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4558),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_begin_keywords_token1] = ACTIONS(4558),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_endmodule] = ACTIONS(4560),
    [anon_sym_COLON] = ACTIONS(4562),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_module] = ACTIONS(4560),
    [anon_sym_macromodule] = ACTIONS(4560),
    [anon_sym_endinterface] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_endprogram] = ACTIONS(4560),
    [anon_sym_program] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_package] = ACTIONS(4560),
    [anon_sym_endpackage] = ACTIONS(4560),
    [anon_sym_timeunit] = ACTIONS(4560),
    [anon_sym_timeprecision] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_input] = ACTIONS(4560),
    [anon_sym_output] = ACTIONS(4560),
    [anon_sym_inout] = ACTIONS(4560),
    [anon_sym_ref] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_specparam] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_modport] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_primitive] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_specify] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [721] = {
    [ts_builtin_sym_end] = ACTIONS(4564),
    [sym_simple_identifier] = ACTIONS(4566),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4564),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4564),
    [anon_sym_BQUOTE] = ACTIONS(4566),
    [aux_sym_id_directive_token1] = ACTIONS(4564),
    [aux_sym_id_directive_token2] = ACTIONS(4564),
    [aux_sym_id_directive_token3] = ACTIONS(4564),
    [aux_sym_id_directive_token4] = ACTIONS(4566),
    [aux_sym_zero_directive_token1] = ACTIONS(4564),
    [aux_sym_zero_directive_token2] = ACTIONS(4564),
    [aux_sym_zero_directive_token3] = ACTIONS(4564),
    [aux_sym_zero_directive_token4] = ACTIONS(4564),
    [aux_sym_zero_directive_token5] = ACTIONS(4564),
    [aux_sym_zero_directive_token6] = ACTIONS(4564),
    [aux_sym_zero_directive_token7] = ACTIONS(4564),
    [aux_sym_zero_directive_token8] = ACTIONS(4564),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4564),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4564),
    [anon_sym_wire] = ACTIONS(4566),
    [anon_sym_tri] = ACTIONS(4566),
    [anon_sym_tri0] = ACTIONS(4566),
    [anon_sym_tri1] = ACTIONS(4566),
    [anon_sym_wand] = ACTIONS(4566),
    [anon_sym_triand] = ACTIONS(4566),
    [anon_sym_wor] = ACTIONS(4566),
    [anon_sym_trior] = ACTIONS(4566),
    [anon_sym_trireg] = ACTIONS(4566),
    [anon_sym_uwire] = ACTIONS(4566),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4564),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4564),
    [aux_sym_begin_keywords_token1] = ACTIONS(4564),
    [anon_sym_SEMI] = ACTIONS(4564),
    [anon_sym_endmodule] = ACTIONS(4566),
    [anon_sym_COLON] = ACTIONS(4568),
    [anon_sym_extern] = ACTIONS(4566),
    [anon_sym_module] = ACTIONS(4566),
    [anon_sym_macromodule] = ACTIONS(4566),
    [anon_sym_endinterface] = ACTIONS(4566),
    [anon_sym_interface] = ACTIONS(4566),
    [anon_sym_endprogram] = ACTIONS(4566),
    [anon_sym_program] = ACTIONS(4566),
    [anon_sym_checker] = ACTIONS(4566),
    [anon_sym_virtual] = ACTIONS(4566),
    [anon_sym_class] = ACTIONS(4566),
    [anon_sym_package] = ACTIONS(4566),
    [anon_sym_endpackage] = ACTIONS(4566),
    [anon_sym_timeunit] = ACTIONS(4566),
    [anon_sym_timeprecision] = ACTIONS(4566),
    [anon_sym_type] = ACTIONS(4566),
    [anon_sym_input] = ACTIONS(4566),
    [anon_sym_output] = ACTIONS(4566),
    [anon_sym_inout] = ACTIONS(4566),
    [anon_sym_ref] = ACTIONS(4566),
    [anon_sym_DOLLARfatal] = ACTIONS(4564),
    [anon_sym_DOLLARerror] = ACTIONS(4564),
    [anon_sym_DOLLARwarning] = ACTIONS(4564),
    [anon_sym_DOLLARinfo] = ACTIONS(4564),
    [anon_sym_default] = ACTIONS(4566),
    [anon_sym_clocking] = ACTIONS(4566),
    [anon_sym_defparam] = ACTIONS(4566),
    [anon_sym_bind] = ACTIONS(4566),
    [anon_sym_const] = ACTIONS(4566),
    [anon_sym_function] = ACTIONS(4566),
    [anon_sym_static] = ACTIONS(4566),
    [anon_sym_constraint] = ACTIONS(4566),
    [anon_sym_if] = ACTIONS(4566),
    [anon_sym_else] = ACTIONS(4566),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_localparam] = ACTIONS(4566),
    [anon_sym_parameter] = ACTIONS(4566),
    [anon_sym_specparam] = ACTIONS(4566),
    [anon_sym_var] = ACTIONS(4566),
    [anon_sym_import] = ACTIONS(4566),
    [anon_sym_export] = ACTIONS(4566),
    [anon_sym_genvar] = ACTIONS(4566),
    [anon_sym_interconnect] = ACTIONS(4566),
    [anon_sym_typedef] = ACTIONS(4566),
    [anon_sym_enum] = ACTIONS(4566),
    [anon_sym_struct] = ACTIONS(4566),
    [anon_sym_union] = ACTIONS(4566),
    [anon_sym_nettype] = ACTIONS(4566),
    [anon_sym_automatic] = ACTIONS(4566),
    [anon_sym_string] = ACTIONS(4566),
    [anon_sym_chandle] = ACTIONS(4566),
    [anon_sym_event] = ACTIONS(4566),
    [anon_sym_byte] = ACTIONS(4566),
    [anon_sym_shortint] = ACTIONS(4566),
    [anon_sym_int] = ACTIONS(4566),
    [anon_sym_longint] = ACTIONS(4566),
    [anon_sym_integer] = ACTIONS(4566),
    [anon_sym_time] = ACTIONS(4566),
    [anon_sym_bit] = ACTIONS(4566),
    [anon_sym_logic] = ACTIONS(4566),
    [anon_sym_reg] = ACTIONS(4566),
    [anon_sym_shortreal] = ACTIONS(4566),
    [anon_sym_real] = ACTIONS(4566),
    [anon_sym_realtime] = ACTIONS(4566),
    [anon_sym_supply0] = ACTIONS(4566),
    [anon_sym_supply1] = ACTIONS(4566),
    [anon_sym_signed] = ACTIONS(4566),
    [anon_sym_unsigned] = ACTIONS(4566),
    [anon_sym_task] = ACTIONS(4566),
    [anon_sym_modport] = ACTIONS(4566),
    [anon_sym_assert] = ACTIONS(4566),
    [anon_sym_property] = ACTIONS(4566),
    [anon_sym_assume] = ACTIONS(4566),
    [anon_sym_cover] = ACTIONS(4566),
    [anon_sym_sequence] = ACTIONS(4566),
    [anon_sym_restrict] = ACTIONS(4566),
    [anon_sym_not] = ACTIONS(4566),
    [anon_sym_or] = ACTIONS(4566),
    [anon_sym_and] = ACTIONS(4566),
    [anon_sym_case] = ACTIONS(4566),
    [anon_sym_always] = ACTIONS(4566),
    [anon_sym_covergroup] = ACTIONS(4566),
    [anon_sym_let] = ACTIONS(4566),
    [anon_sym_pulldown] = ACTIONS(4566),
    [anon_sym_pullup] = ACTIONS(4566),
    [anon_sym_cmos] = ACTIONS(4566),
    [anon_sym_rcmos] = ACTIONS(4566),
    [anon_sym_bufif0] = ACTIONS(4566),
    [anon_sym_bufif1] = ACTIONS(4566),
    [anon_sym_notif0] = ACTIONS(4566),
    [anon_sym_notif1] = ACTIONS(4566),
    [anon_sym_nmos] = ACTIONS(4566),
    [anon_sym_pmos] = ACTIONS(4566),
    [anon_sym_rnmos] = ACTIONS(4566),
    [anon_sym_rpmos] = ACTIONS(4566),
    [anon_sym_nand] = ACTIONS(4566),
    [anon_sym_nor] = ACTIONS(4566),
    [anon_sym_xor] = ACTIONS(4566),
    [anon_sym_xnor] = ACTIONS(4566),
    [anon_sym_buf] = ACTIONS(4566),
    [anon_sym_tranif0] = ACTIONS(4566),
    [anon_sym_tranif1] = ACTIONS(4566),
    [anon_sym_rtranif1] = ACTIONS(4566),
    [anon_sym_rtranif0] = ACTIONS(4566),
    [anon_sym_tran] = ACTIONS(4566),
    [anon_sym_rtran] = ACTIONS(4566),
    [anon_sym_generate] = ACTIONS(4566),
    [anon_sym_for] = ACTIONS(4566),
    [anon_sym_primitive] = ACTIONS(4566),
    [anon_sym_initial] = ACTIONS(4566),
    [anon_sym_assign] = ACTIONS(4566),
    [anon_sym_alias] = ACTIONS(4566),
    [anon_sym_always_comb] = ACTIONS(4566),
    [anon_sym_always_latch] = ACTIONS(4566),
    [anon_sym_always_ff] = ACTIONS(4566),
    [anon_sym_final] = ACTIONS(4566),
    [anon_sym_global] = ACTIONS(4566),
    [anon_sym_specify] = ACTIONS(4566),
    [anon_sym_LPAREN_STAR] = ACTIONS(4564),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4564),
    [anon_sym_DOLLARunit] = ACTIONS(4564),
  },
  [722] = {
    [ts_builtin_sym_end] = ACTIONS(4570),
    [sym_simple_identifier] = ACTIONS(4572),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4570),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4570),
    [anon_sym_BQUOTE] = ACTIONS(4572),
    [aux_sym_id_directive_token1] = ACTIONS(4570),
    [aux_sym_id_directive_token2] = ACTIONS(4570),
    [aux_sym_id_directive_token3] = ACTIONS(4570),
    [aux_sym_id_directive_token4] = ACTIONS(4572),
    [aux_sym_zero_directive_token1] = ACTIONS(4570),
    [aux_sym_zero_directive_token2] = ACTIONS(4570),
    [aux_sym_zero_directive_token3] = ACTIONS(4570),
    [aux_sym_zero_directive_token4] = ACTIONS(4570),
    [aux_sym_zero_directive_token5] = ACTIONS(4570),
    [aux_sym_zero_directive_token6] = ACTIONS(4570),
    [aux_sym_zero_directive_token7] = ACTIONS(4570),
    [aux_sym_zero_directive_token8] = ACTIONS(4570),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4570),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4570),
    [anon_sym_wire] = ACTIONS(4572),
    [anon_sym_tri] = ACTIONS(4572),
    [anon_sym_tri0] = ACTIONS(4572),
    [anon_sym_tri1] = ACTIONS(4572),
    [anon_sym_wand] = ACTIONS(4572),
    [anon_sym_triand] = ACTIONS(4572),
    [anon_sym_wor] = ACTIONS(4572),
    [anon_sym_trior] = ACTIONS(4572),
    [anon_sym_trireg] = ACTIONS(4572),
    [anon_sym_uwire] = ACTIONS(4572),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4570),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4570),
    [aux_sym_begin_keywords_token1] = ACTIONS(4570),
    [anon_sym_SEMI] = ACTIONS(4570),
    [anon_sym_endmodule] = ACTIONS(4572),
    [anon_sym_COLON] = ACTIONS(4574),
    [anon_sym_extern] = ACTIONS(4572),
    [anon_sym_module] = ACTIONS(4572),
    [anon_sym_macromodule] = ACTIONS(4572),
    [anon_sym_endinterface] = ACTIONS(4572),
    [anon_sym_interface] = ACTIONS(4572),
    [anon_sym_endprogram] = ACTIONS(4572),
    [anon_sym_program] = ACTIONS(4572),
    [anon_sym_checker] = ACTIONS(4572),
    [anon_sym_virtual] = ACTIONS(4572),
    [anon_sym_class] = ACTIONS(4572),
    [anon_sym_package] = ACTIONS(4572),
    [anon_sym_endpackage] = ACTIONS(4572),
    [anon_sym_timeunit] = ACTIONS(4572),
    [anon_sym_timeprecision] = ACTIONS(4572),
    [anon_sym_type] = ACTIONS(4572),
    [anon_sym_input] = ACTIONS(4572),
    [anon_sym_output] = ACTIONS(4572),
    [anon_sym_inout] = ACTIONS(4572),
    [anon_sym_ref] = ACTIONS(4572),
    [anon_sym_DOLLARfatal] = ACTIONS(4570),
    [anon_sym_DOLLARerror] = ACTIONS(4570),
    [anon_sym_DOLLARwarning] = ACTIONS(4570),
    [anon_sym_DOLLARinfo] = ACTIONS(4570),
    [anon_sym_default] = ACTIONS(4572),
    [anon_sym_clocking] = ACTIONS(4572),
    [anon_sym_defparam] = ACTIONS(4572),
    [anon_sym_bind] = ACTIONS(4572),
    [anon_sym_const] = ACTIONS(4572),
    [anon_sym_function] = ACTIONS(4572),
    [anon_sym_static] = ACTIONS(4572),
    [anon_sym_constraint] = ACTIONS(4572),
    [anon_sym_if] = ACTIONS(4572),
    [anon_sym_else] = ACTIONS(4572),
    [anon_sym_LBRACK] = ACTIONS(4570),
    [anon_sym_localparam] = ACTIONS(4572),
    [anon_sym_parameter] = ACTIONS(4572),
    [anon_sym_specparam] = ACTIONS(4572),
    [anon_sym_var] = ACTIONS(4572),
    [anon_sym_import] = ACTIONS(4572),
    [anon_sym_export] = ACTIONS(4572),
    [anon_sym_genvar] = ACTIONS(4572),
    [anon_sym_interconnect] = ACTIONS(4572),
    [anon_sym_typedef] = ACTIONS(4572),
    [anon_sym_enum] = ACTIONS(4572),
    [anon_sym_struct] = ACTIONS(4572),
    [anon_sym_union] = ACTIONS(4572),
    [anon_sym_nettype] = ACTIONS(4572),
    [anon_sym_automatic] = ACTIONS(4572),
    [anon_sym_string] = ACTIONS(4572),
    [anon_sym_chandle] = ACTIONS(4572),
    [anon_sym_event] = ACTIONS(4572),
    [anon_sym_byte] = ACTIONS(4572),
    [anon_sym_shortint] = ACTIONS(4572),
    [anon_sym_int] = ACTIONS(4572),
    [anon_sym_longint] = ACTIONS(4572),
    [anon_sym_integer] = ACTIONS(4572),
    [anon_sym_time] = ACTIONS(4572),
    [anon_sym_bit] = ACTIONS(4572),
    [anon_sym_logic] = ACTIONS(4572),
    [anon_sym_reg] = ACTIONS(4572),
    [anon_sym_shortreal] = ACTIONS(4572),
    [anon_sym_real] = ACTIONS(4572),
    [anon_sym_realtime] = ACTIONS(4572),
    [anon_sym_supply0] = ACTIONS(4572),
    [anon_sym_supply1] = ACTIONS(4572),
    [anon_sym_signed] = ACTIONS(4572),
    [anon_sym_unsigned] = ACTIONS(4572),
    [anon_sym_task] = ACTIONS(4572),
    [anon_sym_modport] = ACTIONS(4572),
    [anon_sym_assert] = ACTIONS(4572),
    [anon_sym_property] = ACTIONS(4572),
    [anon_sym_assume] = ACTIONS(4572),
    [anon_sym_cover] = ACTIONS(4572),
    [anon_sym_sequence] = ACTIONS(4572),
    [anon_sym_restrict] = ACTIONS(4572),
    [anon_sym_not] = ACTIONS(4572),
    [anon_sym_or] = ACTIONS(4572),
    [anon_sym_and] = ACTIONS(4572),
    [anon_sym_case] = ACTIONS(4572),
    [anon_sym_always] = ACTIONS(4572),
    [anon_sym_covergroup] = ACTIONS(4572),
    [anon_sym_let] = ACTIONS(4572),
    [anon_sym_pulldown] = ACTIONS(4572),
    [anon_sym_pullup] = ACTIONS(4572),
    [anon_sym_cmos] = ACTIONS(4572),
    [anon_sym_rcmos] = ACTIONS(4572),
    [anon_sym_bufif0] = ACTIONS(4572),
    [anon_sym_bufif1] = ACTIONS(4572),
    [anon_sym_notif0] = ACTIONS(4572),
    [anon_sym_notif1] = ACTIONS(4572),
    [anon_sym_nmos] = ACTIONS(4572),
    [anon_sym_pmos] = ACTIONS(4572),
    [anon_sym_rnmos] = ACTIONS(4572),
    [anon_sym_rpmos] = ACTIONS(4572),
    [anon_sym_nand] = ACTIONS(4572),
    [anon_sym_nor] = ACTIONS(4572),
    [anon_sym_xor] = ACTIONS(4572),
    [anon_sym_xnor] = ACTIONS(4572),
    [anon_sym_buf] = ACTIONS(4572),
    [anon_sym_tranif0] = ACTIONS(4572),
    [anon_sym_tranif1] = ACTIONS(4572),
    [anon_sym_rtranif1] = ACTIONS(4572),
    [anon_sym_rtranif0] = ACTIONS(4572),
    [anon_sym_tran] = ACTIONS(4572),
    [anon_sym_rtran] = ACTIONS(4572),
    [anon_sym_generate] = ACTIONS(4572),
    [anon_sym_for] = ACTIONS(4572),
    [anon_sym_primitive] = ACTIONS(4572),
    [anon_sym_initial] = ACTIONS(4572),
    [anon_sym_assign] = ACTIONS(4572),
    [anon_sym_alias] = ACTIONS(4572),
    [anon_sym_always_comb] = ACTIONS(4572),
    [anon_sym_always_latch] = ACTIONS(4572),
    [anon_sym_always_ff] = ACTIONS(4572),
    [anon_sym_final] = ACTIONS(4572),
    [anon_sym_global] = ACTIONS(4572),
    [anon_sym_specify] = ACTIONS(4572),
    [anon_sym_LPAREN_STAR] = ACTIONS(4570),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4570),
    [anon_sym_DOLLARunit] = ACTIONS(4570),
  },
  [723] = {
    [ts_builtin_sym_end] = ACTIONS(4576),
    [sym_simple_identifier] = ACTIONS(4578),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4576),
    [anon_sym_BQUOTE] = ACTIONS(4578),
    [aux_sym_id_directive_token1] = ACTIONS(4576),
    [aux_sym_id_directive_token2] = ACTIONS(4576),
    [aux_sym_id_directive_token3] = ACTIONS(4576),
    [aux_sym_id_directive_token4] = ACTIONS(4578),
    [aux_sym_zero_directive_token1] = ACTIONS(4576),
    [aux_sym_zero_directive_token2] = ACTIONS(4576),
    [aux_sym_zero_directive_token3] = ACTIONS(4576),
    [aux_sym_zero_directive_token4] = ACTIONS(4576),
    [aux_sym_zero_directive_token5] = ACTIONS(4576),
    [aux_sym_zero_directive_token6] = ACTIONS(4576),
    [aux_sym_zero_directive_token7] = ACTIONS(4576),
    [aux_sym_zero_directive_token8] = ACTIONS(4576),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4576),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4576),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_begin_keywords_token1] = ACTIONS(4576),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_endmodule] = ACTIONS(4578),
    [anon_sym_COLON] = ACTIONS(4580),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_module] = ACTIONS(4578),
    [anon_sym_macromodule] = ACTIONS(4578),
    [anon_sym_endinterface] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_endprogram] = ACTIONS(4578),
    [anon_sym_program] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_package] = ACTIONS(4578),
    [anon_sym_endpackage] = ACTIONS(4578),
    [anon_sym_timeunit] = ACTIONS(4578),
    [anon_sym_timeprecision] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_input] = ACTIONS(4578),
    [anon_sym_output] = ACTIONS(4578),
    [anon_sym_inout] = ACTIONS(4578),
    [anon_sym_ref] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_specparam] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_modport] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_primitive] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_specify] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [724] = {
    [ts_builtin_sym_end] = ACTIONS(4582),
    [sym_simple_identifier] = ACTIONS(4584),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4582),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4582),
    [anon_sym_BQUOTE] = ACTIONS(4584),
    [aux_sym_id_directive_token1] = ACTIONS(4582),
    [aux_sym_id_directive_token2] = ACTIONS(4582),
    [aux_sym_id_directive_token3] = ACTIONS(4582),
    [aux_sym_id_directive_token4] = ACTIONS(4584),
    [aux_sym_zero_directive_token1] = ACTIONS(4582),
    [aux_sym_zero_directive_token2] = ACTIONS(4582),
    [aux_sym_zero_directive_token3] = ACTIONS(4582),
    [aux_sym_zero_directive_token4] = ACTIONS(4582),
    [aux_sym_zero_directive_token5] = ACTIONS(4582),
    [aux_sym_zero_directive_token6] = ACTIONS(4582),
    [aux_sym_zero_directive_token7] = ACTIONS(4582),
    [aux_sym_zero_directive_token8] = ACTIONS(4582),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4582),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4582),
    [anon_sym_wire] = ACTIONS(4584),
    [anon_sym_tri] = ACTIONS(4584),
    [anon_sym_tri0] = ACTIONS(4584),
    [anon_sym_tri1] = ACTIONS(4584),
    [anon_sym_wand] = ACTIONS(4584),
    [anon_sym_triand] = ACTIONS(4584),
    [anon_sym_wor] = ACTIONS(4584),
    [anon_sym_trior] = ACTIONS(4584),
    [anon_sym_trireg] = ACTIONS(4584),
    [anon_sym_uwire] = ACTIONS(4584),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4582),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4582),
    [aux_sym_begin_keywords_token1] = ACTIONS(4582),
    [anon_sym_SEMI] = ACTIONS(4582),
    [anon_sym_endmodule] = ACTIONS(4584),
    [anon_sym_extern] = ACTIONS(4584),
    [anon_sym_module] = ACTIONS(4584),
    [anon_sym_macromodule] = ACTIONS(4584),
    [anon_sym_endinterface] = ACTIONS(4584),
    [anon_sym_interface] = ACTIONS(4584),
    [anon_sym_endprogram] = ACTIONS(4584),
    [anon_sym_program] = ACTIONS(4584),
    [anon_sym_checker] = ACTIONS(4584),
    [anon_sym_virtual] = ACTIONS(4584),
    [anon_sym_class] = ACTIONS(4584),
    [anon_sym_package] = ACTIONS(4584),
    [anon_sym_endpackage] = ACTIONS(4584),
    [anon_sym_timeunit] = ACTIONS(4584),
    [anon_sym_timeprecision] = ACTIONS(4584),
    [anon_sym_type] = ACTIONS(4584),
    [anon_sym_input] = ACTIONS(4584),
    [anon_sym_output] = ACTIONS(4584),
    [anon_sym_inout] = ACTIONS(4584),
    [anon_sym_ref] = ACTIONS(4584),
    [anon_sym_DOLLARfatal] = ACTIONS(4582),
    [anon_sym_DOLLARerror] = ACTIONS(4582),
    [anon_sym_DOLLARwarning] = ACTIONS(4582),
    [anon_sym_DOLLARinfo] = ACTIONS(4582),
    [anon_sym_default] = ACTIONS(4584),
    [anon_sym_clocking] = ACTIONS(4584),
    [anon_sym_defparam] = ACTIONS(4584),
    [anon_sym_bind] = ACTIONS(4584),
    [anon_sym_const] = ACTIONS(4584),
    [anon_sym_function] = ACTIONS(4584),
    [anon_sym_static] = ACTIONS(4584),
    [anon_sym_constraint] = ACTIONS(4584),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4582),
    [anon_sym_localparam] = ACTIONS(4584),
    [anon_sym_parameter] = ACTIONS(4584),
    [anon_sym_specparam] = ACTIONS(4584),
    [anon_sym_var] = ACTIONS(4584),
    [anon_sym_import] = ACTIONS(4584),
    [anon_sym_export] = ACTIONS(4584),
    [anon_sym_genvar] = ACTIONS(4584),
    [anon_sym_interconnect] = ACTIONS(4584),
    [anon_sym_typedef] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_struct] = ACTIONS(4584),
    [anon_sym_union] = ACTIONS(4584),
    [anon_sym_nettype] = ACTIONS(4584),
    [anon_sym_automatic] = ACTIONS(4584),
    [anon_sym_string] = ACTIONS(4584),
    [anon_sym_chandle] = ACTIONS(4584),
    [anon_sym_event] = ACTIONS(4584),
    [anon_sym_byte] = ACTIONS(4584),
    [anon_sym_shortint] = ACTIONS(4584),
    [anon_sym_int] = ACTIONS(4584),
    [anon_sym_longint] = ACTIONS(4584),
    [anon_sym_integer] = ACTIONS(4584),
    [anon_sym_time] = ACTIONS(4584),
    [anon_sym_bit] = ACTIONS(4584),
    [anon_sym_logic] = ACTIONS(4584),
    [anon_sym_reg] = ACTIONS(4584),
    [anon_sym_shortreal] = ACTIONS(4584),
    [anon_sym_real] = ACTIONS(4584),
    [anon_sym_realtime] = ACTIONS(4584),
    [anon_sym_supply0] = ACTIONS(4584),
    [anon_sym_supply1] = ACTIONS(4584),
    [anon_sym_signed] = ACTIONS(4584),
    [anon_sym_unsigned] = ACTIONS(4584),
    [anon_sym_task] = ACTIONS(4584),
    [anon_sym_modport] = ACTIONS(4584),
    [anon_sym_assert] = ACTIONS(4584),
    [anon_sym_property] = ACTIONS(4584),
    [anon_sym_assume] = ACTIONS(4584),
    [anon_sym_cover] = ACTIONS(4584),
    [anon_sym_sequence] = ACTIONS(4584),
    [anon_sym_restrict] = ACTIONS(4584),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_or] = ACTIONS(4584),
    [anon_sym_and] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_always] = ACTIONS(4584),
    [anon_sym_covergroup] = ACTIONS(4584),
    [anon_sym_let] = ACTIONS(4584),
    [anon_sym_pulldown] = ACTIONS(4584),
    [anon_sym_pullup] = ACTIONS(4584),
    [anon_sym_cmos] = ACTIONS(4584),
    [anon_sym_rcmos] = ACTIONS(4584),
    [anon_sym_bufif0] = ACTIONS(4584),
    [anon_sym_bufif1] = ACTIONS(4584),
    [anon_sym_notif0] = ACTIONS(4584),
    [anon_sym_notif1] = ACTIONS(4584),
    [anon_sym_nmos] = ACTIONS(4584),
    [anon_sym_pmos] = ACTIONS(4584),
    [anon_sym_rnmos] = ACTIONS(4584),
    [anon_sym_rpmos] = ACTIONS(4584),
    [anon_sym_nand] = ACTIONS(4584),
    [anon_sym_nor] = ACTIONS(4584),
    [anon_sym_xor] = ACTIONS(4584),
    [anon_sym_xnor] = ACTIONS(4584),
    [anon_sym_buf] = ACTIONS(4584),
    [anon_sym_tranif0] = ACTIONS(4584),
    [anon_sym_tranif1] = ACTIONS(4584),
    [anon_sym_rtranif1] = ACTIONS(4584),
    [anon_sym_rtranif0] = ACTIONS(4584),
    [anon_sym_tran] = ACTIONS(4584),
    [anon_sym_rtran] = ACTIONS(4584),
    [anon_sym_generate] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_primitive] = ACTIONS(4584),
    [anon_sym_initial] = ACTIONS(4584),
    [anon_sym_assign] = ACTIONS(4584),
    [anon_sym_alias] = ACTIONS(4584),
    [anon_sym_always_comb] = ACTIONS(4584),
    [anon_sym_always_latch] = ACTIONS(4584),
    [anon_sym_always_ff] = ACTIONS(4584),
    [anon_sym_final] = ACTIONS(4584),
    [anon_sym_endclocking] = ACTIONS(4584),
    [anon_sym_global] = ACTIONS(4584),
    [anon_sym_specify] = ACTIONS(4584),
    [anon_sym_LPAREN_STAR] = ACTIONS(4582),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4582),
    [anon_sym_DOLLARunit] = ACTIONS(4582),
  },
  [725] = {
    [ts_builtin_sym_end] = ACTIONS(4586),
    [sym_simple_identifier] = ACTIONS(4588),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4586),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4586),
    [anon_sym_BQUOTE] = ACTIONS(4588),
    [aux_sym_id_directive_token1] = ACTIONS(4586),
    [aux_sym_id_directive_token2] = ACTIONS(4586),
    [aux_sym_id_directive_token3] = ACTIONS(4586),
    [aux_sym_id_directive_token4] = ACTIONS(4588),
    [aux_sym_zero_directive_token1] = ACTIONS(4586),
    [aux_sym_zero_directive_token2] = ACTIONS(4586),
    [aux_sym_zero_directive_token3] = ACTIONS(4586),
    [aux_sym_zero_directive_token4] = ACTIONS(4586),
    [aux_sym_zero_directive_token5] = ACTIONS(4586),
    [aux_sym_zero_directive_token6] = ACTIONS(4586),
    [aux_sym_zero_directive_token7] = ACTIONS(4586),
    [aux_sym_zero_directive_token8] = ACTIONS(4586),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4586),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4586),
    [anon_sym_wire] = ACTIONS(4588),
    [anon_sym_tri] = ACTIONS(4588),
    [anon_sym_tri0] = ACTIONS(4588),
    [anon_sym_tri1] = ACTIONS(4588),
    [anon_sym_wand] = ACTIONS(4588),
    [anon_sym_triand] = ACTIONS(4588),
    [anon_sym_wor] = ACTIONS(4588),
    [anon_sym_trior] = ACTIONS(4588),
    [anon_sym_trireg] = ACTIONS(4588),
    [anon_sym_uwire] = ACTIONS(4588),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4586),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4586),
    [aux_sym_begin_keywords_token1] = ACTIONS(4586),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_endmodule] = ACTIONS(4588),
    [anon_sym_COLON] = ACTIONS(4590),
    [anon_sym_extern] = ACTIONS(4588),
    [anon_sym_module] = ACTIONS(4588),
    [anon_sym_macromodule] = ACTIONS(4588),
    [anon_sym_endinterface] = ACTIONS(4588),
    [anon_sym_interface] = ACTIONS(4588),
    [anon_sym_endprogram] = ACTIONS(4588),
    [anon_sym_program] = ACTIONS(4588),
    [anon_sym_checker] = ACTIONS(4588),
    [anon_sym_virtual] = ACTIONS(4588),
    [anon_sym_class] = ACTIONS(4588),
    [anon_sym_package] = ACTIONS(4588),
    [anon_sym_endpackage] = ACTIONS(4588),
    [anon_sym_timeunit] = ACTIONS(4588),
    [anon_sym_timeprecision] = ACTIONS(4588),
    [anon_sym_type] = ACTIONS(4588),
    [anon_sym_input] = ACTIONS(4588),
    [anon_sym_output] = ACTIONS(4588),
    [anon_sym_inout] = ACTIONS(4588),
    [anon_sym_ref] = ACTIONS(4588),
    [anon_sym_DOLLARfatal] = ACTIONS(4586),
    [anon_sym_DOLLARerror] = ACTIONS(4586),
    [anon_sym_DOLLARwarning] = ACTIONS(4586),
    [anon_sym_DOLLARinfo] = ACTIONS(4586),
    [anon_sym_default] = ACTIONS(4588),
    [anon_sym_clocking] = ACTIONS(4588),
    [anon_sym_defparam] = ACTIONS(4588),
    [anon_sym_bind] = ACTIONS(4588),
    [anon_sym_const] = ACTIONS(4588),
    [anon_sym_function] = ACTIONS(4588),
    [anon_sym_static] = ACTIONS(4588),
    [anon_sym_constraint] = ACTIONS(4588),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [anon_sym_localparam] = ACTIONS(4588),
    [anon_sym_parameter] = ACTIONS(4588),
    [anon_sym_specparam] = ACTIONS(4588),
    [anon_sym_var] = ACTIONS(4588),
    [anon_sym_import] = ACTIONS(4588),
    [anon_sym_export] = ACTIONS(4588),
    [anon_sym_genvar] = ACTIONS(4588),
    [anon_sym_interconnect] = ACTIONS(4588),
    [anon_sym_typedef] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_struct] = ACTIONS(4588),
    [anon_sym_union] = ACTIONS(4588),
    [anon_sym_nettype] = ACTIONS(4588),
    [anon_sym_automatic] = ACTIONS(4588),
    [anon_sym_string] = ACTIONS(4588),
    [anon_sym_chandle] = ACTIONS(4588),
    [anon_sym_event] = ACTIONS(4588),
    [anon_sym_byte] = ACTIONS(4588),
    [anon_sym_shortint] = ACTIONS(4588),
    [anon_sym_int] = ACTIONS(4588),
    [anon_sym_longint] = ACTIONS(4588),
    [anon_sym_integer] = ACTIONS(4588),
    [anon_sym_time] = ACTIONS(4588),
    [anon_sym_bit] = ACTIONS(4588),
    [anon_sym_logic] = ACTIONS(4588),
    [anon_sym_reg] = ACTIONS(4588),
    [anon_sym_shortreal] = ACTIONS(4588),
    [anon_sym_real] = ACTIONS(4588),
    [anon_sym_realtime] = ACTIONS(4588),
    [anon_sym_supply0] = ACTIONS(4588),
    [anon_sym_supply1] = ACTIONS(4588),
    [anon_sym_signed] = ACTIONS(4588),
    [anon_sym_unsigned] = ACTIONS(4588),
    [anon_sym_task] = ACTIONS(4588),
    [anon_sym_modport] = ACTIONS(4588),
    [anon_sym_assert] = ACTIONS(4588),
    [anon_sym_property] = ACTIONS(4588),
    [anon_sym_assume] = ACTIONS(4588),
    [anon_sym_cover] = ACTIONS(4588),
    [anon_sym_sequence] = ACTIONS(4588),
    [anon_sym_restrict] = ACTIONS(4588),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_or] = ACTIONS(4588),
    [anon_sym_and] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_always] = ACTIONS(4588),
    [anon_sym_covergroup] = ACTIONS(4588),
    [anon_sym_let] = ACTIONS(4588),
    [anon_sym_pulldown] = ACTIONS(4588),
    [anon_sym_pullup] = ACTIONS(4588),
    [anon_sym_cmos] = ACTIONS(4588),
    [anon_sym_rcmos] = ACTIONS(4588),
    [anon_sym_bufif0] = ACTIONS(4588),
    [anon_sym_bufif1] = ACTIONS(4588),
    [anon_sym_notif0] = ACTIONS(4588),
    [anon_sym_notif1] = ACTIONS(4588),
    [anon_sym_nmos] = ACTIONS(4588),
    [anon_sym_pmos] = ACTIONS(4588),
    [anon_sym_rnmos] = ACTIONS(4588),
    [anon_sym_rpmos] = ACTIONS(4588),
    [anon_sym_nand] = ACTIONS(4588),
    [anon_sym_nor] = ACTIONS(4588),
    [anon_sym_xor] = ACTIONS(4588),
    [anon_sym_xnor] = ACTIONS(4588),
    [anon_sym_buf] = ACTIONS(4588),
    [anon_sym_tranif0] = ACTIONS(4588),
    [anon_sym_tranif1] = ACTIONS(4588),
    [anon_sym_rtranif1] = ACTIONS(4588),
    [anon_sym_rtranif0] = ACTIONS(4588),
    [anon_sym_tran] = ACTIONS(4588),
    [anon_sym_rtran] = ACTIONS(4588),
    [anon_sym_generate] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_primitive] = ACTIONS(4588),
    [anon_sym_initial] = ACTIONS(4588),
    [anon_sym_assign] = ACTIONS(4588),
    [anon_sym_alias] = ACTIONS(4588),
    [anon_sym_always_comb] = ACTIONS(4588),
    [anon_sym_always_latch] = ACTIONS(4588),
    [anon_sym_always_ff] = ACTIONS(4588),
    [anon_sym_final] = ACTIONS(4588),
    [anon_sym_global] = ACTIONS(4588),
    [anon_sym_specify] = ACTIONS(4588),
    [anon_sym_LPAREN_STAR] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4586),
    [anon_sym_DOLLARunit] = ACTIONS(4586),
  },
  [726] = {
    [ts_builtin_sym_end] = ACTIONS(4592),
    [sym_simple_identifier] = ACTIONS(4594),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4592),
    [anon_sym_BQUOTE] = ACTIONS(4594),
    [aux_sym_id_directive_token1] = ACTIONS(4592),
    [aux_sym_id_directive_token2] = ACTIONS(4592),
    [aux_sym_id_directive_token3] = ACTIONS(4592),
    [aux_sym_id_directive_token4] = ACTIONS(4594),
    [aux_sym_zero_directive_token1] = ACTIONS(4592),
    [aux_sym_zero_directive_token2] = ACTIONS(4592),
    [aux_sym_zero_directive_token3] = ACTIONS(4592),
    [aux_sym_zero_directive_token4] = ACTIONS(4592),
    [aux_sym_zero_directive_token5] = ACTIONS(4592),
    [aux_sym_zero_directive_token6] = ACTIONS(4592),
    [aux_sym_zero_directive_token7] = ACTIONS(4592),
    [aux_sym_zero_directive_token8] = ACTIONS(4592),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4592),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4592),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_begin_keywords_token1] = ACTIONS(4592),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_endmodule] = ACTIONS(4594),
    [anon_sym_COLON] = ACTIONS(4596),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_module] = ACTIONS(4594),
    [anon_sym_macromodule] = ACTIONS(4594),
    [anon_sym_endinterface] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_endprogram] = ACTIONS(4594),
    [anon_sym_program] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_package] = ACTIONS(4594),
    [anon_sym_endpackage] = ACTIONS(4594),
    [anon_sym_timeunit] = ACTIONS(4594),
    [anon_sym_timeprecision] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_input] = ACTIONS(4594),
    [anon_sym_output] = ACTIONS(4594),
    [anon_sym_inout] = ACTIONS(4594),
    [anon_sym_ref] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_specparam] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_modport] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_primitive] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_specify] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [727] = {
    [ts_builtin_sym_end] = ACTIONS(4598),
    [sym_simple_identifier] = ACTIONS(4600),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4598),
    [anon_sym_BQUOTE] = ACTIONS(4600),
    [aux_sym_id_directive_token1] = ACTIONS(4598),
    [aux_sym_id_directive_token2] = ACTIONS(4598),
    [aux_sym_id_directive_token3] = ACTIONS(4598),
    [aux_sym_id_directive_token4] = ACTIONS(4600),
    [aux_sym_zero_directive_token1] = ACTIONS(4598),
    [aux_sym_zero_directive_token2] = ACTIONS(4598),
    [aux_sym_zero_directive_token3] = ACTIONS(4598),
    [aux_sym_zero_directive_token4] = ACTIONS(4598),
    [aux_sym_zero_directive_token5] = ACTIONS(4598),
    [aux_sym_zero_directive_token6] = ACTIONS(4598),
    [aux_sym_zero_directive_token7] = ACTIONS(4598),
    [aux_sym_zero_directive_token8] = ACTIONS(4598),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4598),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4598),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_begin_keywords_token1] = ACTIONS(4598),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_endmodule] = ACTIONS(4600),
    [anon_sym_COLON] = ACTIONS(4602),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_module] = ACTIONS(4600),
    [anon_sym_macromodule] = ACTIONS(4600),
    [anon_sym_endinterface] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_endprogram] = ACTIONS(4600),
    [anon_sym_program] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_package] = ACTIONS(4600),
    [anon_sym_endpackage] = ACTIONS(4600),
    [anon_sym_timeunit] = ACTIONS(4600),
    [anon_sym_timeprecision] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_input] = ACTIONS(4600),
    [anon_sym_output] = ACTIONS(4600),
    [anon_sym_inout] = ACTIONS(4600),
    [anon_sym_ref] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_specparam] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_modport] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_primitive] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_specify] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [728] = {
    [ts_builtin_sym_end] = ACTIONS(4604),
    [sym_simple_identifier] = ACTIONS(4606),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4604),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4604),
    [anon_sym_BQUOTE] = ACTIONS(4606),
    [aux_sym_id_directive_token1] = ACTIONS(4604),
    [aux_sym_id_directive_token2] = ACTIONS(4604),
    [aux_sym_id_directive_token3] = ACTIONS(4604),
    [aux_sym_id_directive_token4] = ACTIONS(4606),
    [aux_sym_zero_directive_token1] = ACTIONS(4604),
    [aux_sym_zero_directive_token2] = ACTIONS(4604),
    [aux_sym_zero_directive_token3] = ACTIONS(4604),
    [aux_sym_zero_directive_token4] = ACTIONS(4604),
    [aux_sym_zero_directive_token5] = ACTIONS(4604),
    [aux_sym_zero_directive_token6] = ACTIONS(4604),
    [aux_sym_zero_directive_token7] = ACTIONS(4604),
    [aux_sym_zero_directive_token8] = ACTIONS(4604),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4604),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4604),
    [anon_sym_wire] = ACTIONS(4606),
    [anon_sym_tri] = ACTIONS(4606),
    [anon_sym_tri0] = ACTIONS(4606),
    [anon_sym_tri1] = ACTIONS(4606),
    [anon_sym_wand] = ACTIONS(4606),
    [anon_sym_triand] = ACTIONS(4606),
    [anon_sym_wor] = ACTIONS(4606),
    [anon_sym_trior] = ACTIONS(4606),
    [anon_sym_trireg] = ACTIONS(4606),
    [anon_sym_uwire] = ACTIONS(4606),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4604),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4604),
    [aux_sym_begin_keywords_token1] = ACTIONS(4604),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_endmodule] = ACTIONS(4606),
    [anon_sym_COLON] = ACTIONS(4608),
    [anon_sym_extern] = ACTIONS(4606),
    [anon_sym_module] = ACTIONS(4606),
    [anon_sym_macromodule] = ACTIONS(4606),
    [anon_sym_endinterface] = ACTIONS(4606),
    [anon_sym_interface] = ACTIONS(4606),
    [anon_sym_endprogram] = ACTIONS(4606),
    [anon_sym_program] = ACTIONS(4606),
    [anon_sym_checker] = ACTIONS(4606),
    [anon_sym_virtual] = ACTIONS(4606),
    [anon_sym_class] = ACTIONS(4606),
    [anon_sym_package] = ACTIONS(4606),
    [anon_sym_endpackage] = ACTIONS(4606),
    [anon_sym_timeunit] = ACTIONS(4606),
    [anon_sym_timeprecision] = ACTIONS(4606),
    [anon_sym_type] = ACTIONS(4606),
    [anon_sym_input] = ACTIONS(4606),
    [anon_sym_output] = ACTIONS(4606),
    [anon_sym_inout] = ACTIONS(4606),
    [anon_sym_ref] = ACTIONS(4606),
    [anon_sym_DOLLARfatal] = ACTIONS(4604),
    [anon_sym_DOLLARerror] = ACTIONS(4604),
    [anon_sym_DOLLARwarning] = ACTIONS(4604),
    [anon_sym_DOLLARinfo] = ACTIONS(4604),
    [anon_sym_default] = ACTIONS(4606),
    [anon_sym_clocking] = ACTIONS(4606),
    [anon_sym_defparam] = ACTIONS(4606),
    [anon_sym_bind] = ACTIONS(4606),
    [anon_sym_const] = ACTIONS(4606),
    [anon_sym_function] = ACTIONS(4606),
    [anon_sym_static] = ACTIONS(4606),
    [anon_sym_constraint] = ACTIONS(4606),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [anon_sym_localparam] = ACTIONS(4606),
    [anon_sym_parameter] = ACTIONS(4606),
    [anon_sym_specparam] = ACTIONS(4606),
    [anon_sym_var] = ACTIONS(4606),
    [anon_sym_import] = ACTIONS(4606),
    [anon_sym_export] = ACTIONS(4606),
    [anon_sym_genvar] = ACTIONS(4606),
    [anon_sym_interconnect] = ACTIONS(4606),
    [anon_sym_typedef] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_struct] = ACTIONS(4606),
    [anon_sym_union] = ACTIONS(4606),
    [anon_sym_nettype] = ACTIONS(4606),
    [anon_sym_automatic] = ACTIONS(4606),
    [anon_sym_string] = ACTIONS(4606),
    [anon_sym_chandle] = ACTIONS(4606),
    [anon_sym_event] = ACTIONS(4606),
    [anon_sym_byte] = ACTIONS(4606),
    [anon_sym_shortint] = ACTIONS(4606),
    [anon_sym_int] = ACTIONS(4606),
    [anon_sym_longint] = ACTIONS(4606),
    [anon_sym_integer] = ACTIONS(4606),
    [anon_sym_time] = ACTIONS(4606),
    [anon_sym_bit] = ACTIONS(4606),
    [anon_sym_logic] = ACTIONS(4606),
    [anon_sym_reg] = ACTIONS(4606),
    [anon_sym_shortreal] = ACTIONS(4606),
    [anon_sym_real] = ACTIONS(4606),
    [anon_sym_realtime] = ACTIONS(4606),
    [anon_sym_supply0] = ACTIONS(4606),
    [anon_sym_supply1] = ACTIONS(4606),
    [anon_sym_signed] = ACTIONS(4606),
    [anon_sym_unsigned] = ACTIONS(4606),
    [anon_sym_task] = ACTIONS(4606),
    [anon_sym_modport] = ACTIONS(4606),
    [anon_sym_assert] = ACTIONS(4606),
    [anon_sym_property] = ACTIONS(4606),
    [anon_sym_assume] = ACTIONS(4606),
    [anon_sym_cover] = ACTIONS(4606),
    [anon_sym_sequence] = ACTIONS(4606),
    [anon_sym_restrict] = ACTIONS(4606),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_or] = ACTIONS(4606),
    [anon_sym_and] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_always] = ACTIONS(4606),
    [anon_sym_covergroup] = ACTIONS(4606),
    [anon_sym_let] = ACTIONS(4606),
    [anon_sym_pulldown] = ACTIONS(4606),
    [anon_sym_pullup] = ACTIONS(4606),
    [anon_sym_cmos] = ACTIONS(4606),
    [anon_sym_rcmos] = ACTIONS(4606),
    [anon_sym_bufif0] = ACTIONS(4606),
    [anon_sym_bufif1] = ACTIONS(4606),
    [anon_sym_notif0] = ACTIONS(4606),
    [anon_sym_notif1] = ACTIONS(4606),
    [anon_sym_nmos] = ACTIONS(4606),
    [anon_sym_pmos] = ACTIONS(4606),
    [anon_sym_rnmos] = ACTIONS(4606),
    [anon_sym_rpmos] = ACTIONS(4606),
    [anon_sym_nand] = ACTIONS(4606),
    [anon_sym_nor] = ACTIONS(4606),
    [anon_sym_xor] = ACTIONS(4606),
    [anon_sym_xnor] = ACTIONS(4606),
    [anon_sym_buf] = ACTIONS(4606),
    [anon_sym_tranif0] = ACTIONS(4606),
    [anon_sym_tranif1] = ACTIONS(4606),
    [anon_sym_rtranif1] = ACTIONS(4606),
    [anon_sym_rtranif0] = ACTIONS(4606),
    [anon_sym_tran] = ACTIONS(4606),
    [anon_sym_rtran] = ACTIONS(4606),
    [anon_sym_generate] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_primitive] = ACTIONS(4606),
    [anon_sym_initial] = ACTIONS(4606),
    [anon_sym_assign] = ACTIONS(4606),
    [anon_sym_alias] = ACTIONS(4606),
    [anon_sym_always_comb] = ACTIONS(4606),
    [anon_sym_always_latch] = ACTIONS(4606),
    [anon_sym_always_ff] = ACTIONS(4606),
    [anon_sym_final] = ACTIONS(4606),
    [anon_sym_global] = ACTIONS(4606),
    [anon_sym_specify] = ACTIONS(4606),
    [anon_sym_LPAREN_STAR] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4604),
    [anon_sym_DOLLARunit] = ACTIONS(4604),
  },
  [729] = {
    [ts_builtin_sym_end] = ACTIONS(4610),
    [sym_simple_identifier] = ACTIONS(4612),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4610),
    [anon_sym_BQUOTE] = ACTIONS(4612),
    [aux_sym_id_directive_token1] = ACTIONS(4610),
    [aux_sym_id_directive_token2] = ACTIONS(4610),
    [aux_sym_id_directive_token3] = ACTIONS(4610),
    [aux_sym_id_directive_token4] = ACTIONS(4612),
    [aux_sym_zero_directive_token1] = ACTIONS(4610),
    [aux_sym_zero_directive_token2] = ACTIONS(4610),
    [aux_sym_zero_directive_token3] = ACTIONS(4610),
    [aux_sym_zero_directive_token4] = ACTIONS(4610),
    [aux_sym_zero_directive_token5] = ACTIONS(4610),
    [aux_sym_zero_directive_token6] = ACTIONS(4610),
    [aux_sym_zero_directive_token7] = ACTIONS(4610),
    [aux_sym_zero_directive_token8] = ACTIONS(4610),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4610),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4610),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_begin_keywords_token1] = ACTIONS(4610),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_endmodule] = ACTIONS(4612),
    [anon_sym_COLON] = ACTIONS(4614),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_module] = ACTIONS(4612),
    [anon_sym_macromodule] = ACTIONS(4612),
    [anon_sym_endinterface] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_endprogram] = ACTIONS(4612),
    [anon_sym_program] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_package] = ACTIONS(4612),
    [anon_sym_endpackage] = ACTIONS(4612),
    [anon_sym_timeunit] = ACTIONS(4612),
    [anon_sym_timeprecision] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_input] = ACTIONS(4612),
    [anon_sym_output] = ACTIONS(4612),
    [anon_sym_inout] = ACTIONS(4612),
    [anon_sym_ref] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_specparam] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_modport] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_primitive] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_specify] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [730] = {
    [ts_builtin_sym_end] = ACTIONS(4616),
    [sym_simple_identifier] = ACTIONS(4618),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4616),
    [anon_sym_BQUOTE] = ACTIONS(4618),
    [aux_sym_id_directive_token1] = ACTIONS(4616),
    [aux_sym_id_directive_token2] = ACTIONS(4616),
    [aux_sym_id_directive_token3] = ACTIONS(4616),
    [aux_sym_id_directive_token4] = ACTIONS(4618),
    [aux_sym_zero_directive_token1] = ACTIONS(4616),
    [aux_sym_zero_directive_token2] = ACTIONS(4616),
    [aux_sym_zero_directive_token3] = ACTIONS(4616),
    [aux_sym_zero_directive_token4] = ACTIONS(4616),
    [aux_sym_zero_directive_token5] = ACTIONS(4616),
    [aux_sym_zero_directive_token6] = ACTIONS(4616),
    [aux_sym_zero_directive_token7] = ACTIONS(4616),
    [aux_sym_zero_directive_token8] = ACTIONS(4616),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4616),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4616),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_begin_keywords_token1] = ACTIONS(4616),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_endmodule] = ACTIONS(4618),
    [anon_sym_COLON] = ACTIONS(4620),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_module] = ACTIONS(4618),
    [anon_sym_macromodule] = ACTIONS(4618),
    [anon_sym_endinterface] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_endprogram] = ACTIONS(4618),
    [anon_sym_program] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_package] = ACTIONS(4618),
    [anon_sym_endpackage] = ACTIONS(4618),
    [anon_sym_timeunit] = ACTIONS(4618),
    [anon_sym_timeprecision] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_input] = ACTIONS(4618),
    [anon_sym_output] = ACTIONS(4618),
    [anon_sym_inout] = ACTIONS(4618),
    [anon_sym_ref] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_specparam] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_modport] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_primitive] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_specify] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [731] = {
    [ts_builtin_sym_end] = ACTIONS(4622),
    [sym_simple_identifier] = ACTIONS(4624),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4622),
    [anon_sym_BQUOTE] = ACTIONS(4624),
    [aux_sym_id_directive_token1] = ACTIONS(4622),
    [aux_sym_id_directive_token2] = ACTIONS(4622),
    [aux_sym_id_directive_token3] = ACTIONS(4622),
    [aux_sym_id_directive_token4] = ACTIONS(4624),
    [aux_sym_zero_directive_token1] = ACTIONS(4622),
    [aux_sym_zero_directive_token2] = ACTIONS(4622),
    [aux_sym_zero_directive_token3] = ACTIONS(4622),
    [aux_sym_zero_directive_token4] = ACTIONS(4622),
    [aux_sym_zero_directive_token5] = ACTIONS(4622),
    [aux_sym_zero_directive_token6] = ACTIONS(4622),
    [aux_sym_zero_directive_token7] = ACTIONS(4622),
    [aux_sym_zero_directive_token8] = ACTIONS(4622),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4622),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4622),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_begin_keywords_token1] = ACTIONS(4622),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_endmodule] = ACTIONS(4624),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_module] = ACTIONS(4624),
    [anon_sym_macromodule] = ACTIONS(4624),
    [anon_sym_endinterface] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_endprogram] = ACTIONS(4624),
    [anon_sym_program] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_package] = ACTIONS(4624),
    [anon_sym_endpackage] = ACTIONS(4624),
    [anon_sym_timeunit] = ACTIONS(4624),
    [anon_sym_timeprecision] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_input] = ACTIONS(4624),
    [anon_sym_output] = ACTIONS(4624),
    [anon_sym_inout] = ACTIONS(4624),
    [anon_sym_ref] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_specparam] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_modport] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_primitive] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_specify] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [732] = {
    [ts_builtin_sym_end] = ACTIONS(4628),
    [sym_simple_identifier] = ACTIONS(4630),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4628),
    [anon_sym_BQUOTE] = ACTIONS(4630),
    [aux_sym_id_directive_token1] = ACTIONS(4628),
    [aux_sym_id_directive_token2] = ACTIONS(4628),
    [aux_sym_id_directive_token3] = ACTIONS(4628),
    [aux_sym_id_directive_token4] = ACTIONS(4630),
    [aux_sym_zero_directive_token1] = ACTIONS(4628),
    [aux_sym_zero_directive_token2] = ACTIONS(4628),
    [aux_sym_zero_directive_token3] = ACTIONS(4628),
    [aux_sym_zero_directive_token4] = ACTIONS(4628),
    [aux_sym_zero_directive_token5] = ACTIONS(4628),
    [aux_sym_zero_directive_token6] = ACTIONS(4628),
    [aux_sym_zero_directive_token7] = ACTIONS(4628),
    [aux_sym_zero_directive_token8] = ACTIONS(4628),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4628),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4628),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_begin_keywords_token1] = ACTIONS(4628),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_endmodule] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4632),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_module] = ACTIONS(4630),
    [anon_sym_macromodule] = ACTIONS(4630),
    [anon_sym_endinterface] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_endprogram] = ACTIONS(4630),
    [anon_sym_program] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_package] = ACTIONS(4630),
    [anon_sym_endpackage] = ACTIONS(4630),
    [anon_sym_timeunit] = ACTIONS(4630),
    [anon_sym_timeprecision] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_input] = ACTIONS(4630),
    [anon_sym_output] = ACTIONS(4630),
    [anon_sym_inout] = ACTIONS(4630),
    [anon_sym_ref] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_specparam] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_modport] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_primitive] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_specify] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [733] = {
    [ts_builtin_sym_end] = ACTIONS(4634),
    [sym_simple_identifier] = ACTIONS(4636),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4634),
    [anon_sym_BQUOTE] = ACTIONS(4636),
    [aux_sym_id_directive_token1] = ACTIONS(4634),
    [aux_sym_id_directive_token2] = ACTIONS(4634),
    [aux_sym_id_directive_token3] = ACTIONS(4634),
    [aux_sym_id_directive_token4] = ACTIONS(4636),
    [aux_sym_zero_directive_token1] = ACTIONS(4634),
    [aux_sym_zero_directive_token2] = ACTIONS(4634),
    [aux_sym_zero_directive_token3] = ACTIONS(4634),
    [aux_sym_zero_directive_token4] = ACTIONS(4634),
    [aux_sym_zero_directive_token5] = ACTIONS(4634),
    [aux_sym_zero_directive_token6] = ACTIONS(4634),
    [aux_sym_zero_directive_token7] = ACTIONS(4634),
    [aux_sym_zero_directive_token8] = ACTIONS(4634),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4634),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4634),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_begin_keywords_token1] = ACTIONS(4634),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_endmodule] = ACTIONS(4636),
    [anon_sym_COLON] = ACTIONS(4638),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_module] = ACTIONS(4636),
    [anon_sym_macromodule] = ACTIONS(4636),
    [anon_sym_endinterface] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_endprogram] = ACTIONS(4636),
    [anon_sym_program] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_package] = ACTIONS(4636),
    [anon_sym_endpackage] = ACTIONS(4636),
    [anon_sym_timeunit] = ACTIONS(4636),
    [anon_sym_timeprecision] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_input] = ACTIONS(4636),
    [anon_sym_output] = ACTIONS(4636),
    [anon_sym_inout] = ACTIONS(4636),
    [anon_sym_ref] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_specparam] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_modport] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_primitive] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_specify] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [734] = {
    [ts_builtin_sym_end] = ACTIONS(4558),
    [sym_simple_identifier] = ACTIONS(4560),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4558),
    [anon_sym_BQUOTE] = ACTIONS(4560),
    [aux_sym_id_directive_token1] = ACTIONS(4558),
    [aux_sym_id_directive_token2] = ACTIONS(4558),
    [aux_sym_id_directive_token3] = ACTIONS(4558),
    [aux_sym_id_directive_token4] = ACTIONS(4560),
    [aux_sym_zero_directive_token1] = ACTIONS(4558),
    [aux_sym_zero_directive_token2] = ACTIONS(4558),
    [aux_sym_zero_directive_token3] = ACTIONS(4558),
    [aux_sym_zero_directive_token4] = ACTIONS(4558),
    [aux_sym_zero_directive_token5] = ACTIONS(4558),
    [aux_sym_zero_directive_token6] = ACTIONS(4558),
    [aux_sym_zero_directive_token7] = ACTIONS(4558),
    [aux_sym_zero_directive_token8] = ACTIONS(4558),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4558),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4558),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4558),
    [aux_sym_begin_keywords_token1] = ACTIONS(4558),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_endmodule] = ACTIONS(4560),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_module] = ACTIONS(4560),
    [anon_sym_macromodule] = ACTIONS(4560),
    [anon_sym_endinterface] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_endprogram] = ACTIONS(4560),
    [anon_sym_program] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_package] = ACTIONS(4560),
    [anon_sym_endpackage] = ACTIONS(4560),
    [anon_sym_timeunit] = ACTIONS(4560),
    [anon_sym_timeprecision] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_input] = ACTIONS(4560),
    [anon_sym_output] = ACTIONS(4560),
    [anon_sym_inout] = ACTIONS(4560),
    [anon_sym_ref] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_specparam] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_modport] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_primitive] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_endclocking] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_specify] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [735] = {
    [ts_builtin_sym_end] = ACTIONS(4640),
    [sym_simple_identifier] = ACTIONS(4642),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4640),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4640),
    [anon_sym_BQUOTE] = ACTIONS(4642),
    [aux_sym_id_directive_token1] = ACTIONS(4640),
    [aux_sym_id_directive_token2] = ACTIONS(4640),
    [aux_sym_id_directive_token3] = ACTIONS(4640),
    [aux_sym_id_directive_token4] = ACTIONS(4642),
    [aux_sym_zero_directive_token1] = ACTIONS(4640),
    [aux_sym_zero_directive_token2] = ACTIONS(4640),
    [aux_sym_zero_directive_token3] = ACTIONS(4640),
    [aux_sym_zero_directive_token4] = ACTIONS(4640),
    [aux_sym_zero_directive_token5] = ACTIONS(4640),
    [aux_sym_zero_directive_token6] = ACTIONS(4640),
    [aux_sym_zero_directive_token7] = ACTIONS(4640),
    [aux_sym_zero_directive_token8] = ACTIONS(4640),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4640),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4640),
    [anon_sym_wire] = ACTIONS(4642),
    [anon_sym_tri] = ACTIONS(4642),
    [anon_sym_tri0] = ACTIONS(4642),
    [anon_sym_tri1] = ACTIONS(4642),
    [anon_sym_wand] = ACTIONS(4642),
    [anon_sym_triand] = ACTIONS(4642),
    [anon_sym_wor] = ACTIONS(4642),
    [anon_sym_trior] = ACTIONS(4642),
    [anon_sym_trireg] = ACTIONS(4642),
    [anon_sym_uwire] = ACTIONS(4642),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4640),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4640),
    [aux_sym_begin_keywords_token1] = ACTIONS(4640),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_endmodule] = ACTIONS(4642),
    [anon_sym_extern] = ACTIONS(4642),
    [anon_sym_module] = ACTIONS(4642),
    [anon_sym_macromodule] = ACTIONS(4642),
    [anon_sym_endinterface] = ACTIONS(4642),
    [anon_sym_interface] = ACTIONS(4642),
    [anon_sym_endprogram] = ACTIONS(4642),
    [anon_sym_program] = ACTIONS(4642),
    [anon_sym_checker] = ACTIONS(4642),
    [anon_sym_virtual] = ACTIONS(4642),
    [anon_sym_class] = ACTIONS(4642),
    [anon_sym_package] = ACTIONS(4642),
    [anon_sym_endpackage] = ACTIONS(4642),
    [anon_sym_timeunit] = ACTIONS(4642),
    [anon_sym_timeprecision] = ACTIONS(4642),
    [anon_sym_type] = ACTIONS(4642),
    [anon_sym_input] = ACTIONS(4642),
    [anon_sym_output] = ACTIONS(4642),
    [anon_sym_inout] = ACTIONS(4642),
    [anon_sym_ref] = ACTIONS(4642),
    [anon_sym_DOLLARfatal] = ACTIONS(4640),
    [anon_sym_DOLLARerror] = ACTIONS(4640),
    [anon_sym_DOLLARwarning] = ACTIONS(4640),
    [anon_sym_DOLLARinfo] = ACTIONS(4640),
    [anon_sym_default] = ACTIONS(4642),
    [anon_sym_clocking] = ACTIONS(4642),
    [anon_sym_defparam] = ACTIONS(4642),
    [anon_sym_bind] = ACTIONS(4642),
    [anon_sym_const] = ACTIONS(4642),
    [anon_sym_function] = ACTIONS(4642),
    [anon_sym_static] = ACTIONS(4642),
    [anon_sym_constraint] = ACTIONS(4642),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_localparam] = ACTIONS(4642),
    [anon_sym_parameter] = ACTIONS(4642),
    [anon_sym_specparam] = ACTIONS(4642),
    [anon_sym_var] = ACTIONS(4642),
    [anon_sym_import] = ACTIONS(4642),
    [anon_sym_export] = ACTIONS(4642),
    [anon_sym_genvar] = ACTIONS(4642),
    [anon_sym_interconnect] = ACTIONS(4642),
    [anon_sym_typedef] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_struct] = ACTIONS(4642),
    [anon_sym_union] = ACTIONS(4642),
    [anon_sym_nettype] = ACTIONS(4642),
    [anon_sym_automatic] = ACTIONS(4642),
    [anon_sym_string] = ACTIONS(4642),
    [anon_sym_chandle] = ACTIONS(4642),
    [anon_sym_event] = ACTIONS(4642),
    [anon_sym_byte] = ACTIONS(4642),
    [anon_sym_shortint] = ACTIONS(4642),
    [anon_sym_int] = ACTIONS(4642),
    [anon_sym_longint] = ACTIONS(4642),
    [anon_sym_integer] = ACTIONS(4642),
    [anon_sym_time] = ACTIONS(4642),
    [anon_sym_bit] = ACTIONS(4642),
    [anon_sym_logic] = ACTIONS(4642),
    [anon_sym_reg] = ACTIONS(4642),
    [anon_sym_shortreal] = ACTIONS(4642),
    [anon_sym_real] = ACTIONS(4642),
    [anon_sym_realtime] = ACTIONS(4642),
    [anon_sym_supply0] = ACTIONS(4642),
    [anon_sym_supply1] = ACTIONS(4642),
    [anon_sym_signed] = ACTIONS(4642),
    [anon_sym_unsigned] = ACTIONS(4642),
    [anon_sym_task] = ACTIONS(4642),
    [anon_sym_modport] = ACTIONS(4642),
    [anon_sym_assert] = ACTIONS(4642),
    [anon_sym_property] = ACTIONS(4642),
    [anon_sym_assume] = ACTIONS(4642),
    [anon_sym_cover] = ACTIONS(4642),
    [anon_sym_sequence] = ACTIONS(4642),
    [anon_sym_restrict] = ACTIONS(4642),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_and] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_always] = ACTIONS(4642),
    [anon_sym_covergroup] = ACTIONS(4642),
    [anon_sym_let] = ACTIONS(4642),
    [anon_sym_pulldown] = ACTIONS(4642),
    [anon_sym_pullup] = ACTIONS(4642),
    [anon_sym_cmos] = ACTIONS(4642),
    [anon_sym_rcmos] = ACTIONS(4642),
    [anon_sym_bufif0] = ACTIONS(4642),
    [anon_sym_bufif1] = ACTIONS(4642),
    [anon_sym_notif0] = ACTIONS(4642),
    [anon_sym_notif1] = ACTIONS(4642),
    [anon_sym_nmos] = ACTIONS(4642),
    [anon_sym_pmos] = ACTIONS(4642),
    [anon_sym_rnmos] = ACTIONS(4642),
    [anon_sym_rpmos] = ACTIONS(4642),
    [anon_sym_nand] = ACTIONS(4642),
    [anon_sym_nor] = ACTIONS(4642),
    [anon_sym_xor] = ACTIONS(4642),
    [anon_sym_xnor] = ACTIONS(4642),
    [anon_sym_buf] = ACTIONS(4642),
    [anon_sym_tranif0] = ACTIONS(4642),
    [anon_sym_tranif1] = ACTIONS(4642),
    [anon_sym_rtranif1] = ACTIONS(4642),
    [anon_sym_rtranif0] = ACTIONS(4642),
    [anon_sym_tran] = ACTIONS(4642),
    [anon_sym_rtran] = ACTIONS(4642),
    [anon_sym_generate] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_primitive] = ACTIONS(4642),
    [anon_sym_initial] = ACTIONS(4642),
    [anon_sym_assign] = ACTIONS(4642),
    [anon_sym_alias] = ACTIONS(4642),
    [anon_sym_always_comb] = ACTIONS(4642),
    [anon_sym_always_latch] = ACTIONS(4642),
    [anon_sym_always_ff] = ACTIONS(4642),
    [anon_sym_final] = ACTIONS(4642),
    [anon_sym_endclocking] = ACTIONS(4642),
    [anon_sym_global] = ACTIONS(4642),
    [anon_sym_specify] = ACTIONS(4642),
    [anon_sym_LPAREN_STAR] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4640),
    [anon_sym_DOLLARunit] = ACTIONS(4640),
  },
  [736] = {
    [ts_builtin_sym_end] = ACTIONS(4644),
    [sym_simple_identifier] = ACTIONS(4646),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4644),
    [anon_sym_BQUOTE] = ACTIONS(4646),
    [aux_sym_id_directive_token1] = ACTIONS(4644),
    [aux_sym_id_directive_token2] = ACTIONS(4644),
    [aux_sym_id_directive_token3] = ACTIONS(4644),
    [aux_sym_id_directive_token4] = ACTIONS(4646),
    [aux_sym_zero_directive_token1] = ACTIONS(4644),
    [aux_sym_zero_directive_token2] = ACTIONS(4644),
    [aux_sym_zero_directive_token3] = ACTIONS(4644),
    [aux_sym_zero_directive_token4] = ACTIONS(4644),
    [aux_sym_zero_directive_token5] = ACTIONS(4644),
    [aux_sym_zero_directive_token6] = ACTIONS(4644),
    [aux_sym_zero_directive_token7] = ACTIONS(4644),
    [aux_sym_zero_directive_token8] = ACTIONS(4644),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4644),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4644),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_begin_keywords_token1] = ACTIONS(4644),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_endmodule] = ACTIONS(4646),
    [anon_sym_COLON] = ACTIONS(4648),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_module] = ACTIONS(4646),
    [anon_sym_macromodule] = ACTIONS(4646),
    [anon_sym_endinterface] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_endprogram] = ACTIONS(4646),
    [anon_sym_program] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_package] = ACTIONS(4646),
    [anon_sym_endpackage] = ACTIONS(4646),
    [anon_sym_timeunit] = ACTIONS(4646),
    [anon_sym_timeprecision] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_input] = ACTIONS(4646),
    [anon_sym_output] = ACTIONS(4646),
    [anon_sym_inout] = ACTIONS(4646),
    [anon_sym_ref] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_specparam] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_modport] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_primitive] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_specify] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [737] = {
    [ts_builtin_sym_end] = ACTIONS(4650),
    [sym_simple_identifier] = ACTIONS(4652),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4650),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4650),
    [anon_sym_BQUOTE] = ACTIONS(4652),
    [aux_sym_id_directive_token1] = ACTIONS(4650),
    [aux_sym_id_directive_token2] = ACTIONS(4650),
    [aux_sym_id_directive_token3] = ACTIONS(4650),
    [aux_sym_id_directive_token4] = ACTIONS(4652),
    [aux_sym_zero_directive_token1] = ACTIONS(4650),
    [aux_sym_zero_directive_token2] = ACTIONS(4650),
    [aux_sym_zero_directive_token3] = ACTIONS(4650),
    [aux_sym_zero_directive_token4] = ACTIONS(4650),
    [aux_sym_zero_directive_token5] = ACTIONS(4650),
    [aux_sym_zero_directive_token6] = ACTIONS(4650),
    [aux_sym_zero_directive_token7] = ACTIONS(4650),
    [aux_sym_zero_directive_token8] = ACTIONS(4650),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4650),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4650),
    [anon_sym_wire] = ACTIONS(4652),
    [anon_sym_tri] = ACTIONS(4652),
    [anon_sym_tri0] = ACTIONS(4652),
    [anon_sym_tri1] = ACTIONS(4652),
    [anon_sym_wand] = ACTIONS(4652),
    [anon_sym_triand] = ACTIONS(4652),
    [anon_sym_wor] = ACTIONS(4652),
    [anon_sym_trior] = ACTIONS(4652),
    [anon_sym_trireg] = ACTIONS(4652),
    [anon_sym_uwire] = ACTIONS(4652),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4650),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4650),
    [aux_sym_begin_keywords_token1] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4650),
    [anon_sym_endmodule] = ACTIONS(4652),
    [anon_sym_COLON] = ACTIONS(4654),
    [anon_sym_extern] = ACTIONS(4652),
    [anon_sym_module] = ACTIONS(4652),
    [anon_sym_macromodule] = ACTIONS(4652),
    [anon_sym_endinterface] = ACTIONS(4652),
    [anon_sym_interface] = ACTIONS(4652),
    [anon_sym_endprogram] = ACTIONS(4652),
    [anon_sym_program] = ACTIONS(4652),
    [anon_sym_checker] = ACTIONS(4652),
    [anon_sym_virtual] = ACTIONS(4652),
    [anon_sym_class] = ACTIONS(4652),
    [anon_sym_package] = ACTIONS(4652),
    [anon_sym_endpackage] = ACTIONS(4652),
    [anon_sym_timeunit] = ACTIONS(4652),
    [anon_sym_timeprecision] = ACTIONS(4652),
    [anon_sym_type] = ACTIONS(4652),
    [anon_sym_input] = ACTIONS(4652),
    [anon_sym_output] = ACTIONS(4652),
    [anon_sym_inout] = ACTIONS(4652),
    [anon_sym_ref] = ACTIONS(4652),
    [anon_sym_DOLLARfatal] = ACTIONS(4650),
    [anon_sym_DOLLARerror] = ACTIONS(4650),
    [anon_sym_DOLLARwarning] = ACTIONS(4650),
    [anon_sym_DOLLARinfo] = ACTIONS(4650),
    [anon_sym_default] = ACTIONS(4652),
    [anon_sym_clocking] = ACTIONS(4652),
    [anon_sym_defparam] = ACTIONS(4652),
    [anon_sym_bind] = ACTIONS(4652),
    [anon_sym_const] = ACTIONS(4652),
    [anon_sym_function] = ACTIONS(4652),
    [anon_sym_static] = ACTIONS(4652),
    [anon_sym_constraint] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4652),
    [anon_sym_else] = ACTIONS(4652),
    [anon_sym_LBRACK] = ACTIONS(4650),
    [anon_sym_localparam] = ACTIONS(4652),
    [anon_sym_parameter] = ACTIONS(4652),
    [anon_sym_specparam] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4652),
    [anon_sym_import] = ACTIONS(4652),
    [anon_sym_export] = ACTIONS(4652),
    [anon_sym_genvar] = ACTIONS(4652),
    [anon_sym_interconnect] = ACTIONS(4652),
    [anon_sym_typedef] = ACTIONS(4652),
    [anon_sym_enum] = ACTIONS(4652),
    [anon_sym_struct] = ACTIONS(4652),
    [anon_sym_union] = ACTIONS(4652),
    [anon_sym_nettype] = ACTIONS(4652),
    [anon_sym_automatic] = ACTIONS(4652),
    [anon_sym_string] = ACTIONS(4652),
    [anon_sym_chandle] = ACTIONS(4652),
    [anon_sym_event] = ACTIONS(4652),
    [anon_sym_byte] = ACTIONS(4652),
    [anon_sym_shortint] = ACTIONS(4652),
    [anon_sym_int] = ACTIONS(4652),
    [anon_sym_longint] = ACTIONS(4652),
    [anon_sym_integer] = ACTIONS(4652),
    [anon_sym_time] = ACTIONS(4652),
    [anon_sym_bit] = ACTIONS(4652),
    [anon_sym_logic] = ACTIONS(4652),
    [anon_sym_reg] = ACTIONS(4652),
    [anon_sym_shortreal] = ACTIONS(4652),
    [anon_sym_real] = ACTIONS(4652),
    [anon_sym_realtime] = ACTIONS(4652),
    [anon_sym_supply0] = ACTIONS(4652),
    [anon_sym_supply1] = ACTIONS(4652),
    [anon_sym_signed] = ACTIONS(4652),
    [anon_sym_unsigned] = ACTIONS(4652),
    [anon_sym_task] = ACTIONS(4652),
    [anon_sym_modport] = ACTIONS(4652),
    [anon_sym_assert] = ACTIONS(4652),
    [anon_sym_property] = ACTIONS(4652),
    [anon_sym_assume] = ACTIONS(4652),
    [anon_sym_cover] = ACTIONS(4652),
    [anon_sym_sequence] = ACTIONS(4652),
    [anon_sym_restrict] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4652),
    [anon_sym_or] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4652),
    [anon_sym_case] = ACTIONS(4652),
    [anon_sym_always] = ACTIONS(4652),
    [anon_sym_covergroup] = ACTIONS(4652),
    [anon_sym_let] = ACTIONS(4652),
    [anon_sym_pulldown] = ACTIONS(4652),
    [anon_sym_pullup] = ACTIONS(4652),
    [anon_sym_cmos] = ACTIONS(4652),
    [anon_sym_rcmos] = ACTIONS(4652),
    [anon_sym_bufif0] = ACTIONS(4652),
    [anon_sym_bufif1] = ACTIONS(4652),
    [anon_sym_notif0] = ACTIONS(4652),
    [anon_sym_notif1] = ACTIONS(4652),
    [anon_sym_nmos] = ACTIONS(4652),
    [anon_sym_pmos] = ACTIONS(4652),
    [anon_sym_rnmos] = ACTIONS(4652),
    [anon_sym_rpmos] = ACTIONS(4652),
    [anon_sym_nand] = ACTIONS(4652),
    [anon_sym_nor] = ACTIONS(4652),
    [anon_sym_xor] = ACTIONS(4652),
    [anon_sym_xnor] = ACTIONS(4652),
    [anon_sym_buf] = ACTIONS(4652),
    [anon_sym_tranif0] = ACTIONS(4652),
    [anon_sym_tranif1] = ACTIONS(4652),
    [anon_sym_rtranif1] = ACTIONS(4652),
    [anon_sym_rtranif0] = ACTIONS(4652),
    [anon_sym_tran] = ACTIONS(4652),
    [anon_sym_rtran] = ACTIONS(4652),
    [anon_sym_generate] = ACTIONS(4652),
    [anon_sym_for] = ACTIONS(4652),
    [anon_sym_primitive] = ACTIONS(4652),
    [anon_sym_initial] = ACTIONS(4652),
    [anon_sym_assign] = ACTIONS(4652),
    [anon_sym_alias] = ACTIONS(4652),
    [anon_sym_always_comb] = ACTIONS(4652),
    [anon_sym_always_latch] = ACTIONS(4652),
    [anon_sym_always_ff] = ACTIONS(4652),
    [anon_sym_final] = ACTIONS(4652),
    [anon_sym_global] = ACTIONS(4652),
    [anon_sym_specify] = ACTIONS(4652),
    [anon_sym_LPAREN_STAR] = ACTIONS(4650),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4650),
    [anon_sym_DOLLARunit] = ACTIONS(4650),
  },
  [738] = {
    [ts_builtin_sym_end] = ACTIONS(4656),
    [sym_simple_identifier] = ACTIONS(4658),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4656),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4656),
    [anon_sym_BQUOTE] = ACTIONS(4658),
    [aux_sym_id_directive_token1] = ACTIONS(4656),
    [aux_sym_id_directive_token2] = ACTIONS(4656),
    [aux_sym_id_directive_token3] = ACTIONS(4656),
    [aux_sym_id_directive_token4] = ACTIONS(4658),
    [aux_sym_zero_directive_token1] = ACTIONS(4656),
    [aux_sym_zero_directive_token2] = ACTIONS(4656),
    [aux_sym_zero_directive_token3] = ACTIONS(4656),
    [aux_sym_zero_directive_token4] = ACTIONS(4656),
    [aux_sym_zero_directive_token5] = ACTIONS(4656),
    [aux_sym_zero_directive_token6] = ACTIONS(4656),
    [aux_sym_zero_directive_token7] = ACTIONS(4656),
    [aux_sym_zero_directive_token8] = ACTIONS(4656),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4656),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4656),
    [anon_sym_wire] = ACTIONS(4658),
    [anon_sym_tri] = ACTIONS(4658),
    [anon_sym_tri0] = ACTIONS(4658),
    [anon_sym_tri1] = ACTIONS(4658),
    [anon_sym_wand] = ACTIONS(4658),
    [anon_sym_triand] = ACTIONS(4658),
    [anon_sym_wor] = ACTIONS(4658),
    [anon_sym_trior] = ACTIONS(4658),
    [anon_sym_trireg] = ACTIONS(4658),
    [anon_sym_uwire] = ACTIONS(4658),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4656),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4656),
    [aux_sym_begin_keywords_token1] = ACTIONS(4656),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_endmodule] = ACTIONS(4658),
    [anon_sym_extern] = ACTIONS(4658),
    [anon_sym_module] = ACTIONS(4658),
    [anon_sym_macromodule] = ACTIONS(4658),
    [anon_sym_endinterface] = ACTIONS(4658),
    [anon_sym_interface] = ACTIONS(4658),
    [anon_sym_endprogram] = ACTIONS(4658),
    [anon_sym_program] = ACTIONS(4658),
    [anon_sym_checker] = ACTIONS(4658),
    [anon_sym_virtual] = ACTIONS(4658),
    [anon_sym_class] = ACTIONS(4658),
    [anon_sym_package] = ACTIONS(4658),
    [anon_sym_endpackage] = ACTIONS(4658),
    [anon_sym_timeunit] = ACTIONS(4658),
    [anon_sym_timeprecision] = ACTIONS(4658),
    [anon_sym_type] = ACTIONS(4658),
    [anon_sym_input] = ACTIONS(4658),
    [anon_sym_output] = ACTIONS(4658),
    [anon_sym_inout] = ACTIONS(4658),
    [anon_sym_ref] = ACTIONS(4658),
    [anon_sym_DOLLARfatal] = ACTIONS(4656),
    [anon_sym_DOLLARerror] = ACTIONS(4656),
    [anon_sym_DOLLARwarning] = ACTIONS(4656),
    [anon_sym_DOLLARinfo] = ACTIONS(4656),
    [anon_sym_default] = ACTIONS(4658),
    [anon_sym_clocking] = ACTIONS(4658),
    [anon_sym_defparam] = ACTIONS(4658),
    [anon_sym_bind] = ACTIONS(4658),
    [anon_sym_const] = ACTIONS(4658),
    [anon_sym_function] = ACTIONS(4658),
    [anon_sym_static] = ACTIONS(4658),
    [anon_sym_constraint] = ACTIONS(4658),
    [anon_sym_if] = ACTIONS(4658),
    [anon_sym_else] = ACTIONS(4658),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [anon_sym_localparam] = ACTIONS(4658),
    [anon_sym_parameter] = ACTIONS(4658),
    [anon_sym_specparam] = ACTIONS(4658),
    [anon_sym_var] = ACTIONS(4658),
    [anon_sym_import] = ACTIONS(4658),
    [anon_sym_export] = ACTIONS(4658),
    [anon_sym_genvar] = ACTIONS(4658),
    [anon_sym_interconnect] = ACTIONS(4658),
    [anon_sym_typedef] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_struct] = ACTIONS(4658),
    [anon_sym_union] = ACTIONS(4658),
    [anon_sym_nettype] = ACTIONS(4658),
    [anon_sym_automatic] = ACTIONS(4658),
    [anon_sym_string] = ACTIONS(4658),
    [anon_sym_chandle] = ACTIONS(4658),
    [anon_sym_event] = ACTIONS(4658),
    [anon_sym_byte] = ACTIONS(4658),
    [anon_sym_shortint] = ACTIONS(4658),
    [anon_sym_int] = ACTIONS(4658),
    [anon_sym_longint] = ACTIONS(4658),
    [anon_sym_integer] = ACTIONS(4658),
    [anon_sym_time] = ACTIONS(4658),
    [anon_sym_bit] = ACTIONS(4658),
    [anon_sym_logic] = ACTIONS(4658),
    [anon_sym_reg] = ACTIONS(4658),
    [anon_sym_shortreal] = ACTIONS(4658),
    [anon_sym_real] = ACTIONS(4658),
    [anon_sym_realtime] = ACTIONS(4658),
    [anon_sym_supply0] = ACTIONS(4658),
    [anon_sym_supply1] = ACTIONS(4658),
    [anon_sym_signed] = ACTIONS(4658),
    [anon_sym_unsigned] = ACTIONS(4658),
    [anon_sym_task] = ACTIONS(4658),
    [anon_sym_modport] = ACTIONS(4658),
    [anon_sym_assert] = ACTIONS(4658),
    [anon_sym_property] = ACTIONS(4658),
    [anon_sym_assume] = ACTIONS(4658),
    [anon_sym_cover] = ACTIONS(4658),
    [anon_sym_sequence] = ACTIONS(4658),
    [anon_sym_restrict] = ACTIONS(4658),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_or] = ACTIONS(4658),
    [anon_sym_and] = ACTIONS(4658),
    [anon_sym_case] = ACTIONS(4658),
    [anon_sym_always] = ACTIONS(4658),
    [anon_sym_covergroup] = ACTIONS(4658),
    [anon_sym_let] = ACTIONS(4658),
    [anon_sym_pulldown] = ACTIONS(4658),
    [anon_sym_pullup] = ACTIONS(4658),
    [anon_sym_cmos] = ACTIONS(4658),
    [anon_sym_rcmos] = ACTIONS(4658),
    [anon_sym_bufif0] = ACTIONS(4658),
    [anon_sym_bufif1] = ACTIONS(4658),
    [anon_sym_notif0] = ACTIONS(4658),
    [anon_sym_notif1] = ACTIONS(4658),
    [anon_sym_nmos] = ACTIONS(4658),
    [anon_sym_pmos] = ACTIONS(4658),
    [anon_sym_rnmos] = ACTIONS(4658),
    [anon_sym_rpmos] = ACTIONS(4658),
    [anon_sym_nand] = ACTIONS(4658),
    [anon_sym_nor] = ACTIONS(4658),
    [anon_sym_xor] = ACTIONS(4658),
    [anon_sym_xnor] = ACTIONS(4658),
    [anon_sym_buf] = ACTIONS(4658),
    [anon_sym_tranif0] = ACTIONS(4658),
    [anon_sym_tranif1] = ACTIONS(4658),
    [anon_sym_rtranif1] = ACTIONS(4658),
    [anon_sym_rtranif0] = ACTIONS(4658),
    [anon_sym_tran] = ACTIONS(4658),
    [anon_sym_rtran] = ACTIONS(4658),
    [anon_sym_generate] = ACTIONS(4658),
    [anon_sym_for] = ACTIONS(4658),
    [anon_sym_primitive] = ACTIONS(4658),
    [anon_sym_initial] = ACTIONS(4658),
    [anon_sym_assign] = ACTIONS(4658),
    [anon_sym_alias] = ACTIONS(4658),
    [anon_sym_always_comb] = ACTIONS(4658),
    [anon_sym_always_latch] = ACTIONS(4658),
    [anon_sym_always_ff] = ACTIONS(4658),
    [anon_sym_final] = ACTIONS(4658),
    [anon_sym_endclocking] = ACTIONS(4658),
    [anon_sym_global] = ACTIONS(4658),
    [anon_sym_specify] = ACTIONS(4658),
    [anon_sym_LPAREN_STAR] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4656),
    [anon_sym_DOLLARunit] = ACTIONS(4656),
  },
  [739] = {
    [ts_builtin_sym_end] = ACTIONS(4660),
    [sym_simple_identifier] = ACTIONS(4662),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4660),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4660),
    [anon_sym_BQUOTE] = ACTIONS(4662),
    [aux_sym_id_directive_token1] = ACTIONS(4660),
    [aux_sym_id_directive_token2] = ACTIONS(4660),
    [aux_sym_id_directive_token3] = ACTIONS(4660),
    [aux_sym_id_directive_token4] = ACTIONS(4662),
    [aux_sym_zero_directive_token1] = ACTIONS(4660),
    [aux_sym_zero_directive_token2] = ACTIONS(4660),
    [aux_sym_zero_directive_token3] = ACTIONS(4660),
    [aux_sym_zero_directive_token4] = ACTIONS(4660),
    [aux_sym_zero_directive_token5] = ACTIONS(4660),
    [aux_sym_zero_directive_token6] = ACTIONS(4660),
    [aux_sym_zero_directive_token7] = ACTIONS(4660),
    [aux_sym_zero_directive_token8] = ACTIONS(4660),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4660),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4660),
    [anon_sym_wire] = ACTIONS(4662),
    [anon_sym_tri] = ACTIONS(4662),
    [anon_sym_tri0] = ACTIONS(4662),
    [anon_sym_tri1] = ACTIONS(4662),
    [anon_sym_wand] = ACTIONS(4662),
    [anon_sym_triand] = ACTIONS(4662),
    [anon_sym_wor] = ACTIONS(4662),
    [anon_sym_trior] = ACTIONS(4662),
    [anon_sym_trireg] = ACTIONS(4662),
    [anon_sym_uwire] = ACTIONS(4662),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4660),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4660),
    [aux_sym_begin_keywords_token1] = ACTIONS(4660),
    [anon_sym_SEMI] = ACTIONS(4660),
    [anon_sym_endmodule] = ACTIONS(4662),
    [anon_sym_COLON] = ACTIONS(4664),
    [anon_sym_extern] = ACTIONS(4662),
    [anon_sym_module] = ACTIONS(4662),
    [anon_sym_macromodule] = ACTIONS(4662),
    [anon_sym_endinterface] = ACTIONS(4662),
    [anon_sym_interface] = ACTIONS(4662),
    [anon_sym_endprogram] = ACTIONS(4662),
    [anon_sym_program] = ACTIONS(4662),
    [anon_sym_checker] = ACTIONS(4662),
    [anon_sym_virtual] = ACTIONS(4662),
    [anon_sym_class] = ACTIONS(4662),
    [anon_sym_package] = ACTIONS(4662),
    [anon_sym_endpackage] = ACTIONS(4662),
    [anon_sym_timeunit] = ACTIONS(4662),
    [anon_sym_timeprecision] = ACTIONS(4662),
    [anon_sym_type] = ACTIONS(4662),
    [anon_sym_input] = ACTIONS(4662),
    [anon_sym_output] = ACTIONS(4662),
    [anon_sym_inout] = ACTIONS(4662),
    [anon_sym_ref] = ACTIONS(4662),
    [anon_sym_DOLLARfatal] = ACTIONS(4660),
    [anon_sym_DOLLARerror] = ACTIONS(4660),
    [anon_sym_DOLLARwarning] = ACTIONS(4660),
    [anon_sym_DOLLARinfo] = ACTIONS(4660),
    [anon_sym_default] = ACTIONS(4662),
    [anon_sym_clocking] = ACTIONS(4662),
    [anon_sym_defparam] = ACTIONS(4662),
    [anon_sym_bind] = ACTIONS(4662),
    [anon_sym_const] = ACTIONS(4662),
    [anon_sym_function] = ACTIONS(4662),
    [anon_sym_static] = ACTIONS(4662),
    [anon_sym_constraint] = ACTIONS(4662),
    [anon_sym_if] = ACTIONS(4662),
    [anon_sym_else] = ACTIONS(4662),
    [anon_sym_LBRACK] = ACTIONS(4660),
    [anon_sym_localparam] = ACTIONS(4662),
    [anon_sym_parameter] = ACTIONS(4662),
    [anon_sym_specparam] = ACTIONS(4662),
    [anon_sym_var] = ACTIONS(4662),
    [anon_sym_import] = ACTIONS(4662),
    [anon_sym_export] = ACTIONS(4662),
    [anon_sym_genvar] = ACTIONS(4662),
    [anon_sym_interconnect] = ACTIONS(4662),
    [anon_sym_typedef] = ACTIONS(4662),
    [anon_sym_enum] = ACTIONS(4662),
    [anon_sym_struct] = ACTIONS(4662),
    [anon_sym_union] = ACTIONS(4662),
    [anon_sym_nettype] = ACTIONS(4662),
    [anon_sym_automatic] = ACTIONS(4662),
    [anon_sym_string] = ACTIONS(4662),
    [anon_sym_chandle] = ACTIONS(4662),
    [anon_sym_event] = ACTIONS(4662),
    [anon_sym_byte] = ACTIONS(4662),
    [anon_sym_shortint] = ACTIONS(4662),
    [anon_sym_int] = ACTIONS(4662),
    [anon_sym_longint] = ACTIONS(4662),
    [anon_sym_integer] = ACTIONS(4662),
    [anon_sym_time] = ACTIONS(4662),
    [anon_sym_bit] = ACTIONS(4662),
    [anon_sym_logic] = ACTIONS(4662),
    [anon_sym_reg] = ACTIONS(4662),
    [anon_sym_shortreal] = ACTIONS(4662),
    [anon_sym_real] = ACTIONS(4662),
    [anon_sym_realtime] = ACTIONS(4662),
    [anon_sym_supply0] = ACTIONS(4662),
    [anon_sym_supply1] = ACTIONS(4662),
    [anon_sym_signed] = ACTIONS(4662),
    [anon_sym_unsigned] = ACTIONS(4662),
    [anon_sym_task] = ACTIONS(4662),
    [anon_sym_modport] = ACTIONS(4662),
    [anon_sym_assert] = ACTIONS(4662),
    [anon_sym_property] = ACTIONS(4662),
    [anon_sym_assume] = ACTIONS(4662),
    [anon_sym_cover] = ACTIONS(4662),
    [anon_sym_sequence] = ACTIONS(4662),
    [anon_sym_restrict] = ACTIONS(4662),
    [anon_sym_not] = ACTIONS(4662),
    [anon_sym_or] = ACTIONS(4662),
    [anon_sym_and] = ACTIONS(4662),
    [anon_sym_case] = ACTIONS(4662),
    [anon_sym_always] = ACTIONS(4662),
    [anon_sym_covergroup] = ACTIONS(4662),
    [anon_sym_let] = ACTIONS(4662),
    [anon_sym_pulldown] = ACTIONS(4662),
    [anon_sym_pullup] = ACTIONS(4662),
    [anon_sym_cmos] = ACTIONS(4662),
    [anon_sym_rcmos] = ACTIONS(4662),
    [anon_sym_bufif0] = ACTIONS(4662),
    [anon_sym_bufif1] = ACTIONS(4662),
    [anon_sym_notif0] = ACTIONS(4662),
    [anon_sym_notif1] = ACTIONS(4662),
    [anon_sym_nmos] = ACTIONS(4662),
    [anon_sym_pmos] = ACTIONS(4662),
    [anon_sym_rnmos] = ACTIONS(4662),
    [anon_sym_rpmos] = ACTIONS(4662),
    [anon_sym_nand] = ACTIONS(4662),
    [anon_sym_nor] = ACTIONS(4662),
    [anon_sym_xor] = ACTIONS(4662),
    [anon_sym_xnor] = ACTIONS(4662),
    [anon_sym_buf] = ACTIONS(4662),
    [anon_sym_tranif0] = ACTIONS(4662),
    [anon_sym_tranif1] = ACTIONS(4662),
    [anon_sym_rtranif1] = ACTIONS(4662),
    [anon_sym_rtranif0] = ACTIONS(4662),
    [anon_sym_tran] = ACTIONS(4662),
    [anon_sym_rtran] = ACTIONS(4662),
    [anon_sym_generate] = ACTIONS(4662),
    [anon_sym_for] = ACTIONS(4662),
    [anon_sym_primitive] = ACTIONS(4662),
    [anon_sym_initial] = ACTIONS(4662),
    [anon_sym_assign] = ACTIONS(4662),
    [anon_sym_alias] = ACTIONS(4662),
    [anon_sym_always_comb] = ACTIONS(4662),
    [anon_sym_always_latch] = ACTIONS(4662),
    [anon_sym_always_ff] = ACTIONS(4662),
    [anon_sym_final] = ACTIONS(4662),
    [anon_sym_global] = ACTIONS(4662),
    [anon_sym_specify] = ACTIONS(4662),
    [anon_sym_LPAREN_STAR] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4660),
    [anon_sym_DOLLARunit] = ACTIONS(4660),
  },
  [740] = {
    [ts_builtin_sym_end] = ACTIONS(4666),
    [sym_simple_identifier] = ACTIONS(4668),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4666),
    [anon_sym_BQUOTE] = ACTIONS(4668),
    [aux_sym_id_directive_token1] = ACTIONS(4666),
    [aux_sym_id_directive_token2] = ACTIONS(4666),
    [aux_sym_id_directive_token3] = ACTIONS(4666),
    [aux_sym_id_directive_token4] = ACTIONS(4668),
    [aux_sym_zero_directive_token1] = ACTIONS(4666),
    [aux_sym_zero_directive_token2] = ACTIONS(4666),
    [aux_sym_zero_directive_token3] = ACTIONS(4666),
    [aux_sym_zero_directive_token4] = ACTIONS(4666),
    [aux_sym_zero_directive_token5] = ACTIONS(4666),
    [aux_sym_zero_directive_token6] = ACTIONS(4666),
    [aux_sym_zero_directive_token7] = ACTIONS(4666),
    [aux_sym_zero_directive_token8] = ACTIONS(4666),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4666),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4666),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_begin_keywords_token1] = ACTIONS(4666),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_endmodule] = ACTIONS(4668),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_module] = ACTIONS(4668),
    [anon_sym_macromodule] = ACTIONS(4668),
    [anon_sym_endinterface] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_endprogram] = ACTIONS(4668),
    [anon_sym_program] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_package] = ACTIONS(4668),
    [anon_sym_endpackage] = ACTIONS(4668),
    [anon_sym_timeunit] = ACTIONS(4668),
    [anon_sym_timeprecision] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_input] = ACTIONS(4668),
    [anon_sym_output] = ACTIONS(4668),
    [anon_sym_inout] = ACTIONS(4668),
    [anon_sym_ref] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_specparam] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_modport] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_primitive] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_specify] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [741] = {
    [ts_builtin_sym_end] = ACTIONS(4672),
    [sym_simple_identifier] = ACTIONS(4674),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4672),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4672),
    [anon_sym_BQUOTE] = ACTIONS(4674),
    [aux_sym_id_directive_token1] = ACTIONS(4672),
    [aux_sym_id_directive_token2] = ACTIONS(4672),
    [aux_sym_id_directive_token3] = ACTIONS(4672),
    [aux_sym_id_directive_token4] = ACTIONS(4674),
    [aux_sym_zero_directive_token1] = ACTIONS(4672),
    [aux_sym_zero_directive_token2] = ACTIONS(4672),
    [aux_sym_zero_directive_token3] = ACTIONS(4672),
    [aux_sym_zero_directive_token4] = ACTIONS(4672),
    [aux_sym_zero_directive_token5] = ACTIONS(4672),
    [aux_sym_zero_directive_token6] = ACTIONS(4672),
    [aux_sym_zero_directive_token7] = ACTIONS(4672),
    [aux_sym_zero_directive_token8] = ACTIONS(4672),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4672),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4672),
    [anon_sym_wire] = ACTIONS(4674),
    [anon_sym_tri] = ACTIONS(4674),
    [anon_sym_tri0] = ACTIONS(4674),
    [anon_sym_tri1] = ACTIONS(4674),
    [anon_sym_wand] = ACTIONS(4674),
    [anon_sym_triand] = ACTIONS(4674),
    [anon_sym_wor] = ACTIONS(4674),
    [anon_sym_trior] = ACTIONS(4674),
    [anon_sym_trireg] = ACTIONS(4674),
    [anon_sym_uwire] = ACTIONS(4674),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4672),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4672),
    [aux_sym_begin_keywords_token1] = ACTIONS(4672),
    [anon_sym_SEMI] = ACTIONS(4672),
    [anon_sym_endmodule] = ACTIONS(4674),
    [anon_sym_extern] = ACTIONS(4674),
    [anon_sym_module] = ACTIONS(4674),
    [anon_sym_macromodule] = ACTIONS(4674),
    [anon_sym_endinterface] = ACTIONS(4674),
    [anon_sym_interface] = ACTIONS(4674),
    [anon_sym_endprogram] = ACTIONS(4674),
    [anon_sym_program] = ACTIONS(4674),
    [anon_sym_checker] = ACTIONS(4674),
    [anon_sym_virtual] = ACTIONS(4674),
    [anon_sym_class] = ACTIONS(4674),
    [anon_sym_package] = ACTIONS(4674),
    [anon_sym_endpackage] = ACTIONS(4674),
    [anon_sym_timeunit] = ACTIONS(4674),
    [anon_sym_timeprecision] = ACTIONS(4674),
    [anon_sym_type] = ACTIONS(4674),
    [anon_sym_input] = ACTIONS(4674),
    [anon_sym_output] = ACTIONS(4674),
    [anon_sym_inout] = ACTIONS(4674),
    [anon_sym_ref] = ACTIONS(4674),
    [anon_sym_DOLLARfatal] = ACTIONS(4672),
    [anon_sym_DOLLARerror] = ACTIONS(4672),
    [anon_sym_DOLLARwarning] = ACTIONS(4672),
    [anon_sym_DOLLARinfo] = ACTIONS(4672),
    [anon_sym_default] = ACTIONS(4674),
    [anon_sym_clocking] = ACTIONS(4674),
    [anon_sym_defparam] = ACTIONS(4674),
    [anon_sym_bind] = ACTIONS(4674),
    [anon_sym_const] = ACTIONS(4674),
    [anon_sym_function] = ACTIONS(4674),
    [anon_sym_static] = ACTIONS(4674),
    [anon_sym_constraint] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4674),
    [anon_sym_else] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4672),
    [anon_sym_localparam] = ACTIONS(4674),
    [anon_sym_parameter] = ACTIONS(4674),
    [anon_sym_specparam] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_import] = ACTIONS(4674),
    [anon_sym_export] = ACTIONS(4674),
    [anon_sym_genvar] = ACTIONS(4674),
    [anon_sym_interconnect] = ACTIONS(4674),
    [anon_sym_typedef] = ACTIONS(4674),
    [anon_sym_enum] = ACTIONS(4674),
    [anon_sym_struct] = ACTIONS(4674),
    [anon_sym_union] = ACTIONS(4674),
    [anon_sym_nettype] = ACTIONS(4674),
    [anon_sym_automatic] = ACTIONS(4674),
    [anon_sym_string] = ACTIONS(4674),
    [anon_sym_chandle] = ACTIONS(4674),
    [anon_sym_event] = ACTIONS(4674),
    [anon_sym_byte] = ACTIONS(4674),
    [anon_sym_shortint] = ACTIONS(4674),
    [anon_sym_int] = ACTIONS(4674),
    [anon_sym_longint] = ACTIONS(4674),
    [anon_sym_integer] = ACTIONS(4674),
    [anon_sym_time] = ACTIONS(4674),
    [anon_sym_bit] = ACTIONS(4674),
    [anon_sym_logic] = ACTIONS(4674),
    [anon_sym_reg] = ACTIONS(4674),
    [anon_sym_shortreal] = ACTIONS(4674),
    [anon_sym_real] = ACTIONS(4674),
    [anon_sym_realtime] = ACTIONS(4674),
    [anon_sym_supply0] = ACTIONS(4674),
    [anon_sym_supply1] = ACTIONS(4674),
    [anon_sym_signed] = ACTIONS(4674),
    [anon_sym_unsigned] = ACTIONS(4674),
    [anon_sym_task] = ACTIONS(4674),
    [anon_sym_modport] = ACTIONS(4674),
    [anon_sym_assert] = ACTIONS(4674),
    [anon_sym_property] = ACTIONS(4674),
    [anon_sym_assume] = ACTIONS(4674),
    [anon_sym_cover] = ACTIONS(4674),
    [anon_sym_sequence] = ACTIONS(4674),
    [anon_sym_restrict] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_case] = ACTIONS(4674),
    [anon_sym_always] = ACTIONS(4674),
    [anon_sym_covergroup] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_pulldown] = ACTIONS(4674),
    [anon_sym_pullup] = ACTIONS(4674),
    [anon_sym_cmos] = ACTIONS(4674),
    [anon_sym_rcmos] = ACTIONS(4674),
    [anon_sym_bufif0] = ACTIONS(4674),
    [anon_sym_bufif1] = ACTIONS(4674),
    [anon_sym_notif0] = ACTIONS(4674),
    [anon_sym_notif1] = ACTIONS(4674),
    [anon_sym_nmos] = ACTIONS(4674),
    [anon_sym_pmos] = ACTIONS(4674),
    [anon_sym_rnmos] = ACTIONS(4674),
    [anon_sym_rpmos] = ACTIONS(4674),
    [anon_sym_nand] = ACTIONS(4674),
    [anon_sym_nor] = ACTIONS(4674),
    [anon_sym_xor] = ACTIONS(4674),
    [anon_sym_xnor] = ACTIONS(4674),
    [anon_sym_buf] = ACTIONS(4674),
    [anon_sym_tranif0] = ACTIONS(4674),
    [anon_sym_tranif1] = ACTIONS(4674),
    [anon_sym_rtranif1] = ACTIONS(4674),
    [anon_sym_rtranif0] = ACTIONS(4674),
    [anon_sym_tran] = ACTIONS(4674),
    [anon_sym_rtran] = ACTIONS(4674),
    [anon_sym_generate] = ACTIONS(4674),
    [anon_sym_for] = ACTIONS(4674),
    [anon_sym_primitive] = ACTIONS(4674),
    [anon_sym_initial] = ACTIONS(4674),
    [anon_sym_assign] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_always_comb] = ACTIONS(4674),
    [anon_sym_always_latch] = ACTIONS(4674),
    [anon_sym_always_ff] = ACTIONS(4674),
    [anon_sym_final] = ACTIONS(4674),
    [anon_sym_endclocking] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_specify] = ACTIONS(4674),
    [anon_sym_LPAREN_STAR] = ACTIONS(4672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4672),
    [anon_sym_DOLLARunit] = ACTIONS(4672),
  },
  [742] = {
    [ts_builtin_sym_end] = ACTIONS(4676),
    [sym_simple_identifier] = ACTIONS(4678),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4676),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4676),
    [anon_sym_BQUOTE] = ACTIONS(4678),
    [aux_sym_id_directive_token1] = ACTIONS(4676),
    [aux_sym_id_directive_token2] = ACTIONS(4676),
    [aux_sym_id_directive_token3] = ACTIONS(4676),
    [aux_sym_id_directive_token4] = ACTIONS(4678),
    [aux_sym_zero_directive_token1] = ACTIONS(4676),
    [aux_sym_zero_directive_token2] = ACTIONS(4676),
    [aux_sym_zero_directive_token3] = ACTIONS(4676),
    [aux_sym_zero_directive_token4] = ACTIONS(4676),
    [aux_sym_zero_directive_token5] = ACTIONS(4676),
    [aux_sym_zero_directive_token6] = ACTIONS(4676),
    [aux_sym_zero_directive_token7] = ACTIONS(4676),
    [aux_sym_zero_directive_token8] = ACTIONS(4676),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4676),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4676),
    [anon_sym_wire] = ACTIONS(4678),
    [anon_sym_tri] = ACTIONS(4678),
    [anon_sym_tri0] = ACTIONS(4678),
    [anon_sym_tri1] = ACTIONS(4678),
    [anon_sym_wand] = ACTIONS(4678),
    [anon_sym_triand] = ACTIONS(4678),
    [anon_sym_wor] = ACTIONS(4678),
    [anon_sym_trior] = ACTIONS(4678),
    [anon_sym_trireg] = ACTIONS(4678),
    [anon_sym_uwire] = ACTIONS(4678),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4676),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4676),
    [aux_sym_begin_keywords_token1] = ACTIONS(4676),
    [anon_sym_SEMI] = ACTIONS(4676),
    [anon_sym_endmodule] = ACTIONS(4678),
    [anon_sym_COLON] = ACTIONS(4680),
    [anon_sym_extern] = ACTIONS(4678),
    [anon_sym_module] = ACTIONS(4678),
    [anon_sym_macromodule] = ACTIONS(4678),
    [anon_sym_endinterface] = ACTIONS(4678),
    [anon_sym_interface] = ACTIONS(4678),
    [anon_sym_endprogram] = ACTIONS(4678),
    [anon_sym_program] = ACTIONS(4678),
    [anon_sym_checker] = ACTIONS(4678),
    [anon_sym_virtual] = ACTIONS(4678),
    [anon_sym_class] = ACTIONS(4678),
    [anon_sym_package] = ACTIONS(4678),
    [anon_sym_endpackage] = ACTIONS(4678),
    [anon_sym_timeunit] = ACTIONS(4678),
    [anon_sym_timeprecision] = ACTIONS(4678),
    [anon_sym_type] = ACTIONS(4678),
    [anon_sym_input] = ACTIONS(4678),
    [anon_sym_output] = ACTIONS(4678),
    [anon_sym_inout] = ACTIONS(4678),
    [anon_sym_ref] = ACTIONS(4678),
    [anon_sym_DOLLARfatal] = ACTIONS(4676),
    [anon_sym_DOLLARerror] = ACTIONS(4676),
    [anon_sym_DOLLARwarning] = ACTIONS(4676),
    [anon_sym_DOLLARinfo] = ACTIONS(4676),
    [anon_sym_default] = ACTIONS(4678),
    [anon_sym_clocking] = ACTIONS(4678),
    [anon_sym_defparam] = ACTIONS(4678),
    [anon_sym_bind] = ACTIONS(4678),
    [anon_sym_const] = ACTIONS(4678),
    [anon_sym_function] = ACTIONS(4678),
    [anon_sym_static] = ACTIONS(4678),
    [anon_sym_constraint] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4678),
    [anon_sym_else] = ACTIONS(4678),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_localparam] = ACTIONS(4678),
    [anon_sym_parameter] = ACTIONS(4678),
    [anon_sym_specparam] = ACTIONS(4678),
    [anon_sym_var] = ACTIONS(4678),
    [anon_sym_import] = ACTIONS(4678),
    [anon_sym_export] = ACTIONS(4678),
    [anon_sym_genvar] = ACTIONS(4678),
    [anon_sym_interconnect] = ACTIONS(4678),
    [anon_sym_typedef] = ACTIONS(4678),
    [anon_sym_enum] = ACTIONS(4678),
    [anon_sym_struct] = ACTIONS(4678),
    [anon_sym_union] = ACTIONS(4678),
    [anon_sym_nettype] = ACTIONS(4678),
    [anon_sym_automatic] = ACTIONS(4678),
    [anon_sym_string] = ACTIONS(4678),
    [anon_sym_chandle] = ACTIONS(4678),
    [anon_sym_event] = ACTIONS(4678),
    [anon_sym_byte] = ACTIONS(4678),
    [anon_sym_shortint] = ACTIONS(4678),
    [anon_sym_int] = ACTIONS(4678),
    [anon_sym_longint] = ACTIONS(4678),
    [anon_sym_integer] = ACTIONS(4678),
    [anon_sym_time] = ACTIONS(4678),
    [anon_sym_bit] = ACTIONS(4678),
    [anon_sym_logic] = ACTIONS(4678),
    [anon_sym_reg] = ACTIONS(4678),
    [anon_sym_shortreal] = ACTIONS(4678),
    [anon_sym_real] = ACTIONS(4678),
    [anon_sym_realtime] = ACTIONS(4678),
    [anon_sym_supply0] = ACTIONS(4678),
    [anon_sym_supply1] = ACTIONS(4678),
    [anon_sym_signed] = ACTIONS(4678),
    [anon_sym_unsigned] = ACTIONS(4678),
    [anon_sym_task] = ACTIONS(4678),
    [anon_sym_modport] = ACTIONS(4678),
    [anon_sym_assert] = ACTIONS(4678),
    [anon_sym_property] = ACTIONS(4678),
    [anon_sym_assume] = ACTIONS(4678),
    [anon_sym_cover] = ACTIONS(4678),
    [anon_sym_sequence] = ACTIONS(4678),
    [anon_sym_restrict] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4678),
    [anon_sym_or] = ACTIONS(4678),
    [anon_sym_and] = ACTIONS(4678),
    [anon_sym_case] = ACTIONS(4678),
    [anon_sym_always] = ACTIONS(4678),
    [anon_sym_covergroup] = ACTIONS(4678),
    [anon_sym_let] = ACTIONS(4678),
    [anon_sym_pulldown] = ACTIONS(4678),
    [anon_sym_pullup] = ACTIONS(4678),
    [anon_sym_cmos] = ACTIONS(4678),
    [anon_sym_rcmos] = ACTIONS(4678),
    [anon_sym_bufif0] = ACTIONS(4678),
    [anon_sym_bufif1] = ACTIONS(4678),
    [anon_sym_notif0] = ACTIONS(4678),
    [anon_sym_notif1] = ACTIONS(4678),
    [anon_sym_nmos] = ACTIONS(4678),
    [anon_sym_pmos] = ACTIONS(4678),
    [anon_sym_rnmos] = ACTIONS(4678),
    [anon_sym_rpmos] = ACTIONS(4678),
    [anon_sym_nand] = ACTIONS(4678),
    [anon_sym_nor] = ACTIONS(4678),
    [anon_sym_xor] = ACTIONS(4678),
    [anon_sym_xnor] = ACTIONS(4678),
    [anon_sym_buf] = ACTIONS(4678),
    [anon_sym_tranif0] = ACTIONS(4678),
    [anon_sym_tranif1] = ACTIONS(4678),
    [anon_sym_rtranif1] = ACTIONS(4678),
    [anon_sym_rtranif0] = ACTIONS(4678),
    [anon_sym_tran] = ACTIONS(4678),
    [anon_sym_rtran] = ACTIONS(4678),
    [anon_sym_generate] = ACTIONS(4678),
    [anon_sym_for] = ACTIONS(4678),
    [anon_sym_primitive] = ACTIONS(4678),
    [anon_sym_initial] = ACTIONS(4678),
    [anon_sym_assign] = ACTIONS(4678),
    [anon_sym_alias] = ACTIONS(4678),
    [anon_sym_always_comb] = ACTIONS(4678),
    [anon_sym_always_latch] = ACTIONS(4678),
    [anon_sym_always_ff] = ACTIONS(4678),
    [anon_sym_final] = ACTIONS(4678),
    [anon_sym_global] = ACTIONS(4678),
    [anon_sym_specify] = ACTIONS(4678),
    [anon_sym_LPAREN_STAR] = ACTIONS(4676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4676),
    [anon_sym_DOLLARunit] = ACTIONS(4676),
  },
  [743] = {
    [ts_builtin_sym_end] = ACTIONS(4682),
    [sym_simple_identifier] = ACTIONS(4684),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4682),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4682),
    [anon_sym_BQUOTE] = ACTIONS(4684),
    [aux_sym_id_directive_token1] = ACTIONS(4682),
    [aux_sym_id_directive_token2] = ACTIONS(4682),
    [aux_sym_id_directive_token3] = ACTIONS(4682),
    [aux_sym_id_directive_token4] = ACTIONS(4684),
    [aux_sym_zero_directive_token1] = ACTIONS(4682),
    [aux_sym_zero_directive_token2] = ACTIONS(4682),
    [aux_sym_zero_directive_token3] = ACTIONS(4682),
    [aux_sym_zero_directive_token4] = ACTIONS(4682),
    [aux_sym_zero_directive_token5] = ACTIONS(4682),
    [aux_sym_zero_directive_token6] = ACTIONS(4682),
    [aux_sym_zero_directive_token7] = ACTIONS(4682),
    [aux_sym_zero_directive_token8] = ACTIONS(4682),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4682),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4682),
    [anon_sym_wire] = ACTIONS(4684),
    [anon_sym_tri] = ACTIONS(4684),
    [anon_sym_tri0] = ACTIONS(4684),
    [anon_sym_tri1] = ACTIONS(4684),
    [anon_sym_wand] = ACTIONS(4684),
    [anon_sym_triand] = ACTIONS(4684),
    [anon_sym_wor] = ACTIONS(4684),
    [anon_sym_trior] = ACTIONS(4684),
    [anon_sym_trireg] = ACTIONS(4684),
    [anon_sym_uwire] = ACTIONS(4684),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4682),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4682),
    [aux_sym_begin_keywords_token1] = ACTIONS(4682),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_endmodule] = ACTIONS(4684),
    [anon_sym_COLON] = ACTIONS(4686),
    [anon_sym_extern] = ACTIONS(4684),
    [anon_sym_module] = ACTIONS(4684),
    [anon_sym_macromodule] = ACTIONS(4684),
    [anon_sym_endinterface] = ACTIONS(4684),
    [anon_sym_interface] = ACTIONS(4684),
    [anon_sym_endprogram] = ACTIONS(4684),
    [anon_sym_program] = ACTIONS(4684),
    [anon_sym_checker] = ACTIONS(4684),
    [anon_sym_virtual] = ACTIONS(4684),
    [anon_sym_class] = ACTIONS(4684),
    [anon_sym_package] = ACTIONS(4684),
    [anon_sym_endpackage] = ACTIONS(4684),
    [anon_sym_timeunit] = ACTIONS(4684),
    [anon_sym_timeprecision] = ACTIONS(4684),
    [anon_sym_type] = ACTIONS(4684),
    [anon_sym_input] = ACTIONS(4684),
    [anon_sym_output] = ACTIONS(4684),
    [anon_sym_inout] = ACTIONS(4684),
    [anon_sym_ref] = ACTIONS(4684),
    [anon_sym_DOLLARfatal] = ACTIONS(4682),
    [anon_sym_DOLLARerror] = ACTIONS(4682),
    [anon_sym_DOLLARwarning] = ACTIONS(4682),
    [anon_sym_DOLLARinfo] = ACTIONS(4682),
    [anon_sym_default] = ACTIONS(4684),
    [anon_sym_clocking] = ACTIONS(4684),
    [anon_sym_defparam] = ACTIONS(4684),
    [anon_sym_bind] = ACTIONS(4684),
    [anon_sym_const] = ACTIONS(4684),
    [anon_sym_function] = ACTIONS(4684),
    [anon_sym_static] = ACTIONS(4684),
    [anon_sym_constraint] = ACTIONS(4684),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [anon_sym_localparam] = ACTIONS(4684),
    [anon_sym_parameter] = ACTIONS(4684),
    [anon_sym_specparam] = ACTIONS(4684),
    [anon_sym_var] = ACTIONS(4684),
    [anon_sym_import] = ACTIONS(4684),
    [anon_sym_export] = ACTIONS(4684),
    [anon_sym_genvar] = ACTIONS(4684),
    [anon_sym_interconnect] = ACTIONS(4684),
    [anon_sym_typedef] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_struct] = ACTIONS(4684),
    [anon_sym_union] = ACTIONS(4684),
    [anon_sym_nettype] = ACTIONS(4684),
    [anon_sym_automatic] = ACTIONS(4684),
    [anon_sym_string] = ACTIONS(4684),
    [anon_sym_chandle] = ACTIONS(4684),
    [anon_sym_event] = ACTIONS(4684),
    [anon_sym_byte] = ACTIONS(4684),
    [anon_sym_shortint] = ACTIONS(4684),
    [anon_sym_int] = ACTIONS(4684),
    [anon_sym_longint] = ACTIONS(4684),
    [anon_sym_integer] = ACTIONS(4684),
    [anon_sym_time] = ACTIONS(4684),
    [anon_sym_bit] = ACTIONS(4684),
    [anon_sym_logic] = ACTIONS(4684),
    [anon_sym_reg] = ACTIONS(4684),
    [anon_sym_shortreal] = ACTIONS(4684),
    [anon_sym_real] = ACTIONS(4684),
    [anon_sym_realtime] = ACTIONS(4684),
    [anon_sym_supply0] = ACTIONS(4684),
    [anon_sym_supply1] = ACTIONS(4684),
    [anon_sym_signed] = ACTIONS(4684),
    [anon_sym_unsigned] = ACTIONS(4684),
    [anon_sym_task] = ACTIONS(4684),
    [anon_sym_modport] = ACTIONS(4684),
    [anon_sym_assert] = ACTIONS(4684),
    [anon_sym_property] = ACTIONS(4684),
    [anon_sym_assume] = ACTIONS(4684),
    [anon_sym_cover] = ACTIONS(4684),
    [anon_sym_sequence] = ACTIONS(4684),
    [anon_sym_restrict] = ACTIONS(4684),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_or] = ACTIONS(4684),
    [anon_sym_and] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_always] = ACTIONS(4684),
    [anon_sym_covergroup] = ACTIONS(4684),
    [anon_sym_let] = ACTIONS(4684),
    [anon_sym_pulldown] = ACTIONS(4684),
    [anon_sym_pullup] = ACTIONS(4684),
    [anon_sym_cmos] = ACTIONS(4684),
    [anon_sym_rcmos] = ACTIONS(4684),
    [anon_sym_bufif0] = ACTIONS(4684),
    [anon_sym_bufif1] = ACTIONS(4684),
    [anon_sym_notif0] = ACTIONS(4684),
    [anon_sym_notif1] = ACTIONS(4684),
    [anon_sym_nmos] = ACTIONS(4684),
    [anon_sym_pmos] = ACTIONS(4684),
    [anon_sym_rnmos] = ACTIONS(4684),
    [anon_sym_rpmos] = ACTIONS(4684),
    [anon_sym_nand] = ACTIONS(4684),
    [anon_sym_nor] = ACTIONS(4684),
    [anon_sym_xor] = ACTIONS(4684),
    [anon_sym_xnor] = ACTIONS(4684),
    [anon_sym_buf] = ACTIONS(4684),
    [anon_sym_tranif0] = ACTIONS(4684),
    [anon_sym_tranif1] = ACTIONS(4684),
    [anon_sym_rtranif1] = ACTIONS(4684),
    [anon_sym_rtranif0] = ACTIONS(4684),
    [anon_sym_tran] = ACTIONS(4684),
    [anon_sym_rtran] = ACTIONS(4684),
    [anon_sym_generate] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_primitive] = ACTIONS(4684),
    [anon_sym_initial] = ACTIONS(4684),
    [anon_sym_assign] = ACTIONS(4684),
    [anon_sym_alias] = ACTIONS(4684),
    [anon_sym_always_comb] = ACTIONS(4684),
    [anon_sym_always_latch] = ACTIONS(4684),
    [anon_sym_always_ff] = ACTIONS(4684),
    [anon_sym_final] = ACTIONS(4684),
    [anon_sym_global] = ACTIONS(4684),
    [anon_sym_specify] = ACTIONS(4684),
    [anon_sym_LPAREN_STAR] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4682),
    [anon_sym_DOLLARunit] = ACTIONS(4682),
  },
  [744] = {
    [ts_builtin_sym_end] = ACTIONS(4688),
    [sym_simple_identifier] = ACTIONS(4690),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4688),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4688),
    [anon_sym_BQUOTE] = ACTIONS(4690),
    [aux_sym_id_directive_token1] = ACTIONS(4688),
    [aux_sym_id_directive_token2] = ACTIONS(4688),
    [aux_sym_id_directive_token3] = ACTIONS(4688),
    [aux_sym_id_directive_token4] = ACTIONS(4690),
    [aux_sym_zero_directive_token1] = ACTIONS(4688),
    [aux_sym_zero_directive_token2] = ACTIONS(4688),
    [aux_sym_zero_directive_token3] = ACTIONS(4688),
    [aux_sym_zero_directive_token4] = ACTIONS(4688),
    [aux_sym_zero_directive_token5] = ACTIONS(4688),
    [aux_sym_zero_directive_token6] = ACTIONS(4688),
    [aux_sym_zero_directive_token7] = ACTIONS(4688),
    [aux_sym_zero_directive_token8] = ACTIONS(4688),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4688),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4688),
    [anon_sym_wire] = ACTIONS(4690),
    [anon_sym_tri] = ACTIONS(4690),
    [anon_sym_tri0] = ACTIONS(4690),
    [anon_sym_tri1] = ACTIONS(4690),
    [anon_sym_wand] = ACTIONS(4690),
    [anon_sym_triand] = ACTIONS(4690),
    [anon_sym_wor] = ACTIONS(4690),
    [anon_sym_trior] = ACTIONS(4690),
    [anon_sym_trireg] = ACTIONS(4690),
    [anon_sym_uwire] = ACTIONS(4690),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4688),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4688),
    [aux_sym_begin_keywords_token1] = ACTIONS(4688),
    [anon_sym_SEMI] = ACTIONS(4688),
    [anon_sym_endmodule] = ACTIONS(4690),
    [anon_sym_COLON] = ACTIONS(4692),
    [anon_sym_extern] = ACTIONS(4690),
    [anon_sym_module] = ACTIONS(4690),
    [anon_sym_macromodule] = ACTIONS(4690),
    [anon_sym_endinterface] = ACTIONS(4690),
    [anon_sym_interface] = ACTIONS(4690),
    [anon_sym_endprogram] = ACTIONS(4690),
    [anon_sym_program] = ACTIONS(4690),
    [anon_sym_checker] = ACTIONS(4690),
    [anon_sym_virtual] = ACTIONS(4690),
    [anon_sym_class] = ACTIONS(4690),
    [anon_sym_package] = ACTIONS(4690),
    [anon_sym_endpackage] = ACTIONS(4690),
    [anon_sym_timeunit] = ACTIONS(4690),
    [anon_sym_timeprecision] = ACTIONS(4690),
    [anon_sym_type] = ACTIONS(4690),
    [anon_sym_input] = ACTIONS(4690),
    [anon_sym_output] = ACTIONS(4690),
    [anon_sym_inout] = ACTIONS(4690),
    [anon_sym_ref] = ACTIONS(4690),
    [anon_sym_DOLLARfatal] = ACTIONS(4688),
    [anon_sym_DOLLARerror] = ACTIONS(4688),
    [anon_sym_DOLLARwarning] = ACTIONS(4688),
    [anon_sym_DOLLARinfo] = ACTIONS(4688),
    [anon_sym_default] = ACTIONS(4690),
    [anon_sym_clocking] = ACTIONS(4690),
    [anon_sym_defparam] = ACTIONS(4690),
    [anon_sym_bind] = ACTIONS(4690),
    [anon_sym_const] = ACTIONS(4690),
    [anon_sym_function] = ACTIONS(4690),
    [anon_sym_static] = ACTIONS(4690),
    [anon_sym_constraint] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4690),
    [anon_sym_else] = ACTIONS(4690),
    [anon_sym_LBRACK] = ACTIONS(4688),
    [anon_sym_localparam] = ACTIONS(4690),
    [anon_sym_parameter] = ACTIONS(4690),
    [anon_sym_specparam] = ACTIONS(4690),
    [anon_sym_var] = ACTIONS(4690),
    [anon_sym_import] = ACTIONS(4690),
    [anon_sym_export] = ACTIONS(4690),
    [anon_sym_genvar] = ACTIONS(4690),
    [anon_sym_interconnect] = ACTIONS(4690),
    [anon_sym_typedef] = ACTIONS(4690),
    [anon_sym_enum] = ACTIONS(4690),
    [anon_sym_struct] = ACTIONS(4690),
    [anon_sym_union] = ACTIONS(4690),
    [anon_sym_nettype] = ACTIONS(4690),
    [anon_sym_automatic] = ACTIONS(4690),
    [anon_sym_string] = ACTIONS(4690),
    [anon_sym_chandle] = ACTIONS(4690),
    [anon_sym_event] = ACTIONS(4690),
    [anon_sym_byte] = ACTIONS(4690),
    [anon_sym_shortint] = ACTIONS(4690),
    [anon_sym_int] = ACTIONS(4690),
    [anon_sym_longint] = ACTIONS(4690),
    [anon_sym_integer] = ACTIONS(4690),
    [anon_sym_time] = ACTIONS(4690),
    [anon_sym_bit] = ACTIONS(4690),
    [anon_sym_logic] = ACTIONS(4690),
    [anon_sym_reg] = ACTIONS(4690),
    [anon_sym_shortreal] = ACTIONS(4690),
    [anon_sym_real] = ACTIONS(4690),
    [anon_sym_realtime] = ACTIONS(4690),
    [anon_sym_supply0] = ACTIONS(4690),
    [anon_sym_supply1] = ACTIONS(4690),
    [anon_sym_signed] = ACTIONS(4690),
    [anon_sym_unsigned] = ACTIONS(4690),
    [anon_sym_task] = ACTIONS(4690),
    [anon_sym_modport] = ACTIONS(4690),
    [anon_sym_assert] = ACTIONS(4690),
    [anon_sym_property] = ACTIONS(4690),
    [anon_sym_assume] = ACTIONS(4690),
    [anon_sym_cover] = ACTIONS(4690),
    [anon_sym_sequence] = ACTIONS(4690),
    [anon_sym_restrict] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4690),
    [anon_sym_or] = ACTIONS(4690),
    [anon_sym_and] = ACTIONS(4690),
    [anon_sym_case] = ACTIONS(4690),
    [anon_sym_always] = ACTIONS(4690),
    [anon_sym_covergroup] = ACTIONS(4690),
    [anon_sym_let] = ACTIONS(4690),
    [anon_sym_pulldown] = ACTIONS(4690),
    [anon_sym_pullup] = ACTIONS(4690),
    [anon_sym_cmos] = ACTIONS(4690),
    [anon_sym_rcmos] = ACTIONS(4690),
    [anon_sym_bufif0] = ACTIONS(4690),
    [anon_sym_bufif1] = ACTIONS(4690),
    [anon_sym_notif0] = ACTIONS(4690),
    [anon_sym_notif1] = ACTIONS(4690),
    [anon_sym_nmos] = ACTIONS(4690),
    [anon_sym_pmos] = ACTIONS(4690),
    [anon_sym_rnmos] = ACTIONS(4690),
    [anon_sym_rpmos] = ACTIONS(4690),
    [anon_sym_nand] = ACTIONS(4690),
    [anon_sym_nor] = ACTIONS(4690),
    [anon_sym_xor] = ACTIONS(4690),
    [anon_sym_xnor] = ACTIONS(4690),
    [anon_sym_buf] = ACTIONS(4690),
    [anon_sym_tranif0] = ACTIONS(4690),
    [anon_sym_tranif1] = ACTIONS(4690),
    [anon_sym_rtranif1] = ACTIONS(4690),
    [anon_sym_rtranif0] = ACTIONS(4690),
    [anon_sym_tran] = ACTIONS(4690),
    [anon_sym_rtran] = ACTIONS(4690),
    [anon_sym_generate] = ACTIONS(4690),
    [anon_sym_for] = ACTIONS(4690),
    [anon_sym_primitive] = ACTIONS(4690),
    [anon_sym_initial] = ACTIONS(4690),
    [anon_sym_assign] = ACTIONS(4690),
    [anon_sym_alias] = ACTIONS(4690),
    [anon_sym_always_comb] = ACTIONS(4690),
    [anon_sym_always_latch] = ACTIONS(4690),
    [anon_sym_always_ff] = ACTIONS(4690),
    [anon_sym_final] = ACTIONS(4690),
    [anon_sym_global] = ACTIONS(4690),
    [anon_sym_specify] = ACTIONS(4690),
    [anon_sym_LPAREN_STAR] = ACTIONS(4688),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4688),
    [anon_sym_DOLLARunit] = ACTIONS(4688),
  },
  [745] = {
    [ts_builtin_sym_end] = ACTIONS(4694),
    [sym_simple_identifier] = ACTIONS(4696),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4694),
    [anon_sym_BQUOTE] = ACTIONS(4696),
    [aux_sym_id_directive_token1] = ACTIONS(4694),
    [aux_sym_id_directive_token2] = ACTIONS(4694),
    [aux_sym_id_directive_token3] = ACTIONS(4694),
    [aux_sym_id_directive_token4] = ACTIONS(4696),
    [aux_sym_zero_directive_token1] = ACTIONS(4694),
    [aux_sym_zero_directive_token2] = ACTIONS(4694),
    [aux_sym_zero_directive_token3] = ACTIONS(4694),
    [aux_sym_zero_directive_token4] = ACTIONS(4694),
    [aux_sym_zero_directive_token5] = ACTIONS(4694),
    [aux_sym_zero_directive_token6] = ACTIONS(4694),
    [aux_sym_zero_directive_token7] = ACTIONS(4694),
    [aux_sym_zero_directive_token8] = ACTIONS(4694),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4694),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4694),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_begin_keywords_token1] = ACTIONS(4694),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_endmodule] = ACTIONS(4696),
    [anon_sym_COLON] = ACTIONS(4698),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_module] = ACTIONS(4696),
    [anon_sym_macromodule] = ACTIONS(4696),
    [anon_sym_endinterface] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_endprogram] = ACTIONS(4696),
    [anon_sym_program] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_package] = ACTIONS(4696),
    [anon_sym_endpackage] = ACTIONS(4696),
    [anon_sym_timeunit] = ACTIONS(4696),
    [anon_sym_timeprecision] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_input] = ACTIONS(4696),
    [anon_sym_output] = ACTIONS(4696),
    [anon_sym_inout] = ACTIONS(4696),
    [anon_sym_ref] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_specparam] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_modport] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_primitive] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_specify] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [746] = {
    [ts_builtin_sym_end] = ACTIONS(4700),
    [sym_simple_identifier] = ACTIONS(4702),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4700),
    [anon_sym_BQUOTE] = ACTIONS(4702),
    [aux_sym_id_directive_token1] = ACTIONS(4700),
    [aux_sym_id_directive_token2] = ACTIONS(4700),
    [aux_sym_id_directive_token3] = ACTIONS(4700),
    [aux_sym_id_directive_token4] = ACTIONS(4702),
    [aux_sym_zero_directive_token1] = ACTIONS(4700),
    [aux_sym_zero_directive_token2] = ACTIONS(4700),
    [aux_sym_zero_directive_token3] = ACTIONS(4700),
    [aux_sym_zero_directive_token4] = ACTIONS(4700),
    [aux_sym_zero_directive_token5] = ACTIONS(4700),
    [aux_sym_zero_directive_token6] = ACTIONS(4700),
    [aux_sym_zero_directive_token7] = ACTIONS(4700),
    [aux_sym_zero_directive_token8] = ACTIONS(4700),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4700),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4700),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_begin_keywords_token1] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_endmodule] = ACTIONS(4702),
    [anon_sym_COLON] = ACTIONS(4704),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_module] = ACTIONS(4702),
    [anon_sym_macromodule] = ACTIONS(4702),
    [anon_sym_endinterface] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_endprogram] = ACTIONS(4702),
    [anon_sym_program] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_package] = ACTIONS(4702),
    [anon_sym_endpackage] = ACTIONS(4702),
    [anon_sym_timeunit] = ACTIONS(4702),
    [anon_sym_timeprecision] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_input] = ACTIONS(4702),
    [anon_sym_output] = ACTIONS(4702),
    [anon_sym_inout] = ACTIONS(4702),
    [anon_sym_ref] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_specparam] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_modport] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_primitive] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_specify] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [747] = {
    [ts_builtin_sym_end] = ACTIONS(4706),
    [sym_simple_identifier] = ACTIONS(4708),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4706),
    [anon_sym_BQUOTE] = ACTIONS(4708),
    [aux_sym_id_directive_token1] = ACTIONS(4706),
    [aux_sym_id_directive_token2] = ACTIONS(4706),
    [aux_sym_id_directive_token3] = ACTIONS(4706),
    [aux_sym_id_directive_token4] = ACTIONS(4708),
    [aux_sym_zero_directive_token1] = ACTIONS(4706),
    [aux_sym_zero_directive_token2] = ACTIONS(4706),
    [aux_sym_zero_directive_token3] = ACTIONS(4706),
    [aux_sym_zero_directive_token4] = ACTIONS(4706),
    [aux_sym_zero_directive_token5] = ACTIONS(4706),
    [aux_sym_zero_directive_token6] = ACTIONS(4706),
    [aux_sym_zero_directive_token7] = ACTIONS(4706),
    [aux_sym_zero_directive_token8] = ACTIONS(4706),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4706),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4706),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_begin_keywords_token1] = ACTIONS(4706),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_endmodule] = ACTIONS(4708),
    [anon_sym_COLON] = ACTIONS(4710),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_module] = ACTIONS(4708),
    [anon_sym_macromodule] = ACTIONS(4708),
    [anon_sym_endinterface] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_endprogram] = ACTIONS(4708),
    [anon_sym_program] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_package] = ACTIONS(4708),
    [anon_sym_endpackage] = ACTIONS(4708),
    [anon_sym_timeunit] = ACTIONS(4708),
    [anon_sym_timeprecision] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_input] = ACTIONS(4708),
    [anon_sym_output] = ACTIONS(4708),
    [anon_sym_inout] = ACTIONS(4708),
    [anon_sym_ref] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_specparam] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_modport] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_primitive] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_specify] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [748] = {
    [ts_builtin_sym_end] = ACTIONS(4712),
    [sym_simple_identifier] = ACTIONS(4714),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4712),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4712),
    [anon_sym_BQUOTE] = ACTIONS(4714),
    [aux_sym_id_directive_token1] = ACTIONS(4712),
    [aux_sym_id_directive_token2] = ACTIONS(4712),
    [aux_sym_id_directive_token3] = ACTIONS(4712),
    [aux_sym_id_directive_token4] = ACTIONS(4714),
    [aux_sym_zero_directive_token1] = ACTIONS(4712),
    [aux_sym_zero_directive_token2] = ACTIONS(4712),
    [aux_sym_zero_directive_token3] = ACTIONS(4712),
    [aux_sym_zero_directive_token4] = ACTIONS(4712),
    [aux_sym_zero_directive_token5] = ACTIONS(4712),
    [aux_sym_zero_directive_token6] = ACTIONS(4712),
    [aux_sym_zero_directive_token7] = ACTIONS(4712),
    [aux_sym_zero_directive_token8] = ACTIONS(4712),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4712),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4712),
    [anon_sym_wire] = ACTIONS(4714),
    [anon_sym_tri] = ACTIONS(4714),
    [anon_sym_tri0] = ACTIONS(4714),
    [anon_sym_tri1] = ACTIONS(4714),
    [anon_sym_wand] = ACTIONS(4714),
    [anon_sym_triand] = ACTIONS(4714),
    [anon_sym_wor] = ACTIONS(4714),
    [anon_sym_trior] = ACTIONS(4714),
    [anon_sym_trireg] = ACTIONS(4714),
    [anon_sym_uwire] = ACTIONS(4714),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4712),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4712),
    [aux_sym_begin_keywords_token1] = ACTIONS(4712),
    [anon_sym_SEMI] = ACTIONS(4712),
    [anon_sym_endmodule] = ACTIONS(4714),
    [anon_sym_COLON] = ACTIONS(4716),
    [anon_sym_extern] = ACTIONS(4714),
    [anon_sym_module] = ACTIONS(4714),
    [anon_sym_macromodule] = ACTIONS(4714),
    [anon_sym_endinterface] = ACTIONS(4714),
    [anon_sym_interface] = ACTIONS(4714),
    [anon_sym_endprogram] = ACTIONS(4714),
    [anon_sym_program] = ACTIONS(4714),
    [anon_sym_checker] = ACTIONS(4714),
    [anon_sym_virtual] = ACTIONS(4714),
    [anon_sym_class] = ACTIONS(4714),
    [anon_sym_package] = ACTIONS(4714),
    [anon_sym_endpackage] = ACTIONS(4714),
    [anon_sym_timeunit] = ACTIONS(4714),
    [anon_sym_timeprecision] = ACTIONS(4714),
    [anon_sym_type] = ACTIONS(4714),
    [anon_sym_input] = ACTIONS(4714),
    [anon_sym_output] = ACTIONS(4714),
    [anon_sym_inout] = ACTIONS(4714),
    [anon_sym_ref] = ACTIONS(4714),
    [anon_sym_DOLLARfatal] = ACTIONS(4712),
    [anon_sym_DOLLARerror] = ACTIONS(4712),
    [anon_sym_DOLLARwarning] = ACTIONS(4712),
    [anon_sym_DOLLARinfo] = ACTIONS(4712),
    [anon_sym_default] = ACTIONS(4714),
    [anon_sym_clocking] = ACTIONS(4714),
    [anon_sym_defparam] = ACTIONS(4714),
    [anon_sym_bind] = ACTIONS(4714),
    [anon_sym_const] = ACTIONS(4714),
    [anon_sym_function] = ACTIONS(4714),
    [anon_sym_static] = ACTIONS(4714),
    [anon_sym_constraint] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4714),
    [anon_sym_else] = ACTIONS(4714),
    [anon_sym_LBRACK] = ACTIONS(4712),
    [anon_sym_localparam] = ACTIONS(4714),
    [anon_sym_parameter] = ACTIONS(4714),
    [anon_sym_specparam] = ACTIONS(4714),
    [anon_sym_var] = ACTIONS(4714),
    [anon_sym_import] = ACTIONS(4714),
    [anon_sym_export] = ACTIONS(4714),
    [anon_sym_genvar] = ACTIONS(4714),
    [anon_sym_interconnect] = ACTIONS(4714),
    [anon_sym_typedef] = ACTIONS(4714),
    [anon_sym_enum] = ACTIONS(4714),
    [anon_sym_struct] = ACTIONS(4714),
    [anon_sym_union] = ACTIONS(4714),
    [anon_sym_nettype] = ACTIONS(4714),
    [anon_sym_automatic] = ACTIONS(4714),
    [anon_sym_string] = ACTIONS(4714),
    [anon_sym_chandle] = ACTIONS(4714),
    [anon_sym_event] = ACTIONS(4714),
    [anon_sym_byte] = ACTIONS(4714),
    [anon_sym_shortint] = ACTIONS(4714),
    [anon_sym_int] = ACTIONS(4714),
    [anon_sym_longint] = ACTIONS(4714),
    [anon_sym_integer] = ACTIONS(4714),
    [anon_sym_time] = ACTIONS(4714),
    [anon_sym_bit] = ACTIONS(4714),
    [anon_sym_logic] = ACTIONS(4714),
    [anon_sym_reg] = ACTIONS(4714),
    [anon_sym_shortreal] = ACTIONS(4714),
    [anon_sym_real] = ACTIONS(4714),
    [anon_sym_realtime] = ACTIONS(4714),
    [anon_sym_supply0] = ACTIONS(4714),
    [anon_sym_supply1] = ACTIONS(4714),
    [anon_sym_signed] = ACTIONS(4714),
    [anon_sym_unsigned] = ACTIONS(4714),
    [anon_sym_task] = ACTIONS(4714),
    [anon_sym_modport] = ACTIONS(4714),
    [anon_sym_assert] = ACTIONS(4714),
    [anon_sym_property] = ACTIONS(4714),
    [anon_sym_assume] = ACTIONS(4714),
    [anon_sym_cover] = ACTIONS(4714),
    [anon_sym_sequence] = ACTIONS(4714),
    [anon_sym_restrict] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4714),
    [anon_sym_or] = ACTIONS(4714),
    [anon_sym_and] = ACTIONS(4714),
    [anon_sym_case] = ACTIONS(4714),
    [anon_sym_always] = ACTIONS(4714),
    [anon_sym_covergroup] = ACTIONS(4714),
    [anon_sym_let] = ACTIONS(4714),
    [anon_sym_pulldown] = ACTIONS(4714),
    [anon_sym_pullup] = ACTIONS(4714),
    [anon_sym_cmos] = ACTIONS(4714),
    [anon_sym_rcmos] = ACTIONS(4714),
    [anon_sym_bufif0] = ACTIONS(4714),
    [anon_sym_bufif1] = ACTIONS(4714),
    [anon_sym_notif0] = ACTIONS(4714),
    [anon_sym_notif1] = ACTIONS(4714),
    [anon_sym_nmos] = ACTIONS(4714),
    [anon_sym_pmos] = ACTIONS(4714),
    [anon_sym_rnmos] = ACTIONS(4714),
    [anon_sym_rpmos] = ACTIONS(4714),
    [anon_sym_nand] = ACTIONS(4714),
    [anon_sym_nor] = ACTIONS(4714),
    [anon_sym_xor] = ACTIONS(4714),
    [anon_sym_xnor] = ACTIONS(4714),
    [anon_sym_buf] = ACTIONS(4714),
    [anon_sym_tranif0] = ACTIONS(4714),
    [anon_sym_tranif1] = ACTIONS(4714),
    [anon_sym_rtranif1] = ACTIONS(4714),
    [anon_sym_rtranif0] = ACTIONS(4714),
    [anon_sym_tran] = ACTIONS(4714),
    [anon_sym_rtran] = ACTIONS(4714),
    [anon_sym_generate] = ACTIONS(4714),
    [anon_sym_for] = ACTIONS(4714),
    [anon_sym_primitive] = ACTIONS(4714),
    [anon_sym_initial] = ACTIONS(4714),
    [anon_sym_assign] = ACTIONS(4714),
    [anon_sym_alias] = ACTIONS(4714),
    [anon_sym_always_comb] = ACTIONS(4714),
    [anon_sym_always_latch] = ACTIONS(4714),
    [anon_sym_always_ff] = ACTIONS(4714),
    [anon_sym_final] = ACTIONS(4714),
    [anon_sym_global] = ACTIONS(4714),
    [anon_sym_specify] = ACTIONS(4714),
    [anon_sym_LPAREN_STAR] = ACTIONS(4712),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4712),
    [anon_sym_DOLLARunit] = ACTIONS(4712),
  },
  [749] = {
    [ts_builtin_sym_end] = ACTIONS(4718),
    [sym_simple_identifier] = ACTIONS(4720),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4718),
    [anon_sym_BQUOTE] = ACTIONS(4720),
    [aux_sym_id_directive_token1] = ACTIONS(4718),
    [aux_sym_id_directive_token2] = ACTIONS(4718),
    [aux_sym_id_directive_token3] = ACTIONS(4718),
    [aux_sym_id_directive_token4] = ACTIONS(4720),
    [aux_sym_zero_directive_token1] = ACTIONS(4718),
    [aux_sym_zero_directive_token2] = ACTIONS(4718),
    [aux_sym_zero_directive_token3] = ACTIONS(4718),
    [aux_sym_zero_directive_token4] = ACTIONS(4718),
    [aux_sym_zero_directive_token5] = ACTIONS(4718),
    [aux_sym_zero_directive_token6] = ACTIONS(4718),
    [aux_sym_zero_directive_token7] = ACTIONS(4718),
    [aux_sym_zero_directive_token8] = ACTIONS(4718),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4718),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4718),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_begin_keywords_token1] = ACTIONS(4718),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_endmodule] = ACTIONS(4720),
    [anon_sym_COLON] = ACTIONS(4722),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_module] = ACTIONS(4720),
    [anon_sym_macromodule] = ACTIONS(4720),
    [anon_sym_endinterface] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_endprogram] = ACTIONS(4720),
    [anon_sym_program] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_package] = ACTIONS(4720),
    [anon_sym_endpackage] = ACTIONS(4720),
    [anon_sym_timeunit] = ACTIONS(4720),
    [anon_sym_timeprecision] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_input] = ACTIONS(4720),
    [anon_sym_output] = ACTIONS(4720),
    [anon_sym_inout] = ACTIONS(4720),
    [anon_sym_ref] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_specparam] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_modport] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_primitive] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_specify] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [750] = {
    [ts_builtin_sym_end] = ACTIONS(4724),
    [sym_simple_identifier] = ACTIONS(4726),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4724),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4724),
    [anon_sym_BQUOTE] = ACTIONS(4726),
    [aux_sym_id_directive_token1] = ACTIONS(4724),
    [aux_sym_id_directive_token2] = ACTIONS(4724),
    [aux_sym_id_directive_token3] = ACTIONS(4724),
    [aux_sym_id_directive_token4] = ACTIONS(4726),
    [aux_sym_zero_directive_token1] = ACTIONS(4724),
    [aux_sym_zero_directive_token2] = ACTIONS(4724),
    [aux_sym_zero_directive_token3] = ACTIONS(4724),
    [aux_sym_zero_directive_token4] = ACTIONS(4724),
    [aux_sym_zero_directive_token5] = ACTIONS(4724),
    [aux_sym_zero_directive_token6] = ACTIONS(4724),
    [aux_sym_zero_directive_token7] = ACTIONS(4724),
    [aux_sym_zero_directive_token8] = ACTIONS(4724),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4724),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4724),
    [anon_sym_wire] = ACTIONS(4726),
    [anon_sym_tri] = ACTIONS(4726),
    [anon_sym_tri0] = ACTIONS(4726),
    [anon_sym_tri1] = ACTIONS(4726),
    [anon_sym_wand] = ACTIONS(4726),
    [anon_sym_triand] = ACTIONS(4726),
    [anon_sym_wor] = ACTIONS(4726),
    [anon_sym_trior] = ACTIONS(4726),
    [anon_sym_trireg] = ACTIONS(4726),
    [anon_sym_uwire] = ACTIONS(4726),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4724),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4724),
    [aux_sym_begin_keywords_token1] = ACTIONS(4724),
    [anon_sym_SEMI] = ACTIONS(4724),
    [anon_sym_endmodule] = ACTIONS(4726),
    [anon_sym_COLON] = ACTIONS(4728),
    [anon_sym_extern] = ACTIONS(4726),
    [anon_sym_module] = ACTIONS(4726),
    [anon_sym_macromodule] = ACTIONS(4726),
    [anon_sym_endinterface] = ACTIONS(4726),
    [anon_sym_interface] = ACTIONS(4726),
    [anon_sym_endprogram] = ACTIONS(4726),
    [anon_sym_program] = ACTIONS(4726),
    [anon_sym_checker] = ACTIONS(4726),
    [anon_sym_virtual] = ACTIONS(4726),
    [anon_sym_class] = ACTIONS(4726),
    [anon_sym_package] = ACTIONS(4726),
    [anon_sym_endpackage] = ACTIONS(4726),
    [anon_sym_timeunit] = ACTIONS(4726),
    [anon_sym_timeprecision] = ACTIONS(4726),
    [anon_sym_type] = ACTIONS(4726),
    [anon_sym_input] = ACTIONS(4726),
    [anon_sym_output] = ACTIONS(4726),
    [anon_sym_inout] = ACTIONS(4726),
    [anon_sym_ref] = ACTIONS(4726),
    [anon_sym_DOLLARfatal] = ACTIONS(4724),
    [anon_sym_DOLLARerror] = ACTIONS(4724),
    [anon_sym_DOLLARwarning] = ACTIONS(4724),
    [anon_sym_DOLLARinfo] = ACTIONS(4724),
    [anon_sym_default] = ACTIONS(4726),
    [anon_sym_clocking] = ACTIONS(4726),
    [anon_sym_defparam] = ACTIONS(4726),
    [anon_sym_bind] = ACTIONS(4726),
    [anon_sym_const] = ACTIONS(4726),
    [anon_sym_function] = ACTIONS(4726),
    [anon_sym_static] = ACTIONS(4726),
    [anon_sym_constraint] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4726),
    [anon_sym_else] = ACTIONS(4726),
    [anon_sym_LBRACK] = ACTIONS(4724),
    [anon_sym_localparam] = ACTIONS(4726),
    [anon_sym_parameter] = ACTIONS(4726),
    [anon_sym_specparam] = ACTIONS(4726),
    [anon_sym_var] = ACTIONS(4726),
    [anon_sym_import] = ACTIONS(4726),
    [anon_sym_export] = ACTIONS(4726),
    [anon_sym_genvar] = ACTIONS(4726),
    [anon_sym_interconnect] = ACTIONS(4726),
    [anon_sym_typedef] = ACTIONS(4726),
    [anon_sym_enum] = ACTIONS(4726),
    [anon_sym_struct] = ACTIONS(4726),
    [anon_sym_union] = ACTIONS(4726),
    [anon_sym_nettype] = ACTIONS(4726),
    [anon_sym_automatic] = ACTIONS(4726),
    [anon_sym_string] = ACTIONS(4726),
    [anon_sym_chandle] = ACTIONS(4726),
    [anon_sym_event] = ACTIONS(4726),
    [anon_sym_byte] = ACTIONS(4726),
    [anon_sym_shortint] = ACTIONS(4726),
    [anon_sym_int] = ACTIONS(4726),
    [anon_sym_longint] = ACTIONS(4726),
    [anon_sym_integer] = ACTIONS(4726),
    [anon_sym_time] = ACTIONS(4726),
    [anon_sym_bit] = ACTIONS(4726),
    [anon_sym_logic] = ACTIONS(4726),
    [anon_sym_reg] = ACTIONS(4726),
    [anon_sym_shortreal] = ACTIONS(4726),
    [anon_sym_real] = ACTIONS(4726),
    [anon_sym_realtime] = ACTIONS(4726),
    [anon_sym_supply0] = ACTIONS(4726),
    [anon_sym_supply1] = ACTIONS(4726),
    [anon_sym_signed] = ACTIONS(4726),
    [anon_sym_unsigned] = ACTIONS(4726),
    [anon_sym_task] = ACTIONS(4726),
    [anon_sym_modport] = ACTIONS(4726),
    [anon_sym_assert] = ACTIONS(4726),
    [anon_sym_property] = ACTIONS(4726),
    [anon_sym_assume] = ACTIONS(4726),
    [anon_sym_cover] = ACTIONS(4726),
    [anon_sym_sequence] = ACTIONS(4726),
    [anon_sym_restrict] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4726),
    [anon_sym_or] = ACTIONS(4726),
    [anon_sym_and] = ACTIONS(4726),
    [anon_sym_case] = ACTIONS(4726),
    [anon_sym_always] = ACTIONS(4726),
    [anon_sym_covergroup] = ACTIONS(4726),
    [anon_sym_let] = ACTIONS(4726),
    [anon_sym_pulldown] = ACTIONS(4726),
    [anon_sym_pullup] = ACTIONS(4726),
    [anon_sym_cmos] = ACTIONS(4726),
    [anon_sym_rcmos] = ACTIONS(4726),
    [anon_sym_bufif0] = ACTIONS(4726),
    [anon_sym_bufif1] = ACTIONS(4726),
    [anon_sym_notif0] = ACTIONS(4726),
    [anon_sym_notif1] = ACTIONS(4726),
    [anon_sym_nmos] = ACTIONS(4726),
    [anon_sym_pmos] = ACTIONS(4726),
    [anon_sym_rnmos] = ACTIONS(4726),
    [anon_sym_rpmos] = ACTIONS(4726),
    [anon_sym_nand] = ACTIONS(4726),
    [anon_sym_nor] = ACTIONS(4726),
    [anon_sym_xor] = ACTIONS(4726),
    [anon_sym_xnor] = ACTIONS(4726),
    [anon_sym_buf] = ACTIONS(4726),
    [anon_sym_tranif0] = ACTIONS(4726),
    [anon_sym_tranif1] = ACTIONS(4726),
    [anon_sym_rtranif1] = ACTIONS(4726),
    [anon_sym_rtranif0] = ACTIONS(4726),
    [anon_sym_tran] = ACTIONS(4726),
    [anon_sym_rtran] = ACTIONS(4726),
    [anon_sym_generate] = ACTIONS(4726),
    [anon_sym_for] = ACTIONS(4726),
    [anon_sym_primitive] = ACTIONS(4726),
    [anon_sym_initial] = ACTIONS(4726),
    [anon_sym_assign] = ACTIONS(4726),
    [anon_sym_alias] = ACTIONS(4726),
    [anon_sym_always_comb] = ACTIONS(4726),
    [anon_sym_always_latch] = ACTIONS(4726),
    [anon_sym_always_ff] = ACTIONS(4726),
    [anon_sym_final] = ACTIONS(4726),
    [anon_sym_global] = ACTIONS(4726),
    [anon_sym_specify] = ACTIONS(4726),
    [anon_sym_LPAREN_STAR] = ACTIONS(4724),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4724),
    [anon_sym_DOLLARunit] = ACTIONS(4724),
  },
  [751] = {
    [ts_builtin_sym_end] = ACTIONS(4730),
    [sym_simple_identifier] = ACTIONS(4732),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4730),
    [anon_sym_BQUOTE] = ACTIONS(4732),
    [aux_sym_id_directive_token1] = ACTIONS(4730),
    [aux_sym_id_directive_token2] = ACTIONS(4730),
    [aux_sym_id_directive_token3] = ACTIONS(4730),
    [aux_sym_id_directive_token4] = ACTIONS(4732),
    [aux_sym_zero_directive_token1] = ACTIONS(4730),
    [aux_sym_zero_directive_token2] = ACTIONS(4730),
    [aux_sym_zero_directive_token3] = ACTIONS(4730),
    [aux_sym_zero_directive_token4] = ACTIONS(4730),
    [aux_sym_zero_directive_token5] = ACTIONS(4730),
    [aux_sym_zero_directive_token6] = ACTIONS(4730),
    [aux_sym_zero_directive_token7] = ACTIONS(4730),
    [aux_sym_zero_directive_token8] = ACTIONS(4730),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4730),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4730),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_begin_keywords_token1] = ACTIONS(4730),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_endmodule] = ACTIONS(4732),
    [anon_sym_COLON] = ACTIONS(4734),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_module] = ACTIONS(4732),
    [anon_sym_macromodule] = ACTIONS(4732),
    [anon_sym_endinterface] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_endprogram] = ACTIONS(4732),
    [anon_sym_program] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_package] = ACTIONS(4732),
    [anon_sym_endpackage] = ACTIONS(4732),
    [anon_sym_timeunit] = ACTIONS(4732),
    [anon_sym_timeprecision] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_input] = ACTIONS(4732),
    [anon_sym_output] = ACTIONS(4732),
    [anon_sym_inout] = ACTIONS(4732),
    [anon_sym_ref] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_specparam] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_modport] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_primitive] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_specify] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [752] = {
    [ts_builtin_sym_end] = ACTIONS(4736),
    [sym_simple_identifier] = ACTIONS(4738),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4736),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4736),
    [anon_sym_BQUOTE] = ACTIONS(4738),
    [aux_sym_id_directive_token1] = ACTIONS(4736),
    [aux_sym_id_directive_token2] = ACTIONS(4736),
    [aux_sym_id_directive_token3] = ACTIONS(4736),
    [aux_sym_id_directive_token4] = ACTIONS(4738),
    [aux_sym_zero_directive_token1] = ACTIONS(4736),
    [aux_sym_zero_directive_token2] = ACTIONS(4736),
    [aux_sym_zero_directive_token3] = ACTIONS(4736),
    [aux_sym_zero_directive_token4] = ACTIONS(4736),
    [aux_sym_zero_directive_token5] = ACTIONS(4736),
    [aux_sym_zero_directive_token6] = ACTIONS(4736),
    [aux_sym_zero_directive_token7] = ACTIONS(4736),
    [aux_sym_zero_directive_token8] = ACTIONS(4736),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4736),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4736),
    [anon_sym_wire] = ACTIONS(4738),
    [anon_sym_tri] = ACTIONS(4738),
    [anon_sym_tri0] = ACTIONS(4738),
    [anon_sym_tri1] = ACTIONS(4738),
    [anon_sym_wand] = ACTIONS(4738),
    [anon_sym_triand] = ACTIONS(4738),
    [anon_sym_wor] = ACTIONS(4738),
    [anon_sym_trior] = ACTIONS(4738),
    [anon_sym_trireg] = ACTIONS(4738),
    [anon_sym_uwire] = ACTIONS(4738),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4736),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4736),
    [aux_sym_begin_keywords_token1] = ACTIONS(4736),
    [anon_sym_SEMI] = ACTIONS(4736),
    [anon_sym_endmodule] = ACTIONS(4738),
    [anon_sym_COLON] = ACTIONS(4740),
    [anon_sym_extern] = ACTIONS(4738),
    [anon_sym_module] = ACTIONS(4738),
    [anon_sym_macromodule] = ACTIONS(4738),
    [anon_sym_endinterface] = ACTIONS(4738),
    [anon_sym_interface] = ACTIONS(4738),
    [anon_sym_endprogram] = ACTIONS(4738),
    [anon_sym_program] = ACTIONS(4738),
    [anon_sym_checker] = ACTIONS(4738),
    [anon_sym_virtual] = ACTIONS(4738),
    [anon_sym_class] = ACTIONS(4738),
    [anon_sym_package] = ACTIONS(4738),
    [anon_sym_endpackage] = ACTIONS(4738),
    [anon_sym_timeunit] = ACTIONS(4738),
    [anon_sym_timeprecision] = ACTIONS(4738),
    [anon_sym_type] = ACTIONS(4738),
    [anon_sym_input] = ACTIONS(4738),
    [anon_sym_output] = ACTIONS(4738),
    [anon_sym_inout] = ACTIONS(4738),
    [anon_sym_ref] = ACTIONS(4738),
    [anon_sym_DOLLARfatal] = ACTIONS(4736),
    [anon_sym_DOLLARerror] = ACTIONS(4736),
    [anon_sym_DOLLARwarning] = ACTIONS(4736),
    [anon_sym_DOLLARinfo] = ACTIONS(4736),
    [anon_sym_default] = ACTIONS(4738),
    [anon_sym_clocking] = ACTIONS(4738),
    [anon_sym_defparam] = ACTIONS(4738),
    [anon_sym_bind] = ACTIONS(4738),
    [anon_sym_const] = ACTIONS(4738),
    [anon_sym_function] = ACTIONS(4738),
    [anon_sym_static] = ACTIONS(4738),
    [anon_sym_constraint] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4738),
    [anon_sym_else] = ACTIONS(4738),
    [anon_sym_LBRACK] = ACTIONS(4736),
    [anon_sym_localparam] = ACTIONS(4738),
    [anon_sym_parameter] = ACTIONS(4738),
    [anon_sym_specparam] = ACTIONS(4738),
    [anon_sym_var] = ACTIONS(4738),
    [anon_sym_import] = ACTIONS(4738),
    [anon_sym_export] = ACTIONS(4738),
    [anon_sym_genvar] = ACTIONS(4738),
    [anon_sym_interconnect] = ACTIONS(4738),
    [anon_sym_typedef] = ACTIONS(4738),
    [anon_sym_enum] = ACTIONS(4738),
    [anon_sym_struct] = ACTIONS(4738),
    [anon_sym_union] = ACTIONS(4738),
    [anon_sym_nettype] = ACTIONS(4738),
    [anon_sym_automatic] = ACTIONS(4738),
    [anon_sym_string] = ACTIONS(4738),
    [anon_sym_chandle] = ACTIONS(4738),
    [anon_sym_event] = ACTIONS(4738),
    [anon_sym_byte] = ACTIONS(4738),
    [anon_sym_shortint] = ACTIONS(4738),
    [anon_sym_int] = ACTIONS(4738),
    [anon_sym_longint] = ACTIONS(4738),
    [anon_sym_integer] = ACTIONS(4738),
    [anon_sym_time] = ACTIONS(4738),
    [anon_sym_bit] = ACTIONS(4738),
    [anon_sym_logic] = ACTIONS(4738),
    [anon_sym_reg] = ACTIONS(4738),
    [anon_sym_shortreal] = ACTIONS(4738),
    [anon_sym_real] = ACTIONS(4738),
    [anon_sym_realtime] = ACTIONS(4738),
    [anon_sym_supply0] = ACTIONS(4738),
    [anon_sym_supply1] = ACTIONS(4738),
    [anon_sym_signed] = ACTIONS(4738),
    [anon_sym_unsigned] = ACTIONS(4738),
    [anon_sym_task] = ACTIONS(4738),
    [anon_sym_modport] = ACTIONS(4738),
    [anon_sym_assert] = ACTIONS(4738),
    [anon_sym_property] = ACTIONS(4738),
    [anon_sym_assume] = ACTIONS(4738),
    [anon_sym_cover] = ACTIONS(4738),
    [anon_sym_sequence] = ACTIONS(4738),
    [anon_sym_restrict] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4738),
    [anon_sym_or] = ACTIONS(4738),
    [anon_sym_and] = ACTIONS(4738),
    [anon_sym_case] = ACTIONS(4738),
    [anon_sym_always] = ACTIONS(4738),
    [anon_sym_covergroup] = ACTIONS(4738),
    [anon_sym_let] = ACTIONS(4738),
    [anon_sym_pulldown] = ACTIONS(4738),
    [anon_sym_pullup] = ACTIONS(4738),
    [anon_sym_cmos] = ACTIONS(4738),
    [anon_sym_rcmos] = ACTIONS(4738),
    [anon_sym_bufif0] = ACTIONS(4738),
    [anon_sym_bufif1] = ACTIONS(4738),
    [anon_sym_notif0] = ACTIONS(4738),
    [anon_sym_notif1] = ACTIONS(4738),
    [anon_sym_nmos] = ACTIONS(4738),
    [anon_sym_pmos] = ACTIONS(4738),
    [anon_sym_rnmos] = ACTIONS(4738),
    [anon_sym_rpmos] = ACTIONS(4738),
    [anon_sym_nand] = ACTIONS(4738),
    [anon_sym_nor] = ACTIONS(4738),
    [anon_sym_xor] = ACTIONS(4738),
    [anon_sym_xnor] = ACTIONS(4738),
    [anon_sym_buf] = ACTIONS(4738),
    [anon_sym_tranif0] = ACTIONS(4738),
    [anon_sym_tranif1] = ACTIONS(4738),
    [anon_sym_rtranif1] = ACTIONS(4738),
    [anon_sym_rtranif0] = ACTIONS(4738),
    [anon_sym_tran] = ACTIONS(4738),
    [anon_sym_rtran] = ACTIONS(4738),
    [anon_sym_generate] = ACTIONS(4738),
    [anon_sym_for] = ACTIONS(4738),
    [anon_sym_primitive] = ACTIONS(4738),
    [anon_sym_initial] = ACTIONS(4738),
    [anon_sym_assign] = ACTIONS(4738),
    [anon_sym_alias] = ACTIONS(4738),
    [anon_sym_always_comb] = ACTIONS(4738),
    [anon_sym_always_latch] = ACTIONS(4738),
    [anon_sym_always_ff] = ACTIONS(4738),
    [anon_sym_final] = ACTIONS(4738),
    [anon_sym_global] = ACTIONS(4738),
    [anon_sym_specify] = ACTIONS(4738),
    [anon_sym_LPAREN_STAR] = ACTIONS(4736),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4736),
    [anon_sym_DOLLARunit] = ACTIONS(4736),
  },
  [753] = {
    [ts_builtin_sym_end] = ACTIONS(4730),
    [sym_simple_identifier] = ACTIONS(4732),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4730),
    [anon_sym_BQUOTE] = ACTIONS(4732),
    [aux_sym_id_directive_token1] = ACTIONS(4730),
    [aux_sym_id_directive_token2] = ACTIONS(4730),
    [aux_sym_id_directive_token3] = ACTIONS(4730),
    [aux_sym_id_directive_token4] = ACTIONS(4732),
    [aux_sym_zero_directive_token1] = ACTIONS(4730),
    [aux_sym_zero_directive_token2] = ACTIONS(4730),
    [aux_sym_zero_directive_token3] = ACTIONS(4730),
    [aux_sym_zero_directive_token4] = ACTIONS(4730),
    [aux_sym_zero_directive_token5] = ACTIONS(4730),
    [aux_sym_zero_directive_token6] = ACTIONS(4730),
    [aux_sym_zero_directive_token7] = ACTIONS(4730),
    [aux_sym_zero_directive_token8] = ACTIONS(4730),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4730),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4730),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4730),
    [aux_sym_begin_keywords_token1] = ACTIONS(4730),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_endmodule] = ACTIONS(4732),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_module] = ACTIONS(4732),
    [anon_sym_macromodule] = ACTIONS(4732),
    [anon_sym_endinterface] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_endprogram] = ACTIONS(4732),
    [anon_sym_program] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_package] = ACTIONS(4732),
    [anon_sym_endpackage] = ACTIONS(4732),
    [anon_sym_timeunit] = ACTIONS(4732),
    [anon_sym_timeprecision] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_input] = ACTIONS(4732),
    [anon_sym_output] = ACTIONS(4732),
    [anon_sym_inout] = ACTIONS(4732),
    [anon_sym_ref] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_specparam] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_modport] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_primitive] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_endclocking] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_specify] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [754] = {
    [ts_builtin_sym_end] = ACTIONS(4742),
    [sym_simple_identifier] = ACTIONS(4744),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4742),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4742),
    [anon_sym_BQUOTE] = ACTIONS(4744),
    [aux_sym_id_directive_token1] = ACTIONS(4742),
    [aux_sym_id_directive_token2] = ACTIONS(4742),
    [aux_sym_id_directive_token3] = ACTIONS(4742),
    [aux_sym_id_directive_token4] = ACTIONS(4744),
    [aux_sym_zero_directive_token1] = ACTIONS(4742),
    [aux_sym_zero_directive_token2] = ACTIONS(4742),
    [aux_sym_zero_directive_token3] = ACTIONS(4742),
    [aux_sym_zero_directive_token4] = ACTIONS(4742),
    [aux_sym_zero_directive_token5] = ACTIONS(4742),
    [aux_sym_zero_directive_token6] = ACTIONS(4742),
    [aux_sym_zero_directive_token7] = ACTIONS(4742),
    [aux_sym_zero_directive_token8] = ACTIONS(4742),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4742),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4742),
    [anon_sym_wire] = ACTIONS(4744),
    [anon_sym_tri] = ACTIONS(4744),
    [anon_sym_tri0] = ACTIONS(4744),
    [anon_sym_tri1] = ACTIONS(4744),
    [anon_sym_wand] = ACTIONS(4744),
    [anon_sym_triand] = ACTIONS(4744),
    [anon_sym_wor] = ACTIONS(4744),
    [anon_sym_trior] = ACTIONS(4744),
    [anon_sym_trireg] = ACTIONS(4744),
    [anon_sym_uwire] = ACTIONS(4744),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4742),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4742),
    [aux_sym_begin_keywords_token1] = ACTIONS(4742),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_endmodule] = ACTIONS(4744),
    [anon_sym_COLON] = ACTIONS(4746),
    [anon_sym_extern] = ACTIONS(4744),
    [anon_sym_module] = ACTIONS(4744),
    [anon_sym_macromodule] = ACTIONS(4744),
    [anon_sym_endinterface] = ACTIONS(4744),
    [anon_sym_interface] = ACTIONS(4744),
    [anon_sym_endprogram] = ACTIONS(4744),
    [anon_sym_program] = ACTIONS(4744),
    [anon_sym_checker] = ACTIONS(4744),
    [anon_sym_virtual] = ACTIONS(4744),
    [anon_sym_class] = ACTIONS(4744),
    [anon_sym_package] = ACTIONS(4744),
    [anon_sym_endpackage] = ACTIONS(4744),
    [anon_sym_timeunit] = ACTIONS(4744),
    [anon_sym_timeprecision] = ACTIONS(4744),
    [anon_sym_type] = ACTIONS(4744),
    [anon_sym_input] = ACTIONS(4744),
    [anon_sym_output] = ACTIONS(4744),
    [anon_sym_inout] = ACTIONS(4744),
    [anon_sym_ref] = ACTIONS(4744),
    [anon_sym_DOLLARfatal] = ACTIONS(4742),
    [anon_sym_DOLLARerror] = ACTIONS(4742),
    [anon_sym_DOLLARwarning] = ACTIONS(4742),
    [anon_sym_DOLLARinfo] = ACTIONS(4742),
    [anon_sym_default] = ACTIONS(4744),
    [anon_sym_clocking] = ACTIONS(4744),
    [anon_sym_defparam] = ACTIONS(4744),
    [anon_sym_bind] = ACTIONS(4744),
    [anon_sym_const] = ACTIONS(4744),
    [anon_sym_function] = ACTIONS(4744),
    [anon_sym_static] = ACTIONS(4744),
    [anon_sym_constraint] = ACTIONS(4744),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [anon_sym_localparam] = ACTIONS(4744),
    [anon_sym_parameter] = ACTIONS(4744),
    [anon_sym_specparam] = ACTIONS(4744),
    [anon_sym_var] = ACTIONS(4744),
    [anon_sym_import] = ACTIONS(4744),
    [anon_sym_export] = ACTIONS(4744),
    [anon_sym_genvar] = ACTIONS(4744),
    [anon_sym_interconnect] = ACTIONS(4744),
    [anon_sym_typedef] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_struct] = ACTIONS(4744),
    [anon_sym_union] = ACTIONS(4744),
    [anon_sym_nettype] = ACTIONS(4744),
    [anon_sym_automatic] = ACTIONS(4744),
    [anon_sym_string] = ACTIONS(4744),
    [anon_sym_chandle] = ACTIONS(4744),
    [anon_sym_event] = ACTIONS(4744),
    [anon_sym_byte] = ACTIONS(4744),
    [anon_sym_shortint] = ACTIONS(4744),
    [anon_sym_int] = ACTIONS(4744),
    [anon_sym_longint] = ACTIONS(4744),
    [anon_sym_integer] = ACTIONS(4744),
    [anon_sym_time] = ACTIONS(4744),
    [anon_sym_bit] = ACTIONS(4744),
    [anon_sym_logic] = ACTIONS(4744),
    [anon_sym_reg] = ACTIONS(4744),
    [anon_sym_shortreal] = ACTIONS(4744),
    [anon_sym_real] = ACTIONS(4744),
    [anon_sym_realtime] = ACTIONS(4744),
    [anon_sym_supply0] = ACTIONS(4744),
    [anon_sym_supply1] = ACTIONS(4744),
    [anon_sym_signed] = ACTIONS(4744),
    [anon_sym_unsigned] = ACTIONS(4744),
    [anon_sym_task] = ACTIONS(4744),
    [anon_sym_modport] = ACTIONS(4744),
    [anon_sym_assert] = ACTIONS(4744),
    [anon_sym_property] = ACTIONS(4744),
    [anon_sym_assume] = ACTIONS(4744),
    [anon_sym_cover] = ACTIONS(4744),
    [anon_sym_sequence] = ACTIONS(4744),
    [anon_sym_restrict] = ACTIONS(4744),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_or] = ACTIONS(4744),
    [anon_sym_and] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_always] = ACTIONS(4744),
    [anon_sym_covergroup] = ACTIONS(4744),
    [anon_sym_let] = ACTIONS(4744),
    [anon_sym_pulldown] = ACTIONS(4744),
    [anon_sym_pullup] = ACTIONS(4744),
    [anon_sym_cmos] = ACTIONS(4744),
    [anon_sym_rcmos] = ACTIONS(4744),
    [anon_sym_bufif0] = ACTIONS(4744),
    [anon_sym_bufif1] = ACTIONS(4744),
    [anon_sym_notif0] = ACTIONS(4744),
    [anon_sym_notif1] = ACTIONS(4744),
    [anon_sym_nmos] = ACTIONS(4744),
    [anon_sym_pmos] = ACTIONS(4744),
    [anon_sym_rnmos] = ACTIONS(4744),
    [anon_sym_rpmos] = ACTIONS(4744),
    [anon_sym_nand] = ACTIONS(4744),
    [anon_sym_nor] = ACTIONS(4744),
    [anon_sym_xor] = ACTIONS(4744),
    [anon_sym_xnor] = ACTIONS(4744),
    [anon_sym_buf] = ACTIONS(4744),
    [anon_sym_tranif0] = ACTIONS(4744),
    [anon_sym_tranif1] = ACTIONS(4744),
    [anon_sym_rtranif1] = ACTIONS(4744),
    [anon_sym_rtranif0] = ACTIONS(4744),
    [anon_sym_tran] = ACTIONS(4744),
    [anon_sym_rtran] = ACTIONS(4744),
    [anon_sym_generate] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_primitive] = ACTIONS(4744),
    [anon_sym_initial] = ACTIONS(4744),
    [anon_sym_assign] = ACTIONS(4744),
    [anon_sym_alias] = ACTIONS(4744),
    [anon_sym_always_comb] = ACTIONS(4744),
    [anon_sym_always_latch] = ACTIONS(4744),
    [anon_sym_always_ff] = ACTIONS(4744),
    [anon_sym_final] = ACTIONS(4744),
    [anon_sym_global] = ACTIONS(4744),
    [anon_sym_specify] = ACTIONS(4744),
    [anon_sym_LPAREN_STAR] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4742),
    [anon_sym_DOLLARunit] = ACTIONS(4742),
  },
  [755] = {
    [ts_builtin_sym_end] = ACTIONS(4748),
    [sym_simple_identifier] = ACTIONS(4750),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4748),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4748),
    [anon_sym_BQUOTE] = ACTIONS(4750),
    [aux_sym_id_directive_token1] = ACTIONS(4748),
    [aux_sym_id_directive_token2] = ACTIONS(4748),
    [aux_sym_id_directive_token3] = ACTIONS(4748),
    [aux_sym_id_directive_token4] = ACTIONS(4750),
    [aux_sym_zero_directive_token1] = ACTIONS(4748),
    [aux_sym_zero_directive_token2] = ACTIONS(4748),
    [aux_sym_zero_directive_token3] = ACTIONS(4748),
    [aux_sym_zero_directive_token4] = ACTIONS(4748),
    [aux_sym_zero_directive_token5] = ACTIONS(4748),
    [aux_sym_zero_directive_token6] = ACTIONS(4748),
    [aux_sym_zero_directive_token7] = ACTIONS(4748),
    [aux_sym_zero_directive_token8] = ACTIONS(4748),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4748),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4748),
    [anon_sym_wire] = ACTIONS(4750),
    [anon_sym_tri] = ACTIONS(4750),
    [anon_sym_tri0] = ACTIONS(4750),
    [anon_sym_tri1] = ACTIONS(4750),
    [anon_sym_wand] = ACTIONS(4750),
    [anon_sym_triand] = ACTIONS(4750),
    [anon_sym_wor] = ACTIONS(4750),
    [anon_sym_trior] = ACTIONS(4750),
    [anon_sym_trireg] = ACTIONS(4750),
    [anon_sym_uwire] = ACTIONS(4750),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4748),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4748),
    [aux_sym_begin_keywords_token1] = ACTIONS(4748),
    [anon_sym_SEMI] = ACTIONS(4748),
    [anon_sym_endmodule] = ACTIONS(4750),
    [anon_sym_COLON] = ACTIONS(4752),
    [anon_sym_extern] = ACTIONS(4750),
    [anon_sym_module] = ACTIONS(4750),
    [anon_sym_macromodule] = ACTIONS(4750),
    [anon_sym_endinterface] = ACTIONS(4750),
    [anon_sym_interface] = ACTIONS(4750),
    [anon_sym_endprogram] = ACTIONS(4750),
    [anon_sym_program] = ACTIONS(4750),
    [anon_sym_checker] = ACTIONS(4750),
    [anon_sym_virtual] = ACTIONS(4750),
    [anon_sym_class] = ACTIONS(4750),
    [anon_sym_package] = ACTIONS(4750),
    [anon_sym_endpackage] = ACTIONS(4750),
    [anon_sym_timeunit] = ACTIONS(4750),
    [anon_sym_timeprecision] = ACTIONS(4750),
    [anon_sym_type] = ACTIONS(4750),
    [anon_sym_input] = ACTIONS(4750),
    [anon_sym_output] = ACTIONS(4750),
    [anon_sym_inout] = ACTIONS(4750),
    [anon_sym_ref] = ACTIONS(4750),
    [anon_sym_DOLLARfatal] = ACTIONS(4748),
    [anon_sym_DOLLARerror] = ACTIONS(4748),
    [anon_sym_DOLLARwarning] = ACTIONS(4748),
    [anon_sym_DOLLARinfo] = ACTIONS(4748),
    [anon_sym_default] = ACTIONS(4750),
    [anon_sym_clocking] = ACTIONS(4750),
    [anon_sym_defparam] = ACTIONS(4750),
    [anon_sym_bind] = ACTIONS(4750),
    [anon_sym_const] = ACTIONS(4750),
    [anon_sym_function] = ACTIONS(4750),
    [anon_sym_static] = ACTIONS(4750),
    [anon_sym_constraint] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4750),
    [anon_sym_else] = ACTIONS(4750),
    [anon_sym_LBRACK] = ACTIONS(4748),
    [anon_sym_localparam] = ACTIONS(4750),
    [anon_sym_parameter] = ACTIONS(4750),
    [anon_sym_specparam] = ACTIONS(4750),
    [anon_sym_var] = ACTIONS(4750),
    [anon_sym_import] = ACTIONS(4750),
    [anon_sym_export] = ACTIONS(4750),
    [anon_sym_genvar] = ACTIONS(4750),
    [anon_sym_interconnect] = ACTIONS(4750),
    [anon_sym_typedef] = ACTIONS(4750),
    [anon_sym_enum] = ACTIONS(4750),
    [anon_sym_struct] = ACTIONS(4750),
    [anon_sym_union] = ACTIONS(4750),
    [anon_sym_nettype] = ACTIONS(4750),
    [anon_sym_automatic] = ACTIONS(4750),
    [anon_sym_string] = ACTIONS(4750),
    [anon_sym_chandle] = ACTIONS(4750),
    [anon_sym_event] = ACTIONS(4750),
    [anon_sym_byte] = ACTIONS(4750),
    [anon_sym_shortint] = ACTIONS(4750),
    [anon_sym_int] = ACTIONS(4750),
    [anon_sym_longint] = ACTIONS(4750),
    [anon_sym_integer] = ACTIONS(4750),
    [anon_sym_time] = ACTIONS(4750),
    [anon_sym_bit] = ACTIONS(4750),
    [anon_sym_logic] = ACTIONS(4750),
    [anon_sym_reg] = ACTIONS(4750),
    [anon_sym_shortreal] = ACTIONS(4750),
    [anon_sym_real] = ACTIONS(4750),
    [anon_sym_realtime] = ACTIONS(4750),
    [anon_sym_supply0] = ACTIONS(4750),
    [anon_sym_supply1] = ACTIONS(4750),
    [anon_sym_signed] = ACTIONS(4750),
    [anon_sym_unsigned] = ACTIONS(4750),
    [anon_sym_task] = ACTIONS(4750),
    [anon_sym_modport] = ACTIONS(4750),
    [anon_sym_assert] = ACTIONS(4750),
    [anon_sym_property] = ACTIONS(4750),
    [anon_sym_assume] = ACTIONS(4750),
    [anon_sym_cover] = ACTIONS(4750),
    [anon_sym_sequence] = ACTIONS(4750),
    [anon_sym_restrict] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4750),
    [anon_sym_or] = ACTIONS(4750),
    [anon_sym_and] = ACTIONS(4750),
    [anon_sym_case] = ACTIONS(4750),
    [anon_sym_always] = ACTIONS(4750),
    [anon_sym_covergroup] = ACTIONS(4750),
    [anon_sym_let] = ACTIONS(4750),
    [anon_sym_pulldown] = ACTIONS(4750),
    [anon_sym_pullup] = ACTIONS(4750),
    [anon_sym_cmos] = ACTIONS(4750),
    [anon_sym_rcmos] = ACTIONS(4750),
    [anon_sym_bufif0] = ACTIONS(4750),
    [anon_sym_bufif1] = ACTIONS(4750),
    [anon_sym_notif0] = ACTIONS(4750),
    [anon_sym_notif1] = ACTIONS(4750),
    [anon_sym_nmos] = ACTIONS(4750),
    [anon_sym_pmos] = ACTIONS(4750),
    [anon_sym_rnmos] = ACTIONS(4750),
    [anon_sym_rpmos] = ACTIONS(4750),
    [anon_sym_nand] = ACTIONS(4750),
    [anon_sym_nor] = ACTIONS(4750),
    [anon_sym_xor] = ACTIONS(4750),
    [anon_sym_xnor] = ACTIONS(4750),
    [anon_sym_buf] = ACTIONS(4750),
    [anon_sym_tranif0] = ACTIONS(4750),
    [anon_sym_tranif1] = ACTIONS(4750),
    [anon_sym_rtranif1] = ACTIONS(4750),
    [anon_sym_rtranif0] = ACTIONS(4750),
    [anon_sym_tran] = ACTIONS(4750),
    [anon_sym_rtran] = ACTIONS(4750),
    [anon_sym_generate] = ACTIONS(4750),
    [anon_sym_for] = ACTIONS(4750),
    [anon_sym_primitive] = ACTIONS(4750),
    [anon_sym_initial] = ACTIONS(4750),
    [anon_sym_assign] = ACTIONS(4750),
    [anon_sym_alias] = ACTIONS(4750),
    [anon_sym_always_comb] = ACTIONS(4750),
    [anon_sym_always_latch] = ACTIONS(4750),
    [anon_sym_always_ff] = ACTIONS(4750),
    [anon_sym_final] = ACTIONS(4750),
    [anon_sym_global] = ACTIONS(4750),
    [anon_sym_specify] = ACTIONS(4750),
    [anon_sym_LPAREN_STAR] = ACTIONS(4748),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4748),
    [anon_sym_DOLLARunit] = ACTIONS(4748),
  },
  [756] = {
    [ts_builtin_sym_end] = ACTIONS(4754),
    [sym_simple_identifier] = ACTIONS(4756),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4754),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4754),
    [anon_sym_BQUOTE] = ACTIONS(4756),
    [aux_sym_id_directive_token1] = ACTIONS(4754),
    [aux_sym_id_directive_token2] = ACTIONS(4754),
    [aux_sym_id_directive_token3] = ACTIONS(4754),
    [aux_sym_id_directive_token4] = ACTIONS(4756),
    [aux_sym_zero_directive_token1] = ACTIONS(4754),
    [aux_sym_zero_directive_token2] = ACTIONS(4754),
    [aux_sym_zero_directive_token3] = ACTIONS(4754),
    [aux_sym_zero_directive_token4] = ACTIONS(4754),
    [aux_sym_zero_directive_token5] = ACTIONS(4754),
    [aux_sym_zero_directive_token6] = ACTIONS(4754),
    [aux_sym_zero_directive_token7] = ACTIONS(4754),
    [aux_sym_zero_directive_token8] = ACTIONS(4754),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4754),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4754),
    [anon_sym_wire] = ACTIONS(4756),
    [anon_sym_tri] = ACTIONS(4756),
    [anon_sym_tri0] = ACTIONS(4756),
    [anon_sym_tri1] = ACTIONS(4756),
    [anon_sym_wand] = ACTIONS(4756),
    [anon_sym_triand] = ACTIONS(4756),
    [anon_sym_wor] = ACTIONS(4756),
    [anon_sym_trior] = ACTIONS(4756),
    [anon_sym_trireg] = ACTIONS(4756),
    [anon_sym_uwire] = ACTIONS(4756),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4754),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4754),
    [aux_sym_begin_keywords_token1] = ACTIONS(4754),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_endmodule] = ACTIONS(4756),
    [anon_sym_COLON] = ACTIONS(4758),
    [anon_sym_extern] = ACTIONS(4756),
    [anon_sym_module] = ACTIONS(4756),
    [anon_sym_macromodule] = ACTIONS(4756),
    [anon_sym_endinterface] = ACTIONS(4756),
    [anon_sym_interface] = ACTIONS(4756),
    [anon_sym_endprogram] = ACTIONS(4756),
    [anon_sym_program] = ACTIONS(4756),
    [anon_sym_checker] = ACTIONS(4756),
    [anon_sym_virtual] = ACTIONS(4756),
    [anon_sym_class] = ACTIONS(4756),
    [anon_sym_package] = ACTIONS(4756),
    [anon_sym_endpackage] = ACTIONS(4756),
    [anon_sym_timeunit] = ACTIONS(4756),
    [anon_sym_timeprecision] = ACTIONS(4756),
    [anon_sym_type] = ACTIONS(4756),
    [anon_sym_input] = ACTIONS(4756),
    [anon_sym_output] = ACTIONS(4756),
    [anon_sym_inout] = ACTIONS(4756),
    [anon_sym_ref] = ACTIONS(4756),
    [anon_sym_DOLLARfatal] = ACTIONS(4754),
    [anon_sym_DOLLARerror] = ACTIONS(4754),
    [anon_sym_DOLLARwarning] = ACTIONS(4754),
    [anon_sym_DOLLARinfo] = ACTIONS(4754),
    [anon_sym_default] = ACTIONS(4756),
    [anon_sym_clocking] = ACTIONS(4756),
    [anon_sym_defparam] = ACTIONS(4756),
    [anon_sym_bind] = ACTIONS(4756),
    [anon_sym_const] = ACTIONS(4756),
    [anon_sym_function] = ACTIONS(4756),
    [anon_sym_static] = ACTIONS(4756),
    [anon_sym_constraint] = ACTIONS(4756),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [anon_sym_localparam] = ACTIONS(4756),
    [anon_sym_parameter] = ACTIONS(4756),
    [anon_sym_specparam] = ACTIONS(4756),
    [anon_sym_var] = ACTIONS(4756),
    [anon_sym_import] = ACTIONS(4756),
    [anon_sym_export] = ACTIONS(4756),
    [anon_sym_genvar] = ACTIONS(4756),
    [anon_sym_interconnect] = ACTIONS(4756),
    [anon_sym_typedef] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_struct] = ACTIONS(4756),
    [anon_sym_union] = ACTIONS(4756),
    [anon_sym_nettype] = ACTIONS(4756),
    [anon_sym_automatic] = ACTIONS(4756),
    [anon_sym_string] = ACTIONS(4756),
    [anon_sym_chandle] = ACTIONS(4756),
    [anon_sym_event] = ACTIONS(4756),
    [anon_sym_byte] = ACTIONS(4756),
    [anon_sym_shortint] = ACTIONS(4756),
    [anon_sym_int] = ACTIONS(4756),
    [anon_sym_longint] = ACTIONS(4756),
    [anon_sym_integer] = ACTIONS(4756),
    [anon_sym_time] = ACTIONS(4756),
    [anon_sym_bit] = ACTIONS(4756),
    [anon_sym_logic] = ACTIONS(4756),
    [anon_sym_reg] = ACTIONS(4756),
    [anon_sym_shortreal] = ACTIONS(4756),
    [anon_sym_real] = ACTIONS(4756),
    [anon_sym_realtime] = ACTIONS(4756),
    [anon_sym_supply0] = ACTIONS(4756),
    [anon_sym_supply1] = ACTIONS(4756),
    [anon_sym_signed] = ACTIONS(4756),
    [anon_sym_unsigned] = ACTIONS(4756),
    [anon_sym_task] = ACTIONS(4756),
    [anon_sym_modport] = ACTIONS(4756),
    [anon_sym_assert] = ACTIONS(4756),
    [anon_sym_property] = ACTIONS(4756),
    [anon_sym_assume] = ACTIONS(4756),
    [anon_sym_cover] = ACTIONS(4756),
    [anon_sym_sequence] = ACTIONS(4756),
    [anon_sym_restrict] = ACTIONS(4756),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_or] = ACTIONS(4756),
    [anon_sym_and] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_always] = ACTIONS(4756),
    [anon_sym_covergroup] = ACTIONS(4756),
    [anon_sym_let] = ACTIONS(4756),
    [anon_sym_pulldown] = ACTIONS(4756),
    [anon_sym_pullup] = ACTIONS(4756),
    [anon_sym_cmos] = ACTIONS(4756),
    [anon_sym_rcmos] = ACTIONS(4756),
    [anon_sym_bufif0] = ACTIONS(4756),
    [anon_sym_bufif1] = ACTIONS(4756),
    [anon_sym_notif0] = ACTIONS(4756),
    [anon_sym_notif1] = ACTIONS(4756),
    [anon_sym_nmos] = ACTIONS(4756),
    [anon_sym_pmos] = ACTIONS(4756),
    [anon_sym_rnmos] = ACTIONS(4756),
    [anon_sym_rpmos] = ACTIONS(4756),
    [anon_sym_nand] = ACTIONS(4756),
    [anon_sym_nor] = ACTIONS(4756),
    [anon_sym_xor] = ACTIONS(4756),
    [anon_sym_xnor] = ACTIONS(4756),
    [anon_sym_buf] = ACTIONS(4756),
    [anon_sym_tranif0] = ACTIONS(4756),
    [anon_sym_tranif1] = ACTIONS(4756),
    [anon_sym_rtranif1] = ACTIONS(4756),
    [anon_sym_rtranif0] = ACTIONS(4756),
    [anon_sym_tran] = ACTIONS(4756),
    [anon_sym_rtran] = ACTIONS(4756),
    [anon_sym_generate] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_primitive] = ACTIONS(4756),
    [anon_sym_initial] = ACTIONS(4756),
    [anon_sym_assign] = ACTIONS(4756),
    [anon_sym_alias] = ACTIONS(4756),
    [anon_sym_always_comb] = ACTIONS(4756),
    [anon_sym_always_latch] = ACTIONS(4756),
    [anon_sym_always_ff] = ACTIONS(4756),
    [anon_sym_final] = ACTIONS(4756),
    [anon_sym_global] = ACTIONS(4756),
    [anon_sym_specify] = ACTIONS(4756),
    [anon_sym_LPAREN_STAR] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4754),
    [anon_sym_DOLLARunit] = ACTIONS(4754),
  },
  [757] = {
    [ts_builtin_sym_end] = ACTIONS(4760),
    [sym_simple_identifier] = ACTIONS(4762),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4760),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4760),
    [anon_sym_BQUOTE] = ACTIONS(4762),
    [aux_sym_id_directive_token1] = ACTIONS(4760),
    [aux_sym_id_directive_token2] = ACTIONS(4760),
    [aux_sym_id_directive_token3] = ACTIONS(4760),
    [aux_sym_id_directive_token4] = ACTIONS(4762),
    [aux_sym_zero_directive_token1] = ACTIONS(4760),
    [aux_sym_zero_directive_token2] = ACTIONS(4760),
    [aux_sym_zero_directive_token3] = ACTIONS(4760),
    [aux_sym_zero_directive_token4] = ACTIONS(4760),
    [aux_sym_zero_directive_token5] = ACTIONS(4760),
    [aux_sym_zero_directive_token6] = ACTIONS(4760),
    [aux_sym_zero_directive_token7] = ACTIONS(4760),
    [aux_sym_zero_directive_token8] = ACTIONS(4760),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4760),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4760),
    [anon_sym_wire] = ACTIONS(4762),
    [anon_sym_tri] = ACTIONS(4762),
    [anon_sym_tri0] = ACTIONS(4762),
    [anon_sym_tri1] = ACTIONS(4762),
    [anon_sym_wand] = ACTIONS(4762),
    [anon_sym_triand] = ACTIONS(4762),
    [anon_sym_wor] = ACTIONS(4762),
    [anon_sym_trior] = ACTIONS(4762),
    [anon_sym_trireg] = ACTIONS(4762),
    [anon_sym_uwire] = ACTIONS(4762),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4760),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4760),
    [aux_sym_begin_keywords_token1] = ACTIONS(4760),
    [anon_sym_SEMI] = ACTIONS(4760),
    [anon_sym_endmodule] = ACTIONS(4762),
    [anon_sym_COLON] = ACTIONS(4764),
    [anon_sym_extern] = ACTIONS(4762),
    [anon_sym_module] = ACTIONS(4762),
    [anon_sym_macromodule] = ACTIONS(4762),
    [anon_sym_endinterface] = ACTIONS(4762),
    [anon_sym_interface] = ACTIONS(4762),
    [anon_sym_endprogram] = ACTIONS(4762),
    [anon_sym_program] = ACTIONS(4762),
    [anon_sym_checker] = ACTIONS(4762),
    [anon_sym_virtual] = ACTIONS(4762),
    [anon_sym_class] = ACTIONS(4762),
    [anon_sym_package] = ACTIONS(4762),
    [anon_sym_endpackage] = ACTIONS(4762),
    [anon_sym_timeunit] = ACTIONS(4762),
    [anon_sym_timeprecision] = ACTIONS(4762),
    [anon_sym_type] = ACTIONS(4762),
    [anon_sym_input] = ACTIONS(4762),
    [anon_sym_output] = ACTIONS(4762),
    [anon_sym_inout] = ACTIONS(4762),
    [anon_sym_ref] = ACTIONS(4762),
    [anon_sym_DOLLARfatal] = ACTIONS(4760),
    [anon_sym_DOLLARerror] = ACTIONS(4760),
    [anon_sym_DOLLARwarning] = ACTIONS(4760),
    [anon_sym_DOLLARinfo] = ACTIONS(4760),
    [anon_sym_default] = ACTIONS(4762),
    [anon_sym_clocking] = ACTIONS(4762),
    [anon_sym_defparam] = ACTIONS(4762),
    [anon_sym_bind] = ACTIONS(4762),
    [anon_sym_const] = ACTIONS(4762),
    [anon_sym_function] = ACTIONS(4762),
    [anon_sym_static] = ACTIONS(4762),
    [anon_sym_constraint] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4762),
    [anon_sym_else] = ACTIONS(4762),
    [anon_sym_LBRACK] = ACTIONS(4760),
    [anon_sym_localparam] = ACTIONS(4762),
    [anon_sym_parameter] = ACTIONS(4762),
    [anon_sym_specparam] = ACTIONS(4762),
    [anon_sym_var] = ACTIONS(4762),
    [anon_sym_import] = ACTIONS(4762),
    [anon_sym_export] = ACTIONS(4762),
    [anon_sym_genvar] = ACTIONS(4762),
    [anon_sym_interconnect] = ACTIONS(4762),
    [anon_sym_typedef] = ACTIONS(4762),
    [anon_sym_enum] = ACTIONS(4762),
    [anon_sym_struct] = ACTIONS(4762),
    [anon_sym_union] = ACTIONS(4762),
    [anon_sym_nettype] = ACTIONS(4762),
    [anon_sym_automatic] = ACTIONS(4762),
    [anon_sym_string] = ACTIONS(4762),
    [anon_sym_chandle] = ACTIONS(4762),
    [anon_sym_event] = ACTIONS(4762),
    [anon_sym_byte] = ACTIONS(4762),
    [anon_sym_shortint] = ACTIONS(4762),
    [anon_sym_int] = ACTIONS(4762),
    [anon_sym_longint] = ACTIONS(4762),
    [anon_sym_integer] = ACTIONS(4762),
    [anon_sym_time] = ACTIONS(4762),
    [anon_sym_bit] = ACTIONS(4762),
    [anon_sym_logic] = ACTIONS(4762),
    [anon_sym_reg] = ACTIONS(4762),
    [anon_sym_shortreal] = ACTIONS(4762),
    [anon_sym_real] = ACTIONS(4762),
    [anon_sym_realtime] = ACTIONS(4762),
    [anon_sym_supply0] = ACTIONS(4762),
    [anon_sym_supply1] = ACTIONS(4762),
    [anon_sym_signed] = ACTIONS(4762),
    [anon_sym_unsigned] = ACTIONS(4762),
    [anon_sym_task] = ACTIONS(4762),
    [anon_sym_modport] = ACTIONS(4762),
    [anon_sym_assert] = ACTIONS(4762),
    [anon_sym_property] = ACTIONS(4762),
    [anon_sym_assume] = ACTIONS(4762),
    [anon_sym_cover] = ACTIONS(4762),
    [anon_sym_sequence] = ACTIONS(4762),
    [anon_sym_restrict] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4762),
    [anon_sym_or] = ACTIONS(4762),
    [anon_sym_and] = ACTIONS(4762),
    [anon_sym_case] = ACTIONS(4762),
    [anon_sym_always] = ACTIONS(4762),
    [anon_sym_covergroup] = ACTIONS(4762),
    [anon_sym_let] = ACTIONS(4762),
    [anon_sym_pulldown] = ACTIONS(4762),
    [anon_sym_pullup] = ACTIONS(4762),
    [anon_sym_cmos] = ACTIONS(4762),
    [anon_sym_rcmos] = ACTIONS(4762),
    [anon_sym_bufif0] = ACTIONS(4762),
    [anon_sym_bufif1] = ACTIONS(4762),
    [anon_sym_notif0] = ACTIONS(4762),
    [anon_sym_notif1] = ACTIONS(4762),
    [anon_sym_nmos] = ACTIONS(4762),
    [anon_sym_pmos] = ACTIONS(4762),
    [anon_sym_rnmos] = ACTIONS(4762),
    [anon_sym_rpmos] = ACTIONS(4762),
    [anon_sym_nand] = ACTIONS(4762),
    [anon_sym_nor] = ACTIONS(4762),
    [anon_sym_xor] = ACTIONS(4762),
    [anon_sym_xnor] = ACTIONS(4762),
    [anon_sym_buf] = ACTIONS(4762),
    [anon_sym_tranif0] = ACTIONS(4762),
    [anon_sym_tranif1] = ACTIONS(4762),
    [anon_sym_rtranif1] = ACTIONS(4762),
    [anon_sym_rtranif0] = ACTIONS(4762),
    [anon_sym_tran] = ACTIONS(4762),
    [anon_sym_rtran] = ACTIONS(4762),
    [anon_sym_generate] = ACTIONS(4762),
    [anon_sym_for] = ACTIONS(4762),
    [anon_sym_primitive] = ACTIONS(4762),
    [anon_sym_initial] = ACTIONS(4762),
    [anon_sym_assign] = ACTIONS(4762),
    [anon_sym_alias] = ACTIONS(4762),
    [anon_sym_always_comb] = ACTIONS(4762),
    [anon_sym_always_latch] = ACTIONS(4762),
    [anon_sym_always_ff] = ACTIONS(4762),
    [anon_sym_final] = ACTIONS(4762),
    [anon_sym_global] = ACTIONS(4762),
    [anon_sym_specify] = ACTIONS(4762),
    [anon_sym_LPAREN_STAR] = ACTIONS(4760),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4760),
    [anon_sym_DOLLARunit] = ACTIONS(4760),
  },
  [758] = {
    [ts_builtin_sym_end] = ACTIONS(4766),
    [sym_simple_identifier] = ACTIONS(4768),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4766),
    [anon_sym_BQUOTE] = ACTIONS(4768),
    [aux_sym_id_directive_token1] = ACTIONS(4766),
    [aux_sym_id_directive_token2] = ACTIONS(4766),
    [aux_sym_id_directive_token3] = ACTIONS(4766),
    [aux_sym_id_directive_token4] = ACTIONS(4768),
    [aux_sym_zero_directive_token1] = ACTIONS(4766),
    [aux_sym_zero_directive_token2] = ACTIONS(4766),
    [aux_sym_zero_directive_token3] = ACTIONS(4766),
    [aux_sym_zero_directive_token4] = ACTIONS(4766),
    [aux_sym_zero_directive_token5] = ACTIONS(4766),
    [aux_sym_zero_directive_token6] = ACTIONS(4766),
    [aux_sym_zero_directive_token7] = ACTIONS(4766),
    [aux_sym_zero_directive_token8] = ACTIONS(4766),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4766),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4766),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_begin_keywords_token1] = ACTIONS(4766),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_endmodule] = ACTIONS(4768),
    [anon_sym_COLON] = ACTIONS(4770),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_module] = ACTIONS(4768),
    [anon_sym_macromodule] = ACTIONS(4768),
    [anon_sym_endinterface] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_endprogram] = ACTIONS(4768),
    [anon_sym_program] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_package] = ACTIONS(4768),
    [anon_sym_endpackage] = ACTIONS(4768),
    [anon_sym_timeunit] = ACTIONS(4768),
    [anon_sym_timeprecision] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_input] = ACTIONS(4768),
    [anon_sym_output] = ACTIONS(4768),
    [anon_sym_inout] = ACTIONS(4768),
    [anon_sym_ref] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_specparam] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_modport] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_primitive] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_specify] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [759] = {
    [ts_builtin_sym_end] = ACTIONS(4772),
    [sym_simple_identifier] = ACTIONS(4774),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4772),
    [anon_sym_BQUOTE] = ACTIONS(4774),
    [aux_sym_id_directive_token1] = ACTIONS(4772),
    [aux_sym_id_directive_token2] = ACTIONS(4772),
    [aux_sym_id_directive_token3] = ACTIONS(4772),
    [aux_sym_id_directive_token4] = ACTIONS(4774),
    [aux_sym_zero_directive_token1] = ACTIONS(4772),
    [aux_sym_zero_directive_token2] = ACTIONS(4772),
    [aux_sym_zero_directive_token3] = ACTIONS(4772),
    [aux_sym_zero_directive_token4] = ACTIONS(4772),
    [aux_sym_zero_directive_token5] = ACTIONS(4772),
    [aux_sym_zero_directive_token6] = ACTIONS(4772),
    [aux_sym_zero_directive_token7] = ACTIONS(4772),
    [aux_sym_zero_directive_token8] = ACTIONS(4772),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4772),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4772),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_begin_keywords_token1] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_endmodule] = ACTIONS(4774),
    [anon_sym_COLON] = ACTIONS(4776),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_module] = ACTIONS(4774),
    [anon_sym_macromodule] = ACTIONS(4774),
    [anon_sym_endinterface] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_endprogram] = ACTIONS(4774),
    [anon_sym_program] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_package] = ACTIONS(4774),
    [anon_sym_endpackage] = ACTIONS(4774),
    [anon_sym_timeunit] = ACTIONS(4774),
    [anon_sym_timeprecision] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_input] = ACTIONS(4774),
    [anon_sym_output] = ACTIONS(4774),
    [anon_sym_inout] = ACTIONS(4774),
    [anon_sym_ref] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_specparam] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_modport] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_primitive] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_specify] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [760] = {
    [ts_builtin_sym_end] = ACTIONS(4778),
    [sym_simple_identifier] = ACTIONS(4780),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4778),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4778),
    [anon_sym_BQUOTE] = ACTIONS(4780),
    [aux_sym_id_directive_token1] = ACTIONS(4778),
    [aux_sym_id_directive_token2] = ACTIONS(4778),
    [aux_sym_id_directive_token3] = ACTIONS(4778),
    [aux_sym_id_directive_token4] = ACTIONS(4780),
    [aux_sym_zero_directive_token1] = ACTIONS(4778),
    [aux_sym_zero_directive_token2] = ACTIONS(4778),
    [aux_sym_zero_directive_token3] = ACTIONS(4778),
    [aux_sym_zero_directive_token4] = ACTIONS(4778),
    [aux_sym_zero_directive_token5] = ACTIONS(4778),
    [aux_sym_zero_directive_token6] = ACTIONS(4778),
    [aux_sym_zero_directive_token7] = ACTIONS(4778),
    [aux_sym_zero_directive_token8] = ACTIONS(4778),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4778),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4778),
    [anon_sym_wire] = ACTIONS(4780),
    [anon_sym_tri] = ACTIONS(4780),
    [anon_sym_tri0] = ACTIONS(4780),
    [anon_sym_tri1] = ACTIONS(4780),
    [anon_sym_wand] = ACTIONS(4780),
    [anon_sym_triand] = ACTIONS(4780),
    [anon_sym_wor] = ACTIONS(4780),
    [anon_sym_trior] = ACTIONS(4780),
    [anon_sym_trireg] = ACTIONS(4780),
    [anon_sym_uwire] = ACTIONS(4780),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4778),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4778),
    [aux_sym_begin_keywords_token1] = ACTIONS(4778),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_endmodule] = ACTIONS(4780),
    [anon_sym_extern] = ACTIONS(4780),
    [anon_sym_module] = ACTIONS(4780),
    [anon_sym_macromodule] = ACTIONS(4780),
    [anon_sym_endinterface] = ACTIONS(4780),
    [anon_sym_interface] = ACTIONS(4780),
    [anon_sym_endprogram] = ACTIONS(4780),
    [anon_sym_program] = ACTIONS(4780),
    [anon_sym_checker] = ACTIONS(4780),
    [anon_sym_virtual] = ACTIONS(4780),
    [anon_sym_class] = ACTIONS(4780),
    [anon_sym_package] = ACTIONS(4780),
    [anon_sym_endpackage] = ACTIONS(4780),
    [anon_sym_timeunit] = ACTIONS(4780),
    [anon_sym_timeprecision] = ACTIONS(4780),
    [anon_sym_type] = ACTIONS(4780),
    [anon_sym_input] = ACTIONS(4780),
    [anon_sym_output] = ACTIONS(4780),
    [anon_sym_inout] = ACTIONS(4780),
    [anon_sym_ref] = ACTIONS(4780),
    [anon_sym_DOLLARfatal] = ACTIONS(4778),
    [anon_sym_DOLLARerror] = ACTIONS(4778),
    [anon_sym_DOLLARwarning] = ACTIONS(4778),
    [anon_sym_DOLLARinfo] = ACTIONS(4778),
    [anon_sym_default] = ACTIONS(4780),
    [anon_sym_clocking] = ACTIONS(4780),
    [anon_sym_defparam] = ACTIONS(4780),
    [anon_sym_bind] = ACTIONS(4780),
    [anon_sym_const] = ACTIONS(4780),
    [anon_sym_function] = ACTIONS(4780),
    [anon_sym_static] = ACTIONS(4780),
    [anon_sym_constraint] = ACTIONS(4780),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [anon_sym_localparam] = ACTIONS(4780),
    [anon_sym_parameter] = ACTIONS(4780),
    [anon_sym_specparam] = ACTIONS(4780),
    [anon_sym_var] = ACTIONS(4780),
    [anon_sym_import] = ACTIONS(4780),
    [anon_sym_export] = ACTIONS(4780),
    [anon_sym_genvar] = ACTIONS(4780),
    [anon_sym_interconnect] = ACTIONS(4780),
    [anon_sym_typedef] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_struct] = ACTIONS(4780),
    [anon_sym_union] = ACTIONS(4780),
    [anon_sym_nettype] = ACTIONS(4780),
    [anon_sym_automatic] = ACTIONS(4780),
    [anon_sym_string] = ACTIONS(4780),
    [anon_sym_chandle] = ACTIONS(4780),
    [anon_sym_event] = ACTIONS(4780),
    [anon_sym_byte] = ACTIONS(4780),
    [anon_sym_shortint] = ACTIONS(4780),
    [anon_sym_int] = ACTIONS(4780),
    [anon_sym_longint] = ACTIONS(4780),
    [anon_sym_integer] = ACTIONS(4780),
    [anon_sym_time] = ACTIONS(4780),
    [anon_sym_bit] = ACTIONS(4780),
    [anon_sym_logic] = ACTIONS(4780),
    [anon_sym_reg] = ACTIONS(4780),
    [anon_sym_shortreal] = ACTIONS(4780),
    [anon_sym_real] = ACTIONS(4780),
    [anon_sym_realtime] = ACTIONS(4780),
    [anon_sym_supply0] = ACTIONS(4780),
    [anon_sym_supply1] = ACTIONS(4780),
    [anon_sym_signed] = ACTIONS(4780),
    [anon_sym_unsigned] = ACTIONS(4780),
    [anon_sym_task] = ACTIONS(4780),
    [anon_sym_modport] = ACTIONS(4780),
    [anon_sym_assert] = ACTIONS(4780),
    [anon_sym_property] = ACTIONS(4780),
    [anon_sym_assume] = ACTIONS(4780),
    [anon_sym_cover] = ACTIONS(4780),
    [anon_sym_sequence] = ACTIONS(4780),
    [anon_sym_restrict] = ACTIONS(4780),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_or] = ACTIONS(4780),
    [anon_sym_and] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_always] = ACTIONS(4780),
    [anon_sym_covergroup] = ACTIONS(4780),
    [anon_sym_let] = ACTIONS(4780),
    [anon_sym_pulldown] = ACTIONS(4780),
    [anon_sym_pullup] = ACTIONS(4780),
    [anon_sym_cmos] = ACTIONS(4780),
    [anon_sym_rcmos] = ACTIONS(4780),
    [anon_sym_bufif0] = ACTIONS(4780),
    [anon_sym_bufif1] = ACTIONS(4780),
    [anon_sym_notif0] = ACTIONS(4780),
    [anon_sym_notif1] = ACTIONS(4780),
    [anon_sym_nmos] = ACTIONS(4780),
    [anon_sym_pmos] = ACTIONS(4780),
    [anon_sym_rnmos] = ACTIONS(4780),
    [anon_sym_rpmos] = ACTIONS(4780),
    [anon_sym_nand] = ACTIONS(4780),
    [anon_sym_nor] = ACTIONS(4780),
    [anon_sym_xor] = ACTIONS(4780),
    [anon_sym_xnor] = ACTIONS(4780),
    [anon_sym_buf] = ACTIONS(4780),
    [anon_sym_tranif0] = ACTIONS(4780),
    [anon_sym_tranif1] = ACTIONS(4780),
    [anon_sym_rtranif1] = ACTIONS(4780),
    [anon_sym_rtranif0] = ACTIONS(4780),
    [anon_sym_tran] = ACTIONS(4780),
    [anon_sym_rtran] = ACTIONS(4780),
    [anon_sym_generate] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_primitive] = ACTIONS(4780),
    [anon_sym_initial] = ACTIONS(4780),
    [anon_sym_assign] = ACTIONS(4780),
    [anon_sym_alias] = ACTIONS(4780),
    [anon_sym_always_comb] = ACTIONS(4780),
    [anon_sym_always_latch] = ACTIONS(4780),
    [anon_sym_always_ff] = ACTIONS(4780),
    [anon_sym_final] = ACTIONS(4780),
    [anon_sym_endclocking] = ACTIONS(4780),
    [anon_sym_global] = ACTIONS(4780),
    [anon_sym_specify] = ACTIONS(4780),
    [anon_sym_LPAREN_STAR] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4778),
    [anon_sym_DOLLARunit] = ACTIONS(4778),
  },
  [761] = {
    [ts_builtin_sym_end] = ACTIONS(4782),
    [sym_simple_identifier] = ACTIONS(4784),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4782),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4782),
    [anon_sym_BQUOTE] = ACTIONS(4784),
    [aux_sym_id_directive_token1] = ACTIONS(4782),
    [aux_sym_id_directive_token2] = ACTIONS(4782),
    [aux_sym_id_directive_token3] = ACTIONS(4782),
    [aux_sym_id_directive_token4] = ACTIONS(4784),
    [aux_sym_zero_directive_token1] = ACTIONS(4782),
    [aux_sym_zero_directive_token2] = ACTIONS(4782),
    [aux_sym_zero_directive_token3] = ACTIONS(4782),
    [aux_sym_zero_directive_token4] = ACTIONS(4782),
    [aux_sym_zero_directive_token5] = ACTIONS(4782),
    [aux_sym_zero_directive_token6] = ACTIONS(4782),
    [aux_sym_zero_directive_token7] = ACTIONS(4782),
    [aux_sym_zero_directive_token8] = ACTIONS(4782),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4782),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4782),
    [anon_sym_wire] = ACTIONS(4784),
    [anon_sym_tri] = ACTIONS(4784),
    [anon_sym_tri0] = ACTIONS(4784),
    [anon_sym_tri1] = ACTIONS(4784),
    [anon_sym_wand] = ACTIONS(4784),
    [anon_sym_triand] = ACTIONS(4784),
    [anon_sym_wor] = ACTIONS(4784),
    [anon_sym_trior] = ACTIONS(4784),
    [anon_sym_trireg] = ACTIONS(4784),
    [anon_sym_uwire] = ACTIONS(4784),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4782),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4782),
    [aux_sym_begin_keywords_token1] = ACTIONS(4782),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_endmodule] = ACTIONS(4784),
    [anon_sym_extern] = ACTIONS(4784),
    [anon_sym_module] = ACTIONS(4784),
    [anon_sym_macromodule] = ACTIONS(4784),
    [anon_sym_endinterface] = ACTIONS(4784),
    [anon_sym_interface] = ACTIONS(4784),
    [anon_sym_endprogram] = ACTIONS(4784),
    [anon_sym_program] = ACTIONS(4784),
    [anon_sym_checker] = ACTIONS(4784),
    [anon_sym_virtual] = ACTIONS(4784),
    [anon_sym_class] = ACTIONS(4784),
    [anon_sym_package] = ACTIONS(4784),
    [anon_sym_endpackage] = ACTIONS(4784),
    [anon_sym_timeunit] = ACTIONS(4784),
    [anon_sym_timeprecision] = ACTIONS(4784),
    [anon_sym_type] = ACTIONS(4784),
    [anon_sym_input] = ACTIONS(4784),
    [anon_sym_output] = ACTIONS(4784),
    [anon_sym_inout] = ACTIONS(4784),
    [anon_sym_ref] = ACTIONS(4784),
    [anon_sym_DOLLARfatal] = ACTIONS(4782),
    [anon_sym_DOLLARerror] = ACTIONS(4782),
    [anon_sym_DOLLARwarning] = ACTIONS(4782),
    [anon_sym_DOLLARinfo] = ACTIONS(4782),
    [anon_sym_default] = ACTIONS(4784),
    [anon_sym_clocking] = ACTIONS(4784),
    [anon_sym_defparam] = ACTIONS(4784),
    [anon_sym_bind] = ACTIONS(4784),
    [anon_sym_const] = ACTIONS(4784),
    [anon_sym_function] = ACTIONS(4784),
    [anon_sym_static] = ACTIONS(4784),
    [anon_sym_constraint] = ACTIONS(4784),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [anon_sym_localparam] = ACTIONS(4784),
    [anon_sym_parameter] = ACTIONS(4784),
    [anon_sym_specparam] = ACTIONS(4784),
    [anon_sym_var] = ACTIONS(4784),
    [anon_sym_import] = ACTIONS(4784),
    [anon_sym_export] = ACTIONS(4784),
    [anon_sym_genvar] = ACTIONS(4784),
    [anon_sym_interconnect] = ACTIONS(4784),
    [anon_sym_typedef] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_struct] = ACTIONS(4784),
    [anon_sym_union] = ACTIONS(4784),
    [anon_sym_nettype] = ACTIONS(4784),
    [anon_sym_automatic] = ACTIONS(4784),
    [anon_sym_string] = ACTIONS(4784),
    [anon_sym_chandle] = ACTIONS(4784),
    [anon_sym_event] = ACTIONS(4784),
    [anon_sym_byte] = ACTIONS(4784),
    [anon_sym_shortint] = ACTIONS(4784),
    [anon_sym_int] = ACTIONS(4784),
    [anon_sym_longint] = ACTIONS(4784),
    [anon_sym_integer] = ACTIONS(4784),
    [anon_sym_time] = ACTIONS(4784),
    [anon_sym_bit] = ACTIONS(4784),
    [anon_sym_logic] = ACTIONS(4784),
    [anon_sym_reg] = ACTIONS(4784),
    [anon_sym_shortreal] = ACTIONS(4784),
    [anon_sym_real] = ACTIONS(4784),
    [anon_sym_realtime] = ACTIONS(4784),
    [anon_sym_supply0] = ACTIONS(4784),
    [anon_sym_supply1] = ACTIONS(4784),
    [anon_sym_signed] = ACTIONS(4784),
    [anon_sym_unsigned] = ACTIONS(4784),
    [anon_sym_task] = ACTIONS(4784),
    [anon_sym_modport] = ACTIONS(4784),
    [anon_sym_assert] = ACTIONS(4784),
    [anon_sym_property] = ACTIONS(4784),
    [anon_sym_assume] = ACTIONS(4784),
    [anon_sym_cover] = ACTIONS(4784),
    [anon_sym_sequence] = ACTIONS(4784),
    [anon_sym_restrict] = ACTIONS(4784),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_or] = ACTIONS(4784),
    [anon_sym_and] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_always] = ACTIONS(4784),
    [anon_sym_covergroup] = ACTIONS(4784),
    [anon_sym_let] = ACTIONS(4784),
    [anon_sym_pulldown] = ACTIONS(4784),
    [anon_sym_pullup] = ACTIONS(4784),
    [anon_sym_cmos] = ACTIONS(4784),
    [anon_sym_rcmos] = ACTIONS(4784),
    [anon_sym_bufif0] = ACTIONS(4784),
    [anon_sym_bufif1] = ACTIONS(4784),
    [anon_sym_notif0] = ACTIONS(4784),
    [anon_sym_notif1] = ACTIONS(4784),
    [anon_sym_nmos] = ACTIONS(4784),
    [anon_sym_pmos] = ACTIONS(4784),
    [anon_sym_rnmos] = ACTIONS(4784),
    [anon_sym_rpmos] = ACTIONS(4784),
    [anon_sym_nand] = ACTIONS(4784),
    [anon_sym_nor] = ACTIONS(4784),
    [anon_sym_xor] = ACTIONS(4784),
    [anon_sym_xnor] = ACTIONS(4784),
    [anon_sym_buf] = ACTIONS(4784),
    [anon_sym_tranif0] = ACTIONS(4784),
    [anon_sym_tranif1] = ACTIONS(4784),
    [anon_sym_rtranif1] = ACTIONS(4784),
    [anon_sym_rtranif0] = ACTIONS(4784),
    [anon_sym_tran] = ACTIONS(4784),
    [anon_sym_rtran] = ACTIONS(4784),
    [anon_sym_generate] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_primitive] = ACTIONS(4784),
    [anon_sym_initial] = ACTIONS(4784),
    [anon_sym_assign] = ACTIONS(4784),
    [anon_sym_alias] = ACTIONS(4784),
    [anon_sym_always_comb] = ACTIONS(4784),
    [anon_sym_always_latch] = ACTIONS(4784),
    [anon_sym_always_ff] = ACTIONS(4784),
    [anon_sym_final] = ACTIONS(4784),
    [anon_sym_endclocking] = ACTIONS(4784),
    [anon_sym_global] = ACTIONS(4784),
    [anon_sym_specify] = ACTIONS(4784),
    [anon_sym_LPAREN_STAR] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4782),
    [anon_sym_DOLLARunit] = ACTIONS(4782),
  },
  [762] = {
    [ts_builtin_sym_end] = ACTIONS(4786),
    [sym_simple_identifier] = ACTIONS(4788),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4786),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4786),
    [anon_sym_BQUOTE] = ACTIONS(4788),
    [aux_sym_id_directive_token1] = ACTIONS(4786),
    [aux_sym_id_directive_token2] = ACTIONS(4786),
    [aux_sym_id_directive_token3] = ACTIONS(4786),
    [aux_sym_id_directive_token4] = ACTIONS(4788),
    [aux_sym_zero_directive_token1] = ACTIONS(4786),
    [aux_sym_zero_directive_token2] = ACTIONS(4786),
    [aux_sym_zero_directive_token3] = ACTIONS(4786),
    [aux_sym_zero_directive_token4] = ACTIONS(4786),
    [aux_sym_zero_directive_token5] = ACTIONS(4786),
    [aux_sym_zero_directive_token6] = ACTIONS(4786),
    [aux_sym_zero_directive_token7] = ACTIONS(4786),
    [aux_sym_zero_directive_token8] = ACTIONS(4786),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4786),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4786),
    [anon_sym_wire] = ACTIONS(4788),
    [anon_sym_tri] = ACTIONS(4788),
    [anon_sym_tri0] = ACTIONS(4788),
    [anon_sym_tri1] = ACTIONS(4788),
    [anon_sym_wand] = ACTIONS(4788),
    [anon_sym_triand] = ACTIONS(4788),
    [anon_sym_wor] = ACTIONS(4788),
    [anon_sym_trior] = ACTIONS(4788),
    [anon_sym_trireg] = ACTIONS(4788),
    [anon_sym_uwire] = ACTIONS(4788),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4786),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4786),
    [aux_sym_begin_keywords_token1] = ACTIONS(4786),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_endmodule] = ACTIONS(4788),
    [anon_sym_COLON] = ACTIONS(4790),
    [anon_sym_extern] = ACTIONS(4788),
    [anon_sym_module] = ACTIONS(4788),
    [anon_sym_macromodule] = ACTIONS(4788),
    [anon_sym_endinterface] = ACTIONS(4788),
    [anon_sym_interface] = ACTIONS(4788),
    [anon_sym_endprogram] = ACTIONS(4788),
    [anon_sym_program] = ACTIONS(4788),
    [anon_sym_checker] = ACTIONS(4788),
    [anon_sym_virtual] = ACTIONS(4788),
    [anon_sym_class] = ACTIONS(4788),
    [anon_sym_package] = ACTIONS(4788),
    [anon_sym_endpackage] = ACTIONS(4788),
    [anon_sym_timeunit] = ACTIONS(4788),
    [anon_sym_timeprecision] = ACTIONS(4788),
    [anon_sym_type] = ACTIONS(4788),
    [anon_sym_input] = ACTIONS(4788),
    [anon_sym_output] = ACTIONS(4788),
    [anon_sym_inout] = ACTIONS(4788),
    [anon_sym_ref] = ACTIONS(4788),
    [anon_sym_DOLLARfatal] = ACTIONS(4786),
    [anon_sym_DOLLARerror] = ACTIONS(4786),
    [anon_sym_DOLLARwarning] = ACTIONS(4786),
    [anon_sym_DOLLARinfo] = ACTIONS(4786),
    [anon_sym_default] = ACTIONS(4788),
    [anon_sym_clocking] = ACTIONS(4788),
    [anon_sym_defparam] = ACTIONS(4788),
    [anon_sym_bind] = ACTIONS(4788),
    [anon_sym_const] = ACTIONS(4788),
    [anon_sym_function] = ACTIONS(4788),
    [anon_sym_static] = ACTIONS(4788),
    [anon_sym_constraint] = ACTIONS(4788),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [anon_sym_localparam] = ACTIONS(4788),
    [anon_sym_parameter] = ACTIONS(4788),
    [anon_sym_specparam] = ACTIONS(4788),
    [anon_sym_var] = ACTIONS(4788),
    [anon_sym_import] = ACTIONS(4788),
    [anon_sym_export] = ACTIONS(4788),
    [anon_sym_genvar] = ACTIONS(4788),
    [anon_sym_interconnect] = ACTIONS(4788),
    [anon_sym_typedef] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_struct] = ACTIONS(4788),
    [anon_sym_union] = ACTIONS(4788),
    [anon_sym_nettype] = ACTIONS(4788),
    [anon_sym_automatic] = ACTIONS(4788),
    [anon_sym_string] = ACTIONS(4788),
    [anon_sym_chandle] = ACTIONS(4788),
    [anon_sym_event] = ACTIONS(4788),
    [anon_sym_byte] = ACTIONS(4788),
    [anon_sym_shortint] = ACTIONS(4788),
    [anon_sym_int] = ACTIONS(4788),
    [anon_sym_longint] = ACTIONS(4788),
    [anon_sym_integer] = ACTIONS(4788),
    [anon_sym_time] = ACTIONS(4788),
    [anon_sym_bit] = ACTIONS(4788),
    [anon_sym_logic] = ACTIONS(4788),
    [anon_sym_reg] = ACTIONS(4788),
    [anon_sym_shortreal] = ACTIONS(4788),
    [anon_sym_real] = ACTIONS(4788),
    [anon_sym_realtime] = ACTIONS(4788),
    [anon_sym_supply0] = ACTIONS(4788),
    [anon_sym_supply1] = ACTIONS(4788),
    [anon_sym_signed] = ACTIONS(4788),
    [anon_sym_unsigned] = ACTIONS(4788),
    [anon_sym_task] = ACTIONS(4788),
    [anon_sym_modport] = ACTIONS(4788),
    [anon_sym_assert] = ACTIONS(4788),
    [anon_sym_property] = ACTIONS(4788),
    [anon_sym_assume] = ACTIONS(4788),
    [anon_sym_cover] = ACTIONS(4788),
    [anon_sym_sequence] = ACTIONS(4788),
    [anon_sym_restrict] = ACTIONS(4788),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_or] = ACTIONS(4788),
    [anon_sym_and] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_always] = ACTIONS(4788),
    [anon_sym_covergroup] = ACTIONS(4788),
    [anon_sym_let] = ACTIONS(4788),
    [anon_sym_pulldown] = ACTIONS(4788),
    [anon_sym_pullup] = ACTIONS(4788),
    [anon_sym_cmos] = ACTIONS(4788),
    [anon_sym_rcmos] = ACTIONS(4788),
    [anon_sym_bufif0] = ACTIONS(4788),
    [anon_sym_bufif1] = ACTIONS(4788),
    [anon_sym_notif0] = ACTIONS(4788),
    [anon_sym_notif1] = ACTIONS(4788),
    [anon_sym_nmos] = ACTIONS(4788),
    [anon_sym_pmos] = ACTIONS(4788),
    [anon_sym_rnmos] = ACTIONS(4788),
    [anon_sym_rpmos] = ACTIONS(4788),
    [anon_sym_nand] = ACTIONS(4788),
    [anon_sym_nor] = ACTIONS(4788),
    [anon_sym_xor] = ACTIONS(4788),
    [anon_sym_xnor] = ACTIONS(4788),
    [anon_sym_buf] = ACTIONS(4788),
    [anon_sym_tranif0] = ACTIONS(4788),
    [anon_sym_tranif1] = ACTIONS(4788),
    [anon_sym_rtranif1] = ACTIONS(4788),
    [anon_sym_rtranif0] = ACTIONS(4788),
    [anon_sym_tran] = ACTIONS(4788),
    [anon_sym_rtran] = ACTIONS(4788),
    [anon_sym_generate] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_primitive] = ACTIONS(4788),
    [anon_sym_initial] = ACTIONS(4788),
    [anon_sym_assign] = ACTIONS(4788),
    [anon_sym_alias] = ACTIONS(4788),
    [anon_sym_always_comb] = ACTIONS(4788),
    [anon_sym_always_latch] = ACTIONS(4788),
    [anon_sym_always_ff] = ACTIONS(4788),
    [anon_sym_final] = ACTIONS(4788),
    [anon_sym_global] = ACTIONS(4788),
    [anon_sym_specify] = ACTIONS(4788),
    [anon_sym_LPAREN_STAR] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4786),
    [anon_sym_DOLLARunit] = ACTIONS(4786),
  },
  [763] = {
    [ts_builtin_sym_end] = ACTIONS(4792),
    [sym_simple_identifier] = ACTIONS(4794),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4792),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4792),
    [anon_sym_BQUOTE] = ACTIONS(4794),
    [aux_sym_id_directive_token1] = ACTIONS(4792),
    [aux_sym_id_directive_token2] = ACTIONS(4792),
    [aux_sym_id_directive_token3] = ACTIONS(4792),
    [aux_sym_id_directive_token4] = ACTIONS(4794),
    [aux_sym_zero_directive_token1] = ACTIONS(4792),
    [aux_sym_zero_directive_token2] = ACTIONS(4792),
    [aux_sym_zero_directive_token3] = ACTIONS(4792),
    [aux_sym_zero_directive_token4] = ACTIONS(4792),
    [aux_sym_zero_directive_token5] = ACTIONS(4792),
    [aux_sym_zero_directive_token6] = ACTIONS(4792),
    [aux_sym_zero_directive_token7] = ACTIONS(4792),
    [aux_sym_zero_directive_token8] = ACTIONS(4792),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4792),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4792),
    [anon_sym_wire] = ACTIONS(4794),
    [anon_sym_tri] = ACTIONS(4794),
    [anon_sym_tri0] = ACTIONS(4794),
    [anon_sym_tri1] = ACTIONS(4794),
    [anon_sym_wand] = ACTIONS(4794),
    [anon_sym_triand] = ACTIONS(4794),
    [anon_sym_wor] = ACTIONS(4794),
    [anon_sym_trior] = ACTIONS(4794),
    [anon_sym_trireg] = ACTIONS(4794),
    [anon_sym_uwire] = ACTIONS(4794),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4792),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4792),
    [aux_sym_begin_keywords_token1] = ACTIONS(4792),
    [anon_sym_SEMI] = ACTIONS(4792),
    [anon_sym_endmodule] = ACTIONS(4794),
    [anon_sym_COLON] = ACTIONS(4796),
    [anon_sym_extern] = ACTIONS(4794),
    [anon_sym_module] = ACTIONS(4794),
    [anon_sym_macromodule] = ACTIONS(4794),
    [anon_sym_endinterface] = ACTIONS(4794),
    [anon_sym_interface] = ACTIONS(4794),
    [anon_sym_endprogram] = ACTIONS(4794),
    [anon_sym_program] = ACTIONS(4794),
    [anon_sym_checker] = ACTIONS(4794),
    [anon_sym_virtual] = ACTIONS(4794),
    [anon_sym_class] = ACTIONS(4794),
    [anon_sym_package] = ACTIONS(4794),
    [anon_sym_endpackage] = ACTIONS(4794),
    [anon_sym_timeunit] = ACTIONS(4794),
    [anon_sym_timeprecision] = ACTIONS(4794),
    [anon_sym_type] = ACTIONS(4794),
    [anon_sym_input] = ACTIONS(4794),
    [anon_sym_output] = ACTIONS(4794),
    [anon_sym_inout] = ACTIONS(4794),
    [anon_sym_ref] = ACTIONS(4794),
    [anon_sym_DOLLARfatal] = ACTIONS(4792),
    [anon_sym_DOLLARerror] = ACTIONS(4792),
    [anon_sym_DOLLARwarning] = ACTIONS(4792),
    [anon_sym_DOLLARinfo] = ACTIONS(4792),
    [anon_sym_default] = ACTIONS(4794),
    [anon_sym_clocking] = ACTIONS(4794),
    [anon_sym_defparam] = ACTIONS(4794),
    [anon_sym_bind] = ACTIONS(4794),
    [anon_sym_const] = ACTIONS(4794),
    [anon_sym_function] = ACTIONS(4794),
    [anon_sym_static] = ACTIONS(4794),
    [anon_sym_constraint] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4794),
    [anon_sym_else] = ACTIONS(4794),
    [anon_sym_LBRACK] = ACTIONS(4792),
    [anon_sym_localparam] = ACTIONS(4794),
    [anon_sym_parameter] = ACTIONS(4794),
    [anon_sym_specparam] = ACTIONS(4794),
    [anon_sym_var] = ACTIONS(4794),
    [anon_sym_import] = ACTIONS(4794),
    [anon_sym_export] = ACTIONS(4794),
    [anon_sym_genvar] = ACTIONS(4794),
    [anon_sym_interconnect] = ACTIONS(4794),
    [anon_sym_typedef] = ACTIONS(4794),
    [anon_sym_enum] = ACTIONS(4794),
    [anon_sym_struct] = ACTIONS(4794),
    [anon_sym_union] = ACTIONS(4794),
    [anon_sym_nettype] = ACTIONS(4794),
    [anon_sym_automatic] = ACTIONS(4794),
    [anon_sym_string] = ACTIONS(4794),
    [anon_sym_chandle] = ACTIONS(4794),
    [anon_sym_event] = ACTIONS(4794),
    [anon_sym_byte] = ACTIONS(4794),
    [anon_sym_shortint] = ACTIONS(4794),
    [anon_sym_int] = ACTIONS(4794),
    [anon_sym_longint] = ACTIONS(4794),
    [anon_sym_integer] = ACTIONS(4794),
    [anon_sym_time] = ACTIONS(4794),
    [anon_sym_bit] = ACTIONS(4794),
    [anon_sym_logic] = ACTIONS(4794),
    [anon_sym_reg] = ACTIONS(4794),
    [anon_sym_shortreal] = ACTIONS(4794),
    [anon_sym_real] = ACTIONS(4794),
    [anon_sym_realtime] = ACTIONS(4794),
    [anon_sym_supply0] = ACTIONS(4794),
    [anon_sym_supply1] = ACTIONS(4794),
    [anon_sym_signed] = ACTIONS(4794),
    [anon_sym_unsigned] = ACTIONS(4794),
    [anon_sym_task] = ACTIONS(4794),
    [anon_sym_modport] = ACTIONS(4794),
    [anon_sym_assert] = ACTIONS(4794),
    [anon_sym_property] = ACTIONS(4794),
    [anon_sym_assume] = ACTIONS(4794),
    [anon_sym_cover] = ACTIONS(4794),
    [anon_sym_sequence] = ACTIONS(4794),
    [anon_sym_restrict] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4794),
    [anon_sym_or] = ACTIONS(4794),
    [anon_sym_and] = ACTIONS(4794),
    [anon_sym_case] = ACTIONS(4794),
    [anon_sym_always] = ACTIONS(4794),
    [anon_sym_covergroup] = ACTIONS(4794),
    [anon_sym_let] = ACTIONS(4794),
    [anon_sym_pulldown] = ACTIONS(4794),
    [anon_sym_pullup] = ACTIONS(4794),
    [anon_sym_cmos] = ACTIONS(4794),
    [anon_sym_rcmos] = ACTIONS(4794),
    [anon_sym_bufif0] = ACTIONS(4794),
    [anon_sym_bufif1] = ACTIONS(4794),
    [anon_sym_notif0] = ACTIONS(4794),
    [anon_sym_notif1] = ACTIONS(4794),
    [anon_sym_nmos] = ACTIONS(4794),
    [anon_sym_pmos] = ACTIONS(4794),
    [anon_sym_rnmos] = ACTIONS(4794),
    [anon_sym_rpmos] = ACTIONS(4794),
    [anon_sym_nand] = ACTIONS(4794),
    [anon_sym_nor] = ACTIONS(4794),
    [anon_sym_xor] = ACTIONS(4794),
    [anon_sym_xnor] = ACTIONS(4794),
    [anon_sym_buf] = ACTIONS(4794),
    [anon_sym_tranif0] = ACTIONS(4794),
    [anon_sym_tranif1] = ACTIONS(4794),
    [anon_sym_rtranif1] = ACTIONS(4794),
    [anon_sym_rtranif0] = ACTIONS(4794),
    [anon_sym_tran] = ACTIONS(4794),
    [anon_sym_rtran] = ACTIONS(4794),
    [anon_sym_generate] = ACTIONS(4794),
    [anon_sym_for] = ACTIONS(4794),
    [anon_sym_primitive] = ACTIONS(4794),
    [anon_sym_initial] = ACTIONS(4794),
    [anon_sym_assign] = ACTIONS(4794),
    [anon_sym_alias] = ACTIONS(4794),
    [anon_sym_always_comb] = ACTIONS(4794),
    [anon_sym_always_latch] = ACTIONS(4794),
    [anon_sym_always_ff] = ACTIONS(4794),
    [anon_sym_final] = ACTIONS(4794),
    [anon_sym_global] = ACTIONS(4794),
    [anon_sym_specify] = ACTIONS(4794),
    [anon_sym_LPAREN_STAR] = ACTIONS(4792),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4792),
    [anon_sym_DOLLARunit] = ACTIONS(4792),
  },
  [764] = {
    [ts_builtin_sym_end] = ACTIONS(4798),
    [sym_simple_identifier] = ACTIONS(4800),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4798),
    [anon_sym_BQUOTE] = ACTIONS(4800),
    [aux_sym_id_directive_token1] = ACTIONS(4798),
    [aux_sym_id_directive_token2] = ACTIONS(4798),
    [aux_sym_id_directive_token3] = ACTIONS(4798),
    [aux_sym_id_directive_token4] = ACTIONS(4800),
    [aux_sym_zero_directive_token1] = ACTIONS(4798),
    [aux_sym_zero_directive_token2] = ACTIONS(4798),
    [aux_sym_zero_directive_token3] = ACTIONS(4798),
    [aux_sym_zero_directive_token4] = ACTIONS(4798),
    [aux_sym_zero_directive_token5] = ACTIONS(4798),
    [aux_sym_zero_directive_token6] = ACTIONS(4798),
    [aux_sym_zero_directive_token7] = ACTIONS(4798),
    [aux_sym_zero_directive_token8] = ACTIONS(4798),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4798),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4798),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_begin_keywords_token1] = ACTIONS(4798),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_endmodule] = ACTIONS(4800),
    [anon_sym_COLON] = ACTIONS(4802),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_module] = ACTIONS(4800),
    [anon_sym_macromodule] = ACTIONS(4800),
    [anon_sym_endinterface] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_endprogram] = ACTIONS(4800),
    [anon_sym_program] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_package] = ACTIONS(4800),
    [anon_sym_endpackage] = ACTIONS(4800),
    [anon_sym_timeunit] = ACTIONS(4800),
    [anon_sym_timeprecision] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_input] = ACTIONS(4800),
    [anon_sym_output] = ACTIONS(4800),
    [anon_sym_inout] = ACTIONS(4800),
    [anon_sym_ref] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_specparam] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_modport] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_primitive] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_specify] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [765] = {
    [ts_builtin_sym_end] = ACTIONS(4804),
    [sym_simple_identifier] = ACTIONS(4806),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4804),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4804),
    [anon_sym_BQUOTE] = ACTIONS(4806),
    [aux_sym_id_directive_token1] = ACTIONS(4804),
    [aux_sym_id_directive_token2] = ACTIONS(4804),
    [aux_sym_id_directive_token3] = ACTIONS(4804),
    [aux_sym_id_directive_token4] = ACTIONS(4806),
    [aux_sym_zero_directive_token1] = ACTIONS(4804),
    [aux_sym_zero_directive_token2] = ACTIONS(4804),
    [aux_sym_zero_directive_token3] = ACTIONS(4804),
    [aux_sym_zero_directive_token4] = ACTIONS(4804),
    [aux_sym_zero_directive_token5] = ACTIONS(4804),
    [aux_sym_zero_directive_token6] = ACTIONS(4804),
    [aux_sym_zero_directive_token7] = ACTIONS(4804),
    [aux_sym_zero_directive_token8] = ACTIONS(4804),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4804),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4804),
    [anon_sym_wire] = ACTIONS(4806),
    [anon_sym_tri] = ACTIONS(4806),
    [anon_sym_tri0] = ACTIONS(4806),
    [anon_sym_tri1] = ACTIONS(4806),
    [anon_sym_wand] = ACTIONS(4806),
    [anon_sym_triand] = ACTIONS(4806),
    [anon_sym_wor] = ACTIONS(4806),
    [anon_sym_trior] = ACTIONS(4806),
    [anon_sym_trireg] = ACTIONS(4806),
    [anon_sym_uwire] = ACTIONS(4806),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4804),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4804),
    [aux_sym_begin_keywords_token1] = ACTIONS(4804),
    [anon_sym_SEMI] = ACTIONS(4804),
    [anon_sym_endmodule] = ACTIONS(4806),
    [anon_sym_COLON] = ACTIONS(4808),
    [anon_sym_extern] = ACTIONS(4806),
    [anon_sym_module] = ACTIONS(4806),
    [anon_sym_macromodule] = ACTIONS(4806),
    [anon_sym_endinterface] = ACTIONS(4806),
    [anon_sym_interface] = ACTIONS(4806),
    [anon_sym_endprogram] = ACTIONS(4806),
    [anon_sym_program] = ACTIONS(4806),
    [anon_sym_checker] = ACTIONS(4806),
    [anon_sym_virtual] = ACTIONS(4806),
    [anon_sym_class] = ACTIONS(4806),
    [anon_sym_package] = ACTIONS(4806),
    [anon_sym_endpackage] = ACTIONS(4806),
    [anon_sym_timeunit] = ACTIONS(4806),
    [anon_sym_timeprecision] = ACTIONS(4806),
    [anon_sym_type] = ACTIONS(4806),
    [anon_sym_input] = ACTIONS(4806),
    [anon_sym_output] = ACTIONS(4806),
    [anon_sym_inout] = ACTIONS(4806),
    [anon_sym_ref] = ACTIONS(4806),
    [anon_sym_DOLLARfatal] = ACTIONS(4804),
    [anon_sym_DOLLARerror] = ACTIONS(4804),
    [anon_sym_DOLLARwarning] = ACTIONS(4804),
    [anon_sym_DOLLARinfo] = ACTIONS(4804),
    [anon_sym_default] = ACTIONS(4806),
    [anon_sym_clocking] = ACTIONS(4806),
    [anon_sym_defparam] = ACTIONS(4806),
    [anon_sym_bind] = ACTIONS(4806),
    [anon_sym_const] = ACTIONS(4806),
    [anon_sym_function] = ACTIONS(4806),
    [anon_sym_static] = ACTIONS(4806),
    [anon_sym_constraint] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4806),
    [anon_sym_else] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(4804),
    [anon_sym_localparam] = ACTIONS(4806),
    [anon_sym_parameter] = ACTIONS(4806),
    [anon_sym_specparam] = ACTIONS(4806),
    [anon_sym_var] = ACTIONS(4806),
    [anon_sym_import] = ACTIONS(4806),
    [anon_sym_export] = ACTIONS(4806),
    [anon_sym_genvar] = ACTIONS(4806),
    [anon_sym_interconnect] = ACTIONS(4806),
    [anon_sym_typedef] = ACTIONS(4806),
    [anon_sym_enum] = ACTIONS(4806),
    [anon_sym_struct] = ACTIONS(4806),
    [anon_sym_union] = ACTIONS(4806),
    [anon_sym_nettype] = ACTIONS(4806),
    [anon_sym_automatic] = ACTIONS(4806),
    [anon_sym_string] = ACTIONS(4806),
    [anon_sym_chandle] = ACTIONS(4806),
    [anon_sym_event] = ACTIONS(4806),
    [anon_sym_byte] = ACTIONS(4806),
    [anon_sym_shortint] = ACTIONS(4806),
    [anon_sym_int] = ACTIONS(4806),
    [anon_sym_longint] = ACTIONS(4806),
    [anon_sym_integer] = ACTIONS(4806),
    [anon_sym_time] = ACTIONS(4806),
    [anon_sym_bit] = ACTIONS(4806),
    [anon_sym_logic] = ACTIONS(4806),
    [anon_sym_reg] = ACTIONS(4806),
    [anon_sym_shortreal] = ACTIONS(4806),
    [anon_sym_real] = ACTIONS(4806),
    [anon_sym_realtime] = ACTIONS(4806),
    [anon_sym_supply0] = ACTIONS(4806),
    [anon_sym_supply1] = ACTIONS(4806),
    [anon_sym_signed] = ACTIONS(4806),
    [anon_sym_unsigned] = ACTIONS(4806),
    [anon_sym_task] = ACTIONS(4806),
    [anon_sym_modport] = ACTIONS(4806),
    [anon_sym_assert] = ACTIONS(4806),
    [anon_sym_property] = ACTIONS(4806),
    [anon_sym_assume] = ACTIONS(4806),
    [anon_sym_cover] = ACTIONS(4806),
    [anon_sym_sequence] = ACTIONS(4806),
    [anon_sym_restrict] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_case] = ACTIONS(4806),
    [anon_sym_always] = ACTIONS(4806),
    [anon_sym_covergroup] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_pulldown] = ACTIONS(4806),
    [anon_sym_pullup] = ACTIONS(4806),
    [anon_sym_cmos] = ACTIONS(4806),
    [anon_sym_rcmos] = ACTIONS(4806),
    [anon_sym_bufif0] = ACTIONS(4806),
    [anon_sym_bufif1] = ACTIONS(4806),
    [anon_sym_notif0] = ACTIONS(4806),
    [anon_sym_notif1] = ACTIONS(4806),
    [anon_sym_nmos] = ACTIONS(4806),
    [anon_sym_pmos] = ACTIONS(4806),
    [anon_sym_rnmos] = ACTIONS(4806),
    [anon_sym_rpmos] = ACTIONS(4806),
    [anon_sym_nand] = ACTIONS(4806),
    [anon_sym_nor] = ACTIONS(4806),
    [anon_sym_xor] = ACTIONS(4806),
    [anon_sym_xnor] = ACTIONS(4806),
    [anon_sym_buf] = ACTIONS(4806),
    [anon_sym_tranif0] = ACTIONS(4806),
    [anon_sym_tranif1] = ACTIONS(4806),
    [anon_sym_rtranif1] = ACTIONS(4806),
    [anon_sym_rtranif0] = ACTIONS(4806),
    [anon_sym_tran] = ACTIONS(4806),
    [anon_sym_rtran] = ACTIONS(4806),
    [anon_sym_generate] = ACTIONS(4806),
    [anon_sym_for] = ACTIONS(4806),
    [anon_sym_primitive] = ACTIONS(4806),
    [anon_sym_initial] = ACTIONS(4806),
    [anon_sym_assign] = ACTIONS(4806),
    [anon_sym_alias] = ACTIONS(4806),
    [anon_sym_always_comb] = ACTIONS(4806),
    [anon_sym_always_latch] = ACTIONS(4806),
    [anon_sym_always_ff] = ACTIONS(4806),
    [anon_sym_final] = ACTIONS(4806),
    [anon_sym_global] = ACTIONS(4806),
    [anon_sym_specify] = ACTIONS(4806),
    [anon_sym_LPAREN_STAR] = ACTIONS(4804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4804),
    [anon_sym_DOLLARunit] = ACTIONS(4804),
  },
  [766] = {
    [ts_builtin_sym_end] = ACTIONS(4810),
    [sym_simple_identifier] = ACTIONS(4812),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4810),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4810),
    [anon_sym_BQUOTE] = ACTIONS(4812),
    [aux_sym_id_directive_token1] = ACTIONS(4810),
    [aux_sym_id_directive_token2] = ACTIONS(4810),
    [aux_sym_id_directive_token3] = ACTIONS(4810),
    [aux_sym_id_directive_token4] = ACTIONS(4812),
    [aux_sym_zero_directive_token1] = ACTIONS(4810),
    [aux_sym_zero_directive_token2] = ACTIONS(4810),
    [aux_sym_zero_directive_token3] = ACTIONS(4810),
    [aux_sym_zero_directive_token4] = ACTIONS(4810),
    [aux_sym_zero_directive_token5] = ACTIONS(4810),
    [aux_sym_zero_directive_token6] = ACTIONS(4810),
    [aux_sym_zero_directive_token7] = ACTIONS(4810),
    [aux_sym_zero_directive_token8] = ACTIONS(4810),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4810),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4810),
    [anon_sym_wire] = ACTIONS(4812),
    [anon_sym_tri] = ACTIONS(4812),
    [anon_sym_tri0] = ACTIONS(4812),
    [anon_sym_tri1] = ACTIONS(4812),
    [anon_sym_wand] = ACTIONS(4812),
    [anon_sym_triand] = ACTIONS(4812),
    [anon_sym_wor] = ACTIONS(4812),
    [anon_sym_trior] = ACTIONS(4812),
    [anon_sym_trireg] = ACTIONS(4812),
    [anon_sym_uwire] = ACTIONS(4812),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4810),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4810),
    [aux_sym_begin_keywords_token1] = ACTIONS(4810),
    [anon_sym_SEMI] = ACTIONS(4810),
    [anon_sym_endmodule] = ACTIONS(4812),
    [anon_sym_extern] = ACTIONS(4812),
    [anon_sym_module] = ACTIONS(4812),
    [anon_sym_macromodule] = ACTIONS(4812),
    [anon_sym_endinterface] = ACTIONS(4812),
    [anon_sym_interface] = ACTIONS(4812),
    [anon_sym_endprogram] = ACTIONS(4812),
    [anon_sym_program] = ACTIONS(4812),
    [anon_sym_checker] = ACTIONS(4812),
    [anon_sym_virtual] = ACTIONS(4812),
    [anon_sym_class] = ACTIONS(4812),
    [anon_sym_package] = ACTIONS(4812),
    [anon_sym_endpackage] = ACTIONS(4812),
    [anon_sym_timeunit] = ACTIONS(4812),
    [anon_sym_timeprecision] = ACTIONS(4812),
    [anon_sym_type] = ACTIONS(4812),
    [anon_sym_input] = ACTIONS(4812),
    [anon_sym_output] = ACTIONS(4812),
    [anon_sym_inout] = ACTIONS(4812),
    [anon_sym_ref] = ACTIONS(4812),
    [anon_sym_DOLLARfatal] = ACTIONS(4810),
    [anon_sym_DOLLARerror] = ACTIONS(4810),
    [anon_sym_DOLLARwarning] = ACTIONS(4810),
    [anon_sym_DOLLARinfo] = ACTIONS(4810),
    [anon_sym_default] = ACTIONS(4812),
    [anon_sym_clocking] = ACTIONS(4812),
    [anon_sym_defparam] = ACTIONS(4812),
    [anon_sym_bind] = ACTIONS(4812),
    [anon_sym_const] = ACTIONS(4812),
    [anon_sym_function] = ACTIONS(4812),
    [anon_sym_static] = ACTIONS(4812),
    [anon_sym_constraint] = ACTIONS(4812),
    [anon_sym_if] = ACTIONS(4812),
    [anon_sym_else] = ACTIONS(4812),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [anon_sym_localparam] = ACTIONS(4812),
    [anon_sym_parameter] = ACTIONS(4812),
    [anon_sym_specparam] = ACTIONS(4812),
    [anon_sym_var] = ACTIONS(4812),
    [anon_sym_import] = ACTIONS(4812),
    [anon_sym_export] = ACTIONS(4812),
    [anon_sym_genvar] = ACTIONS(4812),
    [anon_sym_interconnect] = ACTIONS(4812),
    [anon_sym_typedef] = ACTIONS(4812),
    [anon_sym_enum] = ACTIONS(4812),
    [anon_sym_struct] = ACTIONS(4812),
    [anon_sym_union] = ACTIONS(4812),
    [anon_sym_nettype] = ACTIONS(4812),
    [anon_sym_automatic] = ACTIONS(4812),
    [anon_sym_string] = ACTIONS(4812),
    [anon_sym_chandle] = ACTIONS(4812),
    [anon_sym_event] = ACTIONS(4812),
    [anon_sym_byte] = ACTIONS(4812),
    [anon_sym_shortint] = ACTIONS(4812),
    [anon_sym_int] = ACTIONS(4812),
    [anon_sym_longint] = ACTIONS(4812),
    [anon_sym_integer] = ACTIONS(4812),
    [anon_sym_time] = ACTIONS(4812),
    [anon_sym_bit] = ACTIONS(4812),
    [anon_sym_logic] = ACTIONS(4812),
    [anon_sym_reg] = ACTIONS(4812),
    [anon_sym_shortreal] = ACTIONS(4812),
    [anon_sym_real] = ACTIONS(4812),
    [anon_sym_realtime] = ACTIONS(4812),
    [anon_sym_supply0] = ACTIONS(4812),
    [anon_sym_supply1] = ACTIONS(4812),
    [anon_sym_signed] = ACTIONS(4812),
    [anon_sym_unsigned] = ACTIONS(4812),
    [anon_sym_task] = ACTIONS(4812),
    [anon_sym_modport] = ACTIONS(4812),
    [anon_sym_assert] = ACTIONS(4812),
    [anon_sym_property] = ACTIONS(4812),
    [anon_sym_assume] = ACTIONS(4812),
    [anon_sym_cover] = ACTIONS(4812),
    [anon_sym_sequence] = ACTIONS(4812),
    [anon_sym_restrict] = ACTIONS(4812),
    [anon_sym_not] = ACTIONS(4812),
    [anon_sym_or] = ACTIONS(4812),
    [anon_sym_and] = ACTIONS(4812),
    [anon_sym_case] = ACTIONS(4812),
    [anon_sym_always] = ACTIONS(4812),
    [anon_sym_covergroup] = ACTIONS(4812),
    [anon_sym_let] = ACTIONS(4812),
    [anon_sym_pulldown] = ACTIONS(4812),
    [anon_sym_pullup] = ACTIONS(4812),
    [anon_sym_cmos] = ACTIONS(4812),
    [anon_sym_rcmos] = ACTIONS(4812),
    [anon_sym_bufif0] = ACTIONS(4812),
    [anon_sym_bufif1] = ACTIONS(4812),
    [anon_sym_notif0] = ACTIONS(4812),
    [anon_sym_notif1] = ACTIONS(4812),
    [anon_sym_nmos] = ACTIONS(4812),
    [anon_sym_pmos] = ACTIONS(4812),
    [anon_sym_rnmos] = ACTIONS(4812),
    [anon_sym_rpmos] = ACTIONS(4812),
    [anon_sym_nand] = ACTIONS(4812),
    [anon_sym_nor] = ACTIONS(4812),
    [anon_sym_xor] = ACTIONS(4812),
    [anon_sym_xnor] = ACTIONS(4812),
    [anon_sym_buf] = ACTIONS(4812),
    [anon_sym_tranif0] = ACTIONS(4812),
    [anon_sym_tranif1] = ACTIONS(4812),
    [anon_sym_rtranif1] = ACTIONS(4812),
    [anon_sym_rtranif0] = ACTIONS(4812),
    [anon_sym_tran] = ACTIONS(4812),
    [anon_sym_rtran] = ACTIONS(4812),
    [anon_sym_generate] = ACTIONS(4812),
    [anon_sym_for] = ACTIONS(4812),
    [anon_sym_primitive] = ACTIONS(4812),
    [anon_sym_initial] = ACTIONS(4812),
    [anon_sym_assign] = ACTIONS(4812),
    [anon_sym_alias] = ACTIONS(4812),
    [anon_sym_always_comb] = ACTIONS(4812),
    [anon_sym_always_latch] = ACTIONS(4812),
    [anon_sym_always_ff] = ACTIONS(4812),
    [anon_sym_final] = ACTIONS(4812),
    [anon_sym_endclocking] = ACTIONS(4812),
    [anon_sym_global] = ACTIONS(4812),
    [anon_sym_specify] = ACTIONS(4812),
    [anon_sym_LPAREN_STAR] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4810),
    [anon_sym_DOLLARunit] = ACTIONS(4810),
  },
  [767] = {
    [ts_builtin_sym_end] = ACTIONS(4814),
    [sym_simple_identifier] = ACTIONS(4816),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4814),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4814),
    [anon_sym_BQUOTE] = ACTIONS(4816),
    [aux_sym_id_directive_token1] = ACTIONS(4814),
    [aux_sym_id_directive_token2] = ACTIONS(4814),
    [aux_sym_id_directive_token3] = ACTIONS(4814),
    [aux_sym_id_directive_token4] = ACTIONS(4816),
    [aux_sym_zero_directive_token1] = ACTIONS(4814),
    [aux_sym_zero_directive_token2] = ACTIONS(4814),
    [aux_sym_zero_directive_token3] = ACTIONS(4814),
    [aux_sym_zero_directive_token4] = ACTIONS(4814),
    [aux_sym_zero_directive_token5] = ACTIONS(4814),
    [aux_sym_zero_directive_token6] = ACTIONS(4814),
    [aux_sym_zero_directive_token7] = ACTIONS(4814),
    [aux_sym_zero_directive_token8] = ACTIONS(4814),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4814),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4814),
    [anon_sym_wire] = ACTIONS(4816),
    [anon_sym_tri] = ACTIONS(4816),
    [anon_sym_tri0] = ACTIONS(4816),
    [anon_sym_tri1] = ACTIONS(4816),
    [anon_sym_wand] = ACTIONS(4816),
    [anon_sym_triand] = ACTIONS(4816),
    [anon_sym_wor] = ACTIONS(4816),
    [anon_sym_trior] = ACTIONS(4816),
    [anon_sym_trireg] = ACTIONS(4816),
    [anon_sym_uwire] = ACTIONS(4816),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4814),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4814),
    [aux_sym_begin_keywords_token1] = ACTIONS(4814),
    [anon_sym_SEMI] = ACTIONS(4814),
    [anon_sym_endmodule] = ACTIONS(4816),
    [anon_sym_extern] = ACTIONS(4816),
    [anon_sym_module] = ACTIONS(4816),
    [anon_sym_macromodule] = ACTIONS(4816),
    [anon_sym_endinterface] = ACTIONS(4816),
    [anon_sym_interface] = ACTIONS(4816),
    [anon_sym_endprogram] = ACTIONS(4816),
    [anon_sym_program] = ACTIONS(4816),
    [anon_sym_checker] = ACTIONS(4816),
    [anon_sym_virtual] = ACTIONS(4816),
    [anon_sym_class] = ACTIONS(4816),
    [anon_sym_package] = ACTIONS(4816),
    [anon_sym_endpackage] = ACTIONS(4816),
    [anon_sym_timeunit] = ACTIONS(4816),
    [anon_sym_timeprecision] = ACTIONS(4816),
    [anon_sym_type] = ACTIONS(4816),
    [anon_sym_input] = ACTIONS(4816),
    [anon_sym_output] = ACTIONS(4816),
    [anon_sym_inout] = ACTIONS(4816),
    [anon_sym_ref] = ACTIONS(4816),
    [anon_sym_DOLLARfatal] = ACTIONS(4814),
    [anon_sym_DOLLARerror] = ACTIONS(4814),
    [anon_sym_DOLLARwarning] = ACTIONS(4814),
    [anon_sym_DOLLARinfo] = ACTIONS(4814),
    [anon_sym_default] = ACTIONS(4816),
    [anon_sym_clocking] = ACTIONS(4816),
    [anon_sym_defparam] = ACTIONS(4816),
    [anon_sym_bind] = ACTIONS(4816),
    [anon_sym_const] = ACTIONS(4816),
    [anon_sym_function] = ACTIONS(4816),
    [anon_sym_static] = ACTIONS(4816),
    [anon_sym_constraint] = ACTIONS(4816),
    [anon_sym_if] = ACTIONS(4816),
    [anon_sym_else] = ACTIONS(4816),
    [anon_sym_LBRACK] = ACTIONS(4814),
    [anon_sym_localparam] = ACTIONS(4816),
    [anon_sym_parameter] = ACTIONS(4816),
    [anon_sym_specparam] = ACTIONS(4816),
    [anon_sym_var] = ACTIONS(4816),
    [anon_sym_import] = ACTIONS(4816),
    [anon_sym_export] = ACTIONS(4816),
    [anon_sym_genvar] = ACTIONS(4816),
    [anon_sym_interconnect] = ACTIONS(4816),
    [anon_sym_typedef] = ACTIONS(4816),
    [anon_sym_enum] = ACTIONS(4816),
    [anon_sym_struct] = ACTIONS(4816),
    [anon_sym_union] = ACTIONS(4816),
    [anon_sym_nettype] = ACTIONS(4816),
    [anon_sym_automatic] = ACTIONS(4816),
    [anon_sym_string] = ACTIONS(4816),
    [anon_sym_chandle] = ACTIONS(4816),
    [anon_sym_event] = ACTIONS(4816),
    [anon_sym_byte] = ACTIONS(4816),
    [anon_sym_shortint] = ACTIONS(4816),
    [anon_sym_int] = ACTIONS(4816),
    [anon_sym_longint] = ACTIONS(4816),
    [anon_sym_integer] = ACTIONS(4816),
    [anon_sym_time] = ACTIONS(4816),
    [anon_sym_bit] = ACTIONS(4816),
    [anon_sym_logic] = ACTIONS(4816),
    [anon_sym_reg] = ACTIONS(4816),
    [anon_sym_shortreal] = ACTIONS(4816),
    [anon_sym_real] = ACTIONS(4816),
    [anon_sym_realtime] = ACTIONS(4816),
    [anon_sym_supply0] = ACTIONS(4816),
    [anon_sym_supply1] = ACTIONS(4816),
    [anon_sym_signed] = ACTIONS(4816),
    [anon_sym_unsigned] = ACTIONS(4816),
    [anon_sym_task] = ACTIONS(4816),
    [anon_sym_modport] = ACTIONS(4816),
    [anon_sym_assert] = ACTIONS(4816),
    [anon_sym_property] = ACTIONS(4816),
    [anon_sym_assume] = ACTIONS(4816),
    [anon_sym_cover] = ACTIONS(4816),
    [anon_sym_sequence] = ACTIONS(4816),
    [anon_sym_restrict] = ACTIONS(4816),
    [anon_sym_not] = ACTIONS(4816),
    [anon_sym_or] = ACTIONS(4816),
    [anon_sym_and] = ACTIONS(4816),
    [anon_sym_case] = ACTIONS(4816),
    [anon_sym_always] = ACTIONS(4816),
    [anon_sym_covergroup] = ACTIONS(4816),
    [anon_sym_let] = ACTIONS(4816),
    [anon_sym_pulldown] = ACTIONS(4816),
    [anon_sym_pullup] = ACTIONS(4816),
    [anon_sym_cmos] = ACTIONS(4816),
    [anon_sym_rcmos] = ACTIONS(4816),
    [anon_sym_bufif0] = ACTIONS(4816),
    [anon_sym_bufif1] = ACTIONS(4816),
    [anon_sym_notif0] = ACTIONS(4816),
    [anon_sym_notif1] = ACTIONS(4816),
    [anon_sym_nmos] = ACTIONS(4816),
    [anon_sym_pmos] = ACTIONS(4816),
    [anon_sym_rnmos] = ACTIONS(4816),
    [anon_sym_rpmos] = ACTIONS(4816),
    [anon_sym_nand] = ACTIONS(4816),
    [anon_sym_nor] = ACTIONS(4816),
    [anon_sym_xor] = ACTIONS(4816),
    [anon_sym_xnor] = ACTIONS(4816),
    [anon_sym_buf] = ACTIONS(4816),
    [anon_sym_tranif0] = ACTIONS(4816),
    [anon_sym_tranif1] = ACTIONS(4816),
    [anon_sym_rtranif1] = ACTIONS(4816),
    [anon_sym_rtranif0] = ACTIONS(4816),
    [anon_sym_tran] = ACTIONS(4816),
    [anon_sym_rtran] = ACTIONS(4816),
    [anon_sym_generate] = ACTIONS(4816),
    [anon_sym_for] = ACTIONS(4816),
    [anon_sym_primitive] = ACTIONS(4816),
    [anon_sym_initial] = ACTIONS(4816),
    [anon_sym_assign] = ACTIONS(4816),
    [anon_sym_alias] = ACTIONS(4816),
    [anon_sym_always_comb] = ACTIONS(4816),
    [anon_sym_always_latch] = ACTIONS(4816),
    [anon_sym_always_ff] = ACTIONS(4816),
    [anon_sym_final] = ACTIONS(4816),
    [anon_sym_global] = ACTIONS(4816),
    [anon_sym_specify] = ACTIONS(4816),
    [anon_sym_LPAREN_STAR] = ACTIONS(4814),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4814),
    [anon_sym_DOLLARunit] = ACTIONS(4814),
  },
  [768] = {
    [ts_builtin_sym_end] = ACTIONS(4818),
    [sym_simple_identifier] = ACTIONS(4820),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4818),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4818),
    [anon_sym_BQUOTE] = ACTIONS(4820),
    [aux_sym_id_directive_token1] = ACTIONS(4818),
    [aux_sym_id_directive_token2] = ACTIONS(4818),
    [aux_sym_id_directive_token3] = ACTIONS(4818),
    [aux_sym_id_directive_token4] = ACTIONS(4820),
    [aux_sym_zero_directive_token1] = ACTIONS(4818),
    [aux_sym_zero_directive_token2] = ACTIONS(4818),
    [aux_sym_zero_directive_token3] = ACTIONS(4818),
    [aux_sym_zero_directive_token4] = ACTIONS(4818),
    [aux_sym_zero_directive_token5] = ACTIONS(4818),
    [aux_sym_zero_directive_token6] = ACTIONS(4818),
    [aux_sym_zero_directive_token7] = ACTIONS(4818),
    [aux_sym_zero_directive_token8] = ACTIONS(4818),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4818),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4818),
    [anon_sym_wire] = ACTIONS(4820),
    [anon_sym_tri] = ACTIONS(4820),
    [anon_sym_tri0] = ACTIONS(4820),
    [anon_sym_tri1] = ACTIONS(4820),
    [anon_sym_wand] = ACTIONS(4820),
    [anon_sym_triand] = ACTIONS(4820),
    [anon_sym_wor] = ACTIONS(4820),
    [anon_sym_trior] = ACTIONS(4820),
    [anon_sym_trireg] = ACTIONS(4820),
    [anon_sym_uwire] = ACTIONS(4820),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4818),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4818),
    [aux_sym_begin_keywords_token1] = ACTIONS(4818),
    [anon_sym_SEMI] = ACTIONS(4818),
    [anon_sym_endmodule] = ACTIONS(4820),
    [anon_sym_extern] = ACTIONS(4820),
    [anon_sym_module] = ACTIONS(4820),
    [anon_sym_macromodule] = ACTIONS(4820),
    [anon_sym_endinterface] = ACTIONS(4820),
    [anon_sym_interface] = ACTIONS(4820),
    [anon_sym_endprogram] = ACTIONS(4820),
    [anon_sym_program] = ACTIONS(4820),
    [anon_sym_checker] = ACTIONS(4820),
    [anon_sym_virtual] = ACTIONS(4820),
    [anon_sym_class] = ACTIONS(4820),
    [anon_sym_package] = ACTIONS(4820),
    [anon_sym_endpackage] = ACTIONS(4820),
    [anon_sym_timeunit] = ACTIONS(4820),
    [anon_sym_timeprecision] = ACTIONS(4820),
    [anon_sym_type] = ACTIONS(4820),
    [anon_sym_input] = ACTIONS(4820),
    [anon_sym_output] = ACTIONS(4820),
    [anon_sym_inout] = ACTIONS(4820),
    [anon_sym_ref] = ACTIONS(4820),
    [anon_sym_DOLLARfatal] = ACTIONS(4818),
    [anon_sym_DOLLARerror] = ACTIONS(4818),
    [anon_sym_DOLLARwarning] = ACTIONS(4818),
    [anon_sym_DOLLARinfo] = ACTIONS(4818),
    [anon_sym_default] = ACTIONS(4820),
    [anon_sym_clocking] = ACTIONS(4820),
    [anon_sym_defparam] = ACTIONS(4820),
    [anon_sym_bind] = ACTIONS(4820),
    [anon_sym_const] = ACTIONS(4820),
    [anon_sym_function] = ACTIONS(4820),
    [anon_sym_static] = ACTIONS(4820),
    [anon_sym_constraint] = ACTIONS(4820),
    [anon_sym_if] = ACTIONS(4820),
    [anon_sym_else] = ACTIONS(4820),
    [anon_sym_LBRACK] = ACTIONS(4818),
    [anon_sym_localparam] = ACTIONS(4820),
    [anon_sym_parameter] = ACTIONS(4820),
    [anon_sym_specparam] = ACTIONS(4820),
    [anon_sym_var] = ACTIONS(4820),
    [anon_sym_import] = ACTIONS(4820),
    [anon_sym_export] = ACTIONS(4820),
    [anon_sym_genvar] = ACTIONS(4820),
    [anon_sym_interconnect] = ACTIONS(4820),
    [anon_sym_typedef] = ACTIONS(4820),
    [anon_sym_enum] = ACTIONS(4820),
    [anon_sym_struct] = ACTIONS(4820),
    [anon_sym_union] = ACTIONS(4820),
    [anon_sym_nettype] = ACTIONS(4820),
    [anon_sym_automatic] = ACTIONS(4820),
    [anon_sym_string] = ACTIONS(4820),
    [anon_sym_chandle] = ACTIONS(4820),
    [anon_sym_event] = ACTIONS(4820),
    [anon_sym_byte] = ACTIONS(4820),
    [anon_sym_shortint] = ACTIONS(4820),
    [anon_sym_int] = ACTIONS(4820),
    [anon_sym_longint] = ACTIONS(4820),
    [anon_sym_integer] = ACTIONS(4820),
    [anon_sym_time] = ACTIONS(4820),
    [anon_sym_bit] = ACTIONS(4820),
    [anon_sym_logic] = ACTIONS(4820),
    [anon_sym_reg] = ACTIONS(4820),
    [anon_sym_shortreal] = ACTIONS(4820),
    [anon_sym_real] = ACTIONS(4820),
    [anon_sym_realtime] = ACTIONS(4820),
    [anon_sym_supply0] = ACTIONS(4820),
    [anon_sym_supply1] = ACTIONS(4820),
    [anon_sym_signed] = ACTIONS(4820),
    [anon_sym_unsigned] = ACTIONS(4820),
    [anon_sym_task] = ACTIONS(4820),
    [anon_sym_modport] = ACTIONS(4820),
    [anon_sym_assert] = ACTIONS(4820),
    [anon_sym_property] = ACTIONS(4820),
    [anon_sym_assume] = ACTIONS(4820),
    [anon_sym_cover] = ACTIONS(4820),
    [anon_sym_sequence] = ACTIONS(4820),
    [anon_sym_restrict] = ACTIONS(4820),
    [anon_sym_not] = ACTIONS(4820),
    [anon_sym_or] = ACTIONS(4820),
    [anon_sym_and] = ACTIONS(4820),
    [anon_sym_case] = ACTIONS(4820),
    [anon_sym_always] = ACTIONS(4820),
    [anon_sym_covergroup] = ACTIONS(4820),
    [anon_sym_let] = ACTIONS(4820),
    [anon_sym_pulldown] = ACTIONS(4820),
    [anon_sym_pullup] = ACTIONS(4820),
    [anon_sym_cmos] = ACTIONS(4820),
    [anon_sym_rcmos] = ACTIONS(4820),
    [anon_sym_bufif0] = ACTIONS(4820),
    [anon_sym_bufif1] = ACTIONS(4820),
    [anon_sym_notif0] = ACTIONS(4820),
    [anon_sym_notif1] = ACTIONS(4820),
    [anon_sym_nmos] = ACTIONS(4820),
    [anon_sym_pmos] = ACTIONS(4820),
    [anon_sym_rnmos] = ACTIONS(4820),
    [anon_sym_rpmos] = ACTIONS(4820),
    [anon_sym_nand] = ACTIONS(4820),
    [anon_sym_nor] = ACTIONS(4820),
    [anon_sym_xor] = ACTIONS(4820),
    [anon_sym_xnor] = ACTIONS(4820),
    [anon_sym_buf] = ACTIONS(4820),
    [anon_sym_tranif0] = ACTIONS(4820),
    [anon_sym_tranif1] = ACTIONS(4820),
    [anon_sym_rtranif1] = ACTIONS(4820),
    [anon_sym_rtranif0] = ACTIONS(4820),
    [anon_sym_tran] = ACTIONS(4820),
    [anon_sym_rtran] = ACTIONS(4820),
    [anon_sym_generate] = ACTIONS(4820),
    [anon_sym_for] = ACTIONS(4820),
    [anon_sym_primitive] = ACTIONS(4820),
    [anon_sym_initial] = ACTIONS(4820),
    [anon_sym_assign] = ACTIONS(4820),
    [anon_sym_alias] = ACTIONS(4820),
    [anon_sym_always_comb] = ACTIONS(4820),
    [anon_sym_always_latch] = ACTIONS(4820),
    [anon_sym_always_ff] = ACTIONS(4820),
    [anon_sym_final] = ACTIONS(4820),
    [anon_sym_global] = ACTIONS(4820),
    [anon_sym_specify] = ACTIONS(4820),
    [anon_sym_LPAREN_STAR] = ACTIONS(4818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4818),
    [anon_sym_DOLLARunit] = ACTIONS(4818),
  },
  [769] = {
    [ts_builtin_sym_end] = ACTIONS(4522),
    [sym_simple_identifier] = ACTIONS(4524),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4522),
    [anon_sym_BQUOTE] = ACTIONS(4524),
    [aux_sym_id_directive_token1] = ACTIONS(4522),
    [aux_sym_id_directive_token2] = ACTIONS(4522),
    [aux_sym_id_directive_token3] = ACTIONS(4522),
    [aux_sym_id_directive_token4] = ACTIONS(4524),
    [aux_sym_zero_directive_token1] = ACTIONS(4522),
    [aux_sym_zero_directive_token2] = ACTIONS(4522),
    [aux_sym_zero_directive_token3] = ACTIONS(4522),
    [aux_sym_zero_directive_token4] = ACTIONS(4522),
    [aux_sym_zero_directive_token5] = ACTIONS(4522),
    [aux_sym_zero_directive_token6] = ACTIONS(4522),
    [aux_sym_zero_directive_token7] = ACTIONS(4522),
    [aux_sym_zero_directive_token8] = ACTIONS(4522),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4522),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4522),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4522),
    [aux_sym_begin_keywords_token1] = ACTIONS(4522),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_endmodule] = ACTIONS(4524),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_module] = ACTIONS(4524),
    [anon_sym_macromodule] = ACTIONS(4524),
    [anon_sym_endinterface] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_endprogram] = ACTIONS(4524),
    [anon_sym_program] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_package] = ACTIONS(4524),
    [anon_sym_endpackage] = ACTIONS(4524),
    [anon_sym_timeunit] = ACTIONS(4524),
    [anon_sym_timeprecision] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_input] = ACTIONS(4524),
    [anon_sym_output] = ACTIONS(4524),
    [anon_sym_inout] = ACTIONS(4524),
    [anon_sym_ref] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_specparam] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_modport] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_primitive] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_specify] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [770] = {
    [ts_builtin_sym_end] = ACTIONS(4822),
    [sym_simple_identifier] = ACTIONS(4824),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4822),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4822),
    [anon_sym_BQUOTE] = ACTIONS(4824),
    [aux_sym_id_directive_token1] = ACTIONS(4822),
    [aux_sym_id_directive_token2] = ACTIONS(4822),
    [aux_sym_id_directive_token3] = ACTIONS(4822),
    [aux_sym_id_directive_token4] = ACTIONS(4824),
    [aux_sym_zero_directive_token1] = ACTIONS(4822),
    [aux_sym_zero_directive_token2] = ACTIONS(4822),
    [aux_sym_zero_directive_token3] = ACTIONS(4822),
    [aux_sym_zero_directive_token4] = ACTIONS(4822),
    [aux_sym_zero_directive_token5] = ACTIONS(4822),
    [aux_sym_zero_directive_token6] = ACTIONS(4822),
    [aux_sym_zero_directive_token7] = ACTIONS(4822),
    [aux_sym_zero_directive_token8] = ACTIONS(4822),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4822),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4822),
    [anon_sym_wire] = ACTIONS(4824),
    [anon_sym_tri] = ACTIONS(4824),
    [anon_sym_tri0] = ACTIONS(4824),
    [anon_sym_tri1] = ACTIONS(4824),
    [anon_sym_wand] = ACTIONS(4824),
    [anon_sym_triand] = ACTIONS(4824),
    [anon_sym_wor] = ACTIONS(4824),
    [anon_sym_trior] = ACTIONS(4824),
    [anon_sym_trireg] = ACTIONS(4824),
    [anon_sym_uwire] = ACTIONS(4824),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4822),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4822),
    [aux_sym_begin_keywords_token1] = ACTIONS(4822),
    [anon_sym_SEMI] = ACTIONS(4822),
    [anon_sym_endmodule] = ACTIONS(4824),
    [anon_sym_extern] = ACTIONS(4824),
    [anon_sym_module] = ACTIONS(4824),
    [anon_sym_macromodule] = ACTIONS(4824),
    [anon_sym_endinterface] = ACTIONS(4824),
    [anon_sym_interface] = ACTIONS(4824),
    [anon_sym_endprogram] = ACTIONS(4824),
    [anon_sym_program] = ACTIONS(4824),
    [anon_sym_checker] = ACTIONS(4824),
    [anon_sym_virtual] = ACTIONS(4824),
    [anon_sym_class] = ACTIONS(4824),
    [anon_sym_package] = ACTIONS(4824),
    [anon_sym_endpackage] = ACTIONS(4824),
    [anon_sym_timeunit] = ACTIONS(4824),
    [anon_sym_timeprecision] = ACTIONS(4824),
    [anon_sym_type] = ACTIONS(4824),
    [anon_sym_input] = ACTIONS(4824),
    [anon_sym_output] = ACTIONS(4824),
    [anon_sym_inout] = ACTIONS(4824),
    [anon_sym_ref] = ACTIONS(4824),
    [anon_sym_DOLLARfatal] = ACTIONS(4822),
    [anon_sym_DOLLARerror] = ACTIONS(4822),
    [anon_sym_DOLLARwarning] = ACTIONS(4822),
    [anon_sym_DOLLARinfo] = ACTIONS(4822),
    [anon_sym_default] = ACTIONS(4824),
    [anon_sym_clocking] = ACTIONS(4824),
    [anon_sym_defparam] = ACTIONS(4824),
    [anon_sym_bind] = ACTIONS(4824),
    [anon_sym_const] = ACTIONS(4824),
    [anon_sym_function] = ACTIONS(4824),
    [anon_sym_static] = ACTIONS(4824),
    [anon_sym_constraint] = ACTIONS(4824),
    [anon_sym_if] = ACTIONS(4824),
    [anon_sym_else] = ACTIONS(4824),
    [anon_sym_LBRACK] = ACTIONS(4822),
    [anon_sym_localparam] = ACTIONS(4824),
    [anon_sym_parameter] = ACTIONS(4824),
    [anon_sym_specparam] = ACTIONS(4824),
    [anon_sym_var] = ACTIONS(4824),
    [anon_sym_import] = ACTIONS(4824),
    [anon_sym_export] = ACTIONS(4824),
    [anon_sym_genvar] = ACTIONS(4824),
    [anon_sym_interconnect] = ACTIONS(4824),
    [anon_sym_typedef] = ACTIONS(4824),
    [anon_sym_enum] = ACTIONS(4824),
    [anon_sym_struct] = ACTIONS(4824),
    [anon_sym_union] = ACTIONS(4824),
    [anon_sym_nettype] = ACTIONS(4824),
    [anon_sym_automatic] = ACTIONS(4824),
    [anon_sym_string] = ACTIONS(4824),
    [anon_sym_chandle] = ACTIONS(4824),
    [anon_sym_event] = ACTIONS(4824),
    [anon_sym_byte] = ACTIONS(4824),
    [anon_sym_shortint] = ACTIONS(4824),
    [anon_sym_int] = ACTIONS(4824),
    [anon_sym_longint] = ACTIONS(4824),
    [anon_sym_integer] = ACTIONS(4824),
    [anon_sym_time] = ACTIONS(4824),
    [anon_sym_bit] = ACTIONS(4824),
    [anon_sym_logic] = ACTIONS(4824),
    [anon_sym_reg] = ACTIONS(4824),
    [anon_sym_shortreal] = ACTIONS(4824),
    [anon_sym_real] = ACTIONS(4824),
    [anon_sym_realtime] = ACTIONS(4824),
    [anon_sym_supply0] = ACTIONS(4824),
    [anon_sym_supply1] = ACTIONS(4824),
    [anon_sym_signed] = ACTIONS(4824),
    [anon_sym_unsigned] = ACTIONS(4824),
    [anon_sym_task] = ACTIONS(4824),
    [anon_sym_modport] = ACTIONS(4824),
    [anon_sym_assert] = ACTIONS(4824),
    [anon_sym_property] = ACTIONS(4824),
    [anon_sym_assume] = ACTIONS(4824),
    [anon_sym_cover] = ACTIONS(4824),
    [anon_sym_sequence] = ACTIONS(4824),
    [anon_sym_restrict] = ACTIONS(4824),
    [anon_sym_not] = ACTIONS(4824),
    [anon_sym_or] = ACTIONS(4824),
    [anon_sym_and] = ACTIONS(4824),
    [anon_sym_case] = ACTIONS(4824),
    [anon_sym_always] = ACTIONS(4824),
    [anon_sym_covergroup] = ACTIONS(4824),
    [anon_sym_let] = ACTIONS(4824),
    [anon_sym_pulldown] = ACTIONS(4824),
    [anon_sym_pullup] = ACTIONS(4824),
    [anon_sym_cmos] = ACTIONS(4824),
    [anon_sym_rcmos] = ACTIONS(4824),
    [anon_sym_bufif0] = ACTIONS(4824),
    [anon_sym_bufif1] = ACTIONS(4824),
    [anon_sym_notif0] = ACTIONS(4824),
    [anon_sym_notif1] = ACTIONS(4824),
    [anon_sym_nmos] = ACTIONS(4824),
    [anon_sym_pmos] = ACTIONS(4824),
    [anon_sym_rnmos] = ACTIONS(4824),
    [anon_sym_rpmos] = ACTIONS(4824),
    [anon_sym_nand] = ACTIONS(4824),
    [anon_sym_nor] = ACTIONS(4824),
    [anon_sym_xor] = ACTIONS(4824),
    [anon_sym_xnor] = ACTIONS(4824),
    [anon_sym_buf] = ACTIONS(4824),
    [anon_sym_tranif0] = ACTIONS(4824),
    [anon_sym_tranif1] = ACTIONS(4824),
    [anon_sym_rtranif1] = ACTIONS(4824),
    [anon_sym_rtranif0] = ACTIONS(4824),
    [anon_sym_tran] = ACTIONS(4824),
    [anon_sym_rtran] = ACTIONS(4824),
    [anon_sym_generate] = ACTIONS(4824),
    [anon_sym_for] = ACTIONS(4824),
    [anon_sym_primitive] = ACTIONS(4824),
    [anon_sym_initial] = ACTIONS(4824),
    [anon_sym_assign] = ACTIONS(4824),
    [anon_sym_alias] = ACTIONS(4824),
    [anon_sym_always_comb] = ACTIONS(4824),
    [anon_sym_always_latch] = ACTIONS(4824),
    [anon_sym_always_ff] = ACTIONS(4824),
    [anon_sym_final] = ACTIONS(4824),
    [anon_sym_global] = ACTIONS(4824),
    [anon_sym_specify] = ACTIONS(4824),
    [anon_sym_LPAREN_STAR] = ACTIONS(4822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4822),
    [anon_sym_DOLLARunit] = ACTIONS(4822),
  },
  [771] = {
    [ts_builtin_sym_end] = ACTIONS(4826),
    [sym_simple_identifier] = ACTIONS(4828),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4826),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4826),
    [anon_sym_BQUOTE] = ACTIONS(4828),
    [aux_sym_id_directive_token1] = ACTIONS(4826),
    [aux_sym_id_directive_token2] = ACTIONS(4826),
    [aux_sym_id_directive_token3] = ACTIONS(4826),
    [aux_sym_id_directive_token4] = ACTIONS(4828),
    [aux_sym_zero_directive_token1] = ACTIONS(4826),
    [aux_sym_zero_directive_token2] = ACTIONS(4826),
    [aux_sym_zero_directive_token3] = ACTIONS(4826),
    [aux_sym_zero_directive_token4] = ACTIONS(4826),
    [aux_sym_zero_directive_token5] = ACTIONS(4826),
    [aux_sym_zero_directive_token6] = ACTIONS(4826),
    [aux_sym_zero_directive_token7] = ACTIONS(4826),
    [aux_sym_zero_directive_token8] = ACTIONS(4826),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4826),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4826),
    [anon_sym_wire] = ACTIONS(4828),
    [anon_sym_tri] = ACTIONS(4828),
    [anon_sym_tri0] = ACTIONS(4828),
    [anon_sym_tri1] = ACTIONS(4828),
    [anon_sym_wand] = ACTIONS(4828),
    [anon_sym_triand] = ACTIONS(4828),
    [anon_sym_wor] = ACTIONS(4828),
    [anon_sym_trior] = ACTIONS(4828),
    [anon_sym_trireg] = ACTIONS(4828),
    [anon_sym_uwire] = ACTIONS(4828),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4826),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4826),
    [aux_sym_begin_keywords_token1] = ACTIONS(4826),
    [anon_sym_SEMI] = ACTIONS(4826),
    [anon_sym_endmodule] = ACTIONS(4828),
    [anon_sym_extern] = ACTIONS(4828),
    [anon_sym_module] = ACTIONS(4828),
    [anon_sym_macromodule] = ACTIONS(4828),
    [anon_sym_endinterface] = ACTIONS(4828),
    [anon_sym_interface] = ACTIONS(4828),
    [anon_sym_endprogram] = ACTIONS(4828),
    [anon_sym_program] = ACTIONS(4828),
    [anon_sym_checker] = ACTIONS(4828),
    [anon_sym_virtual] = ACTIONS(4828),
    [anon_sym_class] = ACTIONS(4828),
    [anon_sym_package] = ACTIONS(4828),
    [anon_sym_endpackage] = ACTIONS(4828),
    [anon_sym_timeunit] = ACTIONS(4828),
    [anon_sym_timeprecision] = ACTIONS(4828),
    [anon_sym_type] = ACTIONS(4828),
    [anon_sym_input] = ACTIONS(4828),
    [anon_sym_output] = ACTIONS(4828),
    [anon_sym_inout] = ACTIONS(4828),
    [anon_sym_ref] = ACTIONS(4828),
    [anon_sym_DOLLARfatal] = ACTIONS(4826),
    [anon_sym_DOLLARerror] = ACTIONS(4826),
    [anon_sym_DOLLARwarning] = ACTIONS(4826),
    [anon_sym_DOLLARinfo] = ACTIONS(4826),
    [anon_sym_default] = ACTIONS(4828),
    [anon_sym_clocking] = ACTIONS(4828),
    [anon_sym_defparam] = ACTIONS(4828),
    [anon_sym_bind] = ACTIONS(4828),
    [anon_sym_const] = ACTIONS(4828),
    [anon_sym_function] = ACTIONS(4828),
    [anon_sym_static] = ACTIONS(4828),
    [anon_sym_constraint] = ACTIONS(4828),
    [anon_sym_if] = ACTIONS(4828),
    [anon_sym_else] = ACTIONS(4828),
    [anon_sym_LBRACK] = ACTIONS(4826),
    [anon_sym_localparam] = ACTIONS(4828),
    [anon_sym_parameter] = ACTIONS(4828),
    [anon_sym_specparam] = ACTIONS(4828),
    [anon_sym_var] = ACTIONS(4828),
    [anon_sym_import] = ACTIONS(4828),
    [anon_sym_export] = ACTIONS(4828),
    [anon_sym_genvar] = ACTIONS(4828),
    [anon_sym_interconnect] = ACTIONS(4828),
    [anon_sym_typedef] = ACTIONS(4828),
    [anon_sym_enum] = ACTIONS(4828),
    [anon_sym_struct] = ACTIONS(4828),
    [anon_sym_union] = ACTIONS(4828),
    [anon_sym_nettype] = ACTIONS(4828),
    [anon_sym_automatic] = ACTIONS(4828),
    [anon_sym_string] = ACTIONS(4828),
    [anon_sym_chandle] = ACTIONS(4828),
    [anon_sym_event] = ACTIONS(4828),
    [anon_sym_byte] = ACTIONS(4828),
    [anon_sym_shortint] = ACTIONS(4828),
    [anon_sym_int] = ACTIONS(4828),
    [anon_sym_longint] = ACTIONS(4828),
    [anon_sym_integer] = ACTIONS(4828),
    [anon_sym_time] = ACTIONS(4828),
    [anon_sym_bit] = ACTIONS(4828),
    [anon_sym_logic] = ACTIONS(4828),
    [anon_sym_reg] = ACTIONS(4828),
    [anon_sym_shortreal] = ACTIONS(4828),
    [anon_sym_real] = ACTIONS(4828),
    [anon_sym_realtime] = ACTIONS(4828),
    [anon_sym_supply0] = ACTIONS(4828),
    [anon_sym_supply1] = ACTIONS(4828),
    [anon_sym_signed] = ACTIONS(4828),
    [anon_sym_unsigned] = ACTIONS(4828),
    [anon_sym_task] = ACTIONS(4828),
    [anon_sym_modport] = ACTIONS(4828),
    [anon_sym_assert] = ACTIONS(4828),
    [anon_sym_property] = ACTIONS(4828),
    [anon_sym_assume] = ACTIONS(4828),
    [anon_sym_cover] = ACTIONS(4828),
    [anon_sym_sequence] = ACTIONS(4828),
    [anon_sym_restrict] = ACTIONS(4828),
    [anon_sym_not] = ACTIONS(4828),
    [anon_sym_or] = ACTIONS(4828),
    [anon_sym_and] = ACTIONS(4828),
    [anon_sym_case] = ACTIONS(4828),
    [anon_sym_always] = ACTIONS(4828),
    [anon_sym_covergroup] = ACTIONS(4828),
    [anon_sym_let] = ACTIONS(4828),
    [anon_sym_pulldown] = ACTIONS(4828),
    [anon_sym_pullup] = ACTIONS(4828),
    [anon_sym_cmos] = ACTIONS(4828),
    [anon_sym_rcmos] = ACTIONS(4828),
    [anon_sym_bufif0] = ACTIONS(4828),
    [anon_sym_bufif1] = ACTIONS(4828),
    [anon_sym_notif0] = ACTIONS(4828),
    [anon_sym_notif1] = ACTIONS(4828),
    [anon_sym_nmos] = ACTIONS(4828),
    [anon_sym_pmos] = ACTIONS(4828),
    [anon_sym_rnmos] = ACTIONS(4828),
    [anon_sym_rpmos] = ACTIONS(4828),
    [anon_sym_nand] = ACTIONS(4828),
    [anon_sym_nor] = ACTIONS(4828),
    [anon_sym_xor] = ACTIONS(4828),
    [anon_sym_xnor] = ACTIONS(4828),
    [anon_sym_buf] = ACTIONS(4828),
    [anon_sym_tranif0] = ACTIONS(4828),
    [anon_sym_tranif1] = ACTIONS(4828),
    [anon_sym_rtranif1] = ACTIONS(4828),
    [anon_sym_rtranif0] = ACTIONS(4828),
    [anon_sym_tran] = ACTIONS(4828),
    [anon_sym_rtran] = ACTIONS(4828),
    [anon_sym_generate] = ACTIONS(4828),
    [anon_sym_for] = ACTIONS(4828),
    [anon_sym_primitive] = ACTIONS(4828),
    [anon_sym_initial] = ACTIONS(4828),
    [anon_sym_assign] = ACTIONS(4828),
    [anon_sym_alias] = ACTIONS(4828),
    [anon_sym_always_comb] = ACTIONS(4828),
    [anon_sym_always_latch] = ACTIONS(4828),
    [anon_sym_always_ff] = ACTIONS(4828),
    [anon_sym_final] = ACTIONS(4828),
    [anon_sym_global] = ACTIONS(4828),
    [anon_sym_specify] = ACTIONS(4828),
    [anon_sym_LPAREN_STAR] = ACTIONS(4826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4826),
    [anon_sym_DOLLARunit] = ACTIONS(4826),
  },
  [772] = {
    [ts_builtin_sym_end] = ACTIONS(4830),
    [sym_simple_identifier] = ACTIONS(4832),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4830),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4830),
    [anon_sym_BQUOTE] = ACTIONS(4832),
    [aux_sym_id_directive_token1] = ACTIONS(4830),
    [aux_sym_id_directive_token2] = ACTIONS(4830),
    [aux_sym_id_directive_token3] = ACTIONS(4830),
    [aux_sym_id_directive_token4] = ACTIONS(4832),
    [aux_sym_zero_directive_token1] = ACTIONS(4830),
    [aux_sym_zero_directive_token2] = ACTIONS(4830),
    [aux_sym_zero_directive_token3] = ACTIONS(4830),
    [aux_sym_zero_directive_token4] = ACTIONS(4830),
    [aux_sym_zero_directive_token5] = ACTIONS(4830),
    [aux_sym_zero_directive_token6] = ACTIONS(4830),
    [aux_sym_zero_directive_token7] = ACTIONS(4830),
    [aux_sym_zero_directive_token8] = ACTIONS(4830),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4830),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4830),
    [anon_sym_wire] = ACTIONS(4832),
    [anon_sym_tri] = ACTIONS(4832),
    [anon_sym_tri0] = ACTIONS(4832),
    [anon_sym_tri1] = ACTIONS(4832),
    [anon_sym_wand] = ACTIONS(4832),
    [anon_sym_triand] = ACTIONS(4832),
    [anon_sym_wor] = ACTIONS(4832),
    [anon_sym_trior] = ACTIONS(4832),
    [anon_sym_trireg] = ACTIONS(4832),
    [anon_sym_uwire] = ACTIONS(4832),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4830),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4830),
    [aux_sym_begin_keywords_token1] = ACTIONS(4830),
    [anon_sym_SEMI] = ACTIONS(4830),
    [anon_sym_endmodule] = ACTIONS(4832),
    [anon_sym_extern] = ACTIONS(4832),
    [anon_sym_module] = ACTIONS(4832),
    [anon_sym_macromodule] = ACTIONS(4832),
    [anon_sym_endinterface] = ACTIONS(4832),
    [anon_sym_interface] = ACTIONS(4832),
    [anon_sym_endprogram] = ACTIONS(4832),
    [anon_sym_program] = ACTIONS(4832),
    [anon_sym_checker] = ACTIONS(4832),
    [anon_sym_virtual] = ACTIONS(4832),
    [anon_sym_class] = ACTIONS(4832),
    [anon_sym_package] = ACTIONS(4832),
    [anon_sym_endpackage] = ACTIONS(4832),
    [anon_sym_timeunit] = ACTIONS(4832),
    [anon_sym_timeprecision] = ACTIONS(4832),
    [anon_sym_type] = ACTIONS(4832),
    [anon_sym_input] = ACTIONS(4832),
    [anon_sym_output] = ACTIONS(4832),
    [anon_sym_inout] = ACTIONS(4832),
    [anon_sym_ref] = ACTIONS(4832),
    [anon_sym_DOLLARfatal] = ACTIONS(4830),
    [anon_sym_DOLLARerror] = ACTIONS(4830),
    [anon_sym_DOLLARwarning] = ACTIONS(4830),
    [anon_sym_DOLLARinfo] = ACTIONS(4830),
    [anon_sym_default] = ACTIONS(4832),
    [anon_sym_clocking] = ACTIONS(4832),
    [anon_sym_defparam] = ACTIONS(4832),
    [anon_sym_bind] = ACTIONS(4832),
    [anon_sym_const] = ACTIONS(4832),
    [anon_sym_function] = ACTIONS(4832),
    [anon_sym_static] = ACTIONS(4832),
    [anon_sym_constraint] = ACTIONS(4832),
    [anon_sym_if] = ACTIONS(4832),
    [anon_sym_else] = ACTIONS(4832),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [anon_sym_localparam] = ACTIONS(4832),
    [anon_sym_parameter] = ACTIONS(4832),
    [anon_sym_specparam] = ACTIONS(4832),
    [anon_sym_var] = ACTIONS(4832),
    [anon_sym_import] = ACTIONS(4832),
    [anon_sym_export] = ACTIONS(4832),
    [anon_sym_genvar] = ACTIONS(4832),
    [anon_sym_interconnect] = ACTIONS(4832),
    [anon_sym_typedef] = ACTIONS(4832),
    [anon_sym_enum] = ACTIONS(4832),
    [anon_sym_struct] = ACTIONS(4832),
    [anon_sym_union] = ACTIONS(4832),
    [anon_sym_nettype] = ACTIONS(4832),
    [anon_sym_automatic] = ACTIONS(4832),
    [anon_sym_string] = ACTIONS(4832),
    [anon_sym_chandle] = ACTIONS(4832),
    [anon_sym_event] = ACTIONS(4832),
    [anon_sym_byte] = ACTIONS(4832),
    [anon_sym_shortint] = ACTIONS(4832),
    [anon_sym_int] = ACTIONS(4832),
    [anon_sym_longint] = ACTIONS(4832),
    [anon_sym_integer] = ACTIONS(4832),
    [anon_sym_time] = ACTIONS(4832),
    [anon_sym_bit] = ACTIONS(4832),
    [anon_sym_logic] = ACTIONS(4832),
    [anon_sym_reg] = ACTIONS(4832),
    [anon_sym_shortreal] = ACTIONS(4832),
    [anon_sym_real] = ACTIONS(4832),
    [anon_sym_realtime] = ACTIONS(4832),
    [anon_sym_supply0] = ACTIONS(4832),
    [anon_sym_supply1] = ACTIONS(4832),
    [anon_sym_signed] = ACTIONS(4832),
    [anon_sym_unsigned] = ACTIONS(4832),
    [anon_sym_task] = ACTIONS(4832),
    [anon_sym_modport] = ACTIONS(4832),
    [anon_sym_assert] = ACTIONS(4832),
    [anon_sym_property] = ACTIONS(4832),
    [anon_sym_assume] = ACTIONS(4832),
    [anon_sym_cover] = ACTIONS(4832),
    [anon_sym_sequence] = ACTIONS(4832),
    [anon_sym_restrict] = ACTIONS(4832),
    [anon_sym_not] = ACTIONS(4832),
    [anon_sym_or] = ACTIONS(4832),
    [anon_sym_and] = ACTIONS(4832),
    [anon_sym_case] = ACTIONS(4832),
    [anon_sym_always] = ACTIONS(4832),
    [anon_sym_covergroup] = ACTIONS(4832),
    [anon_sym_let] = ACTIONS(4832),
    [anon_sym_pulldown] = ACTIONS(4832),
    [anon_sym_pullup] = ACTIONS(4832),
    [anon_sym_cmos] = ACTIONS(4832),
    [anon_sym_rcmos] = ACTIONS(4832),
    [anon_sym_bufif0] = ACTIONS(4832),
    [anon_sym_bufif1] = ACTIONS(4832),
    [anon_sym_notif0] = ACTIONS(4832),
    [anon_sym_notif1] = ACTIONS(4832),
    [anon_sym_nmos] = ACTIONS(4832),
    [anon_sym_pmos] = ACTIONS(4832),
    [anon_sym_rnmos] = ACTIONS(4832),
    [anon_sym_rpmos] = ACTIONS(4832),
    [anon_sym_nand] = ACTIONS(4832),
    [anon_sym_nor] = ACTIONS(4832),
    [anon_sym_xor] = ACTIONS(4832),
    [anon_sym_xnor] = ACTIONS(4832),
    [anon_sym_buf] = ACTIONS(4832),
    [anon_sym_tranif0] = ACTIONS(4832),
    [anon_sym_tranif1] = ACTIONS(4832),
    [anon_sym_rtranif1] = ACTIONS(4832),
    [anon_sym_rtranif0] = ACTIONS(4832),
    [anon_sym_tran] = ACTIONS(4832),
    [anon_sym_rtran] = ACTIONS(4832),
    [anon_sym_generate] = ACTIONS(4832),
    [anon_sym_for] = ACTIONS(4832),
    [anon_sym_primitive] = ACTIONS(4832),
    [anon_sym_initial] = ACTIONS(4832),
    [anon_sym_assign] = ACTIONS(4832),
    [anon_sym_alias] = ACTIONS(4832),
    [anon_sym_always_comb] = ACTIONS(4832),
    [anon_sym_always_latch] = ACTIONS(4832),
    [anon_sym_always_ff] = ACTIONS(4832),
    [anon_sym_final] = ACTIONS(4832),
    [anon_sym_global] = ACTIONS(4832),
    [anon_sym_specify] = ACTIONS(4832),
    [anon_sym_LPAREN_STAR] = ACTIONS(4830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4830),
    [anon_sym_DOLLARunit] = ACTIONS(4830),
  },
  [773] = {
    [ts_builtin_sym_end] = ACTIONS(4834),
    [sym_simple_identifier] = ACTIONS(4836),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4834),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4834),
    [anon_sym_BQUOTE] = ACTIONS(4836),
    [aux_sym_id_directive_token1] = ACTIONS(4834),
    [aux_sym_id_directive_token2] = ACTIONS(4834),
    [aux_sym_id_directive_token3] = ACTIONS(4834),
    [aux_sym_id_directive_token4] = ACTIONS(4836),
    [aux_sym_zero_directive_token1] = ACTIONS(4834),
    [aux_sym_zero_directive_token2] = ACTIONS(4834),
    [aux_sym_zero_directive_token3] = ACTIONS(4834),
    [aux_sym_zero_directive_token4] = ACTIONS(4834),
    [aux_sym_zero_directive_token5] = ACTIONS(4834),
    [aux_sym_zero_directive_token6] = ACTIONS(4834),
    [aux_sym_zero_directive_token7] = ACTIONS(4834),
    [aux_sym_zero_directive_token8] = ACTIONS(4834),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4834),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4834),
    [anon_sym_wire] = ACTIONS(4836),
    [anon_sym_tri] = ACTIONS(4836),
    [anon_sym_tri0] = ACTIONS(4836),
    [anon_sym_tri1] = ACTIONS(4836),
    [anon_sym_wand] = ACTIONS(4836),
    [anon_sym_triand] = ACTIONS(4836),
    [anon_sym_wor] = ACTIONS(4836),
    [anon_sym_trior] = ACTIONS(4836),
    [anon_sym_trireg] = ACTIONS(4836),
    [anon_sym_uwire] = ACTIONS(4836),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4834),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4834),
    [aux_sym_begin_keywords_token1] = ACTIONS(4834),
    [anon_sym_SEMI] = ACTIONS(4834),
    [anon_sym_endmodule] = ACTIONS(4836),
    [anon_sym_extern] = ACTIONS(4836),
    [anon_sym_module] = ACTIONS(4836),
    [anon_sym_macromodule] = ACTIONS(4836),
    [anon_sym_endinterface] = ACTIONS(4836),
    [anon_sym_interface] = ACTIONS(4836),
    [anon_sym_endprogram] = ACTIONS(4836),
    [anon_sym_program] = ACTIONS(4836),
    [anon_sym_checker] = ACTIONS(4836),
    [anon_sym_virtual] = ACTIONS(4836),
    [anon_sym_class] = ACTIONS(4836),
    [anon_sym_package] = ACTIONS(4836),
    [anon_sym_endpackage] = ACTIONS(4836),
    [anon_sym_timeunit] = ACTIONS(4836),
    [anon_sym_timeprecision] = ACTIONS(4836),
    [anon_sym_type] = ACTIONS(4836),
    [anon_sym_input] = ACTIONS(4836),
    [anon_sym_output] = ACTIONS(4836),
    [anon_sym_inout] = ACTIONS(4836),
    [anon_sym_ref] = ACTIONS(4836),
    [anon_sym_DOLLARfatal] = ACTIONS(4834),
    [anon_sym_DOLLARerror] = ACTIONS(4834),
    [anon_sym_DOLLARwarning] = ACTIONS(4834),
    [anon_sym_DOLLARinfo] = ACTIONS(4834),
    [anon_sym_default] = ACTIONS(4836),
    [anon_sym_clocking] = ACTIONS(4836),
    [anon_sym_defparam] = ACTIONS(4836),
    [anon_sym_bind] = ACTIONS(4836),
    [anon_sym_const] = ACTIONS(4836),
    [anon_sym_function] = ACTIONS(4836),
    [anon_sym_static] = ACTIONS(4836),
    [anon_sym_constraint] = ACTIONS(4836),
    [anon_sym_if] = ACTIONS(4836),
    [anon_sym_else] = ACTIONS(4836),
    [anon_sym_LBRACK] = ACTIONS(4834),
    [anon_sym_localparam] = ACTIONS(4836),
    [anon_sym_parameter] = ACTIONS(4836),
    [anon_sym_specparam] = ACTIONS(4836),
    [anon_sym_var] = ACTIONS(4836),
    [anon_sym_import] = ACTIONS(4836),
    [anon_sym_export] = ACTIONS(4836),
    [anon_sym_genvar] = ACTIONS(4836),
    [anon_sym_interconnect] = ACTIONS(4836),
    [anon_sym_typedef] = ACTIONS(4836),
    [anon_sym_enum] = ACTIONS(4836),
    [anon_sym_struct] = ACTIONS(4836),
    [anon_sym_union] = ACTIONS(4836),
    [anon_sym_nettype] = ACTIONS(4836),
    [anon_sym_automatic] = ACTIONS(4836),
    [anon_sym_string] = ACTIONS(4836),
    [anon_sym_chandle] = ACTIONS(4836),
    [anon_sym_event] = ACTIONS(4836),
    [anon_sym_byte] = ACTIONS(4836),
    [anon_sym_shortint] = ACTIONS(4836),
    [anon_sym_int] = ACTIONS(4836),
    [anon_sym_longint] = ACTIONS(4836),
    [anon_sym_integer] = ACTIONS(4836),
    [anon_sym_time] = ACTIONS(4836),
    [anon_sym_bit] = ACTIONS(4836),
    [anon_sym_logic] = ACTIONS(4836),
    [anon_sym_reg] = ACTIONS(4836),
    [anon_sym_shortreal] = ACTIONS(4836),
    [anon_sym_real] = ACTIONS(4836),
    [anon_sym_realtime] = ACTIONS(4836),
    [anon_sym_supply0] = ACTIONS(4836),
    [anon_sym_supply1] = ACTIONS(4836),
    [anon_sym_signed] = ACTIONS(4836),
    [anon_sym_unsigned] = ACTIONS(4836),
    [anon_sym_task] = ACTIONS(4836),
    [anon_sym_modport] = ACTIONS(4836),
    [anon_sym_assert] = ACTIONS(4836),
    [anon_sym_property] = ACTIONS(4836),
    [anon_sym_assume] = ACTIONS(4836),
    [anon_sym_cover] = ACTIONS(4836),
    [anon_sym_sequence] = ACTIONS(4836),
    [anon_sym_restrict] = ACTIONS(4836),
    [anon_sym_not] = ACTIONS(4836),
    [anon_sym_or] = ACTIONS(4836),
    [anon_sym_and] = ACTIONS(4836),
    [anon_sym_case] = ACTIONS(4836),
    [anon_sym_always] = ACTIONS(4836),
    [anon_sym_covergroup] = ACTIONS(4836),
    [anon_sym_let] = ACTIONS(4836),
    [anon_sym_pulldown] = ACTIONS(4836),
    [anon_sym_pullup] = ACTIONS(4836),
    [anon_sym_cmos] = ACTIONS(4836),
    [anon_sym_rcmos] = ACTIONS(4836),
    [anon_sym_bufif0] = ACTIONS(4836),
    [anon_sym_bufif1] = ACTIONS(4836),
    [anon_sym_notif0] = ACTIONS(4836),
    [anon_sym_notif1] = ACTIONS(4836),
    [anon_sym_nmos] = ACTIONS(4836),
    [anon_sym_pmos] = ACTIONS(4836),
    [anon_sym_rnmos] = ACTIONS(4836),
    [anon_sym_rpmos] = ACTIONS(4836),
    [anon_sym_nand] = ACTIONS(4836),
    [anon_sym_nor] = ACTIONS(4836),
    [anon_sym_xor] = ACTIONS(4836),
    [anon_sym_xnor] = ACTIONS(4836),
    [anon_sym_buf] = ACTIONS(4836),
    [anon_sym_tranif0] = ACTIONS(4836),
    [anon_sym_tranif1] = ACTIONS(4836),
    [anon_sym_rtranif1] = ACTIONS(4836),
    [anon_sym_rtranif0] = ACTIONS(4836),
    [anon_sym_tran] = ACTIONS(4836),
    [anon_sym_rtran] = ACTIONS(4836),
    [anon_sym_generate] = ACTIONS(4836),
    [anon_sym_for] = ACTIONS(4836),
    [anon_sym_primitive] = ACTIONS(4836),
    [anon_sym_initial] = ACTIONS(4836),
    [anon_sym_assign] = ACTIONS(4836),
    [anon_sym_alias] = ACTIONS(4836),
    [anon_sym_always_comb] = ACTIONS(4836),
    [anon_sym_always_latch] = ACTIONS(4836),
    [anon_sym_always_ff] = ACTIONS(4836),
    [anon_sym_final] = ACTIONS(4836),
    [anon_sym_global] = ACTIONS(4836),
    [anon_sym_specify] = ACTIONS(4836),
    [anon_sym_LPAREN_STAR] = ACTIONS(4834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4834),
    [anon_sym_DOLLARunit] = ACTIONS(4834),
  },
  [774] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19719),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19719),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(4838),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [775] = {
    [ts_builtin_sym_end] = ACTIONS(4842),
    [sym_simple_identifier] = ACTIONS(4844),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4842),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4842),
    [anon_sym_BQUOTE] = ACTIONS(4844),
    [aux_sym_id_directive_token1] = ACTIONS(4842),
    [aux_sym_id_directive_token2] = ACTIONS(4842),
    [aux_sym_id_directive_token3] = ACTIONS(4842),
    [aux_sym_id_directive_token4] = ACTIONS(4844),
    [aux_sym_zero_directive_token1] = ACTIONS(4842),
    [aux_sym_zero_directive_token2] = ACTIONS(4842),
    [aux_sym_zero_directive_token3] = ACTIONS(4842),
    [aux_sym_zero_directive_token4] = ACTIONS(4842),
    [aux_sym_zero_directive_token5] = ACTIONS(4842),
    [aux_sym_zero_directive_token6] = ACTIONS(4842),
    [aux_sym_zero_directive_token7] = ACTIONS(4842),
    [aux_sym_zero_directive_token8] = ACTIONS(4842),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4842),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4842),
    [anon_sym_wire] = ACTIONS(4844),
    [anon_sym_tri] = ACTIONS(4844),
    [anon_sym_tri0] = ACTIONS(4844),
    [anon_sym_tri1] = ACTIONS(4844),
    [anon_sym_wand] = ACTIONS(4844),
    [anon_sym_triand] = ACTIONS(4844),
    [anon_sym_wor] = ACTIONS(4844),
    [anon_sym_trior] = ACTIONS(4844),
    [anon_sym_trireg] = ACTIONS(4844),
    [anon_sym_uwire] = ACTIONS(4844),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4842),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4842),
    [aux_sym_begin_keywords_token1] = ACTIONS(4842),
    [anon_sym_SEMI] = ACTIONS(4842),
    [anon_sym_endmodule] = ACTIONS(4844),
    [anon_sym_extern] = ACTIONS(4844),
    [anon_sym_module] = ACTIONS(4844),
    [anon_sym_macromodule] = ACTIONS(4844),
    [anon_sym_endinterface] = ACTIONS(4844),
    [anon_sym_interface] = ACTIONS(4844),
    [anon_sym_endprogram] = ACTIONS(4844),
    [anon_sym_program] = ACTIONS(4844),
    [anon_sym_checker] = ACTIONS(4844),
    [anon_sym_virtual] = ACTIONS(4844),
    [anon_sym_class] = ACTIONS(4844),
    [anon_sym_package] = ACTIONS(4844),
    [anon_sym_endpackage] = ACTIONS(4844),
    [anon_sym_timeunit] = ACTIONS(4844),
    [anon_sym_timeprecision] = ACTIONS(4844),
    [anon_sym_type] = ACTIONS(4844),
    [anon_sym_input] = ACTIONS(4844),
    [anon_sym_output] = ACTIONS(4844),
    [anon_sym_inout] = ACTIONS(4844),
    [anon_sym_ref] = ACTIONS(4844),
    [anon_sym_DOLLARfatal] = ACTIONS(4842),
    [anon_sym_DOLLARerror] = ACTIONS(4842),
    [anon_sym_DOLLARwarning] = ACTIONS(4842),
    [anon_sym_DOLLARinfo] = ACTIONS(4842),
    [anon_sym_default] = ACTIONS(4844),
    [anon_sym_clocking] = ACTIONS(4844),
    [anon_sym_defparam] = ACTIONS(4844),
    [anon_sym_bind] = ACTIONS(4844),
    [anon_sym_const] = ACTIONS(4844),
    [anon_sym_function] = ACTIONS(4844),
    [anon_sym_static] = ACTIONS(4844),
    [anon_sym_constraint] = ACTIONS(4844),
    [anon_sym_if] = ACTIONS(4844),
    [anon_sym_else] = ACTIONS(4844),
    [anon_sym_LBRACK] = ACTIONS(4842),
    [anon_sym_localparam] = ACTIONS(4844),
    [anon_sym_parameter] = ACTIONS(4844),
    [anon_sym_specparam] = ACTIONS(4844),
    [anon_sym_var] = ACTIONS(4844),
    [anon_sym_import] = ACTIONS(4844),
    [anon_sym_export] = ACTIONS(4844),
    [anon_sym_genvar] = ACTIONS(4844),
    [anon_sym_interconnect] = ACTIONS(4844),
    [anon_sym_typedef] = ACTIONS(4844),
    [anon_sym_enum] = ACTIONS(4844),
    [anon_sym_struct] = ACTIONS(4844),
    [anon_sym_union] = ACTIONS(4844),
    [anon_sym_nettype] = ACTIONS(4844),
    [anon_sym_automatic] = ACTIONS(4844),
    [anon_sym_string] = ACTIONS(4844),
    [anon_sym_chandle] = ACTIONS(4844),
    [anon_sym_event] = ACTIONS(4844),
    [anon_sym_byte] = ACTIONS(4844),
    [anon_sym_shortint] = ACTIONS(4844),
    [anon_sym_int] = ACTIONS(4844),
    [anon_sym_longint] = ACTIONS(4844),
    [anon_sym_integer] = ACTIONS(4844),
    [anon_sym_time] = ACTIONS(4844),
    [anon_sym_bit] = ACTIONS(4844),
    [anon_sym_logic] = ACTIONS(4844),
    [anon_sym_reg] = ACTIONS(4844),
    [anon_sym_shortreal] = ACTIONS(4844),
    [anon_sym_real] = ACTIONS(4844),
    [anon_sym_realtime] = ACTIONS(4844),
    [anon_sym_supply0] = ACTIONS(4844),
    [anon_sym_supply1] = ACTIONS(4844),
    [anon_sym_signed] = ACTIONS(4844),
    [anon_sym_unsigned] = ACTIONS(4844),
    [anon_sym_task] = ACTIONS(4844),
    [anon_sym_modport] = ACTIONS(4844),
    [anon_sym_assert] = ACTIONS(4844),
    [anon_sym_property] = ACTIONS(4844),
    [anon_sym_assume] = ACTIONS(4844),
    [anon_sym_cover] = ACTIONS(4844),
    [anon_sym_sequence] = ACTIONS(4844),
    [anon_sym_restrict] = ACTIONS(4844),
    [anon_sym_not] = ACTIONS(4844),
    [anon_sym_or] = ACTIONS(4844),
    [anon_sym_and] = ACTIONS(4844),
    [anon_sym_case] = ACTIONS(4844),
    [anon_sym_always] = ACTIONS(4844),
    [anon_sym_covergroup] = ACTIONS(4844),
    [anon_sym_let] = ACTIONS(4844),
    [anon_sym_pulldown] = ACTIONS(4844),
    [anon_sym_pullup] = ACTIONS(4844),
    [anon_sym_cmos] = ACTIONS(4844),
    [anon_sym_rcmos] = ACTIONS(4844),
    [anon_sym_bufif0] = ACTIONS(4844),
    [anon_sym_bufif1] = ACTIONS(4844),
    [anon_sym_notif0] = ACTIONS(4844),
    [anon_sym_notif1] = ACTIONS(4844),
    [anon_sym_nmos] = ACTIONS(4844),
    [anon_sym_pmos] = ACTIONS(4844),
    [anon_sym_rnmos] = ACTIONS(4844),
    [anon_sym_rpmos] = ACTIONS(4844),
    [anon_sym_nand] = ACTIONS(4844),
    [anon_sym_nor] = ACTIONS(4844),
    [anon_sym_xor] = ACTIONS(4844),
    [anon_sym_xnor] = ACTIONS(4844),
    [anon_sym_buf] = ACTIONS(4844),
    [anon_sym_tranif0] = ACTIONS(4844),
    [anon_sym_tranif1] = ACTIONS(4844),
    [anon_sym_rtranif1] = ACTIONS(4844),
    [anon_sym_rtranif0] = ACTIONS(4844),
    [anon_sym_tran] = ACTIONS(4844),
    [anon_sym_rtran] = ACTIONS(4844),
    [anon_sym_generate] = ACTIONS(4844),
    [anon_sym_for] = ACTIONS(4844),
    [anon_sym_primitive] = ACTIONS(4844),
    [anon_sym_initial] = ACTIONS(4844),
    [anon_sym_assign] = ACTIONS(4844),
    [anon_sym_alias] = ACTIONS(4844),
    [anon_sym_always_comb] = ACTIONS(4844),
    [anon_sym_always_latch] = ACTIONS(4844),
    [anon_sym_always_ff] = ACTIONS(4844),
    [anon_sym_final] = ACTIONS(4844),
    [anon_sym_global] = ACTIONS(4844),
    [anon_sym_specify] = ACTIONS(4844),
    [anon_sym_LPAREN_STAR] = ACTIONS(4842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4842),
    [anon_sym_DOLLARunit] = ACTIONS(4842),
  },
  [776] = {
    [ts_builtin_sym_end] = ACTIONS(4846),
    [sym_simple_identifier] = ACTIONS(4848),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4846),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4846),
    [anon_sym_BQUOTE] = ACTIONS(4848),
    [aux_sym_id_directive_token1] = ACTIONS(4846),
    [aux_sym_id_directive_token2] = ACTIONS(4846),
    [aux_sym_id_directive_token3] = ACTIONS(4846),
    [aux_sym_id_directive_token4] = ACTIONS(4848),
    [aux_sym_zero_directive_token1] = ACTIONS(4846),
    [aux_sym_zero_directive_token2] = ACTIONS(4846),
    [aux_sym_zero_directive_token3] = ACTIONS(4846),
    [aux_sym_zero_directive_token4] = ACTIONS(4846),
    [aux_sym_zero_directive_token5] = ACTIONS(4846),
    [aux_sym_zero_directive_token6] = ACTIONS(4846),
    [aux_sym_zero_directive_token7] = ACTIONS(4846),
    [aux_sym_zero_directive_token8] = ACTIONS(4846),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4846),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4846),
    [anon_sym_wire] = ACTIONS(4848),
    [anon_sym_tri] = ACTIONS(4848),
    [anon_sym_tri0] = ACTIONS(4848),
    [anon_sym_tri1] = ACTIONS(4848),
    [anon_sym_wand] = ACTIONS(4848),
    [anon_sym_triand] = ACTIONS(4848),
    [anon_sym_wor] = ACTIONS(4848),
    [anon_sym_trior] = ACTIONS(4848),
    [anon_sym_trireg] = ACTIONS(4848),
    [anon_sym_uwire] = ACTIONS(4848),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4846),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4846),
    [aux_sym_begin_keywords_token1] = ACTIONS(4846),
    [anon_sym_SEMI] = ACTIONS(4846),
    [anon_sym_endmodule] = ACTIONS(4848),
    [anon_sym_extern] = ACTIONS(4848),
    [anon_sym_module] = ACTIONS(4848),
    [anon_sym_macromodule] = ACTIONS(4848),
    [anon_sym_endinterface] = ACTIONS(4848),
    [anon_sym_interface] = ACTIONS(4848),
    [anon_sym_endprogram] = ACTIONS(4848),
    [anon_sym_program] = ACTIONS(4848),
    [anon_sym_checker] = ACTIONS(4848),
    [anon_sym_virtual] = ACTIONS(4848),
    [anon_sym_class] = ACTIONS(4848),
    [anon_sym_package] = ACTIONS(4848),
    [anon_sym_endpackage] = ACTIONS(4848),
    [anon_sym_timeunit] = ACTIONS(4848),
    [anon_sym_timeprecision] = ACTIONS(4848),
    [anon_sym_type] = ACTIONS(4848),
    [anon_sym_input] = ACTIONS(4848),
    [anon_sym_output] = ACTIONS(4848),
    [anon_sym_inout] = ACTIONS(4848),
    [anon_sym_ref] = ACTIONS(4848),
    [anon_sym_DOLLARfatal] = ACTIONS(4846),
    [anon_sym_DOLLARerror] = ACTIONS(4846),
    [anon_sym_DOLLARwarning] = ACTIONS(4846),
    [anon_sym_DOLLARinfo] = ACTIONS(4846),
    [anon_sym_default] = ACTIONS(4848),
    [anon_sym_clocking] = ACTIONS(4848),
    [anon_sym_defparam] = ACTIONS(4848),
    [anon_sym_bind] = ACTIONS(4848),
    [anon_sym_const] = ACTIONS(4848),
    [anon_sym_function] = ACTIONS(4848),
    [anon_sym_static] = ACTIONS(4848),
    [anon_sym_constraint] = ACTIONS(4848),
    [anon_sym_if] = ACTIONS(4848),
    [anon_sym_else] = ACTIONS(4848),
    [anon_sym_LBRACK] = ACTIONS(4846),
    [anon_sym_localparam] = ACTIONS(4848),
    [anon_sym_parameter] = ACTIONS(4848),
    [anon_sym_specparam] = ACTIONS(4848),
    [anon_sym_var] = ACTIONS(4848),
    [anon_sym_import] = ACTIONS(4848),
    [anon_sym_export] = ACTIONS(4848),
    [anon_sym_genvar] = ACTIONS(4848),
    [anon_sym_interconnect] = ACTIONS(4848),
    [anon_sym_typedef] = ACTIONS(4848),
    [anon_sym_enum] = ACTIONS(4848),
    [anon_sym_struct] = ACTIONS(4848),
    [anon_sym_union] = ACTIONS(4848),
    [anon_sym_nettype] = ACTIONS(4848),
    [anon_sym_automatic] = ACTIONS(4848),
    [anon_sym_string] = ACTIONS(4848),
    [anon_sym_chandle] = ACTIONS(4848),
    [anon_sym_event] = ACTIONS(4848),
    [anon_sym_byte] = ACTIONS(4848),
    [anon_sym_shortint] = ACTIONS(4848),
    [anon_sym_int] = ACTIONS(4848),
    [anon_sym_longint] = ACTIONS(4848),
    [anon_sym_integer] = ACTIONS(4848),
    [anon_sym_time] = ACTIONS(4848),
    [anon_sym_bit] = ACTIONS(4848),
    [anon_sym_logic] = ACTIONS(4848),
    [anon_sym_reg] = ACTIONS(4848),
    [anon_sym_shortreal] = ACTIONS(4848),
    [anon_sym_real] = ACTIONS(4848),
    [anon_sym_realtime] = ACTIONS(4848),
    [anon_sym_supply0] = ACTIONS(4848),
    [anon_sym_supply1] = ACTIONS(4848),
    [anon_sym_signed] = ACTIONS(4848),
    [anon_sym_unsigned] = ACTIONS(4848),
    [anon_sym_task] = ACTIONS(4848),
    [anon_sym_modport] = ACTIONS(4848),
    [anon_sym_assert] = ACTIONS(4848),
    [anon_sym_property] = ACTIONS(4848),
    [anon_sym_assume] = ACTIONS(4848),
    [anon_sym_cover] = ACTIONS(4848),
    [anon_sym_sequence] = ACTIONS(4848),
    [anon_sym_restrict] = ACTIONS(4848),
    [anon_sym_not] = ACTIONS(4848),
    [anon_sym_or] = ACTIONS(4848),
    [anon_sym_and] = ACTIONS(4848),
    [anon_sym_case] = ACTIONS(4848),
    [anon_sym_always] = ACTIONS(4848),
    [anon_sym_covergroup] = ACTIONS(4848),
    [anon_sym_let] = ACTIONS(4848),
    [anon_sym_pulldown] = ACTIONS(4848),
    [anon_sym_pullup] = ACTIONS(4848),
    [anon_sym_cmos] = ACTIONS(4848),
    [anon_sym_rcmos] = ACTIONS(4848),
    [anon_sym_bufif0] = ACTIONS(4848),
    [anon_sym_bufif1] = ACTIONS(4848),
    [anon_sym_notif0] = ACTIONS(4848),
    [anon_sym_notif1] = ACTIONS(4848),
    [anon_sym_nmos] = ACTIONS(4848),
    [anon_sym_pmos] = ACTIONS(4848),
    [anon_sym_rnmos] = ACTIONS(4848),
    [anon_sym_rpmos] = ACTIONS(4848),
    [anon_sym_nand] = ACTIONS(4848),
    [anon_sym_nor] = ACTIONS(4848),
    [anon_sym_xor] = ACTIONS(4848),
    [anon_sym_xnor] = ACTIONS(4848),
    [anon_sym_buf] = ACTIONS(4848),
    [anon_sym_tranif0] = ACTIONS(4848),
    [anon_sym_tranif1] = ACTIONS(4848),
    [anon_sym_rtranif1] = ACTIONS(4848),
    [anon_sym_rtranif0] = ACTIONS(4848),
    [anon_sym_tran] = ACTIONS(4848),
    [anon_sym_rtran] = ACTIONS(4848),
    [anon_sym_generate] = ACTIONS(4848),
    [anon_sym_for] = ACTIONS(4848),
    [anon_sym_primitive] = ACTIONS(4848),
    [anon_sym_initial] = ACTIONS(4848),
    [anon_sym_assign] = ACTIONS(4848),
    [anon_sym_alias] = ACTIONS(4848),
    [anon_sym_always_comb] = ACTIONS(4848),
    [anon_sym_always_latch] = ACTIONS(4848),
    [anon_sym_always_ff] = ACTIONS(4848),
    [anon_sym_final] = ACTIONS(4848),
    [anon_sym_global] = ACTIONS(4848),
    [anon_sym_specify] = ACTIONS(4848),
    [anon_sym_LPAREN_STAR] = ACTIONS(4846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4846),
    [anon_sym_DOLLARunit] = ACTIONS(4846),
  },
  [777] = {
    [ts_builtin_sym_end] = ACTIONS(4850),
    [sym_simple_identifier] = ACTIONS(4852),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4850),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4850),
    [anon_sym_BQUOTE] = ACTIONS(4852),
    [aux_sym_id_directive_token1] = ACTIONS(4850),
    [aux_sym_id_directive_token2] = ACTIONS(4850),
    [aux_sym_id_directive_token3] = ACTIONS(4850),
    [aux_sym_id_directive_token4] = ACTIONS(4852),
    [aux_sym_zero_directive_token1] = ACTIONS(4850),
    [aux_sym_zero_directive_token2] = ACTIONS(4850),
    [aux_sym_zero_directive_token3] = ACTIONS(4850),
    [aux_sym_zero_directive_token4] = ACTIONS(4850),
    [aux_sym_zero_directive_token5] = ACTIONS(4850),
    [aux_sym_zero_directive_token6] = ACTIONS(4850),
    [aux_sym_zero_directive_token7] = ACTIONS(4850),
    [aux_sym_zero_directive_token8] = ACTIONS(4850),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4850),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4850),
    [anon_sym_wire] = ACTIONS(4852),
    [anon_sym_tri] = ACTIONS(4852),
    [anon_sym_tri0] = ACTIONS(4852),
    [anon_sym_tri1] = ACTIONS(4852),
    [anon_sym_wand] = ACTIONS(4852),
    [anon_sym_triand] = ACTIONS(4852),
    [anon_sym_wor] = ACTIONS(4852),
    [anon_sym_trior] = ACTIONS(4852),
    [anon_sym_trireg] = ACTIONS(4852),
    [anon_sym_uwire] = ACTIONS(4852),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4850),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4850),
    [aux_sym_begin_keywords_token1] = ACTIONS(4850),
    [anon_sym_SEMI] = ACTIONS(4850),
    [anon_sym_endmodule] = ACTIONS(4852),
    [anon_sym_extern] = ACTIONS(4852),
    [anon_sym_module] = ACTIONS(4852),
    [anon_sym_macromodule] = ACTIONS(4852),
    [anon_sym_endinterface] = ACTIONS(4852),
    [anon_sym_interface] = ACTIONS(4852),
    [anon_sym_endprogram] = ACTIONS(4852),
    [anon_sym_program] = ACTIONS(4852),
    [anon_sym_checker] = ACTIONS(4852),
    [anon_sym_virtual] = ACTIONS(4852),
    [anon_sym_class] = ACTIONS(4852),
    [anon_sym_package] = ACTIONS(4852),
    [anon_sym_endpackage] = ACTIONS(4852),
    [anon_sym_timeunit] = ACTIONS(4852),
    [anon_sym_timeprecision] = ACTIONS(4852),
    [anon_sym_type] = ACTIONS(4852),
    [anon_sym_input] = ACTIONS(4852),
    [anon_sym_output] = ACTIONS(4852),
    [anon_sym_inout] = ACTIONS(4852),
    [anon_sym_ref] = ACTIONS(4852),
    [anon_sym_DOLLARfatal] = ACTIONS(4850),
    [anon_sym_DOLLARerror] = ACTIONS(4850),
    [anon_sym_DOLLARwarning] = ACTIONS(4850),
    [anon_sym_DOLLARinfo] = ACTIONS(4850),
    [anon_sym_default] = ACTIONS(4852),
    [anon_sym_clocking] = ACTIONS(4852),
    [anon_sym_defparam] = ACTIONS(4852),
    [anon_sym_bind] = ACTIONS(4852),
    [anon_sym_const] = ACTIONS(4852),
    [anon_sym_function] = ACTIONS(4852),
    [anon_sym_static] = ACTIONS(4852),
    [anon_sym_constraint] = ACTIONS(4852),
    [anon_sym_if] = ACTIONS(4852),
    [anon_sym_else] = ACTIONS(4852),
    [anon_sym_LBRACK] = ACTIONS(4850),
    [anon_sym_localparam] = ACTIONS(4852),
    [anon_sym_parameter] = ACTIONS(4852),
    [anon_sym_specparam] = ACTIONS(4852),
    [anon_sym_var] = ACTIONS(4852),
    [anon_sym_import] = ACTIONS(4852),
    [anon_sym_export] = ACTIONS(4852),
    [anon_sym_genvar] = ACTIONS(4852),
    [anon_sym_interconnect] = ACTIONS(4852),
    [anon_sym_typedef] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4852),
    [anon_sym_struct] = ACTIONS(4852),
    [anon_sym_union] = ACTIONS(4852),
    [anon_sym_nettype] = ACTIONS(4852),
    [anon_sym_automatic] = ACTIONS(4852),
    [anon_sym_string] = ACTIONS(4852),
    [anon_sym_chandle] = ACTIONS(4852),
    [anon_sym_event] = ACTIONS(4852),
    [anon_sym_byte] = ACTIONS(4852),
    [anon_sym_shortint] = ACTIONS(4852),
    [anon_sym_int] = ACTIONS(4852),
    [anon_sym_longint] = ACTIONS(4852),
    [anon_sym_integer] = ACTIONS(4852),
    [anon_sym_time] = ACTIONS(4852),
    [anon_sym_bit] = ACTIONS(4852),
    [anon_sym_logic] = ACTIONS(4852),
    [anon_sym_reg] = ACTIONS(4852),
    [anon_sym_shortreal] = ACTIONS(4852),
    [anon_sym_real] = ACTIONS(4852),
    [anon_sym_realtime] = ACTIONS(4852),
    [anon_sym_supply0] = ACTIONS(4852),
    [anon_sym_supply1] = ACTIONS(4852),
    [anon_sym_signed] = ACTIONS(4852),
    [anon_sym_unsigned] = ACTIONS(4852),
    [anon_sym_task] = ACTIONS(4852),
    [anon_sym_modport] = ACTIONS(4852),
    [anon_sym_assert] = ACTIONS(4852),
    [anon_sym_property] = ACTIONS(4852),
    [anon_sym_assume] = ACTIONS(4852),
    [anon_sym_cover] = ACTIONS(4852),
    [anon_sym_sequence] = ACTIONS(4852),
    [anon_sym_restrict] = ACTIONS(4852),
    [anon_sym_not] = ACTIONS(4852),
    [anon_sym_or] = ACTIONS(4852),
    [anon_sym_and] = ACTIONS(4852),
    [anon_sym_case] = ACTIONS(4852),
    [anon_sym_always] = ACTIONS(4852),
    [anon_sym_covergroup] = ACTIONS(4852),
    [anon_sym_let] = ACTIONS(4852),
    [anon_sym_pulldown] = ACTIONS(4852),
    [anon_sym_pullup] = ACTIONS(4852),
    [anon_sym_cmos] = ACTIONS(4852),
    [anon_sym_rcmos] = ACTIONS(4852),
    [anon_sym_bufif0] = ACTIONS(4852),
    [anon_sym_bufif1] = ACTIONS(4852),
    [anon_sym_notif0] = ACTIONS(4852),
    [anon_sym_notif1] = ACTIONS(4852),
    [anon_sym_nmos] = ACTIONS(4852),
    [anon_sym_pmos] = ACTIONS(4852),
    [anon_sym_rnmos] = ACTIONS(4852),
    [anon_sym_rpmos] = ACTIONS(4852),
    [anon_sym_nand] = ACTIONS(4852),
    [anon_sym_nor] = ACTIONS(4852),
    [anon_sym_xor] = ACTIONS(4852),
    [anon_sym_xnor] = ACTIONS(4852),
    [anon_sym_buf] = ACTIONS(4852),
    [anon_sym_tranif0] = ACTIONS(4852),
    [anon_sym_tranif1] = ACTIONS(4852),
    [anon_sym_rtranif1] = ACTIONS(4852),
    [anon_sym_rtranif0] = ACTIONS(4852),
    [anon_sym_tran] = ACTIONS(4852),
    [anon_sym_rtran] = ACTIONS(4852),
    [anon_sym_generate] = ACTIONS(4852),
    [anon_sym_for] = ACTIONS(4852),
    [anon_sym_primitive] = ACTIONS(4852),
    [anon_sym_initial] = ACTIONS(4852),
    [anon_sym_assign] = ACTIONS(4852),
    [anon_sym_alias] = ACTIONS(4852),
    [anon_sym_always_comb] = ACTIONS(4852),
    [anon_sym_always_latch] = ACTIONS(4852),
    [anon_sym_always_ff] = ACTIONS(4852),
    [anon_sym_final] = ACTIONS(4852),
    [anon_sym_global] = ACTIONS(4852),
    [anon_sym_specify] = ACTIONS(4852),
    [anon_sym_LPAREN_STAR] = ACTIONS(4850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4850),
    [anon_sym_DOLLARunit] = ACTIONS(4850),
  },
  [778] = {
    [ts_builtin_sym_end] = ACTIONS(4854),
    [sym_simple_identifier] = ACTIONS(4856),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4854),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4854),
    [anon_sym_BQUOTE] = ACTIONS(4856),
    [aux_sym_id_directive_token1] = ACTIONS(4854),
    [aux_sym_id_directive_token2] = ACTIONS(4854),
    [aux_sym_id_directive_token3] = ACTIONS(4854),
    [aux_sym_id_directive_token4] = ACTIONS(4856),
    [aux_sym_zero_directive_token1] = ACTIONS(4854),
    [aux_sym_zero_directive_token2] = ACTIONS(4854),
    [aux_sym_zero_directive_token3] = ACTIONS(4854),
    [aux_sym_zero_directive_token4] = ACTIONS(4854),
    [aux_sym_zero_directive_token5] = ACTIONS(4854),
    [aux_sym_zero_directive_token6] = ACTIONS(4854),
    [aux_sym_zero_directive_token7] = ACTIONS(4854),
    [aux_sym_zero_directive_token8] = ACTIONS(4854),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4854),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4854),
    [anon_sym_wire] = ACTIONS(4856),
    [anon_sym_tri] = ACTIONS(4856),
    [anon_sym_tri0] = ACTIONS(4856),
    [anon_sym_tri1] = ACTIONS(4856),
    [anon_sym_wand] = ACTIONS(4856),
    [anon_sym_triand] = ACTIONS(4856),
    [anon_sym_wor] = ACTIONS(4856),
    [anon_sym_trior] = ACTIONS(4856),
    [anon_sym_trireg] = ACTIONS(4856),
    [anon_sym_uwire] = ACTIONS(4856),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4854),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4854),
    [aux_sym_begin_keywords_token1] = ACTIONS(4854),
    [anon_sym_SEMI] = ACTIONS(4854),
    [anon_sym_endmodule] = ACTIONS(4856),
    [anon_sym_extern] = ACTIONS(4856),
    [anon_sym_module] = ACTIONS(4856),
    [anon_sym_macromodule] = ACTIONS(4856),
    [anon_sym_endinterface] = ACTIONS(4856),
    [anon_sym_interface] = ACTIONS(4856),
    [anon_sym_endprogram] = ACTIONS(4856),
    [anon_sym_program] = ACTIONS(4856),
    [anon_sym_checker] = ACTIONS(4856),
    [anon_sym_virtual] = ACTIONS(4856),
    [anon_sym_class] = ACTIONS(4856),
    [anon_sym_package] = ACTIONS(4856),
    [anon_sym_endpackage] = ACTIONS(4856),
    [anon_sym_timeunit] = ACTIONS(4856),
    [anon_sym_timeprecision] = ACTIONS(4856),
    [anon_sym_type] = ACTIONS(4856),
    [anon_sym_input] = ACTIONS(4856),
    [anon_sym_output] = ACTIONS(4856),
    [anon_sym_inout] = ACTIONS(4856),
    [anon_sym_ref] = ACTIONS(4856),
    [anon_sym_DOLLARfatal] = ACTIONS(4854),
    [anon_sym_DOLLARerror] = ACTIONS(4854),
    [anon_sym_DOLLARwarning] = ACTIONS(4854),
    [anon_sym_DOLLARinfo] = ACTIONS(4854),
    [anon_sym_default] = ACTIONS(4856),
    [anon_sym_clocking] = ACTIONS(4856),
    [anon_sym_defparam] = ACTIONS(4856),
    [anon_sym_bind] = ACTIONS(4856),
    [anon_sym_const] = ACTIONS(4856),
    [anon_sym_function] = ACTIONS(4856),
    [anon_sym_static] = ACTIONS(4856),
    [anon_sym_constraint] = ACTIONS(4856),
    [anon_sym_if] = ACTIONS(4856),
    [anon_sym_else] = ACTIONS(4856),
    [anon_sym_LBRACK] = ACTIONS(4854),
    [anon_sym_localparam] = ACTIONS(4856),
    [anon_sym_parameter] = ACTIONS(4856),
    [anon_sym_specparam] = ACTIONS(4856),
    [anon_sym_var] = ACTIONS(4856),
    [anon_sym_import] = ACTIONS(4856),
    [anon_sym_export] = ACTIONS(4856),
    [anon_sym_genvar] = ACTIONS(4856),
    [anon_sym_interconnect] = ACTIONS(4856),
    [anon_sym_typedef] = ACTIONS(4856),
    [anon_sym_enum] = ACTIONS(4856),
    [anon_sym_struct] = ACTIONS(4856),
    [anon_sym_union] = ACTIONS(4856),
    [anon_sym_nettype] = ACTIONS(4856),
    [anon_sym_automatic] = ACTIONS(4856),
    [anon_sym_string] = ACTIONS(4856),
    [anon_sym_chandle] = ACTIONS(4856),
    [anon_sym_event] = ACTIONS(4856),
    [anon_sym_byte] = ACTIONS(4856),
    [anon_sym_shortint] = ACTIONS(4856),
    [anon_sym_int] = ACTIONS(4856),
    [anon_sym_longint] = ACTIONS(4856),
    [anon_sym_integer] = ACTIONS(4856),
    [anon_sym_time] = ACTIONS(4856),
    [anon_sym_bit] = ACTIONS(4856),
    [anon_sym_logic] = ACTIONS(4856),
    [anon_sym_reg] = ACTIONS(4856),
    [anon_sym_shortreal] = ACTIONS(4856),
    [anon_sym_real] = ACTIONS(4856),
    [anon_sym_realtime] = ACTIONS(4856),
    [anon_sym_supply0] = ACTIONS(4856),
    [anon_sym_supply1] = ACTIONS(4856),
    [anon_sym_signed] = ACTIONS(4856),
    [anon_sym_unsigned] = ACTIONS(4856),
    [anon_sym_task] = ACTIONS(4856),
    [anon_sym_modport] = ACTIONS(4856),
    [anon_sym_assert] = ACTIONS(4856),
    [anon_sym_property] = ACTIONS(4856),
    [anon_sym_assume] = ACTIONS(4856),
    [anon_sym_cover] = ACTIONS(4856),
    [anon_sym_sequence] = ACTIONS(4856),
    [anon_sym_restrict] = ACTIONS(4856),
    [anon_sym_not] = ACTIONS(4856),
    [anon_sym_or] = ACTIONS(4856),
    [anon_sym_and] = ACTIONS(4856),
    [anon_sym_case] = ACTIONS(4856),
    [anon_sym_always] = ACTIONS(4856),
    [anon_sym_covergroup] = ACTIONS(4856),
    [anon_sym_let] = ACTIONS(4856),
    [anon_sym_pulldown] = ACTIONS(4856),
    [anon_sym_pullup] = ACTIONS(4856),
    [anon_sym_cmos] = ACTIONS(4856),
    [anon_sym_rcmos] = ACTIONS(4856),
    [anon_sym_bufif0] = ACTIONS(4856),
    [anon_sym_bufif1] = ACTIONS(4856),
    [anon_sym_notif0] = ACTIONS(4856),
    [anon_sym_notif1] = ACTIONS(4856),
    [anon_sym_nmos] = ACTIONS(4856),
    [anon_sym_pmos] = ACTIONS(4856),
    [anon_sym_rnmos] = ACTIONS(4856),
    [anon_sym_rpmos] = ACTIONS(4856),
    [anon_sym_nand] = ACTIONS(4856),
    [anon_sym_nor] = ACTIONS(4856),
    [anon_sym_xor] = ACTIONS(4856),
    [anon_sym_xnor] = ACTIONS(4856),
    [anon_sym_buf] = ACTIONS(4856),
    [anon_sym_tranif0] = ACTIONS(4856),
    [anon_sym_tranif1] = ACTIONS(4856),
    [anon_sym_rtranif1] = ACTIONS(4856),
    [anon_sym_rtranif0] = ACTIONS(4856),
    [anon_sym_tran] = ACTIONS(4856),
    [anon_sym_rtran] = ACTIONS(4856),
    [anon_sym_generate] = ACTIONS(4856),
    [anon_sym_for] = ACTIONS(4856),
    [anon_sym_primitive] = ACTIONS(4856),
    [anon_sym_initial] = ACTIONS(4856),
    [anon_sym_assign] = ACTIONS(4856),
    [anon_sym_alias] = ACTIONS(4856),
    [anon_sym_always_comb] = ACTIONS(4856),
    [anon_sym_always_latch] = ACTIONS(4856),
    [anon_sym_always_ff] = ACTIONS(4856),
    [anon_sym_final] = ACTIONS(4856),
    [anon_sym_global] = ACTIONS(4856),
    [anon_sym_specify] = ACTIONS(4856),
    [anon_sym_LPAREN_STAR] = ACTIONS(4854),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4854),
    [anon_sym_DOLLARunit] = ACTIONS(4854),
  },
  [779] = {
    [ts_builtin_sym_end] = ACTIONS(4576),
    [sym_simple_identifier] = ACTIONS(4578),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4576),
    [anon_sym_BQUOTE] = ACTIONS(4578),
    [aux_sym_id_directive_token1] = ACTIONS(4576),
    [aux_sym_id_directive_token2] = ACTIONS(4576),
    [aux_sym_id_directive_token3] = ACTIONS(4576),
    [aux_sym_id_directive_token4] = ACTIONS(4578),
    [aux_sym_zero_directive_token1] = ACTIONS(4576),
    [aux_sym_zero_directive_token2] = ACTIONS(4576),
    [aux_sym_zero_directive_token3] = ACTIONS(4576),
    [aux_sym_zero_directive_token4] = ACTIONS(4576),
    [aux_sym_zero_directive_token5] = ACTIONS(4576),
    [aux_sym_zero_directive_token6] = ACTIONS(4576),
    [aux_sym_zero_directive_token7] = ACTIONS(4576),
    [aux_sym_zero_directive_token8] = ACTIONS(4576),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4576),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4576),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4576),
    [aux_sym_begin_keywords_token1] = ACTIONS(4576),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_endmodule] = ACTIONS(4578),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_module] = ACTIONS(4578),
    [anon_sym_macromodule] = ACTIONS(4578),
    [anon_sym_endinterface] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_endprogram] = ACTIONS(4578),
    [anon_sym_program] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_package] = ACTIONS(4578),
    [anon_sym_endpackage] = ACTIONS(4578),
    [anon_sym_timeunit] = ACTIONS(4578),
    [anon_sym_timeprecision] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_input] = ACTIONS(4578),
    [anon_sym_output] = ACTIONS(4578),
    [anon_sym_inout] = ACTIONS(4578),
    [anon_sym_ref] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_specparam] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_modport] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_primitive] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_specify] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [780] = {
    [ts_builtin_sym_end] = ACTIONS(4592),
    [sym_simple_identifier] = ACTIONS(4594),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4592),
    [anon_sym_BQUOTE] = ACTIONS(4594),
    [aux_sym_id_directive_token1] = ACTIONS(4592),
    [aux_sym_id_directive_token2] = ACTIONS(4592),
    [aux_sym_id_directive_token3] = ACTIONS(4592),
    [aux_sym_id_directive_token4] = ACTIONS(4594),
    [aux_sym_zero_directive_token1] = ACTIONS(4592),
    [aux_sym_zero_directive_token2] = ACTIONS(4592),
    [aux_sym_zero_directive_token3] = ACTIONS(4592),
    [aux_sym_zero_directive_token4] = ACTIONS(4592),
    [aux_sym_zero_directive_token5] = ACTIONS(4592),
    [aux_sym_zero_directive_token6] = ACTIONS(4592),
    [aux_sym_zero_directive_token7] = ACTIONS(4592),
    [aux_sym_zero_directive_token8] = ACTIONS(4592),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4592),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4592),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4592),
    [aux_sym_begin_keywords_token1] = ACTIONS(4592),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_endmodule] = ACTIONS(4594),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_module] = ACTIONS(4594),
    [anon_sym_macromodule] = ACTIONS(4594),
    [anon_sym_endinterface] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_endprogram] = ACTIONS(4594),
    [anon_sym_program] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_package] = ACTIONS(4594),
    [anon_sym_endpackage] = ACTIONS(4594),
    [anon_sym_timeunit] = ACTIONS(4594),
    [anon_sym_timeprecision] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_input] = ACTIONS(4594),
    [anon_sym_output] = ACTIONS(4594),
    [anon_sym_inout] = ACTIONS(4594),
    [anon_sym_ref] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_specparam] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_modport] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_primitive] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_specify] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [781] = {
    [ts_builtin_sym_end] = ACTIONS(4598),
    [sym_simple_identifier] = ACTIONS(4600),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4598),
    [anon_sym_BQUOTE] = ACTIONS(4600),
    [aux_sym_id_directive_token1] = ACTIONS(4598),
    [aux_sym_id_directive_token2] = ACTIONS(4598),
    [aux_sym_id_directive_token3] = ACTIONS(4598),
    [aux_sym_id_directive_token4] = ACTIONS(4600),
    [aux_sym_zero_directive_token1] = ACTIONS(4598),
    [aux_sym_zero_directive_token2] = ACTIONS(4598),
    [aux_sym_zero_directive_token3] = ACTIONS(4598),
    [aux_sym_zero_directive_token4] = ACTIONS(4598),
    [aux_sym_zero_directive_token5] = ACTIONS(4598),
    [aux_sym_zero_directive_token6] = ACTIONS(4598),
    [aux_sym_zero_directive_token7] = ACTIONS(4598),
    [aux_sym_zero_directive_token8] = ACTIONS(4598),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4598),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4598),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4598),
    [aux_sym_begin_keywords_token1] = ACTIONS(4598),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_endmodule] = ACTIONS(4600),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_module] = ACTIONS(4600),
    [anon_sym_macromodule] = ACTIONS(4600),
    [anon_sym_endinterface] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_endprogram] = ACTIONS(4600),
    [anon_sym_program] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_package] = ACTIONS(4600),
    [anon_sym_endpackage] = ACTIONS(4600),
    [anon_sym_timeunit] = ACTIONS(4600),
    [anon_sym_timeprecision] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_input] = ACTIONS(4600),
    [anon_sym_output] = ACTIONS(4600),
    [anon_sym_inout] = ACTIONS(4600),
    [anon_sym_ref] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_specparam] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_modport] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_primitive] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_specify] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [782] = {
    [ts_builtin_sym_end] = ACTIONS(4610),
    [sym_simple_identifier] = ACTIONS(4612),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4610),
    [anon_sym_BQUOTE] = ACTIONS(4612),
    [aux_sym_id_directive_token1] = ACTIONS(4610),
    [aux_sym_id_directive_token2] = ACTIONS(4610),
    [aux_sym_id_directive_token3] = ACTIONS(4610),
    [aux_sym_id_directive_token4] = ACTIONS(4612),
    [aux_sym_zero_directive_token1] = ACTIONS(4610),
    [aux_sym_zero_directive_token2] = ACTIONS(4610),
    [aux_sym_zero_directive_token3] = ACTIONS(4610),
    [aux_sym_zero_directive_token4] = ACTIONS(4610),
    [aux_sym_zero_directive_token5] = ACTIONS(4610),
    [aux_sym_zero_directive_token6] = ACTIONS(4610),
    [aux_sym_zero_directive_token7] = ACTIONS(4610),
    [aux_sym_zero_directive_token8] = ACTIONS(4610),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4610),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4610),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4610),
    [aux_sym_begin_keywords_token1] = ACTIONS(4610),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_endmodule] = ACTIONS(4612),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_module] = ACTIONS(4612),
    [anon_sym_macromodule] = ACTIONS(4612),
    [anon_sym_endinterface] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_endprogram] = ACTIONS(4612),
    [anon_sym_program] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_package] = ACTIONS(4612),
    [anon_sym_endpackage] = ACTIONS(4612),
    [anon_sym_timeunit] = ACTIONS(4612),
    [anon_sym_timeprecision] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_input] = ACTIONS(4612),
    [anon_sym_output] = ACTIONS(4612),
    [anon_sym_inout] = ACTIONS(4612),
    [anon_sym_ref] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_specparam] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_modport] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_primitive] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_specify] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [783] = {
    [ts_builtin_sym_end] = ACTIONS(4858),
    [sym_simple_identifier] = ACTIONS(4860),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4858),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4858),
    [anon_sym_BQUOTE] = ACTIONS(4860),
    [aux_sym_id_directive_token1] = ACTIONS(4858),
    [aux_sym_id_directive_token2] = ACTIONS(4858),
    [aux_sym_id_directive_token3] = ACTIONS(4858),
    [aux_sym_id_directive_token4] = ACTIONS(4860),
    [aux_sym_zero_directive_token1] = ACTIONS(4858),
    [aux_sym_zero_directive_token2] = ACTIONS(4858),
    [aux_sym_zero_directive_token3] = ACTIONS(4858),
    [aux_sym_zero_directive_token4] = ACTIONS(4858),
    [aux_sym_zero_directive_token5] = ACTIONS(4858),
    [aux_sym_zero_directive_token6] = ACTIONS(4858),
    [aux_sym_zero_directive_token7] = ACTIONS(4858),
    [aux_sym_zero_directive_token8] = ACTIONS(4858),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4858),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4858),
    [anon_sym_wire] = ACTIONS(4860),
    [anon_sym_tri] = ACTIONS(4860),
    [anon_sym_tri0] = ACTIONS(4860),
    [anon_sym_tri1] = ACTIONS(4860),
    [anon_sym_wand] = ACTIONS(4860),
    [anon_sym_triand] = ACTIONS(4860),
    [anon_sym_wor] = ACTIONS(4860),
    [anon_sym_trior] = ACTIONS(4860),
    [anon_sym_trireg] = ACTIONS(4860),
    [anon_sym_uwire] = ACTIONS(4860),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4858),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4858),
    [aux_sym_begin_keywords_token1] = ACTIONS(4858),
    [anon_sym_SEMI] = ACTIONS(4858),
    [anon_sym_endmodule] = ACTIONS(4860),
    [anon_sym_extern] = ACTIONS(4860),
    [anon_sym_module] = ACTIONS(4860),
    [anon_sym_macromodule] = ACTIONS(4860),
    [anon_sym_endinterface] = ACTIONS(4860),
    [anon_sym_interface] = ACTIONS(4860),
    [anon_sym_endprogram] = ACTIONS(4860),
    [anon_sym_program] = ACTIONS(4860),
    [anon_sym_checker] = ACTIONS(4860),
    [anon_sym_virtual] = ACTIONS(4860),
    [anon_sym_class] = ACTIONS(4860),
    [anon_sym_package] = ACTIONS(4860),
    [anon_sym_endpackage] = ACTIONS(4860),
    [anon_sym_timeunit] = ACTIONS(4860),
    [anon_sym_timeprecision] = ACTIONS(4860),
    [anon_sym_type] = ACTIONS(4860),
    [anon_sym_input] = ACTIONS(4860),
    [anon_sym_output] = ACTIONS(4860),
    [anon_sym_inout] = ACTIONS(4860),
    [anon_sym_ref] = ACTIONS(4860),
    [anon_sym_DOLLARfatal] = ACTIONS(4858),
    [anon_sym_DOLLARerror] = ACTIONS(4858),
    [anon_sym_DOLLARwarning] = ACTIONS(4858),
    [anon_sym_DOLLARinfo] = ACTIONS(4858),
    [anon_sym_default] = ACTIONS(4860),
    [anon_sym_clocking] = ACTIONS(4860),
    [anon_sym_defparam] = ACTIONS(4860),
    [anon_sym_bind] = ACTIONS(4860),
    [anon_sym_const] = ACTIONS(4860),
    [anon_sym_function] = ACTIONS(4860),
    [anon_sym_static] = ACTIONS(4860),
    [anon_sym_constraint] = ACTIONS(4860),
    [anon_sym_if] = ACTIONS(4860),
    [anon_sym_else] = ACTIONS(4860),
    [anon_sym_LBRACK] = ACTIONS(4858),
    [anon_sym_localparam] = ACTIONS(4860),
    [anon_sym_parameter] = ACTIONS(4860),
    [anon_sym_specparam] = ACTIONS(4860),
    [anon_sym_var] = ACTIONS(4860),
    [anon_sym_import] = ACTIONS(4860),
    [anon_sym_export] = ACTIONS(4860),
    [anon_sym_genvar] = ACTIONS(4860),
    [anon_sym_interconnect] = ACTIONS(4860),
    [anon_sym_typedef] = ACTIONS(4860),
    [anon_sym_enum] = ACTIONS(4860),
    [anon_sym_struct] = ACTIONS(4860),
    [anon_sym_union] = ACTIONS(4860),
    [anon_sym_nettype] = ACTIONS(4860),
    [anon_sym_automatic] = ACTIONS(4860),
    [anon_sym_string] = ACTIONS(4860),
    [anon_sym_chandle] = ACTIONS(4860),
    [anon_sym_event] = ACTIONS(4860),
    [anon_sym_byte] = ACTIONS(4860),
    [anon_sym_shortint] = ACTIONS(4860),
    [anon_sym_int] = ACTIONS(4860),
    [anon_sym_longint] = ACTIONS(4860),
    [anon_sym_integer] = ACTIONS(4860),
    [anon_sym_time] = ACTIONS(4860),
    [anon_sym_bit] = ACTIONS(4860),
    [anon_sym_logic] = ACTIONS(4860),
    [anon_sym_reg] = ACTIONS(4860),
    [anon_sym_shortreal] = ACTIONS(4860),
    [anon_sym_real] = ACTIONS(4860),
    [anon_sym_realtime] = ACTIONS(4860),
    [anon_sym_supply0] = ACTIONS(4860),
    [anon_sym_supply1] = ACTIONS(4860),
    [anon_sym_signed] = ACTIONS(4860),
    [anon_sym_unsigned] = ACTIONS(4860),
    [anon_sym_task] = ACTIONS(4860),
    [anon_sym_modport] = ACTIONS(4860),
    [anon_sym_assert] = ACTIONS(4860),
    [anon_sym_property] = ACTIONS(4860),
    [anon_sym_assume] = ACTIONS(4860),
    [anon_sym_cover] = ACTIONS(4860),
    [anon_sym_sequence] = ACTIONS(4860),
    [anon_sym_restrict] = ACTIONS(4860),
    [anon_sym_not] = ACTIONS(4860),
    [anon_sym_or] = ACTIONS(4860),
    [anon_sym_and] = ACTIONS(4860),
    [anon_sym_case] = ACTIONS(4860),
    [anon_sym_always] = ACTIONS(4860),
    [anon_sym_covergroup] = ACTIONS(4860),
    [anon_sym_let] = ACTIONS(4860),
    [anon_sym_pulldown] = ACTIONS(4860),
    [anon_sym_pullup] = ACTIONS(4860),
    [anon_sym_cmos] = ACTIONS(4860),
    [anon_sym_rcmos] = ACTIONS(4860),
    [anon_sym_bufif0] = ACTIONS(4860),
    [anon_sym_bufif1] = ACTIONS(4860),
    [anon_sym_notif0] = ACTIONS(4860),
    [anon_sym_notif1] = ACTIONS(4860),
    [anon_sym_nmos] = ACTIONS(4860),
    [anon_sym_pmos] = ACTIONS(4860),
    [anon_sym_rnmos] = ACTIONS(4860),
    [anon_sym_rpmos] = ACTIONS(4860),
    [anon_sym_nand] = ACTIONS(4860),
    [anon_sym_nor] = ACTIONS(4860),
    [anon_sym_xor] = ACTIONS(4860),
    [anon_sym_xnor] = ACTIONS(4860),
    [anon_sym_buf] = ACTIONS(4860),
    [anon_sym_tranif0] = ACTIONS(4860),
    [anon_sym_tranif1] = ACTIONS(4860),
    [anon_sym_rtranif1] = ACTIONS(4860),
    [anon_sym_rtranif0] = ACTIONS(4860),
    [anon_sym_tran] = ACTIONS(4860),
    [anon_sym_rtran] = ACTIONS(4860),
    [anon_sym_generate] = ACTIONS(4860),
    [anon_sym_for] = ACTIONS(4860),
    [anon_sym_primitive] = ACTIONS(4860),
    [anon_sym_initial] = ACTIONS(4860),
    [anon_sym_assign] = ACTIONS(4860),
    [anon_sym_alias] = ACTIONS(4860),
    [anon_sym_always_comb] = ACTIONS(4860),
    [anon_sym_always_latch] = ACTIONS(4860),
    [anon_sym_always_ff] = ACTIONS(4860),
    [anon_sym_final] = ACTIONS(4860),
    [anon_sym_global] = ACTIONS(4860),
    [anon_sym_specify] = ACTIONS(4860),
    [anon_sym_LPAREN_STAR] = ACTIONS(4858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4858),
    [anon_sym_DOLLARunit] = ACTIONS(4858),
  },
  [784] = {
    [ts_builtin_sym_end] = ACTIONS(4622),
    [sym_simple_identifier] = ACTIONS(4624),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4622),
    [anon_sym_BQUOTE] = ACTIONS(4624),
    [aux_sym_id_directive_token1] = ACTIONS(4622),
    [aux_sym_id_directive_token2] = ACTIONS(4622),
    [aux_sym_id_directive_token3] = ACTIONS(4622),
    [aux_sym_id_directive_token4] = ACTIONS(4624),
    [aux_sym_zero_directive_token1] = ACTIONS(4622),
    [aux_sym_zero_directive_token2] = ACTIONS(4622),
    [aux_sym_zero_directive_token3] = ACTIONS(4622),
    [aux_sym_zero_directive_token4] = ACTIONS(4622),
    [aux_sym_zero_directive_token5] = ACTIONS(4622),
    [aux_sym_zero_directive_token6] = ACTIONS(4622),
    [aux_sym_zero_directive_token7] = ACTIONS(4622),
    [aux_sym_zero_directive_token8] = ACTIONS(4622),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4622),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4622),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4622),
    [aux_sym_begin_keywords_token1] = ACTIONS(4622),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_endmodule] = ACTIONS(4624),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_module] = ACTIONS(4624),
    [anon_sym_macromodule] = ACTIONS(4624),
    [anon_sym_endinterface] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_endprogram] = ACTIONS(4624),
    [anon_sym_program] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_package] = ACTIONS(4624),
    [anon_sym_endpackage] = ACTIONS(4624),
    [anon_sym_timeunit] = ACTIONS(4624),
    [anon_sym_timeprecision] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_input] = ACTIONS(4624),
    [anon_sym_output] = ACTIONS(4624),
    [anon_sym_inout] = ACTIONS(4624),
    [anon_sym_ref] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_specparam] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_modport] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_primitive] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_specify] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [785] = {
    [ts_builtin_sym_end] = ACTIONS(4862),
    [sym_simple_identifier] = ACTIONS(4864),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4862),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4862),
    [anon_sym_BQUOTE] = ACTIONS(4864),
    [aux_sym_id_directive_token1] = ACTIONS(4862),
    [aux_sym_id_directive_token2] = ACTIONS(4862),
    [aux_sym_id_directive_token3] = ACTIONS(4862),
    [aux_sym_id_directive_token4] = ACTIONS(4864),
    [aux_sym_zero_directive_token1] = ACTIONS(4862),
    [aux_sym_zero_directive_token2] = ACTIONS(4862),
    [aux_sym_zero_directive_token3] = ACTIONS(4862),
    [aux_sym_zero_directive_token4] = ACTIONS(4862),
    [aux_sym_zero_directive_token5] = ACTIONS(4862),
    [aux_sym_zero_directive_token6] = ACTIONS(4862),
    [aux_sym_zero_directive_token7] = ACTIONS(4862),
    [aux_sym_zero_directive_token8] = ACTIONS(4862),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4862),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4862),
    [anon_sym_wire] = ACTIONS(4864),
    [anon_sym_tri] = ACTIONS(4864),
    [anon_sym_tri0] = ACTIONS(4864),
    [anon_sym_tri1] = ACTIONS(4864),
    [anon_sym_wand] = ACTIONS(4864),
    [anon_sym_triand] = ACTIONS(4864),
    [anon_sym_wor] = ACTIONS(4864),
    [anon_sym_trior] = ACTIONS(4864),
    [anon_sym_trireg] = ACTIONS(4864),
    [anon_sym_uwire] = ACTIONS(4864),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4862),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4862),
    [aux_sym_begin_keywords_token1] = ACTIONS(4862),
    [anon_sym_SEMI] = ACTIONS(4862),
    [anon_sym_endmodule] = ACTIONS(4864),
    [anon_sym_extern] = ACTIONS(4864),
    [anon_sym_module] = ACTIONS(4864),
    [anon_sym_macromodule] = ACTIONS(4864),
    [anon_sym_endinterface] = ACTIONS(4864),
    [anon_sym_interface] = ACTIONS(4864),
    [anon_sym_endprogram] = ACTIONS(4864),
    [anon_sym_program] = ACTIONS(4864),
    [anon_sym_checker] = ACTIONS(4864),
    [anon_sym_virtual] = ACTIONS(4864),
    [anon_sym_class] = ACTIONS(4864),
    [anon_sym_package] = ACTIONS(4864),
    [anon_sym_endpackage] = ACTIONS(4864),
    [anon_sym_timeunit] = ACTIONS(4864),
    [anon_sym_timeprecision] = ACTIONS(4864),
    [anon_sym_type] = ACTIONS(4864),
    [anon_sym_input] = ACTIONS(4864),
    [anon_sym_output] = ACTIONS(4864),
    [anon_sym_inout] = ACTIONS(4864),
    [anon_sym_ref] = ACTIONS(4864),
    [anon_sym_DOLLARfatal] = ACTIONS(4862),
    [anon_sym_DOLLARerror] = ACTIONS(4862),
    [anon_sym_DOLLARwarning] = ACTIONS(4862),
    [anon_sym_DOLLARinfo] = ACTIONS(4862),
    [anon_sym_default] = ACTIONS(4864),
    [anon_sym_clocking] = ACTIONS(4864),
    [anon_sym_defparam] = ACTIONS(4864),
    [anon_sym_bind] = ACTIONS(4864),
    [anon_sym_const] = ACTIONS(4864),
    [anon_sym_function] = ACTIONS(4864),
    [anon_sym_static] = ACTIONS(4864),
    [anon_sym_constraint] = ACTIONS(4864),
    [anon_sym_if] = ACTIONS(4864),
    [anon_sym_else] = ACTIONS(4864),
    [anon_sym_LBRACK] = ACTIONS(4862),
    [anon_sym_localparam] = ACTIONS(4864),
    [anon_sym_parameter] = ACTIONS(4864),
    [anon_sym_specparam] = ACTIONS(4864),
    [anon_sym_var] = ACTIONS(4864),
    [anon_sym_import] = ACTIONS(4864),
    [anon_sym_export] = ACTIONS(4864),
    [anon_sym_genvar] = ACTIONS(4864),
    [anon_sym_interconnect] = ACTIONS(4864),
    [anon_sym_typedef] = ACTIONS(4864),
    [anon_sym_enum] = ACTIONS(4864),
    [anon_sym_struct] = ACTIONS(4864),
    [anon_sym_union] = ACTIONS(4864),
    [anon_sym_nettype] = ACTIONS(4864),
    [anon_sym_automatic] = ACTIONS(4864),
    [anon_sym_string] = ACTIONS(4864),
    [anon_sym_chandle] = ACTIONS(4864),
    [anon_sym_event] = ACTIONS(4864),
    [anon_sym_byte] = ACTIONS(4864),
    [anon_sym_shortint] = ACTIONS(4864),
    [anon_sym_int] = ACTIONS(4864),
    [anon_sym_longint] = ACTIONS(4864),
    [anon_sym_integer] = ACTIONS(4864),
    [anon_sym_time] = ACTIONS(4864),
    [anon_sym_bit] = ACTIONS(4864),
    [anon_sym_logic] = ACTIONS(4864),
    [anon_sym_reg] = ACTIONS(4864),
    [anon_sym_shortreal] = ACTIONS(4864),
    [anon_sym_real] = ACTIONS(4864),
    [anon_sym_realtime] = ACTIONS(4864),
    [anon_sym_supply0] = ACTIONS(4864),
    [anon_sym_supply1] = ACTIONS(4864),
    [anon_sym_signed] = ACTIONS(4864),
    [anon_sym_unsigned] = ACTIONS(4864),
    [anon_sym_task] = ACTIONS(4864),
    [anon_sym_modport] = ACTIONS(4864),
    [anon_sym_assert] = ACTIONS(4864),
    [anon_sym_property] = ACTIONS(4864),
    [anon_sym_assume] = ACTIONS(4864),
    [anon_sym_cover] = ACTIONS(4864),
    [anon_sym_sequence] = ACTIONS(4864),
    [anon_sym_restrict] = ACTIONS(4864),
    [anon_sym_not] = ACTIONS(4864),
    [anon_sym_or] = ACTIONS(4864),
    [anon_sym_and] = ACTIONS(4864),
    [anon_sym_case] = ACTIONS(4864),
    [anon_sym_always] = ACTIONS(4864),
    [anon_sym_covergroup] = ACTIONS(4864),
    [anon_sym_let] = ACTIONS(4864),
    [anon_sym_pulldown] = ACTIONS(4864),
    [anon_sym_pullup] = ACTIONS(4864),
    [anon_sym_cmos] = ACTIONS(4864),
    [anon_sym_rcmos] = ACTIONS(4864),
    [anon_sym_bufif0] = ACTIONS(4864),
    [anon_sym_bufif1] = ACTIONS(4864),
    [anon_sym_notif0] = ACTIONS(4864),
    [anon_sym_notif1] = ACTIONS(4864),
    [anon_sym_nmos] = ACTIONS(4864),
    [anon_sym_pmos] = ACTIONS(4864),
    [anon_sym_rnmos] = ACTIONS(4864),
    [anon_sym_rpmos] = ACTIONS(4864),
    [anon_sym_nand] = ACTIONS(4864),
    [anon_sym_nor] = ACTIONS(4864),
    [anon_sym_xor] = ACTIONS(4864),
    [anon_sym_xnor] = ACTIONS(4864),
    [anon_sym_buf] = ACTIONS(4864),
    [anon_sym_tranif0] = ACTIONS(4864),
    [anon_sym_tranif1] = ACTIONS(4864),
    [anon_sym_rtranif1] = ACTIONS(4864),
    [anon_sym_rtranif0] = ACTIONS(4864),
    [anon_sym_tran] = ACTIONS(4864),
    [anon_sym_rtran] = ACTIONS(4864),
    [anon_sym_generate] = ACTIONS(4864),
    [anon_sym_for] = ACTIONS(4864),
    [anon_sym_primitive] = ACTIONS(4864),
    [anon_sym_initial] = ACTIONS(4864),
    [anon_sym_assign] = ACTIONS(4864),
    [anon_sym_alias] = ACTIONS(4864),
    [anon_sym_always_comb] = ACTIONS(4864),
    [anon_sym_always_latch] = ACTIONS(4864),
    [anon_sym_always_ff] = ACTIONS(4864),
    [anon_sym_final] = ACTIONS(4864),
    [anon_sym_global] = ACTIONS(4864),
    [anon_sym_specify] = ACTIONS(4864),
    [anon_sym_LPAREN_STAR] = ACTIONS(4862),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4862),
    [anon_sym_DOLLARunit] = ACTIONS(4862),
  },
  [786] = {
    [ts_builtin_sym_end] = ACTIONS(4866),
    [sym_simple_identifier] = ACTIONS(4868),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4866),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4866),
    [anon_sym_BQUOTE] = ACTIONS(4868),
    [aux_sym_id_directive_token1] = ACTIONS(4866),
    [aux_sym_id_directive_token2] = ACTIONS(4866),
    [aux_sym_id_directive_token3] = ACTIONS(4866),
    [aux_sym_id_directive_token4] = ACTIONS(4868),
    [aux_sym_zero_directive_token1] = ACTIONS(4866),
    [aux_sym_zero_directive_token2] = ACTIONS(4866),
    [aux_sym_zero_directive_token3] = ACTIONS(4866),
    [aux_sym_zero_directive_token4] = ACTIONS(4866),
    [aux_sym_zero_directive_token5] = ACTIONS(4866),
    [aux_sym_zero_directive_token6] = ACTIONS(4866),
    [aux_sym_zero_directive_token7] = ACTIONS(4866),
    [aux_sym_zero_directive_token8] = ACTIONS(4866),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4866),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4866),
    [anon_sym_wire] = ACTIONS(4868),
    [anon_sym_tri] = ACTIONS(4868),
    [anon_sym_tri0] = ACTIONS(4868),
    [anon_sym_tri1] = ACTIONS(4868),
    [anon_sym_wand] = ACTIONS(4868),
    [anon_sym_triand] = ACTIONS(4868),
    [anon_sym_wor] = ACTIONS(4868),
    [anon_sym_trior] = ACTIONS(4868),
    [anon_sym_trireg] = ACTIONS(4868),
    [anon_sym_uwire] = ACTIONS(4868),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4866),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4866),
    [aux_sym_begin_keywords_token1] = ACTIONS(4866),
    [anon_sym_SEMI] = ACTIONS(4866),
    [anon_sym_endmodule] = ACTIONS(4868),
    [anon_sym_extern] = ACTIONS(4868),
    [anon_sym_module] = ACTIONS(4868),
    [anon_sym_macromodule] = ACTIONS(4868),
    [anon_sym_endinterface] = ACTIONS(4868),
    [anon_sym_interface] = ACTIONS(4868),
    [anon_sym_endprogram] = ACTIONS(4868),
    [anon_sym_program] = ACTIONS(4868),
    [anon_sym_checker] = ACTIONS(4868),
    [anon_sym_virtual] = ACTIONS(4868),
    [anon_sym_class] = ACTIONS(4868),
    [anon_sym_package] = ACTIONS(4868),
    [anon_sym_endpackage] = ACTIONS(4868),
    [anon_sym_timeunit] = ACTIONS(4868),
    [anon_sym_timeprecision] = ACTIONS(4868),
    [anon_sym_type] = ACTIONS(4868),
    [anon_sym_input] = ACTIONS(4868),
    [anon_sym_output] = ACTIONS(4868),
    [anon_sym_inout] = ACTIONS(4868),
    [anon_sym_ref] = ACTIONS(4868),
    [anon_sym_DOLLARfatal] = ACTIONS(4866),
    [anon_sym_DOLLARerror] = ACTIONS(4866),
    [anon_sym_DOLLARwarning] = ACTIONS(4866),
    [anon_sym_DOLLARinfo] = ACTIONS(4866),
    [anon_sym_default] = ACTIONS(4868),
    [anon_sym_clocking] = ACTIONS(4868),
    [anon_sym_defparam] = ACTIONS(4868),
    [anon_sym_bind] = ACTIONS(4868),
    [anon_sym_const] = ACTIONS(4868),
    [anon_sym_function] = ACTIONS(4868),
    [anon_sym_static] = ACTIONS(4868),
    [anon_sym_constraint] = ACTIONS(4868),
    [anon_sym_if] = ACTIONS(4868),
    [anon_sym_else] = ACTIONS(4868),
    [anon_sym_LBRACK] = ACTIONS(4866),
    [anon_sym_localparam] = ACTIONS(4868),
    [anon_sym_parameter] = ACTIONS(4868),
    [anon_sym_specparam] = ACTIONS(4868),
    [anon_sym_var] = ACTIONS(4868),
    [anon_sym_import] = ACTIONS(4868),
    [anon_sym_export] = ACTIONS(4868),
    [anon_sym_genvar] = ACTIONS(4868),
    [anon_sym_interconnect] = ACTIONS(4868),
    [anon_sym_typedef] = ACTIONS(4868),
    [anon_sym_enum] = ACTIONS(4868),
    [anon_sym_struct] = ACTIONS(4868),
    [anon_sym_union] = ACTIONS(4868),
    [anon_sym_nettype] = ACTIONS(4868),
    [anon_sym_automatic] = ACTIONS(4868),
    [anon_sym_string] = ACTIONS(4868),
    [anon_sym_chandle] = ACTIONS(4868),
    [anon_sym_event] = ACTIONS(4868),
    [anon_sym_byte] = ACTIONS(4868),
    [anon_sym_shortint] = ACTIONS(4868),
    [anon_sym_int] = ACTIONS(4868),
    [anon_sym_longint] = ACTIONS(4868),
    [anon_sym_integer] = ACTIONS(4868),
    [anon_sym_time] = ACTIONS(4868),
    [anon_sym_bit] = ACTIONS(4868),
    [anon_sym_logic] = ACTIONS(4868),
    [anon_sym_reg] = ACTIONS(4868),
    [anon_sym_shortreal] = ACTIONS(4868),
    [anon_sym_real] = ACTIONS(4868),
    [anon_sym_realtime] = ACTIONS(4868),
    [anon_sym_supply0] = ACTIONS(4868),
    [anon_sym_supply1] = ACTIONS(4868),
    [anon_sym_signed] = ACTIONS(4868),
    [anon_sym_unsigned] = ACTIONS(4868),
    [anon_sym_task] = ACTIONS(4868),
    [anon_sym_modport] = ACTIONS(4868),
    [anon_sym_assert] = ACTIONS(4868),
    [anon_sym_property] = ACTIONS(4868),
    [anon_sym_assume] = ACTIONS(4868),
    [anon_sym_cover] = ACTIONS(4868),
    [anon_sym_sequence] = ACTIONS(4868),
    [anon_sym_restrict] = ACTIONS(4868),
    [anon_sym_not] = ACTIONS(4868),
    [anon_sym_or] = ACTIONS(4868),
    [anon_sym_and] = ACTIONS(4868),
    [anon_sym_case] = ACTIONS(4868),
    [anon_sym_always] = ACTIONS(4868),
    [anon_sym_covergroup] = ACTIONS(4868),
    [anon_sym_let] = ACTIONS(4868),
    [anon_sym_pulldown] = ACTIONS(4868),
    [anon_sym_pullup] = ACTIONS(4868),
    [anon_sym_cmos] = ACTIONS(4868),
    [anon_sym_rcmos] = ACTIONS(4868),
    [anon_sym_bufif0] = ACTIONS(4868),
    [anon_sym_bufif1] = ACTIONS(4868),
    [anon_sym_notif0] = ACTIONS(4868),
    [anon_sym_notif1] = ACTIONS(4868),
    [anon_sym_nmos] = ACTIONS(4868),
    [anon_sym_pmos] = ACTIONS(4868),
    [anon_sym_rnmos] = ACTIONS(4868),
    [anon_sym_rpmos] = ACTIONS(4868),
    [anon_sym_nand] = ACTIONS(4868),
    [anon_sym_nor] = ACTIONS(4868),
    [anon_sym_xor] = ACTIONS(4868),
    [anon_sym_xnor] = ACTIONS(4868),
    [anon_sym_buf] = ACTIONS(4868),
    [anon_sym_tranif0] = ACTIONS(4868),
    [anon_sym_tranif1] = ACTIONS(4868),
    [anon_sym_rtranif1] = ACTIONS(4868),
    [anon_sym_rtranif0] = ACTIONS(4868),
    [anon_sym_tran] = ACTIONS(4868),
    [anon_sym_rtran] = ACTIONS(4868),
    [anon_sym_generate] = ACTIONS(4868),
    [anon_sym_for] = ACTIONS(4868),
    [anon_sym_primitive] = ACTIONS(4868),
    [anon_sym_initial] = ACTIONS(4868),
    [anon_sym_assign] = ACTIONS(4868),
    [anon_sym_alias] = ACTIONS(4868),
    [anon_sym_always_comb] = ACTIONS(4868),
    [anon_sym_always_latch] = ACTIONS(4868),
    [anon_sym_always_ff] = ACTIONS(4868),
    [anon_sym_final] = ACTIONS(4868),
    [anon_sym_global] = ACTIONS(4868),
    [anon_sym_specify] = ACTIONS(4868),
    [anon_sym_LPAREN_STAR] = ACTIONS(4866),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4866),
    [anon_sym_DOLLARunit] = ACTIONS(4866),
  },
  [787] = {
    [ts_builtin_sym_end] = ACTIONS(4870),
    [sym_simple_identifier] = ACTIONS(4872),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4870),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4870),
    [anon_sym_BQUOTE] = ACTIONS(4872),
    [aux_sym_id_directive_token1] = ACTIONS(4870),
    [aux_sym_id_directive_token2] = ACTIONS(4870),
    [aux_sym_id_directive_token3] = ACTIONS(4870),
    [aux_sym_id_directive_token4] = ACTIONS(4872),
    [aux_sym_zero_directive_token1] = ACTIONS(4870),
    [aux_sym_zero_directive_token2] = ACTIONS(4870),
    [aux_sym_zero_directive_token3] = ACTIONS(4870),
    [aux_sym_zero_directive_token4] = ACTIONS(4870),
    [aux_sym_zero_directive_token5] = ACTIONS(4870),
    [aux_sym_zero_directive_token6] = ACTIONS(4870),
    [aux_sym_zero_directive_token7] = ACTIONS(4870),
    [aux_sym_zero_directive_token8] = ACTIONS(4870),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4870),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4870),
    [anon_sym_wire] = ACTIONS(4872),
    [anon_sym_tri] = ACTIONS(4872),
    [anon_sym_tri0] = ACTIONS(4872),
    [anon_sym_tri1] = ACTIONS(4872),
    [anon_sym_wand] = ACTIONS(4872),
    [anon_sym_triand] = ACTIONS(4872),
    [anon_sym_wor] = ACTIONS(4872),
    [anon_sym_trior] = ACTIONS(4872),
    [anon_sym_trireg] = ACTIONS(4872),
    [anon_sym_uwire] = ACTIONS(4872),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4870),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4870),
    [aux_sym_begin_keywords_token1] = ACTIONS(4870),
    [anon_sym_SEMI] = ACTIONS(4870),
    [anon_sym_endmodule] = ACTIONS(4872),
    [anon_sym_extern] = ACTIONS(4872),
    [anon_sym_module] = ACTIONS(4872),
    [anon_sym_macromodule] = ACTIONS(4872),
    [anon_sym_endinterface] = ACTIONS(4872),
    [anon_sym_interface] = ACTIONS(4872),
    [anon_sym_endprogram] = ACTIONS(4872),
    [anon_sym_program] = ACTIONS(4872),
    [anon_sym_checker] = ACTIONS(4872),
    [anon_sym_virtual] = ACTIONS(4872),
    [anon_sym_class] = ACTIONS(4872),
    [anon_sym_package] = ACTIONS(4872),
    [anon_sym_endpackage] = ACTIONS(4872),
    [anon_sym_timeunit] = ACTIONS(4872),
    [anon_sym_timeprecision] = ACTIONS(4872),
    [anon_sym_type] = ACTIONS(4872),
    [anon_sym_input] = ACTIONS(4872),
    [anon_sym_output] = ACTIONS(4872),
    [anon_sym_inout] = ACTIONS(4872),
    [anon_sym_ref] = ACTIONS(4872),
    [anon_sym_DOLLARfatal] = ACTIONS(4870),
    [anon_sym_DOLLARerror] = ACTIONS(4870),
    [anon_sym_DOLLARwarning] = ACTIONS(4870),
    [anon_sym_DOLLARinfo] = ACTIONS(4870),
    [anon_sym_default] = ACTIONS(4872),
    [anon_sym_clocking] = ACTIONS(4872),
    [anon_sym_defparam] = ACTIONS(4872),
    [anon_sym_bind] = ACTIONS(4872),
    [anon_sym_const] = ACTIONS(4872),
    [anon_sym_function] = ACTIONS(4872),
    [anon_sym_static] = ACTIONS(4872),
    [anon_sym_constraint] = ACTIONS(4872),
    [anon_sym_if] = ACTIONS(4872),
    [anon_sym_else] = ACTIONS(4872),
    [anon_sym_LBRACK] = ACTIONS(4870),
    [anon_sym_localparam] = ACTIONS(4872),
    [anon_sym_parameter] = ACTIONS(4872),
    [anon_sym_specparam] = ACTIONS(4872),
    [anon_sym_var] = ACTIONS(4872),
    [anon_sym_import] = ACTIONS(4872),
    [anon_sym_export] = ACTIONS(4872),
    [anon_sym_genvar] = ACTIONS(4872),
    [anon_sym_interconnect] = ACTIONS(4872),
    [anon_sym_typedef] = ACTIONS(4872),
    [anon_sym_enum] = ACTIONS(4872),
    [anon_sym_struct] = ACTIONS(4872),
    [anon_sym_union] = ACTIONS(4872),
    [anon_sym_nettype] = ACTIONS(4872),
    [anon_sym_automatic] = ACTIONS(4872),
    [anon_sym_string] = ACTIONS(4872),
    [anon_sym_chandle] = ACTIONS(4872),
    [anon_sym_event] = ACTIONS(4872),
    [anon_sym_byte] = ACTIONS(4872),
    [anon_sym_shortint] = ACTIONS(4872),
    [anon_sym_int] = ACTIONS(4872),
    [anon_sym_longint] = ACTIONS(4872),
    [anon_sym_integer] = ACTIONS(4872),
    [anon_sym_time] = ACTIONS(4872),
    [anon_sym_bit] = ACTIONS(4872),
    [anon_sym_logic] = ACTIONS(4872),
    [anon_sym_reg] = ACTIONS(4872),
    [anon_sym_shortreal] = ACTIONS(4872),
    [anon_sym_real] = ACTIONS(4872),
    [anon_sym_realtime] = ACTIONS(4872),
    [anon_sym_supply0] = ACTIONS(4872),
    [anon_sym_supply1] = ACTIONS(4872),
    [anon_sym_signed] = ACTIONS(4872),
    [anon_sym_unsigned] = ACTIONS(4872),
    [anon_sym_task] = ACTIONS(4872),
    [anon_sym_modport] = ACTIONS(4872),
    [anon_sym_assert] = ACTIONS(4872),
    [anon_sym_property] = ACTIONS(4872),
    [anon_sym_assume] = ACTIONS(4872),
    [anon_sym_cover] = ACTIONS(4872),
    [anon_sym_sequence] = ACTIONS(4872),
    [anon_sym_restrict] = ACTIONS(4872),
    [anon_sym_not] = ACTIONS(4872),
    [anon_sym_or] = ACTIONS(4872),
    [anon_sym_and] = ACTIONS(4872),
    [anon_sym_case] = ACTIONS(4872),
    [anon_sym_always] = ACTIONS(4872),
    [anon_sym_covergroup] = ACTIONS(4872),
    [anon_sym_let] = ACTIONS(4872),
    [anon_sym_pulldown] = ACTIONS(4872),
    [anon_sym_pullup] = ACTIONS(4872),
    [anon_sym_cmos] = ACTIONS(4872),
    [anon_sym_rcmos] = ACTIONS(4872),
    [anon_sym_bufif0] = ACTIONS(4872),
    [anon_sym_bufif1] = ACTIONS(4872),
    [anon_sym_notif0] = ACTIONS(4872),
    [anon_sym_notif1] = ACTIONS(4872),
    [anon_sym_nmos] = ACTIONS(4872),
    [anon_sym_pmos] = ACTIONS(4872),
    [anon_sym_rnmos] = ACTIONS(4872),
    [anon_sym_rpmos] = ACTIONS(4872),
    [anon_sym_nand] = ACTIONS(4872),
    [anon_sym_nor] = ACTIONS(4872),
    [anon_sym_xor] = ACTIONS(4872),
    [anon_sym_xnor] = ACTIONS(4872),
    [anon_sym_buf] = ACTIONS(4872),
    [anon_sym_tranif0] = ACTIONS(4872),
    [anon_sym_tranif1] = ACTIONS(4872),
    [anon_sym_rtranif1] = ACTIONS(4872),
    [anon_sym_rtranif0] = ACTIONS(4872),
    [anon_sym_tran] = ACTIONS(4872),
    [anon_sym_rtran] = ACTIONS(4872),
    [anon_sym_generate] = ACTIONS(4872),
    [anon_sym_for] = ACTIONS(4872),
    [anon_sym_primitive] = ACTIONS(4872),
    [anon_sym_initial] = ACTIONS(4872),
    [anon_sym_assign] = ACTIONS(4872),
    [anon_sym_alias] = ACTIONS(4872),
    [anon_sym_always_comb] = ACTIONS(4872),
    [anon_sym_always_latch] = ACTIONS(4872),
    [anon_sym_always_ff] = ACTIONS(4872),
    [anon_sym_final] = ACTIONS(4872),
    [anon_sym_global] = ACTIONS(4872),
    [anon_sym_specify] = ACTIONS(4872),
    [anon_sym_LPAREN_STAR] = ACTIONS(4870),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4870),
    [anon_sym_DOLLARunit] = ACTIONS(4870),
  },
  [788] = {
    [ts_builtin_sym_end] = ACTIONS(4874),
    [sym_simple_identifier] = ACTIONS(4876),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4874),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4874),
    [anon_sym_BQUOTE] = ACTIONS(4876),
    [aux_sym_id_directive_token1] = ACTIONS(4874),
    [aux_sym_id_directive_token2] = ACTIONS(4874),
    [aux_sym_id_directive_token3] = ACTIONS(4874),
    [aux_sym_id_directive_token4] = ACTIONS(4876),
    [aux_sym_zero_directive_token1] = ACTIONS(4874),
    [aux_sym_zero_directive_token2] = ACTIONS(4874),
    [aux_sym_zero_directive_token3] = ACTIONS(4874),
    [aux_sym_zero_directive_token4] = ACTIONS(4874),
    [aux_sym_zero_directive_token5] = ACTIONS(4874),
    [aux_sym_zero_directive_token6] = ACTIONS(4874),
    [aux_sym_zero_directive_token7] = ACTIONS(4874),
    [aux_sym_zero_directive_token8] = ACTIONS(4874),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4874),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4874),
    [anon_sym_wire] = ACTIONS(4876),
    [anon_sym_tri] = ACTIONS(4876),
    [anon_sym_tri0] = ACTIONS(4876),
    [anon_sym_tri1] = ACTIONS(4876),
    [anon_sym_wand] = ACTIONS(4876),
    [anon_sym_triand] = ACTIONS(4876),
    [anon_sym_wor] = ACTIONS(4876),
    [anon_sym_trior] = ACTIONS(4876),
    [anon_sym_trireg] = ACTIONS(4876),
    [anon_sym_uwire] = ACTIONS(4876),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4874),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4874),
    [aux_sym_begin_keywords_token1] = ACTIONS(4874),
    [anon_sym_SEMI] = ACTIONS(4874),
    [anon_sym_endmodule] = ACTIONS(4876),
    [anon_sym_extern] = ACTIONS(4876),
    [anon_sym_module] = ACTIONS(4876),
    [anon_sym_macromodule] = ACTIONS(4876),
    [anon_sym_endinterface] = ACTIONS(4876),
    [anon_sym_interface] = ACTIONS(4876),
    [anon_sym_endprogram] = ACTIONS(4876),
    [anon_sym_program] = ACTIONS(4876),
    [anon_sym_checker] = ACTIONS(4876),
    [anon_sym_virtual] = ACTIONS(4876),
    [anon_sym_class] = ACTIONS(4876),
    [anon_sym_package] = ACTIONS(4876),
    [anon_sym_endpackage] = ACTIONS(4876),
    [anon_sym_timeunit] = ACTIONS(4876),
    [anon_sym_timeprecision] = ACTIONS(4876),
    [anon_sym_type] = ACTIONS(4876),
    [anon_sym_input] = ACTIONS(4876),
    [anon_sym_output] = ACTIONS(4876),
    [anon_sym_inout] = ACTIONS(4876),
    [anon_sym_ref] = ACTIONS(4876),
    [anon_sym_DOLLARfatal] = ACTIONS(4874),
    [anon_sym_DOLLARerror] = ACTIONS(4874),
    [anon_sym_DOLLARwarning] = ACTIONS(4874),
    [anon_sym_DOLLARinfo] = ACTIONS(4874),
    [anon_sym_default] = ACTIONS(4876),
    [anon_sym_clocking] = ACTIONS(4876),
    [anon_sym_defparam] = ACTIONS(4876),
    [anon_sym_bind] = ACTIONS(4876),
    [anon_sym_const] = ACTIONS(4876),
    [anon_sym_function] = ACTIONS(4876),
    [anon_sym_static] = ACTIONS(4876),
    [anon_sym_constraint] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4876),
    [anon_sym_else] = ACTIONS(4876),
    [anon_sym_LBRACK] = ACTIONS(4874),
    [anon_sym_localparam] = ACTIONS(4876),
    [anon_sym_parameter] = ACTIONS(4876),
    [anon_sym_specparam] = ACTIONS(4876),
    [anon_sym_var] = ACTIONS(4876),
    [anon_sym_import] = ACTIONS(4876),
    [anon_sym_export] = ACTIONS(4876),
    [anon_sym_genvar] = ACTIONS(4876),
    [anon_sym_interconnect] = ACTIONS(4876),
    [anon_sym_typedef] = ACTIONS(4876),
    [anon_sym_enum] = ACTIONS(4876),
    [anon_sym_struct] = ACTIONS(4876),
    [anon_sym_union] = ACTIONS(4876),
    [anon_sym_nettype] = ACTIONS(4876),
    [anon_sym_automatic] = ACTIONS(4876),
    [anon_sym_string] = ACTIONS(4876),
    [anon_sym_chandle] = ACTIONS(4876),
    [anon_sym_event] = ACTIONS(4876),
    [anon_sym_byte] = ACTIONS(4876),
    [anon_sym_shortint] = ACTIONS(4876),
    [anon_sym_int] = ACTIONS(4876),
    [anon_sym_longint] = ACTIONS(4876),
    [anon_sym_integer] = ACTIONS(4876),
    [anon_sym_time] = ACTIONS(4876),
    [anon_sym_bit] = ACTIONS(4876),
    [anon_sym_logic] = ACTIONS(4876),
    [anon_sym_reg] = ACTIONS(4876),
    [anon_sym_shortreal] = ACTIONS(4876),
    [anon_sym_real] = ACTIONS(4876),
    [anon_sym_realtime] = ACTIONS(4876),
    [anon_sym_supply0] = ACTIONS(4876),
    [anon_sym_supply1] = ACTIONS(4876),
    [anon_sym_signed] = ACTIONS(4876),
    [anon_sym_unsigned] = ACTIONS(4876),
    [anon_sym_task] = ACTIONS(4876),
    [anon_sym_modport] = ACTIONS(4876),
    [anon_sym_assert] = ACTIONS(4876),
    [anon_sym_property] = ACTIONS(4876),
    [anon_sym_assume] = ACTIONS(4876),
    [anon_sym_cover] = ACTIONS(4876),
    [anon_sym_sequence] = ACTIONS(4876),
    [anon_sym_restrict] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4876),
    [anon_sym_or] = ACTIONS(4876),
    [anon_sym_and] = ACTIONS(4876),
    [anon_sym_case] = ACTIONS(4876),
    [anon_sym_always] = ACTIONS(4876),
    [anon_sym_covergroup] = ACTIONS(4876),
    [anon_sym_let] = ACTIONS(4876),
    [anon_sym_pulldown] = ACTIONS(4876),
    [anon_sym_pullup] = ACTIONS(4876),
    [anon_sym_cmos] = ACTIONS(4876),
    [anon_sym_rcmos] = ACTIONS(4876),
    [anon_sym_bufif0] = ACTIONS(4876),
    [anon_sym_bufif1] = ACTIONS(4876),
    [anon_sym_notif0] = ACTIONS(4876),
    [anon_sym_notif1] = ACTIONS(4876),
    [anon_sym_nmos] = ACTIONS(4876),
    [anon_sym_pmos] = ACTIONS(4876),
    [anon_sym_rnmos] = ACTIONS(4876),
    [anon_sym_rpmos] = ACTIONS(4876),
    [anon_sym_nand] = ACTIONS(4876),
    [anon_sym_nor] = ACTIONS(4876),
    [anon_sym_xor] = ACTIONS(4876),
    [anon_sym_xnor] = ACTIONS(4876),
    [anon_sym_buf] = ACTIONS(4876),
    [anon_sym_tranif0] = ACTIONS(4876),
    [anon_sym_tranif1] = ACTIONS(4876),
    [anon_sym_rtranif1] = ACTIONS(4876),
    [anon_sym_rtranif0] = ACTIONS(4876),
    [anon_sym_tran] = ACTIONS(4876),
    [anon_sym_rtran] = ACTIONS(4876),
    [anon_sym_generate] = ACTIONS(4876),
    [anon_sym_for] = ACTIONS(4876),
    [anon_sym_primitive] = ACTIONS(4876),
    [anon_sym_initial] = ACTIONS(4876),
    [anon_sym_assign] = ACTIONS(4876),
    [anon_sym_alias] = ACTIONS(4876),
    [anon_sym_always_comb] = ACTIONS(4876),
    [anon_sym_always_latch] = ACTIONS(4876),
    [anon_sym_always_ff] = ACTIONS(4876),
    [anon_sym_final] = ACTIONS(4876),
    [anon_sym_global] = ACTIONS(4876),
    [anon_sym_specify] = ACTIONS(4876),
    [anon_sym_LPAREN_STAR] = ACTIONS(4874),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4874),
    [anon_sym_DOLLARunit] = ACTIONS(4874),
  },
  [789] = {
    [ts_builtin_sym_end] = ACTIONS(4878),
    [sym_simple_identifier] = ACTIONS(4880),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4878),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4878),
    [anon_sym_BQUOTE] = ACTIONS(4880),
    [aux_sym_id_directive_token1] = ACTIONS(4878),
    [aux_sym_id_directive_token2] = ACTIONS(4878),
    [aux_sym_id_directive_token3] = ACTIONS(4878),
    [aux_sym_id_directive_token4] = ACTIONS(4880),
    [aux_sym_zero_directive_token1] = ACTIONS(4878),
    [aux_sym_zero_directive_token2] = ACTIONS(4878),
    [aux_sym_zero_directive_token3] = ACTIONS(4878),
    [aux_sym_zero_directive_token4] = ACTIONS(4878),
    [aux_sym_zero_directive_token5] = ACTIONS(4878),
    [aux_sym_zero_directive_token6] = ACTIONS(4878),
    [aux_sym_zero_directive_token7] = ACTIONS(4878),
    [aux_sym_zero_directive_token8] = ACTIONS(4878),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4878),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4878),
    [anon_sym_wire] = ACTIONS(4880),
    [anon_sym_tri] = ACTIONS(4880),
    [anon_sym_tri0] = ACTIONS(4880),
    [anon_sym_tri1] = ACTIONS(4880),
    [anon_sym_wand] = ACTIONS(4880),
    [anon_sym_triand] = ACTIONS(4880),
    [anon_sym_wor] = ACTIONS(4880),
    [anon_sym_trior] = ACTIONS(4880),
    [anon_sym_trireg] = ACTIONS(4880),
    [anon_sym_uwire] = ACTIONS(4880),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4878),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4878),
    [aux_sym_begin_keywords_token1] = ACTIONS(4878),
    [anon_sym_SEMI] = ACTIONS(4878),
    [anon_sym_endmodule] = ACTIONS(4880),
    [anon_sym_extern] = ACTIONS(4880),
    [anon_sym_module] = ACTIONS(4880),
    [anon_sym_macromodule] = ACTIONS(4880),
    [anon_sym_endinterface] = ACTIONS(4880),
    [anon_sym_interface] = ACTIONS(4880),
    [anon_sym_endprogram] = ACTIONS(4880),
    [anon_sym_program] = ACTIONS(4880),
    [anon_sym_checker] = ACTIONS(4880),
    [anon_sym_virtual] = ACTIONS(4880),
    [anon_sym_class] = ACTIONS(4880),
    [anon_sym_package] = ACTIONS(4880),
    [anon_sym_endpackage] = ACTIONS(4880),
    [anon_sym_timeunit] = ACTIONS(4880),
    [anon_sym_timeprecision] = ACTIONS(4880),
    [anon_sym_type] = ACTIONS(4880),
    [anon_sym_input] = ACTIONS(4880),
    [anon_sym_output] = ACTIONS(4880),
    [anon_sym_inout] = ACTIONS(4880),
    [anon_sym_ref] = ACTIONS(4880),
    [anon_sym_DOLLARfatal] = ACTIONS(4878),
    [anon_sym_DOLLARerror] = ACTIONS(4878),
    [anon_sym_DOLLARwarning] = ACTIONS(4878),
    [anon_sym_DOLLARinfo] = ACTIONS(4878),
    [anon_sym_default] = ACTIONS(4880),
    [anon_sym_clocking] = ACTIONS(4880),
    [anon_sym_defparam] = ACTIONS(4880),
    [anon_sym_bind] = ACTIONS(4880),
    [anon_sym_const] = ACTIONS(4880),
    [anon_sym_function] = ACTIONS(4880),
    [anon_sym_static] = ACTIONS(4880),
    [anon_sym_constraint] = ACTIONS(4880),
    [anon_sym_if] = ACTIONS(4880),
    [anon_sym_else] = ACTIONS(4880),
    [anon_sym_LBRACK] = ACTIONS(4878),
    [anon_sym_localparam] = ACTIONS(4880),
    [anon_sym_parameter] = ACTIONS(4880),
    [anon_sym_specparam] = ACTIONS(4880),
    [anon_sym_var] = ACTIONS(4880),
    [anon_sym_import] = ACTIONS(4880),
    [anon_sym_export] = ACTIONS(4880),
    [anon_sym_genvar] = ACTIONS(4880),
    [anon_sym_interconnect] = ACTIONS(4880),
    [anon_sym_typedef] = ACTIONS(4880),
    [anon_sym_enum] = ACTIONS(4880),
    [anon_sym_struct] = ACTIONS(4880),
    [anon_sym_union] = ACTIONS(4880),
    [anon_sym_nettype] = ACTIONS(4880),
    [anon_sym_automatic] = ACTIONS(4880),
    [anon_sym_string] = ACTIONS(4880),
    [anon_sym_chandle] = ACTIONS(4880),
    [anon_sym_event] = ACTIONS(4880),
    [anon_sym_byte] = ACTIONS(4880),
    [anon_sym_shortint] = ACTIONS(4880),
    [anon_sym_int] = ACTIONS(4880),
    [anon_sym_longint] = ACTIONS(4880),
    [anon_sym_integer] = ACTIONS(4880),
    [anon_sym_time] = ACTIONS(4880),
    [anon_sym_bit] = ACTIONS(4880),
    [anon_sym_logic] = ACTIONS(4880),
    [anon_sym_reg] = ACTIONS(4880),
    [anon_sym_shortreal] = ACTIONS(4880),
    [anon_sym_real] = ACTIONS(4880),
    [anon_sym_realtime] = ACTIONS(4880),
    [anon_sym_supply0] = ACTIONS(4880),
    [anon_sym_supply1] = ACTIONS(4880),
    [anon_sym_signed] = ACTIONS(4880),
    [anon_sym_unsigned] = ACTIONS(4880),
    [anon_sym_task] = ACTIONS(4880),
    [anon_sym_modport] = ACTIONS(4880),
    [anon_sym_assert] = ACTIONS(4880),
    [anon_sym_property] = ACTIONS(4880),
    [anon_sym_assume] = ACTIONS(4880),
    [anon_sym_cover] = ACTIONS(4880),
    [anon_sym_sequence] = ACTIONS(4880),
    [anon_sym_restrict] = ACTIONS(4880),
    [anon_sym_not] = ACTIONS(4880),
    [anon_sym_or] = ACTIONS(4880),
    [anon_sym_and] = ACTIONS(4880),
    [anon_sym_case] = ACTIONS(4880),
    [anon_sym_always] = ACTIONS(4880),
    [anon_sym_covergroup] = ACTIONS(4880),
    [anon_sym_let] = ACTIONS(4880),
    [anon_sym_pulldown] = ACTIONS(4880),
    [anon_sym_pullup] = ACTIONS(4880),
    [anon_sym_cmos] = ACTIONS(4880),
    [anon_sym_rcmos] = ACTIONS(4880),
    [anon_sym_bufif0] = ACTIONS(4880),
    [anon_sym_bufif1] = ACTIONS(4880),
    [anon_sym_notif0] = ACTIONS(4880),
    [anon_sym_notif1] = ACTIONS(4880),
    [anon_sym_nmos] = ACTIONS(4880),
    [anon_sym_pmos] = ACTIONS(4880),
    [anon_sym_rnmos] = ACTIONS(4880),
    [anon_sym_rpmos] = ACTIONS(4880),
    [anon_sym_nand] = ACTIONS(4880),
    [anon_sym_nor] = ACTIONS(4880),
    [anon_sym_xor] = ACTIONS(4880),
    [anon_sym_xnor] = ACTIONS(4880),
    [anon_sym_buf] = ACTIONS(4880),
    [anon_sym_tranif0] = ACTIONS(4880),
    [anon_sym_tranif1] = ACTIONS(4880),
    [anon_sym_rtranif1] = ACTIONS(4880),
    [anon_sym_rtranif0] = ACTIONS(4880),
    [anon_sym_tran] = ACTIONS(4880),
    [anon_sym_rtran] = ACTIONS(4880),
    [anon_sym_generate] = ACTIONS(4880),
    [anon_sym_for] = ACTIONS(4880),
    [anon_sym_primitive] = ACTIONS(4880),
    [anon_sym_initial] = ACTIONS(4880),
    [anon_sym_assign] = ACTIONS(4880),
    [anon_sym_alias] = ACTIONS(4880),
    [anon_sym_always_comb] = ACTIONS(4880),
    [anon_sym_always_latch] = ACTIONS(4880),
    [anon_sym_always_ff] = ACTIONS(4880),
    [anon_sym_final] = ACTIONS(4880),
    [anon_sym_global] = ACTIONS(4880),
    [anon_sym_specify] = ACTIONS(4880),
    [anon_sym_LPAREN_STAR] = ACTIONS(4878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4878),
    [anon_sym_DOLLARunit] = ACTIONS(4878),
  },
  [790] = {
    [ts_builtin_sym_end] = ACTIONS(4766),
    [sym_simple_identifier] = ACTIONS(4768),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4766),
    [anon_sym_BQUOTE] = ACTIONS(4768),
    [aux_sym_id_directive_token1] = ACTIONS(4766),
    [aux_sym_id_directive_token2] = ACTIONS(4766),
    [aux_sym_id_directive_token3] = ACTIONS(4766),
    [aux_sym_id_directive_token4] = ACTIONS(4768),
    [aux_sym_zero_directive_token1] = ACTIONS(4766),
    [aux_sym_zero_directive_token2] = ACTIONS(4766),
    [aux_sym_zero_directive_token3] = ACTIONS(4766),
    [aux_sym_zero_directive_token4] = ACTIONS(4766),
    [aux_sym_zero_directive_token5] = ACTIONS(4766),
    [aux_sym_zero_directive_token6] = ACTIONS(4766),
    [aux_sym_zero_directive_token7] = ACTIONS(4766),
    [aux_sym_zero_directive_token8] = ACTIONS(4766),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4766),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4766),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4766),
    [aux_sym_begin_keywords_token1] = ACTIONS(4766),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_endmodule] = ACTIONS(4768),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_module] = ACTIONS(4768),
    [anon_sym_macromodule] = ACTIONS(4768),
    [anon_sym_endinterface] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_endprogram] = ACTIONS(4768),
    [anon_sym_program] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_package] = ACTIONS(4768),
    [anon_sym_endpackage] = ACTIONS(4768),
    [anon_sym_timeunit] = ACTIONS(4768),
    [anon_sym_timeprecision] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_input] = ACTIONS(4768),
    [anon_sym_output] = ACTIONS(4768),
    [anon_sym_inout] = ACTIONS(4768),
    [anon_sym_ref] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_specparam] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_modport] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_primitive] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_specify] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [791] = {
    [ts_builtin_sym_end] = ACTIONS(4882),
    [sym_simple_identifier] = ACTIONS(4884),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4882),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4882),
    [anon_sym_BQUOTE] = ACTIONS(4884),
    [aux_sym_id_directive_token1] = ACTIONS(4882),
    [aux_sym_id_directive_token2] = ACTIONS(4882),
    [aux_sym_id_directive_token3] = ACTIONS(4882),
    [aux_sym_id_directive_token4] = ACTIONS(4884),
    [aux_sym_zero_directive_token1] = ACTIONS(4882),
    [aux_sym_zero_directive_token2] = ACTIONS(4882),
    [aux_sym_zero_directive_token3] = ACTIONS(4882),
    [aux_sym_zero_directive_token4] = ACTIONS(4882),
    [aux_sym_zero_directive_token5] = ACTIONS(4882),
    [aux_sym_zero_directive_token6] = ACTIONS(4882),
    [aux_sym_zero_directive_token7] = ACTIONS(4882),
    [aux_sym_zero_directive_token8] = ACTIONS(4882),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4882),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4882),
    [anon_sym_wire] = ACTIONS(4884),
    [anon_sym_tri] = ACTIONS(4884),
    [anon_sym_tri0] = ACTIONS(4884),
    [anon_sym_tri1] = ACTIONS(4884),
    [anon_sym_wand] = ACTIONS(4884),
    [anon_sym_triand] = ACTIONS(4884),
    [anon_sym_wor] = ACTIONS(4884),
    [anon_sym_trior] = ACTIONS(4884),
    [anon_sym_trireg] = ACTIONS(4884),
    [anon_sym_uwire] = ACTIONS(4884),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4882),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4882),
    [aux_sym_begin_keywords_token1] = ACTIONS(4882),
    [anon_sym_SEMI] = ACTIONS(4882),
    [anon_sym_endmodule] = ACTIONS(4884),
    [anon_sym_extern] = ACTIONS(4884),
    [anon_sym_module] = ACTIONS(4884),
    [anon_sym_macromodule] = ACTIONS(4884),
    [anon_sym_endinterface] = ACTIONS(4884),
    [anon_sym_interface] = ACTIONS(4884),
    [anon_sym_endprogram] = ACTIONS(4884),
    [anon_sym_program] = ACTIONS(4884),
    [anon_sym_checker] = ACTIONS(4884),
    [anon_sym_virtual] = ACTIONS(4884),
    [anon_sym_class] = ACTIONS(4884),
    [anon_sym_package] = ACTIONS(4884),
    [anon_sym_endpackage] = ACTIONS(4884),
    [anon_sym_timeunit] = ACTIONS(4884),
    [anon_sym_timeprecision] = ACTIONS(4884),
    [anon_sym_type] = ACTIONS(4884),
    [anon_sym_input] = ACTIONS(4884),
    [anon_sym_output] = ACTIONS(4884),
    [anon_sym_inout] = ACTIONS(4884),
    [anon_sym_ref] = ACTIONS(4884),
    [anon_sym_DOLLARfatal] = ACTIONS(4882),
    [anon_sym_DOLLARerror] = ACTIONS(4882),
    [anon_sym_DOLLARwarning] = ACTIONS(4882),
    [anon_sym_DOLLARinfo] = ACTIONS(4882),
    [anon_sym_default] = ACTIONS(4884),
    [anon_sym_clocking] = ACTIONS(4884),
    [anon_sym_defparam] = ACTIONS(4884),
    [anon_sym_bind] = ACTIONS(4884),
    [anon_sym_const] = ACTIONS(4884),
    [anon_sym_function] = ACTIONS(4884),
    [anon_sym_static] = ACTIONS(4884),
    [anon_sym_constraint] = ACTIONS(4884),
    [anon_sym_if] = ACTIONS(4884),
    [anon_sym_else] = ACTIONS(4884),
    [anon_sym_LBRACK] = ACTIONS(4882),
    [anon_sym_localparam] = ACTIONS(4884),
    [anon_sym_parameter] = ACTIONS(4884),
    [anon_sym_specparam] = ACTIONS(4884),
    [anon_sym_var] = ACTIONS(4884),
    [anon_sym_import] = ACTIONS(4884),
    [anon_sym_export] = ACTIONS(4884),
    [anon_sym_genvar] = ACTIONS(4884),
    [anon_sym_interconnect] = ACTIONS(4884),
    [anon_sym_typedef] = ACTIONS(4884),
    [anon_sym_enum] = ACTIONS(4884),
    [anon_sym_struct] = ACTIONS(4884),
    [anon_sym_union] = ACTIONS(4884),
    [anon_sym_nettype] = ACTIONS(4884),
    [anon_sym_automatic] = ACTIONS(4884),
    [anon_sym_string] = ACTIONS(4884),
    [anon_sym_chandle] = ACTIONS(4884),
    [anon_sym_event] = ACTIONS(4884),
    [anon_sym_byte] = ACTIONS(4884),
    [anon_sym_shortint] = ACTIONS(4884),
    [anon_sym_int] = ACTIONS(4884),
    [anon_sym_longint] = ACTIONS(4884),
    [anon_sym_integer] = ACTIONS(4884),
    [anon_sym_time] = ACTIONS(4884),
    [anon_sym_bit] = ACTIONS(4884),
    [anon_sym_logic] = ACTIONS(4884),
    [anon_sym_reg] = ACTIONS(4884),
    [anon_sym_shortreal] = ACTIONS(4884),
    [anon_sym_real] = ACTIONS(4884),
    [anon_sym_realtime] = ACTIONS(4884),
    [anon_sym_supply0] = ACTIONS(4884),
    [anon_sym_supply1] = ACTIONS(4884),
    [anon_sym_signed] = ACTIONS(4884),
    [anon_sym_unsigned] = ACTIONS(4884),
    [anon_sym_task] = ACTIONS(4884),
    [anon_sym_modport] = ACTIONS(4884),
    [anon_sym_assert] = ACTIONS(4884),
    [anon_sym_property] = ACTIONS(4884),
    [anon_sym_assume] = ACTIONS(4884),
    [anon_sym_cover] = ACTIONS(4884),
    [anon_sym_sequence] = ACTIONS(4884),
    [anon_sym_restrict] = ACTIONS(4884),
    [anon_sym_not] = ACTIONS(4884),
    [anon_sym_or] = ACTIONS(4884),
    [anon_sym_and] = ACTIONS(4884),
    [anon_sym_case] = ACTIONS(4884),
    [anon_sym_always] = ACTIONS(4884),
    [anon_sym_covergroup] = ACTIONS(4884),
    [anon_sym_let] = ACTIONS(4884),
    [anon_sym_pulldown] = ACTIONS(4884),
    [anon_sym_pullup] = ACTIONS(4884),
    [anon_sym_cmos] = ACTIONS(4884),
    [anon_sym_rcmos] = ACTIONS(4884),
    [anon_sym_bufif0] = ACTIONS(4884),
    [anon_sym_bufif1] = ACTIONS(4884),
    [anon_sym_notif0] = ACTIONS(4884),
    [anon_sym_notif1] = ACTIONS(4884),
    [anon_sym_nmos] = ACTIONS(4884),
    [anon_sym_pmos] = ACTIONS(4884),
    [anon_sym_rnmos] = ACTIONS(4884),
    [anon_sym_rpmos] = ACTIONS(4884),
    [anon_sym_nand] = ACTIONS(4884),
    [anon_sym_nor] = ACTIONS(4884),
    [anon_sym_xor] = ACTIONS(4884),
    [anon_sym_xnor] = ACTIONS(4884),
    [anon_sym_buf] = ACTIONS(4884),
    [anon_sym_tranif0] = ACTIONS(4884),
    [anon_sym_tranif1] = ACTIONS(4884),
    [anon_sym_rtranif1] = ACTIONS(4884),
    [anon_sym_rtranif0] = ACTIONS(4884),
    [anon_sym_tran] = ACTIONS(4884),
    [anon_sym_rtran] = ACTIONS(4884),
    [anon_sym_generate] = ACTIONS(4884),
    [anon_sym_for] = ACTIONS(4884),
    [anon_sym_primitive] = ACTIONS(4884),
    [anon_sym_initial] = ACTIONS(4884),
    [anon_sym_assign] = ACTIONS(4884),
    [anon_sym_alias] = ACTIONS(4884),
    [anon_sym_always_comb] = ACTIONS(4884),
    [anon_sym_always_latch] = ACTIONS(4884),
    [anon_sym_always_ff] = ACTIONS(4884),
    [anon_sym_final] = ACTIONS(4884),
    [anon_sym_global] = ACTIONS(4884),
    [anon_sym_specify] = ACTIONS(4884),
    [anon_sym_LPAREN_STAR] = ACTIONS(4882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4882),
    [anon_sym_DOLLARunit] = ACTIONS(4882),
  },
  [792] = {
    [ts_builtin_sym_end] = ACTIONS(4772),
    [sym_simple_identifier] = ACTIONS(4774),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4772),
    [anon_sym_BQUOTE] = ACTIONS(4774),
    [aux_sym_id_directive_token1] = ACTIONS(4772),
    [aux_sym_id_directive_token2] = ACTIONS(4772),
    [aux_sym_id_directive_token3] = ACTIONS(4772),
    [aux_sym_id_directive_token4] = ACTIONS(4774),
    [aux_sym_zero_directive_token1] = ACTIONS(4772),
    [aux_sym_zero_directive_token2] = ACTIONS(4772),
    [aux_sym_zero_directive_token3] = ACTIONS(4772),
    [aux_sym_zero_directive_token4] = ACTIONS(4772),
    [aux_sym_zero_directive_token5] = ACTIONS(4772),
    [aux_sym_zero_directive_token6] = ACTIONS(4772),
    [aux_sym_zero_directive_token7] = ACTIONS(4772),
    [aux_sym_zero_directive_token8] = ACTIONS(4772),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4772),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4772),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4772),
    [aux_sym_begin_keywords_token1] = ACTIONS(4772),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_endmodule] = ACTIONS(4774),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_module] = ACTIONS(4774),
    [anon_sym_macromodule] = ACTIONS(4774),
    [anon_sym_endinterface] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_endprogram] = ACTIONS(4774),
    [anon_sym_program] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_package] = ACTIONS(4774),
    [anon_sym_endpackage] = ACTIONS(4774),
    [anon_sym_timeunit] = ACTIONS(4774),
    [anon_sym_timeprecision] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_input] = ACTIONS(4774),
    [anon_sym_output] = ACTIONS(4774),
    [anon_sym_inout] = ACTIONS(4774),
    [anon_sym_ref] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_specparam] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_modport] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_primitive] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_specify] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [793] = {
    [ts_builtin_sym_end] = ACTIONS(4886),
    [sym_simple_identifier] = ACTIONS(4888),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4886),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4886),
    [anon_sym_BQUOTE] = ACTIONS(4888),
    [aux_sym_id_directive_token1] = ACTIONS(4886),
    [aux_sym_id_directive_token2] = ACTIONS(4886),
    [aux_sym_id_directive_token3] = ACTIONS(4886),
    [aux_sym_id_directive_token4] = ACTIONS(4888),
    [aux_sym_zero_directive_token1] = ACTIONS(4886),
    [aux_sym_zero_directive_token2] = ACTIONS(4886),
    [aux_sym_zero_directive_token3] = ACTIONS(4886),
    [aux_sym_zero_directive_token4] = ACTIONS(4886),
    [aux_sym_zero_directive_token5] = ACTIONS(4886),
    [aux_sym_zero_directive_token6] = ACTIONS(4886),
    [aux_sym_zero_directive_token7] = ACTIONS(4886),
    [aux_sym_zero_directive_token8] = ACTIONS(4886),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4886),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4886),
    [anon_sym_wire] = ACTIONS(4888),
    [anon_sym_tri] = ACTIONS(4888),
    [anon_sym_tri0] = ACTIONS(4888),
    [anon_sym_tri1] = ACTIONS(4888),
    [anon_sym_wand] = ACTIONS(4888),
    [anon_sym_triand] = ACTIONS(4888),
    [anon_sym_wor] = ACTIONS(4888),
    [anon_sym_trior] = ACTIONS(4888),
    [anon_sym_trireg] = ACTIONS(4888),
    [anon_sym_uwire] = ACTIONS(4888),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4886),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4886),
    [aux_sym_begin_keywords_token1] = ACTIONS(4886),
    [anon_sym_SEMI] = ACTIONS(4886),
    [anon_sym_endmodule] = ACTIONS(4888),
    [anon_sym_extern] = ACTIONS(4888),
    [anon_sym_module] = ACTIONS(4888),
    [anon_sym_macromodule] = ACTIONS(4888),
    [anon_sym_endinterface] = ACTIONS(4888),
    [anon_sym_interface] = ACTIONS(4888),
    [anon_sym_endprogram] = ACTIONS(4888),
    [anon_sym_program] = ACTIONS(4888),
    [anon_sym_checker] = ACTIONS(4888),
    [anon_sym_virtual] = ACTIONS(4888),
    [anon_sym_class] = ACTIONS(4888),
    [anon_sym_package] = ACTIONS(4888),
    [anon_sym_endpackage] = ACTIONS(4888),
    [anon_sym_timeunit] = ACTIONS(4888),
    [anon_sym_timeprecision] = ACTIONS(4888),
    [anon_sym_type] = ACTIONS(4888),
    [anon_sym_input] = ACTIONS(4888),
    [anon_sym_output] = ACTIONS(4888),
    [anon_sym_inout] = ACTIONS(4888),
    [anon_sym_ref] = ACTIONS(4888),
    [anon_sym_DOLLARfatal] = ACTIONS(4886),
    [anon_sym_DOLLARerror] = ACTIONS(4886),
    [anon_sym_DOLLARwarning] = ACTIONS(4886),
    [anon_sym_DOLLARinfo] = ACTIONS(4886),
    [anon_sym_default] = ACTIONS(4888),
    [anon_sym_clocking] = ACTIONS(4888),
    [anon_sym_defparam] = ACTIONS(4888),
    [anon_sym_bind] = ACTIONS(4888),
    [anon_sym_const] = ACTIONS(4888),
    [anon_sym_function] = ACTIONS(4888),
    [anon_sym_static] = ACTIONS(4888),
    [anon_sym_constraint] = ACTIONS(4888),
    [anon_sym_if] = ACTIONS(4888),
    [anon_sym_else] = ACTIONS(4888),
    [anon_sym_LBRACK] = ACTIONS(4886),
    [anon_sym_localparam] = ACTIONS(4888),
    [anon_sym_parameter] = ACTIONS(4888),
    [anon_sym_specparam] = ACTIONS(4888),
    [anon_sym_var] = ACTIONS(4888),
    [anon_sym_import] = ACTIONS(4888),
    [anon_sym_export] = ACTIONS(4888),
    [anon_sym_genvar] = ACTIONS(4888),
    [anon_sym_interconnect] = ACTIONS(4888),
    [anon_sym_typedef] = ACTIONS(4888),
    [anon_sym_enum] = ACTIONS(4888),
    [anon_sym_struct] = ACTIONS(4888),
    [anon_sym_union] = ACTIONS(4888),
    [anon_sym_nettype] = ACTIONS(4888),
    [anon_sym_automatic] = ACTIONS(4888),
    [anon_sym_string] = ACTIONS(4888),
    [anon_sym_chandle] = ACTIONS(4888),
    [anon_sym_event] = ACTIONS(4888),
    [anon_sym_byte] = ACTIONS(4888),
    [anon_sym_shortint] = ACTIONS(4888),
    [anon_sym_int] = ACTIONS(4888),
    [anon_sym_longint] = ACTIONS(4888),
    [anon_sym_integer] = ACTIONS(4888),
    [anon_sym_time] = ACTIONS(4888),
    [anon_sym_bit] = ACTIONS(4888),
    [anon_sym_logic] = ACTIONS(4888),
    [anon_sym_reg] = ACTIONS(4888),
    [anon_sym_shortreal] = ACTIONS(4888),
    [anon_sym_real] = ACTIONS(4888),
    [anon_sym_realtime] = ACTIONS(4888),
    [anon_sym_supply0] = ACTIONS(4888),
    [anon_sym_supply1] = ACTIONS(4888),
    [anon_sym_signed] = ACTIONS(4888),
    [anon_sym_unsigned] = ACTIONS(4888),
    [anon_sym_task] = ACTIONS(4888),
    [anon_sym_modport] = ACTIONS(4888),
    [anon_sym_assert] = ACTIONS(4888),
    [anon_sym_property] = ACTIONS(4888),
    [anon_sym_assume] = ACTIONS(4888),
    [anon_sym_cover] = ACTIONS(4888),
    [anon_sym_sequence] = ACTIONS(4888),
    [anon_sym_restrict] = ACTIONS(4888),
    [anon_sym_not] = ACTIONS(4888),
    [anon_sym_or] = ACTIONS(4888),
    [anon_sym_and] = ACTIONS(4888),
    [anon_sym_case] = ACTIONS(4888),
    [anon_sym_always] = ACTIONS(4888),
    [anon_sym_covergroup] = ACTIONS(4888),
    [anon_sym_let] = ACTIONS(4888),
    [anon_sym_pulldown] = ACTIONS(4888),
    [anon_sym_pullup] = ACTIONS(4888),
    [anon_sym_cmos] = ACTIONS(4888),
    [anon_sym_rcmos] = ACTIONS(4888),
    [anon_sym_bufif0] = ACTIONS(4888),
    [anon_sym_bufif1] = ACTIONS(4888),
    [anon_sym_notif0] = ACTIONS(4888),
    [anon_sym_notif1] = ACTIONS(4888),
    [anon_sym_nmos] = ACTIONS(4888),
    [anon_sym_pmos] = ACTIONS(4888),
    [anon_sym_rnmos] = ACTIONS(4888),
    [anon_sym_rpmos] = ACTIONS(4888),
    [anon_sym_nand] = ACTIONS(4888),
    [anon_sym_nor] = ACTIONS(4888),
    [anon_sym_xor] = ACTIONS(4888),
    [anon_sym_xnor] = ACTIONS(4888),
    [anon_sym_buf] = ACTIONS(4888),
    [anon_sym_tranif0] = ACTIONS(4888),
    [anon_sym_tranif1] = ACTIONS(4888),
    [anon_sym_rtranif1] = ACTIONS(4888),
    [anon_sym_rtranif0] = ACTIONS(4888),
    [anon_sym_tran] = ACTIONS(4888),
    [anon_sym_rtran] = ACTIONS(4888),
    [anon_sym_generate] = ACTIONS(4888),
    [anon_sym_for] = ACTIONS(4888),
    [anon_sym_primitive] = ACTIONS(4888),
    [anon_sym_initial] = ACTIONS(4888),
    [anon_sym_assign] = ACTIONS(4888),
    [anon_sym_alias] = ACTIONS(4888),
    [anon_sym_always_comb] = ACTIONS(4888),
    [anon_sym_always_latch] = ACTIONS(4888),
    [anon_sym_always_ff] = ACTIONS(4888),
    [anon_sym_final] = ACTIONS(4888),
    [anon_sym_global] = ACTIONS(4888),
    [anon_sym_specify] = ACTIONS(4888),
    [anon_sym_LPAREN_STAR] = ACTIONS(4886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4886),
    [anon_sym_DOLLARunit] = ACTIONS(4886),
  },
  [794] = {
    [ts_builtin_sym_end] = ACTIONS(4890),
    [sym_simple_identifier] = ACTIONS(4892),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4890),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4890),
    [anon_sym_BQUOTE] = ACTIONS(4892),
    [aux_sym_id_directive_token1] = ACTIONS(4890),
    [aux_sym_id_directive_token2] = ACTIONS(4890),
    [aux_sym_id_directive_token3] = ACTIONS(4890),
    [aux_sym_id_directive_token4] = ACTIONS(4892),
    [aux_sym_zero_directive_token1] = ACTIONS(4890),
    [aux_sym_zero_directive_token2] = ACTIONS(4890),
    [aux_sym_zero_directive_token3] = ACTIONS(4890),
    [aux_sym_zero_directive_token4] = ACTIONS(4890),
    [aux_sym_zero_directive_token5] = ACTIONS(4890),
    [aux_sym_zero_directive_token6] = ACTIONS(4890),
    [aux_sym_zero_directive_token7] = ACTIONS(4890),
    [aux_sym_zero_directive_token8] = ACTIONS(4890),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4890),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4890),
    [anon_sym_wire] = ACTIONS(4892),
    [anon_sym_tri] = ACTIONS(4892),
    [anon_sym_tri0] = ACTIONS(4892),
    [anon_sym_tri1] = ACTIONS(4892),
    [anon_sym_wand] = ACTIONS(4892),
    [anon_sym_triand] = ACTIONS(4892),
    [anon_sym_wor] = ACTIONS(4892),
    [anon_sym_trior] = ACTIONS(4892),
    [anon_sym_trireg] = ACTIONS(4892),
    [anon_sym_uwire] = ACTIONS(4892),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4890),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4890),
    [aux_sym_begin_keywords_token1] = ACTIONS(4890),
    [anon_sym_SEMI] = ACTIONS(4890),
    [anon_sym_endmodule] = ACTIONS(4892),
    [anon_sym_extern] = ACTIONS(4892),
    [anon_sym_module] = ACTIONS(4892),
    [anon_sym_macromodule] = ACTIONS(4892),
    [anon_sym_endinterface] = ACTIONS(4892),
    [anon_sym_interface] = ACTIONS(4892),
    [anon_sym_endprogram] = ACTIONS(4892),
    [anon_sym_program] = ACTIONS(4892),
    [anon_sym_checker] = ACTIONS(4892),
    [anon_sym_virtual] = ACTIONS(4892),
    [anon_sym_class] = ACTIONS(4892),
    [anon_sym_package] = ACTIONS(4892),
    [anon_sym_endpackage] = ACTIONS(4892),
    [anon_sym_timeunit] = ACTIONS(4892),
    [anon_sym_timeprecision] = ACTIONS(4892),
    [anon_sym_type] = ACTIONS(4892),
    [anon_sym_input] = ACTIONS(4892),
    [anon_sym_output] = ACTIONS(4892),
    [anon_sym_inout] = ACTIONS(4892),
    [anon_sym_ref] = ACTIONS(4892),
    [anon_sym_DOLLARfatal] = ACTIONS(4890),
    [anon_sym_DOLLARerror] = ACTIONS(4890),
    [anon_sym_DOLLARwarning] = ACTIONS(4890),
    [anon_sym_DOLLARinfo] = ACTIONS(4890),
    [anon_sym_default] = ACTIONS(4892),
    [anon_sym_clocking] = ACTIONS(4892),
    [anon_sym_defparam] = ACTIONS(4892),
    [anon_sym_bind] = ACTIONS(4892),
    [anon_sym_const] = ACTIONS(4892),
    [anon_sym_function] = ACTIONS(4892),
    [anon_sym_static] = ACTIONS(4892),
    [anon_sym_constraint] = ACTIONS(4892),
    [anon_sym_if] = ACTIONS(4892),
    [anon_sym_else] = ACTIONS(4892),
    [anon_sym_LBRACK] = ACTIONS(4890),
    [anon_sym_localparam] = ACTIONS(4892),
    [anon_sym_parameter] = ACTIONS(4892),
    [anon_sym_specparam] = ACTIONS(4892),
    [anon_sym_var] = ACTIONS(4892),
    [anon_sym_import] = ACTIONS(4892),
    [anon_sym_export] = ACTIONS(4892),
    [anon_sym_genvar] = ACTIONS(4892),
    [anon_sym_interconnect] = ACTIONS(4892),
    [anon_sym_typedef] = ACTIONS(4892),
    [anon_sym_enum] = ACTIONS(4892),
    [anon_sym_struct] = ACTIONS(4892),
    [anon_sym_union] = ACTIONS(4892),
    [anon_sym_nettype] = ACTIONS(4892),
    [anon_sym_automatic] = ACTIONS(4892),
    [anon_sym_string] = ACTIONS(4892),
    [anon_sym_chandle] = ACTIONS(4892),
    [anon_sym_event] = ACTIONS(4892),
    [anon_sym_byte] = ACTIONS(4892),
    [anon_sym_shortint] = ACTIONS(4892),
    [anon_sym_int] = ACTIONS(4892),
    [anon_sym_longint] = ACTIONS(4892),
    [anon_sym_integer] = ACTIONS(4892),
    [anon_sym_time] = ACTIONS(4892),
    [anon_sym_bit] = ACTIONS(4892),
    [anon_sym_logic] = ACTIONS(4892),
    [anon_sym_reg] = ACTIONS(4892),
    [anon_sym_shortreal] = ACTIONS(4892),
    [anon_sym_real] = ACTIONS(4892),
    [anon_sym_realtime] = ACTIONS(4892),
    [anon_sym_supply0] = ACTIONS(4892),
    [anon_sym_supply1] = ACTIONS(4892),
    [anon_sym_signed] = ACTIONS(4892),
    [anon_sym_unsigned] = ACTIONS(4892),
    [anon_sym_task] = ACTIONS(4892),
    [anon_sym_modport] = ACTIONS(4892),
    [anon_sym_assert] = ACTIONS(4892),
    [anon_sym_property] = ACTIONS(4892),
    [anon_sym_assume] = ACTIONS(4892),
    [anon_sym_cover] = ACTIONS(4892),
    [anon_sym_sequence] = ACTIONS(4892),
    [anon_sym_restrict] = ACTIONS(4892),
    [anon_sym_not] = ACTIONS(4892),
    [anon_sym_or] = ACTIONS(4892),
    [anon_sym_and] = ACTIONS(4892),
    [anon_sym_case] = ACTIONS(4892),
    [anon_sym_always] = ACTIONS(4892),
    [anon_sym_covergroup] = ACTIONS(4892),
    [anon_sym_let] = ACTIONS(4892),
    [anon_sym_pulldown] = ACTIONS(4892),
    [anon_sym_pullup] = ACTIONS(4892),
    [anon_sym_cmos] = ACTIONS(4892),
    [anon_sym_rcmos] = ACTIONS(4892),
    [anon_sym_bufif0] = ACTIONS(4892),
    [anon_sym_bufif1] = ACTIONS(4892),
    [anon_sym_notif0] = ACTIONS(4892),
    [anon_sym_notif1] = ACTIONS(4892),
    [anon_sym_nmos] = ACTIONS(4892),
    [anon_sym_pmos] = ACTIONS(4892),
    [anon_sym_rnmos] = ACTIONS(4892),
    [anon_sym_rpmos] = ACTIONS(4892),
    [anon_sym_nand] = ACTIONS(4892),
    [anon_sym_nor] = ACTIONS(4892),
    [anon_sym_xor] = ACTIONS(4892),
    [anon_sym_xnor] = ACTIONS(4892),
    [anon_sym_buf] = ACTIONS(4892),
    [anon_sym_tranif0] = ACTIONS(4892),
    [anon_sym_tranif1] = ACTIONS(4892),
    [anon_sym_rtranif1] = ACTIONS(4892),
    [anon_sym_rtranif0] = ACTIONS(4892),
    [anon_sym_tran] = ACTIONS(4892),
    [anon_sym_rtran] = ACTIONS(4892),
    [anon_sym_generate] = ACTIONS(4892),
    [anon_sym_for] = ACTIONS(4892),
    [anon_sym_primitive] = ACTIONS(4892),
    [anon_sym_initial] = ACTIONS(4892),
    [anon_sym_assign] = ACTIONS(4892),
    [anon_sym_alias] = ACTIONS(4892),
    [anon_sym_always_comb] = ACTIONS(4892),
    [anon_sym_always_latch] = ACTIONS(4892),
    [anon_sym_always_ff] = ACTIONS(4892),
    [anon_sym_final] = ACTIONS(4892),
    [anon_sym_global] = ACTIONS(4892),
    [anon_sym_specify] = ACTIONS(4892),
    [anon_sym_LPAREN_STAR] = ACTIONS(4890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4890),
    [anon_sym_DOLLARunit] = ACTIONS(4890),
  },
  [795] = {
    [ts_builtin_sym_end] = ACTIONS(4894),
    [sym_simple_identifier] = ACTIONS(4896),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4894),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4894),
    [anon_sym_BQUOTE] = ACTIONS(4896),
    [aux_sym_id_directive_token1] = ACTIONS(4894),
    [aux_sym_id_directive_token2] = ACTIONS(4894),
    [aux_sym_id_directive_token3] = ACTIONS(4894),
    [aux_sym_id_directive_token4] = ACTIONS(4896),
    [aux_sym_zero_directive_token1] = ACTIONS(4894),
    [aux_sym_zero_directive_token2] = ACTIONS(4894),
    [aux_sym_zero_directive_token3] = ACTIONS(4894),
    [aux_sym_zero_directive_token4] = ACTIONS(4894),
    [aux_sym_zero_directive_token5] = ACTIONS(4894),
    [aux_sym_zero_directive_token6] = ACTIONS(4894),
    [aux_sym_zero_directive_token7] = ACTIONS(4894),
    [aux_sym_zero_directive_token8] = ACTIONS(4894),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4894),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4894),
    [anon_sym_wire] = ACTIONS(4896),
    [anon_sym_tri] = ACTIONS(4896),
    [anon_sym_tri0] = ACTIONS(4896),
    [anon_sym_tri1] = ACTIONS(4896),
    [anon_sym_wand] = ACTIONS(4896),
    [anon_sym_triand] = ACTIONS(4896),
    [anon_sym_wor] = ACTIONS(4896),
    [anon_sym_trior] = ACTIONS(4896),
    [anon_sym_trireg] = ACTIONS(4896),
    [anon_sym_uwire] = ACTIONS(4896),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4894),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4894),
    [aux_sym_begin_keywords_token1] = ACTIONS(4894),
    [anon_sym_SEMI] = ACTIONS(4894),
    [anon_sym_endmodule] = ACTIONS(4896),
    [anon_sym_extern] = ACTIONS(4896),
    [anon_sym_module] = ACTIONS(4896),
    [anon_sym_macromodule] = ACTIONS(4896),
    [anon_sym_endinterface] = ACTIONS(4896),
    [anon_sym_interface] = ACTIONS(4896),
    [anon_sym_endprogram] = ACTIONS(4896),
    [anon_sym_program] = ACTIONS(4896),
    [anon_sym_checker] = ACTIONS(4896),
    [anon_sym_virtual] = ACTIONS(4896),
    [anon_sym_class] = ACTIONS(4896),
    [anon_sym_package] = ACTIONS(4896),
    [anon_sym_endpackage] = ACTIONS(4896),
    [anon_sym_timeunit] = ACTIONS(4896),
    [anon_sym_timeprecision] = ACTIONS(4896),
    [anon_sym_type] = ACTIONS(4896),
    [anon_sym_input] = ACTIONS(4896),
    [anon_sym_output] = ACTIONS(4896),
    [anon_sym_inout] = ACTIONS(4896),
    [anon_sym_ref] = ACTIONS(4896),
    [anon_sym_DOLLARfatal] = ACTIONS(4894),
    [anon_sym_DOLLARerror] = ACTIONS(4894),
    [anon_sym_DOLLARwarning] = ACTIONS(4894),
    [anon_sym_DOLLARinfo] = ACTIONS(4894),
    [anon_sym_default] = ACTIONS(4896),
    [anon_sym_clocking] = ACTIONS(4896),
    [anon_sym_defparam] = ACTIONS(4896),
    [anon_sym_bind] = ACTIONS(4896),
    [anon_sym_const] = ACTIONS(4896),
    [anon_sym_function] = ACTIONS(4896),
    [anon_sym_static] = ACTIONS(4896),
    [anon_sym_constraint] = ACTIONS(4896),
    [anon_sym_if] = ACTIONS(4896),
    [anon_sym_else] = ACTIONS(4896),
    [anon_sym_LBRACK] = ACTIONS(4894),
    [anon_sym_localparam] = ACTIONS(4896),
    [anon_sym_parameter] = ACTIONS(4896),
    [anon_sym_specparam] = ACTIONS(4896),
    [anon_sym_var] = ACTIONS(4896),
    [anon_sym_import] = ACTIONS(4896),
    [anon_sym_export] = ACTIONS(4896),
    [anon_sym_genvar] = ACTIONS(4896),
    [anon_sym_interconnect] = ACTIONS(4896),
    [anon_sym_typedef] = ACTIONS(4896),
    [anon_sym_enum] = ACTIONS(4896),
    [anon_sym_struct] = ACTIONS(4896),
    [anon_sym_union] = ACTIONS(4896),
    [anon_sym_nettype] = ACTIONS(4896),
    [anon_sym_automatic] = ACTIONS(4896),
    [anon_sym_string] = ACTIONS(4896),
    [anon_sym_chandle] = ACTIONS(4896),
    [anon_sym_event] = ACTIONS(4896),
    [anon_sym_byte] = ACTIONS(4896),
    [anon_sym_shortint] = ACTIONS(4896),
    [anon_sym_int] = ACTIONS(4896),
    [anon_sym_longint] = ACTIONS(4896),
    [anon_sym_integer] = ACTIONS(4896),
    [anon_sym_time] = ACTIONS(4896),
    [anon_sym_bit] = ACTIONS(4896),
    [anon_sym_logic] = ACTIONS(4896),
    [anon_sym_reg] = ACTIONS(4896),
    [anon_sym_shortreal] = ACTIONS(4896),
    [anon_sym_real] = ACTIONS(4896),
    [anon_sym_realtime] = ACTIONS(4896),
    [anon_sym_supply0] = ACTIONS(4896),
    [anon_sym_supply1] = ACTIONS(4896),
    [anon_sym_signed] = ACTIONS(4896),
    [anon_sym_unsigned] = ACTIONS(4896),
    [anon_sym_task] = ACTIONS(4896),
    [anon_sym_modport] = ACTIONS(4896),
    [anon_sym_assert] = ACTIONS(4896),
    [anon_sym_property] = ACTIONS(4896),
    [anon_sym_assume] = ACTIONS(4896),
    [anon_sym_cover] = ACTIONS(4896),
    [anon_sym_sequence] = ACTIONS(4896),
    [anon_sym_restrict] = ACTIONS(4896),
    [anon_sym_not] = ACTIONS(4896),
    [anon_sym_or] = ACTIONS(4896),
    [anon_sym_and] = ACTIONS(4896),
    [anon_sym_case] = ACTIONS(4896),
    [anon_sym_always] = ACTIONS(4896),
    [anon_sym_covergroup] = ACTIONS(4896),
    [anon_sym_let] = ACTIONS(4896),
    [anon_sym_pulldown] = ACTIONS(4896),
    [anon_sym_pullup] = ACTIONS(4896),
    [anon_sym_cmos] = ACTIONS(4896),
    [anon_sym_rcmos] = ACTIONS(4896),
    [anon_sym_bufif0] = ACTIONS(4896),
    [anon_sym_bufif1] = ACTIONS(4896),
    [anon_sym_notif0] = ACTIONS(4896),
    [anon_sym_notif1] = ACTIONS(4896),
    [anon_sym_nmos] = ACTIONS(4896),
    [anon_sym_pmos] = ACTIONS(4896),
    [anon_sym_rnmos] = ACTIONS(4896),
    [anon_sym_rpmos] = ACTIONS(4896),
    [anon_sym_nand] = ACTIONS(4896),
    [anon_sym_nor] = ACTIONS(4896),
    [anon_sym_xor] = ACTIONS(4896),
    [anon_sym_xnor] = ACTIONS(4896),
    [anon_sym_buf] = ACTIONS(4896),
    [anon_sym_tranif0] = ACTIONS(4896),
    [anon_sym_tranif1] = ACTIONS(4896),
    [anon_sym_rtranif1] = ACTIONS(4896),
    [anon_sym_rtranif0] = ACTIONS(4896),
    [anon_sym_tran] = ACTIONS(4896),
    [anon_sym_rtran] = ACTIONS(4896),
    [anon_sym_generate] = ACTIONS(4896),
    [anon_sym_for] = ACTIONS(4896),
    [anon_sym_primitive] = ACTIONS(4896),
    [anon_sym_initial] = ACTIONS(4896),
    [anon_sym_assign] = ACTIONS(4896),
    [anon_sym_alias] = ACTIONS(4896),
    [anon_sym_always_comb] = ACTIONS(4896),
    [anon_sym_always_latch] = ACTIONS(4896),
    [anon_sym_always_ff] = ACTIONS(4896),
    [anon_sym_final] = ACTIONS(4896),
    [anon_sym_global] = ACTIONS(4896),
    [anon_sym_specify] = ACTIONS(4896),
    [anon_sym_LPAREN_STAR] = ACTIONS(4894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4894),
    [anon_sym_DOLLARunit] = ACTIONS(4894),
  },
  [796] = {
    [ts_builtin_sym_end] = ACTIONS(4898),
    [sym_simple_identifier] = ACTIONS(4900),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4898),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4898),
    [anon_sym_BQUOTE] = ACTIONS(4900),
    [aux_sym_id_directive_token1] = ACTIONS(4898),
    [aux_sym_id_directive_token2] = ACTIONS(4898),
    [aux_sym_id_directive_token3] = ACTIONS(4898),
    [aux_sym_id_directive_token4] = ACTIONS(4900),
    [aux_sym_zero_directive_token1] = ACTIONS(4898),
    [aux_sym_zero_directive_token2] = ACTIONS(4898),
    [aux_sym_zero_directive_token3] = ACTIONS(4898),
    [aux_sym_zero_directive_token4] = ACTIONS(4898),
    [aux_sym_zero_directive_token5] = ACTIONS(4898),
    [aux_sym_zero_directive_token6] = ACTIONS(4898),
    [aux_sym_zero_directive_token7] = ACTIONS(4898),
    [aux_sym_zero_directive_token8] = ACTIONS(4898),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4898),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4898),
    [anon_sym_wire] = ACTIONS(4900),
    [anon_sym_tri] = ACTIONS(4900),
    [anon_sym_tri0] = ACTIONS(4900),
    [anon_sym_tri1] = ACTIONS(4900),
    [anon_sym_wand] = ACTIONS(4900),
    [anon_sym_triand] = ACTIONS(4900),
    [anon_sym_wor] = ACTIONS(4900),
    [anon_sym_trior] = ACTIONS(4900),
    [anon_sym_trireg] = ACTIONS(4900),
    [anon_sym_uwire] = ACTIONS(4900),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4898),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4898),
    [aux_sym_begin_keywords_token1] = ACTIONS(4898),
    [anon_sym_SEMI] = ACTIONS(4898),
    [anon_sym_endmodule] = ACTIONS(4900),
    [anon_sym_extern] = ACTIONS(4900),
    [anon_sym_module] = ACTIONS(4900),
    [anon_sym_macromodule] = ACTIONS(4900),
    [anon_sym_endinterface] = ACTIONS(4900),
    [anon_sym_interface] = ACTIONS(4900),
    [anon_sym_endprogram] = ACTIONS(4900),
    [anon_sym_program] = ACTIONS(4900),
    [anon_sym_checker] = ACTIONS(4900),
    [anon_sym_virtual] = ACTIONS(4900),
    [anon_sym_class] = ACTIONS(4900),
    [anon_sym_package] = ACTIONS(4900),
    [anon_sym_endpackage] = ACTIONS(4900),
    [anon_sym_timeunit] = ACTIONS(4900),
    [anon_sym_timeprecision] = ACTIONS(4900),
    [anon_sym_type] = ACTIONS(4900),
    [anon_sym_input] = ACTIONS(4900),
    [anon_sym_output] = ACTIONS(4900),
    [anon_sym_inout] = ACTIONS(4900),
    [anon_sym_ref] = ACTIONS(4900),
    [anon_sym_DOLLARfatal] = ACTIONS(4898),
    [anon_sym_DOLLARerror] = ACTIONS(4898),
    [anon_sym_DOLLARwarning] = ACTIONS(4898),
    [anon_sym_DOLLARinfo] = ACTIONS(4898),
    [anon_sym_default] = ACTIONS(4900),
    [anon_sym_clocking] = ACTIONS(4900),
    [anon_sym_defparam] = ACTIONS(4900),
    [anon_sym_bind] = ACTIONS(4900),
    [anon_sym_const] = ACTIONS(4900),
    [anon_sym_function] = ACTIONS(4900),
    [anon_sym_static] = ACTIONS(4900),
    [anon_sym_constraint] = ACTIONS(4900),
    [anon_sym_if] = ACTIONS(4900),
    [anon_sym_else] = ACTIONS(4900),
    [anon_sym_LBRACK] = ACTIONS(4898),
    [anon_sym_localparam] = ACTIONS(4900),
    [anon_sym_parameter] = ACTIONS(4900),
    [anon_sym_specparam] = ACTIONS(4900),
    [anon_sym_var] = ACTIONS(4900),
    [anon_sym_import] = ACTIONS(4900),
    [anon_sym_export] = ACTIONS(4900),
    [anon_sym_genvar] = ACTIONS(4900),
    [anon_sym_interconnect] = ACTIONS(4900),
    [anon_sym_typedef] = ACTIONS(4900),
    [anon_sym_enum] = ACTIONS(4900),
    [anon_sym_struct] = ACTIONS(4900),
    [anon_sym_union] = ACTIONS(4900),
    [anon_sym_nettype] = ACTIONS(4900),
    [anon_sym_automatic] = ACTIONS(4900),
    [anon_sym_string] = ACTIONS(4900),
    [anon_sym_chandle] = ACTIONS(4900),
    [anon_sym_event] = ACTIONS(4900),
    [anon_sym_byte] = ACTIONS(4900),
    [anon_sym_shortint] = ACTIONS(4900),
    [anon_sym_int] = ACTIONS(4900),
    [anon_sym_longint] = ACTIONS(4900),
    [anon_sym_integer] = ACTIONS(4900),
    [anon_sym_time] = ACTIONS(4900),
    [anon_sym_bit] = ACTIONS(4900),
    [anon_sym_logic] = ACTIONS(4900),
    [anon_sym_reg] = ACTIONS(4900),
    [anon_sym_shortreal] = ACTIONS(4900),
    [anon_sym_real] = ACTIONS(4900),
    [anon_sym_realtime] = ACTIONS(4900),
    [anon_sym_supply0] = ACTIONS(4900),
    [anon_sym_supply1] = ACTIONS(4900),
    [anon_sym_signed] = ACTIONS(4900),
    [anon_sym_unsigned] = ACTIONS(4900),
    [anon_sym_task] = ACTIONS(4900),
    [anon_sym_modport] = ACTIONS(4900),
    [anon_sym_assert] = ACTIONS(4900),
    [anon_sym_property] = ACTIONS(4900),
    [anon_sym_assume] = ACTIONS(4900),
    [anon_sym_cover] = ACTIONS(4900),
    [anon_sym_sequence] = ACTIONS(4900),
    [anon_sym_restrict] = ACTIONS(4900),
    [anon_sym_not] = ACTIONS(4900),
    [anon_sym_or] = ACTIONS(4900),
    [anon_sym_and] = ACTIONS(4900),
    [anon_sym_case] = ACTIONS(4900),
    [anon_sym_always] = ACTIONS(4900),
    [anon_sym_covergroup] = ACTIONS(4900),
    [anon_sym_let] = ACTIONS(4900),
    [anon_sym_pulldown] = ACTIONS(4900),
    [anon_sym_pullup] = ACTIONS(4900),
    [anon_sym_cmos] = ACTIONS(4900),
    [anon_sym_rcmos] = ACTIONS(4900),
    [anon_sym_bufif0] = ACTIONS(4900),
    [anon_sym_bufif1] = ACTIONS(4900),
    [anon_sym_notif0] = ACTIONS(4900),
    [anon_sym_notif1] = ACTIONS(4900),
    [anon_sym_nmos] = ACTIONS(4900),
    [anon_sym_pmos] = ACTIONS(4900),
    [anon_sym_rnmos] = ACTIONS(4900),
    [anon_sym_rpmos] = ACTIONS(4900),
    [anon_sym_nand] = ACTIONS(4900),
    [anon_sym_nor] = ACTIONS(4900),
    [anon_sym_xor] = ACTIONS(4900),
    [anon_sym_xnor] = ACTIONS(4900),
    [anon_sym_buf] = ACTIONS(4900),
    [anon_sym_tranif0] = ACTIONS(4900),
    [anon_sym_tranif1] = ACTIONS(4900),
    [anon_sym_rtranif1] = ACTIONS(4900),
    [anon_sym_rtranif0] = ACTIONS(4900),
    [anon_sym_tran] = ACTIONS(4900),
    [anon_sym_rtran] = ACTIONS(4900),
    [anon_sym_generate] = ACTIONS(4900),
    [anon_sym_for] = ACTIONS(4900),
    [anon_sym_primitive] = ACTIONS(4900),
    [anon_sym_initial] = ACTIONS(4900),
    [anon_sym_assign] = ACTIONS(4900),
    [anon_sym_alias] = ACTIONS(4900),
    [anon_sym_always_comb] = ACTIONS(4900),
    [anon_sym_always_latch] = ACTIONS(4900),
    [anon_sym_always_ff] = ACTIONS(4900),
    [anon_sym_final] = ACTIONS(4900),
    [anon_sym_global] = ACTIONS(4900),
    [anon_sym_specify] = ACTIONS(4900),
    [anon_sym_LPAREN_STAR] = ACTIONS(4898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4898),
    [anon_sym_DOLLARunit] = ACTIONS(4898),
  },
  [797] = {
    [ts_builtin_sym_end] = ACTIONS(4902),
    [sym_simple_identifier] = ACTIONS(4904),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4902),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4902),
    [anon_sym_BQUOTE] = ACTIONS(4904),
    [aux_sym_id_directive_token1] = ACTIONS(4902),
    [aux_sym_id_directive_token2] = ACTIONS(4902),
    [aux_sym_id_directive_token3] = ACTIONS(4902),
    [aux_sym_id_directive_token4] = ACTIONS(4904),
    [aux_sym_zero_directive_token1] = ACTIONS(4902),
    [aux_sym_zero_directive_token2] = ACTIONS(4902),
    [aux_sym_zero_directive_token3] = ACTIONS(4902),
    [aux_sym_zero_directive_token4] = ACTIONS(4902),
    [aux_sym_zero_directive_token5] = ACTIONS(4902),
    [aux_sym_zero_directive_token6] = ACTIONS(4902),
    [aux_sym_zero_directive_token7] = ACTIONS(4902),
    [aux_sym_zero_directive_token8] = ACTIONS(4902),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4902),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4902),
    [anon_sym_wire] = ACTIONS(4904),
    [anon_sym_tri] = ACTIONS(4904),
    [anon_sym_tri0] = ACTIONS(4904),
    [anon_sym_tri1] = ACTIONS(4904),
    [anon_sym_wand] = ACTIONS(4904),
    [anon_sym_triand] = ACTIONS(4904),
    [anon_sym_wor] = ACTIONS(4904),
    [anon_sym_trior] = ACTIONS(4904),
    [anon_sym_trireg] = ACTIONS(4904),
    [anon_sym_uwire] = ACTIONS(4904),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4902),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4902),
    [aux_sym_begin_keywords_token1] = ACTIONS(4902),
    [anon_sym_SEMI] = ACTIONS(4902),
    [anon_sym_endmodule] = ACTIONS(4904),
    [anon_sym_extern] = ACTIONS(4904),
    [anon_sym_module] = ACTIONS(4904),
    [anon_sym_macromodule] = ACTIONS(4904),
    [anon_sym_endinterface] = ACTIONS(4904),
    [anon_sym_interface] = ACTIONS(4904),
    [anon_sym_endprogram] = ACTIONS(4904),
    [anon_sym_program] = ACTIONS(4904),
    [anon_sym_checker] = ACTIONS(4904),
    [anon_sym_virtual] = ACTIONS(4904),
    [anon_sym_class] = ACTIONS(4904),
    [anon_sym_package] = ACTIONS(4904),
    [anon_sym_endpackage] = ACTIONS(4904),
    [anon_sym_timeunit] = ACTIONS(4904),
    [anon_sym_timeprecision] = ACTIONS(4904),
    [anon_sym_type] = ACTIONS(4904),
    [anon_sym_input] = ACTIONS(4904),
    [anon_sym_output] = ACTIONS(4904),
    [anon_sym_inout] = ACTIONS(4904),
    [anon_sym_ref] = ACTIONS(4904),
    [anon_sym_DOLLARfatal] = ACTIONS(4902),
    [anon_sym_DOLLARerror] = ACTIONS(4902),
    [anon_sym_DOLLARwarning] = ACTIONS(4902),
    [anon_sym_DOLLARinfo] = ACTIONS(4902),
    [anon_sym_default] = ACTIONS(4904),
    [anon_sym_clocking] = ACTIONS(4904),
    [anon_sym_defparam] = ACTIONS(4904),
    [anon_sym_bind] = ACTIONS(4904),
    [anon_sym_const] = ACTIONS(4904),
    [anon_sym_function] = ACTIONS(4904),
    [anon_sym_static] = ACTIONS(4904),
    [anon_sym_constraint] = ACTIONS(4904),
    [anon_sym_if] = ACTIONS(4904),
    [anon_sym_else] = ACTIONS(4904),
    [anon_sym_LBRACK] = ACTIONS(4902),
    [anon_sym_localparam] = ACTIONS(4904),
    [anon_sym_parameter] = ACTIONS(4904),
    [anon_sym_specparam] = ACTIONS(4904),
    [anon_sym_var] = ACTIONS(4904),
    [anon_sym_import] = ACTIONS(4904),
    [anon_sym_export] = ACTIONS(4904),
    [anon_sym_genvar] = ACTIONS(4904),
    [anon_sym_interconnect] = ACTIONS(4904),
    [anon_sym_typedef] = ACTIONS(4904),
    [anon_sym_enum] = ACTIONS(4904),
    [anon_sym_struct] = ACTIONS(4904),
    [anon_sym_union] = ACTIONS(4904),
    [anon_sym_nettype] = ACTIONS(4904),
    [anon_sym_automatic] = ACTIONS(4904),
    [anon_sym_string] = ACTIONS(4904),
    [anon_sym_chandle] = ACTIONS(4904),
    [anon_sym_event] = ACTIONS(4904),
    [anon_sym_byte] = ACTIONS(4904),
    [anon_sym_shortint] = ACTIONS(4904),
    [anon_sym_int] = ACTIONS(4904),
    [anon_sym_longint] = ACTIONS(4904),
    [anon_sym_integer] = ACTIONS(4904),
    [anon_sym_time] = ACTIONS(4904),
    [anon_sym_bit] = ACTIONS(4904),
    [anon_sym_logic] = ACTIONS(4904),
    [anon_sym_reg] = ACTIONS(4904),
    [anon_sym_shortreal] = ACTIONS(4904),
    [anon_sym_real] = ACTIONS(4904),
    [anon_sym_realtime] = ACTIONS(4904),
    [anon_sym_supply0] = ACTIONS(4904),
    [anon_sym_supply1] = ACTIONS(4904),
    [anon_sym_signed] = ACTIONS(4904),
    [anon_sym_unsigned] = ACTIONS(4904),
    [anon_sym_task] = ACTIONS(4904),
    [anon_sym_modport] = ACTIONS(4904),
    [anon_sym_assert] = ACTIONS(4904),
    [anon_sym_property] = ACTIONS(4904),
    [anon_sym_assume] = ACTIONS(4904),
    [anon_sym_cover] = ACTIONS(4904),
    [anon_sym_sequence] = ACTIONS(4904),
    [anon_sym_restrict] = ACTIONS(4904),
    [anon_sym_not] = ACTIONS(4904),
    [anon_sym_or] = ACTIONS(4904),
    [anon_sym_and] = ACTIONS(4904),
    [anon_sym_case] = ACTIONS(4904),
    [anon_sym_always] = ACTIONS(4904),
    [anon_sym_covergroup] = ACTIONS(4904),
    [anon_sym_let] = ACTIONS(4904),
    [anon_sym_pulldown] = ACTIONS(4904),
    [anon_sym_pullup] = ACTIONS(4904),
    [anon_sym_cmos] = ACTIONS(4904),
    [anon_sym_rcmos] = ACTIONS(4904),
    [anon_sym_bufif0] = ACTIONS(4904),
    [anon_sym_bufif1] = ACTIONS(4904),
    [anon_sym_notif0] = ACTIONS(4904),
    [anon_sym_notif1] = ACTIONS(4904),
    [anon_sym_nmos] = ACTIONS(4904),
    [anon_sym_pmos] = ACTIONS(4904),
    [anon_sym_rnmos] = ACTIONS(4904),
    [anon_sym_rpmos] = ACTIONS(4904),
    [anon_sym_nand] = ACTIONS(4904),
    [anon_sym_nor] = ACTIONS(4904),
    [anon_sym_xor] = ACTIONS(4904),
    [anon_sym_xnor] = ACTIONS(4904),
    [anon_sym_buf] = ACTIONS(4904),
    [anon_sym_tranif0] = ACTIONS(4904),
    [anon_sym_tranif1] = ACTIONS(4904),
    [anon_sym_rtranif1] = ACTIONS(4904),
    [anon_sym_rtranif0] = ACTIONS(4904),
    [anon_sym_tran] = ACTIONS(4904),
    [anon_sym_rtran] = ACTIONS(4904),
    [anon_sym_generate] = ACTIONS(4904),
    [anon_sym_for] = ACTIONS(4904),
    [anon_sym_primitive] = ACTIONS(4904),
    [anon_sym_initial] = ACTIONS(4904),
    [anon_sym_assign] = ACTIONS(4904),
    [anon_sym_alias] = ACTIONS(4904),
    [anon_sym_always_comb] = ACTIONS(4904),
    [anon_sym_always_latch] = ACTIONS(4904),
    [anon_sym_always_ff] = ACTIONS(4904),
    [anon_sym_final] = ACTIONS(4904),
    [anon_sym_global] = ACTIONS(4904),
    [anon_sym_specify] = ACTIONS(4904),
    [anon_sym_LPAREN_STAR] = ACTIONS(4902),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4902),
    [anon_sym_DOLLARunit] = ACTIONS(4902),
  },
  [798] = {
    [ts_builtin_sym_end] = ACTIONS(4906),
    [sym_simple_identifier] = ACTIONS(4908),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4906),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4906),
    [anon_sym_BQUOTE] = ACTIONS(4908),
    [aux_sym_id_directive_token1] = ACTIONS(4906),
    [aux_sym_id_directive_token2] = ACTIONS(4906),
    [aux_sym_id_directive_token3] = ACTIONS(4906),
    [aux_sym_id_directive_token4] = ACTIONS(4908),
    [aux_sym_zero_directive_token1] = ACTIONS(4906),
    [aux_sym_zero_directive_token2] = ACTIONS(4906),
    [aux_sym_zero_directive_token3] = ACTIONS(4906),
    [aux_sym_zero_directive_token4] = ACTIONS(4906),
    [aux_sym_zero_directive_token5] = ACTIONS(4906),
    [aux_sym_zero_directive_token6] = ACTIONS(4906),
    [aux_sym_zero_directive_token7] = ACTIONS(4906),
    [aux_sym_zero_directive_token8] = ACTIONS(4906),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4906),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4906),
    [anon_sym_wire] = ACTIONS(4908),
    [anon_sym_tri] = ACTIONS(4908),
    [anon_sym_tri0] = ACTIONS(4908),
    [anon_sym_tri1] = ACTIONS(4908),
    [anon_sym_wand] = ACTIONS(4908),
    [anon_sym_triand] = ACTIONS(4908),
    [anon_sym_wor] = ACTIONS(4908),
    [anon_sym_trior] = ACTIONS(4908),
    [anon_sym_trireg] = ACTIONS(4908),
    [anon_sym_uwire] = ACTIONS(4908),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4906),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4906),
    [aux_sym_begin_keywords_token1] = ACTIONS(4906),
    [anon_sym_SEMI] = ACTIONS(4906),
    [anon_sym_endmodule] = ACTIONS(4908),
    [anon_sym_extern] = ACTIONS(4908),
    [anon_sym_module] = ACTIONS(4908),
    [anon_sym_macromodule] = ACTIONS(4908),
    [anon_sym_endinterface] = ACTIONS(4908),
    [anon_sym_interface] = ACTIONS(4908),
    [anon_sym_endprogram] = ACTIONS(4908),
    [anon_sym_program] = ACTIONS(4908),
    [anon_sym_checker] = ACTIONS(4908),
    [anon_sym_virtual] = ACTIONS(4908),
    [anon_sym_class] = ACTIONS(4908),
    [anon_sym_package] = ACTIONS(4908),
    [anon_sym_endpackage] = ACTIONS(4908),
    [anon_sym_timeunit] = ACTIONS(4908),
    [anon_sym_timeprecision] = ACTIONS(4908),
    [anon_sym_type] = ACTIONS(4908),
    [anon_sym_input] = ACTIONS(4908),
    [anon_sym_output] = ACTIONS(4908),
    [anon_sym_inout] = ACTIONS(4908),
    [anon_sym_ref] = ACTIONS(4908),
    [anon_sym_DOLLARfatal] = ACTIONS(4906),
    [anon_sym_DOLLARerror] = ACTIONS(4906),
    [anon_sym_DOLLARwarning] = ACTIONS(4906),
    [anon_sym_DOLLARinfo] = ACTIONS(4906),
    [anon_sym_default] = ACTIONS(4908),
    [anon_sym_clocking] = ACTIONS(4908),
    [anon_sym_defparam] = ACTIONS(4908),
    [anon_sym_bind] = ACTIONS(4908),
    [anon_sym_const] = ACTIONS(4908),
    [anon_sym_function] = ACTIONS(4908),
    [anon_sym_static] = ACTIONS(4908),
    [anon_sym_constraint] = ACTIONS(4908),
    [anon_sym_if] = ACTIONS(4908),
    [anon_sym_else] = ACTIONS(4908),
    [anon_sym_LBRACK] = ACTIONS(4906),
    [anon_sym_localparam] = ACTIONS(4908),
    [anon_sym_parameter] = ACTIONS(4908),
    [anon_sym_specparam] = ACTIONS(4908),
    [anon_sym_var] = ACTIONS(4908),
    [anon_sym_import] = ACTIONS(4908),
    [anon_sym_export] = ACTIONS(4908),
    [anon_sym_genvar] = ACTIONS(4908),
    [anon_sym_interconnect] = ACTIONS(4908),
    [anon_sym_typedef] = ACTIONS(4908),
    [anon_sym_enum] = ACTIONS(4908),
    [anon_sym_struct] = ACTIONS(4908),
    [anon_sym_union] = ACTIONS(4908),
    [anon_sym_nettype] = ACTIONS(4908),
    [anon_sym_automatic] = ACTIONS(4908),
    [anon_sym_string] = ACTIONS(4908),
    [anon_sym_chandle] = ACTIONS(4908),
    [anon_sym_event] = ACTIONS(4908),
    [anon_sym_byte] = ACTIONS(4908),
    [anon_sym_shortint] = ACTIONS(4908),
    [anon_sym_int] = ACTIONS(4908),
    [anon_sym_longint] = ACTIONS(4908),
    [anon_sym_integer] = ACTIONS(4908),
    [anon_sym_time] = ACTIONS(4908),
    [anon_sym_bit] = ACTIONS(4908),
    [anon_sym_logic] = ACTIONS(4908),
    [anon_sym_reg] = ACTIONS(4908),
    [anon_sym_shortreal] = ACTIONS(4908),
    [anon_sym_real] = ACTIONS(4908),
    [anon_sym_realtime] = ACTIONS(4908),
    [anon_sym_supply0] = ACTIONS(4908),
    [anon_sym_supply1] = ACTIONS(4908),
    [anon_sym_signed] = ACTIONS(4908),
    [anon_sym_unsigned] = ACTIONS(4908),
    [anon_sym_task] = ACTIONS(4908),
    [anon_sym_modport] = ACTIONS(4908),
    [anon_sym_assert] = ACTIONS(4908),
    [anon_sym_property] = ACTIONS(4908),
    [anon_sym_assume] = ACTIONS(4908),
    [anon_sym_cover] = ACTIONS(4908),
    [anon_sym_sequence] = ACTIONS(4908),
    [anon_sym_restrict] = ACTIONS(4908),
    [anon_sym_not] = ACTIONS(4908),
    [anon_sym_or] = ACTIONS(4908),
    [anon_sym_and] = ACTIONS(4908),
    [anon_sym_case] = ACTIONS(4908),
    [anon_sym_always] = ACTIONS(4908),
    [anon_sym_covergroup] = ACTIONS(4908),
    [anon_sym_let] = ACTIONS(4908),
    [anon_sym_pulldown] = ACTIONS(4908),
    [anon_sym_pullup] = ACTIONS(4908),
    [anon_sym_cmos] = ACTIONS(4908),
    [anon_sym_rcmos] = ACTIONS(4908),
    [anon_sym_bufif0] = ACTIONS(4908),
    [anon_sym_bufif1] = ACTIONS(4908),
    [anon_sym_notif0] = ACTIONS(4908),
    [anon_sym_notif1] = ACTIONS(4908),
    [anon_sym_nmos] = ACTIONS(4908),
    [anon_sym_pmos] = ACTIONS(4908),
    [anon_sym_rnmos] = ACTIONS(4908),
    [anon_sym_rpmos] = ACTIONS(4908),
    [anon_sym_nand] = ACTIONS(4908),
    [anon_sym_nor] = ACTIONS(4908),
    [anon_sym_xor] = ACTIONS(4908),
    [anon_sym_xnor] = ACTIONS(4908),
    [anon_sym_buf] = ACTIONS(4908),
    [anon_sym_tranif0] = ACTIONS(4908),
    [anon_sym_tranif1] = ACTIONS(4908),
    [anon_sym_rtranif1] = ACTIONS(4908),
    [anon_sym_rtranif0] = ACTIONS(4908),
    [anon_sym_tran] = ACTIONS(4908),
    [anon_sym_rtran] = ACTIONS(4908),
    [anon_sym_generate] = ACTIONS(4908),
    [anon_sym_for] = ACTIONS(4908),
    [anon_sym_primitive] = ACTIONS(4908),
    [anon_sym_initial] = ACTIONS(4908),
    [anon_sym_assign] = ACTIONS(4908),
    [anon_sym_alias] = ACTIONS(4908),
    [anon_sym_always_comb] = ACTIONS(4908),
    [anon_sym_always_latch] = ACTIONS(4908),
    [anon_sym_always_ff] = ACTIONS(4908),
    [anon_sym_final] = ACTIONS(4908),
    [anon_sym_global] = ACTIONS(4908),
    [anon_sym_specify] = ACTIONS(4908),
    [anon_sym_LPAREN_STAR] = ACTIONS(4906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4906),
    [anon_sym_DOLLARunit] = ACTIONS(4906),
  },
  [799] = {
    [ts_builtin_sym_end] = ACTIONS(4798),
    [sym_simple_identifier] = ACTIONS(4800),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4798),
    [anon_sym_BQUOTE] = ACTIONS(4800),
    [aux_sym_id_directive_token1] = ACTIONS(4798),
    [aux_sym_id_directive_token2] = ACTIONS(4798),
    [aux_sym_id_directive_token3] = ACTIONS(4798),
    [aux_sym_id_directive_token4] = ACTIONS(4800),
    [aux_sym_zero_directive_token1] = ACTIONS(4798),
    [aux_sym_zero_directive_token2] = ACTIONS(4798),
    [aux_sym_zero_directive_token3] = ACTIONS(4798),
    [aux_sym_zero_directive_token4] = ACTIONS(4798),
    [aux_sym_zero_directive_token5] = ACTIONS(4798),
    [aux_sym_zero_directive_token6] = ACTIONS(4798),
    [aux_sym_zero_directive_token7] = ACTIONS(4798),
    [aux_sym_zero_directive_token8] = ACTIONS(4798),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4798),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4798),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4798),
    [aux_sym_begin_keywords_token1] = ACTIONS(4798),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_endmodule] = ACTIONS(4800),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_module] = ACTIONS(4800),
    [anon_sym_macromodule] = ACTIONS(4800),
    [anon_sym_endinterface] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_endprogram] = ACTIONS(4800),
    [anon_sym_program] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_package] = ACTIONS(4800),
    [anon_sym_endpackage] = ACTIONS(4800),
    [anon_sym_timeunit] = ACTIONS(4800),
    [anon_sym_timeprecision] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_input] = ACTIONS(4800),
    [anon_sym_output] = ACTIONS(4800),
    [anon_sym_inout] = ACTIONS(4800),
    [anon_sym_ref] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_specparam] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_modport] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_primitive] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_specify] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [800] = {
    [ts_builtin_sym_end] = ACTIONS(4910),
    [sym_simple_identifier] = ACTIONS(4912),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4910),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4910),
    [anon_sym_BQUOTE] = ACTIONS(4912),
    [aux_sym_id_directive_token1] = ACTIONS(4910),
    [aux_sym_id_directive_token2] = ACTIONS(4910),
    [aux_sym_id_directive_token3] = ACTIONS(4910),
    [aux_sym_id_directive_token4] = ACTIONS(4912),
    [aux_sym_zero_directive_token1] = ACTIONS(4910),
    [aux_sym_zero_directive_token2] = ACTIONS(4910),
    [aux_sym_zero_directive_token3] = ACTIONS(4910),
    [aux_sym_zero_directive_token4] = ACTIONS(4910),
    [aux_sym_zero_directive_token5] = ACTIONS(4910),
    [aux_sym_zero_directive_token6] = ACTIONS(4910),
    [aux_sym_zero_directive_token7] = ACTIONS(4910),
    [aux_sym_zero_directive_token8] = ACTIONS(4910),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4910),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4910),
    [anon_sym_wire] = ACTIONS(4912),
    [anon_sym_tri] = ACTIONS(4912),
    [anon_sym_tri0] = ACTIONS(4912),
    [anon_sym_tri1] = ACTIONS(4912),
    [anon_sym_wand] = ACTIONS(4912),
    [anon_sym_triand] = ACTIONS(4912),
    [anon_sym_wor] = ACTIONS(4912),
    [anon_sym_trior] = ACTIONS(4912),
    [anon_sym_trireg] = ACTIONS(4912),
    [anon_sym_uwire] = ACTIONS(4912),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4910),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4910),
    [aux_sym_begin_keywords_token1] = ACTIONS(4910),
    [anon_sym_SEMI] = ACTIONS(4910),
    [anon_sym_endmodule] = ACTIONS(4912),
    [anon_sym_extern] = ACTIONS(4912),
    [anon_sym_module] = ACTIONS(4912),
    [anon_sym_macromodule] = ACTIONS(4912),
    [anon_sym_endinterface] = ACTIONS(4912),
    [anon_sym_interface] = ACTIONS(4912),
    [anon_sym_endprogram] = ACTIONS(4912),
    [anon_sym_program] = ACTIONS(4912),
    [anon_sym_checker] = ACTIONS(4912),
    [anon_sym_virtual] = ACTIONS(4912),
    [anon_sym_class] = ACTIONS(4912),
    [anon_sym_package] = ACTIONS(4912),
    [anon_sym_endpackage] = ACTIONS(4912),
    [anon_sym_timeunit] = ACTIONS(4912),
    [anon_sym_timeprecision] = ACTIONS(4912),
    [anon_sym_type] = ACTIONS(4912),
    [anon_sym_input] = ACTIONS(4912),
    [anon_sym_output] = ACTIONS(4912),
    [anon_sym_inout] = ACTIONS(4912),
    [anon_sym_ref] = ACTIONS(4912),
    [anon_sym_DOLLARfatal] = ACTIONS(4910),
    [anon_sym_DOLLARerror] = ACTIONS(4910),
    [anon_sym_DOLLARwarning] = ACTIONS(4910),
    [anon_sym_DOLLARinfo] = ACTIONS(4910),
    [anon_sym_default] = ACTIONS(4912),
    [anon_sym_clocking] = ACTIONS(4912),
    [anon_sym_defparam] = ACTIONS(4912),
    [anon_sym_bind] = ACTIONS(4912),
    [anon_sym_const] = ACTIONS(4912),
    [anon_sym_function] = ACTIONS(4912),
    [anon_sym_static] = ACTIONS(4912),
    [anon_sym_constraint] = ACTIONS(4912),
    [anon_sym_if] = ACTIONS(4912),
    [anon_sym_else] = ACTIONS(4912),
    [anon_sym_LBRACK] = ACTIONS(4910),
    [anon_sym_localparam] = ACTIONS(4912),
    [anon_sym_parameter] = ACTIONS(4912),
    [anon_sym_specparam] = ACTIONS(4912),
    [anon_sym_var] = ACTIONS(4912),
    [anon_sym_import] = ACTIONS(4912),
    [anon_sym_export] = ACTIONS(4912),
    [anon_sym_genvar] = ACTIONS(4912),
    [anon_sym_interconnect] = ACTIONS(4912),
    [anon_sym_typedef] = ACTIONS(4912),
    [anon_sym_enum] = ACTIONS(4912),
    [anon_sym_struct] = ACTIONS(4912),
    [anon_sym_union] = ACTIONS(4912),
    [anon_sym_nettype] = ACTIONS(4912),
    [anon_sym_automatic] = ACTIONS(4912),
    [anon_sym_string] = ACTIONS(4912),
    [anon_sym_chandle] = ACTIONS(4912),
    [anon_sym_event] = ACTIONS(4912),
    [anon_sym_byte] = ACTIONS(4912),
    [anon_sym_shortint] = ACTIONS(4912),
    [anon_sym_int] = ACTIONS(4912),
    [anon_sym_longint] = ACTIONS(4912),
    [anon_sym_integer] = ACTIONS(4912),
    [anon_sym_time] = ACTIONS(4912),
    [anon_sym_bit] = ACTIONS(4912),
    [anon_sym_logic] = ACTIONS(4912),
    [anon_sym_reg] = ACTIONS(4912),
    [anon_sym_shortreal] = ACTIONS(4912),
    [anon_sym_real] = ACTIONS(4912),
    [anon_sym_realtime] = ACTIONS(4912),
    [anon_sym_supply0] = ACTIONS(4912),
    [anon_sym_supply1] = ACTIONS(4912),
    [anon_sym_signed] = ACTIONS(4912),
    [anon_sym_unsigned] = ACTIONS(4912),
    [anon_sym_task] = ACTIONS(4912),
    [anon_sym_modport] = ACTIONS(4912),
    [anon_sym_assert] = ACTIONS(4912),
    [anon_sym_property] = ACTIONS(4912),
    [anon_sym_assume] = ACTIONS(4912),
    [anon_sym_cover] = ACTIONS(4912),
    [anon_sym_sequence] = ACTIONS(4912),
    [anon_sym_restrict] = ACTIONS(4912),
    [anon_sym_not] = ACTIONS(4912),
    [anon_sym_or] = ACTIONS(4912),
    [anon_sym_and] = ACTIONS(4912),
    [anon_sym_case] = ACTIONS(4912),
    [anon_sym_always] = ACTIONS(4912),
    [anon_sym_covergroup] = ACTIONS(4912),
    [anon_sym_let] = ACTIONS(4912),
    [anon_sym_pulldown] = ACTIONS(4912),
    [anon_sym_pullup] = ACTIONS(4912),
    [anon_sym_cmos] = ACTIONS(4912),
    [anon_sym_rcmos] = ACTIONS(4912),
    [anon_sym_bufif0] = ACTIONS(4912),
    [anon_sym_bufif1] = ACTIONS(4912),
    [anon_sym_notif0] = ACTIONS(4912),
    [anon_sym_notif1] = ACTIONS(4912),
    [anon_sym_nmos] = ACTIONS(4912),
    [anon_sym_pmos] = ACTIONS(4912),
    [anon_sym_rnmos] = ACTIONS(4912),
    [anon_sym_rpmos] = ACTIONS(4912),
    [anon_sym_nand] = ACTIONS(4912),
    [anon_sym_nor] = ACTIONS(4912),
    [anon_sym_xor] = ACTIONS(4912),
    [anon_sym_xnor] = ACTIONS(4912),
    [anon_sym_buf] = ACTIONS(4912),
    [anon_sym_tranif0] = ACTIONS(4912),
    [anon_sym_tranif1] = ACTIONS(4912),
    [anon_sym_rtranif1] = ACTIONS(4912),
    [anon_sym_rtranif0] = ACTIONS(4912),
    [anon_sym_tran] = ACTIONS(4912),
    [anon_sym_rtran] = ACTIONS(4912),
    [anon_sym_generate] = ACTIONS(4912),
    [anon_sym_for] = ACTIONS(4912),
    [anon_sym_primitive] = ACTIONS(4912),
    [anon_sym_initial] = ACTIONS(4912),
    [anon_sym_assign] = ACTIONS(4912),
    [anon_sym_alias] = ACTIONS(4912),
    [anon_sym_always_comb] = ACTIONS(4912),
    [anon_sym_always_latch] = ACTIONS(4912),
    [anon_sym_always_ff] = ACTIONS(4912),
    [anon_sym_final] = ACTIONS(4912),
    [anon_sym_global] = ACTIONS(4912),
    [anon_sym_specify] = ACTIONS(4912),
    [anon_sym_LPAREN_STAR] = ACTIONS(4910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4910),
    [anon_sym_DOLLARunit] = ACTIONS(4910),
  },
  [801] = {
    [ts_builtin_sym_end] = ACTIONS(4914),
    [sym_simple_identifier] = ACTIONS(4916),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4914),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4914),
    [anon_sym_BQUOTE] = ACTIONS(4916),
    [aux_sym_id_directive_token1] = ACTIONS(4914),
    [aux_sym_id_directive_token2] = ACTIONS(4914),
    [aux_sym_id_directive_token3] = ACTIONS(4914),
    [aux_sym_id_directive_token4] = ACTIONS(4916),
    [aux_sym_zero_directive_token1] = ACTIONS(4914),
    [aux_sym_zero_directive_token2] = ACTIONS(4914),
    [aux_sym_zero_directive_token3] = ACTIONS(4914),
    [aux_sym_zero_directive_token4] = ACTIONS(4914),
    [aux_sym_zero_directive_token5] = ACTIONS(4914),
    [aux_sym_zero_directive_token6] = ACTIONS(4914),
    [aux_sym_zero_directive_token7] = ACTIONS(4914),
    [aux_sym_zero_directive_token8] = ACTIONS(4914),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4914),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4914),
    [anon_sym_wire] = ACTIONS(4916),
    [anon_sym_tri] = ACTIONS(4916),
    [anon_sym_tri0] = ACTIONS(4916),
    [anon_sym_tri1] = ACTIONS(4916),
    [anon_sym_wand] = ACTIONS(4916),
    [anon_sym_triand] = ACTIONS(4916),
    [anon_sym_wor] = ACTIONS(4916),
    [anon_sym_trior] = ACTIONS(4916),
    [anon_sym_trireg] = ACTIONS(4916),
    [anon_sym_uwire] = ACTIONS(4916),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4914),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4914),
    [aux_sym_begin_keywords_token1] = ACTIONS(4914),
    [anon_sym_SEMI] = ACTIONS(4914),
    [anon_sym_endmodule] = ACTIONS(4916),
    [anon_sym_extern] = ACTIONS(4916),
    [anon_sym_module] = ACTIONS(4916),
    [anon_sym_macromodule] = ACTIONS(4916),
    [anon_sym_endinterface] = ACTIONS(4916),
    [anon_sym_interface] = ACTIONS(4916),
    [anon_sym_endprogram] = ACTIONS(4916),
    [anon_sym_program] = ACTIONS(4916),
    [anon_sym_checker] = ACTIONS(4916),
    [anon_sym_virtual] = ACTIONS(4916),
    [anon_sym_class] = ACTIONS(4916),
    [anon_sym_package] = ACTIONS(4916),
    [anon_sym_endpackage] = ACTIONS(4916),
    [anon_sym_timeunit] = ACTIONS(4916),
    [anon_sym_timeprecision] = ACTIONS(4916),
    [anon_sym_type] = ACTIONS(4916),
    [anon_sym_input] = ACTIONS(4916),
    [anon_sym_output] = ACTIONS(4916),
    [anon_sym_inout] = ACTIONS(4916),
    [anon_sym_ref] = ACTIONS(4916),
    [anon_sym_DOLLARfatal] = ACTIONS(4914),
    [anon_sym_DOLLARerror] = ACTIONS(4914),
    [anon_sym_DOLLARwarning] = ACTIONS(4914),
    [anon_sym_DOLLARinfo] = ACTIONS(4914),
    [anon_sym_default] = ACTIONS(4916),
    [anon_sym_clocking] = ACTIONS(4916),
    [anon_sym_defparam] = ACTIONS(4916),
    [anon_sym_bind] = ACTIONS(4916),
    [anon_sym_const] = ACTIONS(4916),
    [anon_sym_function] = ACTIONS(4916),
    [anon_sym_static] = ACTIONS(4916),
    [anon_sym_constraint] = ACTIONS(4916),
    [anon_sym_if] = ACTIONS(4916),
    [anon_sym_else] = ACTIONS(4916),
    [anon_sym_LBRACK] = ACTIONS(4914),
    [anon_sym_localparam] = ACTIONS(4916),
    [anon_sym_parameter] = ACTIONS(4916),
    [anon_sym_specparam] = ACTIONS(4916),
    [anon_sym_var] = ACTIONS(4916),
    [anon_sym_import] = ACTIONS(4916),
    [anon_sym_export] = ACTIONS(4916),
    [anon_sym_genvar] = ACTIONS(4916),
    [anon_sym_interconnect] = ACTIONS(4916),
    [anon_sym_typedef] = ACTIONS(4916),
    [anon_sym_enum] = ACTIONS(4916),
    [anon_sym_struct] = ACTIONS(4916),
    [anon_sym_union] = ACTIONS(4916),
    [anon_sym_nettype] = ACTIONS(4916),
    [anon_sym_automatic] = ACTIONS(4916),
    [anon_sym_string] = ACTIONS(4916),
    [anon_sym_chandle] = ACTIONS(4916),
    [anon_sym_event] = ACTIONS(4916),
    [anon_sym_byte] = ACTIONS(4916),
    [anon_sym_shortint] = ACTIONS(4916),
    [anon_sym_int] = ACTIONS(4916),
    [anon_sym_longint] = ACTIONS(4916),
    [anon_sym_integer] = ACTIONS(4916),
    [anon_sym_time] = ACTIONS(4916),
    [anon_sym_bit] = ACTIONS(4916),
    [anon_sym_logic] = ACTIONS(4916),
    [anon_sym_reg] = ACTIONS(4916),
    [anon_sym_shortreal] = ACTIONS(4916),
    [anon_sym_real] = ACTIONS(4916),
    [anon_sym_realtime] = ACTIONS(4916),
    [anon_sym_supply0] = ACTIONS(4916),
    [anon_sym_supply1] = ACTIONS(4916),
    [anon_sym_signed] = ACTIONS(4916),
    [anon_sym_unsigned] = ACTIONS(4916),
    [anon_sym_task] = ACTIONS(4916),
    [anon_sym_modport] = ACTIONS(4916),
    [anon_sym_assert] = ACTIONS(4916),
    [anon_sym_property] = ACTIONS(4916),
    [anon_sym_assume] = ACTIONS(4916),
    [anon_sym_cover] = ACTIONS(4916),
    [anon_sym_sequence] = ACTIONS(4916),
    [anon_sym_restrict] = ACTIONS(4916),
    [anon_sym_not] = ACTIONS(4916),
    [anon_sym_or] = ACTIONS(4916),
    [anon_sym_and] = ACTIONS(4916),
    [anon_sym_case] = ACTIONS(4916),
    [anon_sym_always] = ACTIONS(4916),
    [anon_sym_covergroup] = ACTIONS(4916),
    [anon_sym_let] = ACTIONS(4916),
    [anon_sym_pulldown] = ACTIONS(4916),
    [anon_sym_pullup] = ACTIONS(4916),
    [anon_sym_cmos] = ACTIONS(4916),
    [anon_sym_rcmos] = ACTIONS(4916),
    [anon_sym_bufif0] = ACTIONS(4916),
    [anon_sym_bufif1] = ACTIONS(4916),
    [anon_sym_notif0] = ACTIONS(4916),
    [anon_sym_notif1] = ACTIONS(4916),
    [anon_sym_nmos] = ACTIONS(4916),
    [anon_sym_pmos] = ACTIONS(4916),
    [anon_sym_rnmos] = ACTIONS(4916),
    [anon_sym_rpmos] = ACTIONS(4916),
    [anon_sym_nand] = ACTIONS(4916),
    [anon_sym_nor] = ACTIONS(4916),
    [anon_sym_xor] = ACTIONS(4916),
    [anon_sym_xnor] = ACTIONS(4916),
    [anon_sym_buf] = ACTIONS(4916),
    [anon_sym_tranif0] = ACTIONS(4916),
    [anon_sym_tranif1] = ACTIONS(4916),
    [anon_sym_rtranif1] = ACTIONS(4916),
    [anon_sym_rtranif0] = ACTIONS(4916),
    [anon_sym_tran] = ACTIONS(4916),
    [anon_sym_rtran] = ACTIONS(4916),
    [anon_sym_generate] = ACTIONS(4916),
    [anon_sym_for] = ACTIONS(4916),
    [anon_sym_primitive] = ACTIONS(4916),
    [anon_sym_initial] = ACTIONS(4916),
    [anon_sym_assign] = ACTIONS(4916),
    [anon_sym_alias] = ACTIONS(4916),
    [anon_sym_always_comb] = ACTIONS(4916),
    [anon_sym_always_latch] = ACTIONS(4916),
    [anon_sym_always_ff] = ACTIONS(4916),
    [anon_sym_final] = ACTIONS(4916),
    [anon_sym_global] = ACTIONS(4916),
    [anon_sym_specify] = ACTIONS(4916),
    [anon_sym_LPAREN_STAR] = ACTIONS(4914),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4914),
    [anon_sym_DOLLARunit] = ACTIONS(4914),
  },
  [802] = {
    [ts_builtin_sym_end] = ACTIONS(4918),
    [sym_simple_identifier] = ACTIONS(4920),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4918),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4918),
    [anon_sym_BQUOTE] = ACTIONS(4920),
    [aux_sym_id_directive_token1] = ACTIONS(4918),
    [aux_sym_id_directive_token2] = ACTIONS(4918),
    [aux_sym_id_directive_token3] = ACTIONS(4918),
    [aux_sym_id_directive_token4] = ACTIONS(4920),
    [aux_sym_zero_directive_token1] = ACTIONS(4918),
    [aux_sym_zero_directive_token2] = ACTIONS(4918),
    [aux_sym_zero_directive_token3] = ACTIONS(4918),
    [aux_sym_zero_directive_token4] = ACTIONS(4918),
    [aux_sym_zero_directive_token5] = ACTIONS(4918),
    [aux_sym_zero_directive_token6] = ACTIONS(4918),
    [aux_sym_zero_directive_token7] = ACTIONS(4918),
    [aux_sym_zero_directive_token8] = ACTIONS(4918),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4918),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4918),
    [anon_sym_wire] = ACTIONS(4920),
    [anon_sym_tri] = ACTIONS(4920),
    [anon_sym_tri0] = ACTIONS(4920),
    [anon_sym_tri1] = ACTIONS(4920),
    [anon_sym_wand] = ACTIONS(4920),
    [anon_sym_triand] = ACTIONS(4920),
    [anon_sym_wor] = ACTIONS(4920),
    [anon_sym_trior] = ACTIONS(4920),
    [anon_sym_trireg] = ACTIONS(4920),
    [anon_sym_uwire] = ACTIONS(4920),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4918),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4918),
    [aux_sym_begin_keywords_token1] = ACTIONS(4918),
    [anon_sym_SEMI] = ACTIONS(4918),
    [anon_sym_endmodule] = ACTIONS(4920),
    [anon_sym_extern] = ACTIONS(4920),
    [anon_sym_module] = ACTIONS(4920),
    [anon_sym_macromodule] = ACTIONS(4920),
    [anon_sym_endinterface] = ACTIONS(4920),
    [anon_sym_interface] = ACTIONS(4920),
    [anon_sym_endprogram] = ACTIONS(4920),
    [anon_sym_program] = ACTIONS(4920),
    [anon_sym_checker] = ACTIONS(4920),
    [anon_sym_virtual] = ACTIONS(4920),
    [anon_sym_class] = ACTIONS(4920),
    [anon_sym_package] = ACTIONS(4920),
    [anon_sym_endpackage] = ACTIONS(4920),
    [anon_sym_timeunit] = ACTIONS(4920),
    [anon_sym_timeprecision] = ACTIONS(4920),
    [anon_sym_type] = ACTIONS(4920),
    [anon_sym_input] = ACTIONS(4920),
    [anon_sym_output] = ACTIONS(4920),
    [anon_sym_inout] = ACTIONS(4920),
    [anon_sym_ref] = ACTIONS(4920),
    [anon_sym_DOLLARfatal] = ACTIONS(4918),
    [anon_sym_DOLLARerror] = ACTIONS(4918),
    [anon_sym_DOLLARwarning] = ACTIONS(4918),
    [anon_sym_DOLLARinfo] = ACTIONS(4918),
    [anon_sym_default] = ACTIONS(4920),
    [anon_sym_clocking] = ACTIONS(4920),
    [anon_sym_defparam] = ACTIONS(4920),
    [anon_sym_bind] = ACTIONS(4920),
    [anon_sym_const] = ACTIONS(4920),
    [anon_sym_function] = ACTIONS(4920),
    [anon_sym_static] = ACTIONS(4920),
    [anon_sym_constraint] = ACTIONS(4920),
    [anon_sym_if] = ACTIONS(4920),
    [anon_sym_else] = ACTIONS(4920),
    [anon_sym_LBRACK] = ACTIONS(4918),
    [anon_sym_localparam] = ACTIONS(4920),
    [anon_sym_parameter] = ACTIONS(4920),
    [anon_sym_specparam] = ACTIONS(4920),
    [anon_sym_var] = ACTIONS(4920),
    [anon_sym_import] = ACTIONS(4920),
    [anon_sym_export] = ACTIONS(4920),
    [anon_sym_genvar] = ACTIONS(4920),
    [anon_sym_interconnect] = ACTIONS(4920),
    [anon_sym_typedef] = ACTIONS(4920),
    [anon_sym_enum] = ACTIONS(4920),
    [anon_sym_struct] = ACTIONS(4920),
    [anon_sym_union] = ACTIONS(4920),
    [anon_sym_nettype] = ACTIONS(4920),
    [anon_sym_automatic] = ACTIONS(4920),
    [anon_sym_string] = ACTIONS(4920),
    [anon_sym_chandle] = ACTIONS(4920),
    [anon_sym_event] = ACTIONS(4920),
    [anon_sym_byte] = ACTIONS(4920),
    [anon_sym_shortint] = ACTIONS(4920),
    [anon_sym_int] = ACTIONS(4920),
    [anon_sym_longint] = ACTIONS(4920),
    [anon_sym_integer] = ACTIONS(4920),
    [anon_sym_time] = ACTIONS(4920),
    [anon_sym_bit] = ACTIONS(4920),
    [anon_sym_logic] = ACTIONS(4920),
    [anon_sym_reg] = ACTIONS(4920),
    [anon_sym_shortreal] = ACTIONS(4920),
    [anon_sym_real] = ACTIONS(4920),
    [anon_sym_realtime] = ACTIONS(4920),
    [anon_sym_supply0] = ACTIONS(4920),
    [anon_sym_supply1] = ACTIONS(4920),
    [anon_sym_signed] = ACTIONS(4920),
    [anon_sym_unsigned] = ACTIONS(4920),
    [anon_sym_task] = ACTIONS(4920),
    [anon_sym_modport] = ACTIONS(4920),
    [anon_sym_assert] = ACTIONS(4920),
    [anon_sym_property] = ACTIONS(4920),
    [anon_sym_assume] = ACTIONS(4920),
    [anon_sym_cover] = ACTIONS(4920),
    [anon_sym_sequence] = ACTIONS(4920),
    [anon_sym_restrict] = ACTIONS(4920),
    [anon_sym_not] = ACTIONS(4920),
    [anon_sym_or] = ACTIONS(4920),
    [anon_sym_and] = ACTIONS(4920),
    [anon_sym_case] = ACTIONS(4920),
    [anon_sym_always] = ACTIONS(4920),
    [anon_sym_covergroup] = ACTIONS(4920),
    [anon_sym_let] = ACTIONS(4920),
    [anon_sym_pulldown] = ACTIONS(4920),
    [anon_sym_pullup] = ACTIONS(4920),
    [anon_sym_cmos] = ACTIONS(4920),
    [anon_sym_rcmos] = ACTIONS(4920),
    [anon_sym_bufif0] = ACTIONS(4920),
    [anon_sym_bufif1] = ACTIONS(4920),
    [anon_sym_notif0] = ACTIONS(4920),
    [anon_sym_notif1] = ACTIONS(4920),
    [anon_sym_nmos] = ACTIONS(4920),
    [anon_sym_pmos] = ACTIONS(4920),
    [anon_sym_rnmos] = ACTIONS(4920),
    [anon_sym_rpmos] = ACTIONS(4920),
    [anon_sym_nand] = ACTIONS(4920),
    [anon_sym_nor] = ACTIONS(4920),
    [anon_sym_xor] = ACTIONS(4920),
    [anon_sym_xnor] = ACTIONS(4920),
    [anon_sym_buf] = ACTIONS(4920),
    [anon_sym_tranif0] = ACTIONS(4920),
    [anon_sym_tranif1] = ACTIONS(4920),
    [anon_sym_rtranif1] = ACTIONS(4920),
    [anon_sym_rtranif0] = ACTIONS(4920),
    [anon_sym_tran] = ACTIONS(4920),
    [anon_sym_rtran] = ACTIONS(4920),
    [anon_sym_generate] = ACTIONS(4920),
    [anon_sym_for] = ACTIONS(4920),
    [anon_sym_primitive] = ACTIONS(4920),
    [anon_sym_initial] = ACTIONS(4920),
    [anon_sym_assign] = ACTIONS(4920),
    [anon_sym_alias] = ACTIONS(4920),
    [anon_sym_always_comb] = ACTIONS(4920),
    [anon_sym_always_latch] = ACTIONS(4920),
    [anon_sym_always_ff] = ACTIONS(4920),
    [anon_sym_final] = ACTIONS(4920),
    [anon_sym_global] = ACTIONS(4920),
    [anon_sym_specify] = ACTIONS(4920),
    [anon_sym_LPAREN_STAR] = ACTIONS(4918),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4918),
    [anon_sym_DOLLARunit] = ACTIONS(4918),
  },
  [803] = {
    [ts_builtin_sym_end] = ACTIONS(4922),
    [sym_simple_identifier] = ACTIONS(4924),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4922),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4922),
    [anon_sym_BQUOTE] = ACTIONS(4924),
    [aux_sym_id_directive_token1] = ACTIONS(4922),
    [aux_sym_id_directive_token2] = ACTIONS(4922),
    [aux_sym_id_directive_token3] = ACTIONS(4922),
    [aux_sym_id_directive_token4] = ACTIONS(4924),
    [aux_sym_zero_directive_token1] = ACTIONS(4922),
    [aux_sym_zero_directive_token2] = ACTIONS(4922),
    [aux_sym_zero_directive_token3] = ACTIONS(4922),
    [aux_sym_zero_directive_token4] = ACTIONS(4922),
    [aux_sym_zero_directive_token5] = ACTIONS(4922),
    [aux_sym_zero_directive_token6] = ACTIONS(4922),
    [aux_sym_zero_directive_token7] = ACTIONS(4922),
    [aux_sym_zero_directive_token8] = ACTIONS(4922),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4922),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4922),
    [anon_sym_wire] = ACTIONS(4924),
    [anon_sym_tri] = ACTIONS(4924),
    [anon_sym_tri0] = ACTIONS(4924),
    [anon_sym_tri1] = ACTIONS(4924),
    [anon_sym_wand] = ACTIONS(4924),
    [anon_sym_triand] = ACTIONS(4924),
    [anon_sym_wor] = ACTIONS(4924),
    [anon_sym_trior] = ACTIONS(4924),
    [anon_sym_trireg] = ACTIONS(4924),
    [anon_sym_uwire] = ACTIONS(4924),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4922),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4922),
    [aux_sym_begin_keywords_token1] = ACTIONS(4922),
    [anon_sym_SEMI] = ACTIONS(4922),
    [anon_sym_endmodule] = ACTIONS(4924),
    [anon_sym_extern] = ACTIONS(4924),
    [anon_sym_module] = ACTIONS(4924),
    [anon_sym_macromodule] = ACTIONS(4924),
    [anon_sym_endinterface] = ACTIONS(4924),
    [anon_sym_interface] = ACTIONS(4924),
    [anon_sym_endprogram] = ACTIONS(4924),
    [anon_sym_program] = ACTIONS(4924),
    [anon_sym_checker] = ACTIONS(4924),
    [anon_sym_virtual] = ACTIONS(4924),
    [anon_sym_class] = ACTIONS(4924),
    [anon_sym_package] = ACTIONS(4924),
    [anon_sym_endpackage] = ACTIONS(4924),
    [anon_sym_timeunit] = ACTIONS(4924),
    [anon_sym_timeprecision] = ACTIONS(4924),
    [anon_sym_type] = ACTIONS(4924),
    [anon_sym_input] = ACTIONS(4924),
    [anon_sym_output] = ACTIONS(4924),
    [anon_sym_inout] = ACTIONS(4924),
    [anon_sym_ref] = ACTIONS(4924),
    [anon_sym_DOLLARfatal] = ACTIONS(4922),
    [anon_sym_DOLLARerror] = ACTIONS(4922),
    [anon_sym_DOLLARwarning] = ACTIONS(4922),
    [anon_sym_DOLLARinfo] = ACTIONS(4922),
    [anon_sym_default] = ACTIONS(4924),
    [anon_sym_clocking] = ACTIONS(4924),
    [anon_sym_defparam] = ACTIONS(4924),
    [anon_sym_bind] = ACTIONS(4924),
    [anon_sym_const] = ACTIONS(4924),
    [anon_sym_function] = ACTIONS(4924),
    [anon_sym_static] = ACTIONS(4924),
    [anon_sym_constraint] = ACTIONS(4924),
    [anon_sym_if] = ACTIONS(4924),
    [anon_sym_else] = ACTIONS(4924),
    [anon_sym_LBRACK] = ACTIONS(4922),
    [anon_sym_localparam] = ACTIONS(4924),
    [anon_sym_parameter] = ACTIONS(4924),
    [anon_sym_specparam] = ACTIONS(4924),
    [anon_sym_var] = ACTIONS(4924),
    [anon_sym_import] = ACTIONS(4924),
    [anon_sym_export] = ACTIONS(4924),
    [anon_sym_genvar] = ACTIONS(4924),
    [anon_sym_interconnect] = ACTIONS(4924),
    [anon_sym_typedef] = ACTIONS(4924),
    [anon_sym_enum] = ACTIONS(4924),
    [anon_sym_struct] = ACTIONS(4924),
    [anon_sym_union] = ACTIONS(4924),
    [anon_sym_nettype] = ACTIONS(4924),
    [anon_sym_automatic] = ACTIONS(4924),
    [anon_sym_string] = ACTIONS(4924),
    [anon_sym_chandle] = ACTIONS(4924),
    [anon_sym_event] = ACTIONS(4924),
    [anon_sym_byte] = ACTIONS(4924),
    [anon_sym_shortint] = ACTIONS(4924),
    [anon_sym_int] = ACTIONS(4924),
    [anon_sym_longint] = ACTIONS(4924),
    [anon_sym_integer] = ACTIONS(4924),
    [anon_sym_time] = ACTIONS(4924),
    [anon_sym_bit] = ACTIONS(4924),
    [anon_sym_logic] = ACTIONS(4924),
    [anon_sym_reg] = ACTIONS(4924),
    [anon_sym_shortreal] = ACTIONS(4924),
    [anon_sym_real] = ACTIONS(4924),
    [anon_sym_realtime] = ACTIONS(4924),
    [anon_sym_supply0] = ACTIONS(4924),
    [anon_sym_supply1] = ACTIONS(4924),
    [anon_sym_signed] = ACTIONS(4924),
    [anon_sym_unsigned] = ACTIONS(4924),
    [anon_sym_task] = ACTIONS(4924),
    [anon_sym_modport] = ACTIONS(4924),
    [anon_sym_assert] = ACTIONS(4924),
    [anon_sym_property] = ACTIONS(4924),
    [anon_sym_assume] = ACTIONS(4924),
    [anon_sym_cover] = ACTIONS(4924),
    [anon_sym_sequence] = ACTIONS(4924),
    [anon_sym_restrict] = ACTIONS(4924),
    [anon_sym_not] = ACTIONS(4924),
    [anon_sym_or] = ACTIONS(4924),
    [anon_sym_and] = ACTIONS(4924),
    [anon_sym_case] = ACTIONS(4924),
    [anon_sym_always] = ACTIONS(4924),
    [anon_sym_covergroup] = ACTIONS(4924),
    [anon_sym_let] = ACTIONS(4924),
    [anon_sym_pulldown] = ACTIONS(4924),
    [anon_sym_pullup] = ACTIONS(4924),
    [anon_sym_cmos] = ACTIONS(4924),
    [anon_sym_rcmos] = ACTIONS(4924),
    [anon_sym_bufif0] = ACTIONS(4924),
    [anon_sym_bufif1] = ACTIONS(4924),
    [anon_sym_notif0] = ACTIONS(4924),
    [anon_sym_notif1] = ACTIONS(4924),
    [anon_sym_nmos] = ACTIONS(4924),
    [anon_sym_pmos] = ACTIONS(4924),
    [anon_sym_rnmos] = ACTIONS(4924),
    [anon_sym_rpmos] = ACTIONS(4924),
    [anon_sym_nand] = ACTIONS(4924),
    [anon_sym_nor] = ACTIONS(4924),
    [anon_sym_xor] = ACTIONS(4924),
    [anon_sym_xnor] = ACTIONS(4924),
    [anon_sym_buf] = ACTIONS(4924),
    [anon_sym_tranif0] = ACTIONS(4924),
    [anon_sym_tranif1] = ACTIONS(4924),
    [anon_sym_rtranif1] = ACTIONS(4924),
    [anon_sym_rtranif0] = ACTIONS(4924),
    [anon_sym_tran] = ACTIONS(4924),
    [anon_sym_rtran] = ACTIONS(4924),
    [anon_sym_generate] = ACTIONS(4924),
    [anon_sym_for] = ACTIONS(4924),
    [anon_sym_primitive] = ACTIONS(4924),
    [anon_sym_initial] = ACTIONS(4924),
    [anon_sym_assign] = ACTIONS(4924),
    [anon_sym_alias] = ACTIONS(4924),
    [anon_sym_always_comb] = ACTIONS(4924),
    [anon_sym_always_latch] = ACTIONS(4924),
    [anon_sym_always_ff] = ACTIONS(4924),
    [anon_sym_final] = ACTIONS(4924),
    [anon_sym_global] = ACTIONS(4924),
    [anon_sym_specify] = ACTIONS(4924),
    [anon_sym_LPAREN_STAR] = ACTIONS(4922),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4922),
    [anon_sym_DOLLARunit] = ACTIONS(4922),
  },
  [804] = {
    [ts_builtin_sym_end] = ACTIONS(4926),
    [sym_simple_identifier] = ACTIONS(4928),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4926),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4926),
    [anon_sym_BQUOTE] = ACTIONS(4928),
    [aux_sym_id_directive_token1] = ACTIONS(4926),
    [aux_sym_id_directive_token2] = ACTIONS(4926),
    [aux_sym_id_directive_token3] = ACTIONS(4926),
    [aux_sym_id_directive_token4] = ACTIONS(4928),
    [aux_sym_zero_directive_token1] = ACTIONS(4926),
    [aux_sym_zero_directive_token2] = ACTIONS(4926),
    [aux_sym_zero_directive_token3] = ACTIONS(4926),
    [aux_sym_zero_directive_token4] = ACTIONS(4926),
    [aux_sym_zero_directive_token5] = ACTIONS(4926),
    [aux_sym_zero_directive_token6] = ACTIONS(4926),
    [aux_sym_zero_directive_token7] = ACTIONS(4926),
    [aux_sym_zero_directive_token8] = ACTIONS(4926),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4926),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4926),
    [anon_sym_wire] = ACTIONS(4928),
    [anon_sym_tri] = ACTIONS(4928),
    [anon_sym_tri0] = ACTIONS(4928),
    [anon_sym_tri1] = ACTIONS(4928),
    [anon_sym_wand] = ACTIONS(4928),
    [anon_sym_triand] = ACTIONS(4928),
    [anon_sym_wor] = ACTIONS(4928),
    [anon_sym_trior] = ACTIONS(4928),
    [anon_sym_trireg] = ACTIONS(4928),
    [anon_sym_uwire] = ACTIONS(4928),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4926),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4926),
    [aux_sym_begin_keywords_token1] = ACTIONS(4926),
    [anon_sym_SEMI] = ACTIONS(4926),
    [anon_sym_endmodule] = ACTIONS(4928),
    [anon_sym_extern] = ACTIONS(4928),
    [anon_sym_module] = ACTIONS(4928),
    [anon_sym_macromodule] = ACTIONS(4928),
    [anon_sym_endinterface] = ACTIONS(4928),
    [anon_sym_interface] = ACTIONS(4928),
    [anon_sym_endprogram] = ACTIONS(4928),
    [anon_sym_program] = ACTIONS(4928),
    [anon_sym_checker] = ACTIONS(4928),
    [anon_sym_virtual] = ACTIONS(4928),
    [anon_sym_class] = ACTIONS(4928),
    [anon_sym_package] = ACTIONS(4928),
    [anon_sym_endpackage] = ACTIONS(4928),
    [anon_sym_timeunit] = ACTIONS(4928),
    [anon_sym_timeprecision] = ACTIONS(4928),
    [anon_sym_type] = ACTIONS(4928),
    [anon_sym_input] = ACTIONS(4928),
    [anon_sym_output] = ACTIONS(4928),
    [anon_sym_inout] = ACTIONS(4928),
    [anon_sym_ref] = ACTIONS(4928),
    [anon_sym_DOLLARfatal] = ACTIONS(4926),
    [anon_sym_DOLLARerror] = ACTIONS(4926),
    [anon_sym_DOLLARwarning] = ACTIONS(4926),
    [anon_sym_DOLLARinfo] = ACTIONS(4926),
    [anon_sym_default] = ACTIONS(4928),
    [anon_sym_clocking] = ACTIONS(4928),
    [anon_sym_defparam] = ACTIONS(4928),
    [anon_sym_bind] = ACTIONS(4928),
    [anon_sym_const] = ACTIONS(4928),
    [anon_sym_function] = ACTIONS(4928),
    [anon_sym_static] = ACTIONS(4928),
    [anon_sym_constraint] = ACTIONS(4928),
    [anon_sym_if] = ACTIONS(4928),
    [anon_sym_else] = ACTIONS(4928),
    [anon_sym_LBRACK] = ACTIONS(4926),
    [anon_sym_localparam] = ACTIONS(4928),
    [anon_sym_parameter] = ACTIONS(4928),
    [anon_sym_specparam] = ACTIONS(4928),
    [anon_sym_var] = ACTIONS(4928),
    [anon_sym_import] = ACTIONS(4928),
    [anon_sym_export] = ACTIONS(4928),
    [anon_sym_genvar] = ACTIONS(4928),
    [anon_sym_interconnect] = ACTIONS(4928),
    [anon_sym_typedef] = ACTIONS(4928),
    [anon_sym_enum] = ACTIONS(4928),
    [anon_sym_struct] = ACTIONS(4928),
    [anon_sym_union] = ACTIONS(4928),
    [anon_sym_nettype] = ACTIONS(4928),
    [anon_sym_automatic] = ACTIONS(4928),
    [anon_sym_string] = ACTIONS(4928),
    [anon_sym_chandle] = ACTIONS(4928),
    [anon_sym_event] = ACTIONS(4928),
    [anon_sym_byte] = ACTIONS(4928),
    [anon_sym_shortint] = ACTIONS(4928),
    [anon_sym_int] = ACTIONS(4928),
    [anon_sym_longint] = ACTIONS(4928),
    [anon_sym_integer] = ACTIONS(4928),
    [anon_sym_time] = ACTIONS(4928),
    [anon_sym_bit] = ACTIONS(4928),
    [anon_sym_logic] = ACTIONS(4928),
    [anon_sym_reg] = ACTIONS(4928),
    [anon_sym_shortreal] = ACTIONS(4928),
    [anon_sym_real] = ACTIONS(4928),
    [anon_sym_realtime] = ACTIONS(4928),
    [anon_sym_supply0] = ACTIONS(4928),
    [anon_sym_supply1] = ACTIONS(4928),
    [anon_sym_signed] = ACTIONS(4928),
    [anon_sym_unsigned] = ACTIONS(4928),
    [anon_sym_task] = ACTIONS(4928),
    [anon_sym_modport] = ACTIONS(4928),
    [anon_sym_assert] = ACTIONS(4928),
    [anon_sym_property] = ACTIONS(4928),
    [anon_sym_assume] = ACTIONS(4928),
    [anon_sym_cover] = ACTIONS(4928),
    [anon_sym_sequence] = ACTIONS(4928),
    [anon_sym_restrict] = ACTIONS(4928),
    [anon_sym_not] = ACTIONS(4928),
    [anon_sym_or] = ACTIONS(4928),
    [anon_sym_and] = ACTIONS(4928),
    [anon_sym_case] = ACTIONS(4928),
    [anon_sym_always] = ACTIONS(4928),
    [anon_sym_covergroup] = ACTIONS(4928),
    [anon_sym_let] = ACTIONS(4928),
    [anon_sym_pulldown] = ACTIONS(4928),
    [anon_sym_pullup] = ACTIONS(4928),
    [anon_sym_cmos] = ACTIONS(4928),
    [anon_sym_rcmos] = ACTIONS(4928),
    [anon_sym_bufif0] = ACTIONS(4928),
    [anon_sym_bufif1] = ACTIONS(4928),
    [anon_sym_notif0] = ACTIONS(4928),
    [anon_sym_notif1] = ACTIONS(4928),
    [anon_sym_nmos] = ACTIONS(4928),
    [anon_sym_pmos] = ACTIONS(4928),
    [anon_sym_rnmos] = ACTIONS(4928),
    [anon_sym_rpmos] = ACTIONS(4928),
    [anon_sym_nand] = ACTIONS(4928),
    [anon_sym_nor] = ACTIONS(4928),
    [anon_sym_xor] = ACTIONS(4928),
    [anon_sym_xnor] = ACTIONS(4928),
    [anon_sym_buf] = ACTIONS(4928),
    [anon_sym_tranif0] = ACTIONS(4928),
    [anon_sym_tranif1] = ACTIONS(4928),
    [anon_sym_rtranif1] = ACTIONS(4928),
    [anon_sym_rtranif0] = ACTIONS(4928),
    [anon_sym_tran] = ACTIONS(4928),
    [anon_sym_rtran] = ACTIONS(4928),
    [anon_sym_generate] = ACTIONS(4928),
    [anon_sym_for] = ACTIONS(4928),
    [anon_sym_primitive] = ACTIONS(4928),
    [anon_sym_initial] = ACTIONS(4928),
    [anon_sym_assign] = ACTIONS(4928),
    [anon_sym_alias] = ACTIONS(4928),
    [anon_sym_always_comb] = ACTIONS(4928),
    [anon_sym_always_latch] = ACTIONS(4928),
    [anon_sym_always_ff] = ACTIONS(4928),
    [anon_sym_final] = ACTIONS(4928),
    [anon_sym_global] = ACTIONS(4928),
    [anon_sym_specify] = ACTIONS(4928),
    [anon_sym_LPAREN_STAR] = ACTIONS(4926),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4926),
    [anon_sym_DOLLARunit] = ACTIONS(4926),
  },
  [805] = {
    [ts_builtin_sym_end] = ACTIONS(4930),
    [sym_simple_identifier] = ACTIONS(4932),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4930),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4930),
    [anon_sym_BQUOTE] = ACTIONS(4932),
    [aux_sym_id_directive_token1] = ACTIONS(4930),
    [aux_sym_id_directive_token2] = ACTIONS(4930),
    [aux_sym_id_directive_token3] = ACTIONS(4930),
    [aux_sym_id_directive_token4] = ACTIONS(4932),
    [aux_sym_zero_directive_token1] = ACTIONS(4930),
    [aux_sym_zero_directive_token2] = ACTIONS(4930),
    [aux_sym_zero_directive_token3] = ACTIONS(4930),
    [aux_sym_zero_directive_token4] = ACTIONS(4930),
    [aux_sym_zero_directive_token5] = ACTIONS(4930),
    [aux_sym_zero_directive_token6] = ACTIONS(4930),
    [aux_sym_zero_directive_token7] = ACTIONS(4930),
    [aux_sym_zero_directive_token8] = ACTIONS(4930),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4930),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4930),
    [anon_sym_wire] = ACTIONS(4932),
    [anon_sym_tri] = ACTIONS(4932),
    [anon_sym_tri0] = ACTIONS(4932),
    [anon_sym_tri1] = ACTIONS(4932),
    [anon_sym_wand] = ACTIONS(4932),
    [anon_sym_triand] = ACTIONS(4932),
    [anon_sym_wor] = ACTIONS(4932),
    [anon_sym_trior] = ACTIONS(4932),
    [anon_sym_trireg] = ACTIONS(4932),
    [anon_sym_uwire] = ACTIONS(4932),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4930),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4930),
    [aux_sym_begin_keywords_token1] = ACTIONS(4930),
    [anon_sym_SEMI] = ACTIONS(4930),
    [anon_sym_endmodule] = ACTIONS(4932),
    [anon_sym_extern] = ACTIONS(4932),
    [anon_sym_module] = ACTIONS(4932),
    [anon_sym_macromodule] = ACTIONS(4932),
    [anon_sym_endinterface] = ACTIONS(4932),
    [anon_sym_interface] = ACTIONS(4932),
    [anon_sym_endprogram] = ACTIONS(4932),
    [anon_sym_program] = ACTIONS(4932),
    [anon_sym_checker] = ACTIONS(4932),
    [anon_sym_virtual] = ACTIONS(4932),
    [anon_sym_class] = ACTIONS(4932),
    [anon_sym_package] = ACTIONS(4932),
    [anon_sym_endpackage] = ACTIONS(4932),
    [anon_sym_timeunit] = ACTIONS(4932),
    [anon_sym_timeprecision] = ACTIONS(4932),
    [anon_sym_type] = ACTIONS(4932),
    [anon_sym_input] = ACTIONS(4932),
    [anon_sym_output] = ACTIONS(4932),
    [anon_sym_inout] = ACTIONS(4932),
    [anon_sym_ref] = ACTIONS(4932),
    [anon_sym_DOLLARfatal] = ACTIONS(4930),
    [anon_sym_DOLLARerror] = ACTIONS(4930),
    [anon_sym_DOLLARwarning] = ACTIONS(4930),
    [anon_sym_DOLLARinfo] = ACTIONS(4930),
    [anon_sym_default] = ACTIONS(4932),
    [anon_sym_clocking] = ACTIONS(4932),
    [anon_sym_defparam] = ACTIONS(4932),
    [anon_sym_bind] = ACTIONS(4932),
    [anon_sym_const] = ACTIONS(4932),
    [anon_sym_function] = ACTIONS(4932),
    [anon_sym_static] = ACTIONS(4932),
    [anon_sym_constraint] = ACTIONS(4932),
    [anon_sym_if] = ACTIONS(4932),
    [anon_sym_else] = ACTIONS(4932),
    [anon_sym_LBRACK] = ACTIONS(4930),
    [anon_sym_localparam] = ACTIONS(4932),
    [anon_sym_parameter] = ACTIONS(4932),
    [anon_sym_specparam] = ACTIONS(4932),
    [anon_sym_var] = ACTIONS(4932),
    [anon_sym_import] = ACTIONS(4932),
    [anon_sym_export] = ACTIONS(4932),
    [anon_sym_genvar] = ACTIONS(4932),
    [anon_sym_interconnect] = ACTIONS(4932),
    [anon_sym_typedef] = ACTIONS(4932),
    [anon_sym_enum] = ACTIONS(4932),
    [anon_sym_struct] = ACTIONS(4932),
    [anon_sym_union] = ACTIONS(4932),
    [anon_sym_nettype] = ACTIONS(4932),
    [anon_sym_automatic] = ACTIONS(4932),
    [anon_sym_string] = ACTIONS(4932),
    [anon_sym_chandle] = ACTIONS(4932),
    [anon_sym_event] = ACTIONS(4932),
    [anon_sym_byte] = ACTIONS(4932),
    [anon_sym_shortint] = ACTIONS(4932),
    [anon_sym_int] = ACTIONS(4932),
    [anon_sym_longint] = ACTIONS(4932),
    [anon_sym_integer] = ACTIONS(4932),
    [anon_sym_time] = ACTIONS(4932),
    [anon_sym_bit] = ACTIONS(4932),
    [anon_sym_logic] = ACTIONS(4932),
    [anon_sym_reg] = ACTIONS(4932),
    [anon_sym_shortreal] = ACTIONS(4932),
    [anon_sym_real] = ACTIONS(4932),
    [anon_sym_realtime] = ACTIONS(4932),
    [anon_sym_supply0] = ACTIONS(4932),
    [anon_sym_supply1] = ACTIONS(4932),
    [anon_sym_signed] = ACTIONS(4932),
    [anon_sym_unsigned] = ACTIONS(4932),
    [anon_sym_task] = ACTIONS(4932),
    [anon_sym_modport] = ACTIONS(4932),
    [anon_sym_assert] = ACTIONS(4932),
    [anon_sym_property] = ACTIONS(4932),
    [anon_sym_assume] = ACTIONS(4932),
    [anon_sym_cover] = ACTIONS(4932),
    [anon_sym_sequence] = ACTIONS(4932),
    [anon_sym_restrict] = ACTIONS(4932),
    [anon_sym_not] = ACTIONS(4932),
    [anon_sym_or] = ACTIONS(4932),
    [anon_sym_and] = ACTIONS(4932),
    [anon_sym_case] = ACTIONS(4932),
    [anon_sym_always] = ACTIONS(4932),
    [anon_sym_covergroup] = ACTIONS(4932),
    [anon_sym_let] = ACTIONS(4932),
    [anon_sym_pulldown] = ACTIONS(4932),
    [anon_sym_pullup] = ACTIONS(4932),
    [anon_sym_cmos] = ACTIONS(4932),
    [anon_sym_rcmos] = ACTIONS(4932),
    [anon_sym_bufif0] = ACTIONS(4932),
    [anon_sym_bufif1] = ACTIONS(4932),
    [anon_sym_notif0] = ACTIONS(4932),
    [anon_sym_notif1] = ACTIONS(4932),
    [anon_sym_nmos] = ACTIONS(4932),
    [anon_sym_pmos] = ACTIONS(4932),
    [anon_sym_rnmos] = ACTIONS(4932),
    [anon_sym_rpmos] = ACTIONS(4932),
    [anon_sym_nand] = ACTIONS(4932),
    [anon_sym_nor] = ACTIONS(4932),
    [anon_sym_xor] = ACTIONS(4932),
    [anon_sym_xnor] = ACTIONS(4932),
    [anon_sym_buf] = ACTIONS(4932),
    [anon_sym_tranif0] = ACTIONS(4932),
    [anon_sym_tranif1] = ACTIONS(4932),
    [anon_sym_rtranif1] = ACTIONS(4932),
    [anon_sym_rtranif0] = ACTIONS(4932),
    [anon_sym_tran] = ACTIONS(4932),
    [anon_sym_rtran] = ACTIONS(4932),
    [anon_sym_generate] = ACTIONS(4932),
    [anon_sym_for] = ACTIONS(4932),
    [anon_sym_primitive] = ACTIONS(4932),
    [anon_sym_initial] = ACTIONS(4932),
    [anon_sym_assign] = ACTIONS(4932),
    [anon_sym_alias] = ACTIONS(4932),
    [anon_sym_always_comb] = ACTIONS(4932),
    [anon_sym_always_latch] = ACTIONS(4932),
    [anon_sym_always_ff] = ACTIONS(4932),
    [anon_sym_final] = ACTIONS(4932),
    [anon_sym_global] = ACTIONS(4932),
    [anon_sym_specify] = ACTIONS(4932),
    [anon_sym_LPAREN_STAR] = ACTIONS(4930),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4930),
    [anon_sym_DOLLARunit] = ACTIONS(4930),
  },
  [806] = {
    [ts_builtin_sym_end] = ACTIONS(4934),
    [sym_simple_identifier] = ACTIONS(4936),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4934),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4934),
    [anon_sym_BQUOTE] = ACTIONS(4936),
    [aux_sym_id_directive_token1] = ACTIONS(4934),
    [aux_sym_id_directive_token2] = ACTIONS(4934),
    [aux_sym_id_directive_token3] = ACTIONS(4934),
    [aux_sym_id_directive_token4] = ACTIONS(4936),
    [aux_sym_zero_directive_token1] = ACTIONS(4934),
    [aux_sym_zero_directive_token2] = ACTIONS(4934),
    [aux_sym_zero_directive_token3] = ACTIONS(4934),
    [aux_sym_zero_directive_token4] = ACTIONS(4934),
    [aux_sym_zero_directive_token5] = ACTIONS(4934),
    [aux_sym_zero_directive_token6] = ACTIONS(4934),
    [aux_sym_zero_directive_token7] = ACTIONS(4934),
    [aux_sym_zero_directive_token8] = ACTIONS(4934),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4934),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4934),
    [anon_sym_wire] = ACTIONS(4936),
    [anon_sym_tri] = ACTIONS(4936),
    [anon_sym_tri0] = ACTIONS(4936),
    [anon_sym_tri1] = ACTIONS(4936),
    [anon_sym_wand] = ACTIONS(4936),
    [anon_sym_triand] = ACTIONS(4936),
    [anon_sym_wor] = ACTIONS(4936),
    [anon_sym_trior] = ACTIONS(4936),
    [anon_sym_trireg] = ACTIONS(4936),
    [anon_sym_uwire] = ACTIONS(4936),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4934),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4934),
    [aux_sym_begin_keywords_token1] = ACTIONS(4934),
    [anon_sym_SEMI] = ACTIONS(4934),
    [anon_sym_endmodule] = ACTIONS(4936),
    [anon_sym_extern] = ACTIONS(4936),
    [anon_sym_module] = ACTIONS(4936),
    [anon_sym_macromodule] = ACTIONS(4936),
    [anon_sym_endinterface] = ACTIONS(4936),
    [anon_sym_interface] = ACTIONS(4936),
    [anon_sym_endprogram] = ACTIONS(4936),
    [anon_sym_program] = ACTIONS(4936),
    [anon_sym_checker] = ACTIONS(4936),
    [anon_sym_virtual] = ACTIONS(4936),
    [anon_sym_class] = ACTIONS(4936),
    [anon_sym_package] = ACTIONS(4936),
    [anon_sym_endpackage] = ACTIONS(4936),
    [anon_sym_timeunit] = ACTIONS(4936),
    [anon_sym_timeprecision] = ACTIONS(4936),
    [anon_sym_type] = ACTIONS(4936),
    [anon_sym_input] = ACTIONS(4936),
    [anon_sym_output] = ACTIONS(4936),
    [anon_sym_inout] = ACTIONS(4936),
    [anon_sym_ref] = ACTIONS(4936),
    [anon_sym_DOLLARfatal] = ACTIONS(4934),
    [anon_sym_DOLLARerror] = ACTIONS(4934),
    [anon_sym_DOLLARwarning] = ACTIONS(4934),
    [anon_sym_DOLLARinfo] = ACTIONS(4934),
    [anon_sym_default] = ACTIONS(4936),
    [anon_sym_clocking] = ACTIONS(4936),
    [anon_sym_defparam] = ACTIONS(4936),
    [anon_sym_bind] = ACTIONS(4936),
    [anon_sym_const] = ACTIONS(4936),
    [anon_sym_function] = ACTIONS(4936),
    [anon_sym_static] = ACTIONS(4936),
    [anon_sym_constraint] = ACTIONS(4936),
    [anon_sym_if] = ACTIONS(4936),
    [anon_sym_else] = ACTIONS(4936),
    [anon_sym_LBRACK] = ACTIONS(4934),
    [anon_sym_localparam] = ACTIONS(4936),
    [anon_sym_parameter] = ACTIONS(4936),
    [anon_sym_specparam] = ACTIONS(4936),
    [anon_sym_var] = ACTIONS(4936),
    [anon_sym_import] = ACTIONS(4936),
    [anon_sym_export] = ACTIONS(4936),
    [anon_sym_genvar] = ACTIONS(4936),
    [anon_sym_interconnect] = ACTIONS(4936),
    [anon_sym_typedef] = ACTIONS(4936),
    [anon_sym_enum] = ACTIONS(4936),
    [anon_sym_struct] = ACTIONS(4936),
    [anon_sym_union] = ACTIONS(4936),
    [anon_sym_nettype] = ACTIONS(4936),
    [anon_sym_automatic] = ACTIONS(4936),
    [anon_sym_string] = ACTIONS(4936),
    [anon_sym_chandle] = ACTIONS(4936),
    [anon_sym_event] = ACTIONS(4936),
    [anon_sym_byte] = ACTIONS(4936),
    [anon_sym_shortint] = ACTIONS(4936),
    [anon_sym_int] = ACTIONS(4936),
    [anon_sym_longint] = ACTIONS(4936),
    [anon_sym_integer] = ACTIONS(4936),
    [anon_sym_time] = ACTIONS(4936),
    [anon_sym_bit] = ACTIONS(4936),
    [anon_sym_logic] = ACTIONS(4936),
    [anon_sym_reg] = ACTIONS(4936),
    [anon_sym_shortreal] = ACTIONS(4936),
    [anon_sym_real] = ACTIONS(4936),
    [anon_sym_realtime] = ACTIONS(4936),
    [anon_sym_supply0] = ACTIONS(4936),
    [anon_sym_supply1] = ACTIONS(4936),
    [anon_sym_signed] = ACTIONS(4936),
    [anon_sym_unsigned] = ACTIONS(4936),
    [anon_sym_task] = ACTIONS(4936),
    [anon_sym_modport] = ACTIONS(4936),
    [anon_sym_assert] = ACTIONS(4936),
    [anon_sym_property] = ACTIONS(4936),
    [anon_sym_assume] = ACTIONS(4936),
    [anon_sym_cover] = ACTIONS(4936),
    [anon_sym_sequence] = ACTIONS(4936),
    [anon_sym_restrict] = ACTIONS(4936),
    [anon_sym_not] = ACTIONS(4936),
    [anon_sym_or] = ACTIONS(4936),
    [anon_sym_and] = ACTIONS(4936),
    [anon_sym_case] = ACTIONS(4936),
    [anon_sym_always] = ACTIONS(4936),
    [anon_sym_covergroup] = ACTIONS(4936),
    [anon_sym_let] = ACTIONS(4936),
    [anon_sym_pulldown] = ACTIONS(4936),
    [anon_sym_pullup] = ACTIONS(4936),
    [anon_sym_cmos] = ACTIONS(4936),
    [anon_sym_rcmos] = ACTIONS(4936),
    [anon_sym_bufif0] = ACTIONS(4936),
    [anon_sym_bufif1] = ACTIONS(4936),
    [anon_sym_notif0] = ACTIONS(4936),
    [anon_sym_notif1] = ACTIONS(4936),
    [anon_sym_nmos] = ACTIONS(4936),
    [anon_sym_pmos] = ACTIONS(4936),
    [anon_sym_rnmos] = ACTIONS(4936),
    [anon_sym_rpmos] = ACTIONS(4936),
    [anon_sym_nand] = ACTIONS(4936),
    [anon_sym_nor] = ACTIONS(4936),
    [anon_sym_xor] = ACTIONS(4936),
    [anon_sym_xnor] = ACTIONS(4936),
    [anon_sym_buf] = ACTIONS(4936),
    [anon_sym_tranif0] = ACTIONS(4936),
    [anon_sym_tranif1] = ACTIONS(4936),
    [anon_sym_rtranif1] = ACTIONS(4936),
    [anon_sym_rtranif0] = ACTIONS(4936),
    [anon_sym_tran] = ACTIONS(4936),
    [anon_sym_rtran] = ACTIONS(4936),
    [anon_sym_generate] = ACTIONS(4936),
    [anon_sym_for] = ACTIONS(4936),
    [anon_sym_primitive] = ACTIONS(4936),
    [anon_sym_initial] = ACTIONS(4936),
    [anon_sym_assign] = ACTIONS(4936),
    [anon_sym_alias] = ACTIONS(4936),
    [anon_sym_always_comb] = ACTIONS(4936),
    [anon_sym_always_latch] = ACTIONS(4936),
    [anon_sym_always_ff] = ACTIONS(4936),
    [anon_sym_final] = ACTIONS(4936),
    [anon_sym_global] = ACTIONS(4936),
    [anon_sym_specify] = ACTIONS(4936),
    [anon_sym_LPAREN_STAR] = ACTIONS(4934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4934),
    [anon_sym_DOLLARunit] = ACTIONS(4934),
  },
  [807] = {
    [ts_builtin_sym_end] = ACTIONS(4616),
    [sym_simple_identifier] = ACTIONS(4618),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4616),
    [anon_sym_BQUOTE] = ACTIONS(4618),
    [aux_sym_id_directive_token1] = ACTIONS(4616),
    [aux_sym_id_directive_token2] = ACTIONS(4616),
    [aux_sym_id_directive_token3] = ACTIONS(4616),
    [aux_sym_id_directive_token4] = ACTIONS(4618),
    [aux_sym_zero_directive_token1] = ACTIONS(4616),
    [aux_sym_zero_directive_token2] = ACTIONS(4616),
    [aux_sym_zero_directive_token3] = ACTIONS(4616),
    [aux_sym_zero_directive_token4] = ACTIONS(4616),
    [aux_sym_zero_directive_token5] = ACTIONS(4616),
    [aux_sym_zero_directive_token6] = ACTIONS(4616),
    [aux_sym_zero_directive_token7] = ACTIONS(4616),
    [aux_sym_zero_directive_token8] = ACTIONS(4616),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4616),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4616),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4616),
    [aux_sym_begin_keywords_token1] = ACTIONS(4616),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_endmodule] = ACTIONS(4618),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_module] = ACTIONS(4618),
    [anon_sym_macromodule] = ACTIONS(4618),
    [anon_sym_endinterface] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_endprogram] = ACTIONS(4618),
    [anon_sym_program] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_package] = ACTIONS(4618),
    [anon_sym_endpackage] = ACTIONS(4618),
    [anon_sym_timeunit] = ACTIONS(4618),
    [anon_sym_timeprecision] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_input] = ACTIONS(4618),
    [anon_sym_output] = ACTIONS(4618),
    [anon_sym_inout] = ACTIONS(4618),
    [anon_sym_ref] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_specparam] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_modport] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_primitive] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_specify] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [808] = {
    [ts_builtin_sym_end] = ACTIONS(4938),
    [sym_simple_identifier] = ACTIONS(4940),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4938),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4938),
    [anon_sym_BQUOTE] = ACTIONS(4940),
    [aux_sym_id_directive_token1] = ACTIONS(4938),
    [aux_sym_id_directive_token2] = ACTIONS(4938),
    [aux_sym_id_directive_token3] = ACTIONS(4938),
    [aux_sym_id_directive_token4] = ACTIONS(4940),
    [aux_sym_zero_directive_token1] = ACTIONS(4938),
    [aux_sym_zero_directive_token2] = ACTIONS(4938),
    [aux_sym_zero_directive_token3] = ACTIONS(4938),
    [aux_sym_zero_directive_token4] = ACTIONS(4938),
    [aux_sym_zero_directive_token5] = ACTIONS(4938),
    [aux_sym_zero_directive_token6] = ACTIONS(4938),
    [aux_sym_zero_directive_token7] = ACTIONS(4938),
    [aux_sym_zero_directive_token8] = ACTIONS(4938),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4938),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4938),
    [anon_sym_wire] = ACTIONS(4940),
    [anon_sym_tri] = ACTIONS(4940),
    [anon_sym_tri0] = ACTIONS(4940),
    [anon_sym_tri1] = ACTIONS(4940),
    [anon_sym_wand] = ACTIONS(4940),
    [anon_sym_triand] = ACTIONS(4940),
    [anon_sym_wor] = ACTIONS(4940),
    [anon_sym_trior] = ACTIONS(4940),
    [anon_sym_trireg] = ACTIONS(4940),
    [anon_sym_uwire] = ACTIONS(4940),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4938),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4938),
    [aux_sym_begin_keywords_token1] = ACTIONS(4938),
    [anon_sym_SEMI] = ACTIONS(4938),
    [anon_sym_endmodule] = ACTIONS(4940),
    [anon_sym_extern] = ACTIONS(4940),
    [anon_sym_module] = ACTIONS(4940),
    [anon_sym_macromodule] = ACTIONS(4940),
    [anon_sym_endinterface] = ACTIONS(4940),
    [anon_sym_interface] = ACTIONS(4940),
    [anon_sym_endprogram] = ACTIONS(4940),
    [anon_sym_program] = ACTIONS(4940),
    [anon_sym_checker] = ACTIONS(4940),
    [anon_sym_virtual] = ACTIONS(4940),
    [anon_sym_class] = ACTIONS(4940),
    [anon_sym_package] = ACTIONS(4940),
    [anon_sym_endpackage] = ACTIONS(4940),
    [anon_sym_timeunit] = ACTIONS(4940),
    [anon_sym_timeprecision] = ACTIONS(4940),
    [anon_sym_type] = ACTIONS(4940),
    [anon_sym_input] = ACTIONS(4940),
    [anon_sym_output] = ACTIONS(4940),
    [anon_sym_inout] = ACTIONS(4940),
    [anon_sym_ref] = ACTIONS(4940),
    [anon_sym_DOLLARfatal] = ACTIONS(4938),
    [anon_sym_DOLLARerror] = ACTIONS(4938),
    [anon_sym_DOLLARwarning] = ACTIONS(4938),
    [anon_sym_DOLLARinfo] = ACTIONS(4938),
    [anon_sym_default] = ACTIONS(4940),
    [anon_sym_clocking] = ACTIONS(4940),
    [anon_sym_defparam] = ACTIONS(4940),
    [anon_sym_bind] = ACTIONS(4940),
    [anon_sym_const] = ACTIONS(4940),
    [anon_sym_function] = ACTIONS(4940),
    [anon_sym_static] = ACTIONS(4940),
    [anon_sym_constraint] = ACTIONS(4940),
    [anon_sym_if] = ACTIONS(4940),
    [anon_sym_else] = ACTIONS(4940),
    [anon_sym_LBRACK] = ACTIONS(4938),
    [anon_sym_localparam] = ACTIONS(4940),
    [anon_sym_parameter] = ACTIONS(4940),
    [anon_sym_specparam] = ACTIONS(4940),
    [anon_sym_var] = ACTIONS(4940),
    [anon_sym_import] = ACTIONS(4940),
    [anon_sym_export] = ACTIONS(4940),
    [anon_sym_genvar] = ACTIONS(4940),
    [anon_sym_interconnect] = ACTIONS(4940),
    [anon_sym_typedef] = ACTIONS(4940),
    [anon_sym_enum] = ACTIONS(4940),
    [anon_sym_struct] = ACTIONS(4940),
    [anon_sym_union] = ACTIONS(4940),
    [anon_sym_nettype] = ACTIONS(4940),
    [anon_sym_automatic] = ACTIONS(4940),
    [anon_sym_string] = ACTIONS(4940),
    [anon_sym_chandle] = ACTIONS(4940),
    [anon_sym_event] = ACTIONS(4940),
    [anon_sym_byte] = ACTIONS(4940),
    [anon_sym_shortint] = ACTIONS(4940),
    [anon_sym_int] = ACTIONS(4940),
    [anon_sym_longint] = ACTIONS(4940),
    [anon_sym_integer] = ACTIONS(4940),
    [anon_sym_time] = ACTIONS(4940),
    [anon_sym_bit] = ACTIONS(4940),
    [anon_sym_logic] = ACTIONS(4940),
    [anon_sym_reg] = ACTIONS(4940),
    [anon_sym_shortreal] = ACTIONS(4940),
    [anon_sym_real] = ACTIONS(4940),
    [anon_sym_realtime] = ACTIONS(4940),
    [anon_sym_supply0] = ACTIONS(4940),
    [anon_sym_supply1] = ACTIONS(4940),
    [anon_sym_signed] = ACTIONS(4940),
    [anon_sym_unsigned] = ACTIONS(4940),
    [anon_sym_task] = ACTIONS(4940),
    [anon_sym_modport] = ACTIONS(4940),
    [anon_sym_assert] = ACTIONS(4940),
    [anon_sym_property] = ACTIONS(4940),
    [anon_sym_assume] = ACTIONS(4940),
    [anon_sym_cover] = ACTIONS(4940),
    [anon_sym_sequence] = ACTIONS(4940),
    [anon_sym_restrict] = ACTIONS(4940),
    [anon_sym_not] = ACTIONS(4940),
    [anon_sym_or] = ACTIONS(4940),
    [anon_sym_and] = ACTIONS(4940),
    [anon_sym_case] = ACTIONS(4940),
    [anon_sym_always] = ACTIONS(4940),
    [anon_sym_covergroup] = ACTIONS(4940),
    [anon_sym_let] = ACTIONS(4940),
    [anon_sym_pulldown] = ACTIONS(4940),
    [anon_sym_pullup] = ACTIONS(4940),
    [anon_sym_cmos] = ACTIONS(4940),
    [anon_sym_rcmos] = ACTIONS(4940),
    [anon_sym_bufif0] = ACTIONS(4940),
    [anon_sym_bufif1] = ACTIONS(4940),
    [anon_sym_notif0] = ACTIONS(4940),
    [anon_sym_notif1] = ACTIONS(4940),
    [anon_sym_nmos] = ACTIONS(4940),
    [anon_sym_pmos] = ACTIONS(4940),
    [anon_sym_rnmos] = ACTIONS(4940),
    [anon_sym_rpmos] = ACTIONS(4940),
    [anon_sym_nand] = ACTIONS(4940),
    [anon_sym_nor] = ACTIONS(4940),
    [anon_sym_xor] = ACTIONS(4940),
    [anon_sym_xnor] = ACTIONS(4940),
    [anon_sym_buf] = ACTIONS(4940),
    [anon_sym_tranif0] = ACTIONS(4940),
    [anon_sym_tranif1] = ACTIONS(4940),
    [anon_sym_rtranif1] = ACTIONS(4940),
    [anon_sym_rtranif0] = ACTIONS(4940),
    [anon_sym_tran] = ACTIONS(4940),
    [anon_sym_rtran] = ACTIONS(4940),
    [anon_sym_generate] = ACTIONS(4940),
    [anon_sym_for] = ACTIONS(4940),
    [anon_sym_primitive] = ACTIONS(4940),
    [anon_sym_initial] = ACTIONS(4940),
    [anon_sym_assign] = ACTIONS(4940),
    [anon_sym_alias] = ACTIONS(4940),
    [anon_sym_always_comb] = ACTIONS(4940),
    [anon_sym_always_latch] = ACTIONS(4940),
    [anon_sym_always_ff] = ACTIONS(4940),
    [anon_sym_final] = ACTIONS(4940),
    [anon_sym_global] = ACTIONS(4940),
    [anon_sym_specify] = ACTIONS(4940),
    [anon_sym_LPAREN_STAR] = ACTIONS(4938),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4938),
    [anon_sym_DOLLARunit] = ACTIONS(4938),
  },
  [809] = {
    [ts_builtin_sym_end] = ACTIONS(4942),
    [sym_simple_identifier] = ACTIONS(4944),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4942),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4942),
    [anon_sym_BQUOTE] = ACTIONS(4944),
    [aux_sym_id_directive_token1] = ACTIONS(4942),
    [aux_sym_id_directive_token2] = ACTIONS(4942),
    [aux_sym_id_directive_token3] = ACTIONS(4942),
    [aux_sym_id_directive_token4] = ACTIONS(4944),
    [aux_sym_zero_directive_token1] = ACTIONS(4942),
    [aux_sym_zero_directive_token2] = ACTIONS(4942),
    [aux_sym_zero_directive_token3] = ACTIONS(4942),
    [aux_sym_zero_directive_token4] = ACTIONS(4942),
    [aux_sym_zero_directive_token5] = ACTIONS(4942),
    [aux_sym_zero_directive_token6] = ACTIONS(4942),
    [aux_sym_zero_directive_token7] = ACTIONS(4942),
    [aux_sym_zero_directive_token8] = ACTIONS(4942),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4942),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4942),
    [anon_sym_wire] = ACTIONS(4944),
    [anon_sym_tri] = ACTIONS(4944),
    [anon_sym_tri0] = ACTIONS(4944),
    [anon_sym_tri1] = ACTIONS(4944),
    [anon_sym_wand] = ACTIONS(4944),
    [anon_sym_triand] = ACTIONS(4944),
    [anon_sym_wor] = ACTIONS(4944),
    [anon_sym_trior] = ACTIONS(4944),
    [anon_sym_trireg] = ACTIONS(4944),
    [anon_sym_uwire] = ACTIONS(4944),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4942),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4942),
    [aux_sym_begin_keywords_token1] = ACTIONS(4942),
    [anon_sym_SEMI] = ACTIONS(4942),
    [anon_sym_endmodule] = ACTIONS(4944),
    [anon_sym_extern] = ACTIONS(4944),
    [anon_sym_module] = ACTIONS(4944),
    [anon_sym_macromodule] = ACTIONS(4944),
    [anon_sym_endinterface] = ACTIONS(4944),
    [anon_sym_interface] = ACTIONS(4944),
    [anon_sym_endprogram] = ACTIONS(4944),
    [anon_sym_program] = ACTIONS(4944),
    [anon_sym_checker] = ACTIONS(4944),
    [anon_sym_virtual] = ACTIONS(4944),
    [anon_sym_class] = ACTIONS(4944),
    [anon_sym_package] = ACTIONS(4944),
    [anon_sym_endpackage] = ACTIONS(4944),
    [anon_sym_timeunit] = ACTIONS(4944),
    [anon_sym_timeprecision] = ACTIONS(4944),
    [anon_sym_type] = ACTIONS(4944),
    [anon_sym_input] = ACTIONS(4944),
    [anon_sym_output] = ACTIONS(4944),
    [anon_sym_inout] = ACTIONS(4944),
    [anon_sym_ref] = ACTIONS(4944),
    [anon_sym_DOLLARfatal] = ACTIONS(4942),
    [anon_sym_DOLLARerror] = ACTIONS(4942),
    [anon_sym_DOLLARwarning] = ACTIONS(4942),
    [anon_sym_DOLLARinfo] = ACTIONS(4942),
    [anon_sym_default] = ACTIONS(4944),
    [anon_sym_clocking] = ACTIONS(4944),
    [anon_sym_defparam] = ACTIONS(4944),
    [anon_sym_bind] = ACTIONS(4944),
    [anon_sym_const] = ACTIONS(4944),
    [anon_sym_function] = ACTIONS(4944),
    [anon_sym_static] = ACTIONS(4944),
    [anon_sym_constraint] = ACTIONS(4944),
    [anon_sym_if] = ACTIONS(4944),
    [anon_sym_else] = ACTIONS(4944),
    [anon_sym_LBRACK] = ACTIONS(4942),
    [anon_sym_localparam] = ACTIONS(4944),
    [anon_sym_parameter] = ACTIONS(4944),
    [anon_sym_specparam] = ACTIONS(4944),
    [anon_sym_var] = ACTIONS(4944),
    [anon_sym_import] = ACTIONS(4944),
    [anon_sym_export] = ACTIONS(4944),
    [anon_sym_genvar] = ACTIONS(4944),
    [anon_sym_interconnect] = ACTIONS(4944),
    [anon_sym_typedef] = ACTIONS(4944),
    [anon_sym_enum] = ACTIONS(4944),
    [anon_sym_struct] = ACTIONS(4944),
    [anon_sym_union] = ACTIONS(4944),
    [anon_sym_nettype] = ACTIONS(4944),
    [anon_sym_automatic] = ACTIONS(4944),
    [anon_sym_string] = ACTIONS(4944),
    [anon_sym_chandle] = ACTIONS(4944),
    [anon_sym_event] = ACTIONS(4944),
    [anon_sym_byte] = ACTIONS(4944),
    [anon_sym_shortint] = ACTIONS(4944),
    [anon_sym_int] = ACTIONS(4944),
    [anon_sym_longint] = ACTIONS(4944),
    [anon_sym_integer] = ACTIONS(4944),
    [anon_sym_time] = ACTIONS(4944),
    [anon_sym_bit] = ACTIONS(4944),
    [anon_sym_logic] = ACTIONS(4944),
    [anon_sym_reg] = ACTIONS(4944),
    [anon_sym_shortreal] = ACTIONS(4944),
    [anon_sym_real] = ACTIONS(4944),
    [anon_sym_realtime] = ACTIONS(4944),
    [anon_sym_supply0] = ACTIONS(4944),
    [anon_sym_supply1] = ACTIONS(4944),
    [anon_sym_signed] = ACTIONS(4944),
    [anon_sym_unsigned] = ACTIONS(4944),
    [anon_sym_task] = ACTIONS(4944),
    [anon_sym_modport] = ACTIONS(4944),
    [anon_sym_assert] = ACTIONS(4944),
    [anon_sym_property] = ACTIONS(4944),
    [anon_sym_assume] = ACTIONS(4944),
    [anon_sym_cover] = ACTIONS(4944),
    [anon_sym_sequence] = ACTIONS(4944),
    [anon_sym_restrict] = ACTIONS(4944),
    [anon_sym_not] = ACTIONS(4944),
    [anon_sym_or] = ACTIONS(4944),
    [anon_sym_and] = ACTIONS(4944),
    [anon_sym_case] = ACTIONS(4944),
    [anon_sym_always] = ACTIONS(4944),
    [anon_sym_covergroup] = ACTIONS(4944),
    [anon_sym_let] = ACTIONS(4944),
    [anon_sym_pulldown] = ACTIONS(4944),
    [anon_sym_pullup] = ACTIONS(4944),
    [anon_sym_cmos] = ACTIONS(4944),
    [anon_sym_rcmos] = ACTIONS(4944),
    [anon_sym_bufif0] = ACTIONS(4944),
    [anon_sym_bufif1] = ACTIONS(4944),
    [anon_sym_notif0] = ACTIONS(4944),
    [anon_sym_notif1] = ACTIONS(4944),
    [anon_sym_nmos] = ACTIONS(4944),
    [anon_sym_pmos] = ACTIONS(4944),
    [anon_sym_rnmos] = ACTIONS(4944),
    [anon_sym_rpmos] = ACTIONS(4944),
    [anon_sym_nand] = ACTIONS(4944),
    [anon_sym_nor] = ACTIONS(4944),
    [anon_sym_xor] = ACTIONS(4944),
    [anon_sym_xnor] = ACTIONS(4944),
    [anon_sym_buf] = ACTIONS(4944),
    [anon_sym_tranif0] = ACTIONS(4944),
    [anon_sym_tranif1] = ACTIONS(4944),
    [anon_sym_rtranif1] = ACTIONS(4944),
    [anon_sym_rtranif0] = ACTIONS(4944),
    [anon_sym_tran] = ACTIONS(4944),
    [anon_sym_rtran] = ACTIONS(4944),
    [anon_sym_generate] = ACTIONS(4944),
    [anon_sym_for] = ACTIONS(4944),
    [anon_sym_primitive] = ACTIONS(4944),
    [anon_sym_initial] = ACTIONS(4944),
    [anon_sym_assign] = ACTIONS(4944),
    [anon_sym_alias] = ACTIONS(4944),
    [anon_sym_always_comb] = ACTIONS(4944),
    [anon_sym_always_latch] = ACTIONS(4944),
    [anon_sym_always_ff] = ACTIONS(4944),
    [anon_sym_final] = ACTIONS(4944),
    [anon_sym_global] = ACTIONS(4944),
    [anon_sym_specify] = ACTIONS(4944),
    [anon_sym_LPAREN_STAR] = ACTIONS(4942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4942),
    [anon_sym_DOLLARunit] = ACTIONS(4942),
  },
  [810] = {
    [ts_builtin_sym_end] = ACTIONS(4946),
    [sym_simple_identifier] = ACTIONS(4948),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4946),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4946),
    [anon_sym_BQUOTE] = ACTIONS(4948),
    [aux_sym_id_directive_token1] = ACTIONS(4946),
    [aux_sym_id_directive_token2] = ACTIONS(4946),
    [aux_sym_id_directive_token3] = ACTIONS(4946),
    [aux_sym_id_directive_token4] = ACTIONS(4948),
    [aux_sym_zero_directive_token1] = ACTIONS(4946),
    [aux_sym_zero_directive_token2] = ACTIONS(4946),
    [aux_sym_zero_directive_token3] = ACTIONS(4946),
    [aux_sym_zero_directive_token4] = ACTIONS(4946),
    [aux_sym_zero_directive_token5] = ACTIONS(4946),
    [aux_sym_zero_directive_token6] = ACTIONS(4946),
    [aux_sym_zero_directive_token7] = ACTIONS(4946),
    [aux_sym_zero_directive_token8] = ACTIONS(4946),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4946),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4946),
    [anon_sym_wire] = ACTIONS(4948),
    [anon_sym_tri] = ACTIONS(4948),
    [anon_sym_tri0] = ACTIONS(4948),
    [anon_sym_tri1] = ACTIONS(4948),
    [anon_sym_wand] = ACTIONS(4948),
    [anon_sym_triand] = ACTIONS(4948),
    [anon_sym_wor] = ACTIONS(4948),
    [anon_sym_trior] = ACTIONS(4948),
    [anon_sym_trireg] = ACTIONS(4948),
    [anon_sym_uwire] = ACTIONS(4948),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4946),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4946),
    [aux_sym_begin_keywords_token1] = ACTIONS(4946),
    [anon_sym_SEMI] = ACTIONS(4946),
    [anon_sym_endmodule] = ACTIONS(4948),
    [anon_sym_extern] = ACTIONS(4948),
    [anon_sym_module] = ACTIONS(4948),
    [anon_sym_macromodule] = ACTIONS(4948),
    [anon_sym_endinterface] = ACTIONS(4948),
    [anon_sym_interface] = ACTIONS(4948),
    [anon_sym_endprogram] = ACTIONS(4948),
    [anon_sym_program] = ACTIONS(4948),
    [anon_sym_checker] = ACTIONS(4948),
    [anon_sym_virtual] = ACTIONS(4948),
    [anon_sym_class] = ACTIONS(4948),
    [anon_sym_package] = ACTIONS(4948),
    [anon_sym_endpackage] = ACTIONS(4948),
    [anon_sym_timeunit] = ACTIONS(4948),
    [anon_sym_timeprecision] = ACTIONS(4948),
    [anon_sym_type] = ACTIONS(4948),
    [anon_sym_input] = ACTIONS(4948),
    [anon_sym_output] = ACTIONS(4948),
    [anon_sym_inout] = ACTIONS(4948),
    [anon_sym_ref] = ACTIONS(4948),
    [anon_sym_DOLLARfatal] = ACTIONS(4946),
    [anon_sym_DOLLARerror] = ACTIONS(4946),
    [anon_sym_DOLLARwarning] = ACTIONS(4946),
    [anon_sym_DOLLARinfo] = ACTIONS(4946),
    [anon_sym_default] = ACTIONS(4948),
    [anon_sym_clocking] = ACTIONS(4948),
    [anon_sym_defparam] = ACTIONS(4948),
    [anon_sym_bind] = ACTIONS(4948),
    [anon_sym_const] = ACTIONS(4948),
    [anon_sym_function] = ACTIONS(4948),
    [anon_sym_static] = ACTIONS(4948),
    [anon_sym_constraint] = ACTIONS(4948),
    [anon_sym_if] = ACTIONS(4948),
    [anon_sym_else] = ACTIONS(4948),
    [anon_sym_LBRACK] = ACTIONS(4946),
    [anon_sym_localparam] = ACTIONS(4948),
    [anon_sym_parameter] = ACTIONS(4948),
    [anon_sym_specparam] = ACTIONS(4948),
    [anon_sym_var] = ACTIONS(4948),
    [anon_sym_import] = ACTIONS(4948),
    [anon_sym_export] = ACTIONS(4948),
    [anon_sym_genvar] = ACTIONS(4948),
    [anon_sym_interconnect] = ACTIONS(4948),
    [anon_sym_typedef] = ACTIONS(4948),
    [anon_sym_enum] = ACTIONS(4948),
    [anon_sym_struct] = ACTIONS(4948),
    [anon_sym_union] = ACTIONS(4948),
    [anon_sym_nettype] = ACTIONS(4948),
    [anon_sym_automatic] = ACTIONS(4948),
    [anon_sym_string] = ACTIONS(4948),
    [anon_sym_chandle] = ACTIONS(4948),
    [anon_sym_event] = ACTIONS(4948),
    [anon_sym_byte] = ACTIONS(4948),
    [anon_sym_shortint] = ACTIONS(4948),
    [anon_sym_int] = ACTIONS(4948),
    [anon_sym_longint] = ACTIONS(4948),
    [anon_sym_integer] = ACTIONS(4948),
    [anon_sym_time] = ACTIONS(4948),
    [anon_sym_bit] = ACTIONS(4948),
    [anon_sym_logic] = ACTIONS(4948),
    [anon_sym_reg] = ACTIONS(4948),
    [anon_sym_shortreal] = ACTIONS(4948),
    [anon_sym_real] = ACTIONS(4948),
    [anon_sym_realtime] = ACTIONS(4948),
    [anon_sym_supply0] = ACTIONS(4948),
    [anon_sym_supply1] = ACTIONS(4948),
    [anon_sym_signed] = ACTIONS(4948),
    [anon_sym_unsigned] = ACTIONS(4948),
    [anon_sym_task] = ACTIONS(4948),
    [anon_sym_modport] = ACTIONS(4948),
    [anon_sym_assert] = ACTIONS(4948),
    [anon_sym_property] = ACTIONS(4948),
    [anon_sym_assume] = ACTIONS(4948),
    [anon_sym_cover] = ACTIONS(4948),
    [anon_sym_sequence] = ACTIONS(4948),
    [anon_sym_restrict] = ACTIONS(4948),
    [anon_sym_not] = ACTIONS(4948),
    [anon_sym_or] = ACTIONS(4948),
    [anon_sym_and] = ACTIONS(4948),
    [anon_sym_case] = ACTIONS(4948),
    [anon_sym_always] = ACTIONS(4948),
    [anon_sym_covergroup] = ACTIONS(4948),
    [anon_sym_let] = ACTIONS(4948),
    [anon_sym_pulldown] = ACTIONS(4948),
    [anon_sym_pullup] = ACTIONS(4948),
    [anon_sym_cmos] = ACTIONS(4948),
    [anon_sym_rcmos] = ACTIONS(4948),
    [anon_sym_bufif0] = ACTIONS(4948),
    [anon_sym_bufif1] = ACTIONS(4948),
    [anon_sym_notif0] = ACTIONS(4948),
    [anon_sym_notif1] = ACTIONS(4948),
    [anon_sym_nmos] = ACTIONS(4948),
    [anon_sym_pmos] = ACTIONS(4948),
    [anon_sym_rnmos] = ACTIONS(4948),
    [anon_sym_rpmos] = ACTIONS(4948),
    [anon_sym_nand] = ACTIONS(4948),
    [anon_sym_nor] = ACTIONS(4948),
    [anon_sym_xor] = ACTIONS(4948),
    [anon_sym_xnor] = ACTIONS(4948),
    [anon_sym_buf] = ACTIONS(4948),
    [anon_sym_tranif0] = ACTIONS(4948),
    [anon_sym_tranif1] = ACTIONS(4948),
    [anon_sym_rtranif1] = ACTIONS(4948),
    [anon_sym_rtranif0] = ACTIONS(4948),
    [anon_sym_tran] = ACTIONS(4948),
    [anon_sym_rtran] = ACTIONS(4948),
    [anon_sym_generate] = ACTIONS(4948),
    [anon_sym_for] = ACTIONS(4948),
    [anon_sym_primitive] = ACTIONS(4948),
    [anon_sym_initial] = ACTIONS(4948),
    [anon_sym_assign] = ACTIONS(4948),
    [anon_sym_alias] = ACTIONS(4948),
    [anon_sym_always_comb] = ACTIONS(4948),
    [anon_sym_always_latch] = ACTIONS(4948),
    [anon_sym_always_ff] = ACTIONS(4948),
    [anon_sym_final] = ACTIONS(4948),
    [anon_sym_global] = ACTIONS(4948),
    [anon_sym_specify] = ACTIONS(4948),
    [anon_sym_LPAREN_STAR] = ACTIONS(4946),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4946),
    [anon_sym_DOLLARunit] = ACTIONS(4946),
  },
  [811] = {
    [ts_builtin_sym_end] = ACTIONS(4718),
    [sym_simple_identifier] = ACTIONS(4720),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4718),
    [anon_sym_BQUOTE] = ACTIONS(4720),
    [aux_sym_id_directive_token1] = ACTIONS(4718),
    [aux_sym_id_directive_token2] = ACTIONS(4718),
    [aux_sym_id_directive_token3] = ACTIONS(4718),
    [aux_sym_id_directive_token4] = ACTIONS(4720),
    [aux_sym_zero_directive_token1] = ACTIONS(4718),
    [aux_sym_zero_directive_token2] = ACTIONS(4718),
    [aux_sym_zero_directive_token3] = ACTIONS(4718),
    [aux_sym_zero_directive_token4] = ACTIONS(4718),
    [aux_sym_zero_directive_token5] = ACTIONS(4718),
    [aux_sym_zero_directive_token6] = ACTIONS(4718),
    [aux_sym_zero_directive_token7] = ACTIONS(4718),
    [aux_sym_zero_directive_token8] = ACTIONS(4718),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4718),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4718),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4718),
    [aux_sym_begin_keywords_token1] = ACTIONS(4718),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_endmodule] = ACTIONS(4720),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_module] = ACTIONS(4720),
    [anon_sym_macromodule] = ACTIONS(4720),
    [anon_sym_endinterface] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_endprogram] = ACTIONS(4720),
    [anon_sym_program] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_package] = ACTIONS(4720),
    [anon_sym_endpackage] = ACTIONS(4720),
    [anon_sym_timeunit] = ACTIONS(4720),
    [anon_sym_timeprecision] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_input] = ACTIONS(4720),
    [anon_sym_output] = ACTIONS(4720),
    [anon_sym_inout] = ACTIONS(4720),
    [anon_sym_ref] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_specparam] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_modport] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_primitive] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_specify] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [812] = {
    [ts_builtin_sym_end] = ACTIONS(4950),
    [sym_simple_identifier] = ACTIONS(4952),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4950),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4950),
    [anon_sym_BQUOTE] = ACTIONS(4952),
    [aux_sym_id_directive_token1] = ACTIONS(4950),
    [aux_sym_id_directive_token2] = ACTIONS(4950),
    [aux_sym_id_directive_token3] = ACTIONS(4950),
    [aux_sym_id_directive_token4] = ACTIONS(4952),
    [aux_sym_zero_directive_token1] = ACTIONS(4950),
    [aux_sym_zero_directive_token2] = ACTIONS(4950),
    [aux_sym_zero_directive_token3] = ACTIONS(4950),
    [aux_sym_zero_directive_token4] = ACTIONS(4950),
    [aux_sym_zero_directive_token5] = ACTIONS(4950),
    [aux_sym_zero_directive_token6] = ACTIONS(4950),
    [aux_sym_zero_directive_token7] = ACTIONS(4950),
    [aux_sym_zero_directive_token8] = ACTIONS(4950),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4950),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4950),
    [anon_sym_wire] = ACTIONS(4952),
    [anon_sym_tri] = ACTIONS(4952),
    [anon_sym_tri0] = ACTIONS(4952),
    [anon_sym_tri1] = ACTIONS(4952),
    [anon_sym_wand] = ACTIONS(4952),
    [anon_sym_triand] = ACTIONS(4952),
    [anon_sym_wor] = ACTIONS(4952),
    [anon_sym_trior] = ACTIONS(4952),
    [anon_sym_trireg] = ACTIONS(4952),
    [anon_sym_uwire] = ACTIONS(4952),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4950),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4950),
    [aux_sym_begin_keywords_token1] = ACTIONS(4950),
    [anon_sym_SEMI] = ACTIONS(4950),
    [anon_sym_endmodule] = ACTIONS(4952),
    [anon_sym_extern] = ACTIONS(4952),
    [anon_sym_module] = ACTIONS(4952),
    [anon_sym_macromodule] = ACTIONS(4952),
    [anon_sym_endinterface] = ACTIONS(4952),
    [anon_sym_interface] = ACTIONS(4952),
    [anon_sym_endprogram] = ACTIONS(4952),
    [anon_sym_program] = ACTIONS(4952),
    [anon_sym_checker] = ACTIONS(4952),
    [anon_sym_virtual] = ACTIONS(4952),
    [anon_sym_class] = ACTIONS(4952),
    [anon_sym_package] = ACTIONS(4952),
    [anon_sym_endpackage] = ACTIONS(4952),
    [anon_sym_timeunit] = ACTIONS(4952),
    [anon_sym_timeprecision] = ACTIONS(4952),
    [anon_sym_type] = ACTIONS(4952),
    [anon_sym_input] = ACTIONS(4952),
    [anon_sym_output] = ACTIONS(4952),
    [anon_sym_inout] = ACTIONS(4952),
    [anon_sym_ref] = ACTIONS(4952),
    [anon_sym_DOLLARfatal] = ACTIONS(4950),
    [anon_sym_DOLLARerror] = ACTIONS(4950),
    [anon_sym_DOLLARwarning] = ACTIONS(4950),
    [anon_sym_DOLLARinfo] = ACTIONS(4950),
    [anon_sym_default] = ACTIONS(4952),
    [anon_sym_clocking] = ACTIONS(4952),
    [anon_sym_defparam] = ACTIONS(4952),
    [anon_sym_bind] = ACTIONS(4952),
    [anon_sym_const] = ACTIONS(4952),
    [anon_sym_function] = ACTIONS(4952),
    [anon_sym_static] = ACTIONS(4952),
    [anon_sym_constraint] = ACTIONS(4952),
    [anon_sym_if] = ACTIONS(4952),
    [anon_sym_else] = ACTIONS(4952),
    [anon_sym_LBRACK] = ACTIONS(4950),
    [anon_sym_localparam] = ACTIONS(4952),
    [anon_sym_parameter] = ACTIONS(4952),
    [anon_sym_specparam] = ACTIONS(4952),
    [anon_sym_var] = ACTIONS(4952),
    [anon_sym_import] = ACTIONS(4952),
    [anon_sym_export] = ACTIONS(4952),
    [anon_sym_genvar] = ACTIONS(4952),
    [anon_sym_interconnect] = ACTIONS(4952),
    [anon_sym_typedef] = ACTIONS(4952),
    [anon_sym_enum] = ACTIONS(4952),
    [anon_sym_struct] = ACTIONS(4952),
    [anon_sym_union] = ACTIONS(4952),
    [anon_sym_nettype] = ACTIONS(4952),
    [anon_sym_automatic] = ACTIONS(4952),
    [anon_sym_string] = ACTIONS(4952),
    [anon_sym_chandle] = ACTIONS(4952),
    [anon_sym_event] = ACTIONS(4952),
    [anon_sym_byte] = ACTIONS(4952),
    [anon_sym_shortint] = ACTIONS(4952),
    [anon_sym_int] = ACTIONS(4952),
    [anon_sym_longint] = ACTIONS(4952),
    [anon_sym_integer] = ACTIONS(4952),
    [anon_sym_time] = ACTIONS(4952),
    [anon_sym_bit] = ACTIONS(4952),
    [anon_sym_logic] = ACTIONS(4952),
    [anon_sym_reg] = ACTIONS(4952),
    [anon_sym_shortreal] = ACTIONS(4952),
    [anon_sym_real] = ACTIONS(4952),
    [anon_sym_realtime] = ACTIONS(4952),
    [anon_sym_supply0] = ACTIONS(4952),
    [anon_sym_supply1] = ACTIONS(4952),
    [anon_sym_signed] = ACTIONS(4952),
    [anon_sym_unsigned] = ACTIONS(4952),
    [anon_sym_task] = ACTIONS(4952),
    [anon_sym_modport] = ACTIONS(4952),
    [anon_sym_assert] = ACTIONS(4952),
    [anon_sym_property] = ACTIONS(4952),
    [anon_sym_assume] = ACTIONS(4952),
    [anon_sym_cover] = ACTIONS(4952),
    [anon_sym_sequence] = ACTIONS(4952),
    [anon_sym_restrict] = ACTIONS(4952),
    [anon_sym_not] = ACTIONS(4952),
    [anon_sym_or] = ACTIONS(4952),
    [anon_sym_and] = ACTIONS(4952),
    [anon_sym_case] = ACTIONS(4952),
    [anon_sym_always] = ACTIONS(4952),
    [anon_sym_covergroup] = ACTIONS(4952),
    [anon_sym_let] = ACTIONS(4952),
    [anon_sym_pulldown] = ACTIONS(4952),
    [anon_sym_pullup] = ACTIONS(4952),
    [anon_sym_cmos] = ACTIONS(4952),
    [anon_sym_rcmos] = ACTIONS(4952),
    [anon_sym_bufif0] = ACTIONS(4952),
    [anon_sym_bufif1] = ACTIONS(4952),
    [anon_sym_notif0] = ACTIONS(4952),
    [anon_sym_notif1] = ACTIONS(4952),
    [anon_sym_nmos] = ACTIONS(4952),
    [anon_sym_pmos] = ACTIONS(4952),
    [anon_sym_rnmos] = ACTIONS(4952),
    [anon_sym_rpmos] = ACTIONS(4952),
    [anon_sym_nand] = ACTIONS(4952),
    [anon_sym_nor] = ACTIONS(4952),
    [anon_sym_xor] = ACTIONS(4952),
    [anon_sym_xnor] = ACTIONS(4952),
    [anon_sym_buf] = ACTIONS(4952),
    [anon_sym_tranif0] = ACTIONS(4952),
    [anon_sym_tranif1] = ACTIONS(4952),
    [anon_sym_rtranif1] = ACTIONS(4952),
    [anon_sym_rtranif0] = ACTIONS(4952),
    [anon_sym_tran] = ACTIONS(4952),
    [anon_sym_rtran] = ACTIONS(4952),
    [anon_sym_generate] = ACTIONS(4952),
    [anon_sym_for] = ACTIONS(4952),
    [anon_sym_primitive] = ACTIONS(4952),
    [anon_sym_initial] = ACTIONS(4952),
    [anon_sym_assign] = ACTIONS(4952),
    [anon_sym_alias] = ACTIONS(4952),
    [anon_sym_always_comb] = ACTIONS(4952),
    [anon_sym_always_latch] = ACTIONS(4952),
    [anon_sym_always_ff] = ACTIONS(4952),
    [anon_sym_final] = ACTIONS(4952),
    [anon_sym_global] = ACTIONS(4952),
    [anon_sym_specify] = ACTIONS(4952),
    [anon_sym_LPAREN_STAR] = ACTIONS(4950),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4950),
    [anon_sym_DOLLARunit] = ACTIONS(4950),
  },
  [813] = {
    [ts_builtin_sym_end] = ACTIONS(4954),
    [sym_simple_identifier] = ACTIONS(4956),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4954),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4954),
    [anon_sym_BQUOTE] = ACTIONS(4956),
    [aux_sym_id_directive_token1] = ACTIONS(4954),
    [aux_sym_id_directive_token2] = ACTIONS(4954),
    [aux_sym_id_directive_token3] = ACTIONS(4954),
    [aux_sym_id_directive_token4] = ACTIONS(4956),
    [aux_sym_zero_directive_token1] = ACTIONS(4954),
    [aux_sym_zero_directive_token2] = ACTIONS(4954),
    [aux_sym_zero_directive_token3] = ACTIONS(4954),
    [aux_sym_zero_directive_token4] = ACTIONS(4954),
    [aux_sym_zero_directive_token5] = ACTIONS(4954),
    [aux_sym_zero_directive_token6] = ACTIONS(4954),
    [aux_sym_zero_directive_token7] = ACTIONS(4954),
    [aux_sym_zero_directive_token8] = ACTIONS(4954),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4954),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4954),
    [anon_sym_wire] = ACTIONS(4956),
    [anon_sym_tri] = ACTIONS(4956),
    [anon_sym_tri0] = ACTIONS(4956),
    [anon_sym_tri1] = ACTIONS(4956),
    [anon_sym_wand] = ACTIONS(4956),
    [anon_sym_triand] = ACTIONS(4956),
    [anon_sym_wor] = ACTIONS(4956),
    [anon_sym_trior] = ACTIONS(4956),
    [anon_sym_trireg] = ACTIONS(4956),
    [anon_sym_uwire] = ACTIONS(4956),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4954),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4954),
    [aux_sym_begin_keywords_token1] = ACTIONS(4954),
    [anon_sym_SEMI] = ACTIONS(4954),
    [anon_sym_endmodule] = ACTIONS(4956),
    [anon_sym_extern] = ACTIONS(4956),
    [anon_sym_module] = ACTIONS(4956),
    [anon_sym_macromodule] = ACTIONS(4956),
    [anon_sym_endinterface] = ACTIONS(4956),
    [anon_sym_interface] = ACTIONS(4956),
    [anon_sym_endprogram] = ACTIONS(4956),
    [anon_sym_program] = ACTIONS(4956),
    [anon_sym_checker] = ACTIONS(4956),
    [anon_sym_virtual] = ACTIONS(4956),
    [anon_sym_class] = ACTIONS(4956),
    [anon_sym_package] = ACTIONS(4956),
    [anon_sym_endpackage] = ACTIONS(4956),
    [anon_sym_timeunit] = ACTIONS(4956),
    [anon_sym_timeprecision] = ACTIONS(4956),
    [anon_sym_type] = ACTIONS(4956),
    [anon_sym_input] = ACTIONS(4956),
    [anon_sym_output] = ACTIONS(4956),
    [anon_sym_inout] = ACTIONS(4956),
    [anon_sym_ref] = ACTIONS(4956),
    [anon_sym_DOLLARfatal] = ACTIONS(4954),
    [anon_sym_DOLLARerror] = ACTIONS(4954),
    [anon_sym_DOLLARwarning] = ACTIONS(4954),
    [anon_sym_DOLLARinfo] = ACTIONS(4954),
    [anon_sym_default] = ACTIONS(4956),
    [anon_sym_clocking] = ACTIONS(4956),
    [anon_sym_defparam] = ACTIONS(4956),
    [anon_sym_bind] = ACTIONS(4956),
    [anon_sym_const] = ACTIONS(4956),
    [anon_sym_function] = ACTIONS(4956),
    [anon_sym_static] = ACTIONS(4956),
    [anon_sym_constraint] = ACTIONS(4956),
    [anon_sym_if] = ACTIONS(4956),
    [anon_sym_else] = ACTIONS(4956),
    [anon_sym_LBRACK] = ACTIONS(4954),
    [anon_sym_localparam] = ACTIONS(4956),
    [anon_sym_parameter] = ACTIONS(4956),
    [anon_sym_specparam] = ACTIONS(4956),
    [anon_sym_var] = ACTIONS(4956),
    [anon_sym_import] = ACTIONS(4956),
    [anon_sym_export] = ACTIONS(4956),
    [anon_sym_genvar] = ACTIONS(4956),
    [anon_sym_interconnect] = ACTIONS(4956),
    [anon_sym_typedef] = ACTIONS(4956),
    [anon_sym_enum] = ACTIONS(4956),
    [anon_sym_struct] = ACTIONS(4956),
    [anon_sym_union] = ACTIONS(4956),
    [anon_sym_nettype] = ACTIONS(4956),
    [anon_sym_automatic] = ACTIONS(4956),
    [anon_sym_string] = ACTIONS(4956),
    [anon_sym_chandle] = ACTIONS(4956),
    [anon_sym_event] = ACTIONS(4956),
    [anon_sym_byte] = ACTIONS(4956),
    [anon_sym_shortint] = ACTIONS(4956),
    [anon_sym_int] = ACTIONS(4956),
    [anon_sym_longint] = ACTIONS(4956),
    [anon_sym_integer] = ACTIONS(4956),
    [anon_sym_time] = ACTIONS(4956),
    [anon_sym_bit] = ACTIONS(4956),
    [anon_sym_logic] = ACTIONS(4956),
    [anon_sym_reg] = ACTIONS(4956),
    [anon_sym_shortreal] = ACTIONS(4956),
    [anon_sym_real] = ACTIONS(4956),
    [anon_sym_realtime] = ACTIONS(4956),
    [anon_sym_supply0] = ACTIONS(4956),
    [anon_sym_supply1] = ACTIONS(4956),
    [anon_sym_signed] = ACTIONS(4956),
    [anon_sym_unsigned] = ACTIONS(4956),
    [anon_sym_task] = ACTIONS(4956),
    [anon_sym_modport] = ACTIONS(4956),
    [anon_sym_assert] = ACTIONS(4956),
    [anon_sym_property] = ACTIONS(4956),
    [anon_sym_assume] = ACTIONS(4956),
    [anon_sym_cover] = ACTIONS(4956),
    [anon_sym_sequence] = ACTIONS(4956),
    [anon_sym_restrict] = ACTIONS(4956),
    [anon_sym_not] = ACTIONS(4956),
    [anon_sym_or] = ACTIONS(4956),
    [anon_sym_and] = ACTIONS(4956),
    [anon_sym_case] = ACTIONS(4956),
    [anon_sym_always] = ACTIONS(4956),
    [anon_sym_covergroup] = ACTIONS(4956),
    [anon_sym_let] = ACTIONS(4956),
    [anon_sym_pulldown] = ACTIONS(4956),
    [anon_sym_pullup] = ACTIONS(4956),
    [anon_sym_cmos] = ACTIONS(4956),
    [anon_sym_rcmos] = ACTIONS(4956),
    [anon_sym_bufif0] = ACTIONS(4956),
    [anon_sym_bufif1] = ACTIONS(4956),
    [anon_sym_notif0] = ACTIONS(4956),
    [anon_sym_notif1] = ACTIONS(4956),
    [anon_sym_nmos] = ACTIONS(4956),
    [anon_sym_pmos] = ACTIONS(4956),
    [anon_sym_rnmos] = ACTIONS(4956),
    [anon_sym_rpmos] = ACTIONS(4956),
    [anon_sym_nand] = ACTIONS(4956),
    [anon_sym_nor] = ACTIONS(4956),
    [anon_sym_xor] = ACTIONS(4956),
    [anon_sym_xnor] = ACTIONS(4956),
    [anon_sym_buf] = ACTIONS(4956),
    [anon_sym_tranif0] = ACTIONS(4956),
    [anon_sym_tranif1] = ACTIONS(4956),
    [anon_sym_rtranif1] = ACTIONS(4956),
    [anon_sym_rtranif0] = ACTIONS(4956),
    [anon_sym_tran] = ACTIONS(4956),
    [anon_sym_rtran] = ACTIONS(4956),
    [anon_sym_generate] = ACTIONS(4956),
    [anon_sym_for] = ACTIONS(4956),
    [anon_sym_primitive] = ACTIONS(4956),
    [anon_sym_initial] = ACTIONS(4956),
    [anon_sym_assign] = ACTIONS(4956),
    [anon_sym_alias] = ACTIONS(4956),
    [anon_sym_always_comb] = ACTIONS(4956),
    [anon_sym_always_latch] = ACTIONS(4956),
    [anon_sym_always_ff] = ACTIONS(4956),
    [anon_sym_final] = ACTIONS(4956),
    [anon_sym_global] = ACTIONS(4956),
    [anon_sym_specify] = ACTIONS(4956),
    [anon_sym_LPAREN_STAR] = ACTIONS(4954),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4954),
    [anon_sym_DOLLARunit] = ACTIONS(4954),
  },
  [814] = {
    [ts_builtin_sym_end] = ACTIONS(4958),
    [sym_simple_identifier] = ACTIONS(4960),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4958),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4958),
    [anon_sym_BQUOTE] = ACTIONS(4960),
    [aux_sym_id_directive_token1] = ACTIONS(4958),
    [aux_sym_id_directive_token2] = ACTIONS(4958),
    [aux_sym_id_directive_token3] = ACTIONS(4958),
    [aux_sym_id_directive_token4] = ACTIONS(4960),
    [aux_sym_zero_directive_token1] = ACTIONS(4958),
    [aux_sym_zero_directive_token2] = ACTIONS(4958),
    [aux_sym_zero_directive_token3] = ACTIONS(4958),
    [aux_sym_zero_directive_token4] = ACTIONS(4958),
    [aux_sym_zero_directive_token5] = ACTIONS(4958),
    [aux_sym_zero_directive_token6] = ACTIONS(4958),
    [aux_sym_zero_directive_token7] = ACTIONS(4958),
    [aux_sym_zero_directive_token8] = ACTIONS(4958),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4958),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4958),
    [anon_sym_wire] = ACTIONS(4960),
    [anon_sym_tri] = ACTIONS(4960),
    [anon_sym_tri0] = ACTIONS(4960),
    [anon_sym_tri1] = ACTIONS(4960),
    [anon_sym_wand] = ACTIONS(4960),
    [anon_sym_triand] = ACTIONS(4960),
    [anon_sym_wor] = ACTIONS(4960),
    [anon_sym_trior] = ACTIONS(4960),
    [anon_sym_trireg] = ACTIONS(4960),
    [anon_sym_uwire] = ACTIONS(4960),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4958),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4958),
    [aux_sym_begin_keywords_token1] = ACTIONS(4958),
    [anon_sym_SEMI] = ACTIONS(4958),
    [anon_sym_endmodule] = ACTIONS(4960),
    [anon_sym_extern] = ACTIONS(4960),
    [anon_sym_module] = ACTIONS(4960),
    [anon_sym_macromodule] = ACTIONS(4960),
    [anon_sym_endinterface] = ACTIONS(4960),
    [anon_sym_interface] = ACTIONS(4960),
    [anon_sym_endprogram] = ACTIONS(4960),
    [anon_sym_program] = ACTIONS(4960),
    [anon_sym_checker] = ACTIONS(4960),
    [anon_sym_virtual] = ACTIONS(4960),
    [anon_sym_class] = ACTIONS(4960),
    [anon_sym_package] = ACTIONS(4960),
    [anon_sym_endpackage] = ACTIONS(4960),
    [anon_sym_timeunit] = ACTIONS(4960),
    [anon_sym_timeprecision] = ACTIONS(4960),
    [anon_sym_type] = ACTIONS(4960),
    [anon_sym_input] = ACTIONS(4960),
    [anon_sym_output] = ACTIONS(4960),
    [anon_sym_inout] = ACTIONS(4960),
    [anon_sym_ref] = ACTIONS(4960),
    [anon_sym_DOLLARfatal] = ACTIONS(4958),
    [anon_sym_DOLLARerror] = ACTIONS(4958),
    [anon_sym_DOLLARwarning] = ACTIONS(4958),
    [anon_sym_DOLLARinfo] = ACTIONS(4958),
    [anon_sym_default] = ACTIONS(4960),
    [anon_sym_clocking] = ACTIONS(4960),
    [anon_sym_defparam] = ACTIONS(4960),
    [anon_sym_bind] = ACTIONS(4960),
    [anon_sym_const] = ACTIONS(4960),
    [anon_sym_function] = ACTIONS(4960),
    [anon_sym_static] = ACTIONS(4960),
    [anon_sym_constraint] = ACTIONS(4960),
    [anon_sym_if] = ACTIONS(4960),
    [anon_sym_else] = ACTIONS(4960),
    [anon_sym_LBRACK] = ACTIONS(4958),
    [anon_sym_localparam] = ACTIONS(4960),
    [anon_sym_parameter] = ACTIONS(4960),
    [anon_sym_specparam] = ACTIONS(4960),
    [anon_sym_var] = ACTIONS(4960),
    [anon_sym_import] = ACTIONS(4960),
    [anon_sym_export] = ACTIONS(4960),
    [anon_sym_genvar] = ACTIONS(4960),
    [anon_sym_interconnect] = ACTIONS(4960),
    [anon_sym_typedef] = ACTIONS(4960),
    [anon_sym_enum] = ACTIONS(4960),
    [anon_sym_struct] = ACTIONS(4960),
    [anon_sym_union] = ACTIONS(4960),
    [anon_sym_nettype] = ACTIONS(4960),
    [anon_sym_automatic] = ACTIONS(4960),
    [anon_sym_string] = ACTIONS(4960),
    [anon_sym_chandle] = ACTIONS(4960),
    [anon_sym_event] = ACTIONS(4960),
    [anon_sym_byte] = ACTIONS(4960),
    [anon_sym_shortint] = ACTIONS(4960),
    [anon_sym_int] = ACTIONS(4960),
    [anon_sym_longint] = ACTIONS(4960),
    [anon_sym_integer] = ACTIONS(4960),
    [anon_sym_time] = ACTIONS(4960),
    [anon_sym_bit] = ACTIONS(4960),
    [anon_sym_logic] = ACTIONS(4960),
    [anon_sym_reg] = ACTIONS(4960),
    [anon_sym_shortreal] = ACTIONS(4960),
    [anon_sym_real] = ACTIONS(4960),
    [anon_sym_realtime] = ACTIONS(4960),
    [anon_sym_supply0] = ACTIONS(4960),
    [anon_sym_supply1] = ACTIONS(4960),
    [anon_sym_signed] = ACTIONS(4960),
    [anon_sym_unsigned] = ACTIONS(4960),
    [anon_sym_task] = ACTIONS(4960),
    [anon_sym_modport] = ACTIONS(4960),
    [anon_sym_assert] = ACTIONS(4960),
    [anon_sym_property] = ACTIONS(4960),
    [anon_sym_assume] = ACTIONS(4960),
    [anon_sym_cover] = ACTIONS(4960),
    [anon_sym_sequence] = ACTIONS(4960),
    [anon_sym_restrict] = ACTIONS(4960),
    [anon_sym_not] = ACTIONS(4960),
    [anon_sym_or] = ACTIONS(4960),
    [anon_sym_and] = ACTIONS(4960),
    [anon_sym_case] = ACTIONS(4960),
    [anon_sym_always] = ACTIONS(4960),
    [anon_sym_covergroup] = ACTIONS(4960),
    [anon_sym_let] = ACTIONS(4960),
    [anon_sym_pulldown] = ACTIONS(4960),
    [anon_sym_pullup] = ACTIONS(4960),
    [anon_sym_cmos] = ACTIONS(4960),
    [anon_sym_rcmos] = ACTIONS(4960),
    [anon_sym_bufif0] = ACTIONS(4960),
    [anon_sym_bufif1] = ACTIONS(4960),
    [anon_sym_notif0] = ACTIONS(4960),
    [anon_sym_notif1] = ACTIONS(4960),
    [anon_sym_nmos] = ACTIONS(4960),
    [anon_sym_pmos] = ACTIONS(4960),
    [anon_sym_rnmos] = ACTIONS(4960),
    [anon_sym_rpmos] = ACTIONS(4960),
    [anon_sym_nand] = ACTIONS(4960),
    [anon_sym_nor] = ACTIONS(4960),
    [anon_sym_xor] = ACTIONS(4960),
    [anon_sym_xnor] = ACTIONS(4960),
    [anon_sym_buf] = ACTIONS(4960),
    [anon_sym_tranif0] = ACTIONS(4960),
    [anon_sym_tranif1] = ACTIONS(4960),
    [anon_sym_rtranif1] = ACTIONS(4960),
    [anon_sym_rtranif0] = ACTIONS(4960),
    [anon_sym_tran] = ACTIONS(4960),
    [anon_sym_rtran] = ACTIONS(4960),
    [anon_sym_generate] = ACTIONS(4960),
    [anon_sym_for] = ACTIONS(4960),
    [anon_sym_primitive] = ACTIONS(4960),
    [anon_sym_initial] = ACTIONS(4960),
    [anon_sym_assign] = ACTIONS(4960),
    [anon_sym_alias] = ACTIONS(4960),
    [anon_sym_always_comb] = ACTIONS(4960),
    [anon_sym_always_latch] = ACTIONS(4960),
    [anon_sym_always_ff] = ACTIONS(4960),
    [anon_sym_final] = ACTIONS(4960),
    [anon_sym_global] = ACTIONS(4960),
    [anon_sym_specify] = ACTIONS(4960),
    [anon_sym_LPAREN_STAR] = ACTIONS(4958),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4958),
    [anon_sym_DOLLARunit] = ACTIONS(4958),
  },
  [815] = {
    [ts_builtin_sym_end] = ACTIONS(4962),
    [sym_simple_identifier] = ACTIONS(4964),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4962),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4962),
    [anon_sym_BQUOTE] = ACTIONS(4964),
    [aux_sym_id_directive_token1] = ACTIONS(4962),
    [aux_sym_id_directive_token2] = ACTIONS(4962),
    [aux_sym_id_directive_token3] = ACTIONS(4962),
    [aux_sym_id_directive_token4] = ACTIONS(4964),
    [aux_sym_zero_directive_token1] = ACTIONS(4962),
    [aux_sym_zero_directive_token2] = ACTIONS(4962),
    [aux_sym_zero_directive_token3] = ACTIONS(4962),
    [aux_sym_zero_directive_token4] = ACTIONS(4962),
    [aux_sym_zero_directive_token5] = ACTIONS(4962),
    [aux_sym_zero_directive_token6] = ACTIONS(4962),
    [aux_sym_zero_directive_token7] = ACTIONS(4962),
    [aux_sym_zero_directive_token8] = ACTIONS(4962),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4962),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4962),
    [anon_sym_wire] = ACTIONS(4964),
    [anon_sym_tri] = ACTIONS(4964),
    [anon_sym_tri0] = ACTIONS(4964),
    [anon_sym_tri1] = ACTIONS(4964),
    [anon_sym_wand] = ACTIONS(4964),
    [anon_sym_triand] = ACTIONS(4964),
    [anon_sym_wor] = ACTIONS(4964),
    [anon_sym_trior] = ACTIONS(4964),
    [anon_sym_trireg] = ACTIONS(4964),
    [anon_sym_uwire] = ACTIONS(4964),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4962),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4962),
    [aux_sym_begin_keywords_token1] = ACTIONS(4962),
    [anon_sym_SEMI] = ACTIONS(4962),
    [anon_sym_endmodule] = ACTIONS(4964),
    [anon_sym_extern] = ACTIONS(4964),
    [anon_sym_module] = ACTIONS(4964),
    [anon_sym_macromodule] = ACTIONS(4964),
    [anon_sym_endinterface] = ACTIONS(4964),
    [anon_sym_interface] = ACTIONS(4964),
    [anon_sym_endprogram] = ACTIONS(4964),
    [anon_sym_program] = ACTIONS(4964),
    [anon_sym_checker] = ACTIONS(4964),
    [anon_sym_virtual] = ACTIONS(4964),
    [anon_sym_class] = ACTIONS(4964),
    [anon_sym_package] = ACTIONS(4964),
    [anon_sym_endpackage] = ACTIONS(4964),
    [anon_sym_timeunit] = ACTIONS(4964),
    [anon_sym_timeprecision] = ACTIONS(4964),
    [anon_sym_type] = ACTIONS(4964),
    [anon_sym_input] = ACTIONS(4964),
    [anon_sym_output] = ACTIONS(4964),
    [anon_sym_inout] = ACTIONS(4964),
    [anon_sym_ref] = ACTIONS(4964),
    [anon_sym_DOLLARfatal] = ACTIONS(4962),
    [anon_sym_DOLLARerror] = ACTIONS(4962),
    [anon_sym_DOLLARwarning] = ACTIONS(4962),
    [anon_sym_DOLLARinfo] = ACTIONS(4962),
    [anon_sym_default] = ACTIONS(4964),
    [anon_sym_clocking] = ACTIONS(4964),
    [anon_sym_defparam] = ACTIONS(4964),
    [anon_sym_bind] = ACTIONS(4964),
    [anon_sym_const] = ACTIONS(4964),
    [anon_sym_function] = ACTIONS(4964),
    [anon_sym_static] = ACTIONS(4964),
    [anon_sym_constraint] = ACTIONS(4964),
    [anon_sym_if] = ACTIONS(4964),
    [anon_sym_else] = ACTIONS(4964),
    [anon_sym_LBRACK] = ACTIONS(4962),
    [anon_sym_localparam] = ACTIONS(4964),
    [anon_sym_parameter] = ACTIONS(4964),
    [anon_sym_specparam] = ACTIONS(4964),
    [anon_sym_var] = ACTIONS(4964),
    [anon_sym_import] = ACTIONS(4964),
    [anon_sym_export] = ACTIONS(4964),
    [anon_sym_genvar] = ACTIONS(4964),
    [anon_sym_interconnect] = ACTIONS(4964),
    [anon_sym_typedef] = ACTIONS(4964),
    [anon_sym_enum] = ACTIONS(4964),
    [anon_sym_struct] = ACTIONS(4964),
    [anon_sym_union] = ACTIONS(4964),
    [anon_sym_nettype] = ACTIONS(4964),
    [anon_sym_automatic] = ACTIONS(4964),
    [anon_sym_string] = ACTIONS(4964),
    [anon_sym_chandle] = ACTIONS(4964),
    [anon_sym_event] = ACTIONS(4964),
    [anon_sym_byte] = ACTIONS(4964),
    [anon_sym_shortint] = ACTIONS(4964),
    [anon_sym_int] = ACTIONS(4964),
    [anon_sym_longint] = ACTIONS(4964),
    [anon_sym_integer] = ACTIONS(4964),
    [anon_sym_time] = ACTIONS(4964),
    [anon_sym_bit] = ACTIONS(4964),
    [anon_sym_logic] = ACTIONS(4964),
    [anon_sym_reg] = ACTIONS(4964),
    [anon_sym_shortreal] = ACTIONS(4964),
    [anon_sym_real] = ACTIONS(4964),
    [anon_sym_realtime] = ACTIONS(4964),
    [anon_sym_supply0] = ACTIONS(4964),
    [anon_sym_supply1] = ACTIONS(4964),
    [anon_sym_signed] = ACTIONS(4964),
    [anon_sym_unsigned] = ACTIONS(4964),
    [anon_sym_task] = ACTIONS(4964),
    [anon_sym_modport] = ACTIONS(4964),
    [anon_sym_assert] = ACTIONS(4964),
    [anon_sym_property] = ACTIONS(4964),
    [anon_sym_assume] = ACTIONS(4964),
    [anon_sym_cover] = ACTIONS(4964),
    [anon_sym_sequence] = ACTIONS(4964),
    [anon_sym_restrict] = ACTIONS(4964),
    [anon_sym_not] = ACTIONS(4964),
    [anon_sym_or] = ACTIONS(4964),
    [anon_sym_and] = ACTIONS(4964),
    [anon_sym_case] = ACTIONS(4964),
    [anon_sym_always] = ACTIONS(4964),
    [anon_sym_covergroup] = ACTIONS(4964),
    [anon_sym_let] = ACTIONS(4964),
    [anon_sym_pulldown] = ACTIONS(4964),
    [anon_sym_pullup] = ACTIONS(4964),
    [anon_sym_cmos] = ACTIONS(4964),
    [anon_sym_rcmos] = ACTIONS(4964),
    [anon_sym_bufif0] = ACTIONS(4964),
    [anon_sym_bufif1] = ACTIONS(4964),
    [anon_sym_notif0] = ACTIONS(4964),
    [anon_sym_notif1] = ACTIONS(4964),
    [anon_sym_nmos] = ACTIONS(4964),
    [anon_sym_pmos] = ACTIONS(4964),
    [anon_sym_rnmos] = ACTIONS(4964),
    [anon_sym_rpmos] = ACTIONS(4964),
    [anon_sym_nand] = ACTIONS(4964),
    [anon_sym_nor] = ACTIONS(4964),
    [anon_sym_xor] = ACTIONS(4964),
    [anon_sym_xnor] = ACTIONS(4964),
    [anon_sym_buf] = ACTIONS(4964),
    [anon_sym_tranif0] = ACTIONS(4964),
    [anon_sym_tranif1] = ACTIONS(4964),
    [anon_sym_rtranif1] = ACTIONS(4964),
    [anon_sym_rtranif0] = ACTIONS(4964),
    [anon_sym_tran] = ACTIONS(4964),
    [anon_sym_rtran] = ACTIONS(4964),
    [anon_sym_generate] = ACTIONS(4964),
    [anon_sym_for] = ACTIONS(4964),
    [anon_sym_primitive] = ACTIONS(4964),
    [anon_sym_initial] = ACTIONS(4964),
    [anon_sym_assign] = ACTIONS(4964),
    [anon_sym_alias] = ACTIONS(4964),
    [anon_sym_always_comb] = ACTIONS(4964),
    [anon_sym_always_latch] = ACTIONS(4964),
    [anon_sym_always_ff] = ACTIONS(4964),
    [anon_sym_final] = ACTIONS(4964),
    [anon_sym_global] = ACTIONS(4964),
    [anon_sym_specify] = ACTIONS(4964),
    [anon_sym_LPAREN_STAR] = ACTIONS(4962),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4962),
    [anon_sym_DOLLARunit] = ACTIONS(4962),
  },
  [816] = {
    [ts_builtin_sym_end] = ACTIONS(4966),
    [sym_simple_identifier] = ACTIONS(4968),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4966),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4966),
    [anon_sym_BQUOTE] = ACTIONS(4968),
    [aux_sym_id_directive_token1] = ACTIONS(4966),
    [aux_sym_id_directive_token2] = ACTIONS(4966),
    [aux_sym_id_directive_token3] = ACTIONS(4966),
    [aux_sym_id_directive_token4] = ACTIONS(4968),
    [aux_sym_zero_directive_token1] = ACTIONS(4966),
    [aux_sym_zero_directive_token2] = ACTIONS(4966),
    [aux_sym_zero_directive_token3] = ACTIONS(4966),
    [aux_sym_zero_directive_token4] = ACTIONS(4966),
    [aux_sym_zero_directive_token5] = ACTIONS(4966),
    [aux_sym_zero_directive_token6] = ACTIONS(4966),
    [aux_sym_zero_directive_token7] = ACTIONS(4966),
    [aux_sym_zero_directive_token8] = ACTIONS(4966),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4966),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4966),
    [anon_sym_wire] = ACTIONS(4968),
    [anon_sym_tri] = ACTIONS(4968),
    [anon_sym_tri0] = ACTIONS(4968),
    [anon_sym_tri1] = ACTIONS(4968),
    [anon_sym_wand] = ACTIONS(4968),
    [anon_sym_triand] = ACTIONS(4968),
    [anon_sym_wor] = ACTIONS(4968),
    [anon_sym_trior] = ACTIONS(4968),
    [anon_sym_trireg] = ACTIONS(4968),
    [anon_sym_uwire] = ACTIONS(4968),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4966),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4966),
    [aux_sym_begin_keywords_token1] = ACTIONS(4966),
    [anon_sym_SEMI] = ACTIONS(4966),
    [anon_sym_endmodule] = ACTIONS(4968),
    [anon_sym_extern] = ACTIONS(4968),
    [anon_sym_module] = ACTIONS(4968),
    [anon_sym_macromodule] = ACTIONS(4968),
    [anon_sym_endinterface] = ACTIONS(4968),
    [anon_sym_interface] = ACTIONS(4968),
    [anon_sym_endprogram] = ACTIONS(4968),
    [anon_sym_program] = ACTIONS(4968),
    [anon_sym_checker] = ACTIONS(4968),
    [anon_sym_virtual] = ACTIONS(4968),
    [anon_sym_class] = ACTIONS(4968),
    [anon_sym_package] = ACTIONS(4968),
    [anon_sym_endpackage] = ACTIONS(4968),
    [anon_sym_timeunit] = ACTIONS(4968),
    [anon_sym_timeprecision] = ACTIONS(4968),
    [anon_sym_type] = ACTIONS(4968),
    [anon_sym_input] = ACTIONS(4968),
    [anon_sym_output] = ACTIONS(4968),
    [anon_sym_inout] = ACTIONS(4968),
    [anon_sym_ref] = ACTIONS(4968),
    [anon_sym_DOLLARfatal] = ACTIONS(4966),
    [anon_sym_DOLLARerror] = ACTIONS(4966),
    [anon_sym_DOLLARwarning] = ACTIONS(4966),
    [anon_sym_DOLLARinfo] = ACTIONS(4966),
    [anon_sym_default] = ACTIONS(4968),
    [anon_sym_clocking] = ACTIONS(4968),
    [anon_sym_defparam] = ACTIONS(4968),
    [anon_sym_bind] = ACTIONS(4968),
    [anon_sym_const] = ACTIONS(4968),
    [anon_sym_function] = ACTIONS(4968),
    [anon_sym_static] = ACTIONS(4968),
    [anon_sym_constraint] = ACTIONS(4968),
    [anon_sym_if] = ACTIONS(4968),
    [anon_sym_else] = ACTIONS(4968),
    [anon_sym_LBRACK] = ACTIONS(4966),
    [anon_sym_localparam] = ACTIONS(4968),
    [anon_sym_parameter] = ACTIONS(4968),
    [anon_sym_specparam] = ACTIONS(4968),
    [anon_sym_var] = ACTIONS(4968),
    [anon_sym_import] = ACTIONS(4968),
    [anon_sym_export] = ACTIONS(4968),
    [anon_sym_genvar] = ACTIONS(4968),
    [anon_sym_interconnect] = ACTIONS(4968),
    [anon_sym_typedef] = ACTIONS(4968),
    [anon_sym_enum] = ACTIONS(4968),
    [anon_sym_struct] = ACTIONS(4968),
    [anon_sym_union] = ACTIONS(4968),
    [anon_sym_nettype] = ACTIONS(4968),
    [anon_sym_automatic] = ACTIONS(4968),
    [anon_sym_string] = ACTIONS(4968),
    [anon_sym_chandle] = ACTIONS(4968),
    [anon_sym_event] = ACTIONS(4968),
    [anon_sym_byte] = ACTIONS(4968),
    [anon_sym_shortint] = ACTIONS(4968),
    [anon_sym_int] = ACTIONS(4968),
    [anon_sym_longint] = ACTIONS(4968),
    [anon_sym_integer] = ACTIONS(4968),
    [anon_sym_time] = ACTIONS(4968),
    [anon_sym_bit] = ACTIONS(4968),
    [anon_sym_logic] = ACTIONS(4968),
    [anon_sym_reg] = ACTIONS(4968),
    [anon_sym_shortreal] = ACTIONS(4968),
    [anon_sym_real] = ACTIONS(4968),
    [anon_sym_realtime] = ACTIONS(4968),
    [anon_sym_supply0] = ACTIONS(4968),
    [anon_sym_supply1] = ACTIONS(4968),
    [anon_sym_signed] = ACTIONS(4968),
    [anon_sym_unsigned] = ACTIONS(4968),
    [anon_sym_task] = ACTIONS(4968),
    [anon_sym_modport] = ACTIONS(4968),
    [anon_sym_assert] = ACTIONS(4968),
    [anon_sym_property] = ACTIONS(4968),
    [anon_sym_assume] = ACTIONS(4968),
    [anon_sym_cover] = ACTIONS(4968),
    [anon_sym_sequence] = ACTIONS(4968),
    [anon_sym_restrict] = ACTIONS(4968),
    [anon_sym_not] = ACTIONS(4968),
    [anon_sym_or] = ACTIONS(4968),
    [anon_sym_and] = ACTIONS(4968),
    [anon_sym_case] = ACTIONS(4968),
    [anon_sym_always] = ACTIONS(4968),
    [anon_sym_covergroup] = ACTIONS(4968),
    [anon_sym_let] = ACTIONS(4968),
    [anon_sym_pulldown] = ACTIONS(4968),
    [anon_sym_pullup] = ACTIONS(4968),
    [anon_sym_cmos] = ACTIONS(4968),
    [anon_sym_rcmos] = ACTIONS(4968),
    [anon_sym_bufif0] = ACTIONS(4968),
    [anon_sym_bufif1] = ACTIONS(4968),
    [anon_sym_notif0] = ACTIONS(4968),
    [anon_sym_notif1] = ACTIONS(4968),
    [anon_sym_nmos] = ACTIONS(4968),
    [anon_sym_pmos] = ACTIONS(4968),
    [anon_sym_rnmos] = ACTIONS(4968),
    [anon_sym_rpmos] = ACTIONS(4968),
    [anon_sym_nand] = ACTIONS(4968),
    [anon_sym_nor] = ACTIONS(4968),
    [anon_sym_xor] = ACTIONS(4968),
    [anon_sym_xnor] = ACTIONS(4968),
    [anon_sym_buf] = ACTIONS(4968),
    [anon_sym_tranif0] = ACTIONS(4968),
    [anon_sym_tranif1] = ACTIONS(4968),
    [anon_sym_rtranif1] = ACTIONS(4968),
    [anon_sym_rtranif0] = ACTIONS(4968),
    [anon_sym_tran] = ACTIONS(4968),
    [anon_sym_rtran] = ACTIONS(4968),
    [anon_sym_generate] = ACTIONS(4968),
    [anon_sym_for] = ACTIONS(4968),
    [anon_sym_primitive] = ACTIONS(4968),
    [anon_sym_initial] = ACTIONS(4968),
    [anon_sym_assign] = ACTIONS(4968),
    [anon_sym_alias] = ACTIONS(4968),
    [anon_sym_always_comb] = ACTIONS(4968),
    [anon_sym_always_latch] = ACTIONS(4968),
    [anon_sym_always_ff] = ACTIONS(4968),
    [anon_sym_final] = ACTIONS(4968),
    [anon_sym_global] = ACTIONS(4968),
    [anon_sym_specify] = ACTIONS(4968),
    [anon_sym_LPAREN_STAR] = ACTIONS(4966),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4966),
    [anon_sym_DOLLARunit] = ACTIONS(4966),
  },
  [817] = {
    [ts_builtin_sym_end] = ACTIONS(4970),
    [sym_simple_identifier] = ACTIONS(4972),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4970),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4970),
    [anon_sym_BQUOTE] = ACTIONS(4972),
    [aux_sym_id_directive_token1] = ACTIONS(4970),
    [aux_sym_id_directive_token2] = ACTIONS(4970),
    [aux_sym_id_directive_token3] = ACTIONS(4970),
    [aux_sym_id_directive_token4] = ACTIONS(4972),
    [aux_sym_zero_directive_token1] = ACTIONS(4970),
    [aux_sym_zero_directive_token2] = ACTIONS(4970),
    [aux_sym_zero_directive_token3] = ACTIONS(4970),
    [aux_sym_zero_directive_token4] = ACTIONS(4970),
    [aux_sym_zero_directive_token5] = ACTIONS(4970),
    [aux_sym_zero_directive_token6] = ACTIONS(4970),
    [aux_sym_zero_directive_token7] = ACTIONS(4970),
    [aux_sym_zero_directive_token8] = ACTIONS(4970),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4970),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4970),
    [anon_sym_wire] = ACTIONS(4972),
    [anon_sym_tri] = ACTIONS(4972),
    [anon_sym_tri0] = ACTIONS(4972),
    [anon_sym_tri1] = ACTIONS(4972),
    [anon_sym_wand] = ACTIONS(4972),
    [anon_sym_triand] = ACTIONS(4972),
    [anon_sym_wor] = ACTIONS(4972),
    [anon_sym_trior] = ACTIONS(4972),
    [anon_sym_trireg] = ACTIONS(4972),
    [anon_sym_uwire] = ACTIONS(4972),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4970),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4970),
    [aux_sym_begin_keywords_token1] = ACTIONS(4970),
    [anon_sym_SEMI] = ACTIONS(4970),
    [anon_sym_endmodule] = ACTIONS(4972),
    [anon_sym_extern] = ACTIONS(4972),
    [anon_sym_module] = ACTIONS(4972),
    [anon_sym_macromodule] = ACTIONS(4972),
    [anon_sym_endinterface] = ACTIONS(4972),
    [anon_sym_interface] = ACTIONS(4972),
    [anon_sym_endprogram] = ACTIONS(4972),
    [anon_sym_program] = ACTIONS(4972),
    [anon_sym_checker] = ACTIONS(4972),
    [anon_sym_virtual] = ACTIONS(4972),
    [anon_sym_class] = ACTIONS(4972),
    [anon_sym_package] = ACTIONS(4972),
    [anon_sym_endpackage] = ACTIONS(4972),
    [anon_sym_timeunit] = ACTIONS(4972),
    [anon_sym_timeprecision] = ACTIONS(4972),
    [anon_sym_type] = ACTIONS(4972),
    [anon_sym_input] = ACTIONS(4972),
    [anon_sym_output] = ACTIONS(4972),
    [anon_sym_inout] = ACTIONS(4972),
    [anon_sym_ref] = ACTIONS(4972),
    [anon_sym_DOLLARfatal] = ACTIONS(4970),
    [anon_sym_DOLLARerror] = ACTIONS(4970),
    [anon_sym_DOLLARwarning] = ACTIONS(4970),
    [anon_sym_DOLLARinfo] = ACTIONS(4970),
    [anon_sym_default] = ACTIONS(4972),
    [anon_sym_clocking] = ACTIONS(4972),
    [anon_sym_defparam] = ACTIONS(4972),
    [anon_sym_bind] = ACTIONS(4972),
    [anon_sym_const] = ACTIONS(4972),
    [anon_sym_function] = ACTIONS(4972),
    [anon_sym_static] = ACTIONS(4972),
    [anon_sym_constraint] = ACTIONS(4972),
    [anon_sym_if] = ACTIONS(4972),
    [anon_sym_else] = ACTIONS(4972),
    [anon_sym_LBRACK] = ACTIONS(4970),
    [anon_sym_localparam] = ACTIONS(4972),
    [anon_sym_parameter] = ACTIONS(4972),
    [anon_sym_specparam] = ACTIONS(4972),
    [anon_sym_var] = ACTIONS(4972),
    [anon_sym_import] = ACTIONS(4972),
    [anon_sym_export] = ACTIONS(4972),
    [anon_sym_genvar] = ACTIONS(4972),
    [anon_sym_interconnect] = ACTIONS(4972),
    [anon_sym_typedef] = ACTIONS(4972),
    [anon_sym_enum] = ACTIONS(4972),
    [anon_sym_struct] = ACTIONS(4972),
    [anon_sym_union] = ACTIONS(4972),
    [anon_sym_nettype] = ACTIONS(4972),
    [anon_sym_automatic] = ACTIONS(4972),
    [anon_sym_string] = ACTIONS(4972),
    [anon_sym_chandle] = ACTIONS(4972),
    [anon_sym_event] = ACTIONS(4972),
    [anon_sym_byte] = ACTIONS(4972),
    [anon_sym_shortint] = ACTIONS(4972),
    [anon_sym_int] = ACTIONS(4972),
    [anon_sym_longint] = ACTIONS(4972),
    [anon_sym_integer] = ACTIONS(4972),
    [anon_sym_time] = ACTIONS(4972),
    [anon_sym_bit] = ACTIONS(4972),
    [anon_sym_logic] = ACTIONS(4972),
    [anon_sym_reg] = ACTIONS(4972),
    [anon_sym_shortreal] = ACTIONS(4972),
    [anon_sym_real] = ACTIONS(4972),
    [anon_sym_realtime] = ACTIONS(4972),
    [anon_sym_supply0] = ACTIONS(4972),
    [anon_sym_supply1] = ACTIONS(4972),
    [anon_sym_signed] = ACTIONS(4972),
    [anon_sym_unsigned] = ACTIONS(4972),
    [anon_sym_task] = ACTIONS(4972),
    [anon_sym_modport] = ACTIONS(4972),
    [anon_sym_assert] = ACTIONS(4972),
    [anon_sym_property] = ACTIONS(4972),
    [anon_sym_assume] = ACTIONS(4972),
    [anon_sym_cover] = ACTIONS(4972),
    [anon_sym_sequence] = ACTIONS(4972),
    [anon_sym_restrict] = ACTIONS(4972),
    [anon_sym_not] = ACTIONS(4972),
    [anon_sym_or] = ACTIONS(4972),
    [anon_sym_and] = ACTIONS(4972),
    [anon_sym_case] = ACTIONS(4972),
    [anon_sym_always] = ACTIONS(4972),
    [anon_sym_covergroup] = ACTIONS(4972),
    [anon_sym_let] = ACTIONS(4972),
    [anon_sym_pulldown] = ACTIONS(4972),
    [anon_sym_pullup] = ACTIONS(4972),
    [anon_sym_cmos] = ACTIONS(4972),
    [anon_sym_rcmos] = ACTIONS(4972),
    [anon_sym_bufif0] = ACTIONS(4972),
    [anon_sym_bufif1] = ACTIONS(4972),
    [anon_sym_notif0] = ACTIONS(4972),
    [anon_sym_notif1] = ACTIONS(4972),
    [anon_sym_nmos] = ACTIONS(4972),
    [anon_sym_pmos] = ACTIONS(4972),
    [anon_sym_rnmos] = ACTIONS(4972),
    [anon_sym_rpmos] = ACTIONS(4972),
    [anon_sym_nand] = ACTIONS(4972),
    [anon_sym_nor] = ACTIONS(4972),
    [anon_sym_xor] = ACTIONS(4972),
    [anon_sym_xnor] = ACTIONS(4972),
    [anon_sym_buf] = ACTIONS(4972),
    [anon_sym_tranif0] = ACTIONS(4972),
    [anon_sym_tranif1] = ACTIONS(4972),
    [anon_sym_rtranif1] = ACTIONS(4972),
    [anon_sym_rtranif0] = ACTIONS(4972),
    [anon_sym_tran] = ACTIONS(4972),
    [anon_sym_rtran] = ACTIONS(4972),
    [anon_sym_generate] = ACTIONS(4972),
    [anon_sym_for] = ACTIONS(4972),
    [anon_sym_primitive] = ACTIONS(4972),
    [anon_sym_initial] = ACTIONS(4972),
    [anon_sym_assign] = ACTIONS(4972),
    [anon_sym_alias] = ACTIONS(4972),
    [anon_sym_always_comb] = ACTIONS(4972),
    [anon_sym_always_latch] = ACTIONS(4972),
    [anon_sym_always_ff] = ACTIONS(4972),
    [anon_sym_final] = ACTIONS(4972),
    [anon_sym_global] = ACTIONS(4972),
    [anon_sym_specify] = ACTIONS(4972),
    [anon_sym_LPAREN_STAR] = ACTIONS(4970),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4970),
    [anon_sym_DOLLARunit] = ACTIONS(4970),
  },
  [818] = {
    [ts_builtin_sym_end] = ACTIONS(4974),
    [sym_simple_identifier] = ACTIONS(4976),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4974),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4974),
    [anon_sym_BQUOTE] = ACTIONS(4976),
    [aux_sym_id_directive_token1] = ACTIONS(4974),
    [aux_sym_id_directive_token2] = ACTIONS(4974),
    [aux_sym_id_directive_token3] = ACTIONS(4974),
    [aux_sym_id_directive_token4] = ACTIONS(4976),
    [aux_sym_zero_directive_token1] = ACTIONS(4974),
    [aux_sym_zero_directive_token2] = ACTIONS(4974),
    [aux_sym_zero_directive_token3] = ACTIONS(4974),
    [aux_sym_zero_directive_token4] = ACTIONS(4974),
    [aux_sym_zero_directive_token5] = ACTIONS(4974),
    [aux_sym_zero_directive_token6] = ACTIONS(4974),
    [aux_sym_zero_directive_token7] = ACTIONS(4974),
    [aux_sym_zero_directive_token8] = ACTIONS(4974),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4974),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4974),
    [anon_sym_wire] = ACTIONS(4976),
    [anon_sym_tri] = ACTIONS(4976),
    [anon_sym_tri0] = ACTIONS(4976),
    [anon_sym_tri1] = ACTIONS(4976),
    [anon_sym_wand] = ACTIONS(4976),
    [anon_sym_triand] = ACTIONS(4976),
    [anon_sym_wor] = ACTIONS(4976),
    [anon_sym_trior] = ACTIONS(4976),
    [anon_sym_trireg] = ACTIONS(4976),
    [anon_sym_uwire] = ACTIONS(4976),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4974),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4974),
    [aux_sym_begin_keywords_token1] = ACTIONS(4974),
    [anon_sym_SEMI] = ACTIONS(4974),
    [anon_sym_endmodule] = ACTIONS(4976),
    [anon_sym_extern] = ACTIONS(4976),
    [anon_sym_module] = ACTIONS(4976),
    [anon_sym_macromodule] = ACTIONS(4976),
    [anon_sym_endinterface] = ACTIONS(4976),
    [anon_sym_interface] = ACTIONS(4976),
    [anon_sym_endprogram] = ACTIONS(4976),
    [anon_sym_program] = ACTIONS(4976),
    [anon_sym_checker] = ACTIONS(4976),
    [anon_sym_virtual] = ACTIONS(4976),
    [anon_sym_class] = ACTIONS(4976),
    [anon_sym_package] = ACTIONS(4976),
    [anon_sym_endpackage] = ACTIONS(4976),
    [anon_sym_timeunit] = ACTIONS(4976),
    [anon_sym_timeprecision] = ACTIONS(4976),
    [anon_sym_type] = ACTIONS(4976),
    [anon_sym_input] = ACTIONS(4976),
    [anon_sym_output] = ACTIONS(4976),
    [anon_sym_inout] = ACTIONS(4976),
    [anon_sym_ref] = ACTIONS(4976),
    [anon_sym_DOLLARfatal] = ACTIONS(4974),
    [anon_sym_DOLLARerror] = ACTIONS(4974),
    [anon_sym_DOLLARwarning] = ACTIONS(4974),
    [anon_sym_DOLLARinfo] = ACTIONS(4974),
    [anon_sym_default] = ACTIONS(4976),
    [anon_sym_clocking] = ACTIONS(4976),
    [anon_sym_defparam] = ACTIONS(4976),
    [anon_sym_bind] = ACTIONS(4976),
    [anon_sym_const] = ACTIONS(4976),
    [anon_sym_function] = ACTIONS(4976),
    [anon_sym_static] = ACTIONS(4976),
    [anon_sym_constraint] = ACTIONS(4976),
    [anon_sym_if] = ACTIONS(4976),
    [anon_sym_else] = ACTIONS(4976),
    [anon_sym_LBRACK] = ACTIONS(4974),
    [anon_sym_localparam] = ACTIONS(4976),
    [anon_sym_parameter] = ACTIONS(4976),
    [anon_sym_specparam] = ACTIONS(4976),
    [anon_sym_var] = ACTIONS(4976),
    [anon_sym_import] = ACTIONS(4976),
    [anon_sym_export] = ACTIONS(4976),
    [anon_sym_genvar] = ACTIONS(4976),
    [anon_sym_interconnect] = ACTIONS(4976),
    [anon_sym_typedef] = ACTIONS(4976),
    [anon_sym_enum] = ACTIONS(4976),
    [anon_sym_struct] = ACTIONS(4976),
    [anon_sym_union] = ACTIONS(4976),
    [anon_sym_nettype] = ACTIONS(4976),
    [anon_sym_automatic] = ACTIONS(4976),
    [anon_sym_string] = ACTIONS(4976),
    [anon_sym_chandle] = ACTIONS(4976),
    [anon_sym_event] = ACTIONS(4976),
    [anon_sym_byte] = ACTIONS(4976),
    [anon_sym_shortint] = ACTIONS(4976),
    [anon_sym_int] = ACTIONS(4976),
    [anon_sym_longint] = ACTIONS(4976),
    [anon_sym_integer] = ACTIONS(4976),
    [anon_sym_time] = ACTIONS(4976),
    [anon_sym_bit] = ACTIONS(4976),
    [anon_sym_logic] = ACTIONS(4976),
    [anon_sym_reg] = ACTIONS(4976),
    [anon_sym_shortreal] = ACTIONS(4976),
    [anon_sym_real] = ACTIONS(4976),
    [anon_sym_realtime] = ACTIONS(4976),
    [anon_sym_supply0] = ACTIONS(4976),
    [anon_sym_supply1] = ACTIONS(4976),
    [anon_sym_signed] = ACTIONS(4976),
    [anon_sym_unsigned] = ACTIONS(4976),
    [anon_sym_task] = ACTIONS(4976),
    [anon_sym_modport] = ACTIONS(4976),
    [anon_sym_assert] = ACTIONS(4976),
    [anon_sym_property] = ACTIONS(4976),
    [anon_sym_assume] = ACTIONS(4976),
    [anon_sym_cover] = ACTIONS(4976),
    [anon_sym_sequence] = ACTIONS(4976),
    [anon_sym_restrict] = ACTIONS(4976),
    [anon_sym_not] = ACTIONS(4976),
    [anon_sym_or] = ACTIONS(4976),
    [anon_sym_and] = ACTIONS(4976),
    [anon_sym_case] = ACTIONS(4976),
    [anon_sym_always] = ACTIONS(4976),
    [anon_sym_covergroup] = ACTIONS(4976),
    [anon_sym_let] = ACTIONS(4976),
    [anon_sym_pulldown] = ACTIONS(4976),
    [anon_sym_pullup] = ACTIONS(4976),
    [anon_sym_cmos] = ACTIONS(4976),
    [anon_sym_rcmos] = ACTIONS(4976),
    [anon_sym_bufif0] = ACTIONS(4976),
    [anon_sym_bufif1] = ACTIONS(4976),
    [anon_sym_notif0] = ACTIONS(4976),
    [anon_sym_notif1] = ACTIONS(4976),
    [anon_sym_nmos] = ACTIONS(4976),
    [anon_sym_pmos] = ACTIONS(4976),
    [anon_sym_rnmos] = ACTIONS(4976),
    [anon_sym_rpmos] = ACTIONS(4976),
    [anon_sym_nand] = ACTIONS(4976),
    [anon_sym_nor] = ACTIONS(4976),
    [anon_sym_xor] = ACTIONS(4976),
    [anon_sym_xnor] = ACTIONS(4976),
    [anon_sym_buf] = ACTIONS(4976),
    [anon_sym_tranif0] = ACTIONS(4976),
    [anon_sym_tranif1] = ACTIONS(4976),
    [anon_sym_rtranif1] = ACTIONS(4976),
    [anon_sym_rtranif0] = ACTIONS(4976),
    [anon_sym_tran] = ACTIONS(4976),
    [anon_sym_rtran] = ACTIONS(4976),
    [anon_sym_generate] = ACTIONS(4976),
    [anon_sym_for] = ACTIONS(4976),
    [anon_sym_primitive] = ACTIONS(4976),
    [anon_sym_initial] = ACTIONS(4976),
    [anon_sym_assign] = ACTIONS(4976),
    [anon_sym_alias] = ACTIONS(4976),
    [anon_sym_always_comb] = ACTIONS(4976),
    [anon_sym_always_latch] = ACTIONS(4976),
    [anon_sym_always_ff] = ACTIONS(4976),
    [anon_sym_final] = ACTIONS(4976),
    [anon_sym_global] = ACTIONS(4976),
    [anon_sym_specify] = ACTIONS(4976),
    [anon_sym_LPAREN_STAR] = ACTIONS(4974),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4974),
    [anon_sym_DOLLARunit] = ACTIONS(4974),
  },
  [819] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_non_port_program_item] = STATE(820),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1501),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1501),
    [aux_sym_program_declaration_repeat2] = STATE(820),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(3475),
    [anon_sym_wire] = ACTIONS(3478),
    [anon_sym_tri] = ACTIONS(3478),
    [anon_sym_tri0] = ACTIONS(3478),
    [anon_sym_tri1] = ACTIONS(3478),
    [anon_sym_wand] = ACTIONS(3478),
    [anon_sym_triand] = ACTIONS(3478),
    [anon_sym_wor] = ACTIONS(3478),
    [anon_sym_trior] = ACTIONS(3478),
    [anon_sym_trireg] = ACTIONS(3478),
    [anon_sym_uwire] = ACTIONS(3478),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_interface] = ACTIONS(3484),
    [anon_sym_endprogram] = ACTIONS(3689),
    [anon_sym_checker] = ACTIONS(3490),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3496),
    [anon_sym_timeunit] = ACTIONS(3499),
    [anon_sym_timeprecision] = ACTIONS(3502),
    [anon_sym_type] = ACTIONS(3505),
    [anon_sym_DOLLARfatal] = ACTIONS(3520),
    [anon_sym_DOLLARerror] = ACTIONS(3523),
    [anon_sym_DOLLARwarning] = ACTIONS(3523),
    [anon_sym_DOLLARinfo] = ACTIONS(3523),
    [anon_sym_default] = ACTIONS(3526),
    [anon_sym_clocking] = ACTIONS(3529),
    [anon_sym_bind] = ACTIONS(3532),
    [anon_sym_const] = ACTIONS(3535),
    [anon_sym_function] = ACTIONS(3538),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_constraint] = ACTIONS(3544),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_LBRACK] = ACTIONS(3550),
    [anon_sym_localparam] = ACTIONS(3553),
    [anon_sym_parameter] = ACTIONS(3556),
    [anon_sym_var] = ACTIONS(3559),
    [anon_sym_import] = ACTIONS(3562),
    [anon_sym_export] = ACTIONS(3565),
    [anon_sym_genvar] = ACTIONS(3568),
    [anon_sym_interconnect] = ACTIONS(3571),
    [anon_sym_typedef] = ACTIONS(3574),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3580),
    [anon_sym_union] = ACTIONS(3583),
    [anon_sym_nettype] = ACTIONS(3586),
    [anon_sym_automatic] = ACTIONS(3589),
    [anon_sym_string] = ACTIONS(3592),
    [anon_sym_chandle] = ACTIONS(3592),
    [anon_sym_event] = ACTIONS(3592),
    [anon_sym_byte] = ACTIONS(3595),
    [anon_sym_shortint] = ACTIONS(3595),
    [anon_sym_int] = ACTIONS(3595),
    [anon_sym_longint] = ACTIONS(3595),
    [anon_sym_integer] = ACTIONS(3595),
    [anon_sym_time] = ACTIONS(3595),
    [anon_sym_bit] = ACTIONS(3598),
    [anon_sym_logic] = ACTIONS(3598),
    [anon_sym_reg] = ACTIONS(3598),
    [anon_sym_shortreal] = ACTIONS(3601),
    [anon_sym_real] = ACTIONS(3601),
    [anon_sym_realtime] = ACTIONS(3601),
    [anon_sym_supply0] = ACTIONS(3478),
    [anon_sym_supply1] = ACTIONS(3478),
    [anon_sym_signed] = ACTIONS(3604),
    [anon_sym_unsigned] = ACTIONS(3604),
    [anon_sym_task] = ACTIONS(3607),
    [anon_sym_assert] = ACTIONS(3610),
    [anon_sym_property] = ACTIONS(3613),
    [anon_sym_assume] = ACTIONS(3616),
    [anon_sym_cover] = ACTIONS(3619),
    [anon_sym_sequence] = ACTIONS(3622),
    [anon_sym_restrict] = ACTIONS(3625),
    [anon_sym_case] = ACTIONS(3628),
    [anon_sym_covergroup] = ACTIONS(3631),
    [anon_sym_let] = ACTIONS(3634),
    [anon_sym_generate] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3640),
    [anon_sym_initial] = ACTIONS(3643),
    [anon_sym_assign] = ACTIONS(3646),
    [anon_sym_final] = ACTIONS(3649),
    [anon_sym_global] = ACTIONS(3652),
    [anon_sym_LPAREN_STAR] = ACTIONS(3655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3658),
    [anon_sym_DOLLARunit] = ACTIONS(3661),
  },
  [820] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_non_port_program_item] = STATE(821),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1501),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1501),
    [aux_sym_program_declaration_repeat2] = STATE(821),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3687),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [821] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_non_port_program_item] = STATE(821),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1501),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1501),
    [aux_sym_program_declaration_repeat2] = STATE(821),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(4978),
    [anon_sym_wire] = ACTIONS(4981),
    [anon_sym_tri] = ACTIONS(4981),
    [anon_sym_tri0] = ACTIONS(4981),
    [anon_sym_tri1] = ACTIONS(4981),
    [anon_sym_wand] = ACTIONS(4981),
    [anon_sym_triand] = ACTIONS(4981),
    [anon_sym_wor] = ACTIONS(4981),
    [anon_sym_trior] = ACTIONS(4981),
    [anon_sym_trireg] = ACTIONS(4981),
    [anon_sym_uwire] = ACTIONS(4981),
    [anon_sym_SEMI] = ACTIONS(4984),
    [anon_sym_interface] = ACTIONS(4987),
    [anon_sym_endprogram] = ACTIONS(4990),
    [anon_sym_checker] = ACTIONS(4992),
    [anon_sym_virtual] = ACTIONS(4995),
    [anon_sym_class] = ACTIONS(4998),
    [anon_sym_timeunit] = ACTIONS(5001),
    [anon_sym_timeprecision] = ACTIONS(5004),
    [anon_sym_type] = ACTIONS(5007),
    [anon_sym_DOLLARfatal] = ACTIONS(5010),
    [anon_sym_DOLLARerror] = ACTIONS(5013),
    [anon_sym_DOLLARwarning] = ACTIONS(5013),
    [anon_sym_DOLLARinfo] = ACTIONS(5013),
    [anon_sym_default] = ACTIONS(5016),
    [anon_sym_clocking] = ACTIONS(5019),
    [anon_sym_bind] = ACTIONS(5022),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_function] = ACTIONS(5028),
    [anon_sym_static] = ACTIONS(5031),
    [anon_sym_constraint] = ACTIONS(5034),
    [anon_sym_if] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5040),
    [anon_sym_localparam] = ACTIONS(5043),
    [anon_sym_parameter] = ACTIONS(5046),
    [anon_sym_var] = ACTIONS(5049),
    [anon_sym_import] = ACTIONS(5052),
    [anon_sym_export] = ACTIONS(5055),
    [anon_sym_genvar] = ACTIONS(5058),
    [anon_sym_interconnect] = ACTIONS(5061),
    [anon_sym_typedef] = ACTIONS(5064),
    [anon_sym_enum] = ACTIONS(5067),
    [anon_sym_struct] = ACTIONS(5070),
    [anon_sym_union] = ACTIONS(5073),
    [anon_sym_nettype] = ACTIONS(5076),
    [anon_sym_automatic] = ACTIONS(5079),
    [anon_sym_string] = ACTIONS(5082),
    [anon_sym_chandle] = ACTIONS(5082),
    [anon_sym_event] = ACTIONS(5082),
    [anon_sym_byte] = ACTIONS(5085),
    [anon_sym_shortint] = ACTIONS(5085),
    [anon_sym_int] = ACTIONS(5085),
    [anon_sym_longint] = ACTIONS(5085),
    [anon_sym_integer] = ACTIONS(5085),
    [anon_sym_time] = ACTIONS(5085),
    [anon_sym_bit] = ACTIONS(5088),
    [anon_sym_logic] = ACTIONS(5088),
    [anon_sym_reg] = ACTIONS(5088),
    [anon_sym_shortreal] = ACTIONS(5091),
    [anon_sym_real] = ACTIONS(5091),
    [anon_sym_realtime] = ACTIONS(5091),
    [anon_sym_supply0] = ACTIONS(4981),
    [anon_sym_supply1] = ACTIONS(4981),
    [anon_sym_signed] = ACTIONS(5094),
    [anon_sym_unsigned] = ACTIONS(5094),
    [anon_sym_task] = ACTIONS(5097),
    [anon_sym_assert] = ACTIONS(5100),
    [anon_sym_property] = ACTIONS(5103),
    [anon_sym_assume] = ACTIONS(5106),
    [anon_sym_cover] = ACTIONS(5109),
    [anon_sym_sequence] = ACTIONS(5112),
    [anon_sym_restrict] = ACTIONS(5115),
    [anon_sym_case] = ACTIONS(5118),
    [anon_sym_covergroup] = ACTIONS(5121),
    [anon_sym_let] = ACTIONS(5124),
    [anon_sym_generate] = ACTIONS(5127),
    [anon_sym_for] = ACTIONS(5130),
    [anon_sym_initial] = ACTIONS(5133),
    [anon_sym_assign] = ACTIONS(5136),
    [anon_sym_final] = ACTIONS(5139),
    [anon_sym_global] = ACTIONS(5142),
    [anon_sym_LPAREN_STAR] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5148),
    [anon_sym_DOLLARunit] = ACTIONS(5151),
  },
  [822] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8757),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_LBRACK_STAR] = ACTIONS(2648),
    [anon_sym_LBRACK_EQ] = ACTIONS(2648),
    [anon_sym_EQ_GT] = ACTIONS(2648),
    [anon_sym_LBRACKu2013_GT] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [823] = {
    [ts_builtin_sym_end] = ACTIONS(5168),
    [sym_simple_identifier] = ACTIONS(5170),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5168),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5168),
    [anon_sym_BQUOTE] = ACTIONS(5170),
    [aux_sym_id_directive_token1] = ACTIONS(5168),
    [aux_sym_id_directive_token2] = ACTIONS(5168),
    [aux_sym_id_directive_token3] = ACTIONS(5168),
    [aux_sym_id_directive_token4] = ACTIONS(5170),
    [aux_sym_zero_directive_token1] = ACTIONS(5168),
    [aux_sym_zero_directive_token2] = ACTIONS(5168),
    [aux_sym_zero_directive_token3] = ACTIONS(5168),
    [aux_sym_zero_directive_token4] = ACTIONS(5168),
    [aux_sym_zero_directive_token5] = ACTIONS(5168),
    [aux_sym_zero_directive_token6] = ACTIONS(5168),
    [aux_sym_zero_directive_token7] = ACTIONS(5168),
    [aux_sym_zero_directive_token8] = ACTIONS(5168),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5168),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5168),
    [anon_sym_wire] = ACTIONS(5170),
    [anon_sym_tri] = ACTIONS(5170),
    [anon_sym_tri0] = ACTIONS(5170),
    [anon_sym_tri1] = ACTIONS(5170),
    [anon_sym_wand] = ACTIONS(5170),
    [anon_sym_triand] = ACTIONS(5170),
    [anon_sym_wor] = ACTIONS(5170),
    [anon_sym_trior] = ACTIONS(5170),
    [anon_sym_trireg] = ACTIONS(5170),
    [anon_sym_uwire] = ACTIONS(5170),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5168),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5168),
    [aux_sym_begin_keywords_token1] = ACTIONS(5168),
    [anon_sym_SEMI] = ACTIONS(5168),
    [anon_sym_endmodule] = ACTIONS(5170),
    [anon_sym_extern] = ACTIONS(5170),
    [anon_sym_module] = ACTIONS(5170),
    [anon_sym_macromodule] = ACTIONS(5170),
    [anon_sym_endinterface] = ACTIONS(5170),
    [anon_sym_interface] = ACTIONS(5170),
    [anon_sym_endprogram] = ACTIONS(5170),
    [anon_sym_program] = ACTIONS(5170),
    [anon_sym_checker] = ACTIONS(5170),
    [anon_sym_virtual] = ACTIONS(5170),
    [anon_sym_class] = ACTIONS(5170),
    [anon_sym_package] = ACTIONS(5170),
    [anon_sym_endpackage] = ACTIONS(5170),
    [anon_sym_timeunit] = ACTIONS(5170),
    [anon_sym_timeprecision] = ACTIONS(5170),
    [anon_sym_type] = ACTIONS(5170),
    [anon_sym_input] = ACTIONS(5170),
    [anon_sym_output] = ACTIONS(5170),
    [anon_sym_inout] = ACTIONS(5170),
    [anon_sym_ref] = ACTIONS(5170),
    [anon_sym_DOLLARfatal] = ACTIONS(5168),
    [anon_sym_DOLLARerror] = ACTIONS(5168),
    [anon_sym_DOLLARwarning] = ACTIONS(5168),
    [anon_sym_DOLLARinfo] = ACTIONS(5168),
    [anon_sym_default] = ACTIONS(5170),
    [anon_sym_clocking] = ACTIONS(5170),
    [anon_sym_defparam] = ACTIONS(5170),
    [anon_sym_bind] = ACTIONS(5170),
    [anon_sym_const] = ACTIONS(5170),
    [anon_sym_function] = ACTIONS(5170),
    [anon_sym_static] = ACTIONS(5170),
    [anon_sym_constraint] = ACTIONS(5170),
    [anon_sym_if] = ACTIONS(5170),
    [anon_sym_else] = ACTIONS(5170),
    [anon_sym_LBRACK] = ACTIONS(5168),
    [anon_sym_localparam] = ACTIONS(5170),
    [anon_sym_parameter] = ACTIONS(5170),
    [anon_sym_specparam] = ACTIONS(5170),
    [anon_sym_var] = ACTIONS(5170),
    [anon_sym_import] = ACTIONS(5170),
    [anon_sym_export] = ACTIONS(5170),
    [anon_sym_genvar] = ACTIONS(5170),
    [anon_sym_interconnect] = ACTIONS(5170),
    [anon_sym_typedef] = ACTIONS(5170),
    [anon_sym_enum] = ACTIONS(5170),
    [anon_sym_struct] = ACTIONS(5170),
    [anon_sym_union] = ACTIONS(5170),
    [anon_sym_nettype] = ACTIONS(5170),
    [anon_sym_automatic] = ACTIONS(5170),
    [anon_sym_string] = ACTIONS(5170),
    [anon_sym_chandle] = ACTIONS(5170),
    [anon_sym_event] = ACTIONS(5170),
    [anon_sym_byte] = ACTIONS(5170),
    [anon_sym_shortint] = ACTIONS(5170),
    [anon_sym_int] = ACTIONS(5170),
    [anon_sym_longint] = ACTIONS(5170),
    [anon_sym_integer] = ACTIONS(5170),
    [anon_sym_time] = ACTIONS(5170),
    [anon_sym_bit] = ACTIONS(5170),
    [anon_sym_logic] = ACTIONS(5170),
    [anon_sym_reg] = ACTIONS(5170),
    [anon_sym_shortreal] = ACTIONS(5170),
    [anon_sym_real] = ACTIONS(5170),
    [anon_sym_realtime] = ACTIONS(5170),
    [anon_sym_supply0] = ACTIONS(5170),
    [anon_sym_supply1] = ACTIONS(5170),
    [anon_sym_signed] = ACTIONS(5170),
    [anon_sym_unsigned] = ACTIONS(5170),
    [anon_sym_task] = ACTIONS(5170),
    [anon_sym_modport] = ACTIONS(5170),
    [anon_sym_assert] = ACTIONS(5170),
    [anon_sym_property] = ACTIONS(5170),
    [anon_sym_assume] = ACTIONS(5170),
    [anon_sym_cover] = ACTIONS(5170),
    [anon_sym_sequence] = ACTIONS(5170),
    [anon_sym_restrict] = ACTIONS(5170),
    [anon_sym_not] = ACTIONS(5170),
    [anon_sym_or] = ACTIONS(5170),
    [anon_sym_and] = ACTIONS(5170),
    [anon_sym_case] = ACTIONS(5170),
    [anon_sym_always] = ACTIONS(5170),
    [anon_sym_covergroup] = ACTIONS(5170),
    [anon_sym_let] = ACTIONS(5170),
    [anon_sym_pulldown] = ACTIONS(5170),
    [anon_sym_pullup] = ACTIONS(5170),
    [anon_sym_cmos] = ACTIONS(5170),
    [anon_sym_rcmos] = ACTIONS(5170),
    [anon_sym_bufif0] = ACTIONS(5170),
    [anon_sym_bufif1] = ACTIONS(5170),
    [anon_sym_notif0] = ACTIONS(5170),
    [anon_sym_notif1] = ACTIONS(5170),
    [anon_sym_nmos] = ACTIONS(5170),
    [anon_sym_pmos] = ACTIONS(5170),
    [anon_sym_rnmos] = ACTIONS(5170),
    [anon_sym_rpmos] = ACTIONS(5170),
    [anon_sym_nand] = ACTIONS(5170),
    [anon_sym_nor] = ACTIONS(5170),
    [anon_sym_xor] = ACTIONS(5170),
    [anon_sym_xnor] = ACTIONS(5170),
    [anon_sym_buf] = ACTIONS(5170),
    [anon_sym_tranif0] = ACTIONS(5170),
    [anon_sym_tranif1] = ACTIONS(5170),
    [anon_sym_rtranif1] = ACTIONS(5170),
    [anon_sym_rtranif0] = ACTIONS(5170),
    [anon_sym_tran] = ACTIONS(5170),
    [anon_sym_rtran] = ACTIONS(5170),
    [anon_sym_generate] = ACTIONS(5170),
    [anon_sym_for] = ACTIONS(5170),
    [anon_sym_primitive] = ACTIONS(5170),
    [anon_sym_initial] = ACTIONS(5170),
    [anon_sym_assign] = ACTIONS(5170),
    [anon_sym_alias] = ACTIONS(5170),
    [anon_sym_always_comb] = ACTIONS(5170),
    [anon_sym_always_latch] = ACTIONS(5170),
    [anon_sym_always_ff] = ACTIONS(5170),
    [anon_sym_final] = ACTIONS(5170),
    [anon_sym_global] = ACTIONS(5170),
    [anon_sym_specify] = ACTIONS(5170),
    [anon_sym_LPAREN_STAR] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5168),
    [anon_sym_DOLLARunit] = ACTIONS(5168),
  },
  [824] = {
    [ts_builtin_sym_end] = ACTIONS(5172),
    [sym_simple_identifier] = ACTIONS(5174),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5172),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5172),
    [anon_sym_BQUOTE] = ACTIONS(5174),
    [aux_sym_id_directive_token1] = ACTIONS(5172),
    [aux_sym_id_directive_token2] = ACTIONS(5172),
    [aux_sym_id_directive_token3] = ACTIONS(5172),
    [aux_sym_id_directive_token4] = ACTIONS(5174),
    [aux_sym_zero_directive_token1] = ACTIONS(5172),
    [aux_sym_zero_directive_token2] = ACTIONS(5172),
    [aux_sym_zero_directive_token3] = ACTIONS(5172),
    [aux_sym_zero_directive_token4] = ACTIONS(5172),
    [aux_sym_zero_directive_token5] = ACTIONS(5172),
    [aux_sym_zero_directive_token6] = ACTIONS(5172),
    [aux_sym_zero_directive_token7] = ACTIONS(5172),
    [aux_sym_zero_directive_token8] = ACTIONS(5172),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5172),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5172),
    [anon_sym_wire] = ACTIONS(5174),
    [anon_sym_tri] = ACTIONS(5174),
    [anon_sym_tri0] = ACTIONS(5174),
    [anon_sym_tri1] = ACTIONS(5174),
    [anon_sym_wand] = ACTIONS(5174),
    [anon_sym_triand] = ACTIONS(5174),
    [anon_sym_wor] = ACTIONS(5174),
    [anon_sym_trior] = ACTIONS(5174),
    [anon_sym_trireg] = ACTIONS(5174),
    [anon_sym_uwire] = ACTIONS(5174),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5172),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5172),
    [aux_sym_begin_keywords_token1] = ACTIONS(5172),
    [anon_sym_SEMI] = ACTIONS(5172),
    [anon_sym_endmodule] = ACTIONS(5174),
    [anon_sym_extern] = ACTIONS(5174),
    [anon_sym_module] = ACTIONS(5174),
    [anon_sym_macromodule] = ACTIONS(5174),
    [anon_sym_endinterface] = ACTIONS(5174),
    [anon_sym_interface] = ACTIONS(5174),
    [anon_sym_endprogram] = ACTIONS(5174),
    [anon_sym_program] = ACTIONS(5174),
    [anon_sym_checker] = ACTIONS(5174),
    [anon_sym_virtual] = ACTIONS(5174),
    [anon_sym_class] = ACTIONS(5174),
    [anon_sym_package] = ACTIONS(5174),
    [anon_sym_endpackage] = ACTIONS(5174),
    [anon_sym_timeunit] = ACTIONS(5174),
    [anon_sym_timeprecision] = ACTIONS(5174),
    [anon_sym_type] = ACTIONS(5174),
    [anon_sym_input] = ACTIONS(5174),
    [anon_sym_output] = ACTIONS(5174),
    [anon_sym_inout] = ACTIONS(5174),
    [anon_sym_ref] = ACTIONS(5174),
    [anon_sym_DOLLARfatal] = ACTIONS(5172),
    [anon_sym_DOLLARerror] = ACTIONS(5172),
    [anon_sym_DOLLARwarning] = ACTIONS(5172),
    [anon_sym_DOLLARinfo] = ACTIONS(5172),
    [anon_sym_default] = ACTIONS(5174),
    [anon_sym_clocking] = ACTIONS(5174),
    [anon_sym_defparam] = ACTIONS(5174),
    [anon_sym_bind] = ACTIONS(5174),
    [anon_sym_const] = ACTIONS(5174),
    [anon_sym_function] = ACTIONS(5174),
    [anon_sym_static] = ACTIONS(5174),
    [anon_sym_constraint] = ACTIONS(5174),
    [anon_sym_if] = ACTIONS(5174),
    [anon_sym_else] = ACTIONS(5174),
    [anon_sym_LBRACK] = ACTIONS(5172),
    [anon_sym_localparam] = ACTIONS(5174),
    [anon_sym_parameter] = ACTIONS(5174),
    [anon_sym_specparam] = ACTIONS(5174),
    [anon_sym_var] = ACTIONS(5174),
    [anon_sym_import] = ACTIONS(5174),
    [anon_sym_export] = ACTIONS(5174),
    [anon_sym_genvar] = ACTIONS(5174),
    [anon_sym_interconnect] = ACTIONS(5174),
    [anon_sym_typedef] = ACTIONS(5174),
    [anon_sym_enum] = ACTIONS(5174),
    [anon_sym_struct] = ACTIONS(5174),
    [anon_sym_union] = ACTIONS(5174),
    [anon_sym_nettype] = ACTIONS(5174),
    [anon_sym_automatic] = ACTIONS(5174),
    [anon_sym_string] = ACTIONS(5174),
    [anon_sym_chandle] = ACTIONS(5174),
    [anon_sym_event] = ACTIONS(5174),
    [anon_sym_byte] = ACTIONS(5174),
    [anon_sym_shortint] = ACTIONS(5174),
    [anon_sym_int] = ACTIONS(5174),
    [anon_sym_longint] = ACTIONS(5174),
    [anon_sym_integer] = ACTIONS(5174),
    [anon_sym_time] = ACTIONS(5174),
    [anon_sym_bit] = ACTIONS(5174),
    [anon_sym_logic] = ACTIONS(5174),
    [anon_sym_reg] = ACTIONS(5174),
    [anon_sym_shortreal] = ACTIONS(5174),
    [anon_sym_real] = ACTIONS(5174),
    [anon_sym_realtime] = ACTIONS(5174),
    [anon_sym_supply0] = ACTIONS(5174),
    [anon_sym_supply1] = ACTIONS(5174),
    [anon_sym_signed] = ACTIONS(5174),
    [anon_sym_unsigned] = ACTIONS(5174),
    [anon_sym_task] = ACTIONS(5174),
    [anon_sym_modport] = ACTIONS(5174),
    [anon_sym_assert] = ACTIONS(5174),
    [anon_sym_property] = ACTIONS(5174),
    [anon_sym_assume] = ACTIONS(5174),
    [anon_sym_cover] = ACTIONS(5174),
    [anon_sym_sequence] = ACTIONS(5174),
    [anon_sym_restrict] = ACTIONS(5174),
    [anon_sym_not] = ACTIONS(5174),
    [anon_sym_or] = ACTIONS(5174),
    [anon_sym_and] = ACTIONS(5174),
    [anon_sym_case] = ACTIONS(5174),
    [anon_sym_always] = ACTIONS(5174),
    [anon_sym_covergroup] = ACTIONS(5174),
    [anon_sym_let] = ACTIONS(5174),
    [anon_sym_pulldown] = ACTIONS(5174),
    [anon_sym_pullup] = ACTIONS(5174),
    [anon_sym_cmos] = ACTIONS(5174),
    [anon_sym_rcmos] = ACTIONS(5174),
    [anon_sym_bufif0] = ACTIONS(5174),
    [anon_sym_bufif1] = ACTIONS(5174),
    [anon_sym_notif0] = ACTIONS(5174),
    [anon_sym_notif1] = ACTIONS(5174),
    [anon_sym_nmos] = ACTIONS(5174),
    [anon_sym_pmos] = ACTIONS(5174),
    [anon_sym_rnmos] = ACTIONS(5174),
    [anon_sym_rpmos] = ACTIONS(5174),
    [anon_sym_nand] = ACTIONS(5174),
    [anon_sym_nor] = ACTIONS(5174),
    [anon_sym_xor] = ACTIONS(5174),
    [anon_sym_xnor] = ACTIONS(5174),
    [anon_sym_buf] = ACTIONS(5174),
    [anon_sym_tranif0] = ACTIONS(5174),
    [anon_sym_tranif1] = ACTIONS(5174),
    [anon_sym_rtranif1] = ACTIONS(5174),
    [anon_sym_rtranif0] = ACTIONS(5174),
    [anon_sym_tran] = ACTIONS(5174),
    [anon_sym_rtran] = ACTIONS(5174),
    [anon_sym_generate] = ACTIONS(5174),
    [anon_sym_for] = ACTIONS(5174),
    [anon_sym_primitive] = ACTIONS(5174),
    [anon_sym_initial] = ACTIONS(5174),
    [anon_sym_assign] = ACTIONS(5174),
    [anon_sym_alias] = ACTIONS(5174),
    [anon_sym_always_comb] = ACTIONS(5174),
    [anon_sym_always_latch] = ACTIONS(5174),
    [anon_sym_always_ff] = ACTIONS(5174),
    [anon_sym_final] = ACTIONS(5174),
    [anon_sym_global] = ACTIONS(5174),
    [anon_sym_specify] = ACTIONS(5174),
    [anon_sym_LPAREN_STAR] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5172),
    [anon_sym_DOLLARunit] = ACTIONS(5172),
  },
  [825] = {
    [ts_builtin_sym_end] = ACTIONS(5176),
    [sym_simple_identifier] = ACTIONS(5178),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5176),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5176),
    [anon_sym_BQUOTE] = ACTIONS(5178),
    [aux_sym_id_directive_token1] = ACTIONS(5176),
    [aux_sym_id_directive_token2] = ACTIONS(5176),
    [aux_sym_id_directive_token3] = ACTIONS(5176),
    [aux_sym_id_directive_token4] = ACTIONS(5178),
    [aux_sym_zero_directive_token1] = ACTIONS(5176),
    [aux_sym_zero_directive_token2] = ACTIONS(5176),
    [aux_sym_zero_directive_token3] = ACTIONS(5176),
    [aux_sym_zero_directive_token4] = ACTIONS(5176),
    [aux_sym_zero_directive_token5] = ACTIONS(5176),
    [aux_sym_zero_directive_token6] = ACTIONS(5176),
    [aux_sym_zero_directive_token7] = ACTIONS(5176),
    [aux_sym_zero_directive_token8] = ACTIONS(5176),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5176),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5176),
    [anon_sym_wire] = ACTIONS(5178),
    [anon_sym_tri] = ACTIONS(5178),
    [anon_sym_tri0] = ACTIONS(5178),
    [anon_sym_tri1] = ACTIONS(5178),
    [anon_sym_wand] = ACTIONS(5178),
    [anon_sym_triand] = ACTIONS(5178),
    [anon_sym_wor] = ACTIONS(5178),
    [anon_sym_trior] = ACTIONS(5178),
    [anon_sym_trireg] = ACTIONS(5178),
    [anon_sym_uwire] = ACTIONS(5178),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5176),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5176),
    [aux_sym_begin_keywords_token1] = ACTIONS(5176),
    [anon_sym_SEMI] = ACTIONS(5176),
    [anon_sym_endmodule] = ACTIONS(5178),
    [anon_sym_extern] = ACTIONS(5178),
    [anon_sym_module] = ACTIONS(5178),
    [anon_sym_macromodule] = ACTIONS(5178),
    [anon_sym_endinterface] = ACTIONS(5178),
    [anon_sym_interface] = ACTIONS(5178),
    [anon_sym_endprogram] = ACTIONS(5178),
    [anon_sym_program] = ACTIONS(5178),
    [anon_sym_checker] = ACTIONS(5178),
    [anon_sym_virtual] = ACTIONS(5178),
    [anon_sym_class] = ACTIONS(5178),
    [anon_sym_package] = ACTIONS(5178),
    [anon_sym_endpackage] = ACTIONS(5178),
    [anon_sym_timeunit] = ACTIONS(5178),
    [anon_sym_timeprecision] = ACTIONS(5178),
    [anon_sym_type] = ACTIONS(5178),
    [anon_sym_input] = ACTIONS(5178),
    [anon_sym_output] = ACTIONS(5178),
    [anon_sym_inout] = ACTIONS(5178),
    [anon_sym_ref] = ACTIONS(5178),
    [anon_sym_DOLLARfatal] = ACTIONS(5176),
    [anon_sym_DOLLARerror] = ACTIONS(5176),
    [anon_sym_DOLLARwarning] = ACTIONS(5176),
    [anon_sym_DOLLARinfo] = ACTIONS(5176),
    [anon_sym_default] = ACTIONS(5178),
    [anon_sym_clocking] = ACTIONS(5178),
    [anon_sym_defparam] = ACTIONS(5178),
    [anon_sym_bind] = ACTIONS(5178),
    [anon_sym_const] = ACTIONS(5178),
    [anon_sym_function] = ACTIONS(5178),
    [anon_sym_static] = ACTIONS(5178),
    [anon_sym_constraint] = ACTIONS(5178),
    [anon_sym_if] = ACTIONS(5178),
    [anon_sym_else] = ACTIONS(5178),
    [anon_sym_LBRACK] = ACTIONS(5176),
    [anon_sym_localparam] = ACTIONS(5178),
    [anon_sym_parameter] = ACTIONS(5178),
    [anon_sym_specparam] = ACTIONS(5178),
    [anon_sym_var] = ACTIONS(5178),
    [anon_sym_import] = ACTIONS(5178),
    [anon_sym_export] = ACTIONS(5178),
    [anon_sym_genvar] = ACTIONS(5178),
    [anon_sym_interconnect] = ACTIONS(5178),
    [anon_sym_typedef] = ACTIONS(5178),
    [anon_sym_enum] = ACTIONS(5178),
    [anon_sym_struct] = ACTIONS(5178),
    [anon_sym_union] = ACTIONS(5178),
    [anon_sym_nettype] = ACTIONS(5178),
    [anon_sym_automatic] = ACTIONS(5178),
    [anon_sym_string] = ACTIONS(5178),
    [anon_sym_chandle] = ACTIONS(5178),
    [anon_sym_event] = ACTIONS(5178),
    [anon_sym_byte] = ACTIONS(5178),
    [anon_sym_shortint] = ACTIONS(5178),
    [anon_sym_int] = ACTIONS(5178),
    [anon_sym_longint] = ACTIONS(5178),
    [anon_sym_integer] = ACTIONS(5178),
    [anon_sym_time] = ACTIONS(5178),
    [anon_sym_bit] = ACTIONS(5178),
    [anon_sym_logic] = ACTIONS(5178),
    [anon_sym_reg] = ACTIONS(5178),
    [anon_sym_shortreal] = ACTIONS(5178),
    [anon_sym_real] = ACTIONS(5178),
    [anon_sym_realtime] = ACTIONS(5178),
    [anon_sym_supply0] = ACTIONS(5178),
    [anon_sym_supply1] = ACTIONS(5178),
    [anon_sym_signed] = ACTIONS(5178),
    [anon_sym_unsigned] = ACTIONS(5178),
    [anon_sym_task] = ACTIONS(5178),
    [anon_sym_modport] = ACTIONS(5178),
    [anon_sym_assert] = ACTIONS(5178),
    [anon_sym_property] = ACTIONS(5178),
    [anon_sym_assume] = ACTIONS(5178),
    [anon_sym_cover] = ACTIONS(5178),
    [anon_sym_sequence] = ACTIONS(5178),
    [anon_sym_restrict] = ACTIONS(5178),
    [anon_sym_not] = ACTIONS(5178),
    [anon_sym_or] = ACTIONS(5178),
    [anon_sym_and] = ACTIONS(5178),
    [anon_sym_case] = ACTIONS(5178),
    [anon_sym_always] = ACTIONS(5178),
    [anon_sym_covergroup] = ACTIONS(5178),
    [anon_sym_let] = ACTIONS(5178),
    [anon_sym_pulldown] = ACTIONS(5178),
    [anon_sym_pullup] = ACTIONS(5178),
    [anon_sym_cmos] = ACTIONS(5178),
    [anon_sym_rcmos] = ACTIONS(5178),
    [anon_sym_bufif0] = ACTIONS(5178),
    [anon_sym_bufif1] = ACTIONS(5178),
    [anon_sym_notif0] = ACTIONS(5178),
    [anon_sym_notif1] = ACTIONS(5178),
    [anon_sym_nmos] = ACTIONS(5178),
    [anon_sym_pmos] = ACTIONS(5178),
    [anon_sym_rnmos] = ACTIONS(5178),
    [anon_sym_rpmos] = ACTIONS(5178),
    [anon_sym_nand] = ACTIONS(5178),
    [anon_sym_nor] = ACTIONS(5178),
    [anon_sym_xor] = ACTIONS(5178),
    [anon_sym_xnor] = ACTIONS(5178),
    [anon_sym_buf] = ACTIONS(5178),
    [anon_sym_tranif0] = ACTIONS(5178),
    [anon_sym_tranif1] = ACTIONS(5178),
    [anon_sym_rtranif1] = ACTIONS(5178),
    [anon_sym_rtranif0] = ACTIONS(5178),
    [anon_sym_tran] = ACTIONS(5178),
    [anon_sym_rtran] = ACTIONS(5178),
    [anon_sym_generate] = ACTIONS(5178),
    [anon_sym_for] = ACTIONS(5178),
    [anon_sym_primitive] = ACTIONS(5178),
    [anon_sym_initial] = ACTIONS(5178),
    [anon_sym_assign] = ACTIONS(5178),
    [anon_sym_alias] = ACTIONS(5178),
    [anon_sym_always_comb] = ACTIONS(5178),
    [anon_sym_always_latch] = ACTIONS(5178),
    [anon_sym_always_ff] = ACTIONS(5178),
    [anon_sym_final] = ACTIONS(5178),
    [anon_sym_global] = ACTIONS(5178),
    [anon_sym_specify] = ACTIONS(5178),
    [anon_sym_LPAREN_STAR] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5176),
    [anon_sym_DOLLARunit] = ACTIONS(5176),
  },
  [826] = {
    [ts_builtin_sym_end] = ACTIONS(5180),
    [sym_simple_identifier] = ACTIONS(5182),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5180),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5180),
    [anon_sym_BQUOTE] = ACTIONS(5182),
    [aux_sym_id_directive_token1] = ACTIONS(5180),
    [aux_sym_id_directive_token2] = ACTIONS(5180),
    [aux_sym_id_directive_token3] = ACTIONS(5180),
    [aux_sym_id_directive_token4] = ACTIONS(5182),
    [aux_sym_zero_directive_token1] = ACTIONS(5180),
    [aux_sym_zero_directive_token2] = ACTIONS(5180),
    [aux_sym_zero_directive_token3] = ACTIONS(5180),
    [aux_sym_zero_directive_token4] = ACTIONS(5180),
    [aux_sym_zero_directive_token5] = ACTIONS(5180),
    [aux_sym_zero_directive_token6] = ACTIONS(5180),
    [aux_sym_zero_directive_token7] = ACTIONS(5180),
    [aux_sym_zero_directive_token8] = ACTIONS(5180),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5180),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5180),
    [anon_sym_wire] = ACTIONS(5182),
    [anon_sym_tri] = ACTIONS(5182),
    [anon_sym_tri0] = ACTIONS(5182),
    [anon_sym_tri1] = ACTIONS(5182),
    [anon_sym_wand] = ACTIONS(5182),
    [anon_sym_triand] = ACTIONS(5182),
    [anon_sym_wor] = ACTIONS(5182),
    [anon_sym_trior] = ACTIONS(5182),
    [anon_sym_trireg] = ACTIONS(5182),
    [anon_sym_uwire] = ACTIONS(5182),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5180),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5180),
    [aux_sym_begin_keywords_token1] = ACTIONS(5180),
    [anon_sym_SEMI] = ACTIONS(5180),
    [anon_sym_endmodule] = ACTIONS(5182),
    [anon_sym_extern] = ACTIONS(5182),
    [anon_sym_module] = ACTIONS(5182),
    [anon_sym_macromodule] = ACTIONS(5182),
    [anon_sym_endinterface] = ACTIONS(5182),
    [anon_sym_interface] = ACTIONS(5182),
    [anon_sym_endprogram] = ACTIONS(5182),
    [anon_sym_program] = ACTIONS(5182),
    [anon_sym_checker] = ACTIONS(5182),
    [anon_sym_virtual] = ACTIONS(5182),
    [anon_sym_class] = ACTIONS(5182),
    [anon_sym_package] = ACTIONS(5182),
    [anon_sym_endpackage] = ACTIONS(5182),
    [anon_sym_timeunit] = ACTIONS(5182),
    [anon_sym_timeprecision] = ACTIONS(5182),
    [anon_sym_type] = ACTIONS(5182),
    [anon_sym_input] = ACTIONS(5182),
    [anon_sym_output] = ACTIONS(5182),
    [anon_sym_inout] = ACTIONS(5182),
    [anon_sym_ref] = ACTIONS(5182),
    [anon_sym_DOLLARfatal] = ACTIONS(5180),
    [anon_sym_DOLLARerror] = ACTIONS(5180),
    [anon_sym_DOLLARwarning] = ACTIONS(5180),
    [anon_sym_DOLLARinfo] = ACTIONS(5180),
    [anon_sym_default] = ACTIONS(5182),
    [anon_sym_clocking] = ACTIONS(5182),
    [anon_sym_defparam] = ACTIONS(5182),
    [anon_sym_bind] = ACTIONS(5182),
    [anon_sym_const] = ACTIONS(5182),
    [anon_sym_function] = ACTIONS(5182),
    [anon_sym_static] = ACTIONS(5182),
    [anon_sym_constraint] = ACTIONS(5182),
    [anon_sym_if] = ACTIONS(5182),
    [anon_sym_else] = ACTIONS(5182),
    [anon_sym_LBRACK] = ACTIONS(5180),
    [anon_sym_localparam] = ACTIONS(5182),
    [anon_sym_parameter] = ACTIONS(5182),
    [anon_sym_specparam] = ACTIONS(5182),
    [anon_sym_var] = ACTIONS(5182),
    [anon_sym_import] = ACTIONS(5182),
    [anon_sym_export] = ACTIONS(5182),
    [anon_sym_genvar] = ACTIONS(5182),
    [anon_sym_interconnect] = ACTIONS(5182),
    [anon_sym_typedef] = ACTIONS(5182),
    [anon_sym_enum] = ACTIONS(5182),
    [anon_sym_struct] = ACTIONS(5182),
    [anon_sym_union] = ACTIONS(5182),
    [anon_sym_nettype] = ACTIONS(5182),
    [anon_sym_automatic] = ACTIONS(5182),
    [anon_sym_string] = ACTIONS(5182),
    [anon_sym_chandle] = ACTIONS(5182),
    [anon_sym_event] = ACTIONS(5182),
    [anon_sym_byte] = ACTIONS(5182),
    [anon_sym_shortint] = ACTIONS(5182),
    [anon_sym_int] = ACTIONS(5182),
    [anon_sym_longint] = ACTIONS(5182),
    [anon_sym_integer] = ACTIONS(5182),
    [anon_sym_time] = ACTIONS(5182),
    [anon_sym_bit] = ACTIONS(5182),
    [anon_sym_logic] = ACTIONS(5182),
    [anon_sym_reg] = ACTIONS(5182),
    [anon_sym_shortreal] = ACTIONS(5182),
    [anon_sym_real] = ACTIONS(5182),
    [anon_sym_realtime] = ACTIONS(5182),
    [anon_sym_supply0] = ACTIONS(5182),
    [anon_sym_supply1] = ACTIONS(5182),
    [anon_sym_signed] = ACTIONS(5182),
    [anon_sym_unsigned] = ACTIONS(5182),
    [anon_sym_task] = ACTIONS(5182),
    [anon_sym_modport] = ACTIONS(5182),
    [anon_sym_assert] = ACTIONS(5182),
    [anon_sym_property] = ACTIONS(5182),
    [anon_sym_assume] = ACTIONS(5182),
    [anon_sym_cover] = ACTIONS(5182),
    [anon_sym_sequence] = ACTIONS(5182),
    [anon_sym_restrict] = ACTIONS(5182),
    [anon_sym_not] = ACTIONS(5182),
    [anon_sym_or] = ACTIONS(5182),
    [anon_sym_and] = ACTIONS(5182),
    [anon_sym_case] = ACTIONS(5182),
    [anon_sym_always] = ACTIONS(5182),
    [anon_sym_covergroup] = ACTIONS(5182),
    [anon_sym_let] = ACTIONS(5182),
    [anon_sym_pulldown] = ACTIONS(5182),
    [anon_sym_pullup] = ACTIONS(5182),
    [anon_sym_cmos] = ACTIONS(5182),
    [anon_sym_rcmos] = ACTIONS(5182),
    [anon_sym_bufif0] = ACTIONS(5182),
    [anon_sym_bufif1] = ACTIONS(5182),
    [anon_sym_notif0] = ACTIONS(5182),
    [anon_sym_notif1] = ACTIONS(5182),
    [anon_sym_nmos] = ACTIONS(5182),
    [anon_sym_pmos] = ACTIONS(5182),
    [anon_sym_rnmos] = ACTIONS(5182),
    [anon_sym_rpmos] = ACTIONS(5182),
    [anon_sym_nand] = ACTIONS(5182),
    [anon_sym_nor] = ACTIONS(5182),
    [anon_sym_xor] = ACTIONS(5182),
    [anon_sym_xnor] = ACTIONS(5182),
    [anon_sym_buf] = ACTIONS(5182),
    [anon_sym_tranif0] = ACTIONS(5182),
    [anon_sym_tranif1] = ACTIONS(5182),
    [anon_sym_rtranif1] = ACTIONS(5182),
    [anon_sym_rtranif0] = ACTIONS(5182),
    [anon_sym_tran] = ACTIONS(5182),
    [anon_sym_rtran] = ACTIONS(5182),
    [anon_sym_generate] = ACTIONS(5182),
    [anon_sym_for] = ACTIONS(5182),
    [anon_sym_primitive] = ACTIONS(5182),
    [anon_sym_initial] = ACTIONS(5182),
    [anon_sym_assign] = ACTIONS(5182),
    [anon_sym_alias] = ACTIONS(5182),
    [anon_sym_always_comb] = ACTIONS(5182),
    [anon_sym_always_latch] = ACTIONS(5182),
    [anon_sym_always_ff] = ACTIONS(5182),
    [anon_sym_final] = ACTIONS(5182),
    [anon_sym_global] = ACTIONS(5182),
    [anon_sym_specify] = ACTIONS(5182),
    [anon_sym_LPAREN_STAR] = ACTIONS(5180),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5180),
    [anon_sym_DOLLARunit] = ACTIONS(5180),
  },
  [827] = {
    [ts_builtin_sym_end] = ACTIONS(4534),
    [sym_simple_identifier] = ACTIONS(4536),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4534),
    [anon_sym_BQUOTE] = ACTIONS(4536),
    [aux_sym_id_directive_token1] = ACTIONS(4534),
    [aux_sym_id_directive_token2] = ACTIONS(4534),
    [aux_sym_id_directive_token3] = ACTIONS(4534),
    [aux_sym_id_directive_token4] = ACTIONS(4536),
    [aux_sym_zero_directive_token1] = ACTIONS(4534),
    [aux_sym_zero_directive_token2] = ACTIONS(4534),
    [aux_sym_zero_directive_token3] = ACTIONS(4534),
    [aux_sym_zero_directive_token4] = ACTIONS(4534),
    [aux_sym_zero_directive_token5] = ACTIONS(4534),
    [aux_sym_zero_directive_token6] = ACTIONS(4534),
    [aux_sym_zero_directive_token7] = ACTIONS(4534),
    [aux_sym_zero_directive_token8] = ACTIONS(4534),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4534),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4534),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4534),
    [aux_sym_begin_keywords_token1] = ACTIONS(4534),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_endmodule] = ACTIONS(4536),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_module] = ACTIONS(4536),
    [anon_sym_macromodule] = ACTIONS(4536),
    [anon_sym_endinterface] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_endprogram] = ACTIONS(4536),
    [anon_sym_program] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_package] = ACTIONS(4536),
    [anon_sym_endpackage] = ACTIONS(4536),
    [anon_sym_timeunit] = ACTIONS(4536),
    [anon_sym_timeprecision] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_input] = ACTIONS(4536),
    [anon_sym_output] = ACTIONS(4536),
    [anon_sym_inout] = ACTIONS(4536),
    [anon_sym_ref] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_specparam] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_modport] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_primitive] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_specify] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [828] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5643),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_non_port_program_item] = STATE(821),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1501),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1501),
    [aux_sym_program_declaration_repeat2] = STATE(821),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3880),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [829] = {
    [ts_builtin_sym_end] = ACTIONS(4228),
    [sym_simple_identifier] = ACTIONS(4230),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4228),
    [anon_sym_BQUOTE] = ACTIONS(4230),
    [aux_sym_id_directive_token1] = ACTIONS(4228),
    [aux_sym_id_directive_token2] = ACTIONS(4228),
    [aux_sym_id_directive_token3] = ACTIONS(4228),
    [aux_sym_id_directive_token4] = ACTIONS(4230),
    [aux_sym_zero_directive_token1] = ACTIONS(4228),
    [aux_sym_zero_directive_token2] = ACTIONS(4228),
    [aux_sym_zero_directive_token3] = ACTIONS(4228),
    [aux_sym_zero_directive_token4] = ACTIONS(4228),
    [aux_sym_zero_directive_token5] = ACTIONS(4228),
    [aux_sym_zero_directive_token6] = ACTIONS(4228),
    [aux_sym_zero_directive_token7] = ACTIONS(4228),
    [aux_sym_zero_directive_token8] = ACTIONS(4228),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4228),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4228),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4228),
    [aux_sym_begin_keywords_token1] = ACTIONS(4228),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_endmodule] = ACTIONS(4230),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_module] = ACTIONS(4230),
    [anon_sym_macromodule] = ACTIONS(4230),
    [anon_sym_endinterface] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_endprogram] = ACTIONS(4230),
    [anon_sym_program] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_package] = ACTIONS(4230),
    [anon_sym_endpackage] = ACTIONS(4230),
    [anon_sym_timeunit] = ACTIONS(4230),
    [anon_sym_timeprecision] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_input] = ACTIONS(4230),
    [anon_sym_output] = ACTIONS(4230),
    [anon_sym_inout] = ACTIONS(4230),
    [anon_sym_ref] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_specparam] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_modport] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_primitive] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_specify] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [830] = {
    [ts_builtin_sym_end] = ACTIONS(5184),
    [sym_simple_identifier] = ACTIONS(5186),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5184),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5184),
    [anon_sym_BQUOTE] = ACTIONS(5186),
    [aux_sym_id_directive_token1] = ACTIONS(5184),
    [aux_sym_id_directive_token2] = ACTIONS(5184),
    [aux_sym_id_directive_token3] = ACTIONS(5184),
    [aux_sym_id_directive_token4] = ACTIONS(5186),
    [aux_sym_zero_directive_token1] = ACTIONS(5184),
    [aux_sym_zero_directive_token2] = ACTIONS(5184),
    [aux_sym_zero_directive_token3] = ACTIONS(5184),
    [aux_sym_zero_directive_token4] = ACTIONS(5184),
    [aux_sym_zero_directive_token5] = ACTIONS(5184),
    [aux_sym_zero_directive_token6] = ACTIONS(5184),
    [aux_sym_zero_directive_token7] = ACTIONS(5184),
    [aux_sym_zero_directive_token8] = ACTIONS(5184),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5184),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5184),
    [anon_sym_wire] = ACTIONS(5186),
    [anon_sym_tri] = ACTIONS(5186),
    [anon_sym_tri0] = ACTIONS(5186),
    [anon_sym_tri1] = ACTIONS(5186),
    [anon_sym_wand] = ACTIONS(5186),
    [anon_sym_triand] = ACTIONS(5186),
    [anon_sym_wor] = ACTIONS(5186),
    [anon_sym_trior] = ACTIONS(5186),
    [anon_sym_trireg] = ACTIONS(5186),
    [anon_sym_uwire] = ACTIONS(5186),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5184),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5184),
    [aux_sym_begin_keywords_token1] = ACTIONS(5184),
    [anon_sym_SEMI] = ACTIONS(5184),
    [anon_sym_endmodule] = ACTIONS(5186),
    [anon_sym_extern] = ACTIONS(5186),
    [anon_sym_module] = ACTIONS(5186),
    [anon_sym_macromodule] = ACTIONS(5186),
    [anon_sym_endinterface] = ACTIONS(5186),
    [anon_sym_interface] = ACTIONS(5186),
    [anon_sym_endprogram] = ACTIONS(5186),
    [anon_sym_program] = ACTIONS(5186),
    [anon_sym_checker] = ACTIONS(5186),
    [anon_sym_virtual] = ACTIONS(5186),
    [anon_sym_class] = ACTIONS(5186),
    [anon_sym_package] = ACTIONS(5186),
    [anon_sym_endpackage] = ACTIONS(5186),
    [anon_sym_timeunit] = ACTIONS(5186),
    [anon_sym_timeprecision] = ACTIONS(5186),
    [anon_sym_type] = ACTIONS(5186),
    [anon_sym_input] = ACTIONS(5186),
    [anon_sym_output] = ACTIONS(5186),
    [anon_sym_inout] = ACTIONS(5186),
    [anon_sym_ref] = ACTIONS(5186),
    [anon_sym_DOLLARfatal] = ACTIONS(5184),
    [anon_sym_DOLLARerror] = ACTIONS(5184),
    [anon_sym_DOLLARwarning] = ACTIONS(5184),
    [anon_sym_DOLLARinfo] = ACTIONS(5184),
    [anon_sym_default] = ACTIONS(5186),
    [anon_sym_clocking] = ACTIONS(5186),
    [anon_sym_defparam] = ACTIONS(5186),
    [anon_sym_bind] = ACTIONS(5186),
    [anon_sym_const] = ACTIONS(5186),
    [anon_sym_function] = ACTIONS(5186),
    [anon_sym_static] = ACTIONS(5186),
    [anon_sym_constraint] = ACTIONS(5186),
    [anon_sym_if] = ACTIONS(5186),
    [anon_sym_else] = ACTIONS(5186),
    [anon_sym_LBRACK] = ACTIONS(5184),
    [anon_sym_localparam] = ACTIONS(5186),
    [anon_sym_parameter] = ACTIONS(5186),
    [anon_sym_specparam] = ACTIONS(5186),
    [anon_sym_var] = ACTIONS(5186),
    [anon_sym_import] = ACTIONS(5186),
    [anon_sym_export] = ACTIONS(5186),
    [anon_sym_genvar] = ACTIONS(5186),
    [anon_sym_interconnect] = ACTIONS(5186),
    [anon_sym_typedef] = ACTIONS(5186),
    [anon_sym_enum] = ACTIONS(5186),
    [anon_sym_struct] = ACTIONS(5186),
    [anon_sym_union] = ACTIONS(5186),
    [anon_sym_nettype] = ACTIONS(5186),
    [anon_sym_automatic] = ACTIONS(5186),
    [anon_sym_string] = ACTIONS(5186),
    [anon_sym_chandle] = ACTIONS(5186),
    [anon_sym_event] = ACTIONS(5186),
    [anon_sym_byte] = ACTIONS(5186),
    [anon_sym_shortint] = ACTIONS(5186),
    [anon_sym_int] = ACTIONS(5186),
    [anon_sym_longint] = ACTIONS(5186),
    [anon_sym_integer] = ACTIONS(5186),
    [anon_sym_time] = ACTIONS(5186),
    [anon_sym_bit] = ACTIONS(5186),
    [anon_sym_logic] = ACTIONS(5186),
    [anon_sym_reg] = ACTIONS(5186),
    [anon_sym_shortreal] = ACTIONS(5186),
    [anon_sym_real] = ACTIONS(5186),
    [anon_sym_realtime] = ACTIONS(5186),
    [anon_sym_supply0] = ACTIONS(5186),
    [anon_sym_supply1] = ACTIONS(5186),
    [anon_sym_signed] = ACTIONS(5186),
    [anon_sym_unsigned] = ACTIONS(5186),
    [anon_sym_task] = ACTIONS(5186),
    [anon_sym_modport] = ACTIONS(5186),
    [anon_sym_assert] = ACTIONS(5186),
    [anon_sym_property] = ACTIONS(5186),
    [anon_sym_assume] = ACTIONS(5186),
    [anon_sym_cover] = ACTIONS(5186),
    [anon_sym_sequence] = ACTIONS(5186),
    [anon_sym_restrict] = ACTIONS(5186),
    [anon_sym_not] = ACTIONS(5186),
    [anon_sym_or] = ACTIONS(5186),
    [anon_sym_and] = ACTIONS(5186),
    [anon_sym_case] = ACTIONS(5186),
    [anon_sym_always] = ACTIONS(5186),
    [anon_sym_covergroup] = ACTIONS(5186),
    [anon_sym_let] = ACTIONS(5186),
    [anon_sym_pulldown] = ACTIONS(5186),
    [anon_sym_pullup] = ACTIONS(5186),
    [anon_sym_cmos] = ACTIONS(5186),
    [anon_sym_rcmos] = ACTIONS(5186),
    [anon_sym_bufif0] = ACTIONS(5186),
    [anon_sym_bufif1] = ACTIONS(5186),
    [anon_sym_notif0] = ACTIONS(5186),
    [anon_sym_notif1] = ACTIONS(5186),
    [anon_sym_nmos] = ACTIONS(5186),
    [anon_sym_pmos] = ACTIONS(5186),
    [anon_sym_rnmos] = ACTIONS(5186),
    [anon_sym_rpmos] = ACTIONS(5186),
    [anon_sym_nand] = ACTIONS(5186),
    [anon_sym_nor] = ACTIONS(5186),
    [anon_sym_xor] = ACTIONS(5186),
    [anon_sym_xnor] = ACTIONS(5186),
    [anon_sym_buf] = ACTIONS(5186),
    [anon_sym_tranif0] = ACTIONS(5186),
    [anon_sym_tranif1] = ACTIONS(5186),
    [anon_sym_rtranif1] = ACTIONS(5186),
    [anon_sym_rtranif0] = ACTIONS(5186),
    [anon_sym_tran] = ACTIONS(5186),
    [anon_sym_rtran] = ACTIONS(5186),
    [anon_sym_generate] = ACTIONS(5186),
    [anon_sym_for] = ACTIONS(5186),
    [anon_sym_primitive] = ACTIONS(5186),
    [anon_sym_initial] = ACTIONS(5186),
    [anon_sym_assign] = ACTIONS(5186),
    [anon_sym_alias] = ACTIONS(5186),
    [anon_sym_always_comb] = ACTIONS(5186),
    [anon_sym_always_latch] = ACTIONS(5186),
    [anon_sym_always_ff] = ACTIONS(5186),
    [anon_sym_final] = ACTIONS(5186),
    [anon_sym_global] = ACTIONS(5186),
    [anon_sym_specify] = ACTIONS(5186),
    [anon_sym_LPAREN_STAR] = ACTIONS(5184),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5184),
    [anon_sym_DOLLARunit] = ACTIONS(5184),
  },
  [831] = {
    [ts_builtin_sym_end] = ACTIONS(5188),
    [sym_simple_identifier] = ACTIONS(5190),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5188),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5188),
    [anon_sym_BQUOTE] = ACTIONS(5190),
    [aux_sym_id_directive_token1] = ACTIONS(5188),
    [aux_sym_id_directive_token2] = ACTIONS(5188),
    [aux_sym_id_directive_token3] = ACTIONS(5188),
    [aux_sym_id_directive_token4] = ACTIONS(5190),
    [aux_sym_zero_directive_token1] = ACTIONS(5188),
    [aux_sym_zero_directive_token2] = ACTIONS(5188),
    [aux_sym_zero_directive_token3] = ACTIONS(5188),
    [aux_sym_zero_directive_token4] = ACTIONS(5188),
    [aux_sym_zero_directive_token5] = ACTIONS(5188),
    [aux_sym_zero_directive_token6] = ACTIONS(5188),
    [aux_sym_zero_directive_token7] = ACTIONS(5188),
    [aux_sym_zero_directive_token8] = ACTIONS(5188),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5188),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5188),
    [anon_sym_wire] = ACTIONS(5190),
    [anon_sym_tri] = ACTIONS(5190),
    [anon_sym_tri0] = ACTIONS(5190),
    [anon_sym_tri1] = ACTIONS(5190),
    [anon_sym_wand] = ACTIONS(5190),
    [anon_sym_triand] = ACTIONS(5190),
    [anon_sym_wor] = ACTIONS(5190),
    [anon_sym_trior] = ACTIONS(5190),
    [anon_sym_trireg] = ACTIONS(5190),
    [anon_sym_uwire] = ACTIONS(5190),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5188),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5188),
    [aux_sym_begin_keywords_token1] = ACTIONS(5188),
    [anon_sym_SEMI] = ACTIONS(5188),
    [anon_sym_endmodule] = ACTIONS(5190),
    [anon_sym_extern] = ACTIONS(5190),
    [anon_sym_module] = ACTIONS(5190),
    [anon_sym_macromodule] = ACTIONS(5190),
    [anon_sym_endinterface] = ACTIONS(5190),
    [anon_sym_interface] = ACTIONS(5190),
    [anon_sym_endprogram] = ACTIONS(5190),
    [anon_sym_program] = ACTIONS(5190),
    [anon_sym_checker] = ACTIONS(5190),
    [anon_sym_virtual] = ACTIONS(5190),
    [anon_sym_class] = ACTIONS(5190),
    [anon_sym_package] = ACTIONS(5190),
    [anon_sym_endpackage] = ACTIONS(5190),
    [anon_sym_timeunit] = ACTIONS(5190),
    [anon_sym_timeprecision] = ACTIONS(5190),
    [anon_sym_type] = ACTIONS(5190),
    [anon_sym_input] = ACTIONS(5190),
    [anon_sym_output] = ACTIONS(5190),
    [anon_sym_inout] = ACTIONS(5190),
    [anon_sym_ref] = ACTIONS(5190),
    [anon_sym_DOLLARfatal] = ACTIONS(5188),
    [anon_sym_DOLLARerror] = ACTIONS(5188),
    [anon_sym_DOLLARwarning] = ACTIONS(5188),
    [anon_sym_DOLLARinfo] = ACTIONS(5188),
    [anon_sym_default] = ACTIONS(5190),
    [anon_sym_clocking] = ACTIONS(5190),
    [anon_sym_defparam] = ACTIONS(5190),
    [anon_sym_bind] = ACTIONS(5190),
    [anon_sym_const] = ACTIONS(5190),
    [anon_sym_function] = ACTIONS(5190),
    [anon_sym_static] = ACTIONS(5190),
    [anon_sym_constraint] = ACTIONS(5190),
    [anon_sym_if] = ACTIONS(5190),
    [anon_sym_else] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(5188),
    [anon_sym_localparam] = ACTIONS(5190),
    [anon_sym_parameter] = ACTIONS(5190),
    [anon_sym_specparam] = ACTIONS(5190),
    [anon_sym_var] = ACTIONS(5190),
    [anon_sym_import] = ACTIONS(5190),
    [anon_sym_export] = ACTIONS(5190),
    [anon_sym_genvar] = ACTIONS(5190),
    [anon_sym_interconnect] = ACTIONS(5190),
    [anon_sym_typedef] = ACTIONS(5190),
    [anon_sym_enum] = ACTIONS(5190),
    [anon_sym_struct] = ACTIONS(5190),
    [anon_sym_union] = ACTIONS(5190),
    [anon_sym_nettype] = ACTIONS(5190),
    [anon_sym_automatic] = ACTIONS(5190),
    [anon_sym_string] = ACTIONS(5190),
    [anon_sym_chandle] = ACTIONS(5190),
    [anon_sym_event] = ACTIONS(5190),
    [anon_sym_byte] = ACTIONS(5190),
    [anon_sym_shortint] = ACTIONS(5190),
    [anon_sym_int] = ACTIONS(5190),
    [anon_sym_longint] = ACTIONS(5190),
    [anon_sym_integer] = ACTIONS(5190),
    [anon_sym_time] = ACTIONS(5190),
    [anon_sym_bit] = ACTIONS(5190),
    [anon_sym_logic] = ACTIONS(5190),
    [anon_sym_reg] = ACTIONS(5190),
    [anon_sym_shortreal] = ACTIONS(5190),
    [anon_sym_real] = ACTIONS(5190),
    [anon_sym_realtime] = ACTIONS(5190),
    [anon_sym_supply0] = ACTIONS(5190),
    [anon_sym_supply1] = ACTIONS(5190),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_task] = ACTIONS(5190),
    [anon_sym_modport] = ACTIONS(5190),
    [anon_sym_assert] = ACTIONS(5190),
    [anon_sym_property] = ACTIONS(5190),
    [anon_sym_assume] = ACTIONS(5190),
    [anon_sym_cover] = ACTIONS(5190),
    [anon_sym_sequence] = ACTIONS(5190),
    [anon_sym_restrict] = ACTIONS(5190),
    [anon_sym_not] = ACTIONS(5190),
    [anon_sym_or] = ACTIONS(5190),
    [anon_sym_and] = ACTIONS(5190),
    [anon_sym_case] = ACTIONS(5190),
    [anon_sym_always] = ACTIONS(5190),
    [anon_sym_covergroup] = ACTIONS(5190),
    [anon_sym_let] = ACTIONS(5190),
    [anon_sym_pulldown] = ACTIONS(5190),
    [anon_sym_pullup] = ACTIONS(5190),
    [anon_sym_cmos] = ACTIONS(5190),
    [anon_sym_rcmos] = ACTIONS(5190),
    [anon_sym_bufif0] = ACTIONS(5190),
    [anon_sym_bufif1] = ACTIONS(5190),
    [anon_sym_notif0] = ACTIONS(5190),
    [anon_sym_notif1] = ACTIONS(5190),
    [anon_sym_nmos] = ACTIONS(5190),
    [anon_sym_pmos] = ACTIONS(5190),
    [anon_sym_rnmos] = ACTIONS(5190),
    [anon_sym_rpmos] = ACTIONS(5190),
    [anon_sym_nand] = ACTIONS(5190),
    [anon_sym_nor] = ACTIONS(5190),
    [anon_sym_xor] = ACTIONS(5190),
    [anon_sym_xnor] = ACTIONS(5190),
    [anon_sym_buf] = ACTIONS(5190),
    [anon_sym_tranif0] = ACTIONS(5190),
    [anon_sym_tranif1] = ACTIONS(5190),
    [anon_sym_rtranif1] = ACTIONS(5190),
    [anon_sym_rtranif0] = ACTIONS(5190),
    [anon_sym_tran] = ACTIONS(5190),
    [anon_sym_rtran] = ACTIONS(5190),
    [anon_sym_generate] = ACTIONS(5190),
    [anon_sym_for] = ACTIONS(5190),
    [anon_sym_primitive] = ACTIONS(5190),
    [anon_sym_initial] = ACTIONS(5190),
    [anon_sym_assign] = ACTIONS(5190),
    [anon_sym_alias] = ACTIONS(5190),
    [anon_sym_always_comb] = ACTIONS(5190),
    [anon_sym_always_latch] = ACTIONS(5190),
    [anon_sym_always_ff] = ACTIONS(5190),
    [anon_sym_final] = ACTIONS(5190),
    [anon_sym_global] = ACTIONS(5190),
    [anon_sym_specify] = ACTIONS(5190),
    [anon_sym_LPAREN_STAR] = ACTIONS(5188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5188),
    [anon_sym_DOLLARunit] = ACTIONS(5188),
  },
  [832] = {
    [ts_builtin_sym_end] = ACTIONS(5192),
    [sym_simple_identifier] = ACTIONS(5194),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5192),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5192),
    [anon_sym_BQUOTE] = ACTIONS(5194),
    [aux_sym_id_directive_token1] = ACTIONS(5192),
    [aux_sym_id_directive_token2] = ACTIONS(5192),
    [aux_sym_id_directive_token3] = ACTIONS(5192),
    [aux_sym_id_directive_token4] = ACTIONS(5194),
    [aux_sym_zero_directive_token1] = ACTIONS(5192),
    [aux_sym_zero_directive_token2] = ACTIONS(5192),
    [aux_sym_zero_directive_token3] = ACTIONS(5192),
    [aux_sym_zero_directive_token4] = ACTIONS(5192),
    [aux_sym_zero_directive_token5] = ACTIONS(5192),
    [aux_sym_zero_directive_token6] = ACTIONS(5192),
    [aux_sym_zero_directive_token7] = ACTIONS(5192),
    [aux_sym_zero_directive_token8] = ACTIONS(5192),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5192),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5192),
    [anon_sym_wire] = ACTIONS(5194),
    [anon_sym_tri] = ACTIONS(5194),
    [anon_sym_tri0] = ACTIONS(5194),
    [anon_sym_tri1] = ACTIONS(5194),
    [anon_sym_wand] = ACTIONS(5194),
    [anon_sym_triand] = ACTIONS(5194),
    [anon_sym_wor] = ACTIONS(5194),
    [anon_sym_trior] = ACTIONS(5194),
    [anon_sym_trireg] = ACTIONS(5194),
    [anon_sym_uwire] = ACTIONS(5194),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5192),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5192),
    [aux_sym_begin_keywords_token1] = ACTIONS(5192),
    [anon_sym_SEMI] = ACTIONS(5192),
    [anon_sym_endmodule] = ACTIONS(5194),
    [anon_sym_extern] = ACTIONS(5194),
    [anon_sym_module] = ACTIONS(5194),
    [anon_sym_macromodule] = ACTIONS(5194),
    [anon_sym_endinterface] = ACTIONS(5194),
    [anon_sym_interface] = ACTIONS(5194),
    [anon_sym_endprogram] = ACTIONS(5194),
    [anon_sym_program] = ACTIONS(5194),
    [anon_sym_checker] = ACTIONS(5194),
    [anon_sym_virtual] = ACTIONS(5194),
    [anon_sym_class] = ACTIONS(5194),
    [anon_sym_package] = ACTIONS(5194),
    [anon_sym_endpackage] = ACTIONS(5194),
    [anon_sym_timeunit] = ACTIONS(5194),
    [anon_sym_timeprecision] = ACTIONS(5194),
    [anon_sym_type] = ACTIONS(5194),
    [anon_sym_input] = ACTIONS(5194),
    [anon_sym_output] = ACTIONS(5194),
    [anon_sym_inout] = ACTIONS(5194),
    [anon_sym_ref] = ACTIONS(5194),
    [anon_sym_DOLLARfatal] = ACTIONS(5192),
    [anon_sym_DOLLARerror] = ACTIONS(5192),
    [anon_sym_DOLLARwarning] = ACTIONS(5192),
    [anon_sym_DOLLARinfo] = ACTIONS(5192),
    [anon_sym_default] = ACTIONS(5194),
    [anon_sym_clocking] = ACTIONS(5194),
    [anon_sym_defparam] = ACTIONS(5194),
    [anon_sym_bind] = ACTIONS(5194),
    [anon_sym_const] = ACTIONS(5194),
    [anon_sym_function] = ACTIONS(5194),
    [anon_sym_static] = ACTIONS(5194),
    [anon_sym_constraint] = ACTIONS(5194),
    [anon_sym_if] = ACTIONS(5194),
    [anon_sym_else] = ACTIONS(5194),
    [anon_sym_LBRACK] = ACTIONS(5192),
    [anon_sym_localparam] = ACTIONS(5194),
    [anon_sym_parameter] = ACTIONS(5194),
    [anon_sym_specparam] = ACTIONS(5194),
    [anon_sym_var] = ACTIONS(5194),
    [anon_sym_import] = ACTIONS(5194),
    [anon_sym_export] = ACTIONS(5194),
    [anon_sym_genvar] = ACTIONS(5194),
    [anon_sym_interconnect] = ACTIONS(5194),
    [anon_sym_typedef] = ACTIONS(5194),
    [anon_sym_enum] = ACTIONS(5194),
    [anon_sym_struct] = ACTIONS(5194),
    [anon_sym_union] = ACTIONS(5194),
    [anon_sym_nettype] = ACTIONS(5194),
    [anon_sym_automatic] = ACTIONS(5194),
    [anon_sym_string] = ACTIONS(5194),
    [anon_sym_chandle] = ACTIONS(5194),
    [anon_sym_event] = ACTIONS(5194),
    [anon_sym_byte] = ACTIONS(5194),
    [anon_sym_shortint] = ACTIONS(5194),
    [anon_sym_int] = ACTIONS(5194),
    [anon_sym_longint] = ACTIONS(5194),
    [anon_sym_integer] = ACTIONS(5194),
    [anon_sym_time] = ACTIONS(5194),
    [anon_sym_bit] = ACTIONS(5194),
    [anon_sym_logic] = ACTIONS(5194),
    [anon_sym_reg] = ACTIONS(5194),
    [anon_sym_shortreal] = ACTIONS(5194),
    [anon_sym_real] = ACTIONS(5194),
    [anon_sym_realtime] = ACTIONS(5194),
    [anon_sym_supply0] = ACTIONS(5194),
    [anon_sym_supply1] = ACTIONS(5194),
    [anon_sym_signed] = ACTIONS(5194),
    [anon_sym_unsigned] = ACTIONS(5194),
    [anon_sym_task] = ACTIONS(5194),
    [anon_sym_modport] = ACTIONS(5194),
    [anon_sym_assert] = ACTIONS(5194),
    [anon_sym_property] = ACTIONS(5194),
    [anon_sym_assume] = ACTIONS(5194),
    [anon_sym_cover] = ACTIONS(5194),
    [anon_sym_sequence] = ACTIONS(5194),
    [anon_sym_restrict] = ACTIONS(5194),
    [anon_sym_not] = ACTIONS(5194),
    [anon_sym_or] = ACTIONS(5194),
    [anon_sym_and] = ACTIONS(5194),
    [anon_sym_case] = ACTIONS(5194),
    [anon_sym_always] = ACTIONS(5194),
    [anon_sym_covergroup] = ACTIONS(5194),
    [anon_sym_let] = ACTIONS(5194),
    [anon_sym_pulldown] = ACTIONS(5194),
    [anon_sym_pullup] = ACTIONS(5194),
    [anon_sym_cmos] = ACTIONS(5194),
    [anon_sym_rcmos] = ACTIONS(5194),
    [anon_sym_bufif0] = ACTIONS(5194),
    [anon_sym_bufif1] = ACTIONS(5194),
    [anon_sym_notif0] = ACTIONS(5194),
    [anon_sym_notif1] = ACTIONS(5194),
    [anon_sym_nmos] = ACTIONS(5194),
    [anon_sym_pmos] = ACTIONS(5194),
    [anon_sym_rnmos] = ACTIONS(5194),
    [anon_sym_rpmos] = ACTIONS(5194),
    [anon_sym_nand] = ACTIONS(5194),
    [anon_sym_nor] = ACTIONS(5194),
    [anon_sym_xor] = ACTIONS(5194),
    [anon_sym_xnor] = ACTIONS(5194),
    [anon_sym_buf] = ACTIONS(5194),
    [anon_sym_tranif0] = ACTIONS(5194),
    [anon_sym_tranif1] = ACTIONS(5194),
    [anon_sym_rtranif1] = ACTIONS(5194),
    [anon_sym_rtranif0] = ACTIONS(5194),
    [anon_sym_tran] = ACTIONS(5194),
    [anon_sym_rtran] = ACTIONS(5194),
    [anon_sym_generate] = ACTIONS(5194),
    [anon_sym_for] = ACTIONS(5194),
    [anon_sym_primitive] = ACTIONS(5194),
    [anon_sym_initial] = ACTIONS(5194),
    [anon_sym_assign] = ACTIONS(5194),
    [anon_sym_alias] = ACTIONS(5194),
    [anon_sym_always_comb] = ACTIONS(5194),
    [anon_sym_always_latch] = ACTIONS(5194),
    [anon_sym_always_ff] = ACTIONS(5194),
    [anon_sym_final] = ACTIONS(5194),
    [anon_sym_global] = ACTIONS(5194),
    [anon_sym_specify] = ACTIONS(5194),
    [anon_sym_LPAREN_STAR] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5192),
    [anon_sym_DOLLARunit] = ACTIONS(5192),
  },
  [833] = {
    [ts_builtin_sym_end] = ACTIONS(5196),
    [sym_simple_identifier] = ACTIONS(5198),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5196),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5196),
    [anon_sym_BQUOTE] = ACTIONS(5198),
    [aux_sym_id_directive_token1] = ACTIONS(5196),
    [aux_sym_id_directive_token2] = ACTIONS(5196),
    [aux_sym_id_directive_token3] = ACTIONS(5196),
    [aux_sym_id_directive_token4] = ACTIONS(5198),
    [aux_sym_zero_directive_token1] = ACTIONS(5196),
    [aux_sym_zero_directive_token2] = ACTIONS(5196),
    [aux_sym_zero_directive_token3] = ACTIONS(5196),
    [aux_sym_zero_directive_token4] = ACTIONS(5196),
    [aux_sym_zero_directive_token5] = ACTIONS(5196),
    [aux_sym_zero_directive_token6] = ACTIONS(5196),
    [aux_sym_zero_directive_token7] = ACTIONS(5196),
    [aux_sym_zero_directive_token8] = ACTIONS(5196),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5196),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5196),
    [anon_sym_wire] = ACTIONS(5198),
    [anon_sym_tri] = ACTIONS(5198),
    [anon_sym_tri0] = ACTIONS(5198),
    [anon_sym_tri1] = ACTIONS(5198),
    [anon_sym_wand] = ACTIONS(5198),
    [anon_sym_triand] = ACTIONS(5198),
    [anon_sym_wor] = ACTIONS(5198),
    [anon_sym_trior] = ACTIONS(5198),
    [anon_sym_trireg] = ACTIONS(5198),
    [anon_sym_uwire] = ACTIONS(5198),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5196),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5196),
    [aux_sym_begin_keywords_token1] = ACTIONS(5196),
    [anon_sym_SEMI] = ACTIONS(5196),
    [anon_sym_endmodule] = ACTIONS(5198),
    [anon_sym_extern] = ACTIONS(5198),
    [anon_sym_module] = ACTIONS(5198),
    [anon_sym_macromodule] = ACTIONS(5198),
    [anon_sym_endinterface] = ACTIONS(5198),
    [anon_sym_interface] = ACTIONS(5198),
    [anon_sym_endprogram] = ACTIONS(5198),
    [anon_sym_program] = ACTIONS(5198),
    [anon_sym_checker] = ACTIONS(5198),
    [anon_sym_virtual] = ACTIONS(5198),
    [anon_sym_class] = ACTIONS(5198),
    [anon_sym_package] = ACTIONS(5198),
    [anon_sym_endpackage] = ACTIONS(5198),
    [anon_sym_timeunit] = ACTIONS(5198),
    [anon_sym_timeprecision] = ACTIONS(5198),
    [anon_sym_type] = ACTIONS(5198),
    [anon_sym_input] = ACTIONS(5198),
    [anon_sym_output] = ACTIONS(5198),
    [anon_sym_inout] = ACTIONS(5198),
    [anon_sym_ref] = ACTIONS(5198),
    [anon_sym_DOLLARfatal] = ACTIONS(5196),
    [anon_sym_DOLLARerror] = ACTIONS(5196),
    [anon_sym_DOLLARwarning] = ACTIONS(5196),
    [anon_sym_DOLLARinfo] = ACTIONS(5196),
    [anon_sym_default] = ACTIONS(5198),
    [anon_sym_clocking] = ACTIONS(5198),
    [anon_sym_defparam] = ACTIONS(5198),
    [anon_sym_bind] = ACTIONS(5198),
    [anon_sym_const] = ACTIONS(5198),
    [anon_sym_function] = ACTIONS(5198),
    [anon_sym_static] = ACTIONS(5198),
    [anon_sym_constraint] = ACTIONS(5198),
    [anon_sym_if] = ACTIONS(5198),
    [anon_sym_else] = ACTIONS(5198),
    [anon_sym_LBRACK] = ACTIONS(5196),
    [anon_sym_localparam] = ACTIONS(5198),
    [anon_sym_parameter] = ACTIONS(5198),
    [anon_sym_specparam] = ACTIONS(5198),
    [anon_sym_var] = ACTIONS(5198),
    [anon_sym_import] = ACTIONS(5198),
    [anon_sym_export] = ACTIONS(5198),
    [anon_sym_genvar] = ACTIONS(5198),
    [anon_sym_interconnect] = ACTIONS(5198),
    [anon_sym_typedef] = ACTIONS(5198),
    [anon_sym_enum] = ACTIONS(5198),
    [anon_sym_struct] = ACTIONS(5198),
    [anon_sym_union] = ACTIONS(5198),
    [anon_sym_nettype] = ACTIONS(5198),
    [anon_sym_automatic] = ACTIONS(5198),
    [anon_sym_string] = ACTIONS(5198),
    [anon_sym_chandle] = ACTIONS(5198),
    [anon_sym_event] = ACTIONS(5198),
    [anon_sym_byte] = ACTIONS(5198),
    [anon_sym_shortint] = ACTIONS(5198),
    [anon_sym_int] = ACTIONS(5198),
    [anon_sym_longint] = ACTIONS(5198),
    [anon_sym_integer] = ACTIONS(5198),
    [anon_sym_time] = ACTIONS(5198),
    [anon_sym_bit] = ACTIONS(5198),
    [anon_sym_logic] = ACTIONS(5198),
    [anon_sym_reg] = ACTIONS(5198),
    [anon_sym_shortreal] = ACTIONS(5198),
    [anon_sym_real] = ACTIONS(5198),
    [anon_sym_realtime] = ACTIONS(5198),
    [anon_sym_supply0] = ACTIONS(5198),
    [anon_sym_supply1] = ACTIONS(5198),
    [anon_sym_signed] = ACTIONS(5198),
    [anon_sym_unsigned] = ACTIONS(5198),
    [anon_sym_task] = ACTIONS(5198),
    [anon_sym_modport] = ACTIONS(5198),
    [anon_sym_assert] = ACTIONS(5198),
    [anon_sym_property] = ACTIONS(5198),
    [anon_sym_assume] = ACTIONS(5198),
    [anon_sym_cover] = ACTIONS(5198),
    [anon_sym_sequence] = ACTIONS(5198),
    [anon_sym_restrict] = ACTIONS(5198),
    [anon_sym_not] = ACTIONS(5198),
    [anon_sym_or] = ACTIONS(5198),
    [anon_sym_and] = ACTIONS(5198),
    [anon_sym_case] = ACTIONS(5198),
    [anon_sym_always] = ACTIONS(5198),
    [anon_sym_covergroup] = ACTIONS(5198),
    [anon_sym_let] = ACTIONS(5198),
    [anon_sym_pulldown] = ACTIONS(5198),
    [anon_sym_pullup] = ACTIONS(5198),
    [anon_sym_cmos] = ACTIONS(5198),
    [anon_sym_rcmos] = ACTIONS(5198),
    [anon_sym_bufif0] = ACTIONS(5198),
    [anon_sym_bufif1] = ACTIONS(5198),
    [anon_sym_notif0] = ACTIONS(5198),
    [anon_sym_notif1] = ACTIONS(5198),
    [anon_sym_nmos] = ACTIONS(5198),
    [anon_sym_pmos] = ACTIONS(5198),
    [anon_sym_rnmos] = ACTIONS(5198),
    [anon_sym_rpmos] = ACTIONS(5198),
    [anon_sym_nand] = ACTIONS(5198),
    [anon_sym_nor] = ACTIONS(5198),
    [anon_sym_xor] = ACTIONS(5198),
    [anon_sym_xnor] = ACTIONS(5198),
    [anon_sym_buf] = ACTIONS(5198),
    [anon_sym_tranif0] = ACTIONS(5198),
    [anon_sym_tranif1] = ACTIONS(5198),
    [anon_sym_rtranif1] = ACTIONS(5198),
    [anon_sym_rtranif0] = ACTIONS(5198),
    [anon_sym_tran] = ACTIONS(5198),
    [anon_sym_rtran] = ACTIONS(5198),
    [anon_sym_generate] = ACTIONS(5198),
    [anon_sym_for] = ACTIONS(5198),
    [anon_sym_primitive] = ACTIONS(5198),
    [anon_sym_initial] = ACTIONS(5198),
    [anon_sym_assign] = ACTIONS(5198),
    [anon_sym_alias] = ACTIONS(5198),
    [anon_sym_always_comb] = ACTIONS(5198),
    [anon_sym_always_latch] = ACTIONS(5198),
    [anon_sym_always_ff] = ACTIONS(5198),
    [anon_sym_final] = ACTIONS(5198),
    [anon_sym_global] = ACTIONS(5198),
    [anon_sym_specify] = ACTIONS(5198),
    [anon_sym_LPAREN_STAR] = ACTIONS(5196),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5196),
    [anon_sym_DOLLARunit] = ACTIONS(5196),
  },
  [834] = {
    [ts_builtin_sym_end] = ACTIONS(5200),
    [sym_simple_identifier] = ACTIONS(5202),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5200),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5200),
    [anon_sym_BQUOTE] = ACTIONS(5202),
    [aux_sym_id_directive_token1] = ACTIONS(5200),
    [aux_sym_id_directive_token2] = ACTIONS(5200),
    [aux_sym_id_directive_token3] = ACTIONS(5200),
    [aux_sym_id_directive_token4] = ACTIONS(5202),
    [aux_sym_zero_directive_token1] = ACTIONS(5200),
    [aux_sym_zero_directive_token2] = ACTIONS(5200),
    [aux_sym_zero_directive_token3] = ACTIONS(5200),
    [aux_sym_zero_directive_token4] = ACTIONS(5200),
    [aux_sym_zero_directive_token5] = ACTIONS(5200),
    [aux_sym_zero_directive_token6] = ACTIONS(5200),
    [aux_sym_zero_directive_token7] = ACTIONS(5200),
    [aux_sym_zero_directive_token8] = ACTIONS(5200),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5200),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5200),
    [anon_sym_wire] = ACTIONS(5202),
    [anon_sym_tri] = ACTIONS(5202),
    [anon_sym_tri0] = ACTIONS(5202),
    [anon_sym_tri1] = ACTIONS(5202),
    [anon_sym_wand] = ACTIONS(5202),
    [anon_sym_triand] = ACTIONS(5202),
    [anon_sym_wor] = ACTIONS(5202),
    [anon_sym_trior] = ACTIONS(5202),
    [anon_sym_trireg] = ACTIONS(5202),
    [anon_sym_uwire] = ACTIONS(5202),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5200),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5200),
    [aux_sym_begin_keywords_token1] = ACTIONS(5200),
    [anon_sym_SEMI] = ACTIONS(5200),
    [anon_sym_endmodule] = ACTIONS(5202),
    [anon_sym_extern] = ACTIONS(5202),
    [anon_sym_module] = ACTIONS(5202),
    [anon_sym_macromodule] = ACTIONS(5202),
    [anon_sym_endinterface] = ACTIONS(5202),
    [anon_sym_interface] = ACTIONS(5202),
    [anon_sym_endprogram] = ACTIONS(5202),
    [anon_sym_program] = ACTIONS(5202),
    [anon_sym_checker] = ACTIONS(5202),
    [anon_sym_virtual] = ACTIONS(5202),
    [anon_sym_class] = ACTIONS(5202),
    [anon_sym_package] = ACTIONS(5202),
    [anon_sym_endpackage] = ACTIONS(5202),
    [anon_sym_timeunit] = ACTIONS(5202),
    [anon_sym_timeprecision] = ACTIONS(5202),
    [anon_sym_type] = ACTIONS(5202),
    [anon_sym_input] = ACTIONS(5202),
    [anon_sym_output] = ACTIONS(5202),
    [anon_sym_inout] = ACTIONS(5202),
    [anon_sym_ref] = ACTIONS(5202),
    [anon_sym_DOLLARfatal] = ACTIONS(5200),
    [anon_sym_DOLLARerror] = ACTIONS(5200),
    [anon_sym_DOLLARwarning] = ACTIONS(5200),
    [anon_sym_DOLLARinfo] = ACTIONS(5200),
    [anon_sym_default] = ACTIONS(5202),
    [anon_sym_clocking] = ACTIONS(5202),
    [anon_sym_defparam] = ACTIONS(5202),
    [anon_sym_bind] = ACTIONS(5202),
    [anon_sym_const] = ACTIONS(5202),
    [anon_sym_function] = ACTIONS(5202),
    [anon_sym_static] = ACTIONS(5202),
    [anon_sym_constraint] = ACTIONS(5202),
    [anon_sym_if] = ACTIONS(5202),
    [anon_sym_else] = ACTIONS(5202),
    [anon_sym_LBRACK] = ACTIONS(5200),
    [anon_sym_localparam] = ACTIONS(5202),
    [anon_sym_parameter] = ACTIONS(5202),
    [anon_sym_specparam] = ACTIONS(5202),
    [anon_sym_var] = ACTIONS(5202),
    [anon_sym_import] = ACTIONS(5202),
    [anon_sym_export] = ACTIONS(5202),
    [anon_sym_genvar] = ACTIONS(5202),
    [anon_sym_interconnect] = ACTIONS(5202),
    [anon_sym_typedef] = ACTIONS(5202),
    [anon_sym_enum] = ACTIONS(5202),
    [anon_sym_struct] = ACTIONS(5202),
    [anon_sym_union] = ACTIONS(5202),
    [anon_sym_nettype] = ACTIONS(5202),
    [anon_sym_automatic] = ACTIONS(5202),
    [anon_sym_string] = ACTIONS(5202),
    [anon_sym_chandle] = ACTIONS(5202),
    [anon_sym_event] = ACTIONS(5202),
    [anon_sym_byte] = ACTIONS(5202),
    [anon_sym_shortint] = ACTIONS(5202),
    [anon_sym_int] = ACTIONS(5202),
    [anon_sym_longint] = ACTIONS(5202),
    [anon_sym_integer] = ACTIONS(5202),
    [anon_sym_time] = ACTIONS(5202),
    [anon_sym_bit] = ACTIONS(5202),
    [anon_sym_logic] = ACTIONS(5202),
    [anon_sym_reg] = ACTIONS(5202),
    [anon_sym_shortreal] = ACTIONS(5202),
    [anon_sym_real] = ACTIONS(5202),
    [anon_sym_realtime] = ACTIONS(5202),
    [anon_sym_supply0] = ACTIONS(5202),
    [anon_sym_supply1] = ACTIONS(5202),
    [anon_sym_signed] = ACTIONS(5202),
    [anon_sym_unsigned] = ACTIONS(5202),
    [anon_sym_task] = ACTIONS(5202),
    [anon_sym_modport] = ACTIONS(5202),
    [anon_sym_assert] = ACTIONS(5202),
    [anon_sym_property] = ACTIONS(5202),
    [anon_sym_assume] = ACTIONS(5202),
    [anon_sym_cover] = ACTIONS(5202),
    [anon_sym_sequence] = ACTIONS(5202),
    [anon_sym_restrict] = ACTIONS(5202),
    [anon_sym_not] = ACTIONS(5202),
    [anon_sym_or] = ACTIONS(5202),
    [anon_sym_and] = ACTIONS(5202),
    [anon_sym_case] = ACTIONS(5202),
    [anon_sym_always] = ACTIONS(5202),
    [anon_sym_covergroup] = ACTIONS(5202),
    [anon_sym_let] = ACTIONS(5202),
    [anon_sym_pulldown] = ACTIONS(5202),
    [anon_sym_pullup] = ACTIONS(5202),
    [anon_sym_cmos] = ACTIONS(5202),
    [anon_sym_rcmos] = ACTIONS(5202),
    [anon_sym_bufif0] = ACTIONS(5202),
    [anon_sym_bufif1] = ACTIONS(5202),
    [anon_sym_notif0] = ACTIONS(5202),
    [anon_sym_notif1] = ACTIONS(5202),
    [anon_sym_nmos] = ACTIONS(5202),
    [anon_sym_pmos] = ACTIONS(5202),
    [anon_sym_rnmos] = ACTIONS(5202),
    [anon_sym_rpmos] = ACTIONS(5202),
    [anon_sym_nand] = ACTIONS(5202),
    [anon_sym_nor] = ACTIONS(5202),
    [anon_sym_xor] = ACTIONS(5202),
    [anon_sym_xnor] = ACTIONS(5202),
    [anon_sym_buf] = ACTIONS(5202),
    [anon_sym_tranif0] = ACTIONS(5202),
    [anon_sym_tranif1] = ACTIONS(5202),
    [anon_sym_rtranif1] = ACTIONS(5202),
    [anon_sym_rtranif0] = ACTIONS(5202),
    [anon_sym_tran] = ACTIONS(5202),
    [anon_sym_rtran] = ACTIONS(5202),
    [anon_sym_generate] = ACTIONS(5202),
    [anon_sym_for] = ACTIONS(5202),
    [anon_sym_primitive] = ACTIONS(5202),
    [anon_sym_initial] = ACTIONS(5202),
    [anon_sym_assign] = ACTIONS(5202),
    [anon_sym_alias] = ACTIONS(5202),
    [anon_sym_always_comb] = ACTIONS(5202),
    [anon_sym_always_latch] = ACTIONS(5202),
    [anon_sym_always_ff] = ACTIONS(5202),
    [anon_sym_final] = ACTIONS(5202),
    [anon_sym_global] = ACTIONS(5202),
    [anon_sym_specify] = ACTIONS(5202),
    [anon_sym_LPAREN_STAR] = ACTIONS(5200),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5200),
    [anon_sym_DOLLARunit] = ACTIONS(5200),
  },
  [835] = {
    [ts_builtin_sym_end] = ACTIONS(4634),
    [sym_simple_identifier] = ACTIONS(4636),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4634),
    [anon_sym_BQUOTE] = ACTIONS(4636),
    [aux_sym_id_directive_token1] = ACTIONS(4634),
    [aux_sym_id_directive_token2] = ACTIONS(4634),
    [aux_sym_id_directive_token3] = ACTIONS(4634),
    [aux_sym_id_directive_token4] = ACTIONS(4636),
    [aux_sym_zero_directive_token1] = ACTIONS(4634),
    [aux_sym_zero_directive_token2] = ACTIONS(4634),
    [aux_sym_zero_directive_token3] = ACTIONS(4634),
    [aux_sym_zero_directive_token4] = ACTIONS(4634),
    [aux_sym_zero_directive_token5] = ACTIONS(4634),
    [aux_sym_zero_directive_token6] = ACTIONS(4634),
    [aux_sym_zero_directive_token7] = ACTIONS(4634),
    [aux_sym_zero_directive_token8] = ACTIONS(4634),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4634),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4634),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4634),
    [aux_sym_begin_keywords_token1] = ACTIONS(4634),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_endmodule] = ACTIONS(4636),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_module] = ACTIONS(4636),
    [anon_sym_macromodule] = ACTIONS(4636),
    [anon_sym_endinterface] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_endprogram] = ACTIONS(4636),
    [anon_sym_program] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_package] = ACTIONS(4636),
    [anon_sym_endpackage] = ACTIONS(4636),
    [anon_sym_timeunit] = ACTIONS(4636),
    [anon_sym_timeprecision] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_input] = ACTIONS(4636),
    [anon_sym_output] = ACTIONS(4636),
    [anon_sym_inout] = ACTIONS(4636),
    [anon_sym_ref] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_specparam] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_modport] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_primitive] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_specify] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [836] = {
    [ts_builtin_sym_end] = ACTIONS(5204),
    [sym_simple_identifier] = ACTIONS(5206),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5204),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5204),
    [anon_sym_BQUOTE] = ACTIONS(5206),
    [aux_sym_id_directive_token1] = ACTIONS(5204),
    [aux_sym_id_directive_token2] = ACTIONS(5204),
    [aux_sym_id_directive_token3] = ACTIONS(5204),
    [aux_sym_id_directive_token4] = ACTIONS(5206),
    [aux_sym_zero_directive_token1] = ACTIONS(5204),
    [aux_sym_zero_directive_token2] = ACTIONS(5204),
    [aux_sym_zero_directive_token3] = ACTIONS(5204),
    [aux_sym_zero_directive_token4] = ACTIONS(5204),
    [aux_sym_zero_directive_token5] = ACTIONS(5204),
    [aux_sym_zero_directive_token6] = ACTIONS(5204),
    [aux_sym_zero_directive_token7] = ACTIONS(5204),
    [aux_sym_zero_directive_token8] = ACTIONS(5204),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5204),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5204),
    [anon_sym_wire] = ACTIONS(5206),
    [anon_sym_tri] = ACTIONS(5206),
    [anon_sym_tri0] = ACTIONS(5206),
    [anon_sym_tri1] = ACTIONS(5206),
    [anon_sym_wand] = ACTIONS(5206),
    [anon_sym_triand] = ACTIONS(5206),
    [anon_sym_wor] = ACTIONS(5206),
    [anon_sym_trior] = ACTIONS(5206),
    [anon_sym_trireg] = ACTIONS(5206),
    [anon_sym_uwire] = ACTIONS(5206),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5204),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5204),
    [aux_sym_begin_keywords_token1] = ACTIONS(5204),
    [anon_sym_SEMI] = ACTIONS(5204),
    [anon_sym_endmodule] = ACTIONS(5206),
    [anon_sym_extern] = ACTIONS(5206),
    [anon_sym_module] = ACTIONS(5206),
    [anon_sym_macromodule] = ACTIONS(5206),
    [anon_sym_endinterface] = ACTIONS(5206),
    [anon_sym_interface] = ACTIONS(5206),
    [anon_sym_endprogram] = ACTIONS(5206),
    [anon_sym_program] = ACTIONS(5206),
    [anon_sym_checker] = ACTIONS(5206),
    [anon_sym_virtual] = ACTIONS(5206),
    [anon_sym_class] = ACTIONS(5206),
    [anon_sym_package] = ACTIONS(5206),
    [anon_sym_endpackage] = ACTIONS(5206),
    [anon_sym_timeunit] = ACTIONS(5206),
    [anon_sym_timeprecision] = ACTIONS(5206),
    [anon_sym_type] = ACTIONS(5206),
    [anon_sym_input] = ACTIONS(5206),
    [anon_sym_output] = ACTIONS(5206),
    [anon_sym_inout] = ACTIONS(5206),
    [anon_sym_ref] = ACTIONS(5206),
    [anon_sym_DOLLARfatal] = ACTIONS(5204),
    [anon_sym_DOLLARerror] = ACTIONS(5204),
    [anon_sym_DOLLARwarning] = ACTIONS(5204),
    [anon_sym_DOLLARinfo] = ACTIONS(5204),
    [anon_sym_default] = ACTIONS(5206),
    [anon_sym_clocking] = ACTIONS(5206),
    [anon_sym_defparam] = ACTIONS(5206),
    [anon_sym_bind] = ACTIONS(5206),
    [anon_sym_const] = ACTIONS(5206),
    [anon_sym_function] = ACTIONS(5206),
    [anon_sym_static] = ACTIONS(5206),
    [anon_sym_constraint] = ACTIONS(5206),
    [anon_sym_if] = ACTIONS(5206),
    [anon_sym_else] = ACTIONS(5206),
    [anon_sym_LBRACK] = ACTIONS(5204),
    [anon_sym_localparam] = ACTIONS(5206),
    [anon_sym_parameter] = ACTIONS(5206),
    [anon_sym_specparam] = ACTIONS(5206),
    [anon_sym_var] = ACTIONS(5206),
    [anon_sym_import] = ACTIONS(5206),
    [anon_sym_export] = ACTIONS(5206),
    [anon_sym_genvar] = ACTIONS(5206),
    [anon_sym_interconnect] = ACTIONS(5206),
    [anon_sym_typedef] = ACTIONS(5206),
    [anon_sym_enum] = ACTIONS(5206),
    [anon_sym_struct] = ACTIONS(5206),
    [anon_sym_union] = ACTIONS(5206),
    [anon_sym_nettype] = ACTIONS(5206),
    [anon_sym_automatic] = ACTIONS(5206),
    [anon_sym_string] = ACTIONS(5206),
    [anon_sym_chandle] = ACTIONS(5206),
    [anon_sym_event] = ACTIONS(5206),
    [anon_sym_byte] = ACTIONS(5206),
    [anon_sym_shortint] = ACTIONS(5206),
    [anon_sym_int] = ACTIONS(5206),
    [anon_sym_longint] = ACTIONS(5206),
    [anon_sym_integer] = ACTIONS(5206),
    [anon_sym_time] = ACTIONS(5206),
    [anon_sym_bit] = ACTIONS(5206),
    [anon_sym_logic] = ACTIONS(5206),
    [anon_sym_reg] = ACTIONS(5206),
    [anon_sym_shortreal] = ACTIONS(5206),
    [anon_sym_real] = ACTIONS(5206),
    [anon_sym_realtime] = ACTIONS(5206),
    [anon_sym_supply0] = ACTIONS(5206),
    [anon_sym_supply1] = ACTIONS(5206),
    [anon_sym_signed] = ACTIONS(5206),
    [anon_sym_unsigned] = ACTIONS(5206),
    [anon_sym_task] = ACTIONS(5206),
    [anon_sym_modport] = ACTIONS(5206),
    [anon_sym_assert] = ACTIONS(5206),
    [anon_sym_property] = ACTIONS(5206),
    [anon_sym_assume] = ACTIONS(5206),
    [anon_sym_cover] = ACTIONS(5206),
    [anon_sym_sequence] = ACTIONS(5206),
    [anon_sym_restrict] = ACTIONS(5206),
    [anon_sym_not] = ACTIONS(5206),
    [anon_sym_or] = ACTIONS(5206),
    [anon_sym_and] = ACTIONS(5206),
    [anon_sym_case] = ACTIONS(5206),
    [anon_sym_always] = ACTIONS(5206),
    [anon_sym_covergroup] = ACTIONS(5206),
    [anon_sym_let] = ACTIONS(5206),
    [anon_sym_pulldown] = ACTIONS(5206),
    [anon_sym_pullup] = ACTIONS(5206),
    [anon_sym_cmos] = ACTIONS(5206),
    [anon_sym_rcmos] = ACTIONS(5206),
    [anon_sym_bufif0] = ACTIONS(5206),
    [anon_sym_bufif1] = ACTIONS(5206),
    [anon_sym_notif0] = ACTIONS(5206),
    [anon_sym_notif1] = ACTIONS(5206),
    [anon_sym_nmos] = ACTIONS(5206),
    [anon_sym_pmos] = ACTIONS(5206),
    [anon_sym_rnmos] = ACTIONS(5206),
    [anon_sym_rpmos] = ACTIONS(5206),
    [anon_sym_nand] = ACTIONS(5206),
    [anon_sym_nor] = ACTIONS(5206),
    [anon_sym_xor] = ACTIONS(5206),
    [anon_sym_xnor] = ACTIONS(5206),
    [anon_sym_buf] = ACTIONS(5206),
    [anon_sym_tranif0] = ACTIONS(5206),
    [anon_sym_tranif1] = ACTIONS(5206),
    [anon_sym_rtranif1] = ACTIONS(5206),
    [anon_sym_rtranif0] = ACTIONS(5206),
    [anon_sym_tran] = ACTIONS(5206),
    [anon_sym_rtran] = ACTIONS(5206),
    [anon_sym_generate] = ACTIONS(5206),
    [anon_sym_for] = ACTIONS(5206),
    [anon_sym_primitive] = ACTIONS(5206),
    [anon_sym_initial] = ACTIONS(5206),
    [anon_sym_assign] = ACTIONS(5206),
    [anon_sym_alias] = ACTIONS(5206),
    [anon_sym_always_comb] = ACTIONS(5206),
    [anon_sym_always_latch] = ACTIONS(5206),
    [anon_sym_always_ff] = ACTIONS(5206),
    [anon_sym_final] = ACTIONS(5206),
    [anon_sym_global] = ACTIONS(5206),
    [anon_sym_specify] = ACTIONS(5206),
    [anon_sym_LPAREN_STAR] = ACTIONS(5204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5204),
    [anon_sym_DOLLARunit] = ACTIONS(5204),
  },
  [837] = {
    [ts_builtin_sym_end] = ACTIONS(5208),
    [sym_simple_identifier] = ACTIONS(5210),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5208),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5208),
    [anon_sym_BQUOTE] = ACTIONS(5210),
    [aux_sym_id_directive_token1] = ACTIONS(5208),
    [aux_sym_id_directive_token2] = ACTIONS(5208),
    [aux_sym_id_directive_token3] = ACTIONS(5208),
    [aux_sym_id_directive_token4] = ACTIONS(5210),
    [aux_sym_zero_directive_token1] = ACTIONS(5208),
    [aux_sym_zero_directive_token2] = ACTIONS(5208),
    [aux_sym_zero_directive_token3] = ACTIONS(5208),
    [aux_sym_zero_directive_token4] = ACTIONS(5208),
    [aux_sym_zero_directive_token5] = ACTIONS(5208),
    [aux_sym_zero_directive_token6] = ACTIONS(5208),
    [aux_sym_zero_directive_token7] = ACTIONS(5208),
    [aux_sym_zero_directive_token8] = ACTIONS(5208),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5208),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5208),
    [anon_sym_wire] = ACTIONS(5210),
    [anon_sym_tri] = ACTIONS(5210),
    [anon_sym_tri0] = ACTIONS(5210),
    [anon_sym_tri1] = ACTIONS(5210),
    [anon_sym_wand] = ACTIONS(5210),
    [anon_sym_triand] = ACTIONS(5210),
    [anon_sym_wor] = ACTIONS(5210),
    [anon_sym_trior] = ACTIONS(5210),
    [anon_sym_trireg] = ACTIONS(5210),
    [anon_sym_uwire] = ACTIONS(5210),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5208),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5208),
    [aux_sym_begin_keywords_token1] = ACTIONS(5208),
    [anon_sym_SEMI] = ACTIONS(5208),
    [anon_sym_endmodule] = ACTIONS(5210),
    [anon_sym_extern] = ACTIONS(5210),
    [anon_sym_module] = ACTIONS(5210),
    [anon_sym_macromodule] = ACTIONS(5210),
    [anon_sym_endinterface] = ACTIONS(5210),
    [anon_sym_interface] = ACTIONS(5210),
    [anon_sym_endprogram] = ACTIONS(5210),
    [anon_sym_program] = ACTIONS(5210),
    [anon_sym_checker] = ACTIONS(5210),
    [anon_sym_virtual] = ACTIONS(5210),
    [anon_sym_class] = ACTIONS(5210),
    [anon_sym_package] = ACTIONS(5210),
    [anon_sym_endpackage] = ACTIONS(5210),
    [anon_sym_timeunit] = ACTIONS(5210),
    [anon_sym_timeprecision] = ACTIONS(5210),
    [anon_sym_type] = ACTIONS(5210),
    [anon_sym_input] = ACTIONS(5210),
    [anon_sym_output] = ACTIONS(5210),
    [anon_sym_inout] = ACTIONS(5210),
    [anon_sym_ref] = ACTIONS(5210),
    [anon_sym_DOLLARfatal] = ACTIONS(5208),
    [anon_sym_DOLLARerror] = ACTIONS(5208),
    [anon_sym_DOLLARwarning] = ACTIONS(5208),
    [anon_sym_DOLLARinfo] = ACTIONS(5208),
    [anon_sym_default] = ACTIONS(5210),
    [anon_sym_clocking] = ACTIONS(5210),
    [anon_sym_defparam] = ACTIONS(5210),
    [anon_sym_bind] = ACTIONS(5210),
    [anon_sym_const] = ACTIONS(5210),
    [anon_sym_function] = ACTIONS(5210),
    [anon_sym_static] = ACTIONS(5210),
    [anon_sym_constraint] = ACTIONS(5210),
    [anon_sym_if] = ACTIONS(5210),
    [anon_sym_else] = ACTIONS(5210),
    [anon_sym_LBRACK] = ACTIONS(5208),
    [anon_sym_localparam] = ACTIONS(5210),
    [anon_sym_parameter] = ACTIONS(5210),
    [anon_sym_specparam] = ACTIONS(5210),
    [anon_sym_var] = ACTIONS(5210),
    [anon_sym_import] = ACTIONS(5210),
    [anon_sym_export] = ACTIONS(5210),
    [anon_sym_genvar] = ACTIONS(5210),
    [anon_sym_interconnect] = ACTIONS(5210),
    [anon_sym_typedef] = ACTIONS(5210),
    [anon_sym_enum] = ACTIONS(5210),
    [anon_sym_struct] = ACTIONS(5210),
    [anon_sym_union] = ACTIONS(5210),
    [anon_sym_nettype] = ACTIONS(5210),
    [anon_sym_automatic] = ACTIONS(5210),
    [anon_sym_string] = ACTIONS(5210),
    [anon_sym_chandle] = ACTIONS(5210),
    [anon_sym_event] = ACTIONS(5210),
    [anon_sym_byte] = ACTIONS(5210),
    [anon_sym_shortint] = ACTIONS(5210),
    [anon_sym_int] = ACTIONS(5210),
    [anon_sym_longint] = ACTIONS(5210),
    [anon_sym_integer] = ACTIONS(5210),
    [anon_sym_time] = ACTIONS(5210),
    [anon_sym_bit] = ACTIONS(5210),
    [anon_sym_logic] = ACTIONS(5210),
    [anon_sym_reg] = ACTIONS(5210),
    [anon_sym_shortreal] = ACTIONS(5210),
    [anon_sym_real] = ACTIONS(5210),
    [anon_sym_realtime] = ACTIONS(5210),
    [anon_sym_supply0] = ACTIONS(5210),
    [anon_sym_supply1] = ACTIONS(5210),
    [anon_sym_signed] = ACTIONS(5210),
    [anon_sym_unsigned] = ACTIONS(5210),
    [anon_sym_task] = ACTIONS(5210),
    [anon_sym_modport] = ACTIONS(5210),
    [anon_sym_assert] = ACTIONS(5210),
    [anon_sym_property] = ACTIONS(5210),
    [anon_sym_assume] = ACTIONS(5210),
    [anon_sym_cover] = ACTIONS(5210),
    [anon_sym_sequence] = ACTIONS(5210),
    [anon_sym_restrict] = ACTIONS(5210),
    [anon_sym_not] = ACTIONS(5210),
    [anon_sym_or] = ACTIONS(5210),
    [anon_sym_and] = ACTIONS(5210),
    [anon_sym_case] = ACTIONS(5210),
    [anon_sym_always] = ACTIONS(5210),
    [anon_sym_covergroup] = ACTIONS(5210),
    [anon_sym_let] = ACTIONS(5210),
    [anon_sym_pulldown] = ACTIONS(5210),
    [anon_sym_pullup] = ACTIONS(5210),
    [anon_sym_cmos] = ACTIONS(5210),
    [anon_sym_rcmos] = ACTIONS(5210),
    [anon_sym_bufif0] = ACTIONS(5210),
    [anon_sym_bufif1] = ACTIONS(5210),
    [anon_sym_notif0] = ACTIONS(5210),
    [anon_sym_notif1] = ACTIONS(5210),
    [anon_sym_nmos] = ACTIONS(5210),
    [anon_sym_pmos] = ACTIONS(5210),
    [anon_sym_rnmos] = ACTIONS(5210),
    [anon_sym_rpmos] = ACTIONS(5210),
    [anon_sym_nand] = ACTIONS(5210),
    [anon_sym_nor] = ACTIONS(5210),
    [anon_sym_xor] = ACTIONS(5210),
    [anon_sym_xnor] = ACTIONS(5210),
    [anon_sym_buf] = ACTIONS(5210),
    [anon_sym_tranif0] = ACTIONS(5210),
    [anon_sym_tranif1] = ACTIONS(5210),
    [anon_sym_rtranif1] = ACTIONS(5210),
    [anon_sym_rtranif0] = ACTIONS(5210),
    [anon_sym_tran] = ACTIONS(5210),
    [anon_sym_rtran] = ACTIONS(5210),
    [anon_sym_generate] = ACTIONS(5210),
    [anon_sym_for] = ACTIONS(5210),
    [anon_sym_primitive] = ACTIONS(5210),
    [anon_sym_initial] = ACTIONS(5210),
    [anon_sym_assign] = ACTIONS(5210),
    [anon_sym_alias] = ACTIONS(5210),
    [anon_sym_always_comb] = ACTIONS(5210),
    [anon_sym_always_latch] = ACTIONS(5210),
    [anon_sym_always_ff] = ACTIONS(5210),
    [anon_sym_final] = ACTIONS(5210),
    [anon_sym_global] = ACTIONS(5210),
    [anon_sym_specify] = ACTIONS(5210),
    [anon_sym_LPAREN_STAR] = ACTIONS(5208),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5208),
    [anon_sym_DOLLARunit] = ACTIONS(5208),
  },
  [838] = {
    [ts_builtin_sym_end] = ACTIONS(5212),
    [sym_simple_identifier] = ACTIONS(5214),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5212),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5212),
    [anon_sym_BQUOTE] = ACTIONS(5214),
    [aux_sym_id_directive_token1] = ACTIONS(5212),
    [aux_sym_id_directive_token2] = ACTIONS(5212),
    [aux_sym_id_directive_token3] = ACTIONS(5212),
    [aux_sym_id_directive_token4] = ACTIONS(5214),
    [aux_sym_zero_directive_token1] = ACTIONS(5212),
    [aux_sym_zero_directive_token2] = ACTIONS(5212),
    [aux_sym_zero_directive_token3] = ACTIONS(5212),
    [aux_sym_zero_directive_token4] = ACTIONS(5212),
    [aux_sym_zero_directive_token5] = ACTIONS(5212),
    [aux_sym_zero_directive_token6] = ACTIONS(5212),
    [aux_sym_zero_directive_token7] = ACTIONS(5212),
    [aux_sym_zero_directive_token8] = ACTIONS(5212),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5212),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5212),
    [anon_sym_wire] = ACTIONS(5214),
    [anon_sym_tri] = ACTIONS(5214),
    [anon_sym_tri0] = ACTIONS(5214),
    [anon_sym_tri1] = ACTIONS(5214),
    [anon_sym_wand] = ACTIONS(5214),
    [anon_sym_triand] = ACTIONS(5214),
    [anon_sym_wor] = ACTIONS(5214),
    [anon_sym_trior] = ACTIONS(5214),
    [anon_sym_trireg] = ACTIONS(5214),
    [anon_sym_uwire] = ACTIONS(5214),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5212),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5212),
    [aux_sym_begin_keywords_token1] = ACTIONS(5212),
    [anon_sym_SEMI] = ACTIONS(5212),
    [anon_sym_endmodule] = ACTIONS(5214),
    [anon_sym_extern] = ACTIONS(5214),
    [anon_sym_module] = ACTIONS(5214),
    [anon_sym_macromodule] = ACTIONS(5214),
    [anon_sym_endinterface] = ACTIONS(5214),
    [anon_sym_interface] = ACTIONS(5214),
    [anon_sym_endprogram] = ACTIONS(5214),
    [anon_sym_program] = ACTIONS(5214),
    [anon_sym_checker] = ACTIONS(5214),
    [anon_sym_virtual] = ACTIONS(5214),
    [anon_sym_class] = ACTIONS(5214),
    [anon_sym_package] = ACTIONS(5214),
    [anon_sym_endpackage] = ACTIONS(5214),
    [anon_sym_timeunit] = ACTIONS(5214),
    [anon_sym_timeprecision] = ACTIONS(5214),
    [anon_sym_type] = ACTIONS(5214),
    [anon_sym_input] = ACTIONS(5214),
    [anon_sym_output] = ACTIONS(5214),
    [anon_sym_inout] = ACTIONS(5214),
    [anon_sym_ref] = ACTIONS(5214),
    [anon_sym_DOLLARfatal] = ACTIONS(5212),
    [anon_sym_DOLLARerror] = ACTIONS(5212),
    [anon_sym_DOLLARwarning] = ACTIONS(5212),
    [anon_sym_DOLLARinfo] = ACTIONS(5212),
    [anon_sym_default] = ACTIONS(5214),
    [anon_sym_clocking] = ACTIONS(5214),
    [anon_sym_defparam] = ACTIONS(5214),
    [anon_sym_bind] = ACTIONS(5214),
    [anon_sym_const] = ACTIONS(5214),
    [anon_sym_function] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(5214),
    [anon_sym_constraint] = ACTIONS(5214),
    [anon_sym_if] = ACTIONS(5214),
    [anon_sym_else] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5212),
    [anon_sym_localparam] = ACTIONS(5214),
    [anon_sym_parameter] = ACTIONS(5214),
    [anon_sym_specparam] = ACTIONS(5214),
    [anon_sym_var] = ACTIONS(5214),
    [anon_sym_import] = ACTIONS(5214),
    [anon_sym_export] = ACTIONS(5214),
    [anon_sym_genvar] = ACTIONS(5214),
    [anon_sym_interconnect] = ACTIONS(5214),
    [anon_sym_typedef] = ACTIONS(5214),
    [anon_sym_enum] = ACTIONS(5214),
    [anon_sym_struct] = ACTIONS(5214),
    [anon_sym_union] = ACTIONS(5214),
    [anon_sym_nettype] = ACTIONS(5214),
    [anon_sym_automatic] = ACTIONS(5214),
    [anon_sym_string] = ACTIONS(5214),
    [anon_sym_chandle] = ACTIONS(5214),
    [anon_sym_event] = ACTIONS(5214),
    [anon_sym_byte] = ACTIONS(5214),
    [anon_sym_shortint] = ACTIONS(5214),
    [anon_sym_int] = ACTIONS(5214),
    [anon_sym_longint] = ACTIONS(5214),
    [anon_sym_integer] = ACTIONS(5214),
    [anon_sym_time] = ACTIONS(5214),
    [anon_sym_bit] = ACTIONS(5214),
    [anon_sym_logic] = ACTIONS(5214),
    [anon_sym_reg] = ACTIONS(5214),
    [anon_sym_shortreal] = ACTIONS(5214),
    [anon_sym_real] = ACTIONS(5214),
    [anon_sym_realtime] = ACTIONS(5214),
    [anon_sym_supply0] = ACTIONS(5214),
    [anon_sym_supply1] = ACTIONS(5214),
    [anon_sym_signed] = ACTIONS(5214),
    [anon_sym_unsigned] = ACTIONS(5214),
    [anon_sym_task] = ACTIONS(5214),
    [anon_sym_modport] = ACTIONS(5214),
    [anon_sym_assert] = ACTIONS(5214),
    [anon_sym_property] = ACTIONS(5214),
    [anon_sym_assume] = ACTIONS(5214),
    [anon_sym_cover] = ACTIONS(5214),
    [anon_sym_sequence] = ACTIONS(5214),
    [anon_sym_restrict] = ACTIONS(5214),
    [anon_sym_not] = ACTIONS(5214),
    [anon_sym_or] = ACTIONS(5214),
    [anon_sym_and] = ACTIONS(5214),
    [anon_sym_case] = ACTIONS(5214),
    [anon_sym_always] = ACTIONS(5214),
    [anon_sym_covergroup] = ACTIONS(5214),
    [anon_sym_let] = ACTIONS(5214),
    [anon_sym_pulldown] = ACTIONS(5214),
    [anon_sym_pullup] = ACTIONS(5214),
    [anon_sym_cmos] = ACTIONS(5214),
    [anon_sym_rcmos] = ACTIONS(5214),
    [anon_sym_bufif0] = ACTIONS(5214),
    [anon_sym_bufif1] = ACTIONS(5214),
    [anon_sym_notif0] = ACTIONS(5214),
    [anon_sym_notif1] = ACTIONS(5214),
    [anon_sym_nmos] = ACTIONS(5214),
    [anon_sym_pmos] = ACTIONS(5214),
    [anon_sym_rnmos] = ACTIONS(5214),
    [anon_sym_rpmos] = ACTIONS(5214),
    [anon_sym_nand] = ACTIONS(5214),
    [anon_sym_nor] = ACTIONS(5214),
    [anon_sym_xor] = ACTIONS(5214),
    [anon_sym_xnor] = ACTIONS(5214),
    [anon_sym_buf] = ACTIONS(5214),
    [anon_sym_tranif0] = ACTIONS(5214),
    [anon_sym_tranif1] = ACTIONS(5214),
    [anon_sym_rtranif1] = ACTIONS(5214),
    [anon_sym_rtranif0] = ACTIONS(5214),
    [anon_sym_tran] = ACTIONS(5214),
    [anon_sym_rtran] = ACTIONS(5214),
    [anon_sym_generate] = ACTIONS(5214),
    [anon_sym_for] = ACTIONS(5214),
    [anon_sym_primitive] = ACTIONS(5214),
    [anon_sym_initial] = ACTIONS(5214),
    [anon_sym_assign] = ACTIONS(5214),
    [anon_sym_alias] = ACTIONS(5214),
    [anon_sym_always_comb] = ACTIONS(5214),
    [anon_sym_always_latch] = ACTIONS(5214),
    [anon_sym_always_ff] = ACTIONS(5214),
    [anon_sym_final] = ACTIONS(5214),
    [anon_sym_global] = ACTIONS(5214),
    [anon_sym_specify] = ACTIONS(5214),
    [anon_sym_LPAREN_STAR] = ACTIONS(5212),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5212),
    [anon_sym_DOLLARunit] = ACTIONS(5212),
  },
  [839] = {
    [ts_builtin_sym_end] = ACTIONS(5216),
    [sym_simple_identifier] = ACTIONS(5218),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5216),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5216),
    [anon_sym_BQUOTE] = ACTIONS(5218),
    [aux_sym_id_directive_token1] = ACTIONS(5216),
    [aux_sym_id_directive_token2] = ACTIONS(5216),
    [aux_sym_id_directive_token3] = ACTIONS(5216),
    [aux_sym_id_directive_token4] = ACTIONS(5218),
    [aux_sym_zero_directive_token1] = ACTIONS(5216),
    [aux_sym_zero_directive_token2] = ACTIONS(5216),
    [aux_sym_zero_directive_token3] = ACTIONS(5216),
    [aux_sym_zero_directive_token4] = ACTIONS(5216),
    [aux_sym_zero_directive_token5] = ACTIONS(5216),
    [aux_sym_zero_directive_token6] = ACTIONS(5216),
    [aux_sym_zero_directive_token7] = ACTIONS(5216),
    [aux_sym_zero_directive_token8] = ACTIONS(5216),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5216),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5216),
    [anon_sym_wire] = ACTIONS(5218),
    [anon_sym_tri] = ACTIONS(5218),
    [anon_sym_tri0] = ACTIONS(5218),
    [anon_sym_tri1] = ACTIONS(5218),
    [anon_sym_wand] = ACTIONS(5218),
    [anon_sym_triand] = ACTIONS(5218),
    [anon_sym_wor] = ACTIONS(5218),
    [anon_sym_trior] = ACTIONS(5218),
    [anon_sym_trireg] = ACTIONS(5218),
    [anon_sym_uwire] = ACTIONS(5218),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5216),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5216),
    [aux_sym_begin_keywords_token1] = ACTIONS(5216),
    [anon_sym_SEMI] = ACTIONS(5216),
    [anon_sym_endmodule] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(5218),
    [anon_sym_module] = ACTIONS(5218),
    [anon_sym_macromodule] = ACTIONS(5218),
    [anon_sym_endinterface] = ACTIONS(5218),
    [anon_sym_interface] = ACTIONS(5218),
    [anon_sym_endprogram] = ACTIONS(5218),
    [anon_sym_program] = ACTIONS(5218),
    [anon_sym_checker] = ACTIONS(5218),
    [anon_sym_virtual] = ACTIONS(5218),
    [anon_sym_class] = ACTIONS(5218),
    [anon_sym_package] = ACTIONS(5218),
    [anon_sym_endpackage] = ACTIONS(5218),
    [anon_sym_timeunit] = ACTIONS(5218),
    [anon_sym_timeprecision] = ACTIONS(5218),
    [anon_sym_type] = ACTIONS(5218),
    [anon_sym_input] = ACTIONS(5218),
    [anon_sym_output] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_ref] = ACTIONS(5218),
    [anon_sym_DOLLARfatal] = ACTIONS(5216),
    [anon_sym_DOLLARerror] = ACTIONS(5216),
    [anon_sym_DOLLARwarning] = ACTIONS(5216),
    [anon_sym_DOLLARinfo] = ACTIONS(5216),
    [anon_sym_default] = ACTIONS(5218),
    [anon_sym_clocking] = ACTIONS(5218),
    [anon_sym_defparam] = ACTIONS(5218),
    [anon_sym_bind] = ACTIONS(5218),
    [anon_sym_const] = ACTIONS(5218),
    [anon_sym_function] = ACTIONS(5218),
    [anon_sym_static] = ACTIONS(5218),
    [anon_sym_constraint] = ACTIONS(5218),
    [anon_sym_if] = ACTIONS(5218),
    [anon_sym_else] = ACTIONS(5218),
    [anon_sym_LBRACK] = ACTIONS(5216),
    [anon_sym_localparam] = ACTIONS(5218),
    [anon_sym_parameter] = ACTIONS(5218),
    [anon_sym_specparam] = ACTIONS(5218),
    [anon_sym_var] = ACTIONS(5218),
    [anon_sym_import] = ACTIONS(5218),
    [anon_sym_export] = ACTIONS(5218),
    [anon_sym_genvar] = ACTIONS(5218),
    [anon_sym_interconnect] = ACTIONS(5218),
    [anon_sym_typedef] = ACTIONS(5218),
    [anon_sym_enum] = ACTIONS(5218),
    [anon_sym_struct] = ACTIONS(5218),
    [anon_sym_union] = ACTIONS(5218),
    [anon_sym_nettype] = ACTIONS(5218),
    [anon_sym_automatic] = ACTIONS(5218),
    [anon_sym_string] = ACTIONS(5218),
    [anon_sym_chandle] = ACTIONS(5218),
    [anon_sym_event] = ACTIONS(5218),
    [anon_sym_byte] = ACTIONS(5218),
    [anon_sym_shortint] = ACTIONS(5218),
    [anon_sym_int] = ACTIONS(5218),
    [anon_sym_longint] = ACTIONS(5218),
    [anon_sym_integer] = ACTIONS(5218),
    [anon_sym_time] = ACTIONS(5218),
    [anon_sym_bit] = ACTIONS(5218),
    [anon_sym_logic] = ACTIONS(5218),
    [anon_sym_reg] = ACTIONS(5218),
    [anon_sym_shortreal] = ACTIONS(5218),
    [anon_sym_real] = ACTIONS(5218),
    [anon_sym_realtime] = ACTIONS(5218),
    [anon_sym_supply0] = ACTIONS(5218),
    [anon_sym_supply1] = ACTIONS(5218),
    [anon_sym_signed] = ACTIONS(5218),
    [anon_sym_unsigned] = ACTIONS(5218),
    [anon_sym_task] = ACTIONS(5218),
    [anon_sym_modport] = ACTIONS(5218),
    [anon_sym_assert] = ACTIONS(5218),
    [anon_sym_property] = ACTIONS(5218),
    [anon_sym_assume] = ACTIONS(5218),
    [anon_sym_cover] = ACTIONS(5218),
    [anon_sym_sequence] = ACTIONS(5218),
    [anon_sym_restrict] = ACTIONS(5218),
    [anon_sym_not] = ACTIONS(5218),
    [anon_sym_or] = ACTIONS(5218),
    [anon_sym_and] = ACTIONS(5218),
    [anon_sym_case] = ACTIONS(5218),
    [anon_sym_always] = ACTIONS(5218),
    [anon_sym_covergroup] = ACTIONS(5218),
    [anon_sym_let] = ACTIONS(5218),
    [anon_sym_pulldown] = ACTIONS(5218),
    [anon_sym_pullup] = ACTIONS(5218),
    [anon_sym_cmos] = ACTIONS(5218),
    [anon_sym_rcmos] = ACTIONS(5218),
    [anon_sym_bufif0] = ACTIONS(5218),
    [anon_sym_bufif1] = ACTIONS(5218),
    [anon_sym_notif0] = ACTIONS(5218),
    [anon_sym_notif1] = ACTIONS(5218),
    [anon_sym_nmos] = ACTIONS(5218),
    [anon_sym_pmos] = ACTIONS(5218),
    [anon_sym_rnmos] = ACTIONS(5218),
    [anon_sym_rpmos] = ACTIONS(5218),
    [anon_sym_nand] = ACTIONS(5218),
    [anon_sym_nor] = ACTIONS(5218),
    [anon_sym_xor] = ACTIONS(5218),
    [anon_sym_xnor] = ACTIONS(5218),
    [anon_sym_buf] = ACTIONS(5218),
    [anon_sym_tranif0] = ACTIONS(5218),
    [anon_sym_tranif1] = ACTIONS(5218),
    [anon_sym_rtranif1] = ACTIONS(5218),
    [anon_sym_rtranif0] = ACTIONS(5218),
    [anon_sym_tran] = ACTIONS(5218),
    [anon_sym_rtran] = ACTIONS(5218),
    [anon_sym_generate] = ACTIONS(5218),
    [anon_sym_for] = ACTIONS(5218),
    [anon_sym_primitive] = ACTIONS(5218),
    [anon_sym_initial] = ACTIONS(5218),
    [anon_sym_assign] = ACTIONS(5218),
    [anon_sym_alias] = ACTIONS(5218),
    [anon_sym_always_comb] = ACTIONS(5218),
    [anon_sym_always_latch] = ACTIONS(5218),
    [anon_sym_always_ff] = ACTIONS(5218),
    [anon_sym_final] = ACTIONS(5218),
    [anon_sym_global] = ACTIONS(5218),
    [anon_sym_specify] = ACTIONS(5218),
    [anon_sym_LPAREN_STAR] = ACTIONS(5216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5216),
    [anon_sym_DOLLARunit] = ACTIONS(5216),
  },
  [840] = {
    [ts_builtin_sym_end] = ACTIONS(5220),
    [sym_simple_identifier] = ACTIONS(5222),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5220),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5220),
    [anon_sym_BQUOTE] = ACTIONS(5222),
    [aux_sym_id_directive_token1] = ACTIONS(5220),
    [aux_sym_id_directive_token2] = ACTIONS(5220),
    [aux_sym_id_directive_token3] = ACTIONS(5220),
    [aux_sym_id_directive_token4] = ACTIONS(5222),
    [aux_sym_zero_directive_token1] = ACTIONS(5220),
    [aux_sym_zero_directive_token2] = ACTIONS(5220),
    [aux_sym_zero_directive_token3] = ACTIONS(5220),
    [aux_sym_zero_directive_token4] = ACTIONS(5220),
    [aux_sym_zero_directive_token5] = ACTIONS(5220),
    [aux_sym_zero_directive_token6] = ACTIONS(5220),
    [aux_sym_zero_directive_token7] = ACTIONS(5220),
    [aux_sym_zero_directive_token8] = ACTIONS(5220),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5220),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5220),
    [anon_sym_wire] = ACTIONS(5222),
    [anon_sym_tri] = ACTIONS(5222),
    [anon_sym_tri0] = ACTIONS(5222),
    [anon_sym_tri1] = ACTIONS(5222),
    [anon_sym_wand] = ACTIONS(5222),
    [anon_sym_triand] = ACTIONS(5222),
    [anon_sym_wor] = ACTIONS(5222),
    [anon_sym_trior] = ACTIONS(5222),
    [anon_sym_trireg] = ACTIONS(5222),
    [anon_sym_uwire] = ACTIONS(5222),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5220),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5220),
    [aux_sym_begin_keywords_token1] = ACTIONS(5220),
    [anon_sym_SEMI] = ACTIONS(5220),
    [anon_sym_endmodule] = ACTIONS(5222),
    [anon_sym_extern] = ACTIONS(5222),
    [anon_sym_module] = ACTIONS(5222),
    [anon_sym_macromodule] = ACTIONS(5222),
    [anon_sym_endinterface] = ACTIONS(5222),
    [anon_sym_interface] = ACTIONS(5222),
    [anon_sym_endprogram] = ACTIONS(5222),
    [anon_sym_program] = ACTIONS(5222),
    [anon_sym_checker] = ACTIONS(5222),
    [anon_sym_virtual] = ACTIONS(5222),
    [anon_sym_class] = ACTIONS(5222),
    [anon_sym_package] = ACTIONS(5222),
    [anon_sym_endpackage] = ACTIONS(5222),
    [anon_sym_timeunit] = ACTIONS(5222),
    [anon_sym_timeprecision] = ACTIONS(5222),
    [anon_sym_type] = ACTIONS(5222),
    [anon_sym_input] = ACTIONS(5222),
    [anon_sym_output] = ACTIONS(5222),
    [anon_sym_inout] = ACTIONS(5222),
    [anon_sym_ref] = ACTIONS(5222),
    [anon_sym_DOLLARfatal] = ACTIONS(5220),
    [anon_sym_DOLLARerror] = ACTIONS(5220),
    [anon_sym_DOLLARwarning] = ACTIONS(5220),
    [anon_sym_DOLLARinfo] = ACTIONS(5220),
    [anon_sym_default] = ACTIONS(5222),
    [anon_sym_clocking] = ACTIONS(5222),
    [anon_sym_defparam] = ACTIONS(5222),
    [anon_sym_bind] = ACTIONS(5222),
    [anon_sym_const] = ACTIONS(5222),
    [anon_sym_function] = ACTIONS(5222),
    [anon_sym_static] = ACTIONS(5222),
    [anon_sym_constraint] = ACTIONS(5222),
    [anon_sym_if] = ACTIONS(5222),
    [anon_sym_else] = ACTIONS(5222),
    [anon_sym_LBRACK] = ACTIONS(5220),
    [anon_sym_localparam] = ACTIONS(5222),
    [anon_sym_parameter] = ACTIONS(5222),
    [anon_sym_specparam] = ACTIONS(5222),
    [anon_sym_var] = ACTIONS(5222),
    [anon_sym_import] = ACTIONS(5222),
    [anon_sym_export] = ACTIONS(5222),
    [anon_sym_genvar] = ACTIONS(5222),
    [anon_sym_interconnect] = ACTIONS(5222),
    [anon_sym_typedef] = ACTIONS(5222),
    [anon_sym_enum] = ACTIONS(5222),
    [anon_sym_struct] = ACTIONS(5222),
    [anon_sym_union] = ACTIONS(5222),
    [anon_sym_nettype] = ACTIONS(5222),
    [anon_sym_automatic] = ACTIONS(5222),
    [anon_sym_string] = ACTIONS(5222),
    [anon_sym_chandle] = ACTIONS(5222),
    [anon_sym_event] = ACTIONS(5222),
    [anon_sym_byte] = ACTIONS(5222),
    [anon_sym_shortint] = ACTIONS(5222),
    [anon_sym_int] = ACTIONS(5222),
    [anon_sym_longint] = ACTIONS(5222),
    [anon_sym_integer] = ACTIONS(5222),
    [anon_sym_time] = ACTIONS(5222),
    [anon_sym_bit] = ACTIONS(5222),
    [anon_sym_logic] = ACTIONS(5222),
    [anon_sym_reg] = ACTIONS(5222),
    [anon_sym_shortreal] = ACTIONS(5222),
    [anon_sym_real] = ACTIONS(5222),
    [anon_sym_realtime] = ACTIONS(5222),
    [anon_sym_supply0] = ACTIONS(5222),
    [anon_sym_supply1] = ACTIONS(5222),
    [anon_sym_signed] = ACTIONS(5222),
    [anon_sym_unsigned] = ACTIONS(5222),
    [anon_sym_task] = ACTIONS(5222),
    [anon_sym_modport] = ACTIONS(5222),
    [anon_sym_assert] = ACTIONS(5222),
    [anon_sym_property] = ACTIONS(5222),
    [anon_sym_assume] = ACTIONS(5222),
    [anon_sym_cover] = ACTIONS(5222),
    [anon_sym_sequence] = ACTIONS(5222),
    [anon_sym_restrict] = ACTIONS(5222),
    [anon_sym_not] = ACTIONS(5222),
    [anon_sym_or] = ACTIONS(5222),
    [anon_sym_and] = ACTIONS(5222),
    [anon_sym_case] = ACTIONS(5222),
    [anon_sym_always] = ACTIONS(5222),
    [anon_sym_covergroup] = ACTIONS(5222),
    [anon_sym_let] = ACTIONS(5222),
    [anon_sym_pulldown] = ACTIONS(5222),
    [anon_sym_pullup] = ACTIONS(5222),
    [anon_sym_cmos] = ACTIONS(5222),
    [anon_sym_rcmos] = ACTIONS(5222),
    [anon_sym_bufif0] = ACTIONS(5222),
    [anon_sym_bufif1] = ACTIONS(5222),
    [anon_sym_notif0] = ACTIONS(5222),
    [anon_sym_notif1] = ACTIONS(5222),
    [anon_sym_nmos] = ACTIONS(5222),
    [anon_sym_pmos] = ACTIONS(5222),
    [anon_sym_rnmos] = ACTIONS(5222),
    [anon_sym_rpmos] = ACTIONS(5222),
    [anon_sym_nand] = ACTIONS(5222),
    [anon_sym_nor] = ACTIONS(5222),
    [anon_sym_xor] = ACTIONS(5222),
    [anon_sym_xnor] = ACTIONS(5222),
    [anon_sym_buf] = ACTIONS(5222),
    [anon_sym_tranif0] = ACTIONS(5222),
    [anon_sym_tranif1] = ACTIONS(5222),
    [anon_sym_rtranif1] = ACTIONS(5222),
    [anon_sym_rtranif0] = ACTIONS(5222),
    [anon_sym_tran] = ACTIONS(5222),
    [anon_sym_rtran] = ACTIONS(5222),
    [anon_sym_generate] = ACTIONS(5222),
    [anon_sym_for] = ACTIONS(5222),
    [anon_sym_primitive] = ACTIONS(5222),
    [anon_sym_initial] = ACTIONS(5222),
    [anon_sym_assign] = ACTIONS(5222),
    [anon_sym_alias] = ACTIONS(5222),
    [anon_sym_always_comb] = ACTIONS(5222),
    [anon_sym_always_latch] = ACTIONS(5222),
    [anon_sym_always_ff] = ACTIONS(5222),
    [anon_sym_final] = ACTIONS(5222),
    [anon_sym_global] = ACTIONS(5222),
    [anon_sym_specify] = ACTIONS(5222),
    [anon_sym_LPAREN_STAR] = ACTIONS(5220),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5220),
    [anon_sym_DOLLARunit] = ACTIONS(5220),
  },
  [841] = {
    [ts_builtin_sym_end] = ACTIONS(5224),
    [sym_simple_identifier] = ACTIONS(5226),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5224),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5224),
    [anon_sym_BQUOTE] = ACTIONS(5226),
    [aux_sym_id_directive_token1] = ACTIONS(5224),
    [aux_sym_id_directive_token2] = ACTIONS(5224),
    [aux_sym_id_directive_token3] = ACTIONS(5224),
    [aux_sym_id_directive_token4] = ACTIONS(5226),
    [aux_sym_zero_directive_token1] = ACTIONS(5224),
    [aux_sym_zero_directive_token2] = ACTIONS(5224),
    [aux_sym_zero_directive_token3] = ACTIONS(5224),
    [aux_sym_zero_directive_token4] = ACTIONS(5224),
    [aux_sym_zero_directive_token5] = ACTIONS(5224),
    [aux_sym_zero_directive_token6] = ACTIONS(5224),
    [aux_sym_zero_directive_token7] = ACTIONS(5224),
    [aux_sym_zero_directive_token8] = ACTIONS(5224),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5224),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5224),
    [anon_sym_wire] = ACTIONS(5226),
    [anon_sym_tri] = ACTIONS(5226),
    [anon_sym_tri0] = ACTIONS(5226),
    [anon_sym_tri1] = ACTIONS(5226),
    [anon_sym_wand] = ACTIONS(5226),
    [anon_sym_triand] = ACTIONS(5226),
    [anon_sym_wor] = ACTIONS(5226),
    [anon_sym_trior] = ACTIONS(5226),
    [anon_sym_trireg] = ACTIONS(5226),
    [anon_sym_uwire] = ACTIONS(5226),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5224),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5224),
    [aux_sym_begin_keywords_token1] = ACTIONS(5224),
    [anon_sym_SEMI] = ACTIONS(5224),
    [anon_sym_endmodule] = ACTIONS(5226),
    [anon_sym_extern] = ACTIONS(5226),
    [anon_sym_module] = ACTIONS(5226),
    [anon_sym_macromodule] = ACTIONS(5226),
    [anon_sym_endinterface] = ACTIONS(5226),
    [anon_sym_interface] = ACTIONS(5226),
    [anon_sym_endprogram] = ACTIONS(5226),
    [anon_sym_program] = ACTIONS(5226),
    [anon_sym_checker] = ACTIONS(5226),
    [anon_sym_virtual] = ACTIONS(5226),
    [anon_sym_class] = ACTIONS(5226),
    [anon_sym_package] = ACTIONS(5226),
    [anon_sym_endpackage] = ACTIONS(5226),
    [anon_sym_timeunit] = ACTIONS(5226),
    [anon_sym_timeprecision] = ACTIONS(5226),
    [anon_sym_type] = ACTIONS(5226),
    [anon_sym_input] = ACTIONS(5226),
    [anon_sym_output] = ACTIONS(5226),
    [anon_sym_inout] = ACTIONS(5226),
    [anon_sym_ref] = ACTIONS(5226),
    [anon_sym_DOLLARfatal] = ACTIONS(5224),
    [anon_sym_DOLLARerror] = ACTIONS(5224),
    [anon_sym_DOLLARwarning] = ACTIONS(5224),
    [anon_sym_DOLLARinfo] = ACTIONS(5224),
    [anon_sym_default] = ACTIONS(5226),
    [anon_sym_clocking] = ACTIONS(5226),
    [anon_sym_defparam] = ACTIONS(5226),
    [anon_sym_bind] = ACTIONS(5226),
    [anon_sym_const] = ACTIONS(5226),
    [anon_sym_function] = ACTIONS(5226),
    [anon_sym_static] = ACTIONS(5226),
    [anon_sym_constraint] = ACTIONS(5226),
    [anon_sym_if] = ACTIONS(5226),
    [anon_sym_else] = ACTIONS(5226),
    [anon_sym_LBRACK] = ACTIONS(5224),
    [anon_sym_localparam] = ACTIONS(5226),
    [anon_sym_parameter] = ACTIONS(5226),
    [anon_sym_specparam] = ACTIONS(5226),
    [anon_sym_var] = ACTIONS(5226),
    [anon_sym_import] = ACTIONS(5226),
    [anon_sym_export] = ACTIONS(5226),
    [anon_sym_genvar] = ACTIONS(5226),
    [anon_sym_interconnect] = ACTIONS(5226),
    [anon_sym_typedef] = ACTIONS(5226),
    [anon_sym_enum] = ACTIONS(5226),
    [anon_sym_struct] = ACTIONS(5226),
    [anon_sym_union] = ACTIONS(5226),
    [anon_sym_nettype] = ACTIONS(5226),
    [anon_sym_automatic] = ACTIONS(5226),
    [anon_sym_string] = ACTIONS(5226),
    [anon_sym_chandle] = ACTIONS(5226),
    [anon_sym_event] = ACTIONS(5226),
    [anon_sym_byte] = ACTIONS(5226),
    [anon_sym_shortint] = ACTIONS(5226),
    [anon_sym_int] = ACTIONS(5226),
    [anon_sym_longint] = ACTIONS(5226),
    [anon_sym_integer] = ACTIONS(5226),
    [anon_sym_time] = ACTIONS(5226),
    [anon_sym_bit] = ACTIONS(5226),
    [anon_sym_logic] = ACTIONS(5226),
    [anon_sym_reg] = ACTIONS(5226),
    [anon_sym_shortreal] = ACTIONS(5226),
    [anon_sym_real] = ACTIONS(5226),
    [anon_sym_realtime] = ACTIONS(5226),
    [anon_sym_supply0] = ACTIONS(5226),
    [anon_sym_supply1] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5226),
    [anon_sym_unsigned] = ACTIONS(5226),
    [anon_sym_task] = ACTIONS(5226),
    [anon_sym_modport] = ACTIONS(5226),
    [anon_sym_assert] = ACTIONS(5226),
    [anon_sym_property] = ACTIONS(5226),
    [anon_sym_assume] = ACTIONS(5226),
    [anon_sym_cover] = ACTIONS(5226),
    [anon_sym_sequence] = ACTIONS(5226),
    [anon_sym_restrict] = ACTIONS(5226),
    [anon_sym_not] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5226),
    [anon_sym_and] = ACTIONS(5226),
    [anon_sym_case] = ACTIONS(5226),
    [anon_sym_always] = ACTIONS(5226),
    [anon_sym_covergroup] = ACTIONS(5226),
    [anon_sym_let] = ACTIONS(5226),
    [anon_sym_pulldown] = ACTIONS(5226),
    [anon_sym_pullup] = ACTIONS(5226),
    [anon_sym_cmos] = ACTIONS(5226),
    [anon_sym_rcmos] = ACTIONS(5226),
    [anon_sym_bufif0] = ACTIONS(5226),
    [anon_sym_bufif1] = ACTIONS(5226),
    [anon_sym_notif0] = ACTIONS(5226),
    [anon_sym_notif1] = ACTIONS(5226),
    [anon_sym_nmos] = ACTIONS(5226),
    [anon_sym_pmos] = ACTIONS(5226),
    [anon_sym_rnmos] = ACTIONS(5226),
    [anon_sym_rpmos] = ACTIONS(5226),
    [anon_sym_nand] = ACTIONS(5226),
    [anon_sym_nor] = ACTIONS(5226),
    [anon_sym_xor] = ACTIONS(5226),
    [anon_sym_xnor] = ACTIONS(5226),
    [anon_sym_buf] = ACTIONS(5226),
    [anon_sym_tranif0] = ACTIONS(5226),
    [anon_sym_tranif1] = ACTIONS(5226),
    [anon_sym_rtranif1] = ACTIONS(5226),
    [anon_sym_rtranif0] = ACTIONS(5226),
    [anon_sym_tran] = ACTIONS(5226),
    [anon_sym_rtran] = ACTIONS(5226),
    [anon_sym_generate] = ACTIONS(5226),
    [anon_sym_for] = ACTIONS(5226),
    [anon_sym_primitive] = ACTIONS(5226),
    [anon_sym_initial] = ACTIONS(5226),
    [anon_sym_assign] = ACTIONS(5226),
    [anon_sym_alias] = ACTIONS(5226),
    [anon_sym_always_comb] = ACTIONS(5226),
    [anon_sym_always_latch] = ACTIONS(5226),
    [anon_sym_always_ff] = ACTIONS(5226),
    [anon_sym_final] = ACTIONS(5226),
    [anon_sym_global] = ACTIONS(5226),
    [anon_sym_specify] = ACTIONS(5226),
    [anon_sym_LPAREN_STAR] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5224),
    [anon_sym_DOLLARunit] = ACTIONS(5224),
  },
  [842] = {
    [ts_builtin_sym_end] = ACTIONS(5228),
    [sym_simple_identifier] = ACTIONS(5230),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5228),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5228),
    [anon_sym_BQUOTE] = ACTIONS(5230),
    [aux_sym_id_directive_token1] = ACTIONS(5228),
    [aux_sym_id_directive_token2] = ACTIONS(5228),
    [aux_sym_id_directive_token3] = ACTIONS(5228),
    [aux_sym_id_directive_token4] = ACTIONS(5230),
    [aux_sym_zero_directive_token1] = ACTIONS(5228),
    [aux_sym_zero_directive_token2] = ACTIONS(5228),
    [aux_sym_zero_directive_token3] = ACTIONS(5228),
    [aux_sym_zero_directive_token4] = ACTIONS(5228),
    [aux_sym_zero_directive_token5] = ACTIONS(5228),
    [aux_sym_zero_directive_token6] = ACTIONS(5228),
    [aux_sym_zero_directive_token7] = ACTIONS(5228),
    [aux_sym_zero_directive_token8] = ACTIONS(5228),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5228),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5228),
    [anon_sym_wire] = ACTIONS(5230),
    [anon_sym_tri] = ACTIONS(5230),
    [anon_sym_tri0] = ACTIONS(5230),
    [anon_sym_tri1] = ACTIONS(5230),
    [anon_sym_wand] = ACTIONS(5230),
    [anon_sym_triand] = ACTIONS(5230),
    [anon_sym_wor] = ACTIONS(5230),
    [anon_sym_trior] = ACTIONS(5230),
    [anon_sym_trireg] = ACTIONS(5230),
    [anon_sym_uwire] = ACTIONS(5230),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5228),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5228),
    [aux_sym_begin_keywords_token1] = ACTIONS(5228),
    [anon_sym_SEMI] = ACTIONS(5228),
    [anon_sym_endmodule] = ACTIONS(5230),
    [anon_sym_extern] = ACTIONS(5230),
    [anon_sym_module] = ACTIONS(5230),
    [anon_sym_macromodule] = ACTIONS(5230),
    [anon_sym_endinterface] = ACTIONS(5230),
    [anon_sym_interface] = ACTIONS(5230),
    [anon_sym_endprogram] = ACTIONS(5230),
    [anon_sym_program] = ACTIONS(5230),
    [anon_sym_checker] = ACTIONS(5230),
    [anon_sym_virtual] = ACTIONS(5230),
    [anon_sym_class] = ACTIONS(5230),
    [anon_sym_package] = ACTIONS(5230),
    [anon_sym_endpackage] = ACTIONS(5230),
    [anon_sym_timeunit] = ACTIONS(5230),
    [anon_sym_timeprecision] = ACTIONS(5230),
    [anon_sym_type] = ACTIONS(5230),
    [anon_sym_input] = ACTIONS(5230),
    [anon_sym_output] = ACTIONS(5230),
    [anon_sym_inout] = ACTIONS(5230),
    [anon_sym_ref] = ACTIONS(5230),
    [anon_sym_DOLLARfatal] = ACTIONS(5228),
    [anon_sym_DOLLARerror] = ACTIONS(5228),
    [anon_sym_DOLLARwarning] = ACTIONS(5228),
    [anon_sym_DOLLARinfo] = ACTIONS(5228),
    [anon_sym_default] = ACTIONS(5230),
    [anon_sym_clocking] = ACTIONS(5230),
    [anon_sym_defparam] = ACTIONS(5230),
    [anon_sym_bind] = ACTIONS(5230),
    [anon_sym_const] = ACTIONS(5230),
    [anon_sym_function] = ACTIONS(5230),
    [anon_sym_static] = ACTIONS(5230),
    [anon_sym_constraint] = ACTIONS(5230),
    [anon_sym_if] = ACTIONS(5230),
    [anon_sym_else] = ACTIONS(5230),
    [anon_sym_LBRACK] = ACTIONS(5228),
    [anon_sym_localparam] = ACTIONS(5230),
    [anon_sym_parameter] = ACTIONS(5230),
    [anon_sym_specparam] = ACTIONS(5230),
    [anon_sym_var] = ACTIONS(5230),
    [anon_sym_import] = ACTIONS(5230),
    [anon_sym_export] = ACTIONS(5230),
    [anon_sym_genvar] = ACTIONS(5230),
    [anon_sym_interconnect] = ACTIONS(5230),
    [anon_sym_typedef] = ACTIONS(5230),
    [anon_sym_enum] = ACTIONS(5230),
    [anon_sym_struct] = ACTIONS(5230),
    [anon_sym_union] = ACTIONS(5230),
    [anon_sym_nettype] = ACTIONS(5230),
    [anon_sym_automatic] = ACTIONS(5230),
    [anon_sym_string] = ACTIONS(5230),
    [anon_sym_chandle] = ACTIONS(5230),
    [anon_sym_event] = ACTIONS(5230),
    [anon_sym_byte] = ACTIONS(5230),
    [anon_sym_shortint] = ACTIONS(5230),
    [anon_sym_int] = ACTIONS(5230),
    [anon_sym_longint] = ACTIONS(5230),
    [anon_sym_integer] = ACTIONS(5230),
    [anon_sym_time] = ACTIONS(5230),
    [anon_sym_bit] = ACTIONS(5230),
    [anon_sym_logic] = ACTIONS(5230),
    [anon_sym_reg] = ACTIONS(5230),
    [anon_sym_shortreal] = ACTIONS(5230),
    [anon_sym_real] = ACTIONS(5230),
    [anon_sym_realtime] = ACTIONS(5230),
    [anon_sym_supply0] = ACTIONS(5230),
    [anon_sym_supply1] = ACTIONS(5230),
    [anon_sym_signed] = ACTIONS(5230),
    [anon_sym_unsigned] = ACTIONS(5230),
    [anon_sym_task] = ACTIONS(5230),
    [anon_sym_modport] = ACTIONS(5230),
    [anon_sym_assert] = ACTIONS(5230),
    [anon_sym_property] = ACTIONS(5230),
    [anon_sym_assume] = ACTIONS(5230),
    [anon_sym_cover] = ACTIONS(5230),
    [anon_sym_sequence] = ACTIONS(5230),
    [anon_sym_restrict] = ACTIONS(5230),
    [anon_sym_not] = ACTIONS(5230),
    [anon_sym_or] = ACTIONS(5230),
    [anon_sym_and] = ACTIONS(5230),
    [anon_sym_case] = ACTIONS(5230),
    [anon_sym_always] = ACTIONS(5230),
    [anon_sym_covergroup] = ACTIONS(5230),
    [anon_sym_let] = ACTIONS(5230),
    [anon_sym_pulldown] = ACTIONS(5230),
    [anon_sym_pullup] = ACTIONS(5230),
    [anon_sym_cmos] = ACTIONS(5230),
    [anon_sym_rcmos] = ACTIONS(5230),
    [anon_sym_bufif0] = ACTIONS(5230),
    [anon_sym_bufif1] = ACTIONS(5230),
    [anon_sym_notif0] = ACTIONS(5230),
    [anon_sym_notif1] = ACTIONS(5230),
    [anon_sym_nmos] = ACTIONS(5230),
    [anon_sym_pmos] = ACTIONS(5230),
    [anon_sym_rnmos] = ACTIONS(5230),
    [anon_sym_rpmos] = ACTIONS(5230),
    [anon_sym_nand] = ACTIONS(5230),
    [anon_sym_nor] = ACTIONS(5230),
    [anon_sym_xor] = ACTIONS(5230),
    [anon_sym_xnor] = ACTIONS(5230),
    [anon_sym_buf] = ACTIONS(5230),
    [anon_sym_tranif0] = ACTIONS(5230),
    [anon_sym_tranif1] = ACTIONS(5230),
    [anon_sym_rtranif1] = ACTIONS(5230),
    [anon_sym_rtranif0] = ACTIONS(5230),
    [anon_sym_tran] = ACTIONS(5230),
    [anon_sym_rtran] = ACTIONS(5230),
    [anon_sym_generate] = ACTIONS(5230),
    [anon_sym_for] = ACTIONS(5230),
    [anon_sym_primitive] = ACTIONS(5230),
    [anon_sym_initial] = ACTIONS(5230),
    [anon_sym_assign] = ACTIONS(5230),
    [anon_sym_alias] = ACTIONS(5230),
    [anon_sym_always_comb] = ACTIONS(5230),
    [anon_sym_always_latch] = ACTIONS(5230),
    [anon_sym_always_ff] = ACTIONS(5230),
    [anon_sym_final] = ACTIONS(5230),
    [anon_sym_global] = ACTIONS(5230),
    [anon_sym_specify] = ACTIONS(5230),
    [anon_sym_LPAREN_STAR] = ACTIONS(5228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5228),
    [anon_sym_DOLLARunit] = ACTIONS(5228),
  },
  [843] = {
    [ts_builtin_sym_end] = ACTIONS(5232),
    [sym_simple_identifier] = ACTIONS(5234),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5232),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5232),
    [anon_sym_BQUOTE] = ACTIONS(5234),
    [aux_sym_id_directive_token1] = ACTIONS(5232),
    [aux_sym_id_directive_token2] = ACTIONS(5232),
    [aux_sym_id_directive_token3] = ACTIONS(5232),
    [aux_sym_id_directive_token4] = ACTIONS(5234),
    [aux_sym_zero_directive_token1] = ACTIONS(5232),
    [aux_sym_zero_directive_token2] = ACTIONS(5232),
    [aux_sym_zero_directive_token3] = ACTIONS(5232),
    [aux_sym_zero_directive_token4] = ACTIONS(5232),
    [aux_sym_zero_directive_token5] = ACTIONS(5232),
    [aux_sym_zero_directive_token6] = ACTIONS(5232),
    [aux_sym_zero_directive_token7] = ACTIONS(5232),
    [aux_sym_zero_directive_token8] = ACTIONS(5232),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5232),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5232),
    [anon_sym_wire] = ACTIONS(5234),
    [anon_sym_tri] = ACTIONS(5234),
    [anon_sym_tri0] = ACTIONS(5234),
    [anon_sym_tri1] = ACTIONS(5234),
    [anon_sym_wand] = ACTIONS(5234),
    [anon_sym_triand] = ACTIONS(5234),
    [anon_sym_wor] = ACTIONS(5234),
    [anon_sym_trior] = ACTIONS(5234),
    [anon_sym_trireg] = ACTIONS(5234),
    [anon_sym_uwire] = ACTIONS(5234),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5232),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5232),
    [aux_sym_begin_keywords_token1] = ACTIONS(5232),
    [anon_sym_SEMI] = ACTIONS(5232),
    [anon_sym_endmodule] = ACTIONS(5234),
    [anon_sym_extern] = ACTIONS(5234),
    [anon_sym_module] = ACTIONS(5234),
    [anon_sym_macromodule] = ACTIONS(5234),
    [anon_sym_endinterface] = ACTIONS(5234),
    [anon_sym_interface] = ACTIONS(5234),
    [anon_sym_endprogram] = ACTIONS(5234),
    [anon_sym_program] = ACTIONS(5234),
    [anon_sym_checker] = ACTIONS(5234),
    [anon_sym_virtual] = ACTIONS(5234),
    [anon_sym_class] = ACTIONS(5234),
    [anon_sym_package] = ACTIONS(5234),
    [anon_sym_endpackage] = ACTIONS(5234),
    [anon_sym_timeunit] = ACTIONS(5234),
    [anon_sym_timeprecision] = ACTIONS(5234),
    [anon_sym_type] = ACTIONS(5234),
    [anon_sym_input] = ACTIONS(5234),
    [anon_sym_output] = ACTIONS(5234),
    [anon_sym_inout] = ACTIONS(5234),
    [anon_sym_ref] = ACTIONS(5234),
    [anon_sym_DOLLARfatal] = ACTIONS(5232),
    [anon_sym_DOLLARerror] = ACTIONS(5232),
    [anon_sym_DOLLARwarning] = ACTIONS(5232),
    [anon_sym_DOLLARinfo] = ACTIONS(5232),
    [anon_sym_default] = ACTIONS(5234),
    [anon_sym_clocking] = ACTIONS(5234),
    [anon_sym_defparam] = ACTIONS(5234),
    [anon_sym_bind] = ACTIONS(5234),
    [anon_sym_const] = ACTIONS(5234),
    [anon_sym_function] = ACTIONS(5234),
    [anon_sym_static] = ACTIONS(5234),
    [anon_sym_constraint] = ACTIONS(5234),
    [anon_sym_if] = ACTIONS(5234),
    [anon_sym_else] = ACTIONS(5234),
    [anon_sym_LBRACK] = ACTIONS(5232),
    [anon_sym_localparam] = ACTIONS(5234),
    [anon_sym_parameter] = ACTIONS(5234),
    [anon_sym_specparam] = ACTIONS(5234),
    [anon_sym_var] = ACTIONS(5234),
    [anon_sym_import] = ACTIONS(5234),
    [anon_sym_export] = ACTIONS(5234),
    [anon_sym_genvar] = ACTIONS(5234),
    [anon_sym_interconnect] = ACTIONS(5234),
    [anon_sym_typedef] = ACTIONS(5234),
    [anon_sym_enum] = ACTIONS(5234),
    [anon_sym_struct] = ACTIONS(5234),
    [anon_sym_union] = ACTIONS(5234),
    [anon_sym_nettype] = ACTIONS(5234),
    [anon_sym_automatic] = ACTIONS(5234),
    [anon_sym_string] = ACTIONS(5234),
    [anon_sym_chandle] = ACTIONS(5234),
    [anon_sym_event] = ACTIONS(5234),
    [anon_sym_byte] = ACTIONS(5234),
    [anon_sym_shortint] = ACTIONS(5234),
    [anon_sym_int] = ACTIONS(5234),
    [anon_sym_longint] = ACTIONS(5234),
    [anon_sym_integer] = ACTIONS(5234),
    [anon_sym_time] = ACTIONS(5234),
    [anon_sym_bit] = ACTIONS(5234),
    [anon_sym_logic] = ACTIONS(5234),
    [anon_sym_reg] = ACTIONS(5234),
    [anon_sym_shortreal] = ACTIONS(5234),
    [anon_sym_real] = ACTIONS(5234),
    [anon_sym_realtime] = ACTIONS(5234),
    [anon_sym_supply0] = ACTIONS(5234),
    [anon_sym_supply1] = ACTIONS(5234),
    [anon_sym_signed] = ACTIONS(5234),
    [anon_sym_unsigned] = ACTIONS(5234),
    [anon_sym_task] = ACTIONS(5234),
    [anon_sym_modport] = ACTIONS(5234),
    [anon_sym_assert] = ACTIONS(5234),
    [anon_sym_property] = ACTIONS(5234),
    [anon_sym_assume] = ACTIONS(5234),
    [anon_sym_cover] = ACTIONS(5234),
    [anon_sym_sequence] = ACTIONS(5234),
    [anon_sym_restrict] = ACTIONS(5234),
    [anon_sym_not] = ACTIONS(5234),
    [anon_sym_or] = ACTIONS(5234),
    [anon_sym_and] = ACTIONS(5234),
    [anon_sym_case] = ACTIONS(5234),
    [anon_sym_always] = ACTIONS(5234),
    [anon_sym_covergroup] = ACTIONS(5234),
    [anon_sym_let] = ACTIONS(5234),
    [anon_sym_pulldown] = ACTIONS(5234),
    [anon_sym_pullup] = ACTIONS(5234),
    [anon_sym_cmos] = ACTIONS(5234),
    [anon_sym_rcmos] = ACTIONS(5234),
    [anon_sym_bufif0] = ACTIONS(5234),
    [anon_sym_bufif1] = ACTIONS(5234),
    [anon_sym_notif0] = ACTIONS(5234),
    [anon_sym_notif1] = ACTIONS(5234),
    [anon_sym_nmos] = ACTIONS(5234),
    [anon_sym_pmos] = ACTIONS(5234),
    [anon_sym_rnmos] = ACTIONS(5234),
    [anon_sym_rpmos] = ACTIONS(5234),
    [anon_sym_nand] = ACTIONS(5234),
    [anon_sym_nor] = ACTIONS(5234),
    [anon_sym_xor] = ACTIONS(5234),
    [anon_sym_xnor] = ACTIONS(5234),
    [anon_sym_buf] = ACTIONS(5234),
    [anon_sym_tranif0] = ACTIONS(5234),
    [anon_sym_tranif1] = ACTIONS(5234),
    [anon_sym_rtranif1] = ACTIONS(5234),
    [anon_sym_rtranif0] = ACTIONS(5234),
    [anon_sym_tran] = ACTIONS(5234),
    [anon_sym_rtran] = ACTIONS(5234),
    [anon_sym_generate] = ACTIONS(5234),
    [anon_sym_for] = ACTIONS(5234),
    [anon_sym_primitive] = ACTIONS(5234),
    [anon_sym_initial] = ACTIONS(5234),
    [anon_sym_assign] = ACTIONS(5234),
    [anon_sym_alias] = ACTIONS(5234),
    [anon_sym_always_comb] = ACTIONS(5234),
    [anon_sym_always_latch] = ACTIONS(5234),
    [anon_sym_always_ff] = ACTIONS(5234),
    [anon_sym_final] = ACTIONS(5234),
    [anon_sym_global] = ACTIONS(5234),
    [anon_sym_specify] = ACTIONS(5234),
    [anon_sym_LPAREN_STAR] = ACTIONS(5232),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5232),
    [anon_sym_DOLLARunit] = ACTIONS(5232),
  },
  [844] = {
    [ts_builtin_sym_end] = ACTIONS(5236),
    [sym_simple_identifier] = ACTIONS(5238),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5236),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5236),
    [anon_sym_BQUOTE] = ACTIONS(5238),
    [aux_sym_id_directive_token1] = ACTIONS(5236),
    [aux_sym_id_directive_token2] = ACTIONS(5236),
    [aux_sym_id_directive_token3] = ACTIONS(5236),
    [aux_sym_id_directive_token4] = ACTIONS(5238),
    [aux_sym_zero_directive_token1] = ACTIONS(5236),
    [aux_sym_zero_directive_token2] = ACTIONS(5236),
    [aux_sym_zero_directive_token3] = ACTIONS(5236),
    [aux_sym_zero_directive_token4] = ACTIONS(5236),
    [aux_sym_zero_directive_token5] = ACTIONS(5236),
    [aux_sym_zero_directive_token6] = ACTIONS(5236),
    [aux_sym_zero_directive_token7] = ACTIONS(5236),
    [aux_sym_zero_directive_token8] = ACTIONS(5236),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5236),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5236),
    [anon_sym_wire] = ACTIONS(5238),
    [anon_sym_tri] = ACTIONS(5238),
    [anon_sym_tri0] = ACTIONS(5238),
    [anon_sym_tri1] = ACTIONS(5238),
    [anon_sym_wand] = ACTIONS(5238),
    [anon_sym_triand] = ACTIONS(5238),
    [anon_sym_wor] = ACTIONS(5238),
    [anon_sym_trior] = ACTIONS(5238),
    [anon_sym_trireg] = ACTIONS(5238),
    [anon_sym_uwire] = ACTIONS(5238),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5236),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5236),
    [aux_sym_begin_keywords_token1] = ACTIONS(5236),
    [anon_sym_SEMI] = ACTIONS(5236),
    [anon_sym_endmodule] = ACTIONS(5238),
    [anon_sym_extern] = ACTIONS(5238),
    [anon_sym_module] = ACTIONS(5238),
    [anon_sym_macromodule] = ACTIONS(5238),
    [anon_sym_endinterface] = ACTIONS(5238),
    [anon_sym_interface] = ACTIONS(5238),
    [anon_sym_endprogram] = ACTIONS(5238),
    [anon_sym_program] = ACTIONS(5238),
    [anon_sym_checker] = ACTIONS(5238),
    [anon_sym_virtual] = ACTIONS(5238),
    [anon_sym_class] = ACTIONS(5238),
    [anon_sym_package] = ACTIONS(5238),
    [anon_sym_endpackage] = ACTIONS(5238),
    [anon_sym_timeunit] = ACTIONS(5238),
    [anon_sym_timeprecision] = ACTIONS(5238),
    [anon_sym_type] = ACTIONS(5238),
    [anon_sym_input] = ACTIONS(5238),
    [anon_sym_output] = ACTIONS(5238),
    [anon_sym_inout] = ACTIONS(5238),
    [anon_sym_ref] = ACTIONS(5238),
    [anon_sym_DOLLARfatal] = ACTIONS(5236),
    [anon_sym_DOLLARerror] = ACTIONS(5236),
    [anon_sym_DOLLARwarning] = ACTIONS(5236),
    [anon_sym_DOLLARinfo] = ACTIONS(5236),
    [anon_sym_default] = ACTIONS(5238),
    [anon_sym_clocking] = ACTIONS(5238),
    [anon_sym_defparam] = ACTIONS(5238),
    [anon_sym_bind] = ACTIONS(5238),
    [anon_sym_const] = ACTIONS(5238),
    [anon_sym_function] = ACTIONS(5238),
    [anon_sym_static] = ACTIONS(5238),
    [anon_sym_constraint] = ACTIONS(5238),
    [anon_sym_if] = ACTIONS(5238),
    [anon_sym_else] = ACTIONS(5238),
    [anon_sym_LBRACK] = ACTIONS(5236),
    [anon_sym_localparam] = ACTIONS(5238),
    [anon_sym_parameter] = ACTIONS(5238),
    [anon_sym_specparam] = ACTIONS(5238),
    [anon_sym_var] = ACTIONS(5238),
    [anon_sym_import] = ACTIONS(5238),
    [anon_sym_export] = ACTIONS(5238),
    [anon_sym_genvar] = ACTIONS(5238),
    [anon_sym_interconnect] = ACTIONS(5238),
    [anon_sym_typedef] = ACTIONS(5238),
    [anon_sym_enum] = ACTIONS(5238),
    [anon_sym_struct] = ACTIONS(5238),
    [anon_sym_union] = ACTIONS(5238),
    [anon_sym_nettype] = ACTIONS(5238),
    [anon_sym_automatic] = ACTIONS(5238),
    [anon_sym_string] = ACTIONS(5238),
    [anon_sym_chandle] = ACTIONS(5238),
    [anon_sym_event] = ACTIONS(5238),
    [anon_sym_byte] = ACTIONS(5238),
    [anon_sym_shortint] = ACTIONS(5238),
    [anon_sym_int] = ACTIONS(5238),
    [anon_sym_longint] = ACTIONS(5238),
    [anon_sym_integer] = ACTIONS(5238),
    [anon_sym_time] = ACTIONS(5238),
    [anon_sym_bit] = ACTIONS(5238),
    [anon_sym_logic] = ACTIONS(5238),
    [anon_sym_reg] = ACTIONS(5238),
    [anon_sym_shortreal] = ACTIONS(5238),
    [anon_sym_real] = ACTIONS(5238),
    [anon_sym_realtime] = ACTIONS(5238),
    [anon_sym_supply0] = ACTIONS(5238),
    [anon_sym_supply1] = ACTIONS(5238),
    [anon_sym_signed] = ACTIONS(5238),
    [anon_sym_unsigned] = ACTIONS(5238),
    [anon_sym_task] = ACTIONS(5238),
    [anon_sym_modport] = ACTIONS(5238),
    [anon_sym_assert] = ACTIONS(5238),
    [anon_sym_property] = ACTIONS(5238),
    [anon_sym_assume] = ACTIONS(5238),
    [anon_sym_cover] = ACTIONS(5238),
    [anon_sym_sequence] = ACTIONS(5238),
    [anon_sym_restrict] = ACTIONS(5238),
    [anon_sym_not] = ACTIONS(5238),
    [anon_sym_or] = ACTIONS(5238),
    [anon_sym_and] = ACTIONS(5238),
    [anon_sym_case] = ACTIONS(5238),
    [anon_sym_always] = ACTIONS(5238),
    [anon_sym_covergroup] = ACTIONS(5238),
    [anon_sym_let] = ACTIONS(5238),
    [anon_sym_pulldown] = ACTIONS(5238),
    [anon_sym_pullup] = ACTIONS(5238),
    [anon_sym_cmos] = ACTIONS(5238),
    [anon_sym_rcmos] = ACTIONS(5238),
    [anon_sym_bufif0] = ACTIONS(5238),
    [anon_sym_bufif1] = ACTIONS(5238),
    [anon_sym_notif0] = ACTIONS(5238),
    [anon_sym_notif1] = ACTIONS(5238),
    [anon_sym_nmos] = ACTIONS(5238),
    [anon_sym_pmos] = ACTIONS(5238),
    [anon_sym_rnmos] = ACTIONS(5238),
    [anon_sym_rpmos] = ACTIONS(5238),
    [anon_sym_nand] = ACTIONS(5238),
    [anon_sym_nor] = ACTIONS(5238),
    [anon_sym_xor] = ACTIONS(5238),
    [anon_sym_xnor] = ACTIONS(5238),
    [anon_sym_buf] = ACTIONS(5238),
    [anon_sym_tranif0] = ACTIONS(5238),
    [anon_sym_tranif1] = ACTIONS(5238),
    [anon_sym_rtranif1] = ACTIONS(5238),
    [anon_sym_rtranif0] = ACTIONS(5238),
    [anon_sym_tran] = ACTIONS(5238),
    [anon_sym_rtran] = ACTIONS(5238),
    [anon_sym_generate] = ACTIONS(5238),
    [anon_sym_for] = ACTIONS(5238),
    [anon_sym_primitive] = ACTIONS(5238),
    [anon_sym_initial] = ACTIONS(5238),
    [anon_sym_assign] = ACTIONS(5238),
    [anon_sym_alias] = ACTIONS(5238),
    [anon_sym_always_comb] = ACTIONS(5238),
    [anon_sym_always_latch] = ACTIONS(5238),
    [anon_sym_always_ff] = ACTIONS(5238),
    [anon_sym_final] = ACTIONS(5238),
    [anon_sym_global] = ACTIONS(5238),
    [anon_sym_specify] = ACTIONS(5238),
    [anon_sym_LPAREN_STAR] = ACTIONS(5236),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5236),
    [anon_sym_DOLLARunit] = ACTIONS(5236),
  },
  [845] = {
    [ts_builtin_sym_end] = ACTIONS(5240),
    [sym_simple_identifier] = ACTIONS(5242),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5240),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5240),
    [anon_sym_BQUOTE] = ACTIONS(5242),
    [aux_sym_id_directive_token1] = ACTIONS(5240),
    [aux_sym_id_directive_token2] = ACTIONS(5240),
    [aux_sym_id_directive_token3] = ACTIONS(5240),
    [aux_sym_id_directive_token4] = ACTIONS(5242),
    [aux_sym_zero_directive_token1] = ACTIONS(5240),
    [aux_sym_zero_directive_token2] = ACTIONS(5240),
    [aux_sym_zero_directive_token3] = ACTIONS(5240),
    [aux_sym_zero_directive_token4] = ACTIONS(5240),
    [aux_sym_zero_directive_token5] = ACTIONS(5240),
    [aux_sym_zero_directive_token6] = ACTIONS(5240),
    [aux_sym_zero_directive_token7] = ACTIONS(5240),
    [aux_sym_zero_directive_token8] = ACTIONS(5240),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5240),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5240),
    [anon_sym_wire] = ACTIONS(5242),
    [anon_sym_tri] = ACTIONS(5242),
    [anon_sym_tri0] = ACTIONS(5242),
    [anon_sym_tri1] = ACTIONS(5242),
    [anon_sym_wand] = ACTIONS(5242),
    [anon_sym_triand] = ACTIONS(5242),
    [anon_sym_wor] = ACTIONS(5242),
    [anon_sym_trior] = ACTIONS(5242),
    [anon_sym_trireg] = ACTIONS(5242),
    [anon_sym_uwire] = ACTIONS(5242),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5240),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5240),
    [aux_sym_begin_keywords_token1] = ACTIONS(5240),
    [anon_sym_SEMI] = ACTIONS(5240),
    [anon_sym_endmodule] = ACTIONS(5242),
    [anon_sym_extern] = ACTIONS(5242),
    [anon_sym_module] = ACTIONS(5242),
    [anon_sym_macromodule] = ACTIONS(5242),
    [anon_sym_endinterface] = ACTIONS(5242),
    [anon_sym_interface] = ACTIONS(5242),
    [anon_sym_endprogram] = ACTIONS(5242),
    [anon_sym_program] = ACTIONS(5242),
    [anon_sym_checker] = ACTIONS(5242),
    [anon_sym_virtual] = ACTIONS(5242),
    [anon_sym_class] = ACTIONS(5242),
    [anon_sym_package] = ACTIONS(5242),
    [anon_sym_endpackage] = ACTIONS(5242),
    [anon_sym_timeunit] = ACTIONS(5242),
    [anon_sym_timeprecision] = ACTIONS(5242),
    [anon_sym_type] = ACTIONS(5242),
    [anon_sym_input] = ACTIONS(5242),
    [anon_sym_output] = ACTIONS(5242),
    [anon_sym_inout] = ACTIONS(5242),
    [anon_sym_ref] = ACTIONS(5242),
    [anon_sym_DOLLARfatal] = ACTIONS(5240),
    [anon_sym_DOLLARerror] = ACTIONS(5240),
    [anon_sym_DOLLARwarning] = ACTIONS(5240),
    [anon_sym_DOLLARinfo] = ACTIONS(5240),
    [anon_sym_default] = ACTIONS(5242),
    [anon_sym_clocking] = ACTIONS(5242),
    [anon_sym_defparam] = ACTIONS(5242),
    [anon_sym_bind] = ACTIONS(5242),
    [anon_sym_const] = ACTIONS(5242),
    [anon_sym_function] = ACTIONS(5242),
    [anon_sym_static] = ACTIONS(5242),
    [anon_sym_constraint] = ACTIONS(5242),
    [anon_sym_if] = ACTIONS(5242),
    [anon_sym_else] = ACTIONS(5242),
    [anon_sym_LBRACK] = ACTIONS(5240),
    [anon_sym_localparam] = ACTIONS(5242),
    [anon_sym_parameter] = ACTIONS(5242),
    [anon_sym_specparam] = ACTIONS(5242),
    [anon_sym_var] = ACTIONS(5242),
    [anon_sym_import] = ACTIONS(5242),
    [anon_sym_export] = ACTIONS(5242),
    [anon_sym_genvar] = ACTIONS(5242),
    [anon_sym_interconnect] = ACTIONS(5242),
    [anon_sym_typedef] = ACTIONS(5242),
    [anon_sym_enum] = ACTIONS(5242),
    [anon_sym_struct] = ACTIONS(5242),
    [anon_sym_union] = ACTIONS(5242),
    [anon_sym_nettype] = ACTIONS(5242),
    [anon_sym_automatic] = ACTIONS(5242),
    [anon_sym_string] = ACTIONS(5242),
    [anon_sym_chandle] = ACTIONS(5242),
    [anon_sym_event] = ACTIONS(5242),
    [anon_sym_byte] = ACTIONS(5242),
    [anon_sym_shortint] = ACTIONS(5242),
    [anon_sym_int] = ACTIONS(5242),
    [anon_sym_longint] = ACTIONS(5242),
    [anon_sym_integer] = ACTIONS(5242),
    [anon_sym_time] = ACTIONS(5242),
    [anon_sym_bit] = ACTIONS(5242),
    [anon_sym_logic] = ACTIONS(5242),
    [anon_sym_reg] = ACTIONS(5242),
    [anon_sym_shortreal] = ACTIONS(5242),
    [anon_sym_real] = ACTIONS(5242),
    [anon_sym_realtime] = ACTIONS(5242),
    [anon_sym_supply0] = ACTIONS(5242),
    [anon_sym_supply1] = ACTIONS(5242),
    [anon_sym_signed] = ACTIONS(5242),
    [anon_sym_unsigned] = ACTIONS(5242),
    [anon_sym_task] = ACTIONS(5242),
    [anon_sym_modport] = ACTIONS(5242),
    [anon_sym_assert] = ACTIONS(5242),
    [anon_sym_property] = ACTIONS(5242),
    [anon_sym_assume] = ACTIONS(5242),
    [anon_sym_cover] = ACTIONS(5242),
    [anon_sym_sequence] = ACTIONS(5242),
    [anon_sym_restrict] = ACTIONS(5242),
    [anon_sym_not] = ACTIONS(5242),
    [anon_sym_or] = ACTIONS(5242),
    [anon_sym_and] = ACTIONS(5242),
    [anon_sym_case] = ACTIONS(5242),
    [anon_sym_always] = ACTIONS(5242),
    [anon_sym_covergroup] = ACTIONS(5242),
    [anon_sym_let] = ACTIONS(5242),
    [anon_sym_pulldown] = ACTIONS(5242),
    [anon_sym_pullup] = ACTIONS(5242),
    [anon_sym_cmos] = ACTIONS(5242),
    [anon_sym_rcmos] = ACTIONS(5242),
    [anon_sym_bufif0] = ACTIONS(5242),
    [anon_sym_bufif1] = ACTIONS(5242),
    [anon_sym_notif0] = ACTIONS(5242),
    [anon_sym_notif1] = ACTIONS(5242),
    [anon_sym_nmos] = ACTIONS(5242),
    [anon_sym_pmos] = ACTIONS(5242),
    [anon_sym_rnmos] = ACTIONS(5242),
    [anon_sym_rpmos] = ACTIONS(5242),
    [anon_sym_nand] = ACTIONS(5242),
    [anon_sym_nor] = ACTIONS(5242),
    [anon_sym_xor] = ACTIONS(5242),
    [anon_sym_xnor] = ACTIONS(5242),
    [anon_sym_buf] = ACTIONS(5242),
    [anon_sym_tranif0] = ACTIONS(5242),
    [anon_sym_tranif1] = ACTIONS(5242),
    [anon_sym_rtranif1] = ACTIONS(5242),
    [anon_sym_rtranif0] = ACTIONS(5242),
    [anon_sym_tran] = ACTIONS(5242),
    [anon_sym_rtran] = ACTIONS(5242),
    [anon_sym_generate] = ACTIONS(5242),
    [anon_sym_for] = ACTIONS(5242),
    [anon_sym_primitive] = ACTIONS(5242),
    [anon_sym_initial] = ACTIONS(5242),
    [anon_sym_assign] = ACTIONS(5242),
    [anon_sym_alias] = ACTIONS(5242),
    [anon_sym_always_comb] = ACTIONS(5242),
    [anon_sym_always_latch] = ACTIONS(5242),
    [anon_sym_always_ff] = ACTIONS(5242),
    [anon_sym_final] = ACTIONS(5242),
    [anon_sym_global] = ACTIONS(5242),
    [anon_sym_specify] = ACTIONS(5242),
    [anon_sym_LPAREN_STAR] = ACTIONS(5240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5240),
    [anon_sym_DOLLARunit] = ACTIONS(5240),
  },
  [846] = {
    [ts_builtin_sym_end] = ACTIONS(5244),
    [sym_simple_identifier] = ACTIONS(5246),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5244),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5244),
    [anon_sym_BQUOTE] = ACTIONS(5246),
    [aux_sym_id_directive_token1] = ACTIONS(5244),
    [aux_sym_id_directive_token2] = ACTIONS(5244),
    [aux_sym_id_directive_token3] = ACTIONS(5244),
    [aux_sym_id_directive_token4] = ACTIONS(5246),
    [aux_sym_zero_directive_token1] = ACTIONS(5244),
    [aux_sym_zero_directive_token2] = ACTIONS(5244),
    [aux_sym_zero_directive_token3] = ACTIONS(5244),
    [aux_sym_zero_directive_token4] = ACTIONS(5244),
    [aux_sym_zero_directive_token5] = ACTIONS(5244),
    [aux_sym_zero_directive_token6] = ACTIONS(5244),
    [aux_sym_zero_directive_token7] = ACTIONS(5244),
    [aux_sym_zero_directive_token8] = ACTIONS(5244),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5244),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5244),
    [anon_sym_wire] = ACTIONS(5246),
    [anon_sym_tri] = ACTIONS(5246),
    [anon_sym_tri0] = ACTIONS(5246),
    [anon_sym_tri1] = ACTIONS(5246),
    [anon_sym_wand] = ACTIONS(5246),
    [anon_sym_triand] = ACTIONS(5246),
    [anon_sym_wor] = ACTIONS(5246),
    [anon_sym_trior] = ACTIONS(5246),
    [anon_sym_trireg] = ACTIONS(5246),
    [anon_sym_uwire] = ACTIONS(5246),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5244),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5244),
    [aux_sym_begin_keywords_token1] = ACTIONS(5244),
    [anon_sym_SEMI] = ACTIONS(5244),
    [anon_sym_endmodule] = ACTIONS(5246),
    [anon_sym_extern] = ACTIONS(5246),
    [anon_sym_module] = ACTIONS(5246),
    [anon_sym_macromodule] = ACTIONS(5246),
    [anon_sym_endinterface] = ACTIONS(5246),
    [anon_sym_interface] = ACTIONS(5246),
    [anon_sym_endprogram] = ACTIONS(5246),
    [anon_sym_program] = ACTIONS(5246),
    [anon_sym_checker] = ACTIONS(5246),
    [anon_sym_virtual] = ACTIONS(5246),
    [anon_sym_class] = ACTIONS(5246),
    [anon_sym_package] = ACTIONS(5246),
    [anon_sym_endpackage] = ACTIONS(5246),
    [anon_sym_timeunit] = ACTIONS(5246),
    [anon_sym_timeprecision] = ACTIONS(5246),
    [anon_sym_type] = ACTIONS(5246),
    [anon_sym_input] = ACTIONS(5246),
    [anon_sym_output] = ACTIONS(5246),
    [anon_sym_inout] = ACTIONS(5246),
    [anon_sym_ref] = ACTIONS(5246),
    [anon_sym_DOLLARfatal] = ACTIONS(5244),
    [anon_sym_DOLLARerror] = ACTIONS(5244),
    [anon_sym_DOLLARwarning] = ACTIONS(5244),
    [anon_sym_DOLLARinfo] = ACTIONS(5244),
    [anon_sym_default] = ACTIONS(5246),
    [anon_sym_clocking] = ACTIONS(5246),
    [anon_sym_defparam] = ACTIONS(5246),
    [anon_sym_bind] = ACTIONS(5246),
    [anon_sym_const] = ACTIONS(5246),
    [anon_sym_function] = ACTIONS(5246),
    [anon_sym_static] = ACTIONS(5246),
    [anon_sym_constraint] = ACTIONS(5246),
    [anon_sym_if] = ACTIONS(5246),
    [anon_sym_else] = ACTIONS(5246),
    [anon_sym_LBRACK] = ACTIONS(5244),
    [anon_sym_localparam] = ACTIONS(5246),
    [anon_sym_parameter] = ACTIONS(5246),
    [anon_sym_specparam] = ACTIONS(5246),
    [anon_sym_var] = ACTIONS(5246),
    [anon_sym_import] = ACTIONS(5246),
    [anon_sym_export] = ACTIONS(5246),
    [anon_sym_genvar] = ACTIONS(5246),
    [anon_sym_interconnect] = ACTIONS(5246),
    [anon_sym_typedef] = ACTIONS(5246),
    [anon_sym_enum] = ACTIONS(5246),
    [anon_sym_struct] = ACTIONS(5246),
    [anon_sym_union] = ACTIONS(5246),
    [anon_sym_nettype] = ACTIONS(5246),
    [anon_sym_automatic] = ACTIONS(5246),
    [anon_sym_string] = ACTIONS(5246),
    [anon_sym_chandle] = ACTIONS(5246),
    [anon_sym_event] = ACTIONS(5246),
    [anon_sym_byte] = ACTIONS(5246),
    [anon_sym_shortint] = ACTIONS(5246),
    [anon_sym_int] = ACTIONS(5246),
    [anon_sym_longint] = ACTIONS(5246),
    [anon_sym_integer] = ACTIONS(5246),
    [anon_sym_time] = ACTIONS(5246),
    [anon_sym_bit] = ACTIONS(5246),
    [anon_sym_logic] = ACTIONS(5246),
    [anon_sym_reg] = ACTIONS(5246),
    [anon_sym_shortreal] = ACTIONS(5246),
    [anon_sym_real] = ACTIONS(5246),
    [anon_sym_realtime] = ACTIONS(5246),
    [anon_sym_supply0] = ACTIONS(5246),
    [anon_sym_supply1] = ACTIONS(5246),
    [anon_sym_signed] = ACTIONS(5246),
    [anon_sym_unsigned] = ACTIONS(5246),
    [anon_sym_task] = ACTIONS(5246),
    [anon_sym_modport] = ACTIONS(5246),
    [anon_sym_assert] = ACTIONS(5246),
    [anon_sym_property] = ACTIONS(5246),
    [anon_sym_assume] = ACTIONS(5246),
    [anon_sym_cover] = ACTIONS(5246),
    [anon_sym_sequence] = ACTIONS(5246),
    [anon_sym_restrict] = ACTIONS(5246),
    [anon_sym_not] = ACTIONS(5246),
    [anon_sym_or] = ACTIONS(5246),
    [anon_sym_and] = ACTIONS(5246),
    [anon_sym_case] = ACTIONS(5246),
    [anon_sym_always] = ACTIONS(5246),
    [anon_sym_covergroup] = ACTIONS(5246),
    [anon_sym_let] = ACTIONS(5246),
    [anon_sym_pulldown] = ACTIONS(5246),
    [anon_sym_pullup] = ACTIONS(5246),
    [anon_sym_cmos] = ACTIONS(5246),
    [anon_sym_rcmos] = ACTIONS(5246),
    [anon_sym_bufif0] = ACTIONS(5246),
    [anon_sym_bufif1] = ACTIONS(5246),
    [anon_sym_notif0] = ACTIONS(5246),
    [anon_sym_notif1] = ACTIONS(5246),
    [anon_sym_nmos] = ACTIONS(5246),
    [anon_sym_pmos] = ACTIONS(5246),
    [anon_sym_rnmos] = ACTIONS(5246),
    [anon_sym_rpmos] = ACTIONS(5246),
    [anon_sym_nand] = ACTIONS(5246),
    [anon_sym_nor] = ACTIONS(5246),
    [anon_sym_xor] = ACTIONS(5246),
    [anon_sym_xnor] = ACTIONS(5246),
    [anon_sym_buf] = ACTIONS(5246),
    [anon_sym_tranif0] = ACTIONS(5246),
    [anon_sym_tranif1] = ACTIONS(5246),
    [anon_sym_rtranif1] = ACTIONS(5246),
    [anon_sym_rtranif0] = ACTIONS(5246),
    [anon_sym_tran] = ACTIONS(5246),
    [anon_sym_rtran] = ACTIONS(5246),
    [anon_sym_generate] = ACTIONS(5246),
    [anon_sym_for] = ACTIONS(5246),
    [anon_sym_primitive] = ACTIONS(5246),
    [anon_sym_initial] = ACTIONS(5246),
    [anon_sym_assign] = ACTIONS(5246),
    [anon_sym_alias] = ACTIONS(5246),
    [anon_sym_always_comb] = ACTIONS(5246),
    [anon_sym_always_latch] = ACTIONS(5246),
    [anon_sym_always_ff] = ACTIONS(5246),
    [anon_sym_final] = ACTIONS(5246),
    [anon_sym_global] = ACTIONS(5246),
    [anon_sym_specify] = ACTIONS(5246),
    [anon_sym_LPAREN_STAR] = ACTIONS(5244),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5244),
    [anon_sym_DOLLARunit] = ACTIONS(5244),
  },
  [847] = {
    [ts_builtin_sym_end] = ACTIONS(5248),
    [sym_simple_identifier] = ACTIONS(5250),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5248),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5248),
    [anon_sym_BQUOTE] = ACTIONS(5250),
    [aux_sym_id_directive_token1] = ACTIONS(5248),
    [aux_sym_id_directive_token2] = ACTIONS(5248),
    [aux_sym_id_directive_token3] = ACTIONS(5248),
    [aux_sym_id_directive_token4] = ACTIONS(5250),
    [aux_sym_zero_directive_token1] = ACTIONS(5248),
    [aux_sym_zero_directive_token2] = ACTIONS(5248),
    [aux_sym_zero_directive_token3] = ACTIONS(5248),
    [aux_sym_zero_directive_token4] = ACTIONS(5248),
    [aux_sym_zero_directive_token5] = ACTIONS(5248),
    [aux_sym_zero_directive_token6] = ACTIONS(5248),
    [aux_sym_zero_directive_token7] = ACTIONS(5248),
    [aux_sym_zero_directive_token8] = ACTIONS(5248),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5248),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5248),
    [anon_sym_wire] = ACTIONS(5250),
    [anon_sym_tri] = ACTIONS(5250),
    [anon_sym_tri0] = ACTIONS(5250),
    [anon_sym_tri1] = ACTIONS(5250),
    [anon_sym_wand] = ACTIONS(5250),
    [anon_sym_triand] = ACTIONS(5250),
    [anon_sym_wor] = ACTIONS(5250),
    [anon_sym_trior] = ACTIONS(5250),
    [anon_sym_trireg] = ACTIONS(5250),
    [anon_sym_uwire] = ACTIONS(5250),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5248),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5248),
    [aux_sym_begin_keywords_token1] = ACTIONS(5248),
    [anon_sym_SEMI] = ACTIONS(5248),
    [anon_sym_endmodule] = ACTIONS(5250),
    [anon_sym_extern] = ACTIONS(5250),
    [anon_sym_module] = ACTIONS(5250),
    [anon_sym_macromodule] = ACTIONS(5250),
    [anon_sym_endinterface] = ACTIONS(5250),
    [anon_sym_interface] = ACTIONS(5250),
    [anon_sym_endprogram] = ACTIONS(5250),
    [anon_sym_program] = ACTIONS(5250),
    [anon_sym_checker] = ACTIONS(5250),
    [anon_sym_virtual] = ACTIONS(5250),
    [anon_sym_class] = ACTIONS(5250),
    [anon_sym_package] = ACTIONS(5250),
    [anon_sym_endpackage] = ACTIONS(5250),
    [anon_sym_timeunit] = ACTIONS(5250),
    [anon_sym_timeprecision] = ACTIONS(5250),
    [anon_sym_type] = ACTIONS(5250),
    [anon_sym_input] = ACTIONS(5250),
    [anon_sym_output] = ACTIONS(5250),
    [anon_sym_inout] = ACTIONS(5250),
    [anon_sym_ref] = ACTIONS(5250),
    [anon_sym_DOLLARfatal] = ACTIONS(5248),
    [anon_sym_DOLLARerror] = ACTIONS(5248),
    [anon_sym_DOLLARwarning] = ACTIONS(5248),
    [anon_sym_DOLLARinfo] = ACTIONS(5248),
    [anon_sym_default] = ACTIONS(5250),
    [anon_sym_clocking] = ACTIONS(5250),
    [anon_sym_defparam] = ACTIONS(5250),
    [anon_sym_bind] = ACTIONS(5250),
    [anon_sym_const] = ACTIONS(5250),
    [anon_sym_function] = ACTIONS(5250),
    [anon_sym_static] = ACTIONS(5250),
    [anon_sym_constraint] = ACTIONS(5250),
    [anon_sym_if] = ACTIONS(5250),
    [anon_sym_else] = ACTIONS(5250),
    [anon_sym_LBRACK] = ACTIONS(5248),
    [anon_sym_localparam] = ACTIONS(5250),
    [anon_sym_parameter] = ACTIONS(5250),
    [anon_sym_specparam] = ACTIONS(5250),
    [anon_sym_var] = ACTIONS(5250),
    [anon_sym_import] = ACTIONS(5250),
    [anon_sym_export] = ACTIONS(5250),
    [anon_sym_genvar] = ACTIONS(5250),
    [anon_sym_interconnect] = ACTIONS(5250),
    [anon_sym_typedef] = ACTIONS(5250),
    [anon_sym_enum] = ACTIONS(5250),
    [anon_sym_struct] = ACTIONS(5250),
    [anon_sym_union] = ACTIONS(5250),
    [anon_sym_nettype] = ACTIONS(5250),
    [anon_sym_automatic] = ACTIONS(5250),
    [anon_sym_string] = ACTIONS(5250),
    [anon_sym_chandle] = ACTIONS(5250),
    [anon_sym_event] = ACTIONS(5250),
    [anon_sym_byte] = ACTIONS(5250),
    [anon_sym_shortint] = ACTIONS(5250),
    [anon_sym_int] = ACTIONS(5250),
    [anon_sym_longint] = ACTIONS(5250),
    [anon_sym_integer] = ACTIONS(5250),
    [anon_sym_time] = ACTIONS(5250),
    [anon_sym_bit] = ACTIONS(5250),
    [anon_sym_logic] = ACTIONS(5250),
    [anon_sym_reg] = ACTIONS(5250),
    [anon_sym_shortreal] = ACTIONS(5250),
    [anon_sym_real] = ACTIONS(5250),
    [anon_sym_realtime] = ACTIONS(5250),
    [anon_sym_supply0] = ACTIONS(5250),
    [anon_sym_supply1] = ACTIONS(5250),
    [anon_sym_signed] = ACTIONS(5250),
    [anon_sym_unsigned] = ACTIONS(5250),
    [anon_sym_task] = ACTIONS(5250),
    [anon_sym_modport] = ACTIONS(5250),
    [anon_sym_assert] = ACTIONS(5250),
    [anon_sym_property] = ACTIONS(5250),
    [anon_sym_assume] = ACTIONS(5250),
    [anon_sym_cover] = ACTIONS(5250),
    [anon_sym_sequence] = ACTIONS(5250),
    [anon_sym_restrict] = ACTIONS(5250),
    [anon_sym_not] = ACTIONS(5250),
    [anon_sym_or] = ACTIONS(5250),
    [anon_sym_and] = ACTIONS(5250),
    [anon_sym_case] = ACTIONS(5250),
    [anon_sym_always] = ACTIONS(5250),
    [anon_sym_covergroup] = ACTIONS(5250),
    [anon_sym_let] = ACTIONS(5250),
    [anon_sym_pulldown] = ACTIONS(5250),
    [anon_sym_pullup] = ACTIONS(5250),
    [anon_sym_cmos] = ACTIONS(5250),
    [anon_sym_rcmos] = ACTIONS(5250),
    [anon_sym_bufif0] = ACTIONS(5250),
    [anon_sym_bufif1] = ACTIONS(5250),
    [anon_sym_notif0] = ACTIONS(5250),
    [anon_sym_notif1] = ACTIONS(5250),
    [anon_sym_nmos] = ACTIONS(5250),
    [anon_sym_pmos] = ACTIONS(5250),
    [anon_sym_rnmos] = ACTIONS(5250),
    [anon_sym_rpmos] = ACTIONS(5250),
    [anon_sym_nand] = ACTIONS(5250),
    [anon_sym_nor] = ACTIONS(5250),
    [anon_sym_xor] = ACTIONS(5250),
    [anon_sym_xnor] = ACTIONS(5250),
    [anon_sym_buf] = ACTIONS(5250),
    [anon_sym_tranif0] = ACTIONS(5250),
    [anon_sym_tranif1] = ACTIONS(5250),
    [anon_sym_rtranif1] = ACTIONS(5250),
    [anon_sym_rtranif0] = ACTIONS(5250),
    [anon_sym_tran] = ACTIONS(5250),
    [anon_sym_rtran] = ACTIONS(5250),
    [anon_sym_generate] = ACTIONS(5250),
    [anon_sym_for] = ACTIONS(5250),
    [anon_sym_primitive] = ACTIONS(5250),
    [anon_sym_initial] = ACTIONS(5250),
    [anon_sym_assign] = ACTIONS(5250),
    [anon_sym_alias] = ACTIONS(5250),
    [anon_sym_always_comb] = ACTIONS(5250),
    [anon_sym_always_latch] = ACTIONS(5250),
    [anon_sym_always_ff] = ACTIONS(5250),
    [anon_sym_final] = ACTIONS(5250),
    [anon_sym_global] = ACTIONS(5250),
    [anon_sym_specify] = ACTIONS(5250),
    [anon_sym_LPAREN_STAR] = ACTIONS(5248),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5248),
    [anon_sym_DOLLARunit] = ACTIONS(5248),
  },
  [848] = {
    [ts_builtin_sym_end] = ACTIONS(5252),
    [sym_simple_identifier] = ACTIONS(5254),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5252),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5252),
    [anon_sym_BQUOTE] = ACTIONS(5254),
    [aux_sym_id_directive_token1] = ACTIONS(5252),
    [aux_sym_id_directive_token2] = ACTIONS(5252),
    [aux_sym_id_directive_token3] = ACTIONS(5252),
    [aux_sym_id_directive_token4] = ACTIONS(5254),
    [aux_sym_zero_directive_token1] = ACTIONS(5252),
    [aux_sym_zero_directive_token2] = ACTIONS(5252),
    [aux_sym_zero_directive_token3] = ACTIONS(5252),
    [aux_sym_zero_directive_token4] = ACTIONS(5252),
    [aux_sym_zero_directive_token5] = ACTIONS(5252),
    [aux_sym_zero_directive_token6] = ACTIONS(5252),
    [aux_sym_zero_directive_token7] = ACTIONS(5252),
    [aux_sym_zero_directive_token8] = ACTIONS(5252),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5252),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5252),
    [anon_sym_wire] = ACTIONS(5254),
    [anon_sym_tri] = ACTIONS(5254),
    [anon_sym_tri0] = ACTIONS(5254),
    [anon_sym_tri1] = ACTIONS(5254),
    [anon_sym_wand] = ACTIONS(5254),
    [anon_sym_triand] = ACTIONS(5254),
    [anon_sym_wor] = ACTIONS(5254),
    [anon_sym_trior] = ACTIONS(5254),
    [anon_sym_trireg] = ACTIONS(5254),
    [anon_sym_uwire] = ACTIONS(5254),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5252),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5252),
    [aux_sym_begin_keywords_token1] = ACTIONS(5252),
    [anon_sym_SEMI] = ACTIONS(5252),
    [anon_sym_endmodule] = ACTIONS(5254),
    [anon_sym_extern] = ACTIONS(5254),
    [anon_sym_module] = ACTIONS(5254),
    [anon_sym_macromodule] = ACTIONS(5254),
    [anon_sym_endinterface] = ACTIONS(5254),
    [anon_sym_interface] = ACTIONS(5254),
    [anon_sym_endprogram] = ACTIONS(5254),
    [anon_sym_program] = ACTIONS(5254),
    [anon_sym_checker] = ACTIONS(5254),
    [anon_sym_virtual] = ACTIONS(5254),
    [anon_sym_class] = ACTIONS(5254),
    [anon_sym_package] = ACTIONS(5254),
    [anon_sym_endpackage] = ACTIONS(5254),
    [anon_sym_timeunit] = ACTIONS(5254),
    [anon_sym_timeprecision] = ACTIONS(5254),
    [anon_sym_type] = ACTIONS(5254),
    [anon_sym_input] = ACTIONS(5254),
    [anon_sym_output] = ACTIONS(5254),
    [anon_sym_inout] = ACTIONS(5254),
    [anon_sym_ref] = ACTIONS(5254),
    [anon_sym_DOLLARfatal] = ACTIONS(5252),
    [anon_sym_DOLLARerror] = ACTIONS(5252),
    [anon_sym_DOLLARwarning] = ACTIONS(5252),
    [anon_sym_DOLLARinfo] = ACTIONS(5252),
    [anon_sym_default] = ACTIONS(5254),
    [anon_sym_clocking] = ACTIONS(5254),
    [anon_sym_defparam] = ACTIONS(5254),
    [anon_sym_bind] = ACTIONS(5254),
    [anon_sym_const] = ACTIONS(5254),
    [anon_sym_function] = ACTIONS(5254),
    [anon_sym_static] = ACTIONS(5254),
    [anon_sym_constraint] = ACTIONS(5254),
    [anon_sym_if] = ACTIONS(5254),
    [anon_sym_else] = ACTIONS(5254),
    [anon_sym_LBRACK] = ACTIONS(5252),
    [anon_sym_localparam] = ACTIONS(5254),
    [anon_sym_parameter] = ACTIONS(5254),
    [anon_sym_specparam] = ACTIONS(5254),
    [anon_sym_var] = ACTIONS(5254),
    [anon_sym_import] = ACTIONS(5254),
    [anon_sym_export] = ACTIONS(5254),
    [anon_sym_genvar] = ACTIONS(5254),
    [anon_sym_interconnect] = ACTIONS(5254),
    [anon_sym_typedef] = ACTIONS(5254),
    [anon_sym_enum] = ACTIONS(5254),
    [anon_sym_struct] = ACTIONS(5254),
    [anon_sym_union] = ACTIONS(5254),
    [anon_sym_nettype] = ACTIONS(5254),
    [anon_sym_automatic] = ACTIONS(5254),
    [anon_sym_string] = ACTIONS(5254),
    [anon_sym_chandle] = ACTIONS(5254),
    [anon_sym_event] = ACTIONS(5254),
    [anon_sym_byte] = ACTIONS(5254),
    [anon_sym_shortint] = ACTIONS(5254),
    [anon_sym_int] = ACTIONS(5254),
    [anon_sym_longint] = ACTIONS(5254),
    [anon_sym_integer] = ACTIONS(5254),
    [anon_sym_time] = ACTIONS(5254),
    [anon_sym_bit] = ACTIONS(5254),
    [anon_sym_logic] = ACTIONS(5254),
    [anon_sym_reg] = ACTIONS(5254),
    [anon_sym_shortreal] = ACTIONS(5254),
    [anon_sym_real] = ACTIONS(5254),
    [anon_sym_realtime] = ACTIONS(5254),
    [anon_sym_supply0] = ACTIONS(5254),
    [anon_sym_supply1] = ACTIONS(5254),
    [anon_sym_signed] = ACTIONS(5254),
    [anon_sym_unsigned] = ACTIONS(5254),
    [anon_sym_task] = ACTIONS(5254),
    [anon_sym_modport] = ACTIONS(5254),
    [anon_sym_assert] = ACTIONS(5254),
    [anon_sym_property] = ACTIONS(5254),
    [anon_sym_assume] = ACTIONS(5254),
    [anon_sym_cover] = ACTIONS(5254),
    [anon_sym_sequence] = ACTIONS(5254),
    [anon_sym_restrict] = ACTIONS(5254),
    [anon_sym_not] = ACTIONS(5254),
    [anon_sym_or] = ACTIONS(5254),
    [anon_sym_and] = ACTIONS(5254),
    [anon_sym_case] = ACTIONS(5254),
    [anon_sym_always] = ACTIONS(5254),
    [anon_sym_covergroup] = ACTIONS(5254),
    [anon_sym_let] = ACTIONS(5254),
    [anon_sym_pulldown] = ACTIONS(5254),
    [anon_sym_pullup] = ACTIONS(5254),
    [anon_sym_cmos] = ACTIONS(5254),
    [anon_sym_rcmos] = ACTIONS(5254),
    [anon_sym_bufif0] = ACTIONS(5254),
    [anon_sym_bufif1] = ACTIONS(5254),
    [anon_sym_notif0] = ACTIONS(5254),
    [anon_sym_notif1] = ACTIONS(5254),
    [anon_sym_nmos] = ACTIONS(5254),
    [anon_sym_pmos] = ACTIONS(5254),
    [anon_sym_rnmos] = ACTIONS(5254),
    [anon_sym_rpmos] = ACTIONS(5254),
    [anon_sym_nand] = ACTIONS(5254),
    [anon_sym_nor] = ACTIONS(5254),
    [anon_sym_xor] = ACTIONS(5254),
    [anon_sym_xnor] = ACTIONS(5254),
    [anon_sym_buf] = ACTIONS(5254),
    [anon_sym_tranif0] = ACTIONS(5254),
    [anon_sym_tranif1] = ACTIONS(5254),
    [anon_sym_rtranif1] = ACTIONS(5254),
    [anon_sym_rtranif0] = ACTIONS(5254),
    [anon_sym_tran] = ACTIONS(5254),
    [anon_sym_rtran] = ACTIONS(5254),
    [anon_sym_generate] = ACTIONS(5254),
    [anon_sym_for] = ACTIONS(5254),
    [anon_sym_primitive] = ACTIONS(5254),
    [anon_sym_initial] = ACTIONS(5254),
    [anon_sym_assign] = ACTIONS(5254),
    [anon_sym_alias] = ACTIONS(5254),
    [anon_sym_always_comb] = ACTIONS(5254),
    [anon_sym_always_latch] = ACTIONS(5254),
    [anon_sym_always_ff] = ACTIONS(5254),
    [anon_sym_final] = ACTIONS(5254),
    [anon_sym_global] = ACTIONS(5254),
    [anon_sym_specify] = ACTIONS(5254),
    [anon_sym_LPAREN_STAR] = ACTIONS(5252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5252),
    [anon_sym_DOLLARunit] = ACTIONS(5252),
  },
  [849] = {
    [ts_builtin_sym_end] = ACTIONS(4700),
    [sym_simple_identifier] = ACTIONS(4702),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4700),
    [anon_sym_BQUOTE] = ACTIONS(4702),
    [aux_sym_id_directive_token1] = ACTIONS(4700),
    [aux_sym_id_directive_token2] = ACTIONS(4700),
    [aux_sym_id_directive_token3] = ACTIONS(4700),
    [aux_sym_id_directive_token4] = ACTIONS(4702),
    [aux_sym_zero_directive_token1] = ACTIONS(4700),
    [aux_sym_zero_directive_token2] = ACTIONS(4700),
    [aux_sym_zero_directive_token3] = ACTIONS(4700),
    [aux_sym_zero_directive_token4] = ACTIONS(4700),
    [aux_sym_zero_directive_token5] = ACTIONS(4700),
    [aux_sym_zero_directive_token6] = ACTIONS(4700),
    [aux_sym_zero_directive_token7] = ACTIONS(4700),
    [aux_sym_zero_directive_token8] = ACTIONS(4700),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4700),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4700),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4700),
    [aux_sym_begin_keywords_token1] = ACTIONS(4700),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_endmodule] = ACTIONS(4702),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_module] = ACTIONS(4702),
    [anon_sym_macromodule] = ACTIONS(4702),
    [anon_sym_endinterface] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_endprogram] = ACTIONS(4702),
    [anon_sym_program] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_package] = ACTIONS(4702),
    [anon_sym_endpackage] = ACTIONS(4702),
    [anon_sym_timeunit] = ACTIONS(4702),
    [anon_sym_timeprecision] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_input] = ACTIONS(4702),
    [anon_sym_output] = ACTIONS(4702),
    [anon_sym_inout] = ACTIONS(4702),
    [anon_sym_ref] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_specparam] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_modport] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_primitive] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_specify] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [850] = {
    [ts_builtin_sym_end] = ACTIONS(4516),
    [sym_simple_identifier] = ACTIONS(4518),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4516),
    [anon_sym_BQUOTE] = ACTIONS(4518),
    [aux_sym_id_directive_token1] = ACTIONS(4516),
    [aux_sym_id_directive_token2] = ACTIONS(4516),
    [aux_sym_id_directive_token3] = ACTIONS(4516),
    [aux_sym_id_directive_token4] = ACTIONS(4518),
    [aux_sym_zero_directive_token1] = ACTIONS(4516),
    [aux_sym_zero_directive_token2] = ACTIONS(4516),
    [aux_sym_zero_directive_token3] = ACTIONS(4516),
    [aux_sym_zero_directive_token4] = ACTIONS(4516),
    [aux_sym_zero_directive_token5] = ACTIONS(4516),
    [aux_sym_zero_directive_token6] = ACTIONS(4516),
    [aux_sym_zero_directive_token7] = ACTIONS(4516),
    [aux_sym_zero_directive_token8] = ACTIONS(4516),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4516),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4516),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4516),
    [aux_sym_begin_keywords_token1] = ACTIONS(4516),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_endmodule] = ACTIONS(4518),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_module] = ACTIONS(4518),
    [anon_sym_macromodule] = ACTIONS(4518),
    [anon_sym_endinterface] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_endprogram] = ACTIONS(4518),
    [anon_sym_program] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_package] = ACTIONS(4518),
    [anon_sym_endpackage] = ACTIONS(4518),
    [anon_sym_timeunit] = ACTIONS(4518),
    [anon_sym_timeprecision] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_input] = ACTIONS(4518),
    [anon_sym_output] = ACTIONS(4518),
    [anon_sym_inout] = ACTIONS(4518),
    [anon_sym_ref] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_specparam] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_modport] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_primitive] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_specify] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [851] = {
    [ts_builtin_sym_end] = ACTIONS(4198),
    [sym_simple_identifier] = ACTIONS(4200),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4198),
    [anon_sym_BQUOTE] = ACTIONS(4200),
    [aux_sym_id_directive_token1] = ACTIONS(4198),
    [aux_sym_id_directive_token2] = ACTIONS(4198),
    [aux_sym_id_directive_token3] = ACTIONS(4198),
    [aux_sym_id_directive_token4] = ACTIONS(4200),
    [aux_sym_zero_directive_token1] = ACTIONS(4198),
    [aux_sym_zero_directive_token2] = ACTIONS(4198),
    [aux_sym_zero_directive_token3] = ACTIONS(4198),
    [aux_sym_zero_directive_token4] = ACTIONS(4198),
    [aux_sym_zero_directive_token5] = ACTIONS(4198),
    [aux_sym_zero_directive_token6] = ACTIONS(4198),
    [aux_sym_zero_directive_token7] = ACTIONS(4198),
    [aux_sym_zero_directive_token8] = ACTIONS(4198),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4198),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4198),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4198),
    [aux_sym_begin_keywords_token1] = ACTIONS(4198),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_endmodule] = ACTIONS(4200),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_module] = ACTIONS(4200),
    [anon_sym_macromodule] = ACTIONS(4200),
    [anon_sym_endinterface] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_endprogram] = ACTIONS(4200),
    [anon_sym_program] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_package] = ACTIONS(4200),
    [anon_sym_endpackage] = ACTIONS(4200),
    [anon_sym_timeunit] = ACTIONS(4200),
    [anon_sym_timeprecision] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_input] = ACTIONS(4200),
    [anon_sym_output] = ACTIONS(4200),
    [anon_sym_inout] = ACTIONS(4200),
    [anon_sym_ref] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_specparam] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_modport] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_primitive] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_specify] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [852] = {
    [ts_builtin_sym_end] = ACTIONS(5256),
    [sym_simple_identifier] = ACTIONS(5258),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5256),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5256),
    [anon_sym_BQUOTE] = ACTIONS(5258),
    [aux_sym_id_directive_token1] = ACTIONS(5256),
    [aux_sym_id_directive_token2] = ACTIONS(5256),
    [aux_sym_id_directive_token3] = ACTIONS(5256),
    [aux_sym_id_directive_token4] = ACTIONS(5258),
    [aux_sym_zero_directive_token1] = ACTIONS(5256),
    [aux_sym_zero_directive_token2] = ACTIONS(5256),
    [aux_sym_zero_directive_token3] = ACTIONS(5256),
    [aux_sym_zero_directive_token4] = ACTIONS(5256),
    [aux_sym_zero_directive_token5] = ACTIONS(5256),
    [aux_sym_zero_directive_token6] = ACTIONS(5256),
    [aux_sym_zero_directive_token7] = ACTIONS(5256),
    [aux_sym_zero_directive_token8] = ACTIONS(5256),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5256),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5256),
    [anon_sym_wire] = ACTIONS(5258),
    [anon_sym_tri] = ACTIONS(5258),
    [anon_sym_tri0] = ACTIONS(5258),
    [anon_sym_tri1] = ACTIONS(5258),
    [anon_sym_wand] = ACTIONS(5258),
    [anon_sym_triand] = ACTIONS(5258),
    [anon_sym_wor] = ACTIONS(5258),
    [anon_sym_trior] = ACTIONS(5258),
    [anon_sym_trireg] = ACTIONS(5258),
    [anon_sym_uwire] = ACTIONS(5258),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5256),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5256),
    [aux_sym_begin_keywords_token1] = ACTIONS(5256),
    [anon_sym_SEMI] = ACTIONS(5256),
    [anon_sym_endmodule] = ACTIONS(5258),
    [anon_sym_extern] = ACTIONS(5258),
    [anon_sym_module] = ACTIONS(5258),
    [anon_sym_macromodule] = ACTIONS(5258),
    [anon_sym_endinterface] = ACTIONS(5258),
    [anon_sym_interface] = ACTIONS(5258),
    [anon_sym_endprogram] = ACTIONS(5258),
    [anon_sym_program] = ACTIONS(5258),
    [anon_sym_checker] = ACTIONS(5258),
    [anon_sym_virtual] = ACTIONS(5258),
    [anon_sym_class] = ACTIONS(5258),
    [anon_sym_package] = ACTIONS(5258),
    [anon_sym_endpackage] = ACTIONS(5258),
    [anon_sym_timeunit] = ACTIONS(5258),
    [anon_sym_timeprecision] = ACTIONS(5258),
    [anon_sym_type] = ACTIONS(5258),
    [anon_sym_input] = ACTIONS(5258),
    [anon_sym_output] = ACTIONS(5258),
    [anon_sym_inout] = ACTIONS(5258),
    [anon_sym_ref] = ACTIONS(5258),
    [anon_sym_DOLLARfatal] = ACTIONS(5256),
    [anon_sym_DOLLARerror] = ACTIONS(5256),
    [anon_sym_DOLLARwarning] = ACTIONS(5256),
    [anon_sym_DOLLARinfo] = ACTIONS(5256),
    [anon_sym_default] = ACTIONS(5258),
    [anon_sym_clocking] = ACTIONS(5258),
    [anon_sym_defparam] = ACTIONS(5258),
    [anon_sym_bind] = ACTIONS(5258),
    [anon_sym_const] = ACTIONS(5258),
    [anon_sym_function] = ACTIONS(5258),
    [anon_sym_static] = ACTIONS(5258),
    [anon_sym_constraint] = ACTIONS(5258),
    [anon_sym_if] = ACTIONS(5258),
    [anon_sym_else] = ACTIONS(5258),
    [anon_sym_LBRACK] = ACTIONS(5256),
    [anon_sym_localparam] = ACTIONS(5258),
    [anon_sym_parameter] = ACTIONS(5258),
    [anon_sym_specparam] = ACTIONS(5258),
    [anon_sym_var] = ACTIONS(5258),
    [anon_sym_import] = ACTIONS(5258),
    [anon_sym_export] = ACTIONS(5258),
    [anon_sym_genvar] = ACTIONS(5258),
    [anon_sym_interconnect] = ACTIONS(5258),
    [anon_sym_typedef] = ACTIONS(5258),
    [anon_sym_enum] = ACTIONS(5258),
    [anon_sym_struct] = ACTIONS(5258),
    [anon_sym_union] = ACTIONS(5258),
    [anon_sym_nettype] = ACTIONS(5258),
    [anon_sym_automatic] = ACTIONS(5258),
    [anon_sym_string] = ACTIONS(5258),
    [anon_sym_chandle] = ACTIONS(5258),
    [anon_sym_event] = ACTIONS(5258),
    [anon_sym_byte] = ACTIONS(5258),
    [anon_sym_shortint] = ACTIONS(5258),
    [anon_sym_int] = ACTIONS(5258),
    [anon_sym_longint] = ACTIONS(5258),
    [anon_sym_integer] = ACTIONS(5258),
    [anon_sym_time] = ACTIONS(5258),
    [anon_sym_bit] = ACTIONS(5258),
    [anon_sym_logic] = ACTIONS(5258),
    [anon_sym_reg] = ACTIONS(5258),
    [anon_sym_shortreal] = ACTIONS(5258),
    [anon_sym_real] = ACTIONS(5258),
    [anon_sym_realtime] = ACTIONS(5258),
    [anon_sym_supply0] = ACTIONS(5258),
    [anon_sym_supply1] = ACTIONS(5258),
    [anon_sym_signed] = ACTIONS(5258),
    [anon_sym_unsigned] = ACTIONS(5258),
    [anon_sym_task] = ACTIONS(5258),
    [anon_sym_modport] = ACTIONS(5258),
    [anon_sym_assert] = ACTIONS(5258),
    [anon_sym_property] = ACTIONS(5258),
    [anon_sym_assume] = ACTIONS(5258),
    [anon_sym_cover] = ACTIONS(5258),
    [anon_sym_sequence] = ACTIONS(5258),
    [anon_sym_restrict] = ACTIONS(5258),
    [anon_sym_not] = ACTIONS(5258),
    [anon_sym_or] = ACTIONS(5258),
    [anon_sym_and] = ACTIONS(5258),
    [anon_sym_case] = ACTIONS(5258),
    [anon_sym_always] = ACTIONS(5258),
    [anon_sym_covergroup] = ACTIONS(5258),
    [anon_sym_let] = ACTIONS(5258),
    [anon_sym_pulldown] = ACTIONS(5258),
    [anon_sym_pullup] = ACTIONS(5258),
    [anon_sym_cmos] = ACTIONS(5258),
    [anon_sym_rcmos] = ACTIONS(5258),
    [anon_sym_bufif0] = ACTIONS(5258),
    [anon_sym_bufif1] = ACTIONS(5258),
    [anon_sym_notif0] = ACTIONS(5258),
    [anon_sym_notif1] = ACTIONS(5258),
    [anon_sym_nmos] = ACTIONS(5258),
    [anon_sym_pmos] = ACTIONS(5258),
    [anon_sym_rnmos] = ACTIONS(5258),
    [anon_sym_rpmos] = ACTIONS(5258),
    [anon_sym_nand] = ACTIONS(5258),
    [anon_sym_nor] = ACTIONS(5258),
    [anon_sym_xor] = ACTIONS(5258),
    [anon_sym_xnor] = ACTIONS(5258),
    [anon_sym_buf] = ACTIONS(5258),
    [anon_sym_tranif0] = ACTIONS(5258),
    [anon_sym_tranif1] = ACTIONS(5258),
    [anon_sym_rtranif1] = ACTIONS(5258),
    [anon_sym_rtranif0] = ACTIONS(5258),
    [anon_sym_tran] = ACTIONS(5258),
    [anon_sym_rtran] = ACTIONS(5258),
    [anon_sym_generate] = ACTIONS(5258),
    [anon_sym_for] = ACTIONS(5258),
    [anon_sym_primitive] = ACTIONS(5258),
    [anon_sym_initial] = ACTIONS(5258),
    [anon_sym_assign] = ACTIONS(5258),
    [anon_sym_alias] = ACTIONS(5258),
    [anon_sym_always_comb] = ACTIONS(5258),
    [anon_sym_always_latch] = ACTIONS(5258),
    [anon_sym_always_ff] = ACTIONS(5258),
    [anon_sym_final] = ACTIONS(5258),
    [anon_sym_global] = ACTIONS(5258),
    [anon_sym_specify] = ACTIONS(5258),
    [anon_sym_LPAREN_STAR] = ACTIONS(5256),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5256),
    [anon_sym_DOLLARunit] = ACTIONS(5256),
  },
  [853] = {
    [ts_builtin_sym_end] = ACTIONS(5260),
    [sym_simple_identifier] = ACTIONS(5262),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5260),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5260),
    [anon_sym_BQUOTE] = ACTIONS(5262),
    [aux_sym_id_directive_token1] = ACTIONS(5260),
    [aux_sym_id_directive_token2] = ACTIONS(5260),
    [aux_sym_id_directive_token3] = ACTIONS(5260),
    [aux_sym_id_directive_token4] = ACTIONS(5262),
    [aux_sym_zero_directive_token1] = ACTIONS(5260),
    [aux_sym_zero_directive_token2] = ACTIONS(5260),
    [aux_sym_zero_directive_token3] = ACTIONS(5260),
    [aux_sym_zero_directive_token4] = ACTIONS(5260),
    [aux_sym_zero_directive_token5] = ACTIONS(5260),
    [aux_sym_zero_directive_token6] = ACTIONS(5260),
    [aux_sym_zero_directive_token7] = ACTIONS(5260),
    [aux_sym_zero_directive_token8] = ACTIONS(5260),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5260),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5260),
    [anon_sym_wire] = ACTIONS(5262),
    [anon_sym_tri] = ACTIONS(5262),
    [anon_sym_tri0] = ACTIONS(5262),
    [anon_sym_tri1] = ACTIONS(5262),
    [anon_sym_wand] = ACTIONS(5262),
    [anon_sym_triand] = ACTIONS(5262),
    [anon_sym_wor] = ACTIONS(5262),
    [anon_sym_trior] = ACTIONS(5262),
    [anon_sym_trireg] = ACTIONS(5262),
    [anon_sym_uwire] = ACTIONS(5262),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5260),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5260),
    [aux_sym_begin_keywords_token1] = ACTIONS(5260),
    [anon_sym_SEMI] = ACTIONS(5260),
    [anon_sym_endmodule] = ACTIONS(5262),
    [anon_sym_extern] = ACTIONS(5262),
    [anon_sym_module] = ACTIONS(5262),
    [anon_sym_macromodule] = ACTIONS(5262),
    [anon_sym_endinterface] = ACTIONS(5262),
    [anon_sym_interface] = ACTIONS(5262),
    [anon_sym_endprogram] = ACTIONS(5262),
    [anon_sym_program] = ACTIONS(5262),
    [anon_sym_checker] = ACTIONS(5262),
    [anon_sym_virtual] = ACTIONS(5262),
    [anon_sym_class] = ACTIONS(5262),
    [anon_sym_package] = ACTIONS(5262),
    [anon_sym_endpackage] = ACTIONS(5262),
    [anon_sym_timeunit] = ACTIONS(5262),
    [anon_sym_timeprecision] = ACTIONS(5262),
    [anon_sym_type] = ACTIONS(5262),
    [anon_sym_input] = ACTIONS(5262),
    [anon_sym_output] = ACTIONS(5262),
    [anon_sym_inout] = ACTIONS(5262),
    [anon_sym_ref] = ACTIONS(5262),
    [anon_sym_DOLLARfatal] = ACTIONS(5260),
    [anon_sym_DOLLARerror] = ACTIONS(5260),
    [anon_sym_DOLLARwarning] = ACTIONS(5260),
    [anon_sym_DOLLARinfo] = ACTIONS(5260),
    [anon_sym_default] = ACTIONS(5262),
    [anon_sym_clocking] = ACTIONS(5262),
    [anon_sym_defparam] = ACTIONS(5262),
    [anon_sym_bind] = ACTIONS(5262),
    [anon_sym_const] = ACTIONS(5262),
    [anon_sym_function] = ACTIONS(5262),
    [anon_sym_static] = ACTIONS(5262),
    [anon_sym_constraint] = ACTIONS(5262),
    [anon_sym_if] = ACTIONS(5262),
    [anon_sym_else] = ACTIONS(5262),
    [anon_sym_LBRACK] = ACTIONS(5260),
    [anon_sym_localparam] = ACTIONS(5262),
    [anon_sym_parameter] = ACTIONS(5262),
    [anon_sym_specparam] = ACTIONS(5262),
    [anon_sym_var] = ACTIONS(5262),
    [anon_sym_import] = ACTIONS(5262),
    [anon_sym_export] = ACTIONS(5262),
    [anon_sym_genvar] = ACTIONS(5262),
    [anon_sym_interconnect] = ACTIONS(5262),
    [anon_sym_typedef] = ACTIONS(5262),
    [anon_sym_enum] = ACTIONS(5262),
    [anon_sym_struct] = ACTIONS(5262),
    [anon_sym_union] = ACTIONS(5262),
    [anon_sym_nettype] = ACTIONS(5262),
    [anon_sym_automatic] = ACTIONS(5262),
    [anon_sym_string] = ACTIONS(5262),
    [anon_sym_chandle] = ACTIONS(5262),
    [anon_sym_event] = ACTIONS(5262),
    [anon_sym_byte] = ACTIONS(5262),
    [anon_sym_shortint] = ACTIONS(5262),
    [anon_sym_int] = ACTIONS(5262),
    [anon_sym_longint] = ACTIONS(5262),
    [anon_sym_integer] = ACTIONS(5262),
    [anon_sym_time] = ACTIONS(5262),
    [anon_sym_bit] = ACTIONS(5262),
    [anon_sym_logic] = ACTIONS(5262),
    [anon_sym_reg] = ACTIONS(5262),
    [anon_sym_shortreal] = ACTIONS(5262),
    [anon_sym_real] = ACTIONS(5262),
    [anon_sym_realtime] = ACTIONS(5262),
    [anon_sym_supply0] = ACTIONS(5262),
    [anon_sym_supply1] = ACTIONS(5262),
    [anon_sym_signed] = ACTIONS(5262),
    [anon_sym_unsigned] = ACTIONS(5262),
    [anon_sym_task] = ACTIONS(5262),
    [anon_sym_modport] = ACTIONS(5262),
    [anon_sym_assert] = ACTIONS(5262),
    [anon_sym_property] = ACTIONS(5262),
    [anon_sym_assume] = ACTIONS(5262),
    [anon_sym_cover] = ACTIONS(5262),
    [anon_sym_sequence] = ACTIONS(5262),
    [anon_sym_restrict] = ACTIONS(5262),
    [anon_sym_not] = ACTIONS(5262),
    [anon_sym_or] = ACTIONS(5262),
    [anon_sym_and] = ACTIONS(5262),
    [anon_sym_case] = ACTIONS(5262),
    [anon_sym_always] = ACTIONS(5262),
    [anon_sym_covergroup] = ACTIONS(5262),
    [anon_sym_let] = ACTIONS(5262),
    [anon_sym_pulldown] = ACTIONS(5262),
    [anon_sym_pullup] = ACTIONS(5262),
    [anon_sym_cmos] = ACTIONS(5262),
    [anon_sym_rcmos] = ACTIONS(5262),
    [anon_sym_bufif0] = ACTIONS(5262),
    [anon_sym_bufif1] = ACTIONS(5262),
    [anon_sym_notif0] = ACTIONS(5262),
    [anon_sym_notif1] = ACTIONS(5262),
    [anon_sym_nmos] = ACTIONS(5262),
    [anon_sym_pmos] = ACTIONS(5262),
    [anon_sym_rnmos] = ACTIONS(5262),
    [anon_sym_rpmos] = ACTIONS(5262),
    [anon_sym_nand] = ACTIONS(5262),
    [anon_sym_nor] = ACTIONS(5262),
    [anon_sym_xor] = ACTIONS(5262),
    [anon_sym_xnor] = ACTIONS(5262),
    [anon_sym_buf] = ACTIONS(5262),
    [anon_sym_tranif0] = ACTIONS(5262),
    [anon_sym_tranif1] = ACTIONS(5262),
    [anon_sym_rtranif1] = ACTIONS(5262),
    [anon_sym_rtranif0] = ACTIONS(5262),
    [anon_sym_tran] = ACTIONS(5262),
    [anon_sym_rtran] = ACTIONS(5262),
    [anon_sym_generate] = ACTIONS(5262),
    [anon_sym_for] = ACTIONS(5262),
    [anon_sym_primitive] = ACTIONS(5262),
    [anon_sym_initial] = ACTIONS(5262),
    [anon_sym_assign] = ACTIONS(5262),
    [anon_sym_alias] = ACTIONS(5262),
    [anon_sym_always_comb] = ACTIONS(5262),
    [anon_sym_always_latch] = ACTIONS(5262),
    [anon_sym_always_ff] = ACTIONS(5262),
    [anon_sym_final] = ACTIONS(5262),
    [anon_sym_global] = ACTIONS(5262),
    [anon_sym_specify] = ACTIONS(5262),
    [anon_sym_LPAREN_STAR] = ACTIONS(5260),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5260),
    [anon_sym_DOLLARunit] = ACTIONS(5260),
  },
  [854] = {
    [ts_builtin_sym_end] = ACTIONS(5264),
    [sym_simple_identifier] = ACTIONS(5266),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5264),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5264),
    [anon_sym_BQUOTE] = ACTIONS(5266),
    [aux_sym_id_directive_token1] = ACTIONS(5264),
    [aux_sym_id_directive_token2] = ACTIONS(5264),
    [aux_sym_id_directive_token3] = ACTIONS(5264),
    [aux_sym_id_directive_token4] = ACTIONS(5266),
    [aux_sym_zero_directive_token1] = ACTIONS(5264),
    [aux_sym_zero_directive_token2] = ACTIONS(5264),
    [aux_sym_zero_directive_token3] = ACTIONS(5264),
    [aux_sym_zero_directive_token4] = ACTIONS(5264),
    [aux_sym_zero_directive_token5] = ACTIONS(5264),
    [aux_sym_zero_directive_token6] = ACTIONS(5264),
    [aux_sym_zero_directive_token7] = ACTIONS(5264),
    [aux_sym_zero_directive_token8] = ACTIONS(5264),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5264),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5264),
    [anon_sym_wire] = ACTIONS(5266),
    [anon_sym_tri] = ACTIONS(5266),
    [anon_sym_tri0] = ACTIONS(5266),
    [anon_sym_tri1] = ACTIONS(5266),
    [anon_sym_wand] = ACTIONS(5266),
    [anon_sym_triand] = ACTIONS(5266),
    [anon_sym_wor] = ACTIONS(5266),
    [anon_sym_trior] = ACTIONS(5266),
    [anon_sym_trireg] = ACTIONS(5266),
    [anon_sym_uwire] = ACTIONS(5266),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5264),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5264),
    [aux_sym_begin_keywords_token1] = ACTIONS(5264),
    [anon_sym_SEMI] = ACTIONS(5264),
    [anon_sym_endmodule] = ACTIONS(5266),
    [anon_sym_extern] = ACTIONS(5266),
    [anon_sym_module] = ACTIONS(5266),
    [anon_sym_macromodule] = ACTIONS(5266),
    [anon_sym_endinterface] = ACTIONS(5266),
    [anon_sym_interface] = ACTIONS(5266),
    [anon_sym_endprogram] = ACTIONS(5266),
    [anon_sym_program] = ACTIONS(5266),
    [anon_sym_checker] = ACTIONS(5266),
    [anon_sym_virtual] = ACTIONS(5266),
    [anon_sym_class] = ACTIONS(5266),
    [anon_sym_package] = ACTIONS(5266),
    [anon_sym_endpackage] = ACTIONS(5266),
    [anon_sym_timeunit] = ACTIONS(5266),
    [anon_sym_timeprecision] = ACTIONS(5266),
    [anon_sym_type] = ACTIONS(5266),
    [anon_sym_input] = ACTIONS(5266),
    [anon_sym_output] = ACTIONS(5266),
    [anon_sym_inout] = ACTIONS(5266),
    [anon_sym_ref] = ACTIONS(5266),
    [anon_sym_DOLLARfatal] = ACTIONS(5264),
    [anon_sym_DOLLARerror] = ACTIONS(5264),
    [anon_sym_DOLLARwarning] = ACTIONS(5264),
    [anon_sym_DOLLARinfo] = ACTIONS(5264),
    [anon_sym_default] = ACTIONS(5266),
    [anon_sym_clocking] = ACTIONS(5266),
    [anon_sym_defparam] = ACTIONS(5266),
    [anon_sym_bind] = ACTIONS(5266),
    [anon_sym_const] = ACTIONS(5266),
    [anon_sym_function] = ACTIONS(5266),
    [anon_sym_static] = ACTIONS(5266),
    [anon_sym_constraint] = ACTIONS(5266),
    [anon_sym_if] = ACTIONS(5266),
    [anon_sym_else] = ACTIONS(5266),
    [anon_sym_LBRACK] = ACTIONS(5264),
    [anon_sym_localparam] = ACTIONS(5266),
    [anon_sym_parameter] = ACTIONS(5266),
    [anon_sym_specparam] = ACTIONS(5266),
    [anon_sym_var] = ACTIONS(5266),
    [anon_sym_import] = ACTIONS(5266),
    [anon_sym_export] = ACTIONS(5266),
    [anon_sym_genvar] = ACTIONS(5266),
    [anon_sym_interconnect] = ACTIONS(5266),
    [anon_sym_typedef] = ACTIONS(5266),
    [anon_sym_enum] = ACTIONS(5266),
    [anon_sym_struct] = ACTIONS(5266),
    [anon_sym_union] = ACTIONS(5266),
    [anon_sym_nettype] = ACTIONS(5266),
    [anon_sym_automatic] = ACTIONS(5266),
    [anon_sym_string] = ACTIONS(5266),
    [anon_sym_chandle] = ACTIONS(5266),
    [anon_sym_event] = ACTIONS(5266),
    [anon_sym_byte] = ACTIONS(5266),
    [anon_sym_shortint] = ACTIONS(5266),
    [anon_sym_int] = ACTIONS(5266),
    [anon_sym_longint] = ACTIONS(5266),
    [anon_sym_integer] = ACTIONS(5266),
    [anon_sym_time] = ACTIONS(5266),
    [anon_sym_bit] = ACTIONS(5266),
    [anon_sym_logic] = ACTIONS(5266),
    [anon_sym_reg] = ACTIONS(5266),
    [anon_sym_shortreal] = ACTIONS(5266),
    [anon_sym_real] = ACTIONS(5266),
    [anon_sym_realtime] = ACTIONS(5266),
    [anon_sym_supply0] = ACTIONS(5266),
    [anon_sym_supply1] = ACTIONS(5266),
    [anon_sym_signed] = ACTIONS(5266),
    [anon_sym_unsigned] = ACTIONS(5266),
    [anon_sym_task] = ACTIONS(5266),
    [anon_sym_modport] = ACTIONS(5266),
    [anon_sym_assert] = ACTIONS(5266),
    [anon_sym_property] = ACTIONS(5266),
    [anon_sym_assume] = ACTIONS(5266),
    [anon_sym_cover] = ACTIONS(5266),
    [anon_sym_sequence] = ACTIONS(5266),
    [anon_sym_restrict] = ACTIONS(5266),
    [anon_sym_not] = ACTIONS(5266),
    [anon_sym_or] = ACTIONS(5266),
    [anon_sym_and] = ACTIONS(5266),
    [anon_sym_case] = ACTIONS(5266),
    [anon_sym_always] = ACTIONS(5266),
    [anon_sym_covergroup] = ACTIONS(5266),
    [anon_sym_let] = ACTIONS(5266),
    [anon_sym_pulldown] = ACTIONS(5266),
    [anon_sym_pullup] = ACTIONS(5266),
    [anon_sym_cmos] = ACTIONS(5266),
    [anon_sym_rcmos] = ACTIONS(5266),
    [anon_sym_bufif0] = ACTIONS(5266),
    [anon_sym_bufif1] = ACTIONS(5266),
    [anon_sym_notif0] = ACTIONS(5266),
    [anon_sym_notif1] = ACTIONS(5266),
    [anon_sym_nmos] = ACTIONS(5266),
    [anon_sym_pmos] = ACTIONS(5266),
    [anon_sym_rnmos] = ACTIONS(5266),
    [anon_sym_rpmos] = ACTIONS(5266),
    [anon_sym_nand] = ACTIONS(5266),
    [anon_sym_nor] = ACTIONS(5266),
    [anon_sym_xor] = ACTIONS(5266),
    [anon_sym_xnor] = ACTIONS(5266),
    [anon_sym_buf] = ACTIONS(5266),
    [anon_sym_tranif0] = ACTIONS(5266),
    [anon_sym_tranif1] = ACTIONS(5266),
    [anon_sym_rtranif1] = ACTIONS(5266),
    [anon_sym_rtranif0] = ACTIONS(5266),
    [anon_sym_tran] = ACTIONS(5266),
    [anon_sym_rtran] = ACTIONS(5266),
    [anon_sym_generate] = ACTIONS(5266),
    [anon_sym_for] = ACTIONS(5266),
    [anon_sym_primitive] = ACTIONS(5266),
    [anon_sym_initial] = ACTIONS(5266),
    [anon_sym_assign] = ACTIONS(5266),
    [anon_sym_alias] = ACTIONS(5266),
    [anon_sym_always_comb] = ACTIONS(5266),
    [anon_sym_always_latch] = ACTIONS(5266),
    [anon_sym_always_ff] = ACTIONS(5266),
    [anon_sym_final] = ACTIONS(5266),
    [anon_sym_global] = ACTIONS(5266),
    [anon_sym_specify] = ACTIONS(5266),
    [anon_sym_LPAREN_STAR] = ACTIONS(5264),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5264),
    [anon_sym_DOLLARunit] = ACTIONS(5264),
  },
  [855] = {
    [ts_builtin_sym_end] = ACTIONS(5268),
    [sym_simple_identifier] = ACTIONS(5270),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5268),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5268),
    [anon_sym_BQUOTE] = ACTIONS(5270),
    [aux_sym_id_directive_token1] = ACTIONS(5268),
    [aux_sym_id_directive_token2] = ACTIONS(5268),
    [aux_sym_id_directive_token3] = ACTIONS(5268),
    [aux_sym_id_directive_token4] = ACTIONS(5270),
    [aux_sym_zero_directive_token1] = ACTIONS(5268),
    [aux_sym_zero_directive_token2] = ACTIONS(5268),
    [aux_sym_zero_directive_token3] = ACTIONS(5268),
    [aux_sym_zero_directive_token4] = ACTIONS(5268),
    [aux_sym_zero_directive_token5] = ACTIONS(5268),
    [aux_sym_zero_directive_token6] = ACTIONS(5268),
    [aux_sym_zero_directive_token7] = ACTIONS(5268),
    [aux_sym_zero_directive_token8] = ACTIONS(5268),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5268),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5268),
    [anon_sym_wire] = ACTIONS(5270),
    [anon_sym_tri] = ACTIONS(5270),
    [anon_sym_tri0] = ACTIONS(5270),
    [anon_sym_tri1] = ACTIONS(5270),
    [anon_sym_wand] = ACTIONS(5270),
    [anon_sym_triand] = ACTIONS(5270),
    [anon_sym_wor] = ACTIONS(5270),
    [anon_sym_trior] = ACTIONS(5270),
    [anon_sym_trireg] = ACTIONS(5270),
    [anon_sym_uwire] = ACTIONS(5270),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5268),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5268),
    [aux_sym_begin_keywords_token1] = ACTIONS(5268),
    [anon_sym_SEMI] = ACTIONS(5268),
    [anon_sym_endmodule] = ACTIONS(5270),
    [anon_sym_extern] = ACTIONS(5270),
    [anon_sym_module] = ACTIONS(5270),
    [anon_sym_macromodule] = ACTIONS(5270),
    [anon_sym_endinterface] = ACTIONS(5270),
    [anon_sym_interface] = ACTIONS(5270),
    [anon_sym_endprogram] = ACTIONS(5270),
    [anon_sym_program] = ACTIONS(5270),
    [anon_sym_checker] = ACTIONS(5270),
    [anon_sym_virtual] = ACTIONS(5270),
    [anon_sym_class] = ACTIONS(5270),
    [anon_sym_package] = ACTIONS(5270),
    [anon_sym_endpackage] = ACTIONS(5270),
    [anon_sym_timeunit] = ACTIONS(5270),
    [anon_sym_timeprecision] = ACTIONS(5270),
    [anon_sym_type] = ACTIONS(5270),
    [anon_sym_input] = ACTIONS(5270),
    [anon_sym_output] = ACTIONS(5270),
    [anon_sym_inout] = ACTIONS(5270),
    [anon_sym_ref] = ACTIONS(5270),
    [anon_sym_DOLLARfatal] = ACTIONS(5268),
    [anon_sym_DOLLARerror] = ACTIONS(5268),
    [anon_sym_DOLLARwarning] = ACTIONS(5268),
    [anon_sym_DOLLARinfo] = ACTIONS(5268),
    [anon_sym_default] = ACTIONS(5270),
    [anon_sym_clocking] = ACTIONS(5270),
    [anon_sym_defparam] = ACTIONS(5270),
    [anon_sym_bind] = ACTIONS(5270),
    [anon_sym_const] = ACTIONS(5270),
    [anon_sym_function] = ACTIONS(5270),
    [anon_sym_static] = ACTIONS(5270),
    [anon_sym_constraint] = ACTIONS(5270),
    [anon_sym_if] = ACTIONS(5270),
    [anon_sym_else] = ACTIONS(5270),
    [anon_sym_LBRACK] = ACTIONS(5268),
    [anon_sym_localparam] = ACTIONS(5270),
    [anon_sym_parameter] = ACTIONS(5270),
    [anon_sym_specparam] = ACTIONS(5270),
    [anon_sym_var] = ACTIONS(5270),
    [anon_sym_import] = ACTIONS(5270),
    [anon_sym_export] = ACTIONS(5270),
    [anon_sym_genvar] = ACTIONS(5270),
    [anon_sym_interconnect] = ACTIONS(5270),
    [anon_sym_typedef] = ACTIONS(5270),
    [anon_sym_enum] = ACTIONS(5270),
    [anon_sym_struct] = ACTIONS(5270),
    [anon_sym_union] = ACTIONS(5270),
    [anon_sym_nettype] = ACTIONS(5270),
    [anon_sym_automatic] = ACTIONS(5270),
    [anon_sym_string] = ACTIONS(5270),
    [anon_sym_chandle] = ACTIONS(5270),
    [anon_sym_event] = ACTIONS(5270),
    [anon_sym_byte] = ACTIONS(5270),
    [anon_sym_shortint] = ACTIONS(5270),
    [anon_sym_int] = ACTIONS(5270),
    [anon_sym_longint] = ACTIONS(5270),
    [anon_sym_integer] = ACTIONS(5270),
    [anon_sym_time] = ACTIONS(5270),
    [anon_sym_bit] = ACTIONS(5270),
    [anon_sym_logic] = ACTIONS(5270),
    [anon_sym_reg] = ACTIONS(5270),
    [anon_sym_shortreal] = ACTIONS(5270),
    [anon_sym_real] = ACTIONS(5270),
    [anon_sym_realtime] = ACTIONS(5270),
    [anon_sym_supply0] = ACTIONS(5270),
    [anon_sym_supply1] = ACTIONS(5270),
    [anon_sym_signed] = ACTIONS(5270),
    [anon_sym_unsigned] = ACTIONS(5270),
    [anon_sym_task] = ACTIONS(5270),
    [anon_sym_modport] = ACTIONS(5270),
    [anon_sym_assert] = ACTIONS(5270),
    [anon_sym_property] = ACTIONS(5270),
    [anon_sym_assume] = ACTIONS(5270),
    [anon_sym_cover] = ACTIONS(5270),
    [anon_sym_sequence] = ACTIONS(5270),
    [anon_sym_restrict] = ACTIONS(5270),
    [anon_sym_not] = ACTIONS(5270),
    [anon_sym_or] = ACTIONS(5270),
    [anon_sym_and] = ACTIONS(5270),
    [anon_sym_case] = ACTIONS(5270),
    [anon_sym_always] = ACTIONS(5270),
    [anon_sym_covergroup] = ACTIONS(5270),
    [anon_sym_let] = ACTIONS(5270),
    [anon_sym_pulldown] = ACTIONS(5270),
    [anon_sym_pullup] = ACTIONS(5270),
    [anon_sym_cmos] = ACTIONS(5270),
    [anon_sym_rcmos] = ACTIONS(5270),
    [anon_sym_bufif0] = ACTIONS(5270),
    [anon_sym_bufif1] = ACTIONS(5270),
    [anon_sym_notif0] = ACTIONS(5270),
    [anon_sym_notif1] = ACTIONS(5270),
    [anon_sym_nmos] = ACTIONS(5270),
    [anon_sym_pmos] = ACTIONS(5270),
    [anon_sym_rnmos] = ACTIONS(5270),
    [anon_sym_rpmos] = ACTIONS(5270),
    [anon_sym_nand] = ACTIONS(5270),
    [anon_sym_nor] = ACTIONS(5270),
    [anon_sym_xor] = ACTIONS(5270),
    [anon_sym_xnor] = ACTIONS(5270),
    [anon_sym_buf] = ACTIONS(5270),
    [anon_sym_tranif0] = ACTIONS(5270),
    [anon_sym_tranif1] = ACTIONS(5270),
    [anon_sym_rtranif1] = ACTIONS(5270),
    [anon_sym_rtranif0] = ACTIONS(5270),
    [anon_sym_tran] = ACTIONS(5270),
    [anon_sym_rtran] = ACTIONS(5270),
    [anon_sym_generate] = ACTIONS(5270),
    [anon_sym_for] = ACTIONS(5270),
    [anon_sym_primitive] = ACTIONS(5270),
    [anon_sym_initial] = ACTIONS(5270),
    [anon_sym_assign] = ACTIONS(5270),
    [anon_sym_alias] = ACTIONS(5270),
    [anon_sym_always_comb] = ACTIONS(5270),
    [anon_sym_always_latch] = ACTIONS(5270),
    [anon_sym_always_ff] = ACTIONS(5270),
    [anon_sym_final] = ACTIONS(5270),
    [anon_sym_global] = ACTIONS(5270),
    [anon_sym_specify] = ACTIONS(5270),
    [anon_sym_LPAREN_STAR] = ACTIONS(5268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5268),
    [anon_sym_DOLLARunit] = ACTIONS(5268),
  },
  [856] = {
    [ts_builtin_sym_end] = ACTIONS(4476),
    [sym_simple_identifier] = ACTIONS(4478),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4476),
    [anon_sym_BQUOTE] = ACTIONS(4478),
    [aux_sym_id_directive_token1] = ACTIONS(4476),
    [aux_sym_id_directive_token2] = ACTIONS(4476),
    [aux_sym_id_directive_token3] = ACTIONS(4476),
    [aux_sym_id_directive_token4] = ACTIONS(4478),
    [aux_sym_zero_directive_token1] = ACTIONS(4476),
    [aux_sym_zero_directive_token2] = ACTIONS(4476),
    [aux_sym_zero_directive_token3] = ACTIONS(4476),
    [aux_sym_zero_directive_token4] = ACTIONS(4476),
    [aux_sym_zero_directive_token5] = ACTIONS(4476),
    [aux_sym_zero_directive_token6] = ACTIONS(4476),
    [aux_sym_zero_directive_token7] = ACTIONS(4476),
    [aux_sym_zero_directive_token8] = ACTIONS(4476),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4476),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4476),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4476),
    [aux_sym_begin_keywords_token1] = ACTIONS(4476),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_endmodule] = ACTIONS(4478),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_module] = ACTIONS(4478),
    [anon_sym_macromodule] = ACTIONS(4478),
    [anon_sym_endinterface] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_endprogram] = ACTIONS(4478),
    [anon_sym_program] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_package] = ACTIONS(4478),
    [anon_sym_endpackage] = ACTIONS(4478),
    [anon_sym_timeunit] = ACTIONS(4478),
    [anon_sym_timeprecision] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_input] = ACTIONS(4478),
    [anon_sym_output] = ACTIONS(4478),
    [anon_sym_inout] = ACTIONS(4478),
    [anon_sym_ref] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_specparam] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_modport] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_primitive] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_specify] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [857] = {
    [ts_builtin_sym_end] = ACTIONS(5272),
    [sym_simple_identifier] = ACTIONS(5274),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5272),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5272),
    [anon_sym_BQUOTE] = ACTIONS(5274),
    [aux_sym_id_directive_token1] = ACTIONS(5272),
    [aux_sym_id_directive_token2] = ACTIONS(5272),
    [aux_sym_id_directive_token3] = ACTIONS(5272),
    [aux_sym_id_directive_token4] = ACTIONS(5274),
    [aux_sym_zero_directive_token1] = ACTIONS(5272),
    [aux_sym_zero_directive_token2] = ACTIONS(5272),
    [aux_sym_zero_directive_token3] = ACTIONS(5272),
    [aux_sym_zero_directive_token4] = ACTIONS(5272),
    [aux_sym_zero_directive_token5] = ACTIONS(5272),
    [aux_sym_zero_directive_token6] = ACTIONS(5272),
    [aux_sym_zero_directive_token7] = ACTIONS(5272),
    [aux_sym_zero_directive_token8] = ACTIONS(5272),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5272),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5272),
    [anon_sym_wire] = ACTIONS(5274),
    [anon_sym_tri] = ACTIONS(5274),
    [anon_sym_tri0] = ACTIONS(5274),
    [anon_sym_tri1] = ACTIONS(5274),
    [anon_sym_wand] = ACTIONS(5274),
    [anon_sym_triand] = ACTIONS(5274),
    [anon_sym_wor] = ACTIONS(5274),
    [anon_sym_trior] = ACTIONS(5274),
    [anon_sym_trireg] = ACTIONS(5274),
    [anon_sym_uwire] = ACTIONS(5274),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5272),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5272),
    [aux_sym_begin_keywords_token1] = ACTIONS(5272),
    [anon_sym_SEMI] = ACTIONS(5272),
    [anon_sym_endmodule] = ACTIONS(5274),
    [anon_sym_extern] = ACTIONS(5274),
    [anon_sym_module] = ACTIONS(5274),
    [anon_sym_macromodule] = ACTIONS(5274),
    [anon_sym_endinterface] = ACTIONS(5274),
    [anon_sym_interface] = ACTIONS(5274),
    [anon_sym_endprogram] = ACTIONS(5274),
    [anon_sym_program] = ACTIONS(5274),
    [anon_sym_checker] = ACTIONS(5274),
    [anon_sym_virtual] = ACTIONS(5274),
    [anon_sym_class] = ACTIONS(5274),
    [anon_sym_package] = ACTIONS(5274),
    [anon_sym_endpackage] = ACTIONS(5274),
    [anon_sym_timeunit] = ACTIONS(5274),
    [anon_sym_timeprecision] = ACTIONS(5274),
    [anon_sym_type] = ACTIONS(5274),
    [anon_sym_input] = ACTIONS(5274),
    [anon_sym_output] = ACTIONS(5274),
    [anon_sym_inout] = ACTIONS(5274),
    [anon_sym_ref] = ACTIONS(5274),
    [anon_sym_DOLLARfatal] = ACTIONS(5272),
    [anon_sym_DOLLARerror] = ACTIONS(5272),
    [anon_sym_DOLLARwarning] = ACTIONS(5272),
    [anon_sym_DOLLARinfo] = ACTIONS(5272),
    [anon_sym_default] = ACTIONS(5274),
    [anon_sym_clocking] = ACTIONS(5274),
    [anon_sym_defparam] = ACTIONS(5274),
    [anon_sym_bind] = ACTIONS(5274),
    [anon_sym_const] = ACTIONS(5274),
    [anon_sym_function] = ACTIONS(5274),
    [anon_sym_static] = ACTIONS(5274),
    [anon_sym_constraint] = ACTIONS(5274),
    [anon_sym_if] = ACTIONS(5274),
    [anon_sym_else] = ACTIONS(5274),
    [anon_sym_LBRACK] = ACTIONS(5272),
    [anon_sym_localparam] = ACTIONS(5274),
    [anon_sym_parameter] = ACTIONS(5274),
    [anon_sym_specparam] = ACTIONS(5274),
    [anon_sym_var] = ACTIONS(5274),
    [anon_sym_import] = ACTIONS(5274),
    [anon_sym_export] = ACTIONS(5274),
    [anon_sym_genvar] = ACTIONS(5274),
    [anon_sym_interconnect] = ACTIONS(5274),
    [anon_sym_typedef] = ACTIONS(5274),
    [anon_sym_enum] = ACTIONS(5274),
    [anon_sym_struct] = ACTIONS(5274),
    [anon_sym_union] = ACTIONS(5274),
    [anon_sym_nettype] = ACTIONS(5274),
    [anon_sym_automatic] = ACTIONS(5274),
    [anon_sym_string] = ACTIONS(5274),
    [anon_sym_chandle] = ACTIONS(5274),
    [anon_sym_event] = ACTIONS(5274),
    [anon_sym_byte] = ACTIONS(5274),
    [anon_sym_shortint] = ACTIONS(5274),
    [anon_sym_int] = ACTIONS(5274),
    [anon_sym_longint] = ACTIONS(5274),
    [anon_sym_integer] = ACTIONS(5274),
    [anon_sym_time] = ACTIONS(5274),
    [anon_sym_bit] = ACTIONS(5274),
    [anon_sym_logic] = ACTIONS(5274),
    [anon_sym_reg] = ACTIONS(5274),
    [anon_sym_shortreal] = ACTIONS(5274),
    [anon_sym_real] = ACTIONS(5274),
    [anon_sym_realtime] = ACTIONS(5274),
    [anon_sym_supply0] = ACTIONS(5274),
    [anon_sym_supply1] = ACTIONS(5274),
    [anon_sym_signed] = ACTIONS(5274),
    [anon_sym_unsigned] = ACTIONS(5274),
    [anon_sym_task] = ACTIONS(5274),
    [anon_sym_modport] = ACTIONS(5274),
    [anon_sym_assert] = ACTIONS(5274),
    [anon_sym_property] = ACTIONS(5274),
    [anon_sym_assume] = ACTIONS(5274),
    [anon_sym_cover] = ACTIONS(5274),
    [anon_sym_sequence] = ACTIONS(5274),
    [anon_sym_restrict] = ACTIONS(5274),
    [anon_sym_not] = ACTIONS(5274),
    [anon_sym_or] = ACTIONS(5274),
    [anon_sym_and] = ACTIONS(5274),
    [anon_sym_case] = ACTIONS(5274),
    [anon_sym_always] = ACTIONS(5274),
    [anon_sym_covergroup] = ACTIONS(5274),
    [anon_sym_let] = ACTIONS(5274),
    [anon_sym_pulldown] = ACTIONS(5274),
    [anon_sym_pullup] = ACTIONS(5274),
    [anon_sym_cmos] = ACTIONS(5274),
    [anon_sym_rcmos] = ACTIONS(5274),
    [anon_sym_bufif0] = ACTIONS(5274),
    [anon_sym_bufif1] = ACTIONS(5274),
    [anon_sym_notif0] = ACTIONS(5274),
    [anon_sym_notif1] = ACTIONS(5274),
    [anon_sym_nmos] = ACTIONS(5274),
    [anon_sym_pmos] = ACTIONS(5274),
    [anon_sym_rnmos] = ACTIONS(5274),
    [anon_sym_rpmos] = ACTIONS(5274),
    [anon_sym_nand] = ACTIONS(5274),
    [anon_sym_nor] = ACTIONS(5274),
    [anon_sym_xor] = ACTIONS(5274),
    [anon_sym_xnor] = ACTIONS(5274),
    [anon_sym_buf] = ACTIONS(5274),
    [anon_sym_tranif0] = ACTIONS(5274),
    [anon_sym_tranif1] = ACTIONS(5274),
    [anon_sym_rtranif1] = ACTIONS(5274),
    [anon_sym_rtranif0] = ACTIONS(5274),
    [anon_sym_tran] = ACTIONS(5274),
    [anon_sym_rtran] = ACTIONS(5274),
    [anon_sym_generate] = ACTIONS(5274),
    [anon_sym_for] = ACTIONS(5274),
    [anon_sym_primitive] = ACTIONS(5274),
    [anon_sym_initial] = ACTIONS(5274),
    [anon_sym_assign] = ACTIONS(5274),
    [anon_sym_alias] = ACTIONS(5274),
    [anon_sym_always_comb] = ACTIONS(5274),
    [anon_sym_always_latch] = ACTIONS(5274),
    [anon_sym_always_ff] = ACTIONS(5274),
    [anon_sym_final] = ACTIONS(5274),
    [anon_sym_global] = ACTIONS(5274),
    [anon_sym_specify] = ACTIONS(5274),
    [anon_sym_LPAREN_STAR] = ACTIONS(5272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5272),
    [anon_sym_DOLLARunit] = ACTIONS(5272),
  },
  [858] = {
    [ts_builtin_sym_end] = ACTIONS(5276),
    [sym_simple_identifier] = ACTIONS(5278),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5276),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5276),
    [anon_sym_BQUOTE] = ACTIONS(5278),
    [aux_sym_id_directive_token1] = ACTIONS(5276),
    [aux_sym_id_directive_token2] = ACTIONS(5276),
    [aux_sym_id_directive_token3] = ACTIONS(5276),
    [aux_sym_id_directive_token4] = ACTIONS(5278),
    [aux_sym_zero_directive_token1] = ACTIONS(5276),
    [aux_sym_zero_directive_token2] = ACTIONS(5276),
    [aux_sym_zero_directive_token3] = ACTIONS(5276),
    [aux_sym_zero_directive_token4] = ACTIONS(5276),
    [aux_sym_zero_directive_token5] = ACTIONS(5276),
    [aux_sym_zero_directive_token6] = ACTIONS(5276),
    [aux_sym_zero_directive_token7] = ACTIONS(5276),
    [aux_sym_zero_directive_token8] = ACTIONS(5276),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5276),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5276),
    [anon_sym_wire] = ACTIONS(5278),
    [anon_sym_tri] = ACTIONS(5278),
    [anon_sym_tri0] = ACTIONS(5278),
    [anon_sym_tri1] = ACTIONS(5278),
    [anon_sym_wand] = ACTIONS(5278),
    [anon_sym_triand] = ACTIONS(5278),
    [anon_sym_wor] = ACTIONS(5278),
    [anon_sym_trior] = ACTIONS(5278),
    [anon_sym_trireg] = ACTIONS(5278),
    [anon_sym_uwire] = ACTIONS(5278),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5276),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5276),
    [aux_sym_begin_keywords_token1] = ACTIONS(5276),
    [anon_sym_SEMI] = ACTIONS(5276),
    [anon_sym_endmodule] = ACTIONS(5278),
    [anon_sym_extern] = ACTIONS(5278),
    [anon_sym_module] = ACTIONS(5278),
    [anon_sym_macromodule] = ACTIONS(5278),
    [anon_sym_endinterface] = ACTIONS(5278),
    [anon_sym_interface] = ACTIONS(5278),
    [anon_sym_endprogram] = ACTIONS(5278),
    [anon_sym_program] = ACTIONS(5278),
    [anon_sym_checker] = ACTIONS(5278),
    [anon_sym_virtual] = ACTIONS(5278),
    [anon_sym_class] = ACTIONS(5278),
    [anon_sym_package] = ACTIONS(5278),
    [anon_sym_endpackage] = ACTIONS(5278),
    [anon_sym_timeunit] = ACTIONS(5278),
    [anon_sym_timeprecision] = ACTIONS(5278),
    [anon_sym_type] = ACTIONS(5278),
    [anon_sym_input] = ACTIONS(5278),
    [anon_sym_output] = ACTIONS(5278),
    [anon_sym_inout] = ACTIONS(5278),
    [anon_sym_ref] = ACTIONS(5278),
    [anon_sym_DOLLARfatal] = ACTIONS(5276),
    [anon_sym_DOLLARerror] = ACTIONS(5276),
    [anon_sym_DOLLARwarning] = ACTIONS(5276),
    [anon_sym_DOLLARinfo] = ACTIONS(5276),
    [anon_sym_default] = ACTIONS(5278),
    [anon_sym_clocking] = ACTIONS(5278),
    [anon_sym_defparam] = ACTIONS(5278),
    [anon_sym_bind] = ACTIONS(5278),
    [anon_sym_const] = ACTIONS(5278),
    [anon_sym_function] = ACTIONS(5278),
    [anon_sym_static] = ACTIONS(5278),
    [anon_sym_constraint] = ACTIONS(5278),
    [anon_sym_if] = ACTIONS(5278),
    [anon_sym_else] = ACTIONS(5278),
    [anon_sym_LBRACK] = ACTIONS(5276),
    [anon_sym_localparam] = ACTIONS(5278),
    [anon_sym_parameter] = ACTIONS(5278),
    [anon_sym_specparam] = ACTIONS(5278),
    [anon_sym_var] = ACTIONS(5278),
    [anon_sym_import] = ACTIONS(5278),
    [anon_sym_export] = ACTIONS(5278),
    [anon_sym_genvar] = ACTIONS(5278),
    [anon_sym_interconnect] = ACTIONS(5278),
    [anon_sym_typedef] = ACTIONS(5278),
    [anon_sym_enum] = ACTIONS(5278),
    [anon_sym_struct] = ACTIONS(5278),
    [anon_sym_union] = ACTIONS(5278),
    [anon_sym_nettype] = ACTIONS(5278),
    [anon_sym_automatic] = ACTIONS(5278),
    [anon_sym_string] = ACTIONS(5278),
    [anon_sym_chandle] = ACTIONS(5278),
    [anon_sym_event] = ACTIONS(5278),
    [anon_sym_byte] = ACTIONS(5278),
    [anon_sym_shortint] = ACTIONS(5278),
    [anon_sym_int] = ACTIONS(5278),
    [anon_sym_longint] = ACTIONS(5278),
    [anon_sym_integer] = ACTIONS(5278),
    [anon_sym_time] = ACTIONS(5278),
    [anon_sym_bit] = ACTIONS(5278),
    [anon_sym_logic] = ACTIONS(5278),
    [anon_sym_reg] = ACTIONS(5278),
    [anon_sym_shortreal] = ACTIONS(5278),
    [anon_sym_real] = ACTIONS(5278),
    [anon_sym_realtime] = ACTIONS(5278),
    [anon_sym_supply0] = ACTIONS(5278),
    [anon_sym_supply1] = ACTIONS(5278),
    [anon_sym_signed] = ACTIONS(5278),
    [anon_sym_unsigned] = ACTIONS(5278),
    [anon_sym_task] = ACTIONS(5278),
    [anon_sym_modport] = ACTIONS(5278),
    [anon_sym_assert] = ACTIONS(5278),
    [anon_sym_property] = ACTIONS(5278),
    [anon_sym_assume] = ACTIONS(5278),
    [anon_sym_cover] = ACTIONS(5278),
    [anon_sym_sequence] = ACTIONS(5278),
    [anon_sym_restrict] = ACTIONS(5278),
    [anon_sym_not] = ACTIONS(5278),
    [anon_sym_or] = ACTIONS(5278),
    [anon_sym_and] = ACTIONS(5278),
    [anon_sym_case] = ACTIONS(5278),
    [anon_sym_always] = ACTIONS(5278),
    [anon_sym_covergroup] = ACTIONS(5278),
    [anon_sym_let] = ACTIONS(5278),
    [anon_sym_pulldown] = ACTIONS(5278),
    [anon_sym_pullup] = ACTIONS(5278),
    [anon_sym_cmos] = ACTIONS(5278),
    [anon_sym_rcmos] = ACTIONS(5278),
    [anon_sym_bufif0] = ACTIONS(5278),
    [anon_sym_bufif1] = ACTIONS(5278),
    [anon_sym_notif0] = ACTIONS(5278),
    [anon_sym_notif1] = ACTIONS(5278),
    [anon_sym_nmos] = ACTIONS(5278),
    [anon_sym_pmos] = ACTIONS(5278),
    [anon_sym_rnmos] = ACTIONS(5278),
    [anon_sym_rpmos] = ACTIONS(5278),
    [anon_sym_nand] = ACTIONS(5278),
    [anon_sym_nor] = ACTIONS(5278),
    [anon_sym_xor] = ACTIONS(5278),
    [anon_sym_xnor] = ACTIONS(5278),
    [anon_sym_buf] = ACTIONS(5278),
    [anon_sym_tranif0] = ACTIONS(5278),
    [anon_sym_tranif1] = ACTIONS(5278),
    [anon_sym_rtranif1] = ACTIONS(5278),
    [anon_sym_rtranif0] = ACTIONS(5278),
    [anon_sym_tran] = ACTIONS(5278),
    [anon_sym_rtran] = ACTIONS(5278),
    [anon_sym_generate] = ACTIONS(5278),
    [anon_sym_for] = ACTIONS(5278),
    [anon_sym_primitive] = ACTIONS(5278),
    [anon_sym_initial] = ACTIONS(5278),
    [anon_sym_assign] = ACTIONS(5278),
    [anon_sym_alias] = ACTIONS(5278),
    [anon_sym_always_comb] = ACTIONS(5278),
    [anon_sym_always_latch] = ACTIONS(5278),
    [anon_sym_always_ff] = ACTIONS(5278),
    [anon_sym_final] = ACTIONS(5278),
    [anon_sym_global] = ACTIONS(5278),
    [anon_sym_specify] = ACTIONS(5278),
    [anon_sym_LPAREN_STAR] = ACTIONS(5276),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5276),
    [anon_sym_DOLLARunit] = ACTIONS(5276),
  },
  [859] = {
    [ts_builtin_sym_end] = ACTIONS(5280),
    [sym_simple_identifier] = ACTIONS(5282),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5280),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5280),
    [anon_sym_BQUOTE] = ACTIONS(5282),
    [aux_sym_id_directive_token1] = ACTIONS(5280),
    [aux_sym_id_directive_token2] = ACTIONS(5280),
    [aux_sym_id_directive_token3] = ACTIONS(5280),
    [aux_sym_id_directive_token4] = ACTIONS(5282),
    [aux_sym_zero_directive_token1] = ACTIONS(5280),
    [aux_sym_zero_directive_token2] = ACTIONS(5280),
    [aux_sym_zero_directive_token3] = ACTIONS(5280),
    [aux_sym_zero_directive_token4] = ACTIONS(5280),
    [aux_sym_zero_directive_token5] = ACTIONS(5280),
    [aux_sym_zero_directive_token6] = ACTIONS(5280),
    [aux_sym_zero_directive_token7] = ACTIONS(5280),
    [aux_sym_zero_directive_token8] = ACTIONS(5280),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5280),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5280),
    [anon_sym_wire] = ACTIONS(5282),
    [anon_sym_tri] = ACTIONS(5282),
    [anon_sym_tri0] = ACTIONS(5282),
    [anon_sym_tri1] = ACTIONS(5282),
    [anon_sym_wand] = ACTIONS(5282),
    [anon_sym_triand] = ACTIONS(5282),
    [anon_sym_wor] = ACTIONS(5282),
    [anon_sym_trior] = ACTIONS(5282),
    [anon_sym_trireg] = ACTIONS(5282),
    [anon_sym_uwire] = ACTIONS(5282),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5280),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5280),
    [aux_sym_begin_keywords_token1] = ACTIONS(5280),
    [anon_sym_SEMI] = ACTIONS(5280),
    [anon_sym_endmodule] = ACTIONS(5282),
    [anon_sym_extern] = ACTIONS(5282),
    [anon_sym_module] = ACTIONS(5282),
    [anon_sym_macromodule] = ACTIONS(5282),
    [anon_sym_endinterface] = ACTIONS(5282),
    [anon_sym_interface] = ACTIONS(5282),
    [anon_sym_endprogram] = ACTIONS(5282),
    [anon_sym_program] = ACTIONS(5282),
    [anon_sym_checker] = ACTIONS(5282),
    [anon_sym_virtual] = ACTIONS(5282),
    [anon_sym_class] = ACTIONS(5282),
    [anon_sym_package] = ACTIONS(5282),
    [anon_sym_endpackage] = ACTIONS(5282),
    [anon_sym_timeunit] = ACTIONS(5282),
    [anon_sym_timeprecision] = ACTIONS(5282),
    [anon_sym_type] = ACTIONS(5282),
    [anon_sym_input] = ACTIONS(5282),
    [anon_sym_output] = ACTIONS(5282),
    [anon_sym_inout] = ACTIONS(5282),
    [anon_sym_ref] = ACTIONS(5282),
    [anon_sym_DOLLARfatal] = ACTIONS(5280),
    [anon_sym_DOLLARerror] = ACTIONS(5280),
    [anon_sym_DOLLARwarning] = ACTIONS(5280),
    [anon_sym_DOLLARinfo] = ACTIONS(5280),
    [anon_sym_default] = ACTIONS(5282),
    [anon_sym_clocking] = ACTIONS(5282),
    [anon_sym_defparam] = ACTIONS(5282),
    [anon_sym_bind] = ACTIONS(5282),
    [anon_sym_const] = ACTIONS(5282),
    [anon_sym_function] = ACTIONS(5282),
    [anon_sym_static] = ACTIONS(5282),
    [anon_sym_constraint] = ACTIONS(5282),
    [anon_sym_if] = ACTIONS(5282),
    [anon_sym_else] = ACTIONS(5282),
    [anon_sym_LBRACK] = ACTIONS(5280),
    [anon_sym_localparam] = ACTIONS(5282),
    [anon_sym_parameter] = ACTIONS(5282),
    [anon_sym_specparam] = ACTIONS(5282),
    [anon_sym_var] = ACTIONS(5282),
    [anon_sym_import] = ACTIONS(5282),
    [anon_sym_export] = ACTIONS(5282),
    [anon_sym_genvar] = ACTIONS(5282),
    [anon_sym_interconnect] = ACTIONS(5282),
    [anon_sym_typedef] = ACTIONS(5282),
    [anon_sym_enum] = ACTIONS(5282),
    [anon_sym_struct] = ACTIONS(5282),
    [anon_sym_union] = ACTIONS(5282),
    [anon_sym_nettype] = ACTIONS(5282),
    [anon_sym_automatic] = ACTIONS(5282),
    [anon_sym_string] = ACTIONS(5282),
    [anon_sym_chandle] = ACTIONS(5282),
    [anon_sym_event] = ACTIONS(5282),
    [anon_sym_byte] = ACTIONS(5282),
    [anon_sym_shortint] = ACTIONS(5282),
    [anon_sym_int] = ACTIONS(5282),
    [anon_sym_longint] = ACTIONS(5282),
    [anon_sym_integer] = ACTIONS(5282),
    [anon_sym_time] = ACTIONS(5282),
    [anon_sym_bit] = ACTIONS(5282),
    [anon_sym_logic] = ACTIONS(5282),
    [anon_sym_reg] = ACTIONS(5282),
    [anon_sym_shortreal] = ACTIONS(5282),
    [anon_sym_real] = ACTIONS(5282),
    [anon_sym_realtime] = ACTIONS(5282),
    [anon_sym_supply0] = ACTIONS(5282),
    [anon_sym_supply1] = ACTIONS(5282),
    [anon_sym_signed] = ACTIONS(5282),
    [anon_sym_unsigned] = ACTIONS(5282),
    [anon_sym_task] = ACTIONS(5282),
    [anon_sym_modport] = ACTIONS(5282),
    [anon_sym_assert] = ACTIONS(5282),
    [anon_sym_property] = ACTIONS(5282),
    [anon_sym_assume] = ACTIONS(5282),
    [anon_sym_cover] = ACTIONS(5282),
    [anon_sym_sequence] = ACTIONS(5282),
    [anon_sym_restrict] = ACTIONS(5282),
    [anon_sym_not] = ACTIONS(5282),
    [anon_sym_or] = ACTIONS(5282),
    [anon_sym_and] = ACTIONS(5282),
    [anon_sym_case] = ACTIONS(5282),
    [anon_sym_always] = ACTIONS(5282),
    [anon_sym_covergroup] = ACTIONS(5282),
    [anon_sym_let] = ACTIONS(5282),
    [anon_sym_pulldown] = ACTIONS(5282),
    [anon_sym_pullup] = ACTIONS(5282),
    [anon_sym_cmos] = ACTIONS(5282),
    [anon_sym_rcmos] = ACTIONS(5282),
    [anon_sym_bufif0] = ACTIONS(5282),
    [anon_sym_bufif1] = ACTIONS(5282),
    [anon_sym_notif0] = ACTIONS(5282),
    [anon_sym_notif1] = ACTIONS(5282),
    [anon_sym_nmos] = ACTIONS(5282),
    [anon_sym_pmos] = ACTIONS(5282),
    [anon_sym_rnmos] = ACTIONS(5282),
    [anon_sym_rpmos] = ACTIONS(5282),
    [anon_sym_nand] = ACTIONS(5282),
    [anon_sym_nor] = ACTIONS(5282),
    [anon_sym_xor] = ACTIONS(5282),
    [anon_sym_xnor] = ACTIONS(5282),
    [anon_sym_buf] = ACTIONS(5282),
    [anon_sym_tranif0] = ACTIONS(5282),
    [anon_sym_tranif1] = ACTIONS(5282),
    [anon_sym_rtranif1] = ACTIONS(5282),
    [anon_sym_rtranif0] = ACTIONS(5282),
    [anon_sym_tran] = ACTIONS(5282),
    [anon_sym_rtran] = ACTIONS(5282),
    [anon_sym_generate] = ACTIONS(5282),
    [anon_sym_for] = ACTIONS(5282),
    [anon_sym_primitive] = ACTIONS(5282),
    [anon_sym_initial] = ACTIONS(5282),
    [anon_sym_assign] = ACTIONS(5282),
    [anon_sym_alias] = ACTIONS(5282),
    [anon_sym_always_comb] = ACTIONS(5282),
    [anon_sym_always_latch] = ACTIONS(5282),
    [anon_sym_always_ff] = ACTIONS(5282),
    [anon_sym_final] = ACTIONS(5282),
    [anon_sym_global] = ACTIONS(5282),
    [anon_sym_specify] = ACTIONS(5282),
    [anon_sym_LPAREN_STAR] = ACTIONS(5280),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5280),
    [anon_sym_DOLLARunit] = ACTIONS(5280),
  },
  [860] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(20099),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(20099),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7377),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5284),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [861] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(20099),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(20099),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [862] = {
    [ts_builtin_sym_end] = ACTIONS(5288),
    [sym_simple_identifier] = ACTIONS(5290),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5288),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5288),
    [anon_sym_BQUOTE] = ACTIONS(5290),
    [aux_sym_id_directive_token1] = ACTIONS(5288),
    [aux_sym_id_directive_token2] = ACTIONS(5288),
    [aux_sym_id_directive_token3] = ACTIONS(5288),
    [aux_sym_id_directive_token4] = ACTIONS(5290),
    [aux_sym_zero_directive_token1] = ACTIONS(5288),
    [aux_sym_zero_directive_token2] = ACTIONS(5288),
    [aux_sym_zero_directive_token3] = ACTIONS(5288),
    [aux_sym_zero_directive_token4] = ACTIONS(5288),
    [aux_sym_zero_directive_token5] = ACTIONS(5288),
    [aux_sym_zero_directive_token6] = ACTIONS(5288),
    [aux_sym_zero_directive_token7] = ACTIONS(5288),
    [aux_sym_zero_directive_token8] = ACTIONS(5288),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5288),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5288),
    [anon_sym_wire] = ACTIONS(5290),
    [anon_sym_tri] = ACTIONS(5290),
    [anon_sym_tri0] = ACTIONS(5290),
    [anon_sym_tri1] = ACTIONS(5290),
    [anon_sym_wand] = ACTIONS(5290),
    [anon_sym_triand] = ACTIONS(5290),
    [anon_sym_wor] = ACTIONS(5290),
    [anon_sym_trior] = ACTIONS(5290),
    [anon_sym_trireg] = ACTIONS(5290),
    [anon_sym_uwire] = ACTIONS(5290),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5288),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5288),
    [aux_sym_begin_keywords_token1] = ACTIONS(5288),
    [anon_sym_SEMI] = ACTIONS(5288),
    [anon_sym_endmodule] = ACTIONS(5290),
    [anon_sym_extern] = ACTIONS(5290),
    [anon_sym_module] = ACTIONS(5290),
    [anon_sym_macromodule] = ACTIONS(5290),
    [anon_sym_endinterface] = ACTIONS(5290),
    [anon_sym_interface] = ACTIONS(5290),
    [anon_sym_endprogram] = ACTIONS(5290),
    [anon_sym_program] = ACTIONS(5290),
    [anon_sym_checker] = ACTIONS(5290),
    [anon_sym_virtual] = ACTIONS(5290),
    [anon_sym_class] = ACTIONS(5290),
    [anon_sym_package] = ACTIONS(5290),
    [anon_sym_endpackage] = ACTIONS(5290),
    [anon_sym_timeunit] = ACTIONS(5290),
    [anon_sym_timeprecision] = ACTIONS(5290),
    [anon_sym_type] = ACTIONS(5290),
    [anon_sym_input] = ACTIONS(5290),
    [anon_sym_output] = ACTIONS(5290),
    [anon_sym_inout] = ACTIONS(5290),
    [anon_sym_ref] = ACTIONS(5290),
    [anon_sym_DOLLARfatal] = ACTIONS(5288),
    [anon_sym_DOLLARerror] = ACTIONS(5288),
    [anon_sym_DOLLARwarning] = ACTIONS(5288),
    [anon_sym_DOLLARinfo] = ACTIONS(5288),
    [anon_sym_default] = ACTIONS(5290),
    [anon_sym_clocking] = ACTIONS(5290),
    [anon_sym_defparam] = ACTIONS(5290),
    [anon_sym_bind] = ACTIONS(5290),
    [anon_sym_const] = ACTIONS(5290),
    [anon_sym_function] = ACTIONS(5290),
    [anon_sym_static] = ACTIONS(5290),
    [anon_sym_constraint] = ACTIONS(5290),
    [anon_sym_if] = ACTIONS(5290),
    [anon_sym_else] = ACTIONS(5290),
    [anon_sym_LBRACK] = ACTIONS(5288),
    [anon_sym_localparam] = ACTIONS(5290),
    [anon_sym_parameter] = ACTIONS(5290),
    [anon_sym_specparam] = ACTIONS(5290),
    [anon_sym_var] = ACTIONS(5290),
    [anon_sym_import] = ACTIONS(5290),
    [anon_sym_export] = ACTIONS(5290),
    [anon_sym_genvar] = ACTIONS(5290),
    [anon_sym_interconnect] = ACTIONS(5290),
    [anon_sym_typedef] = ACTIONS(5290),
    [anon_sym_enum] = ACTIONS(5290),
    [anon_sym_struct] = ACTIONS(5290),
    [anon_sym_union] = ACTIONS(5290),
    [anon_sym_nettype] = ACTIONS(5290),
    [anon_sym_automatic] = ACTIONS(5290),
    [anon_sym_string] = ACTIONS(5290),
    [anon_sym_chandle] = ACTIONS(5290),
    [anon_sym_event] = ACTIONS(5290),
    [anon_sym_byte] = ACTIONS(5290),
    [anon_sym_shortint] = ACTIONS(5290),
    [anon_sym_int] = ACTIONS(5290),
    [anon_sym_longint] = ACTIONS(5290),
    [anon_sym_integer] = ACTIONS(5290),
    [anon_sym_time] = ACTIONS(5290),
    [anon_sym_bit] = ACTIONS(5290),
    [anon_sym_logic] = ACTIONS(5290),
    [anon_sym_reg] = ACTIONS(5290),
    [anon_sym_shortreal] = ACTIONS(5290),
    [anon_sym_real] = ACTIONS(5290),
    [anon_sym_realtime] = ACTIONS(5290),
    [anon_sym_supply0] = ACTIONS(5290),
    [anon_sym_supply1] = ACTIONS(5290),
    [anon_sym_signed] = ACTIONS(5290),
    [anon_sym_unsigned] = ACTIONS(5290),
    [anon_sym_task] = ACTIONS(5290),
    [anon_sym_modport] = ACTIONS(5290),
    [anon_sym_assert] = ACTIONS(5290),
    [anon_sym_property] = ACTIONS(5290),
    [anon_sym_assume] = ACTIONS(5290),
    [anon_sym_cover] = ACTIONS(5290),
    [anon_sym_sequence] = ACTIONS(5290),
    [anon_sym_restrict] = ACTIONS(5290),
    [anon_sym_not] = ACTIONS(5290),
    [anon_sym_or] = ACTIONS(5290),
    [anon_sym_and] = ACTIONS(5290),
    [anon_sym_case] = ACTIONS(5290),
    [anon_sym_always] = ACTIONS(5290),
    [anon_sym_covergroup] = ACTIONS(5290),
    [anon_sym_let] = ACTIONS(5290),
    [anon_sym_pulldown] = ACTIONS(5290),
    [anon_sym_pullup] = ACTIONS(5290),
    [anon_sym_cmos] = ACTIONS(5290),
    [anon_sym_rcmos] = ACTIONS(5290),
    [anon_sym_bufif0] = ACTIONS(5290),
    [anon_sym_bufif1] = ACTIONS(5290),
    [anon_sym_notif0] = ACTIONS(5290),
    [anon_sym_notif1] = ACTIONS(5290),
    [anon_sym_nmos] = ACTIONS(5290),
    [anon_sym_pmos] = ACTIONS(5290),
    [anon_sym_rnmos] = ACTIONS(5290),
    [anon_sym_rpmos] = ACTIONS(5290),
    [anon_sym_nand] = ACTIONS(5290),
    [anon_sym_nor] = ACTIONS(5290),
    [anon_sym_xor] = ACTIONS(5290),
    [anon_sym_xnor] = ACTIONS(5290),
    [anon_sym_buf] = ACTIONS(5290),
    [anon_sym_tranif0] = ACTIONS(5290),
    [anon_sym_tranif1] = ACTIONS(5290),
    [anon_sym_rtranif1] = ACTIONS(5290),
    [anon_sym_rtranif0] = ACTIONS(5290),
    [anon_sym_tran] = ACTIONS(5290),
    [anon_sym_rtran] = ACTIONS(5290),
    [anon_sym_generate] = ACTIONS(5290),
    [anon_sym_for] = ACTIONS(5290),
    [anon_sym_primitive] = ACTIONS(5290),
    [anon_sym_initial] = ACTIONS(5290),
    [anon_sym_assign] = ACTIONS(5290),
    [anon_sym_alias] = ACTIONS(5290),
    [anon_sym_always_comb] = ACTIONS(5290),
    [anon_sym_always_latch] = ACTIONS(5290),
    [anon_sym_always_ff] = ACTIONS(5290),
    [anon_sym_final] = ACTIONS(5290),
    [anon_sym_global] = ACTIONS(5290),
    [anon_sym_specify] = ACTIONS(5290),
    [anon_sym_LPAREN_STAR] = ACTIONS(5288),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5288),
    [anon_sym_DOLLARunit] = ACTIONS(5288),
  },
  [863] = {
    [ts_builtin_sym_end] = ACTIONS(5292),
    [sym_simple_identifier] = ACTIONS(5294),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5292),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5292),
    [anon_sym_BQUOTE] = ACTIONS(5294),
    [aux_sym_id_directive_token1] = ACTIONS(5292),
    [aux_sym_id_directive_token2] = ACTIONS(5292),
    [aux_sym_id_directive_token3] = ACTIONS(5292),
    [aux_sym_id_directive_token4] = ACTIONS(5294),
    [aux_sym_zero_directive_token1] = ACTIONS(5292),
    [aux_sym_zero_directive_token2] = ACTIONS(5292),
    [aux_sym_zero_directive_token3] = ACTIONS(5292),
    [aux_sym_zero_directive_token4] = ACTIONS(5292),
    [aux_sym_zero_directive_token5] = ACTIONS(5292),
    [aux_sym_zero_directive_token6] = ACTIONS(5292),
    [aux_sym_zero_directive_token7] = ACTIONS(5292),
    [aux_sym_zero_directive_token8] = ACTIONS(5292),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5292),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5292),
    [anon_sym_wire] = ACTIONS(5294),
    [anon_sym_tri] = ACTIONS(5294),
    [anon_sym_tri0] = ACTIONS(5294),
    [anon_sym_tri1] = ACTIONS(5294),
    [anon_sym_wand] = ACTIONS(5294),
    [anon_sym_triand] = ACTIONS(5294),
    [anon_sym_wor] = ACTIONS(5294),
    [anon_sym_trior] = ACTIONS(5294),
    [anon_sym_trireg] = ACTIONS(5294),
    [anon_sym_uwire] = ACTIONS(5294),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5292),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5292),
    [aux_sym_begin_keywords_token1] = ACTIONS(5292),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_endmodule] = ACTIONS(5294),
    [anon_sym_extern] = ACTIONS(5294),
    [anon_sym_module] = ACTIONS(5294),
    [anon_sym_macromodule] = ACTIONS(5294),
    [anon_sym_endinterface] = ACTIONS(5294),
    [anon_sym_interface] = ACTIONS(5294),
    [anon_sym_endprogram] = ACTIONS(5294),
    [anon_sym_program] = ACTIONS(5294),
    [anon_sym_checker] = ACTIONS(5294),
    [anon_sym_virtual] = ACTIONS(5294),
    [anon_sym_class] = ACTIONS(5294),
    [anon_sym_package] = ACTIONS(5294),
    [anon_sym_endpackage] = ACTIONS(5294),
    [anon_sym_timeunit] = ACTIONS(5294),
    [anon_sym_timeprecision] = ACTIONS(5294),
    [anon_sym_type] = ACTIONS(5294),
    [anon_sym_input] = ACTIONS(5294),
    [anon_sym_output] = ACTIONS(5294),
    [anon_sym_inout] = ACTIONS(5294),
    [anon_sym_ref] = ACTIONS(5294),
    [anon_sym_DOLLARfatal] = ACTIONS(5292),
    [anon_sym_DOLLARerror] = ACTIONS(5292),
    [anon_sym_DOLLARwarning] = ACTIONS(5292),
    [anon_sym_DOLLARinfo] = ACTIONS(5292),
    [anon_sym_default] = ACTIONS(5294),
    [anon_sym_clocking] = ACTIONS(5294),
    [anon_sym_defparam] = ACTIONS(5294),
    [anon_sym_bind] = ACTIONS(5294),
    [anon_sym_const] = ACTIONS(5294),
    [anon_sym_function] = ACTIONS(5294),
    [anon_sym_static] = ACTIONS(5294),
    [anon_sym_constraint] = ACTIONS(5294),
    [anon_sym_if] = ACTIONS(5294),
    [anon_sym_else] = ACTIONS(5294),
    [anon_sym_LBRACK] = ACTIONS(5292),
    [anon_sym_localparam] = ACTIONS(5294),
    [anon_sym_parameter] = ACTIONS(5294),
    [anon_sym_specparam] = ACTIONS(5294),
    [anon_sym_var] = ACTIONS(5294),
    [anon_sym_import] = ACTIONS(5294),
    [anon_sym_export] = ACTIONS(5294),
    [anon_sym_genvar] = ACTIONS(5294),
    [anon_sym_interconnect] = ACTIONS(5294),
    [anon_sym_typedef] = ACTIONS(5294),
    [anon_sym_enum] = ACTIONS(5294),
    [anon_sym_struct] = ACTIONS(5294),
    [anon_sym_union] = ACTIONS(5294),
    [anon_sym_nettype] = ACTIONS(5294),
    [anon_sym_automatic] = ACTIONS(5294),
    [anon_sym_string] = ACTIONS(5294),
    [anon_sym_chandle] = ACTIONS(5294),
    [anon_sym_event] = ACTIONS(5294),
    [anon_sym_byte] = ACTIONS(5294),
    [anon_sym_shortint] = ACTIONS(5294),
    [anon_sym_int] = ACTIONS(5294),
    [anon_sym_longint] = ACTIONS(5294),
    [anon_sym_integer] = ACTIONS(5294),
    [anon_sym_time] = ACTIONS(5294),
    [anon_sym_bit] = ACTIONS(5294),
    [anon_sym_logic] = ACTIONS(5294),
    [anon_sym_reg] = ACTIONS(5294),
    [anon_sym_shortreal] = ACTIONS(5294),
    [anon_sym_real] = ACTIONS(5294),
    [anon_sym_realtime] = ACTIONS(5294),
    [anon_sym_supply0] = ACTIONS(5294),
    [anon_sym_supply1] = ACTIONS(5294),
    [anon_sym_signed] = ACTIONS(5294),
    [anon_sym_unsigned] = ACTIONS(5294),
    [anon_sym_task] = ACTIONS(5294),
    [anon_sym_modport] = ACTIONS(5294),
    [anon_sym_assert] = ACTIONS(5294),
    [anon_sym_property] = ACTIONS(5294),
    [anon_sym_assume] = ACTIONS(5294),
    [anon_sym_cover] = ACTIONS(5294),
    [anon_sym_sequence] = ACTIONS(5294),
    [anon_sym_restrict] = ACTIONS(5294),
    [anon_sym_not] = ACTIONS(5294),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_and] = ACTIONS(5294),
    [anon_sym_case] = ACTIONS(5294),
    [anon_sym_always] = ACTIONS(5294),
    [anon_sym_covergroup] = ACTIONS(5294),
    [anon_sym_let] = ACTIONS(5294),
    [anon_sym_pulldown] = ACTIONS(5294),
    [anon_sym_pullup] = ACTIONS(5294),
    [anon_sym_cmos] = ACTIONS(5294),
    [anon_sym_rcmos] = ACTIONS(5294),
    [anon_sym_bufif0] = ACTIONS(5294),
    [anon_sym_bufif1] = ACTIONS(5294),
    [anon_sym_notif0] = ACTIONS(5294),
    [anon_sym_notif1] = ACTIONS(5294),
    [anon_sym_nmos] = ACTIONS(5294),
    [anon_sym_pmos] = ACTIONS(5294),
    [anon_sym_rnmos] = ACTIONS(5294),
    [anon_sym_rpmos] = ACTIONS(5294),
    [anon_sym_nand] = ACTIONS(5294),
    [anon_sym_nor] = ACTIONS(5294),
    [anon_sym_xor] = ACTIONS(5294),
    [anon_sym_xnor] = ACTIONS(5294),
    [anon_sym_buf] = ACTIONS(5294),
    [anon_sym_tranif0] = ACTIONS(5294),
    [anon_sym_tranif1] = ACTIONS(5294),
    [anon_sym_rtranif1] = ACTIONS(5294),
    [anon_sym_rtranif0] = ACTIONS(5294),
    [anon_sym_tran] = ACTIONS(5294),
    [anon_sym_rtran] = ACTIONS(5294),
    [anon_sym_generate] = ACTIONS(5294),
    [anon_sym_for] = ACTIONS(5294),
    [anon_sym_primitive] = ACTIONS(5294),
    [anon_sym_initial] = ACTIONS(5294),
    [anon_sym_assign] = ACTIONS(5294),
    [anon_sym_alias] = ACTIONS(5294),
    [anon_sym_always_comb] = ACTIONS(5294),
    [anon_sym_always_latch] = ACTIONS(5294),
    [anon_sym_always_ff] = ACTIONS(5294),
    [anon_sym_final] = ACTIONS(5294),
    [anon_sym_global] = ACTIONS(5294),
    [anon_sym_specify] = ACTIONS(5294),
    [anon_sym_LPAREN_STAR] = ACTIONS(5292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5292),
    [anon_sym_DOLLARunit] = ACTIONS(5292),
  },
  [864] = {
    [ts_builtin_sym_end] = ACTIONS(5296),
    [sym_simple_identifier] = ACTIONS(5298),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5296),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5296),
    [anon_sym_BQUOTE] = ACTIONS(5298),
    [aux_sym_id_directive_token1] = ACTIONS(5296),
    [aux_sym_id_directive_token2] = ACTIONS(5296),
    [aux_sym_id_directive_token3] = ACTIONS(5296),
    [aux_sym_id_directive_token4] = ACTIONS(5298),
    [aux_sym_zero_directive_token1] = ACTIONS(5296),
    [aux_sym_zero_directive_token2] = ACTIONS(5296),
    [aux_sym_zero_directive_token3] = ACTIONS(5296),
    [aux_sym_zero_directive_token4] = ACTIONS(5296),
    [aux_sym_zero_directive_token5] = ACTIONS(5296),
    [aux_sym_zero_directive_token6] = ACTIONS(5296),
    [aux_sym_zero_directive_token7] = ACTIONS(5296),
    [aux_sym_zero_directive_token8] = ACTIONS(5296),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5296),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5296),
    [anon_sym_wire] = ACTIONS(5298),
    [anon_sym_tri] = ACTIONS(5298),
    [anon_sym_tri0] = ACTIONS(5298),
    [anon_sym_tri1] = ACTIONS(5298),
    [anon_sym_wand] = ACTIONS(5298),
    [anon_sym_triand] = ACTIONS(5298),
    [anon_sym_wor] = ACTIONS(5298),
    [anon_sym_trior] = ACTIONS(5298),
    [anon_sym_trireg] = ACTIONS(5298),
    [anon_sym_uwire] = ACTIONS(5298),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5296),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5296),
    [aux_sym_begin_keywords_token1] = ACTIONS(5296),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_endmodule] = ACTIONS(5298),
    [anon_sym_extern] = ACTIONS(5298),
    [anon_sym_module] = ACTIONS(5298),
    [anon_sym_macromodule] = ACTIONS(5298),
    [anon_sym_endinterface] = ACTIONS(5298),
    [anon_sym_interface] = ACTIONS(5298),
    [anon_sym_endprogram] = ACTIONS(5298),
    [anon_sym_program] = ACTIONS(5298),
    [anon_sym_checker] = ACTIONS(5298),
    [anon_sym_virtual] = ACTIONS(5298),
    [anon_sym_class] = ACTIONS(5298),
    [anon_sym_package] = ACTIONS(5298),
    [anon_sym_endpackage] = ACTIONS(5298),
    [anon_sym_timeunit] = ACTIONS(5298),
    [anon_sym_timeprecision] = ACTIONS(5298),
    [anon_sym_type] = ACTIONS(5298),
    [anon_sym_input] = ACTIONS(5298),
    [anon_sym_output] = ACTIONS(5298),
    [anon_sym_inout] = ACTIONS(5298),
    [anon_sym_ref] = ACTIONS(5298),
    [anon_sym_DOLLARfatal] = ACTIONS(5296),
    [anon_sym_DOLLARerror] = ACTIONS(5296),
    [anon_sym_DOLLARwarning] = ACTIONS(5296),
    [anon_sym_DOLLARinfo] = ACTIONS(5296),
    [anon_sym_default] = ACTIONS(5298),
    [anon_sym_clocking] = ACTIONS(5298),
    [anon_sym_defparam] = ACTIONS(5298),
    [anon_sym_bind] = ACTIONS(5298),
    [anon_sym_const] = ACTIONS(5298),
    [anon_sym_function] = ACTIONS(5298),
    [anon_sym_static] = ACTIONS(5298),
    [anon_sym_constraint] = ACTIONS(5298),
    [anon_sym_if] = ACTIONS(5298),
    [anon_sym_else] = ACTIONS(5298),
    [anon_sym_LBRACK] = ACTIONS(5296),
    [anon_sym_localparam] = ACTIONS(5298),
    [anon_sym_parameter] = ACTIONS(5298),
    [anon_sym_specparam] = ACTIONS(5298),
    [anon_sym_var] = ACTIONS(5298),
    [anon_sym_import] = ACTIONS(5298),
    [anon_sym_export] = ACTIONS(5298),
    [anon_sym_genvar] = ACTIONS(5298),
    [anon_sym_interconnect] = ACTIONS(5298),
    [anon_sym_typedef] = ACTIONS(5298),
    [anon_sym_enum] = ACTIONS(5298),
    [anon_sym_struct] = ACTIONS(5298),
    [anon_sym_union] = ACTIONS(5298),
    [anon_sym_nettype] = ACTIONS(5298),
    [anon_sym_automatic] = ACTIONS(5298),
    [anon_sym_string] = ACTIONS(5298),
    [anon_sym_chandle] = ACTIONS(5298),
    [anon_sym_event] = ACTIONS(5298),
    [anon_sym_byte] = ACTIONS(5298),
    [anon_sym_shortint] = ACTIONS(5298),
    [anon_sym_int] = ACTIONS(5298),
    [anon_sym_longint] = ACTIONS(5298),
    [anon_sym_integer] = ACTIONS(5298),
    [anon_sym_time] = ACTIONS(5298),
    [anon_sym_bit] = ACTIONS(5298),
    [anon_sym_logic] = ACTIONS(5298),
    [anon_sym_reg] = ACTIONS(5298),
    [anon_sym_shortreal] = ACTIONS(5298),
    [anon_sym_real] = ACTIONS(5298),
    [anon_sym_realtime] = ACTIONS(5298),
    [anon_sym_supply0] = ACTIONS(5298),
    [anon_sym_supply1] = ACTIONS(5298),
    [anon_sym_signed] = ACTIONS(5298),
    [anon_sym_unsigned] = ACTIONS(5298),
    [anon_sym_task] = ACTIONS(5298),
    [anon_sym_modport] = ACTIONS(5298),
    [anon_sym_assert] = ACTIONS(5298),
    [anon_sym_property] = ACTIONS(5298),
    [anon_sym_assume] = ACTIONS(5298),
    [anon_sym_cover] = ACTIONS(5298),
    [anon_sym_sequence] = ACTIONS(5298),
    [anon_sym_restrict] = ACTIONS(5298),
    [anon_sym_not] = ACTIONS(5298),
    [anon_sym_or] = ACTIONS(5298),
    [anon_sym_and] = ACTIONS(5298),
    [anon_sym_case] = ACTIONS(5298),
    [anon_sym_always] = ACTIONS(5298),
    [anon_sym_covergroup] = ACTIONS(5298),
    [anon_sym_let] = ACTIONS(5298),
    [anon_sym_pulldown] = ACTIONS(5298),
    [anon_sym_pullup] = ACTIONS(5298),
    [anon_sym_cmos] = ACTIONS(5298),
    [anon_sym_rcmos] = ACTIONS(5298),
    [anon_sym_bufif0] = ACTIONS(5298),
    [anon_sym_bufif1] = ACTIONS(5298),
    [anon_sym_notif0] = ACTIONS(5298),
    [anon_sym_notif1] = ACTIONS(5298),
    [anon_sym_nmos] = ACTIONS(5298),
    [anon_sym_pmos] = ACTIONS(5298),
    [anon_sym_rnmos] = ACTIONS(5298),
    [anon_sym_rpmos] = ACTIONS(5298),
    [anon_sym_nand] = ACTIONS(5298),
    [anon_sym_nor] = ACTIONS(5298),
    [anon_sym_xor] = ACTIONS(5298),
    [anon_sym_xnor] = ACTIONS(5298),
    [anon_sym_buf] = ACTIONS(5298),
    [anon_sym_tranif0] = ACTIONS(5298),
    [anon_sym_tranif1] = ACTIONS(5298),
    [anon_sym_rtranif1] = ACTIONS(5298),
    [anon_sym_rtranif0] = ACTIONS(5298),
    [anon_sym_tran] = ACTIONS(5298),
    [anon_sym_rtran] = ACTIONS(5298),
    [anon_sym_generate] = ACTIONS(5298),
    [anon_sym_for] = ACTIONS(5298),
    [anon_sym_primitive] = ACTIONS(5298),
    [anon_sym_initial] = ACTIONS(5298),
    [anon_sym_assign] = ACTIONS(5298),
    [anon_sym_alias] = ACTIONS(5298),
    [anon_sym_always_comb] = ACTIONS(5298),
    [anon_sym_always_latch] = ACTIONS(5298),
    [anon_sym_always_ff] = ACTIONS(5298),
    [anon_sym_final] = ACTIONS(5298),
    [anon_sym_global] = ACTIONS(5298),
    [anon_sym_specify] = ACTIONS(5298),
    [anon_sym_LPAREN_STAR] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5296),
    [anon_sym_DOLLARunit] = ACTIONS(5296),
  },
  [865] = {
    [ts_builtin_sym_end] = ACTIONS(5300),
    [sym_simple_identifier] = ACTIONS(5302),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5300),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5300),
    [anon_sym_BQUOTE] = ACTIONS(5302),
    [aux_sym_id_directive_token1] = ACTIONS(5300),
    [aux_sym_id_directive_token2] = ACTIONS(5300),
    [aux_sym_id_directive_token3] = ACTIONS(5300),
    [aux_sym_id_directive_token4] = ACTIONS(5302),
    [aux_sym_zero_directive_token1] = ACTIONS(5300),
    [aux_sym_zero_directive_token2] = ACTIONS(5300),
    [aux_sym_zero_directive_token3] = ACTIONS(5300),
    [aux_sym_zero_directive_token4] = ACTIONS(5300),
    [aux_sym_zero_directive_token5] = ACTIONS(5300),
    [aux_sym_zero_directive_token6] = ACTIONS(5300),
    [aux_sym_zero_directive_token7] = ACTIONS(5300),
    [aux_sym_zero_directive_token8] = ACTIONS(5300),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5300),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5300),
    [anon_sym_wire] = ACTIONS(5302),
    [anon_sym_tri] = ACTIONS(5302),
    [anon_sym_tri0] = ACTIONS(5302),
    [anon_sym_tri1] = ACTIONS(5302),
    [anon_sym_wand] = ACTIONS(5302),
    [anon_sym_triand] = ACTIONS(5302),
    [anon_sym_wor] = ACTIONS(5302),
    [anon_sym_trior] = ACTIONS(5302),
    [anon_sym_trireg] = ACTIONS(5302),
    [anon_sym_uwire] = ACTIONS(5302),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5300),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5300),
    [aux_sym_begin_keywords_token1] = ACTIONS(5300),
    [anon_sym_SEMI] = ACTIONS(5300),
    [anon_sym_endmodule] = ACTIONS(5302),
    [anon_sym_extern] = ACTIONS(5302),
    [anon_sym_module] = ACTIONS(5302),
    [anon_sym_macromodule] = ACTIONS(5302),
    [anon_sym_endinterface] = ACTIONS(5302),
    [anon_sym_interface] = ACTIONS(5302),
    [anon_sym_endprogram] = ACTIONS(5302),
    [anon_sym_program] = ACTIONS(5302),
    [anon_sym_checker] = ACTIONS(5302),
    [anon_sym_virtual] = ACTIONS(5302),
    [anon_sym_class] = ACTIONS(5302),
    [anon_sym_package] = ACTIONS(5302),
    [anon_sym_endpackage] = ACTIONS(5302),
    [anon_sym_timeunit] = ACTIONS(5302),
    [anon_sym_timeprecision] = ACTIONS(5302),
    [anon_sym_type] = ACTIONS(5302),
    [anon_sym_input] = ACTIONS(5302),
    [anon_sym_output] = ACTIONS(5302),
    [anon_sym_inout] = ACTIONS(5302),
    [anon_sym_ref] = ACTIONS(5302),
    [anon_sym_DOLLARfatal] = ACTIONS(5300),
    [anon_sym_DOLLARerror] = ACTIONS(5300),
    [anon_sym_DOLLARwarning] = ACTIONS(5300),
    [anon_sym_DOLLARinfo] = ACTIONS(5300),
    [anon_sym_default] = ACTIONS(5302),
    [anon_sym_clocking] = ACTIONS(5302),
    [anon_sym_defparam] = ACTIONS(5302),
    [anon_sym_bind] = ACTIONS(5302),
    [anon_sym_const] = ACTIONS(5302),
    [anon_sym_function] = ACTIONS(5302),
    [anon_sym_static] = ACTIONS(5302),
    [anon_sym_constraint] = ACTIONS(5302),
    [anon_sym_if] = ACTIONS(5302),
    [anon_sym_else] = ACTIONS(5302),
    [anon_sym_LBRACK] = ACTIONS(5300),
    [anon_sym_localparam] = ACTIONS(5302),
    [anon_sym_parameter] = ACTIONS(5302),
    [anon_sym_specparam] = ACTIONS(5302),
    [anon_sym_var] = ACTIONS(5302),
    [anon_sym_import] = ACTIONS(5302),
    [anon_sym_export] = ACTIONS(5302),
    [anon_sym_genvar] = ACTIONS(5302),
    [anon_sym_interconnect] = ACTIONS(5302),
    [anon_sym_typedef] = ACTIONS(5302),
    [anon_sym_enum] = ACTIONS(5302),
    [anon_sym_struct] = ACTIONS(5302),
    [anon_sym_union] = ACTIONS(5302),
    [anon_sym_nettype] = ACTIONS(5302),
    [anon_sym_automatic] = ACTIONS(5302),
    [anon_sym_string] = ACTIONS(5302),
    [anon_sym_chandle] = ACTIONS(5302),
    [anon_sym_event] = ACTIONS(5302),
    [anon_sym_byte] = ACTIONS(5302),
    [anon_sym_shortint] = ACTIONS(5302),
    [anon_sym_int] = ACTIONS(5302),
    [anon_sym_longint] = ACTIONS(5302),
    [anon_sym_integer] = ACTIONS(5302),
    [anon_sym_time] = ACTIONS(5302),
    [anon_sym_bit] = ACTIONS(5302),
    [anon_sym_logic] = ACTIONS(5302),
    [anon_sym_reg] = ACTIONS(5302),
    [anon_sym_shortreal] = ACTIONS(5302),
    [anon_sym_real] = ACTIONS(5302),
    [anon_sym_realtime] = ACTIONS(5302),
    [anon_sym_supply0] = ACTIONS(5302),
    [anon_sym_supply1] = ACTIONS(5302),
    [anon_sym_signed] = ACTIONS(5302),
    [anon_sym_unsigned] = ACTIONS(5302),
    [anon_sym_task] = ACTIONS(5302),
    [anon_sym_modport] = ACTIONS(5302),
    [anon_sym_assert] = ACTIONS(5302),
    [anon_sym_property] = ACTIONS(5302),
    [anon_sym_assume] = ACTIONS(5302),
    [anon_sym_cover] = ACTIONS(5302),
    [anon_sym_sequence] = ACTIONS(5302),
    [anon_sym_restrict] = ACTIONS(5302),
    [anon_sym_not] = ACTIONS(5302),
    [anon_sym_or] = ACTIONS(5302),
    [anon_sym_and] = ACTIONS(5302),
    [anon_sym_case] = ACTIONS(5302),
    [anon_sym_always] = ACTIONS(5302),
    [anon_sym_covergroup] = ACTIONS(5302),
    [anon_sym_let] = ACTIONS(5302),
    [anon_sym_pulldown] = ACTIONS(5302),
    [anon_sym_pullup] = ACTIONS(5302),
    [anon_sym_cmos] = ACTIONS(5302),
    [anon_sym_rcmos] = ACTIONS(5302),
    [anon_sym_bufif0] = ACTIONS(5302),
    [anon_sym_bufif1] = ACTIONS(5302),
    [anon_sym_notif0] = ACTIONS(5302),
    [anon_sym_notif1] = ACTIONS(5302),
    [anon_sym_nmos] = ACTIONS(5302),
    [anon_sym_pmos] = ACTIONS(5302),
    [anon_sym_rnmos] = ACTIONS(5302),
    [anon_sym_rpmos] = ACTIONS(5302),
    [anon_sym_nand] = ACTIONS(5302),
    [anon_sym_nor] = ACTIONS(5302),
    [anon_sym_xor] = ACTIONS(5302),
    [anon_sym_xnor] = ACTIONS(5302),
    [anon_sym_buf] = ACTIONS(5302),
    [anon_sym_tranif0] = ACTIONS(5302),
    [anon_sym_tranif1] = ACTIONS(5302),
    [anon_sym_rtranif1] = ACTIONS(5302),
    [anon_sym_rtranif0] = ACTIONS(5302),
    [anon_sym_tran] = ACTIONS(5302),
    [anon_sym_rtran] = ACTIONS(5302),
    [anon_sym_generate] = ACTIONS(5302),
    [anon_sym_for] = ACTIONS(5302),
    [anon_sym_primitive] = ACTIONS(5302),
    [anon_sym_initial] = ACTIONS(5302),
    [anon_sym_assign] = ACTIONS(5302),
    [anon_sym_alias] = ACTIONS(5302),
    [anon_sym_always_comb] = ACTIONS(5302),
    [anon_sym_always_latch] = ACTIONS(5302),
    [anon_sym_always_ff] = ACTIONS(5302),
    [anon_sym_final] = ACTIONS(5302),
    [anon_sym_global] = ACTIONS(5302),
    [anon_sym_specify] = ACTIONS(5302),
    [anon_sym_LPAREN_STAR] = ACTIONS(5300),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5300),
    [anon_sym_DOLLARunit] = ACTIONS(5300),
  },
  [866] = {
    [ts_builtin_sym_end] = ACTIONS(5304),
    [sym_simple_identifier] = ACTIONS(5306),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5304),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5304),
    [anon_sym_BQUOTE] = ACTIONS(5306),
    [aux_sym_id_directive_token1] = ACTIONS(5304),
    [aux_sym_id_directive_token2] = ACTIONS(5304),
    [aux_sym_id_directive_token3] = ACTIONS(5304),
    [aux_sym_id_directive_token4] = ACTIONS(5306),
    [aux_sym_zero_directive_token1] = ACTIONS(5304),
    [aux_sym_zero_directive_token2] = ACTIONS(5304),
    [aux_sym_zero_directive_token3] = ACTIONS(5304),
    [aux_sym_zero_directive_token4] = ACTIONS(5304),
    [aux_sym_zero_directive_token5] = ACTIONS(5304),
    [aux_sym_zero_directive_token6] = ACTIONS(5304),
    [aux_sym_zero_directive_token7] = ACTIONS(5304),
    [aux_sym_zero_directive_token8] = ACTIONS(5304),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5304),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5304),
    [anon_sym_wire] = ACTIONS(5306),
    [anon_sym_tri] = ACTIONS(5306),
    [anon_sym_tri0] = ACTIONS(5306),
    [anon_sym_tri1] = ACTIONS(5306),
    [anon_sym_wand] = ACTIONS(5306),
    [anon_sym_triand] = ACTIONS(5306),
    [anon_sym_wor] = ACTIONS(5306),
    [anon_sym_trior] = ACTIONS(5306),
    [anon_sym_trireg] = ACTIONS(5306),
    [anon_sym_uwire] = ACTIONS(5306),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5304),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5304),
    [aux_sym_begin_keywords_token1] = ACTIONS(5304),
    [anon_sym_SEMI] = ACTIONS(5304),
    [anon_sym_endmodule] = ACTIONS(5306),
    [anon_sym_extern] = ACTIONS(5306),
    [anon_sym_module] = ACTIONS(5306),
    [anon_sym_macromodule] = ACTIONS(5306),
    [anon_sym_endinterface] = ACTIONS(5306),
    [anon_sym_interface] = ACTIONS(5306),
    [anon_sym_endprogram] = ACTIONS(5306),
    [anon_sym_program] = ACTIONS(5306),
    [anon_sym_checker] = ACTIONS(5306),
    [anon_sym_virtual] = ACTIONS(5306),
    [anon_sym_class] = ACTIONS(5306),
    [anon_sym_package] = ACTIONS(5306),
    [anon_sym_endpackage] = ACTIONS(5306),
    [anon_sym_timeunit] = ACTIONS(5306),
    [anon_sym_timeprecision] = ACTIONS(5306),
    [anon_sym_type] = ACTIONS(5306),
    [anon_sym_input] = ACTIONS(5306),
    [anon_sym_output] = ACTIONS(5306),
    [anon_sym_inout] = ACTIONS(5306),
    [anon_sym_ref] = ACTIONS(5306),
    [anon_sym_DOLLARfatal] = ACTIONS(5304),
    [anon_sym_DOLLARerror] = ACTIONS(5304),
    [anon_sym_DOLLARwarning] = ACTIONS(5304),
    [anon_sym_DOLLARinfo] = ACTIONS(5304),
    [anon_sym_default] = ACTIONS(5306),
    [anon_sym_clocking] = ACTIONS(5306),
    [anon_sym_defparam] = ACTIONS(5306),
    [anon_sym_bind] = ACTIONS(5306),
    [anon_sym_const] = ACTIONS(5306),
    [anon_sym_function] = ACTIONS(5306),
    [anon_sym_static] = ACTIONS(5306),
    [anon_sym_constraint] = ACTIONS(5306),
    [anon_sym_if] = ACTIONS(5306),
    [anon_sym_else] = ACTIONS(5306),
    [anon_sym_LBRACK] = ACTIONS(5304),
    [anon_sym_localparam] = ACTIONS(5306),
    [anon_sym_parameter] = ACTIONS(5306),
    [anon_sym_specparam] = ACTIONS(5306),
    [anon_sym_var] = ACTIONS(5306),
    [anon_sym_import] = ACTIONS(5306),
    [anon_sym_export] = ACTIONS(5306),
    [anon_sym_genvar] = ACTIONS(5306),
    [anon_sym_interconnect] = ACTIONS(5306),
    [anon_sym_typedef] = ACTIONS(5306),
    [anon_sym_enum] = ACTIONS(5306),
    [anon_sym_struct] = ACTIONS(5306),
    [anon_sym_union] = ACTIONS(5306),
    [anon_sym_nettype] = ACTIONS(5306),
    [anon_sym_automatic] = ACTIONS(5306),
    [anon_sym_string] = ACTIONS(5306),
    [anon_sym_chandle] = ACTIONS(5306),
    [anon_sym_event] = ACTIONS(5306),
    [anon_sym_byte] = ACTIONS(5306),
    [anon_sym_shortint] = ACTIONS(5306),
    [anon_sym_int] = ACTIONS(5306),
    [anon_sym_longint] = ACTIONS(5306),
    [anon_sym_integer] = ACTIONS(5306),
    [anon_sym_time] = ACTIONS(5306),
    [anon_sym_bit] = ACTIONS(5306),
    [anon_sym_logic] = ACTIONS(5306),
    [anon_sym_reg] = ACTIONS(5306),
    [anon_sym_shortreal] = ACTIONS(5306),
    [anon_sym_real] = ACTIONS(5306),
    [anon_sym_realtime] = ACTIONS(5306),
    [anon_sym_supply0] = ACTIONS(5306),
    [anon_sym_supply1] = ACTIONS(5306),
    [anon_sym_signed] = ACTIONS(5306),
    [anon_sym_unsigned] = ACTIONS(5306),
    [anon_sym_task] = ACTIONS(5306),
    [anon_sym_modport] = ACTIONS(5306),
    [anon_sym_assert] = ACTIONS(5306),
    [anon_sym_property] = ACTIONS(5306),
    [anon_sym_assume] = ACTIONS(5306),
    [anon_sym_cover] = ACTIONS(5306),
    [anon_sym_sequence] = ACTIONS(5306),
    [anon_sym_restrict] = ACTIONS(5306),
    [anon_sym_not] = ACTIONS(5306),
    [anon_sym_or] = ACTIONS(5306),
    [anon_sym_and] = ACTIONS(5306),
    [anon_sym_case] = ACTIONS(5306),
    [anon_sym_always] = ACTIONS(5306),
    [anon_sym_covergroup] = ACTIONS(5306),
    [anon_sym_let] = ACTIONS(5306),
    [anon_sym_pulldown] = ACTIONS(5306),
    [anon_sym_pullup] = ACTIONS(5306),
    [anon_sym_cmos] = ACTIONS(5306),
    [anon_sym_rcmos] = ACTIONS(5306),
    [anon_sym_bufif0] = ACTIONS(5306),
    [anon_sym_bufif1] = ACTIONS(5306),
    [anon_sym_notif0] = ACTIONS(5306),
    [anon_sym_notif1] = ACTIONS(5306),
    [anon_sym_nmos] = ACTIONS(5306),
    [anon_sym_pmos] = ACTIONS(5306),
    [anon_sym_rnmos] = ACTIONS(5306),
    [anon_sym_rpmos] = ACTIONS(5306),
    [anon_sym_nand] = ACTIONS(5306),
    [anon_sym_nor] = ACTIONS(5306),
    [anon_sym_xor] = ACTIONS(5306),
    [anon_sym_xnor] = ACTIONS(5306),
    [anon_sym_buf] = ACTIONS(5306),
    [anon_sym_tranif0] = ACTIONS(5306),
    [anon_sym_tranif1] = ACTIONS(5306),
    [anon_sym_rtranif1] = ACTIONS(5306),
    [anon_sym_rtranif0] = ACTIONS(5306),
    [anon_sym_tran] = ACTIONS(5306),
    [anon_sym_rtran] = ACTIONS(5306),
    [anon_sym_generate] = ACTIONS(5306),
    [anon_sym_for] = ACTIONS(5306),
    [anon_sym_primitive] = ACTIONS(5306),
    [anon_sym_initial] = ACTIONS(5306),
    [anon_sym_assign] = ACTIONS(5306),
    [anon_sym_alias] = ACTIONS(5306),
    [anon_sym_always_comb] = ACTIONS(5306),
    [anon_sym_always_latch] = ACTIONS(5306),
    [anon_sym_always_ff] = ACTIONS(5306),
    [anon_sym_final] = ACTIONS(5306),
    [anon_sym_global] = ACTIONS(5306),
    [anon_sym_specify] = ACTIONS(5306),
    [anon_sym_LPAREN_STAR] = ACTIONS(5304),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5304),
    [anon_sym_DOLLARunit] = ACTIONS(5304),
  },
  [867] = {
    [ts_builtin_sym_end] = ACTIONS(4510),
    [sym_simple_identifier] = ACTIONS(4512),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4510),
    [anon_sym_BQUOTE] = ACTIONS(4512),
    [aux_sym_id_directive_token1] = ACTIONS(4510),
    [aux_sym_id_directive_token2] = ACTIONS(4510),
    [aux_sym_id_directive_token3] = ACTIONS(4510),
    [aux_sym_id_directive_token4] = ACTIONS(4512),
    [aux_sym_zero_directive_token1] = ACTIONS(4510),
    [aux_sym_zero_directive_token2] = ACTIONS(4510),
    [aux_sym_zero_directive_token3] = ACTIONS(4510),
    [aux_sym_zero_directive_token4] = ACTIONS(4510),
    [aux_sym_zero_directive_token5] = ACTIONS(4510),
    [aux_sym_zero_directive_token6] = ACTIONS(4510),
    [aux_sym_zero_directive_token7] = ACTIONS(4510),
    [aux_sym_zero_directive_token8] = ACTIONS(4510),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4510),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4510),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4510),
    [aux_sym_begin_keywords_token1] = ACTIONS(4510),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_endmodule] = ACTIONS(4512),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_module] = ACTIONS(4512),
    [anon_sym_macromodule] = ACTIONS(4512),
    [anon_sym_endinterface] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_endprogram] = ACTIONS(4512),
    [anon_sym_program] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_package] = ACTIONS(4512),
    [anon_sym_endpackage] = ACTIONS(4512),
    [anon_sym_timeunit] = ACTIONS(4512),
    [anon_sym_timeprecision] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_input] = ACTIONS(4512),
    [anon_sym_output] = ACTIONS(4512),
    [anon_sym_inout] = ACTIONS(4512),
    [anon_sym_ref] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_specparam] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_modport] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_primitive] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_specify] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [868] = {
    [ts_builtin_sym_end] = ACTIONS(5308),
    [sym_simple_identifier] = ACTIONS(5310),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5308),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5308),
    [anon_sym_BQUOTE] = ACTIONS(5310),
    [aux_sym_id_directive_token1] = ACTIONS(5308),
    [aux_sym_id_directive_token2] = ACTIONS(5308),
    [aux_sym_id_directive_token3] = ACTIONS(5308),
    [aux_sym_id_directive_token4] = ACTIONS(5310),
    [aux_sym_zero_directive_token1] = ACTIONS(5308),
    [aux_sym_zero_directive_token2] = ACTIONS(5308),
    [aux_sym_zero_directive_token3] = ACTIONS(5308),
    [aux_sym_zero_directive_token4] = ACTIONS(5308),
    [aux_sym_zero_directive_token5] = ACTIONS(5308),
    [aux_sym_zero_directive_token6] = ACTIONS(5308),
    [aux_sym_zero_directive_token7] = ACTIONS(5308),
    [aux_sym_zero_directive_token8] = ACTIONS(5308),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5308),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5308),
    [anon_sym_wire] = ACTIONS(5310),
    [anon_sym_tri] = ACTIONS(5310),
    [anon_sym_tri0] = ACTIONS(5310),
    [anon_sym_tri1] = ACTIONS(5310),
    [anon_sym_wand] = ACTIONS(5310),
    [anon_sym_triand] = ACTIONS(5310),
    [anon_sym_wor] = ACTIONS(5310),
    [anon_sym_trior] = ACTIONS(5310),
    [anon_sym_trireg] = ACTIONS(5310),
    [anon_sym_uwire] = ACTIONS(5310),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5308),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5308),
    [aux_sym_begin_keywords_token1] = ACTIONS(5308),
    [anon_sym_SEMI] = ACTIONS(5308),
    [anon_sym_endmodule] = ACTIONS(5310),
    [anon_sym_extern] = ACTIONS(5310),
    [anon_sym_module] = ACTIONS(5310),
    [anon_sym_macromodule] = ACTIONS(5310),
    [anon_sym_endinterface] = ACTIONS(5310),
    [anon_sym_interface] = ACTIONS(5310),
    [anon_sym_endprogram] = ACTIONS(5310),
    [anon_sym_program] = ACTIONS(5310),
    [anon_sym_checker] = ACTIONS(5310),
    [anon_sym_virtual] = ACTIONS(5310),
    [anon_sym_class] = ACTIONS(5310),
    [anon_sym_package] = ACTIONS(5310),
    [anon_sym_endpackage] = ACTIONS(5310),
    [anon_sym_timeunit] = ACTIONS(5310),
    [anon_sym_timeprecision] = ACTIONS(5310),
    [anon_sym_type] = ACTIONS(5310),
    [anon_sym_input] = ACTIONS(5310),
    [anon_sym_output] = ACTIONS(5310),
    [anon_sym_inout] = ACTIONS(5310),
    [anon_sym_ref] = ACTIONS(5310),
    [anon_sym_DOLLARfatal] = ACTIONS(5308),
    [anon_sym_DOLLARerror] = ACTIONS(5308),
    [anon_sym_DOLLARwarning] = ACTIONS(5308),
    [anon_sym_DOLLARinfo] = ACTIONS(5308),
    [anon_sym_default] = ACTIONS(5310),
    [anon_sym_clocking] = ACTIONS(5310),
    [anon_sym_defparam] = ACTIONS(5310),
    [anon_sym_bind] = ACTIONS(5310),
    [anon_sym_const] = ACTIONS(5310),
    [anon_sym_function] = ACTIONS(5310),
    [anon_sym_static] = ACTIONS(5310),
    [anon_sym_constraint] = ACTIONS(5310),
    [anon_sym_if] = ACTIONS(5310),
    [anon_sym_else] = ACTIONS(5310),
    [anon_sym_LBRACK] = ACTIONS(5308),
    [anon_sym_localparam] = ACTIONS(5310),
    [anon_sym_parameter] = ACTIONS(5310),
    [anon_sym_specparam] = ACTIONS(5310),
    [anon_sym_var] = ACTIONS(5310),
    [anon_sym_import] = ACTIONS(5310),
    [anon_sym_export] = ACTIONS(5310),
    [anon_sym_genvar] = ACTIONS(5310),
    [anon_sym_interconnect] = ACTIONS(5310),
    [anon_sym_typedef] = ACTIONS(5310),
    [anon_sym_enum] = ACTIONS(5310),
    [anon_sym_struct] = ACTIONS(5310),
    [anon_sym_union] = ACTIONS(5310),
    [anon_sym_nettype] = ACTIONS(5310),
    [anon_sym_automatic] = ACTIONS(5310),
    [anon_sym_string] = ACTIONS(5310),
    [anon_sym_chandle] = ACTIONS(5310),
    [anon_sym_event] = ACTIONS(5310),
    [anon_sym_byte] = ACTIONS(5310),
    [anon_sym_shortint] = ACTIONS(5310),
    [anon_sym_int] = ACTIONS(5310),
    [anon_sym_longint] = ACTIONS(5310),
    [anon_sym_integer] = ACTIONS(5310),
    [anon_sym_time] = ACTIONS(5310),
    [anon_sym_bit] = ACTIONS(5310),
    [anon_sym_logic] = ACTIONS(5310),
    [anon_sym_reg] = ACTIONS(5310),
    [anon_sym_shortreal] = ACTIONS(5310),
    [anon_sym_real] = ACTIONS(5310),
    [anon_sym_realtime] = ACTIONS(5310),
    [anon_sym_supply0] = ACTIONS(5310),
    [anon_sym_supply1] = ACTIONS(5310),
    [anon_sym_signed] = ACTIONS(5310),
    [anon_sym_unsigned] = ACTIONS(5310),
    [anon_sym_task] = ACTIONS(5310),
    [anon_sym_modport] = ACTIONS(5310),
    [anon_sym_assert] = ACTIONS(5310),
    [anon_sym_property] = ACTIONS(5310),
    [anon_sym_assume] = ACTIONS(5310),
    [anon_sym_cover] = ACTIONS(5310),
    [anon_sym_sequence] = ACTIONS(5310),
    [anon_sym_restrict] = ACTIONS(5310),
    [anon_sym_not] = ACTIONS(5310),
    [anon_sym_or] = ACTIONS(5310),
    [anon_sym_and] = ACTIONS(5310),
    [anon_sym_case] = ACTIONS(5310),
    [anon_sym_always] = ACTIONS(5310),
    [anon_sym_covergroup] = ACTIONS(5310),
    [anon_sym_let] = ACTIONS(5310),
    [anon_sym_pulldown] = ACTIONS(5310),
    [anon_sym_pullup] = ACTIONS(5310),
    [anon_sym_cmos] = ACTIONS(5310),
    [anon_sym_rcmos] = ACTIONS(5310),
    [anon_sym_bufif0] = ACTIONS(5310),
    [anon_sym_bufif1] = ACTIONS(5310),
    [anon_sym_notif0] = ACTIONS(5310),
    [anon_sym_notif1] = ACTIONS(5310),
    [anon_sym_nmos] = ACTIONS(5310),
    [anon_sym_pmos] = ACTIONS(5310),
    [anon_sym_rnmos] = ACTIONS(5310),
    [anon_sym_rpmos] = ACTIONS(5310),
    [anon_sym_nand] = ACTIONS(5310),
    [anon_sym_nor] = ACTIONS(5310),
    [anon_sym_xor] = ACTIONS(5310),
    [anon_sym_xnor] = ACTIONS(5310),
    [anon_sym_buf] = ACTIONS(5310),
    [anon_sym_tranif0] = ACTIONS(5310),
    [anon_sym_tranif1] = ACTIONS(5310),
    [anon_sym_rtranif1] = ACTIONS(5310),
    [anon_sym_rtranif0] = ACTIONS(5310),
    [anon_sym_tran] = ACTIONS(5310),
    [anon_sym_rtran] = ACTIONS(5310),
    [anon_sym_generate] = ACTIONS(5310),
    [anon_sym_for] = ACTIONS(5310),
    [anon_sym_primitive] = ACTIONS(5310),
    [anon_sym_initial] = ACTIONS(5310),
    [anon_sym_assign] = ACTIONS(5310),
    [anon_sym_alias] = ACTIONS(5310),
    [anon_sym_always_comb] = ACTIONS(5310),
    [anon_sym_always_latch] = ACTIONS(5310),
    [anon_sym_always_ff] = ACTIONS(5310),
    [anon_sym_final] = ACTIONS(5310),
    [anon_sym_global] = ACTIONS(5310),
    [anon_sym_specify] = ACTIONS(5310),
    [anon_sym_LPAREN_STAR] = ACTIONS(5308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5308),
    [anon_sym_DOLLARunit] = ACTIONS(5308),
  },
  [869] = {
    [ts_builtin_sym_end] = ACTIONS(4240),
    [sym_simple_identifier] = ACTIONS(4242),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4240),
    [anon_sym_BQUOTE] = ACTIONS(4242),
    [aux_sym_id_directive_token1] = ACTIONS(4240),
    [aux_sym_id_directive_token2] = ACTIONS(4240),
    [aux_sym_id_directive_token3] = ACTIONS(4240),
    [aux_sym_id_directive_token4] = ACTIONS(4242),
    [aux_sym_zero_directive_token1] = ACTIONS(4240),
    [aux_sym_zero_directive_token2] = ACTIONS(4240),
    [aux_sym_zero_directive_token3] = ACTIONS(4240),
    [aux_sym_zero_directive_token4] = ACTIONS(4240),
    [aux_sym_zero_directive_token5] = ACTIONS(4240),
    [aux_sym_zero_directive_token6] = ACTIONS(4240),
    [aux_sym_zero_directive_token7] = ACTIONS(4240),
    [aux_sym_zero_directive_token8] = ACTIONS(4240),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4240),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4240),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4240),
    [aux_sym_begin_keywords_token1] = ACTIONS(4240),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_endmodule] = ACTIONS(4242),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_module] = ACTIONS(4242),
    [anon_sym_macromodule] = ACTIONS(4242),
    [anon_sym_endinterface] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_endprogram] = ACTIONS(4242),
    [anon_sym_program] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_package] = ACTIONS(4242),
    [anon_sym_endpackage] = ACTIONS(4242),
    [anon_sym_timeunit] = ACTIONS(4242),
    [anon_sym_timeprecision] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_input] = ACTIONS(4242),
    [anon_sym_output] = ACTIONS(4242),
    [anon_sym_inout] = ACTIONS(4242),
    [anon_sym_ref] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_specparam] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_modport] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_primitive] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_specify] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [870] = {
    [ts_builtin_sym_end] = ACTIONS(4706),
    [sym_simple_identifier] = ACTIONS(4708),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4706),
    [anon_sym_BQUOTE] = ACTIONS(4708),
    [aux_sym_id_directive_token1] = ACTIONS(4706),
    [aux_sym_id_directive_token2] = ACTIONS(4706),
    [aux_sym_id_directive_token3] = ACTIONS(4706),
    [aux_sym_id_directive_token4] = ACTIONS(4708),
    [aux_sym_zero_directive_token1] = ACTIONS(4706),
    [aux_sym_zero_directive_token2] = ACTIONS(4706),
    [aux_sym_zero_directive_token3] = ACTIONS(4706),
    [aux_sym_zero_directive_token4] = ACTIONS(4706),
    [aux_sym_zero_directive_token5] = ACTIONS(4706),
    [aux_sym_zero_directive_token6] = ACTIONS(4706),
    [aux_sym_zero_directive_token7] = ACTIONS(4706),
    [aux_sym_zero_directive_token8] = ACTIONS(4706),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4706),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4706),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4706),
    [aux_sym_begin_keywords_token1] = ACTIONS(4706),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_endmodule] = ACTIONS(4708),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_module] = ACTIONS(4708),
    [anon_sym_macromodule] = ACTIONS(4708),
    [anon_sym_endinterface] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_endprogram] = ACTIONS(4708),
    [anon_sym_program] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_package] = ACTIONS(4708),
    [anon_sym_endpackage] = ACTIONS(4708),
    [anon_sym_timeunit] = ACTIONS(4708),
    [anon_sym_timeprecision] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_input] = ACTIONS(4708),
    [anon_sym_output] = ACTIONS(4708),
    [anon_sym_inout] = ACTIONS(4708),
    [anon_sym_ref] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_specparam] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_modport] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_primitive] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_specify] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [871] = {
    [ts_builtin_sym_end] = ACTIONS(5312),
    [sym_simple_identifier] = ACTIONS(5314),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5312),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5312),
    [anon_sym_BQUOTE] = ACTIONS(5314),
    [aux_sym_id_directive_token1] = ACTIONS(5312),
    [aux_sym_id_directive_token2] = ACTIONS(5312),
    [aux_sym_id_directive_token3] = ACTIONS(5312),
    [aux_sym_id_directive_token4] = ACTIONS(5314),
    [aux_sym_zero_directive_token1] = ACTIONS(5312),
    [aux_sym_zero_directive_token2] = ACTIONS(5312),
    [aux_sym_zero_directive_token3] = ACTIONS(5312),
    [aux_sym_zero_directive_token4] = ACTIONS(5312),
    [aux_sym_zero_directive_token5] = ACTIONS(5312),
    [aux_sym_zero_directive_token6] = ACTIONS(5312),
    [aux_sym_zero_directive_token7] = ACTIONS(5312),
    [aux_sym_zero_directive_token8] = ACTIONS(5312),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5312),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5312),
    [anon_sym_wire] = ACTIONS(5314),
    [anon_sym_tri] = ACTIONS(5314),
    [anon_sym_tri0] = ACTIONS(5314),
    [anon_sym_tri1] = ACTIONS(5314),
    [anon_sym_wand] = ACTIONS(5314),
    [anon_sym_triand] = ACTIONS(5314),
    [anon_sym_wor] = ACTIONS(5314),
    [anon_sym_trior] = ACTIONS(5314),
    [anon_sym_trireg] = ACTIONS(5314),
    [anon_sym_uwire] = ACTIONS(5314),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5312),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5312),
    [aux_sym_begin_keywords_token1] = ACTIONS(5312),
    [anon_sym_SEMI] = ACTIONS(5312),
    [anon_sym_endmodule] = ACTIONS(5314),
    [anon_sym_extern] = ACTIONS(5314),
    [anon_sym_module] = ACTIONS(5314),
    [anon_sym_macromodule] = ACTIONS(5314),
    [anon_sym_endinterface] = ACTIONS(5314),
    [anon_sym_interface] = ACTIONS(5314),
    [anon_sym_endprogram] = ACTIONS(5314),
    [anon_sym_program] = ACTIONS(5314),
    [anon_sym_checker] = ACTIONS(5314),
    [anon_sym_virtual] = ACTIONS(5314),
    [anon_sym_class] = ACTIONS(5314),
    [anon_sym_package] = ACTIONS(5314),
    [anon_sym_endpackage] = ACTIONS(5314),
    [anon_sym_timeunit] = ACTIONS(5314),
    [anon_sym_timeprecision] = ACTIONS(5314),
    [anon_sym_type] = ACTIONS(5314),
    [anon_sym_input] = ACTIONS(5314),
    [anon_sym_output] = ACTIONS(5314),
    [anon_sym_inout] = ACTIONS(5314),
    [anon_sym_ref] = ACTIONS(5314),
    [anon_sym_DOLLARfatal] = ACTIONS(5312),
    [anon_sym_DOLLARerror] = ACTIONS(5312),
    [anon_sym_DOLLARwarning] = ACTIONS(5312),
    [anon_sym_DOLLARinfo] = ACTIONS(5312),
    [anon_sym_default] = ACTIONS(5314),
    [anon_sym_clocking] = ACTIONS(5314),
    [anon_sym_defparam] = ACTIONS(5314),
    [anon_sym_bind] = ACTIONS(5314),
    [anon_sym_const] = ACTIONS(5314),
    [anon_sym_function] = ACTIONS(5314),
    [anon_sym_static] = ACTIONS(5314),
    [anon_sym_constraint] = ACTIONS(5314),
    [anon_sym_if] = ACTIONS(5314),
    [anon_sym_else] = ACTIONS(5314),
    [anon_sym_LBRACK] = ACTIONS(5312),
    [anon_sym_localparam] = ACTIONS(5314),
    [anon_sym_parameter] = ACTIONS(5314),
    [anon_sym_specparam] = ACTIONS(5314),
    [anon_sym_var] = ACTIONS(5314),
    [anon_sym_import] = ACTIONS(5314),
    [anon_sym_export] = ACTIONS(5314),
    [anon_sym_genvar] = ACTIONS(5314),
    [anon_sym_interconnect] = ACTIONS(5314),
    [anon_sym_typedef] = ACTIONS(5314),
    [anon_sym_enum] = ACTIONS(5314),
    [anon_sym_struct] = ACTIONS(5314),
    [anon_sym_union] = ACTIONS(5314),
    [anon_sym_nettype] = ACTIONS(5314),
    [anon_sym_automatic] = ACTIONS(5314),
    [anon_sym_string] = ACTIONS(5314),
    [anon_sym_chandle] = ACTIONS(5314),
    [anon_sym_event] = ACTIONS(5314),
    [anon_sym_byte] = ACTIONS(5314),
    [anon_sym_shortint] = ACTIONS(5314),
    [anon_sym_int] = ACTIONS(5314),
    [anon_sym_longint] = ACTIONS(5314),
    [anon_sym_integer] = ACTIONS(5314),
    [anon_sym_time] = ACTIONS(5314),
    [anon_sym_bit] = ACTIONS(5314),
    [anon_sym_logic] = ACTIONS(5314),
    [anon_sym_reg] = ACTIONS(5314),
    [anon_sym_shortreal] = ACTIONS(5314),
    [anon_sym_real] = ACTIONS(5314),
    [anon_sym_realtime] = ACTIONS(5314),
    [anon_sym_supply0] = ACTIONS(5314),
    [anon_sym_supply1] = ACTIONS(5314),
    [anon_sym_signed] = ACTIONS(5314),
    [anon_sym_unsigned] = ACTIONS(5314),
    [anon_sym_task] = ACTIONS(5314),
    [anon_sym_modport] = ACTIONS(5314),
    [anon_sym_assert] = ACTIONS(5314),
    [anon_sym_property] = ACTIONS(5314),
    [anon_sym_assume] = ACTIONS(5314),
    [anon_sym_cover] = ACTIONS(5314),
    [anon_sym_sequence] = ACTIONS(5314),
    [anon_sym_restrict] = ACTIONS(5314),
    [anon_sym_not] = ACTIONS(5314),
    [anon_sym_or] = ACTIONS(5314),
    [anon_sym_and] = ACTIONS(5314),
    [anon_sym_case] = ACTIONS(5314),
    [anon_sym_always] = ACTIONS(5314),
    [anon_sym_covergroup] = ACTIONS(5314),
    [anon_sym_let] = ACTIONS(5314),
    [anon_sym_pulldown] = ACTIONS(5314),
    [anon_sym_pullup] = ACTIONS(5314),
    [anon_sym_cmos] = ACTIONS(5314),
    [anon_sym_rcmos] = ACTIONS(5314),
    [anon_sym_bufif0] = ACTIONS(5314),
    [anon_sym_bufif1] = ACTIONS(5314),
    [anon_sym_notif0] = ACTIONS(5314),
    [anon_sym_notif1] = ACTIONS(5314),
    [anon_sym_nmos] = ACTIONS(5314),
    [anon_sym_pmos] = ACTIONS(5314),
    [anon_sym_rnmos] = ACTIONS(5314),
    [anon_sym_rpmos] = ACTIONS(5314),
    [anon_sym_nand] = ACTIONS(5314),
    [anon_sym_nor] = ACTIONS(5314),
    [anon_sym_xor] = ACTIONS(5314),
    [anon_sym_xnor] = ACTIONS(5314),
    [anon_sym_buf] = ACTIONS(5314),
    [anon_sym_tranif0] = ACTIONS(5314),
    [anon_sym_tranif1] = ACTIONS(5314),
    [anon_sym_rtranif1] = ACTIONS(5314),
    [anon_sym_rtranif0] = ACTIONS(5314),
    [anon_sym_tran] = ACTIONS(5314),
    [anon_sym_rtran] = ACTIONS(5314),
    [anon_sym_generate] = ACTIONS(5314),
    [anon_sym_for] = ACTIONS(5314),
    [anon_sym_primitive] = ACTIONS(5314),
    [anon_sym_initial] = ACTIONS(5314),
    [anon_sym_assign] = ACTIONS(5314),
    [anon_sym_alias] = ACTIONS(5314),
    [anon_sym_always_comb] = ACTIONS(5314),
    [anon_sym_always_latch] = ACTIONS(5314),
    [anon_sym_always_ff] = ACTIONS(5314),
    [anon_sym_final] = ACTIONS(5314),
    [anon_sym_global] = ACTIONS(5314),
    [anon_sym_specify] = ACTIONS(5314),
    [anon_sym_LPAREN_STAR] = ACTIONS(5312),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5312),
    [anon_sym_DOLLARunit] = ACTIONS(5312),
  },
  [872] = {
    [ts_builtin_sym_end] = ACTIONS(4320),
    [sym_simple_identifier] = ACTIONS(4322),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4320),
    [anon_sym_BQUOTE] = ACTIONS(4322),
    [aux_sym_id_directive_token1] = ACTIONS(4320),
    [aux_sym_id_directive_token2] = ACTIONS(4320),
    [aux_sym_id_directive_token3] = ACTIONS(4320),
    [aux_sym_id_directive_token4] = ACTIONS(4322),
    [aux_sym_zero_directive_token1] = ACTIONS(4320),
    [aux_sym_zero_directive_token2] = ACTIONS(4320),
    [aux_sym_zero_directive_token3] = ACTIONS(4320),
    [aux_sym_zero_directive_token4] = ACTIONS(4320),
    [aux_sym_zero_directive_token5] = ACTIONS(4320),
    [aux_sym_zero_directive_token6] = ACTIONS(4320),
    [aux_sym_zero_directive_token7] = ACTIONS(4320),
    [aux_sym_zero_directive_token8] = ACTIONS(4320),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4320),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4320),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4320),
    [aux_sym_begin_keywords_token1] = ACTIONS(4320),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_endmodule] = ACTIONS(4322),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_module] = ACTIONS(4322),
    [anon_sym_macromodule] = ACTIONS(4322),
    [anon_sym_endinterface] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_endprogram] = ACTIONS(4322),
    [anon_sym_program] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_package] = ACTIONS(4322),
    [anon_sym_endpackage] = ACTIONS(4322),
    [anon_sym_timeunit] = ACTIONS(4322),
    [anon_sym_timeprecision] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_input] = ACTIONS(4322),
    [anon_sym_output] = ACTIONS(4322),
    [anon_sym_inout] = ACTIONS(4322),
    [anon_sym_ref] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_specparam] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_modport] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_primitive] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_specify] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [873] = {
    [ts_builtin_sym_end] = ACTIONS(4362),
    [sym_simple_identifier] = ACTIONS(4364),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4362),
    [anon_sym_BQUOTE] = ACTIONS(4364),
    [aux_sym_id_directive_token1] = ACTIONS(4362),
    [aux_sym_id_directive_token2] = ACTIONS(4362),
    [aux_sym_id_directive_token3] = ACTIONS(4362),
    [aux_sym_id_directive_token4] = ACTIONS(4364),
    [aux_sym_zero_directive_token1] = ACTIONS(4362),
    [aux_sym_zero_directive_token2] = ACTIONS(4362),
    [aux_sym_zero_directive_token3] = ACTIONS(4362),
    [aux_sym_zero_directive_token4] = ACTIONS(4362),
    [aux_sym_zero_directive_token5] = ACTIONS(4362),
    [aux_sym_zero_directive_token6] = ACTIONS(4362),
    [aux_sym_zero_directive_token7] = ACTIONS(4362),
    [aux_sym_zero_directive_token8] = ACTIONS(4362),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4362),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4362),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4362),
    [aux_sym_begin_keywords_token1] = ACTIONS(4362),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_endmodule] = ACTIONS(4364),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_module] = ACTIONS(4364),
    [anon_sym_macromodule] = ACTIONS(4364),
    [anon_sym_endinterface] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_endprogram] = ACTIONS(4364),
    [anon_sym_program] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_package] = ACTIONS(4364),
    [anon_sym_endpackage] = ACTIONS(4364),
    [anon_sym_timeunit] = ACTIONS(4364),
    [anon_sym_timeprecision] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_input] = ACTIONS(4364),
    [anon_sym_output] = ACTIONS(4364),
    [anon_sym_inout] = ACTIONS(4364),
    [anon_sym_ref] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_specparam] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_modport] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_primitive] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_specify] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [874] = {
    [ts_builtin_sym_end] = ACTIONS(5316),
    [sym_simple_identifier] = ACTIONS(5318),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5316),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5316),
    [anon_sym_BQUOTE] = ACTIONS(5318),
    [aux_sym_id_directive_token1] = ACTIONS(5316),
    [aux_sym_id_directive_token2] = ACTIONS(5316),
    [aux_sym_id_directive_token3] = ACTIONS(5316),
    [aux_sym_id_directive_token4] = ACTIONS(5318),
    [aux_sym_zero_directive_token1] = ACTIONS(5316),
    [aux_sym_zero_directive_token2] = ACTIONS(5316),
    [aux_sym_zero_directive_token3] = ACTIONS(5316),
    [aux_sym_zero_directive_token4] = ACTIONS(5316),
    [aux_sym_zero_directive_token5] = ACTIONS(5316),
    [aux_sym_zero_directive_token6] = ACTIONS(5316),
    [aux_sym_zero_directive_token7] = ACTIONS(5316),
    [aux_sym_zero_directive_token8] = ACTIONS(5316),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5316),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5316),
    [anon_sym_wire] = ACTIONS(5318),
    [anon_sym_tri] = ACTIONS(5318),
    [anon_sym_tri0] = ACTIONS(5318),
    [anon_sym_tri1] = ACTIONS(5318),
    [anon_sym_wand] = ACTIONS(5318),
    [anon_sym_triand] = ACTIONS(5318),
    [anon_sym_wor] = ACTIONS(5318),
    [anon_sym_trior] = ACTIONS(5318),
    [anon_sym_trireg] = ACTIONS(5318),
    [anon_sym_uwire] = ACTIONS(5318),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5316),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5316),
    [aux_sym_begin_keywords_token1] = ACTIONS(5316),
    [anon_sym_SEMI] = ACTIONS(5316),
    [anon_sym_endmodule] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym_module] = ACTIONS(5318),
    [anon_sym_macromodule] = ACTIONS(5318),
    [anon_sym_endinterface] = ACTIONS(5318),
    [anon_sym_interface] = ACTIONS(5318),
    [anon_sym_endprogram] = ACTIONS(5318),
    [anon_sym_program] = ACTIONS(5318),
    [anon_sym_checker] = ACTIONS(5318),
    [anon_sym_virtual] = ACTIONS(5318),
    [anon_sym_class] = ACTIONS(5318),
    [anon_sym_package] = ACTIONS(5318),
    [anon_sym_endpackage] = ACTIONS(5318),
    [anon_sym_timeunit] = ACTIONS(5318),
    [anon_sym_timeprecision] = ACTIONS(5318),
    [anon_sym_type] = ACTIONS(5318),
    [anon_sym_input] = ACTIONS(5318),
    [anon_sym_output] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_ref] = ACTIONS(5318),
    [anon_sym_DOLLARfatal] = ACTIONS(5316),
    [anon_sym_DOLLARerror] = ACTIONS(5316),
    [anon_sym_DOLLARwarning] = ACTIONS(5316),
    [anon_sym_DOLLARinfo] = ACTIONS(5316),
    [anon_sym_default] = ACTIONS(5318),
    [anon_sym_clocking] = ACTIONS(5318),
    [anon_sym_defparam] = ACTIONS(5318),
    [anon_sym_bind] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_function] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_constraint] = ACTIONS(5318),
    [anon_sym_if] = ACTIONS(5318),
    [anon_sym_else] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5316),
    [anon_sym_localparam] = ACTIONS(5318),
    [anon_sym_parameter] = ACTIONS(5318),
    [anon_sym_specparam] = ACTIONS(5318),
    [anon_sym_var] = ACTIONS(5318),
    [anon_sym_import] = ACTIONS(5318),
    [anon_sym_export] = ACTIONS(5318),
    [anon_sym_genvar] = ACTIONS(5318),
    [anon_sym_interconnect] = ACTIONS(5318),
    [anon_sym_typedef] = ACTIONS(5318),
    [anon_sym_enum] = ACTIONS(5318),
    [anon_sym_struct] = ACTIONS(5318),
    [anon_sym_union] = ACTIONS(5318),
    [anon_sym_nettype] = ACTIONS(5318),
    [anon_sym_automatic] = ACTIONS(5318),
    [anon_sym_string] = ACTIONS(5318),
    [anon_sym_chandle] = ACTIONS(5318),
    [anon_sym_event] = ACTIONS(5318),
    [anon_sym_byte] = ACTIONS(5318),
    [anon_sym_shortint] = ACTIONS(5318),
    [anon_sym_int] = ACTIONS(5318),
    [anon_sym_longint] = ACTIONS(5318),
    [anon_sym_integer] = ACTIONS(5318),
    [anon_sym_time] = ACTIONS(5318),
    [anon_sym_bit] = ACTIONS(5318),
    [anon_sym_logic] = ACTIONS(5318),
    [anon_sym_reg] = ACTIONS(5318),
    [anon_sym_shortreal] = ACTIONS(5318),
    [anon_sym_real] = ACTIONS(5318),
    [anon_sym_realtime] = ACTIONS(5318),
    [anon_sym_supply0] = ACTIONS(5318),
    [anon_sym_supply1] = ACTIONS(5318),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_task] = ACTIONS(5318),
    [anon_sym_modport] = ACTIONS(5318),
    [anon_sym_assert] = ACTIONS(5318),
    [anon_sym_property] = ACTIONS(5318),
    [anon_sym_assume] = ACTIONS(5318),
    [anon_sym_cover] = ACTIONS(5318),
    [anon_sym_sequence] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym_not] = ACTIONS(5318),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_case] = ACTIONS(5318),
    [anon_sym_always] = ACTIONS(5318),
    [anon_sym_covergroup] = ACTIONS(5318),
    [anon_sym_let] = ACTIONS(5318),
    [anon_sym_pulldown] = ACTIONS(5318),
    [anon_sym_pullup] = ACTIONS(5318),
    [anon_sym_cmos] = ACTIONS(5318),
    [anon_sym_rcmos] = ACTIONS(5318),
    [anon_sym_bufif0] = ACTIONS(5318),
    [anon_sym_bufif1] = ACTIONS(5318),
    [anon_sym_notif0] = ACTIONS(5318),
    [anon_sym_notif1] = ACTIONS(5318),
    [anon_sym_nmos] = ACTIONS(5318),
    [anon_sym_pmos] = ACTIONS(5318),
    [anon_sym_rnmos] = ACTIONS(5318),
    [anon_sym_rpmos] = ACTIONS(5318),
    [anon_sym_nand] = ACTIONS(5318),
    [anon_sym_nor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_xnor] = ACTIONS(5318),
    [anon_sym_buf] = ACTIONS(5318),
    [anon_sym_tranif0] = ACTIONS(5318),
    [anon_sym_tranif1] = ACTIONS(5318),
    [anon_sym_rtranif1] = ACTIONS(5318),
    [anon_sym_rtranif0] = ACTIONS(5318),
    [anon_sym_tran] = ACTIONS(5318),
    [anon_sym_rtran] = ACTIONS(5318),
    [anon_sym_generate] = ACTIONS(5318),
    [anon_sym_for] = ACTIONS(5318),
    [anon_sym_primitive] = ACTIONS(5318),
    [anon_sym_initial] = ACTIONS(5318),
    [anon_sym_assign] = ACTIONS(5318),
    [anon_sym_alias] = ACTIONS(5318),
    [anon_sym_always_comb] = ACTIONS(5318),
    [anon_sym_always_latch] = ACTIONS(5318),
    [anon_sym_always_ff] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_global] = ACTIONS(5318),
    [anon_sym_specify] = ACTIONS(5318),
    [anon_sym_LPAREN_STAR] = ACTIONS(5316),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5316),
    [anon_sym_DOLLARunit] = ACTIONS(5316),
  },
  [875] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18378),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18378),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7364),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [876] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18392),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18392),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5322),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [877] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18378),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18378),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5324),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [878] = {
    [ts_builtin_sym_end] = ACTIONS(5326),
    [sym_simple_identifier] = ACTIONS(5328),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5326),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5326),
    [anon_sym_BQUOTE] = ACTIONS(5328),
    [aux_sym_id_directive_token1] = ACTIONS(5326),
    [aux_sym_id_directive_token2] = ACTIONS(5326),
    [aux_sym_id_directive_token3] = ACTIONS(5326),
    [aux_sym_id_directive_token4] = ACTIONS(5328),
    [aux_sym_zero_directive_token1] = ACTIONS(5326),
    [aux_sym_zero_directive_token2] = ACTIONS(5326),
    [aux_sym_zero_directive_token3] = ACTIONS(5326),
    [aux_sym_zero_directive_token4] = ACTIONS(5326),
    [aux_sym_zero_directive_token5] = ACTIONS(5326),
    [aux_sym_zero_directive_token6] = ACTIONS(5326),
    [aux_sym_zero_directive_token7] = ACTIONS(5326),
    [aux_sym_zero_directive_token8] = ACTIONS(5326),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5326),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5326),
    [anon_sym_wire] = ACTIONS(5328),
    [anon_sym_tri] = ACTIONS(5328),
    [anon_sym_tri0] = ACTIONS(5328),
    [anon_sym_tri1] = ACTIONS(5328),
    [anon_sym_wand] = ACTIONS(5328),
    [anon_sym_triand] = ACTIONS(5328),
    [anon_sym_wor] = ACTIONS(5328),
    [anon_sym_trior] = ACTIONS(5328),
    [anon_sym_trireg] = ACTIONS(5328),
    [anon_sym_uwire] = ACTIONS(5328),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5326),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5326),
    [aux_sym_begin_keywords_token1] = ACTIONS(5326),
    [anon_sym_SEMI] = ACTIONS(5326),
    [anon_sym_endmodule] = ACTIONS(5328),
    [anon_sym_extern] = ACTIONS(5328),
    [anon_sym_module] = ACTIONS(5328),
    [anon_sym_macromodule] = ACTIONS(5328),
    [anon_sym_endinterface] = ACTIONS(5328),
    [anon_sym_interface] = ACTIONS(5328),
    [anon_sym_endprogram] = ACTIONS(5328),
    [anon_sym_program] = ACTIONS(5328),
    [anon_sym_checker] = ACTIONS(5328),
    [anon_sym_virtual] = ACTIONS(5328),
    [anon_sym_class] = ACTIONS(5328),
    [anon_sym_package] = ACTIONS(5328),
    [anon_sym_endpackage] = ACTIONS(5328),
    [anon_sym_timeunit] = ACTIONS(5328),
    [anon_sym_timeprecision] = ACTIONS(5328),
    [anon_sym_type] = ACTIONS(5328),
    [anon_sym_input] = ACTIONS(5328),
    [anon_sym_output] = ACTIONS(5328),
    [anon_sym_inout] = ACTIONS(5328),
    [anon_sym_ref] = ACTIONS(5328),
    [anon_sym_DOLLARfatal] = ACTIONS(5326),
    [anon_sym_DOLLARerror] = ACTIONS(5326),
    [anon_sym_DOLLARwarning] = ACTIONS(5326),
    [anon_sym_DOLLARinfo] = ACTIONS(5326),
    [anon_sym_default] = ACTIONS(5328),
    [anon_sym_clocking] = ACTIONS(5328),
    [anon_sym_defparam] = ACTIONS(5328),
    [anon_sym_bind] = ACTIONS(5328),
    [anon_sym_const] = ACTIONS(5328),
    [anon_sym_function] = ACTIONS(5328),
    [anon_sym_static] = ACTIONS(5328),
    [anon_sym_constraint] = ACTIONS(5328),
    [anon_sym_if] = ACTIONS(5328),
    [anon_sym_else] = ACTIONS(5328),
    [anon_sym_LBRACK] = ACTIONS(5326),
    [anon_sym_localparam] = ACTIONS(5328),
    [anon_sym_parameter] = ACTIONS(5328),
    [anon_sym_specparam] = ACTIONS(5328),
    [anon_sym_var] = ACTIONS(5328),
    [anon_sym_import] = ACTIONS(5328),
    [anon_sym_export] = ACTIONS(5328),
    [anon_sym_genvar] = ACTIONS(5328),
    [anon_sym_interconnect] = ACTIONS(5328),
    [anon_sym_typedef] = ACTIONS(5328),
    [anon_sym_enum] = ACTIONS(5328),
    [anon_sym_struct] = ACTIONS(5328),
    [anon_sym_union] = ACTIONS(5328),
    [anon_sym_nettype] = ACTIONS(5328),
    [anon_sym_automatic] = ACTIONS(5328),
    [anon_sym_string] = ACTIONS(5328),
    [anon_sym_chandle] = ACTIONS(5328),
    [anon_sym_event] = ACTIONS(5328),
    [anon_sym_byte] = ACTIONS(5328),
    [anon_sym_shortint] = ACTIONS(5328),
    [anon_sym_int] = ACTIONS(5328),
    [anon_sym_longint] = ACTIONS(5328),
    [anon_sym_integer] = ACTIONS(5328),
    [anon_sym_time] = ACTIONS(5328),
    [anon_sym_bit] = ACTIONS(5328),
    [anon_sym_logic] = ACTIONS(5328),
    [anon_sym_reg] = ACTIONS(5328),
    [anon_sym_shortreal] = ACTIONS(5328),
    [anon_sym_real] = ACTIONS(5328),
    [anon_sym_realtime] = ACTIONS(5328),
    [anon_sym_supply0] = ACTIONS(5328),
    [anon_sym_supply1] = ACTIONS(5328),
    [anon_sym_signed] = ACTIONS(5328),
    [anon_sym_unsigned] = ACTIONS(5328),
    [anon_sym_task] = ACTIONS(5328),
    [anon_sym_modport] = ACTIONS(5328),
    [anon_sym_assert] = ACTIONS(5328),
    [anon_sym_property] = ACTIONS(5328),
    [anon_sym_assume] = ACTIONS(5328),
    [anon_sym_cover] = ACTIONS(5328),
    [anon_sym_sequence] = ACTIONS(5328),
    [anon_sym_restrict] = ACTIONS(5328),
    [anon_sym_not] = ACTIONS(5328),
    [anon_sym_or] = ACTIONS(5328),
    [anon_sym_and] = ACTIONS(5328),
    [anon_sym_case] = ACTIONS(5328),
    [anon_sym_always] = ACTIONS(5328),
    [anon_sym_covergroup] = ACTIONS(5328),
    [anon_sym_let] = ACTIONS(5328),
    [anon_sym_pulldown] = ACTIONS(5328),
    [anon_sym_pullup] = ACTIONS(5328),
    [anon_sym_cmos] = ACTIONS(5328),
    [anon_sym_rcmos] = ACTIONS(5328),
    [anon_sym_bufif0] = ACTIONS(5328),
    [anon_sym_bufif1] = ACTIONS(5328),
    [anon_sym_notif0] = ACTIONS(5328),
    [anon_sym_notif1] = ACTIONS(5328),
    [anon_sym_nmos] = ACTIONS(5328),
    [anon_sym_pmos] = ACTIONS(5328),
    [anon_sym_rnmos] = ACTIONS(5328),
    [anon_sym_rpmos] = ACTIONS(5328),
    [anon_sym_nand] = ACTIONS(5328),
    [anon_sym_nor] = ACTIONS(5328),
    [anon_sym_xor] = ACTIONS(5328),
    [anon_sym_xnor] = ACTIONS(5328),
    [anon_sym_buf] = ACTIONS(5328),
    [anon_sym_tranif0] = ACTIONS(5328),
    [anon_sym_tranif1] = ACTIONS(5328),
    [anon_sym_rtranif1] = ACTIONS(5328),
    [anon_sym_rtranif0] = ACTIONS(5328),
    [anon_sym_tran] = ACTIONS(5328),
    [anon_sym_rtran] = ACTIONS(5328),
    [anon_sym_generate] = ACTIONS(5328),
    [anon_sym_for] = ACTIONS(5328),
    [anon_sym_primitive] = ACTIONS(5328),
    [anon_sym_initial] = ACTIONS(5328),
    [anon_sym_assign] = ACTIONS(5328),
    [anon_sym_alias] = ACTIONS(5328),
    [anon_sym_always_comb] = ACTIONS(5328),
    [anon_sym_always_latch] = ACTIONS(5328),
    [anon_sym_always_ff] = ACTIONS(5328),
    [anon_sym_final] = ACTIONS(5328),
    [anon_sym_global] = ACTIONS(5328),
    [anon_sym_specify] = ACTIONS(5328),
    [anon_sym_LPAREN_STAR] = ACTIONS(5326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5326),
    [anon_sym_DOLLARunit] = ACTIONS(5326),
  },
  [879] = {
    [ts_builtin_sym_end] = ACTIONS(5330),
    [sym_simple_identifier] = ACTIONS(5332),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5330),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5330),
    [anon_sym_BQUOTE] = ACTIONS(5332),
    [aux_sym_id_directive_token1] = ACTIONS(5330),
    [aux_sym_id_directive_token2] = ACTIONS(5330),
    [aux_sym_id_directive_token3] = ACTIONS(5330),
    [aux_sym_id_directive_token4] = ACTIONS(5332),
    [aux_sym_zero_directive_token1] = ACTIONS(5330),
    [aux_sym_zero_directive_token2] = ACTIONS(5330),
    [aux_sym_zero_directive_token3] = ACTIONS(5330),
    [aux_sym_zero_directive_token4] = ACTIONS(5330),
    [aux_sym_zero_directive_token5] = ACTIONS(5330),
    [aux_sym_zero_directive_token6] = ACTIONS(5330),
    [aux_sym_zero_directive_token7] = ACTIONS(5330),
    [aux_sym_zero_directive_token8] = ACTIONS(5330),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5330),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5330),
    [anon_sym_wire] = ACTIONS(5332),
    [anon_sym_tri] = ACTIONS(5332),
    [anon_sym_tri0] = ACTIONS(5332),
    [anon_sym_tri1] = ACTIONS(5332),
    [anon_sym_wand] = ACTIONS(5332),
    [anon_sym_triand] = ACTIONS(5332),
    [anon_sym_wor] = ACTIONS(5332),
    [anon_sym_trior] = ACTIONS(5332),
    [anon_sym_trireg] = ACTIONS(5332),
    [anon_sym_uwire] = ACTIONS(5332),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5330),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5330),
    [aux_sym_begin_keywords_token1] = ACTIONS(5330),
    [anon_sym_SEMI] = ACTIONS(5330),
    [anon_sym_endmodule] = ACTIONS(5332),
    [anon_sym_extern] = ACTIONS(5332),
    [anon_sym_module] = ACTIONS(5332),
    [anon_sym_macromodule] = ACTIONS(5332),
    [anon_sym_endinterface] = ACTIONS(5332),
    [anon_sym_interface] = ACTIONS(5332),
    [anon_sym_endprogram] = ACTIONS(5332),
    [anon_sym_program] = ACTIONS(5332),
    [anon_sym_checker] = ACTIONS(5332),
    [anon_sym_virtual] = ACTIONS(5332),
    [anon_sym_class] = ACTIONS(5332),
    [anon_sym_package] = ACTIONS(5332),
    [anon_sym_endpackage] = ACTIONS(5332),
    [anon_sym_timeunit] = ACTIONS(5332),
    [anon_sym_timeprecision] = ACTIONS(5332),
    [anon_sym_type] = ACTIONS(5332),
    [anon_sym_input] = ACTIONS(5332),
    [anon_sym_output] = ACTIONS(5332),
    [anon_sym_inout] = ACTIONS(5332),
    [anon_sym_ref] = ACTIONS(5332),
    [anon_sym_DOLLARfatal] = ACTIONS(5330),
    [anon_sym_DOLLARerror] = ACTIONS(5330),
    [anon_sym_DOLLARwarning] = ACTIONS(5330),
    [anon_sym_DOLLARinfo] = ACTIONS(5330),
    [anon_sym_default] = ACTIONS(5332),
    [anon_sym_clocking] = ACTIONS(5332),
    [anon_sym_defparam] = ACTIONS(5332),
    [anon_sym_bind] = ACTIONS(5332),
    [anon_sym_const] = ACTIONS(5332),
    [anon_sym_function] = ACTIONS(5332),
    [anon_sym_static] = ACTIONS(5332),
    [anon_sym_constraint] = ACTIONS(5332),
    [anon_sym_if] = ACTIONS(5332),
    [anon_sym_else] = ACTIONS(5332),
    [anon_sym_LBRACK] = ACTIONS(5330),
    [anon_sym_localparam] = ACTIONS(5332),
    [anon_sym_parameter] = ACTIONS(5332),
    [anon_sym_specparam] = ACTIONS(5332),
    [anon_sym_var] = ACTIONS(5332),
    [anon_sym_import] = ACTIONS(5332),
    [anon_sym_export] = ACTIONS(5332),
    [anon_sym_genvar] = ACTIONS(5332),
    [anon_sym_interconnect] = ACTIONS(5332),
    [anon_sym_typedef] = ACTIONS(5332),
    [anon_sym_enum] = ACTIONS(5332),
    [anon_sym_struct] = ACTIONS(5332),
    [anon_sym_union] = ACTIONS(5332),
    [anon_sym_nettype] = ACTIONS(5332),
    [anon_sym_automatic] = ACTIONS(5332),
    [anon_sym_string] = ACTIONS(5332),
    [anon_sym_chandle] = ACTIONS(5332),
    [anon_sym_event] = ACTIONS(5332),
    [anon_sym_byte] = ACTIONS(5332),
    [anon_sym_shortint] = ACTIONS(5332),
    [anon_sym_int] = ACTIONS(5332),
    [anon_sym_longint] = ACTIONS(5332),
    [anon_sym_integer] = ACTIONS(5332),
    [anon_sym_time] = ACTIONS(5332),
    [anon_sym_bit] = ACTIONS(5332),
    [anon_sym_logic] = ACTIONS(5332),
    [anon_sym_reg] = ACTIONS(5332),
    [anon_sym_shortreal] = ACTIONS(5332),
    [anon_sym_real] = ACTIONS(5332),
    [anon_sym_realtime] = ACTIONS(5332),
    [anon_sym_supply0] = ACTIONS(5332),
    [anon_sym_supply1] = ACTIONS(5332),
    [anon_sym_signed] = ACTIONS(5332),
    [anon_sym_unsigned] = ACTIONS(5332),
    [anon_sym_task] = ACTIONS(5332),
    [anon_sym_modport] = ACTIONS(5332),
    [anon_sym_assert] = ACTIONS(5332),
    [anon_sym_property] = ACTIONS(5332),
    [anon_sym_assume] = ACTIONS(5332),
    [anon_sym_cover] = ACTIONS(5332),
    [anon_sym_sequence] = ACTIONS(5332),
    [anon_sym_restrict] = ACTIONS(5332),
    [anon_sym_not] = ACTIONS(5332),
    [anon_sym_or] = ACTIONS(5332),
    [anon_sym_and] = ACTIONS(5332),
    [anon_sym_case] = ACTIONS(5332),
    [anon_sym_always] = ACTIONS(5332),
    [anon_sym_covergroup] = ACTIONS(5332),
    [anon_sym_let] = ACTIONS(5332),
    [anon_sym_pulldown] = ACTIONS(5332),
    [anon_sym_pullup] = ACTIONS(5332),
    [anon_sym_cmos] = ACTIONS(5332),
    [anon_sym_rcmos] = ACTIONS(5332),
    [anon_sym_bufif0] = ACTIONS(5332),
    [anon_sym_bufif1] = ACTIONS(5332),
    [anon_sym_notif0] = ACTIONS(5332),
    [anon_sym_notif1] = ACTIONS(5332),
    [anon_sym_nmos] = ACTIONS(5332),
    [anon_sym_pmos] = ACTIONS(5332),
    [anon_sym_rnmos] = ACTIONS(5332),
    [anon_sym_rpmos] = ACTIONS(5332),
    [anon_sym_nand] = ACTIONS(5332),
    [anon_sym_nor] = ACTIONS(5332),
    [anon_sym_xor] = ACTIONS(5332),
    [anon_sym_xnor] = ACTIONS(5332),
    [anon_sym_buf] = ACTIONS(5332),
    [anon_sym_tranif0] = ACTIONS(5332),
    [anon_sym_tranif1] = ACTIONS(5332),
    [anon_sym_rtranif1] = ACTIONS(5332),
    [anon_sym_rtranif0] = ACTIONS(5332),
    [anon_sym_tran] = ACTIONS(5332),
    [anon_sym_rtran] = ACTIONS(5332),
    [anon_sym_generate] = ACTIONS(5332),
    [anon_sym_for] = ACTIONS(5332),
    [anon_sym_primitive] = ACTIONS(5332),
    [anon_sym_initial] = ACTIONS(5332),
    [anon_sym_assign] = ACTIONS(5332),
    [anon_sym_alias] = ACTIONS(5332),
    [anon_sym_always_comb] = ACTIONS(5332),
    [anon_sym_always_latch] = ACTIONS(5332),
    [anon_sym_always_ff] = ACTIONS(5332),
    [anon_sym_final] = ACTIONS(5332),
    [anon_sym_global] = ACTIONS(5332),
    [anon_sym_specify] = ACTIONS(5332),
    [anon_sym_LPAREN_STAR] = ACTIONS(5330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5330),
    [anon_sym_DOLLARunit] = ACTIONS(5330),
  },
  [880] = {
    [ts_builtin_sym_end] = ACTIONS(5334),
    [sym_simple_identifier] = ACTIONS(5336),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5334),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5334),
    [anon_sym_BQUOTE] = ACTIONS(5336),
    [aux_sym_id_directive_token1] = ACTIONS(5334),
    [aux_sym_id_directive_token2] = ACTIONS(5334),
    [aux_sym_id_directive_token3] = ACTIONS(5334),
    [aux_sym_id_directive_token4] = ACTIONS(5336),
    [aux_sym_zero_directive_token1] = ACTIONS(5334),
    [aux_sym_zero_directive_token2] = ACTIONS(5334),
    [aux_sym_zero_directive_token3] = ACTIONS(5334),
    [aux_sym_zero_directive_token4] = ACTIONS(5334),
    [aux_sym_zero_directive_token5] = ACTIONS(5334),
    [aux_sym_zero_directive_token6] = ACTIONS(5334),
    [aux_sym_zero_directive_token7] = ACTIONS(5334),
    [aux_sym_zero_directive_token8] = ACTIONS(5334),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5334),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5334),
    [anon_sym_wire] = ACTIONS(5336),
    [anon_sym_tri] = ACTIONS(5336),
    [anon_sym_tri0] = ACTIONS(5336),
    [anon_sym_tri1] = ACTIONS(5336),
    [anon_sym_wand] = ACTIONS(5336),
    [anon_sym_triand] = ACTIONS(5336),
    [anon_sym_wor] = ACTIONS(5336),
    [anon_sym_trior] = ACTIONS(5336),
    [anon_sym_trireg] = ACTIONS(5336),
    [anon_sym_uwire] = ACTIONS(5336),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5334),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5334),
    [aux_sym_begin_keywords_token1] = ACTIONS(5334),
    [anon_sym_SEMI] = ACTIONS(5334),
    [anon_sym_endmodule] = ACTIONS(5336),
    [anon_sym_extern] = ACTIONS(5336),
    [anon_sym_module] = ACTIONS(5336),
    [anon_sym_macromodule] = ACTIONS(5336),
    [anon_sym_endinterface] = ACTIONS(5336),
    [anon_sym_interface] = ACTIONS(5336),
    [anon_sym_endprogram] = ACTIONS(5336),
    [anon_sym_program] = ACTIONS(5336),
    [anon_sym_checker] = ACTIONS(5336),
    [anon_sym_virtual] = ACTIONS(5336),
    [anon_sym_class] = ACTIONS(5336),
    [anon_sym_package] = ACTIONS(5336),
    [anon_sym_endpackage] = ACTIONS(5336),
    [anon_sym_timeunit] = ACTIONS(5336),
    [anon_sym_timeprecision] = ACTIONS(5336),
    [anon_sym_type] = ACTIONS(5336),
    [anon_sym_input] = ACTIONS(5336),
    [anon_sym_output] = ACTIONS(5336),
    [anon_sym_inout] = ACTIONS(5336),
    [anon_sym_ref] = ACTIONS(5336),
    [anon_sym_DOLLARfatal] = ACTIONS(5334),
    [anon_sym_DOLLARerror] = ACTIONS(5334),
    [anon_sym_DOLLARwarning] = ACTIONS(5334),
    [anon_sym_DOLLARinfo] = ACTIONS(5334),
    [anon_sym_default] = ACTIONS(5336),
    [anon_sym_clocking] = ACTIONS(5336),
    [anon_sym_defparam] = ACTIONS(5336),
    [anon_sym_bind] = ACTIONS(5336),
    [anon_sym_const] = ACTIONS(5336),
    [anon_sym_function] = ACTIONS(5336),
    [anon_sym_static] = ACTIONS(5336),
    [anon_sym_constraint] = ACTIONS(5336),
    [anon_sym_if] = ACTIONS(5336),
    [anon_sym_else] = ACTIONS(5336),
    [anon_sym_LBRACK] = ACTIONS(5334),
    [anon_sym_localparam] = ACTIONS(5336),
    [anon_sym_parameter] = ACTIONS(5336),
    [anon_sym_specparam] = ACTIONS(5336),
    [anon_sym_var] = ACTIONS(5336),
    [anon_sym_import] = ACTIONS(5336),
    [anon_sym_export] = ACTIONS(5336),
    [anon_sym_genvar] = ACTIONS(5336),
    [anon_sym_interconnect] = ACTIONS(5336),
    [anon_sym_typedef] = ACTIONS(5336),
    [anon_sym_enum] = ACTIONS(5336),
    [anon_sym_struct] = ACTIONS(5336),
    [anon_sym_union] = ACTIONS(5336),
    [anon_sym_nettype] = ACTIONS(5336),
    [anon_sym_automatic] = ACTIONS(5336),
    [anon_sym_string] = ACTIONS(5336),
    [anon_sym_chandle] = ACTIONS(5336),
    [anon_sym_event] = ACTIONS(5336),
    [anon_sym_byte] = ACTIONS(5336),
    [anon_sym_shortint] = ACTIONS(5336),
    [anon_sym_int] = ACTIONS(5336),
    [anon_sym_longint] = ACTIONS(5336),
    [anon_sym_integer] = ACTIONS(5336),
    [anon_sym_time] = ACTIONS(5336),
    [anon_sym_bit] = ACTIONS(5336),
    [anon_sym_logic] = ACTIONS(5336),
    [anon_sym_reg] = ACTIONS(5336),
    [anon_sym_shortreal] = ACTIONS(5336),
    [anon_sym_real] = ACTIONS(5336),
    [anon_sym_realtime] = ACTIONS(5336),
    [anon_sym_supply0] = ACTIONS(5336),
    [anon_sym_supply1] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(5336),
    [anon_sym_unsigned] = ACTIONS(5336),
    [anon_sym_task] = ACTIONS(5336),
    [anon_sym_modport] = ACTIONS(5336),
    [anon_sym_assert] = ACTIONS(5336),
    [anon_sym_property] = ACTIONS(5336),
    [anon_sym_assume] = ACTIONS(5336),
    [anon_sym_cover] = ACTIONS(5336),
    [anon_sym_sequence] = ACTIONS(5336),
    [anon_sym_restrict] = ACTIONS(5336),
    [anon_sym_not] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5336),
    [anon_sym_and] = ACTIONS(5336),
    [anon_sym_case] = ACTIONS(5336),
    [anon_sym_always] = ACTIONS(5336),
    [anon_sym_covergroup] = ACTIONS(5336),
    [anon_sym_let] = ACTIONS(5336),
    [anon_sym_pulldown] = ACTIONS(5336),
    [anon_sym_pullup] = ACTIONS(5336),
    [anon_sym_cmos] = ACTIONS(5336),
    [anon_sym_rcmos] = ACTIONS(5336),
    [anon_sym_bufif0] = ACTIONS(5336),
    [anon_sym_bufif1] = ACTIONS(5336),
    [anon_sym_notif0] = ACTIONS(5336),
    [anon_sym_notif1] = ACTIONS(5336),
    [anon_sym_nmos] = ACTIONS(5336),
    [anon_sym_pmos] = ACTIONS(5336),
    [anon_sym_rnmos] = ACTIONS(5336),
    [anon_sym_rpmos] = ACTIONS(5336),
    [anon_sym_nand] = ACTIONS(5336),
    [anon_sym_nor] = ACTIONS(5336),
    [anon_sym_xor] = ACTIONS(5336),
    [anon_sym_xnor] = ACTIONS(5336),
    [anon_sym_buf] = ACTIONS(5336),
    [anon_sym_tranif0] = ACTIONS(5336),
    [anon_sym_tranif1] = ACTIONS(5336),
    [anon_sym_rtranif1] = ACTIONS(5336),
    [anon_sym_rtranif0] = ACTIONS(5336),
    [anon_sym_tran] = ACTIONS(5336),
    [anon_sym_rtran] = ACTIONS(5336),
    [anon_sym_generate] = ACTIONS(5336),
    [anon_sym_for] = ACTIONS(5336),
    [anon_sym_primitive] = ACTIONS(5336),
    [anon_sym_initial] = ACTIONS(5336),
    [anon_sym_assign] = ACTIONS(5336),
    [anon_sym_alias] = ACTIONS(5336),
    [anon_sym_always_comb] = ACTIONS(5336),
    [anon_sym_always_latch] = ACTIONS(5336),
    [anon_sym_always_ff] = ACTIONS(5336),
    [anon_sym_final] = ACTIONS(5336),
    [anon_sym_global] = ACTIONS(5336),
    [anon_sym_specify] = ACTIONS(5336),
    [anon_sym_LPAREN_STAR] = ACTIONS(5334),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5334),
    [anon_sym_DOLLARunit] = ACTIONS(5334),
  },
  [881] = {
    [ts_builtin_sym_end] = ACTIONS(5338),
    [sym_simple_identifier] = ACTIONS(5340),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5338),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5338),
    [anon_sym_BQUOTE] = ACTIONS(5340),
    [aux_sym_id_directive_token1] = ACTIONS(5338),
    [aux_sym_id_directive_token2] = ACTIONS(5338),
    [aux_sym_id_directive_token3] = ACTIONS(5338),
    [aux_sym_id_directive_token4] = ACTIONS(5340),
    [aux_sym_zero_directive_token1] = ACTIONS(5338),
    [aux_sym_zero_directive_token2] = ACTIONS(5338),
    [aux_sym_zero_directive_token3] = ACTIONS(5338),
    [aux_sym_zero_directive_token4] = ACTIONS(5338),
    [aux_sym_zero_directive_token5] = ACTIONS(5338),
    [aux_sym_zero_directive_token6] = ACTIONS(5338),
    [aux_sym_zero_directive_token7] = ACTIONS(5338),
    [aux_sym_zero_directive_token8] = ACTIONS(5338),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5338),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5338),
    [anon_sym_wire] = ACTIONS(5340),
    [anon_sym_tri] = ACTIONS(5340),
    [anon_sym_tri0] = ACTIONS(5340),
    [anon_sym_tri1] = ACTIONS(5340),
    [anon_sym_wand] = ACTIONS(5340),
    [anon_sym_triand] = ACTIONS(5340),
    [anon_sym_wor] = ACTIONS(5340),
    [anon_sym_trior] = ACTIONS(5340),
    [anon_sym_trireg] = ACTIONS(5340),
    [anon_sym_uwire] = ACTIONS(5340),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5338),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5338),
    [aux_sym_begin_keywords_token1] = ACTIONS(5338),
    [anon_sym_SEMI] = ACTIONS(5338),
    [anon_sym_endmodule] = ACTIONS(5340),
    [anon_sym_extern] = ACTIONS(5340),
    [anon_sym_module] = ACTIONS(5340),
    [anon_sym_macromodule] = ACTIONS(5340),
    [anon_sym_endinterface] = ACTIONS(5340),
    [anon_sym_interface] = ACTIONS(5340),
    [anon_sym_endprogram] = ACTIONS(5340),
    [anon_sym_program] = ACTIONS(5340),
    [anon_sym_checker] = ACTIONS(5340),
    [anon_sym_virtual] = ACTIONS(5340),
    [anon_sym_class] = ACTIONS(5340),
    [anon_sym_package] = ACTIONS(5340),
    [anon_sym_endpackage] = ACTIONS(5340),
    [anon_sym_timeunit] = ACTIONS(5340),
    [anon_sym_timeprecision] = ACTIONS(5340),
    [anon_sym_type] = ACTIONS(5340),
    [anon_sym_input] = ACTIONS(5340),
    [anon_sym_output] = ACTIONS(5340),
    [anon_sym_inout] = ACTIONS(5340),
    [anon_sym_ref] = ACTIONS(5340),
    [anon_sym_DOLLARfatal] = ACTIONS(5338),
    [anon_sym_DOLLARerror] = ACTIONS(5338),
    [anon_sym_DOLLARwarning] = ACTIONS(5338),
    [anon_sym_DOLLARinfo] = ACTIONS(5338),
    [anon_sym_default] = ACTIONS(5340),
    [anon_sym_clocking] = ACTIONS(5340),
    [anon_sym_defparam] = ACTIONS(5340),
    [anon_sym_bind] = ACTIONS(5340),
    [anon_sym_const] = ACTIONS(5340),
    [anon_sym_function] = ACTIONS(5340),
    [anon_sym_static] = ACTIONS(5340),
    [anon_sym_constraint] = ACTIONS(5340),
    [anon_sym_if] = ACTIONS(5340),
    [anon_sym_else] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5338),
    [anon_sym_localparam] = ACTIONS(5340),
    [anon_sym_parameter] = ACTIONS(5340),
    [anon_sym_specparam] = ACTIONS(5340),
    [anon_sym_var] = ACTIONS(5340),
    [anon_sym_import] = ACTIONS(5340),
    [anon_sym_export] = ACTIONS(5340),
    [anon_sym_genvar] = ACTIONS(5340),
    [anon_sym_interconnect] = ACTIONS(5340),
    [anon_sym_typedef] = ACTIONS(5340),
    [anon_sym_enum] = ACTIONS(5340),
    [anon_sym_struct] = ACTIONS(5340),
    [anon_sym_union] = ACTIONS(5340),
    [anon_sym_nettype] = ACTIONS(5340),
    [anon_sym_automatic] = ACTIONS(5340),
    [anon_sym_string] = ACTIONS(5340),
    [anon_sym_chandle] = ACTIONS(5340),
    [anon_sym_event] = ACTIONS(5340),
    [anon_sym_byte] = ACTIONS(5340),
    [anon_sym_shortint] = ACTIONS(5340),
    [anon_sym_int] = ACTIONS(5340),
    [anon_sym_longint] = ACTIONS(5340),
    [anon_sym_integer] = ACTIONS(5340),
    [anon_sym_time] = ACTIONS(5340),
    [anon_sym_bit] = ACTIONS(5340),
    [anon_sym_logic] = ACTIONS(5340),
    [anon_sym_reg] = ACTIONS(5340),
    [anon_sym_shortreal] = ACTIONS(5340),
    [anon_sym_real] = ACTIONS(5340),
    [anon_sym_realtime] = ACTIONS(5340),
    [anon_sym_supply0] = ACTIONS(5340),
    [anon_sym_supply1] = ACTIONS(5340),
    [anon_sym_signed] = ACTIONS(5340),
    [anon_sym_unsigned] = ACTIONS(5340),
    [anon_sym_task] = ACTIONS(5340),
    [anon_sym_modport] = ACTIONS(5340),
    [anon_sym_assert] = ACTIONS(5340),
    [anon_sym_property] = ACTIONS(5340),
    [anon_sym_assume] = ACTIONS(5340),
    [anon_sym_cover] = ACTIONS(5340),
    [anon_sym_sequence] = ACTIONS(5340),
    [anon_sym_restrict] = ACTIONS(5340),
    [anon_sym_not] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_case] = ACTIONS(5340),
    [anon_sym_always] = ACTIONS(5340),
    [anon_sym_covergroup] = ACTIONS(5340),
    [anon_sym_let] = ACTIONS(5340),
    [anon_sym_pulldown] = ACTIONS(5340),
    [anon_sym_pullup] = ACTIONS(5340),
    [anon_sym_cmos] = ACTIONS(5340),
    [anon_sym_rcmos] = ACTIONS(5340),
    [anon_sym_bufif0] = ACTIONS(5340),
    [anon_sym_bufif1] = ACTIONS(5340),
    [anon_sym_notif0] = ACTIONS(5340),
    [anon_sym_notif1] = ACTIONS(5340),
    [anon_sym_nmos] = ACTIONS(5340),
    [anon_sym_pmos] = ACTIONS(5340),
    [anon_sym_rnmos] = ACTIONS(5340),
    [anon_sym_rpmos] = ACTIONS(5340),
    [anon_sym_nand] = ACTIONS(5340),
    [anon_sym_nor] = ACTIONS(5340),
    [anon_sym_xor] = ACTIONS(5340),
    [anon_sym_xnor] = ACTIONS(5340),
    [anon_sym_buf] = ACTIONS(5340),
    [anon_sym_tranif0] = ACTIONS(5340),
    [anon_sym_tranif1] = ACTIONS(5340),
    [anon_sym_rtranif1] = ACTIONS(5340),
    [anon_sym_rtranif0] = ACTIONS(5340),
    [anon_sym_tran] = ACTIONS(5340),
    [anon_sym_rtran] = ACTIONS(5340),
    [anon_sym_generate] = ACTIONS(5340),
    [anon_sym_for] = ACTIONS(5340),
    [anon_sym_primitive] = ACTIONS(5340),
    [anon_sym_initial] = ACTIONS(5340),
    [anon_sym_assign] = ACTIONS(5340),
    [anon_sym_alias] = ACTIONS(5340),
    [anon_sym_always_comb] = ACTIONS(5340),
    [anon_sym_always_latch] = ACTIONS(5340),
    [anon_sym_always_ff] = ACTIONS(5340),
    [anon_sym_final] = ACTIONS(5340),
    [anon_sym_global] = ACTIONS(5340),
    [anon_sym_specify] = ACTIONS(5340),
    [anon_sym_LPAREN_STAR] = ACTIONS(5338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5338),
    [anon_sym_DOLLARunit] = ACTIONS(5338),
  },
  [882] = {
    [ts_builtin_sym_end] = ACTIONS(5342),
    [sym_simple_identifier] = ACTIONS(5344),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5342),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5342),
    [anon_sym_BQUOTE] = ACTIONS(5344),
    [aux_sym_id_directive_token1] = ACTIONS(5342),
    [aux_sym_id_directive_token2] = ACTIONS(5342),
    [aux_sym_id_directive_token3] = ACTIONS(5342),
    [aux_sym_id_directive_token4] = ACTIONS(5344),
    [aux_sym_zero_directive_token1] = ACTIONS(5342),
    [aux_sym_zero_directive_token2] = ACTIONS(5342),
    [aux_sym_zero_directive_token3] = ACTIONS(5342),
    [aux_sym_zero_directive_token4] = ACTIONS(5342),
    [aux_sym_zero_directive_token5] = ACTIONS(5342),
    [aux_sym_zero_directive_token6] = ACTIONS(5342),
    [aux_sym_zero_directive_token7] = ACTIONS(5342),
    [aux_sym_zero_directive_token8] = ACTIONS(5342),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5342),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5342),
    [anon_sym_wire] = ACTIONS(5344),
    [anon_sym_tri] = ACTIONS(5344),
    [anon_sym_tri0] = ACTIONS(5344),
    [anon_sym_tri1] = ACTIONS(5344),
    [anon_sym_wand] = ACTIONS(5344),
    [anon_sym_triand] = ACTIONS(5344),
    [anon_sym_wor] = ACTIONS(5344),
    [anon_sym_trior] = ACTIONS(5344),
    [anon_sym_trireg] = ACTIONS(5344),
    [anon_sym_uwire] = ACTIONS(5344),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5342),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5342),
    [aux_sym_begin_keywords_token1] = ACTIONS(5342),
    [anon_sym_SEMI] = ACTIONS(5342),
    [anon_sym_endmodule] = ACTIONS(5344),
    [anon_sym_extern] = ACTIONS(5344),
    [anon_sym_module] = ACTIONS(5344),
    [anon_sym_macromodule] = ACTIONS(5344),
    [anon_sym_endinterface] = ACTIONS(5344),
    [anon_sym_interface] = ACTIONS(5344),
    [anon_sym_endprogram] = ACTIONS(5344),
    [anon_sym_program] = ACTIONS(5344),
    [anon_sym_checker] = ACTIONS(5344),
    [anon_sym_virtual] = ACTIONS(5344),
    [anon_sym_class] = ACTIONS(5344),
    [anon_sym_package] = ACTIONS(5344),
    [anon_sym_endpackage] = ACTIONS(5344),
    [anon_sym_timeunit] = ACTIONS(5344),
    [anon_sym_timeprecision] = ACTIONS(5344),
    [anon_sym_type] = ACTIONS(5344),
    [anon_sym_input] = ACTIONS(5344),
    [anon_sym_output] = ACTIONS(5344),
    [anon_sym_inout] = ACTIONS(5344),
    [anon_sym_ref] = ACTIONS(5344),
    [anon_sym_DOLLARfatal] = ACTIONS(5342),
    [anon_sym_DOLLARerror] = ACTIONS(5342),
    [anon_sym_DOLLARwarning] = ACTIONS(5342),
    [anon_sym_DOLLARinfo] = ACTIONS(5342),
    [anon_sym_default] = ACTIONS(5344),
    [anon_sym_clocking] = ACTIONS(5344),
    [anon_sym_defparam] = ACTIONS(5344),
    [anon_sym_bind] = ACTIONS(5344),
    [anon_sym_const] = ACTIONS(5344),
    [anon_sym_function] = ACTIONS(5344),
    [anon_sym_static] = ACTIONS(5344),
    [anon_sym_constraint] = ACTIONS(5344),
    [anon_sym_if] = ACTIONS(5344),
    [anon_sym_else] = ACTIONS(5344),
    [anon_sym_LBRACK] = ACTIONS(5342),
    [anon_sym_localparam] = ACTIONS(5344),
    [anon_sym_parameter] = ACTIONS(5344),
    [anon_sym_specparam] = ACTIONS(5344),
    [anon_sym_var] = ACTIONS(5344),
    [anon_sym_import] = ACTIONS(5344),
    [anon_sym_export] = ACTIONS(5344),
    [anon_sym_genvar] = ACTIONS(5344),
    [anon_sym_interconnect] = ACTIONS(5344),
    [anon_sym_typedef] = ACTIONS(5344),
    [anon_sym_enum] = ACTIONS(5344),
    [anon_sym_struct] = ACTIONS(5344),
    [anon_sym_union] = ACTIONS(5344),
    [anon_sym_nettype] = ACTIONS(5344),
    [anon_sym_automatic] = ACTIONS(5344),
    [anon_sym_string] = ACTIONS(5344),
    [anon_sym_chandle] = ACTIONS(5344),
    [anon_sym_event] = ACTIONS(5344),
    [anon_sym_byte] = ACTIONS(5344),
    [anon_sym_shortint] = ACTIONS(5344),
    [anon_sym_int] = ACTIONS(5344),
    [anon_sym_longint] = ACTIONS(5344),
    [anon_sym_integer] = ACTIONS(5344),
    [anon_sym_time] = ACTIONS(5344),
    [anon_sym_bit] = ACTIONS(5344),
    [anon_sym_logic] = ACTIONS(5344),
    [anon_sym_reg] = ACTIONS(5344),
    [anon_sym_shortreal] = ACTIONS(5344),
    [anon_sym_real] = ACTIONS(5344),
    [anon_sym_realtime] = ACTIONS(5344),
    [anon_sym_supply0] = ACTIONS(5344),
    [anon_sym_supply1] = ACTIONS(5344),
    [anon_sym_signed] = ACTIONS(5344),
    [anon_sym_unsigned] = ACTIONS(5344),
    [anon_sym_task] = ACTIONS(5344),
    [anon_sym_modport] = ACTIONS(5344),
    [anon_sym_assert] = ACTIONS(5344),
    [anon_sym_property] = ACTIONS(5344),
    [anon_sym_assume] = ACTIONS(5344),
    [anon_sym_cover] = ACTIONS(5344),
    [anon_sym_sequence] = ACTIONS(5344),
    [anon_sym_restrict] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(5344),
    [anon_sym_or] = ACTIONS(5344),
    [anon_sym_and] = ACTIONS(5344),
    [anon_sym_case] = ACTIONS(5344),
    [anon_sym_always] = ACTIONS(5344),
    [anon_sym_covergroup] = ACTIONS(5344),
    [anon_sym_let] = ACTIONS(5344),
    [anon_sym_pulldown] = ACTIONS(5344),
    [anon_sym_pullup] = ACTIONS(5344),
    [anon_sym_cmos] = ACTIONS(5344),
    [anon_sym_rcmos] = ACTIONS(5344),
    [anon_sym_bufif0] = ACTIONS(5344),
    [anon_sym_bufif1] = ACTIONS(5344),
    [anon_sym_notif0] = ACTIONS(5344),
    [anon_sym_notif1] = ACTIONS(5344),
    [anon_sym_nmos] = ACTIONS(5344),
    [anon_sym_pmos] = ACTIONS(5344),
    [anon_sym_rnmos] = ACTIONS(5344),
    [anon_sym_rpmos] = ACTIONS(5344),
    [anon_sym_nand] = ACTIONS(5344),
    [anon_sym_nor] = ACTIONS(5344),
    [anon_sym_xor] = ACTIONS(5344),
    [anon_sym_xnor] = ACTIONS(5344),
    [anon_sym_buf] = ACTIONS(5344),
    [anon_sym_tranif0] = ACTIONS(5344),
    [anon_sym_tranif1] = ACTIONS(5344),
    [anon_sym_rtranif1] = ACTIONS(5344),
    [anon_sym_rtranif0] = ACTIONS(5344),
    [anon_sym_tran] = ACTIONS(5344),
    [anon_sym_rtran] = ACTIONS(5344),
    [anon_sym_generate] = ACTIONS(5344),
    [anon_sym_for] = ACTIONS(5344),
    [anon_sym_primitive] = ACTIONS(5344),
    [anon_sym_initial] = ACTIONS(5344),
    [anon_sym_assign] = ACTIONS(5344),
    [anon_sym_alias] = ACTIONS(5344),
    [anon_sym_always_comb] = ACTIONS(5344),
    [anon_sym_always_latch] = ACTIONS(5344),
    [anon_sym_always_ff] = ACTIONS(5344),
    [anon_sym_final] = ACTIONS(5344),
    [anon_sym_global] = ACTIONS(5344),
    [anon_sym_specify] = ACTIONS(5344),
    [anon_sym_LPAREN_STAR] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5342),
    [anon_sym_DOLLARunit] = ACTIONS(5342),
  },
  [883] = {
    [ts_builtin_sym_end] = ACTIONS(5346),
    [sym_simple_identifier] = ACTIONS(5348),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5346),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5346),
    [anon_sym_BQUOTE] = ACTIONS(5348),
    [aux_sym_id_directive_token1] = ACTIONS(5346),
    [aux_sym_id_directive_token2] = ACTIONS(5346),
    [aux_sym_id_directive_token3] = ACTIONS(5346),
    [aux_sym_id_directive_token4] = ACTIONS(5348),
    [aux_sym_zero_directive_token1] = ACTIONS(5346),
    [aux_sym_zero_directive_token2] = ACTIONS(5346),
    [aux_sym_zero_directive_token3] = ACTIONS(5346),
    [aux_sym_zero_directive_token4] = ACTIONS(5346),
    [aux_sym_zero_directive_token5] = ACTIONS(5346),
    [aux_sym_zero_directive_token6] = ACTIONS(5346),
    [aux_sym_zero_directive_token7] = ACTIONS(5346),
    [aux_sym_zero_directive_token8] = ACTIONS(5346),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5346),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5346),
    [anon_sym_wire] = ACTIONS(5348),
    [anon_sym_tri] = ACTIONS(5348),
    [anon_sym_tri0] = ACTIONS(5348),
    [anon_sym_tri1] = ACTIONS(5348),
    [anon_sym_wand] = ACTIONS(5348),
    [anon_sym_triand] = ACTIONS(5348),
    [anon_sym_wor] = ACTIONS(5348),
    [anon_sym_trior] = ACTIONS(5348),
    [anon_sym_trireg] = ACTIONS(5348),
    [anon_sym_uwire] = ACTIONS(5348),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5346),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5346),
    [aux_sym_begin_keywords_token1] = ACTIONS(5346),
    [anon_sym_SEMI] = ACTIONS(5346),
    [anon_sym_endmodule] = ACTIONS(5348),
    [anon_sym_extern] = ACTIONS(5348),
    [anon_sym_module] = ACTIONS(5348),
    [anon_sym_macromodule] = ACTIONS(5348),
    [anon_sym_endinterface] = ACTIONS(5348),
    [anon_sym_interface] = ACTIONS(5348),
    [anon_sym_endprogram] = ACTIONS(5348),
    [anon_sym_program] = ACTIONS(5348),
    [anon_sym_checker] = ACTIONS(5348),
    [anon_sym_virtual] = ACTIONS(5348),
    [anon_sym_class] = ACTIONS(5348),
    [anon_sym_package] = ACTIONS(5348),
    [anon_sym_endpackage] = ACTIONS(5348),
    [anon_sym_timeunit] = ACTIONS(5348),
    [anon_sym_timeprecision] = ACTIONS(5348),
    [anon_sym_type] = ACTIONS(5348),
    [anon_sym_input] = ACTIONS(5348),
    [anon_sym_output] = ACTIONS(5348),
    [anon_sym_inout] = ACTIONS(5348),
    [anon_sym_ref] = ACTIONS(5348),
    [anon_sym_DOLLARfatal] = ACTIONS(5346),
    [anon_sym_DOLLARerror] = ACTIONS(5346),
    [anon_sym_DOLLARwarning] = ACTIONS(5346),
    [anon_sym_DOLLARinfo] = ACTIONS(5346),
    [anon_sym_default] = ACTIONS(5348),
    [anon_sym_clocking] = ACTIONS(5348),
    [anon_sym_defparam] = ACTIONS(5348),
    [anon_sym_bind] = ACTIONS(5348),
    [anon_sym_const] = ACTIONS(5348),
    [anon_sym_function] = ACTIONS(5348),
    [anon_sym_static] = ACTIONS(5348),
    [anon_sym_constraint] = ACTIONS(5348),
    [anon_sym_if] = ACTIONS(5348),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_LBRACK] = ACTIONS(5346),
    [anon_sym_localparam] = ACTIONS(5348),
    [anon_sym_parameter] = ACTIONS(5348),
    [anon_sym_specparam] = ACTIONS(5348),
    [anon_sym_var] = ACTIONS(5348),
    [anon_sym_import] = ACTIONS(5348),
    [anon_sym_export] = ACTIONS(5348),
    [anon_sym_genvar] = ACTIONS(5348),
    [anon_sym_interconnect] = ACTIONS(5348),
    [anon_sym_typedef] = ACTIONS(5348),
    [anon_sym_enum] = ACTIONS(5348),
    [anon_sym_struct] = ACTIONS(5348),
    [anon_sym_union] = ACTIONS(5348),
    [anon_sym_nettype] = ACTIONS(5348),
    [anon_sym_automatic] = ACTIONS(5348),
    [anon_sym_string] = ACTIONS(5348),
    [anon_sym_chandle] = ACTIONS(5348),
    [anon_sym_event] = ACTIONS(5348),
    [anon_sym_byte] = ACTIONS(5348),
    [anon_sym_shortint] = ACTIONS(5348),
    [anon_sym_int] = ACTIONS(5348),
    [anon_sym_longint] = ACTIONS(5348),
    [anon_sym_integer] = ACTIONS(5348),
    [anon_sym_time] = ACTIONS(5348),
    [anon_sym_bit] = ACTIONS(5348),
    [anon_sym_logic] = ACTIONS(5348),
    [anon_sym_reg] = ACTIONS(5348),
    [anon_sym_shortreal] = ACTIONS(5348),
    [anon_sym_real] = ACTIONS(5348),
    [anon_sym_realtime] = ACTIONS(5348),
    [anon_sym_supply0] = ACTIONS(5348),
    [anon_sym_supply1] = ACTIONS(5348),
    [anon_sym_signed] = ACTIONS(5348),
    [anon_sym_unsigned] = ACTIONS(5348),
    [anon_sym_task] = ACTIONS(5348),
    [anon_sym_modport] = ACTIONS(5348),
    [anon_sym_assert] = ACTIONS(5348),
    [anon_sym_property] = ACTIONS(5348),
    [anon_sym_assume] = ACTIONS(5348),
    [anon_sym_cover] = ACTIONS(5348),
    [anon_sym_sequence] = ACTIONS(5348),
    [anon_sym_restrict] = ACTIONS(5348),
    [anon_sym_not] = ACTIONS(5348),
    [anon_sym_or] = ACTIONS(5348),
    [anon_sym_and] = ACTIONS(5348),
    [anon_sym_case] = ACTIONS(5348),
    [anon_sym_always] = ACTIONS(5348),
    [anon_sym_covergroup] = ACTIONS(5348),
    [anon_sym_let] = ACTIONS(5348),
    [anon_sym_pulldown] = ACTIONS(5348),
    [anon_sym_pullup] = ACTIONS(5348),
    [anon_sym_cmos] = ACTIONS(5348),
    [anon_sym_rcmos] = ACTIONS(5348),
    [anon_sym_bufif0] = ACTIONS(5348),
    [anon_sym_bufif1] = ACTIONS(5348),
    [anon_sym_notif0] = ACTIONS(5348),
    [anon_sym_notif1] = ACTIONS(5348),
    [anon_sym_nmos] = ACTIONS(5348),
    [anon_sym_pmos] = ACTIONS(5348),
    [anon_sym_rnmos] = ACTIONS(5348),
    [anon_sym_rpmos] = ACTIONS(5348),
    [anon_sym_nand] = ACTIONS(5348),
    [anon_sym_nor] = ACTIONS(5348),
    [anon_sym_xor] = ACTIONS(5348),
    [anon_sym_xnor] = ACTIONS(5348),
    [anon_sym_buf] = ACTIONS(5348),
    [anon_sym_tranif0] = ACTIONS(5348),
    [anon_sym_tranif1] = ACTIONS(5348),
    [anon_sym_rtranif1] = ACTIONS(5348),
    [anon_sym_rtranif0] = ACTIONS(5348),
    [anon_sym_tran] = ACTIONS(5348),
    [anon_sym_rtran] = ACTIONS(5348),
    [anon_sym_generate] = ACTIONS(5348),
    [anon_sym_for] = ACTIONS(5348),
    [anon_sym_primitive] = ACTIONS(5348),
    [anon_sym_initial] = ACTIONS(5348),
    [anon_sym_assign] = ACTIONS(5348),
    [anon_sym_alias] = ACTIONS(5348),
    [anon_sym_always_comb] = ACTIONS(5348),
    [anon_sym_always_latch] = ACTIONS(5348),
    [anon_sym_always_ff] = ACTIONS(5348),
    [anon_sym_final] = ACTIONS(5348),
    [anon_sym_global] = ACTIONS(5348),
    [anon_sym_specify] = ACTIONS(5348),
    [anon_sym_LPAREN_STAR] = ACTIONS(5346),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5346),
    [anon_sym_DOLLARunit] = ACTIONS(5346),
  },
  [884] = {
    [ts_builtin_sym_end] = ACTIONS(4458),
    [sym_simple_identifier] = ACTIONS(4460),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4458),
    [anon_sym_BQUOTE] = ACTIONS(4460),
    [aux_sym_id_directive_token1] = ACTIONS(4458),
    [aux_sym_id_directive_token2] = ACTIONS(4458),
    [aux_sym_id_directive_token3] = ACTIONS(4458),
    [aux_sym_id_directive_token4] = ACTIONS(4460),
    [aux_sym_zero_directive_token1] = ACTIONS(4458),
    [aux_sym_zero_directive_token2] = ACTIONS(4458),
    [aux_sym_zero_directive_token3] = ACTIONS(4458),
    [aux_sym_zero_directive_token4] = ACTIONS(4458),
    [aux_sym_zero_directive_token5] = ACTIONS(4458),
    [aux_sym_zero_directive_token6] = ACTIONS(4458),
    [aux_sym_zero_directive_token7] = ACTIONS(4458),
    [aux_sym_zero_directive_token8] = ACTIONS(4458),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4458),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4458),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4458),
    [aux_sym_begin_keywords_token1] = ACTIONS(4458),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_endmodule] = ACTIONS(4460),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_module] = ACTIONS(4460),
    [anon_sym_macromodule] = ACTIONS(4460),
    [anon_sym_endinterface] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_endprogram] = ACTIONS(4460),
    [anon_sym_program] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_package] = ACTIONS(4460),
    [anon_sym_endpackage] = ACTIONS(4460),
    [anon_sym_timeunit] = ACTIONS(4460),
    [anon_sym_timeprecision] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_input] = ACTIONS(4460),
    [anon_sym_output] = ACTIONS(4460),
    [anon_sym_inout] = ACTIONS(4460),
    [anon_sym_ref] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_specparam] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_modport] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_primitive] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_specify] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [885] = {
    [ts_builtin_sym_end] = ACTIONS(4492),
    [sym_simple_identifier] = ACTIONS(4494),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4492),
    [anon_sym_BQUOTE] = ACTIONS(4494),
    [aux_sym_id_directive_token1] = ACTIONS(4492),
    [aux_sym_id_directive_token2] = ACTIONS(4492),
    [aux_sym_id_directive_token3] = ACTIONS(4492),
    [aux_sym_id_directive_token4] = ACTIONS(4494),
    [aux_sym_zero_directive_token1] = ACTIONS(4492),
    [aux_sym_zero_directive_token2] = ACTIONS(4492),
    [aux_sym_zero_directive_token3] = ACTIONS(4492),
    [aux_sym_zero_directive_token4] = ACTIONS(4492),
    [aux_sym_zero_directive_token5] = ACTIONS(4492),
    [aux_sym_zero_directive_token6] = ACTIONS(4492),
    [aux_sym_zero_directive_token7] = ACTIONS(4492),
    [aux_sym_zero_directive_token8] = ACTIONS(4492),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4492),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4492),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4492),
    [aux_sym_begin_keywords_token1] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_endmodule] = ACTIONS(4494),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_module] = ACTIONS(4494),
    [anon_sym_macromodule] = ACTIONS(4494),
    [anon_sym_endinterface] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_endprogram] = ACTIONS(4494),
    [anon_sym_program] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_package] = ACTIONS(4494),
    [anon_sym_endpackage] = ACTIONS(4494),
    [anon_sym_timeunit] = ACTIONS(4494),
    [anon_sym_timeprecision] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_input] = ACTIONS(4494),
    [anon_sym_output] = ACTIONS(4494),
    [anon_sym_inout] = ACTIONS(4494),
    [anon_sym_ref] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_specparam] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_modport] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_primitive] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_specify] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [886] = {
    [ts_builtin_sym_end] = ACTIONS(4666),
    [sym_simple_identifier] = ACTIONS(4668),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4666),
    [anon_sym_BQUOTE] = ACTIONS(4668),
    [aux_sym_id_directive_token1] = ACTIONS(4666),
    [aux_sym_id_directive_token2] = ACTIONS(4666),
    [aux_sym_id_directive_token3] = ACTIONS(4666),
    [aux_sym_id_directive_token4] = ACTIONS(4668),
    [aux_sym_zero_directive_token1] = ACTIONS(4666),
    [aux_sym_zero_directive_token2] = ACTIONS(4666),
    [aux_sym_zero_directive_token3] = ACTIONS(4666),
    [aux_sym_zero_directive_token4] = ACTIONS(4666),
    [aux_sym_zero_directive_token5] = ACTIONS(4666),
    [aux_sym_zero_directive_token6] = ACTIONS(4666),
    [aux_sym_zero_directive_token7] = ACTIONS(4666),
    [aux_sym_zero_directive_token8] = ACTIONS(4666),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4666),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4666),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4666),
    [aux_sym_begin_keywords_token1] = ACTIONS(4666),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_endmodule] = ACTIONS(4668),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_module] = ACTIONS(4668),
    [anon_sym_macromodule] = ACTIONS(4668),
    [anon_sym_endinterface] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_endprogram] = ACTIONS(4668),
    [anon_sym_program] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_package] = ACTIONS(4668),
    [anon_sym_endpackage] = ACTIONS(4668),
    [anon_sym_timeunit] = ACTIONS(4668),
    [anon_sym_timeprecision] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_input] = ACTIONS(4668),
    [anon_sym_output] = ACTIONS(4668),
    [anon_sym_inout] = ACTIONS(4668),
    [anon_sym_ref] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_specparam] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_modport] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_primitive] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_specify] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [887] = {
    [ts_builtin_sym_end] = ACTIONS(4204),
    [sym_simple_identifier] = ACTIONS(4206),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4204),
    [anon_sym_BQUOTE] = ACTIONS(4206),
    [aux_sym_id_directive_token1] = ACTIONS(4204),
    [aux_sym_id_directive_token2] = ACTIONS(4204),
    [aux_sym_id_directive_token3] = ACTIONS(4204),
    [aux_sym_id_directive_token4] = ACTIONS(4206),
    [aux_sym_zero_directive_token1] = ACTIONS(4204),
    [aux_sym_zero_directive_token2] = ACTIONS(4204),
    [aux_sym_zero_directive_token3] = ACTIONS(4204),
    [aux_sym_zero_directive_token4] = ACTIONS(4204),
    [aux_sym_zero_directive_token5] = ACTIONS(4204),
    [aux_sym_zero_directive_token6] = ACTIONS(4204),
    [aux_sym_zero_directive_token7] = ACTIONS(4204),
    [aux_sym_zero_directive_token8] = ACTIONS(4204),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4204),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4204),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4204),
    [aux_sym_begin_keywords_token1] = ACTIONS(4204),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_endmodule] = ACTIONS(4206),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_module] = ACTIONS(4206),
    [anon_sym_macromodule] = ACTIONS(4206),
    [anon_sym_endinterface] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_endprogram] = ACTIONS(4206),
    [anon_sym_program] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_package] = ACTIONS(4206),
    [anon_sym_endpackage] = ACTIONS(4206),
    [anon_sym_timeunit] = ACTIONS(4206),
    [anon_sym_timeprecision] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_input] = ACTIONS(4206),
    [anon_sym_output] = ACTIONS(4206),
    [anon_sym_inout] = ACTIONS(4206),
    [anon_sym_ref] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_specparam] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_modport] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_primitive] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_specify] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [888] = {
    [ts_builtin_sym_end] = ACTIONS(4222),
    [sym_simple_identifier] = ACTIONS(4224),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4222),
    [anon_sym_BQUOTE] = ACTIONS(4224),
    [aux_sym_id_directive_token1] = ACTIONS(4222),
    [aux_sym_id_directive_token2] = ACTIONS(4222),
    [aux_sym_id_directive_token3] = ACTIONS(4222),
    [aux_sym_id_directive_token4] = ACTIONS(4224),
    [aux_sym_zero_directive_token1] = ACTIONS(4222),
    [aux_sym_zero_directive_token2] = ACTIONS(4222),
    [aux_sym_zero_directive_token3] = ACTIONS(4222),
    [aux_sym_zero_directive_token4] = ACTIONS(4222),
    [aux_sym_zero_directive_token5] = ACTIONS(4222),
    [aux_sym_zero_directive_token6] = ACTIONS(4222),
    [aux_sym_zero_directive_token7] = ACTIONS(4222),
    [aux_sym_zero_directive_token8] = ACTIONS(4222),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4222),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4222),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4222),
    [aux_sym_begin_keywords_token1] = ACTIONS(4222),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_endmodule] = ACTIONS(4224),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_module] = ACTIONS(4224),
    [anon_sym_macromodule] = ACTIONS(4224),
    [anon_sym_endinterface] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_endprogram] = ACTIONS(4224),
    [anon_sym_program] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_package] = ACTIONS(4224),
    [anon_sym_endpackage] = ACTIONS(4224),
    [anon_sym_timeunit] = ACTIONS(4224),
    [anon_sym_timeprecision] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_input] = ACTIONS(4224),
    [anon_sym_output] = ACTIONS(4224),
    [anon_sym_inout] = ACTIONS(4224),
    [anon_sym_ref] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_specparam] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_modport] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_primitive] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_specify] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [889] = {
    [ts_builtin_sym_end] = ACTIONS(4234),
    [sym_simple_identifier] = ACTIONS(4236),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4234),
    [anon_sym_BQUOTE] = ACTIONS(4236),
    [aux_sym_id_directive_token1] = ACTIONS(4234),
    [aux_sym_id_directive_token2] = ACTIONS(4234),
    [aux_sym_id_directive_token3] = ACTIONS(4234),
    [aux_sym_id_directive_token4] = ACTIONS(4236),
    [aux_sym_zero_directive_token1] = ACTIONS(4234),
    [aux_sym_zero_directive_token2] = ACTIONS(4234),
    [aux_sym_zero_directive_token3] = ACTIONS(4234),
    [aux_sym_zero_directive_token4] = ACTIONS(4234),
    [aux_sym_zero_directive_token5] = ACTIONS(4234),
    [aux_sym_zero_directive_token6] = ACTIONS(4234),
    [aux_sym_zero_directive_token7] = ACTIONS(4234),
    [aux_sym_zero_directive_token8] = ACTIONS(4234),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4234),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4234),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4234),
    [aux_sym_begin_keywords_token1] = ACTIONS(4234),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_endmodule] = ACTIONS(4236),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_module] = ACTIONS(4236),
    [anon_sym_macromodule] = ACTIONS(4236),
    [anon_sym_endinterface] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_endprogram] = ACTIONS(4236),
    [anon_sym_program] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_package] = ACTIONS(4236),
    [anon_sym_endpackage] = ACTIONS(4236),
    [anon_sym_timeunit] = ACTIONS(4236),
    [anon_sym_timeprecision] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_input] = ACTIONS(4236),
    [anon_sym_output] = ACTIONS(4236),
    [anon_sym_inout] = ACTIONS(4236),
    [anon_sym_ref] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_specparam] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_modport] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_primitive] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_specify] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [890] = {
    [ts_builtin_sym_end] = ACTIONS(5350),
    [sym_simple_identifier] = ACTIONS(5352),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5350),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5350),
    [anon_sym_BQUOTE] = ACTIONS(5352),
    [aux_sym_id_directive_token1] = ACTIONS(5350),
    [aux_sym_id_directive_token2] = ACTIONS(5350),
    [aux_sym_id_directive_token3] = ACTIONS(5350),
    [aux_sym_id_directive_token4] = ACTIONS(5352),
    [aux_sym_zero_directive_token1] = ACTIONS(5350),
    [aux_sym_zero_directive_token2] = ACTIONS(5350),
    [aux_sym_zero_directive_token3] = ACTIONS(5350),
    [aux_sym_zero_directive_token4] = ACTIONS(5350),
    [aux_sym_zero_directive_token5] = ACTIONS(5350),
    [aux_sym_zero_directive_token6] = ACTIONS(5350),
    [aux_sym_zero_directive_token7] = ACTIONS(5350),
    [aux_sym_zero_directive_token8] = ACTIONS(5350),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5350),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5350),
    [anon_sym_wire] = ACTIONS(5352),
    [anon_sym_tri] = ACTIONS(5352),
    [anon_sym_tri0] = ACTIONS(5352),
    [anon_sym_tri1] = ACTIONS(5352),
    [anon_sym_wand] = ACTIONS(5352),
    [anon_sym_triand] = ACTIONS(5352),
    [anon_sym_wor] = ACTIONS(5352),
    [anon_sym_trior] = ACTIONS(5352),
    [anon_sym_trireg] = ACTIONS(5352),
    [anon_sym_uwire] = ACTIONS(5352),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5350),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5350),
    [aux_sym_begin_keywords_token1] = ACTIONS(5350),
    [anon_sym_SEMI] = ACTIONS(5350),
    [anon_sym_endmodule] = ACTIONS(5352),
    [anon_sym_extern] = ACTIONS(5352),
    [anon_sym_module] = ACTIONS(5352),
    [anon_sym_macromodule] = ACTIONS(5352),
    [anon_sym_endinterface] = ACTIONS(5352),
    [anon_sym_interface] = ACTIONS(5352),
    [anon_sym_endprogram] = ACTIONS(5352),
    [anon_sym_program] = ACTIONS(5352),
    [anon_sym_checker] = ACTIONS(5352),
    [anon_sym_virtual] = ACTIONS(5352),
    [anon_sym_class] = ACTIONS(5352),
    [anon_sym_package] = ACTIONS(5352),
    [anon_sym_endpackage] = ACTIONS(5352),
    [anon_sym_timeunit] = ACTIONS(5352),
    [anon_sym_timeprecision] = ACTIONS(5352),
    [anon_sym_type] = ACTIONS(5352),
    [anon_sym_input] = ACTIONS(5352),
    [anon_sym_output] = ACTIONS(5352),
    [anon_sym_inout] = ACTIONS(5352),
    [anon_sym_ref] = ACTIONS(5352),
    [anon_sym_DOLLARfatal] = ACTIONS(5350),
    [anon_sym_DOLLARerror] = ACTIONS(5350),
    [anon_sym_DOLLARwarning] = ACTIONS(5350),
    [anon_sym_DOLLARinfo] = ACTIONS(5350),
    [anon_sym_default] = ACTIONS(5352),
    [anon_sym_clocking] = ACTIONS(5352),
    [anon_sym_defparam] = ACTIONS(5352),
    [anon_sym_bind] = ACTIONS(5352),
    [anon_sym_const] = ACTIONS(5352),
    [anon_sym_function] = ACTIONS(5352),
    [anon_sym_static] = ACTIONS(5352),
    [anon_sym_constraint] = ACTIONS(5352),
    [anon_sym_if] = ACTIONS(5352),
    [anon_sym_else] = ACTIONS(5352),
    [anon_sym_LBRACK] = ACTIONS(5350),
    [anon_sym_localparam] = ACTIONS(5352),
    [anon_sym_parameter] = ACTIONS(5352),
    [anon_sym_specparam] = ACTIONS(5352),
    [anon_sym_var] = ACTIONS(5352),
    [anon_sym_import] = ACTIONS(5352),
    [anon_sym_export] = ACTIONS(5352),
    [anon_sym_genvar] = ACTIONS(5352),
    [anon_sym_interconnect] = ACTIONS(5352),
    [anon_sym_typedef] = ACTIONS(5352),
    [anon_sym_enum] = ACTIONS(5352),
    [anon_sym_struct] = ACTIONS(5352),
    [anon_sym_union] = ACTIONS(5352),
    [anon_sym_nettype] = ACTIONS(5352),
    [anon_sym_automatic] = ACTIONS(5352),
    [anon_sym_string] = ACTIONS(5352),
    [anon_sym_chandle] = ACTIONS(5352),
    [anon_sym_event] = ACTIONS(5352),
    [anon_sym_byte] = ACTIONS(5352),
    [anon_sym_shortint] = ACTIONS(5352),
    [anon_sym_int] = ACTIONS(5352),
    [anon_sym_longint] = ACTIONS(5352),
    [anon_sym_integer] = ACTIONS(5352),
    [anon_sym_time] = ACTIONS(5352),
    [anon_sym_bit] = ACTIONS(5352),
    [anon_sym_logic] = ACTIONS(5352),
    [anon_sym_reg] = ACTIONS(5352),
    [anon_sym_shortreal] = ACTIONS(5352),
    [anon_sym_real] = ACTIONS(5352),
    [anon_sym_realtime] = ACTIONS(5352),
    [anon_sym_supply0] = ACTIONS(5352),
    [anon_sym_supply1] = ACTIONS(5352),
    [anon_sym_signed] = ACTIONS(5352),
    [anon_sym_unsigned] = ACTIONS(5352),
    [anon_sym_task] = ACTIONS(5352),
    [anon_sym_modport] = ACTIONS(5352),
    [anon_sym_assert] = ACTIONS(5352),
    [anon_sym_property] = ACTIONS(5352),
    [anon_sym_assume] = ACTIONS(5352),
    [anon_sym_cover] = ACTIONS(5352),
    [anon_sym_sequence] = ACTIONS(5352),
    [anon_sym_restrict] = ACTIONS(5352),
    [anon_sym_not] = ACTIONS(5352),
    [anon_sym_or] = ACTIONS(5352),
    [anon_sym_and] = ACTIONS(5352),
    [anon_sym_case] = ACTIONS(5352),
    [anon_sym_always] = ACTIONS(5352),
    [anon_sym_covergroup] = ACTIONS(5352),
    [anon_sym_let] = ACTIONS(5352),
    [anon_sym_pulldown] = ACTIONS(5352),
    [anon_sym_pullup] = ACTIONS(5352),
    [anon_sym_cmos] = ACTIONS(5352),
    [anon_sym_rcmos] = ACTIONS(5352),
    [anon_sym_bufif0] = ACTIONS(5352),
    [anon_sym_bufif1] = ACTIONS(5352),
    [anon_sym_notif0] = ACTIONS(5352),
    [anon_sym_notif1] = ACTIONS(5352),
    [anon_sym_nmos] = ACTIONS(5352),
    [anon_sym_pmos] = ACTIONS(5352),
    [anon_sym_rnmos] = ACTIONS(5352),
    [anon_sym_rpmos] = ACTIONS(5352),
    [anon_sym_nand] = ACTIONS(5352),
    [anon_sym_nor] = ACTIONS(5352),
    [anon_sym_xor] = ACTIONS(5352),
    [anon_sym_xnor] = ACTIONS(5352),
    [anon_sym_buf] = ACTIONS(5352),
    [anon_sym_tranif0] = ACTIONS(5352),
    [anon_sym_tranif1] = ACTIONS(5352),
    [anon_sym_rtranif1] = ACTIONS(5352),
    [anon_sym_rtranif0] = ACTIONS(5352),
    [anon_sym_tran] = ACTIONS(5352),
    [anon_sym_rtran] = ACTIONS(5352),
    [anon_sym_generate] = ACTIONS(5352),
    [anon_sym_for] = ACTIONS(5352),
    [anon_sym_primitive] = ACTIONS(5352),
    [anon_sym_initial] = ACTIONS(5352),
    [anon_sym_assign] = ACTIONS(5352),
    [anon_sym_alias] = ACTIONS(5352),
    [anon_sym_always_comb] = ACTIONS(5352),
    [anon_sym_always_latch] = ACTIONS(5352),
    [anon_sym_always_ff] = ACTIONS(5352),
    [anon_sym_final] = ACTIONS(5352),
    [anon_sym_global] = ACTIONS(5352),
    [anon_sym_specify] = ACTIONS(5352),
    [anon_sym_LPAREN_STAR] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5350),
    [anon_sym_DOLLARunit] = ACTIONS(5350),
  },
  [891] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19451),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19451),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5354),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [892] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19468),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19468),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5356),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [893] = {
    [ts_builtin_sym_end] = ACTIONS(5358),
    [sym_simple_identifier] = ACTIONS(5360),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5358),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5358),
    [anon_sym_BQUOTE] = ACTIONS(5360),
    [aux_sym_id_directive_token1] = ACTIONS(5358),
    [aux_sym_id_directive_token2] = ACTIONS(5358),
    [aux_sym_id_directive_token3] = ACTIONS(5358),
    [aux_sym_id_directive_token4] = ACTIONS(5360),
    [aux_sym_zero_directive_token1] = ACTIONS(5358),
    [aux_sym_zero_directive_token2] = ACTIONS(5358),
    [aux_sym_zero_directive_token3] = ACTIONS(5358),
    [aux_sym_zero_directive_token4] = ACTIONS(5358),
    [aux_sym_zero_directive_token5] = ACTIONS(5358),
    [aux_sym_zero_directive_token6] = ACTIONS(5358),
    [aux_sym_zero_directive_token7] = ACTIONS(5358),
    [aux_sym_zero_directive_token8] = ACTIONS(5358),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5358),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5358),
    [anon_sym_wire] = ACTIONS(5360),
    [anon_sym_tri] = ACTIONS(5360),
    [anon_sym_tri0] = ACTIONS(5360),
    [anon_sym_tri1] = ACTIONS(5360),
    [anon_sym_wand] = ACTIONS(5360),
    [anon_sym_triand] = ACTIONS(5360),
    [anon_sym_wor] = ACTIONS(5360),
    [anon_sym_trior] = ACTIONS(5360),
    [anon_sym_trireg] = ACTIONS(5360),
    [anon_sym_uwire] = ACTIONS(5360),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5358),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5358),
    [aux_sym_begin_keywords_token1] = ACTIONS(5358),
    [anon_sym_SEMI] = ACTIONS(5358),
    [anon_sym_endmodule] = ACTIONS(5360),
    [anon_sym_extern] = ACTIONS(5360),
    [anon_sym_module] = ACTIONS(5360),
    [anon_sym_macromodule] = ACTIONS(5360),
    [anon_sym_endinterface] = ACTIONS(5360),
    [anon_sym_interface] = ACTIONS(5360),
    [anon_sym_endprogram] = ACTIONS(5360),
    [anon_sym_program] = ACTIONS(5360),
    [anon_sym_checker] = ACTIONS(5360),
    [anon_sym_virtual] = ACTIONS(5360),
    [anon_sym_class] = ACTIONS(5360),
    [anon_sym_package] = ACTIONS(5360),
    [anon_sym_endpackage] = ACTIONS(5360),
    [anon_sym_timeunit] = ACTIONS(5360),
    [anon_sym_timeprecision] = ACTIONS(5360),
    [anon_sym_type] = ACTIONS(5360),
    [anon_sym_input] = ACTIONS(5360),
    [anon_sym_output] = ACTIONS(5360),
    [anon_sym_inout] = ACTIONS(5360),
    [anon_sym_ref] = ACTIONS(5360),
    [anon_sym_DOLLARfatal] = ACTIONS(5358),
    [anon_sym_DOLLARerror] = ACTIONS(5358),
    [anon_sym_DOLLARwarning] = ACTIONS(5358),
    [anon_sym_DOLLARinfo] = ACTIONS(5358),
    [anon_sym_default] = ACTIONS(5360),
    [anon_sym_clocking] = ACTIONS(5360),
    [anon_sym_defparam] = ACTIONS(5360),
    [anon_sym_bind] = ACTIONS(5360),
    [anon_sym_const] = ACTIONS(5360),
    [anon_sym_function] = ACTIONS(5360),
    [anon_sym_static] = ACTIONS(5360),
    [anon_sym_constraint] = ACTIONS(5360),
    [anon_sym_if] = ACTIONS(5360),
    [anon_sym_else] = ACTIONS(5360),
    [anon_sym_LBRACK] = ACTIONS(5358),
    [anon_sym_localparam] = ACTIONS(5360),
    [anon_sym_parameter] = ACTIONS(5360),
    [anon_sym_specparam] = ACTIONS(5360),
    [anon_sym_var] = ACTIONS(5360),
    [anon_sym_import] = ACTIONS(5360),
    [anon_sym_export] = ACTIONS(5360),
    [anon_sym_genvar] = ACTIONS(5360),
    [anon_sym_interconnect] = ACTIONS(5360),
    [anon_sym_typedef] = ACTIONS(5360),
    [anon_sym_enum] = ACTIONS(5360),
    [anon_sym_struct] = ACTIONS(5360),
    [anon_sym_union] = ACTIONS(5360),
    [anon_sym_nettype] = ACTIONS(5360),
    [anon_sym_automatic] = ACTIONS(5360),
    [anon_sym_string] = ACTIONS(5360),
    [anon_sym_chandle] = ACTIONS(5360),
    [anon_sym_event] = ACTIONS(5360),
    [anon_sym_byte] = ACTIONS(5360),
    [anon_sym_shortint] = ACTIONS(5360),
    [anon_sym_int] = ACTIONS(5360),
    [anon_sym_longint] = ACTIONS(5360),
    [anon_sym_integer] = ACTIONS(5360),
    [anon_sym_time] = ACTIONS(5360),
    [anon_sym_bit] = ACTIONS(5360),
    [anon_sym_logic] = ACTIONS(5360),
    [anon_sym_reg] = ACTIONS(5360),
    [anon_sym_shortreal] = ACTIONS(5360),
    [anon_sym_real] = ACTIONS(5360),
    [anon_sym_realtime] = ACTIONS(5360),
    [anon_sym_supply0] = ACTIONS(5360),
    [anon_sym_supply1] = ACTIONS(5360),
    [anon_sym_signed] = ACTIONS(5360),
    [anon_sym_unsigned] = ACTIONS(5360),
    [anon_sym_task] = ACTIONS(5360),
    [anon_sym_modport] = ACTIONS(5360),
    [anon_sym_assert] = ACTIONS(5360),
    [anon_sym_property] = ACTIONS(5360),
    [anon_sym_assume] = ACTIONS(5360),
    [anon_sym_cover] = ACTIONS(5360),
    [anon_sym_sequence] = ACTIONS(5360),
    [anon_sym_restrict] = ACTIONS(5360),
    [anon_sym_not] = ACTIONS(5360),
    [anon_sym_or] = ACTIONS(5360),
    [anon_sym_and] = ACTIONS(5360),
    [anon_sym_case] = ACTIONS(5360),
    [anon_sym_always] = ACTIONS(5360),
    [anon_sym_covergroup] = ACTIONS(5360),
    [anon_sym_let] = ACTIONS(5360),
    [anon_sym_pulldown] = ACTIONS(5360),
    [anon_sym_pullup] = ACTIONS(5360),
    [anon_sym_cmos] = ACTIONS(5360),
    [anon_sym_rcmos] = ACTIONS(5360),
    [anon_sym_bufif0] = ACTIONS(5360),
    [anon_sym_bufif1] = ACTIONS(5360),
    [anon_sym_notif0] = ACTIONS(5360),
    [anon_sym_notif1] = ACTIONS(5360),
    [anon_sym_nmos] = ACTIONS(5360),
    [anon_sym_pmos] = ACTIONS(5360),
    [anon_sym_rnmos] = ACTIONS(5360),
    [anon_sym_rpmos] = ACTIONS(5360),
    [anon_sym_nand] = ACTIONS(5360),
    [anon_sym_nor] = ACTIONS(5360),
    [anon_sym_xor] = ACTIONS(5360),
    [anon_sym_xnor] = ACTIONS(5360),
    [anon_sym_buf] = ACTIONS(5360),
    [anon_sym_tranif0] = ACTIONS(5360),
    [anon_sym_tranif1] = ACTIONS(5360),
    [anon_sym_rtranif1] = ACTIONS(5360),
    [anon_sym_rtranif0] = ACTIONS(5360),
    [anon_sym_tran] = ACTIONS(5360),
    [anon_sym_rtran] = ACTIONS(5360),
    [anon_sym_generate] = ACTIONS(5360),
    [anon_sym_for] = ACTIONS(5360),
    [anon_sym_primitive] = ACTIONS(5360),
    [anon_sym_initial] = ACTIONS(5360),
    [anon_sym_assign] = ACTIONS(5360),
    [anon_sym_alias] = ACTIONS(5360),
    [anon_sym_always_comb] = ACTIONS(5360),
    [anon_sym_always_latch] = ACTIONS(5360),
    [anon_sym_always_ff] = ACTIONS(5360),
    [anon_sym_final] = ACTIONS(5360),
    [anon_sym_global] = ACTIONS(5360),
    [anon_sym_specify] = ACTIONS(5360),
    [anon_sym_LPAREN_STAR] = ACTIONS(5358),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5358),
    [anon_sym_DOLLARunit] = ACTIONS(5358),
  },
  [894] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18560),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18560),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5362),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [895] = {
    [ts_builtin_sym_end] = ACTIONS(5364),
    [sym_simple_identifier] = ACTIONS(5366),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5364),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5364),
    [anon_sym_BQUOTE] = ACTIONS(5366),
    [aux_sym_id_directive_token1] = ACTIONS(5364),
    [aux_sym_id_directive_token2] = ACTIONS(5364),
    [aux_sym_id_directive_token3] = ACTIONS(5364),
    [aux_sym_id_directive_token4] = ACTIONS(5366),
    [aux_sym_zero_directive_token1] = ACTIONS(5364),
    [aux_sym_zero_directive_token2] = ACTIONS(5364),
    [aux_sym_zero_directive_token3] = ACTIONS(5364),
    [aux_sym_zero_directive_token4] = ACTIONS(5364),
    [aux_sym_zero_directive_token5] = ACTIONS(5364),
    [aux_sym_zero_directive_token6] = ACTIONS(5364),
    [aux_sym_zero_directive_token7] = ACTIONS(5364),
    [aux_sym_zero_directive_token8] = ACTIONS(5364),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5364),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5364),
    [anon_sym_wire] = ACTIONS(5366),
    [anon_sym_tri] = ACTIONS(5366),
    [anon_sym_tri0] = ACTIONS(5366),
    [anon_sym_tri1] = ACTIONS(5366),
    [anon_sym_wand] = ACTIONS(5366),
    [anon_sym_triand] = ACTIONS(5366),
    [anon_sym_wor] = ACTIONS(5366),
    [anon_sym_trior] = ACTIONS(5366),
    [anon_sym_trireg] = ACTIONS(5366),
    [anon_sym_uwire] = ACTIONS(5366),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5364),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5364),
    [aux_sym_begin_keywords_token1] = ACTIONS(5364),
    [anon_sym_SEMI] = ACTIONS(5364),
    [anon_sym_endmodule] = ACTIONS(5366),
    [anon_sym_extern] = ACTIONS(5366),
    [anon_sym_module] = ACTIONS(5366),
    [anon_sym_macromodule] = ACTIONS(5366),
    [anon_sym_endinterface] = ACTIONS(5366),
    [anon_sym_interface] = ACTIONS(5366),
    [anon_sym_endprogram] = ACTIONS(5366),
    [anon_sym_program] = ACTIONS(5366),
    [anon_sym_checker] = ACTIONS(5366),
    [anon_sym_virtual] = ACTIONS(5366),
    [anon_sym_class] = ACTIONS(5366),
    [anon_sym_package] = ACTIONS(5366),
    [anon_sym_endpackage] = ACTIONS(5366),
    [anon_sym_timeunit] = ACTIONS(5366),
    [anon_sym_timeprecision] = ACTIONS(5366),
    [anon_sym_type] = ACTIONS(5366),
    [anon_sym_input] = ACTIONS(5366),
    [anon_sym_output] = ACTIONS(5366),
    [anon_sym_inout] = ACTIONS(5366),
    [anon_sym_ref] = ACTIONS(5366),
    [anon_sym_DOLLARfatal] = ACTIONS(5364),
    [anon_sym_DOLLARerror] = ACTIONS(5364),
    [anon_sym_DOLLARwarning] = ACTIONS(5364),
    [anon_sym_DOLLARinfo] = ACTIONS(5364),
    [anon_sym_default] = ACTIONS(5366),
    [anon_sym_clocking] = ACTIONS(5366),
    [anon_sym_defparam] = ACTIONS(5366),
    [anon_sym_bind] = ACTIONS(5366),
    [anon_sym_const] = ACTIONS(5366),
    [anon_sym_function] = ACTIONS(5366),
    [anon_sym_static] = ACTIONS(5366),
    [anon_sym_constraint] = ACTIONS(5366),
    [anon_sym_if] = ACTIONS(5366),
    [anon_sym_else] = ACTIONS(5366),
    [anon_sym_LBRACK] = ACTIONS(5364),
    [anon_sym_localparam] = ACTIONS(5366),
    [anon_sym_parameter] = ACTIONS(5366),
    [anon_sym_specparam] = ACTIONS(5366),
    [anon_sym_var] = ACTIONS(5366),
    [anon_sym_import] = ACTIONS(5366),
    [anon_sym_export] = ACTIONS(5366),
    [anon_sym_genvar] = ACTIONS(5366),
    [anon_sym_interconnect] = ACTIONS(5366),
    [anon_sym_typedef] = ACTIONS(5366),
    [anon_sym_enum] = ACTIONS(5366),
    [anon_sym_struct] = ACTIONS(5366),
    [anon_sym_union] = ACTIONS(5366),
    [anon_sym_nettype] = ACTIONS(5366),
    [anon_sym_automatic] = ACTIONS(5366),
    [anon_sym_string] = ACTIONS(5366),
    [anon_sym_chandle] = ACTIONS(5366),
    [anon_sym_event] = ACTIONS(5366),
    [anon_sym_byte] = ACTIONS(5366),
    [anon_sym_shortint] = ACTIONS(5366),
    [anon_sym_int] = ACTIONS(5366),
    [anon_sym_longint] = ACTIONS(5366),
    [anon_sym_integer] = ACTIONS(5366),
    [anon_sym_time] = ACTIONS(5366),
    [anon_sym_bit] = ACTIONS(5366),
    [anon_sym_logic] = ACTIONS(5366),
    [anon_sym_reg] = ACTIONS(5366),
    [anon_sym_shortreal] = ACTIONS(5366),
    [anon_sym_real] = ACTIONS(5366),
    [anon_sym_realtime] = ACTIONS(5366),
    [anon_sym_supply0] = ACTIONS(5366),
    [anon_sym_supply1] = ACTIONS(5366),
    [anon_sym_signed] = ACTIONS(5366),
    [anon_sym_unsigned] = ACTIONS(5366),
    [anon_sym_task] = ACTIONS(5366),
    [anon_sym_modport] = ACTIONS(5366),
    [anon_sym_assert] = ACTIONS(5366),
    [anon_sym_property] = ACTIONS(5366),
    [anon_sym_assume] = ACTIONS(5366),
    [anon_sym_cover] = ACTIONS(5366),
    [anon_sym_sequence] = ACTIONS(5366),
    [anon_sym_restrict] = ACTIONS(5366),
    [anon_sym_not] = ACTIONS(5366),
    [anon_sym_or] = ACTIONS(5366),
    [anon_sym_and] = ACTIONS(5366),
    [anon_sym_case] = ACTIONS(5366),
    [anon_sym_always] = ACTIONS(5366),
    [anon_sym_covergroup] = ACTIONS(5366),
    [anon_sym_let] = ACTIONS(5366),
    [anon_sym_pulldown] = ACTIONS(5366),
    [anon_sym_pullup] = ACTIONS(5366),
    [anon_sym_cmos] = ACTIONS(5366),
    [anon_sym_rcmos] = ACTIONS(5366),
    [anon_sym_bufif0] = ACTIONS(5366),
    [anon_sym_bufif1] = ACTIONS(5366),
    [anon_sym_notif0] = ACTIONS(5366),
    [anon_sym_notif1] = ACTIONS(5366),
    [anon_sym_nmos] = ACTIONS(5366),
    [anon_sym_pmos] = ACTIONS(5366),
    [anon_sym_rnmos] = ACTIONS(5366),
    [anon_sym_rpmos] = ACTIONS(5366),
    [anon_sym_nand] = ACTIONS(5366),
    [anon_sym_nor] = ACTIONS(5366),
    [anon_sym_xor] = ACTIONS(5366),
    [anon_sym_xnor] = ACTIONS(5366),
    [anon_sym_buf] = ACTIONS(5366),
    [anon_sym_tranif0] = ACTIONS(5366),
    [anon_sym_tranif1] = ACTIONS(5366),
    [anon_sym_rtranif1] = ACTIONS(5366),
    [anon_sym_rtranif0] = ACTIONS(5366),
    [anon_sym_tran] = ACTIONS(5366),
    [anon_sym_rtran] = ACTIONS(5366),
    [anon_sym_generate] = ACTIONS(5366),
    [anon_sym_for] = ACTIONS(5366),
    [anon_sym_primitive] = ACTIONS(5366),
    [anon_sym_initial] = ACTIONS(5366),
    [anon_sym_assign] = ACTIONS(5366),
    [anon_sym_alias] = ACTIONS(5366),
    [anon_sym_always_comb] = ACTIONS(5366),
    [anon_sym_always_latch] = ACTIONS(5366),
    [anon_sym_always_ff] = ACTIONS(5366),
    [anon_sym_final] = ACTIONS(5366),
    [anon_sym_global] = ACTIONS(5366),
    [anon_sym_specify] = ACTIONS(5366),
    [anon_sym_LPAREN_STAR] = ACTIONS(5364),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5364),
    [anon_sym_DOLLARunit] = ACTIONS(5364),
  },
  [896] = {
    [ts_builtin_sym_end] = ACTIONS(5368),
    [sym_simple_identifier] = ACTIONS(5370),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5368),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5368),
    [anon_sym_BQUOTE] = ACTIONS(5370),
    [aux_sym_id_directive_token1] = ACTIONS(5368),
    [aux_sym_id_directive_token2] = ACTIONS(5368),
    [aux_sym_id_directive_token3] = ACTIONS(5368),
    [aux_sym_id_directive_token4] = ACTIONS(5370),
    [aux_sym_zero_directive_token1] = ACTIONS(5368),
    [aux_sym_zero_directive_token2] = ACTIONS(5368),
    [aux_sym_zero_directive_token3] = ACTIONS(5368),
    [aux_sym_zero_directive_token4] = ACTIONS(5368),
    [aux_sym_zero_directive_token5] = ACTIONS(5368),
    [aux_sym_zero_directive_token6] = ACTIONS(5368),
    [aux_sym_zero_directive_token7] = ACTIONS(5368),
    [aux_sym_zero_directive_token8] = ACTIONS(5368),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5368),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5368),
    [anon_sym_wire] = ACTIONS(5370),
    [anon_sym_tri] = ACTIONS(5370),
    [anon_sym_tri0] = ACTIONS(5370),
    [anon_sym_tri1] = ACTIONS(5370),
    [anon_sym_wand] = ACTIONS(5370),
    [anon_sym_triand] = ACTIONS(5370),
    [anon_sym_wor] = ACTIONS(5370),
    [anon_sym_trior] = ACTIONS(5370),
    [anon_sym_trireg] = ACTIONS(5370),
    [anon_sym_uwire] = ACTIONS(5370),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5368),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5368),
    [aux_sym_begin_keywords_token1] = ACTIONS(5368),
    [anon_sym_SEMI] = ACTIONS(5368),
    [anon_sym_endmodule] = ACTIONS(5370),
    [anon_sym_extern] = ACTIONS(5370),
    [anon_sym_module] = ACTIONS(5370),
    [anon_sym_macromodule] = ACTIONS(5370),
    [anon_sym_endinterface] = ACTIONS(5370),
    [anon_sym_interface] = ACTIONS(5370),
    [anon_sym_endprogram] = ACTIONS(5370),
    [anon_sym_program] = ACTIONS(5370),
    [anon_sym_checker] = ACTIONS(5370),
    [anon_sym_virtual] = ACTIONS(5370),
    [anon_sym_class] = ACTIONS(5370),
    [anon_sym_package] = ACTIONS(5370),
    [anon_sym_endpackage] = ACTIONS(5370),
    [anon_sym_timeunit] = ACTIONS(5370),
    [anon_sym_timeprecision] = ACTIONS(5370),
    [anon_sym_type] = ACTIONS(5370),
    [anon_sym_input] = ACTIONS(5370),
    [anon_sym_output] = ACTIONS(5370),
    [anon_sym_inout] = ACTIONS(5370),
    [anon_sym_ref] = ACTIONS(5370),
    [anon_sym_DOLLARfatal] = ACTIONS(5368),
    [anon_sym_DOLLARerror] = ACTIONS(5368),
    [anon_sym_DOLLARwarning] = ACTIONS(5368),
    [anon_sym_DOLLARinfo] = ACTIONS(5368),
    [anon_sym_default] = ACTIONS(5370),
    [anon_sym_clocking] = ACTIONS(5370),
    [anon_sym_defparam] = ACTIONS(5370),
    [anon_sym_bind] = ACTIONS(5370),
    [anon_sym_const] = ACTIONS(5370),
    [anon_sym_function] = ACTIONS(5370),
    [anon_sym_static] = ACTIONS(5370),
    [anon_sym_constraint] = ACTIONS(5370),
    [anon_sym_if] = ACTIONS(5370),
    [anon_sym_else] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5368),
    [anon_sym_localparam] = ACTIONS(5370),
    [anon_sym_parameter] = ACTIONS(5370),
    [anon_sym_specparam] = ACTIONS(5370),
    [anon_sym_var] = ACTIONS(5370),
    [anon_sym_import] = ACTIONS(5370),
    [anon_sym_export] = ACTIONS(5370),
    [anon_sym_genvar] = ACTIONS(5370),
    [anon_sym_interconnect] = ACTIONS(5370),
    [anon_sym_typedef] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_struct] = ACTIONS(5370),
    [anon_sym_union] = ACTIONS(5370),
    [anon_sym_nettype] = ACTIONS(5370),
    [anon_sym_automatic] = ACTIONS(5370),
    [anon_sym_string] = ACTIONS(5370),
    [anon_sym_chandle] = ACTIONS(5370),
    [anon_sym_event] = ACTIONS(5370),
    [anon_sym_byte] = ACTIONS(5370),
    [anon_sym_shortint] = ACTIONS(5370),
    [anon_sym_int] = ACTIONS(5370),
    [anon_sym_longint] = ACTIONS(5370),
    [anon_sym_integer] = ACTIONS(5370),
    [anon_sym_time] = ACTIONS(5370),
    [anon_sym_bit] = ACTIONS(5370),
    [anon_sym_logic] = ACTIONS(5370),
    [anon_sym_reg] = ACTIONS(5370),
    [anon_sym_shortreal] = ACTIONS(5370),
    [anon_sym_real] = ACTIONS(5370),
    [anon_sym_realtime] = ACTIONS(5370),
    [anon_sym_supply0] = ACTIONS(5370),
    [anon_sym_supply1] = ACTIONS(5370),
    [anon_sym_signed] = ACTIONS(5370),
    [anon_sym_unsigned] = ACTIONS(5370),
    [anon_sym_task] = ACTIONS(5370),
    [anon_sym_modport] = ACTIONS(5370),
    [anon_sym_assert] = ACTIONS(5370),
    [anon_sym_property] = ACTIONS(5370),
    [anon_sym_assume] = ACTIONS(5370),
    [anon_sym_cover] = ACTIONS(5370),
    [anon_sym_sequence] = ACTIONS(5370),
    [anon_sym_restrict] = ACTIONS(5370),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_or] = ACTIONS(5370),
    [anon_sym_and] = ACTIONS(5370),
    [anon_sym_case] = ACTIONS(5370),
    [anon_sym_always] = ACTIONS(5370),
    [anon_sym_covergroup] = ACTIONS(5370),
    [anon_sym_let] = ACTIONS(5370),
    [anon_sym_pulldown] = ACTIONS(5370),
    [anon_sym_pullup] = ACTIONS(5370),
    [anon_sym_cmos] = ACTIONS(5370),
    [anon_sym_rcmos] = ACTIONS(5370),
    [anon_sym_bufif0] = ACTIONS(5370),
    [anon_sym_bufif1] = ACTIONS(5370),
    [anon_sym_notif0] = ACTIONS(5370),
    [anon_sym_notif1] = ACTIONS(5370),
    [anon_sym_nmos] = ACTIONS(5370),
    [anon_sym_pmos] = ACTIONS(5370),
    [anon_sym_rnmos] = ACTIONS(5370),
    [anon_sym_rpmos] = ACTIONS(5370),
    [anon_sym_nand] = ACTIONS(5370),
    [anon_sym_nor] = ACTIONS(5370),
    [anon_sym_xor] = ACTIONS(5370),
    [anon_sym_xnor] = ACTIONS(5370),
    [anon_sym_buf] = ACTIONS(5370),
    [anon_sym_tranif0] = ACTIONS(5370),
    [anon_sym_tranif1] = ACTIONS(5370),
    [anon_sym_rtranif1] = ACTIONS(5370),
    [anon_sym_rtranif0] = ACTIONS(5370),
    [anon_sym_tran] = ACTIONS(5370),
    [anon_sym_rtran] = ACTIONS(5370),
    [anon_sym_generate] = ACTIONS(5370),
    [anon_sym_for] = ACTIONS(5370),
    [anon_sym_primitive] = ACTIONS(5370),
    [anon_sym_initial] = ACTIONS(5370),
    [anon_sym_assign] = ACTIONS(5370),
    [anon_sym_alias] = ACTIONS(5370),
    [anon_sym_always_comb] = ACTIONS(5370),
    [anon_sym_always_latch] = ACTIONS(5370),
    [anon_sym_always_ff] = ACTIONS(5370),
    [anon_sym_final] = ACTIONS(5370),
    [anon_sym_global] = ACTIONS(5370),
    [anon_sym_specify] = ACTIONS(5370),
    [anon_sym_LPAREN_STAR] = ACTIONS(5368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5368),
    [anon_sym_DOLLARunit] = ACTIONS(5368),
  },
  [897] = {
    [ts_builtin_sym_end] = ACTIONS(5372),
    [sym_simple_identifier] = ACTIONS(5374),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5372),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5372),
    [anon_sym_BQUOTE] = ACTIONS(5374),
    [aux_sym_id_directive_token1] = ACTIONS(5372),
    [aux_sym_id_directive_token2] = ACTIONS(5372),
    [aux_sym_id_directive_token3] = ACTIONS(5372),
    [aux_sym_id_directive_token4] = ACTIONS(5374),
    [aux_sym_zero_directive_token1] = ACTIONS(5372),
    [aux_sym_zero_directive_token2] = ACTIONS(5372),
    [aux_sym_zero_directive_token3] = ACTIONS(5372),
    [aux_sym_zero_directive_token4] = ACTIONS(5372),
    [aux_sym_zero_directive_token5] = ACTIONS(5372),
    [aux_sym_zero_directive_token6] = ACTIONS(5372),
    [aux_sym_zero_directive_token7] = ACTIONS(5372),
    [aux_sym_zero_directive_token8] = ACTIONS(5372),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5372),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5372),
    [anon_sym_wire] = ACTIONS(5374),
    [anon_sym_tri] = ACTIONS(5374),
    [anon_sym_tri0] = ACTIONS(5374),
    [anon_sym_tri1] = ACTIONS(5374),
    [anon_sym_wand] = ACTIONS(5374),
    [anon_sym_triand] = ACTIONS(5374),
    [anon_sym_wor] = ACTIONS(5374),
    [anon_sym_trior] = ACTIONS(5374),
    [anon_sym_trireg] = ACTIONS(5374),
    [anon_sym_uwire] = ACTIONS(5374),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5372),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5372),
    [aux_sym_begin_keywords_token1] = ACTIONS(5372),
    [anon_sym_SEMI] = ACTIONS(5372),
    [anon_sym_endmodule] = ACTIONS(5374),
    [anon_sym_extern] = ACTIONS(5374),
    [anon_sym_module] = ACTIONS(5374),
    [anon_sym_macromodule] = ACTIONS(5374),
    [anon_sym_endinterface] = ACTIONS(5374),
    [anon_sym_interface] = ACTIONS(5374),
    [anon_sym_endprogram] = ACTIONS(5374),
    [anon_sym_program] = ACTIONS(5374),
    [anon_sym_checker] = ACTIONS(5374),
    [anon_sym_virtual] = ACTIONS(5374),
    [anon_sym_class] = ACTIONS(5374),
    [anon_sym_package] = ACTIONS(5374),
    [anon_sym_endpackage] = ACTIONS(5374),
    [anon_sym_timeunit] = ACTIONS(5374),
    [anon_sym_timeprecision] = ACTIONS(5374),
    [anon_sym_type] = ACTIONS(5374),
    [anon_sym_input] = ACTIONS(5374),
    [anon_sym_output] = ACTIONS(5374),
    [anon_sym_inout] = ACTIONS(5374),
    [anon_sym_ref] = ACTIONS(5374),
    [anon_sym_DOLLARfatal] = ACTIONS(5372),
    [anon_sym_DOLLARerror] = ACTIONS(5372),
    [anon_sym_DOLLARwarning] = ACTIONS(5372),
    [anon_sym_DOLLARinfo] = ACTIONS(5372),
    [anon_sym_default] = ACTIONS(5374),
    [anon_sym_clocking] = ACTIONS(5374),
    [anon_sym_defparam] = ACTIONS(5374),
    [anon_sym_bind] = ACTIONS(5374),
    [anon_sym_const] = ACTIONS(5374),
    [anon_sym_function] = ACTIONS(5374),
    [anon_sym_static] = ACTIONS(5374),
    [anon_sym_constraint] = ACTIONS(5374),
    [anon_sym_if] = ACTIONS(5374),
    [anon_sym_else] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [anon_sym_localparam] = ACTIONS(5374),
    [anon_sym_parameter] = ACTIONS(5374),
    [anon_sym_specparam] = ACTIONS(5374),
    [anon_sym_var] = ACTIONS(5374),
    [anon_sym_import] = ACTIONS(5374),
    [anon_sym_export] = ACTIONS(5374),
    [anon_sym_genvar] = ACTIONS(5374),
    [anon_sym_interconnect] = ACTIONS(5374),
    [anon_sym_typedef] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_struct] = ACTIONS(5374),
    [anon_sym_union] = ACTIONS(5374),
    [anon_sym_nettype] = ACTIONS(5374),
    [anon_sym_automatic] = ACTIONS(5374),
    [anon_sym_string] = ACTIONS(5374),
    [anon_sym_chandle] = ACTIONS(5374),
    [anon_sym_event] = ACTIONS(5374),
    [anon_sym_byte] = ACTIONS(5374),
    [anon_sym_shortint] = ACTIONS(5374),
    [anon_sym_int] = ACTIONS(5374),
    [anon_sym_longint] = ACTIONS(5374),
    [anon_sym_integer] = ACTIONS(5374),
    [anon_sym_time] = ACTIONS(5374),
    [anon_sym_bit] = ACTIONS(5374),
    [anon_sym_logic] = ACTIONS(5374),
    [anon_sym_reg] = ACTIONS(5374),
    [anon_sym_shortreal] = ACTIONS(5374),
    [anon_sym_real] = ACTIONS(5374),
    [anon_sym_realtime] = ACTIONS(5374),
    [anon_sym_supply0] = ACTIONS(5374),
    [anon_sym_supply1] = ACTIONS(5374),
    [anon_sym_signed] = ACTIONS(5374),
    [anon_sym_unsigned] = ACTIONS(5374),
    [anon_sym_task] = ACTIONS(5374),
    [anon_sym_modport] = ACTIONS(5374),
    [anon_sym_assert] = ACTIONS(5374),
    [anon_sym_property] = ACTIONS(5374),
    [anon_sym_assume] = ACTIONS(5374),
    [anon_sym_cover] = ACTIONS(5374),
    [anon_sym_sequence] = ACTIONS(5374),
    [anon_sym_restrict] = ACTIONS(5374),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_or] = ACTIONS(5374),
    [anon_sym_and] = ACTIONS(5374),
    [anon_sym_case] = ACTIONS(5374),
    [anon_sym_always] = ACTIONS(5374),
    [anon_sym_covergroup] = ACTIONS(5374),
    [anon_sym_let] = ACTIONS(5374),
    [anon_sym_pulldown] = ACTIONS(5374),
    [anon_sym_pullup] = ACTIONS(5374),
    [anon_sym_cmos] = ACTIONS(5374),
    [anon_sym_rcmos] = ACTIONS(5374),
    [anon_sym_bufif0] = ACTIONS(5374),
    [anon_sym_bufif1] = ACTIONS(5374),
    [anon_sym_notif0] = ACTIONS(5374),
    [anon_sym_notif1] = ACTIONS(5374),
    [anon_sym_nmos] = ACTIONS(5374),
    [anon_sym_pmos] = ACTIONS(5374),
    [anon_sym_rnmos] = ACTIONS(5374),
    [anon_sym_rpmos] = ACTIONS(5374),
    [anon_sym_nand] = ACTIONS(5374),
    [anon_sym_nor] = ACTIONS(5374),
    [anon_sym_xor] = ACTIONS(5374),
    [anon_sym_xnor] = ACTIONS(5374),
    [anon_sym_buf] = ACTIONS(5374),
    [anon_sym_tranif0] = ACTIONS(5374),
    [anon_sym_tranif1] = ACTIONS(5374),
    [anon_sym_rtranif1] = ACTIONS(5374),
    [anon_sym_rtranif0] = ACTIONS(5374),
    [anon_sym_tran] = ACTIONS(5374),
    [anon_sym_rtran] = ACTIONS(5374),
    [anon_sym_generate] = ACTIONS(5374),
    [anon_sym_for] = ACTIONS(5374),
    [anon_sym_primitive] = ACTIONS(5374),
    [anon_sym_initial] = ACTIONS(5374),
    [anon_sym_assign] = ACTIONS(5374),
    [anon_sym_alias] = ACTIONS(5374),
    [anon_sym_always_comb] = ACTIONS(5374),
    [anon_sym_always_latch] = ACTIONS(5374),
    [anon_sym_always_ff] = ACTIONS(5374),
    [anon_sym_final] = ACTIONS(5374),
    [anon_sym_global] = ACTIONS(5374),
    [anon_sym_specify] = ACTIONS(5374),
    [anon_sym_LPAREN_STAR] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5372),
    [anon_sym_DOLLARunit] = ACTIONS(5372),
  },
  [898] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18357),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18357),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5376),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [899] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18567),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18567),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5378),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [900] = {
    [ts_builtin_sym_end] = ACTIONS(5380),
    [sym_simple_identifier] = ACTIONS(5382),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5380),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5380),
    [anon_sym_BQUOTE] = ACTIONS(5382),
    [aux_sym_id_directive_token1] = ACTIONS(5380),
    [aux_sym_id_directive_token2] = ACTIONS(5380),
    [aux_sym_id_directive_token3] = ACTIONS(5380),
    [aux_sym_id_directive_token4] = ACTIONS(5382),
    [aux_sym_zero_directive_token1] = ACTIONS(5380),
    [aux_sym_zero_directive_token2] = ACTIONS(5380),
    [aux_sym_zero_directive_token3] = ACTIONS(5380),
    [aux_sym_zero_directive_token4] = ACTIONS(5380),
    [aux_sym_zero_directive_token5] = ACTIONS(5380),
    [aux_sym_zero_directive_token6] = ACTIONS(5380),
    [aux_sym_zero_directive_token7] = ACTIONS(5380),
    [aux_sym_zero_directive_token8] = ACTIONS(5380),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5380),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5380),
    [anon_sym_wire] = ACTIONS(5382),
    [anon_sym_tri] = ACTIONS(5382),
    [anon_sym_tri0] = ACTIONS(5382),
    [anon_sym_tri1] = ACTIONS(5382),
    [anon_sym_wand] = ACTIONS(5382),
    [anon_sym_triand] = ACTIONS(5382),
    [anon_sym_wor] = ACTIONS(5382),
    [anon_sym_trior] = ACTIONS(5382),
    [anon_sym_trireg] = ACTIONS(5382),
    [anon_sym_uwire] = ACTIONS(5382),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5380),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5380),
    [aux_sym_begin_keywords_token1] = ACTIONS(5380),
    [anon_sym_SEMI] = ACTIONS(5380),
    [anon_sym_endmodule] = ACTIONS(5382),
    [anon_sym_extern] = ACTIONS(5382),
    [anon_sym_module] = ACTIONS(5382),
    [anon_sym_macromodule] = ACTIONS(5382),
    [anon_sym_endinterface] = ACTIONS(5382),
    [anon_sym_interface] = ACTIONS(5382),
    [anon_sym_endprogram] = ACTIONS(5382),
    [anon_sym_program] = ACTIONS(5382),
    [anon_sym_checker] = ACTIONS(5382),
    [anon_sym_virtual] = ACTIONS(5382),
    [anon_sym_class] = ACTIONS(5382),
    [anon_sym_package] = ACTIONS(5382),
    [anon_sym_endpackage] = ACTIONS(5382),
    [anon_sym_timeunit] = ACTIONS(5382),
    [anon_sym_timeprecision] = ACTIONS(5382),
    [anon_sym_type] = ACTIONS(5382),
    [anon_sym_input] = ACTIONS(5382),
    [anon_sym_output] = ACTIONS(5382),
    [anon_sym_inout] = ACTIONS(5382),
    [anon_sym_ref] = ACTIONS(5382),
    [anon_sym_DOLLARfatal] = ACTIONS(5380),
    [anon_sym_DOLLARerror] = ACTIONS(5380),
    [anon_sym_DOLLARwarning] = ACTIONS(5380),
    [anon_sym_DOLLARinfo] = ACTIONS(5380),
    [anon_sym_default] = ACTIONS(5382),
    [anon_sym_clocking] = ACTIONS(5382),
    [anon_sym_defparam] = ACTIONS(5382),
    [anon_sym_bind] = ACTIONS(5382),
    [anon_sym_const] = ACTIONS(5382),
    [anon_sym_function] = ACTIONS(5382),
    [anon_sym_static] = ACTIONS(5382),
    [anon_sym_constraint] = ACTIONS(5382),
    [anon_sym_if] = ACTIONS(5382),
    [anon_sym_else] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [anon_sym_localparam] = ACTIONS(5382),
    [anon_sym_parameter] = ACTIONS(5382),
    [anon_sym_specparam] = ACTIONS(5382),
    [anon_sym_var] = ACTIONS(5382),
    [anon_sym_import] = ACTIONS(5382),
    [anon_sym_export] = ACTIONS(5382),
    [anon_sym_genvar] = ACTIONS(5382),
    [anon_sym_interconnect] = ACTIONS(5382),
    [anon_sym_typedef] = ACTIONS(5382),
    [anon_sym_enum] = ACTIONS(5382),
    [anon_sym_struct] = ACTIONS(5382),
    [anon_sym_union] = ACTIONS(5382),
    [anon_sym_nettype] = ACTIONS(5382),
    [anon_sym_automatic] = ACTIONS(5382),
    [anon_sym_string] = ACTIONS(5382),
    [anon_sym_chandle] = ACTIONS(5382),
    [anon_sym_event] = ACTIONS(5382),
    [anon_sym_byte] = ACTIONS(5382),
    [anon_sym_shortint] = ACTIONS(5382),
    [anon_sym_int] = ACTIONS(5382),
    [anon_sym_longint] = ACTIONS(5382),
    [anon_sym_integer] = ACTIONS(5382),
    [anon_sym_time] = ACTIONS(5382),
    [anon_sym_bit] = ACTIONS(5382),
    [anon_sym_logic] = ACTIONS(5382),
    [anon_sym_reg] = ACTIONS(5382),
    [anon_sym_shortreal] = ACTIONS(5382),
    [anon_sym_real] = ACTIONS(5382),
    [anon_sym_realtime] = ACTIONS(5382),
    [anon_sym_supply0] = ACTIONS(5382),
    [anon_sym_supply1] = ACTIONS(5382),
    [anon_sym_signed] = ACTIONS(5382),
    [anon_sym_unsigned] = ACTIONS(5382),
    [anon_sym_task] = ACTIONS(5382),
    [anon_sym_modport] = ACTIONS(5382),
    [anon_sym_assert] = ACTIONS(5382),
    [anon_sym_property] = ACTIONS(5382),
    [anon_sym_assume] = ACTIONS(5382),
    [anon_sym_cover] = ACTIONS(5382),
    [anon_sym_sequence] = ACTIONS(5382),
    [anon_sym_restrict] = ACTIONS(5382),
    [anon_sym_not] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_case] = ACTIONS(5382),
    [anon_sym_always] = ACTIONS(5382),
    [anon_sym_covergroup] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_pulldown] = ACTIONS(5382),
    [anon_sym_pullup] = ACTIONS(5382),
    [anon_sym_cmos] = ACTIONS(5382),
    [anon_sym_rcmos] = ACTIONS(5382),
    [anon_sym_bufif0] = ACTIONS(5382),
    [anon_sym_bufif1] = ACTIONS(5382),
    [anon_sym_notif0] = ACTIONS(5382),
    [anon_sym_notif1] = ACTIONS(5382),
    [anon_sym_nmos] = ACTIONS(5382),
    [anon_sym_pmos] = ACTIONS(5382),
    [anon_sym_rnmos] = ACTIONS(5382),
    [anon_sym_rpmos] = ACTIONS(5382),
    [anon_sym_nand] = ACTIONS(5382),
    [anon_sym_nor] = ACTIONS(5382),
    [anon_sym_xor] = ACTIONS(5382),
    [anon_sym_xnor] = ACTIONS(5382),
    [anon_sym_buf] = ACTIONS(5382),
    [anon_sym_tranif0] = ACTIONS(5382),
    [anon_sym_tranif1] = ACTIONS(5382),
    [anon_sym_rtranif1] = ACTIONS(5382),
    [anon_sym_rtranif0] = ACTIONS(5382),
    [anon_sym_tran] = ACTIONS(5382),
    [anon_sym_rtran] = ACTIONS(5382),
    [anon_sym_generate] = ACTIONS(5382),
    [anon_sym_for] = ACTIONS(5382),
    [anon_sym_primitive] = ACTIONS(5382),
    [anon_sym_initial] = ACTIONS(5382),
    [anon_sym_assign] = ACTIONS(5382),
    [anon_sym_alias] = ACTIONS(5382),
    [anon_sym_always_comb] = ACTIONS(5382),
    [anon_sym_always_latch] = ACTIONS(5382),
    [anon_sym_always_ff] = ACTIONS(5382),
    [anon_sym_final] = ACTIONS(5382),
    [anon_sym_global] = ACTIONS(5382),
    [anon_sym_specify] = ACTIONS(5382),
    [anon_sym_LPAREN_STAR] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5380),
    [anon_sym_DOLLARunit] = ACTIONS(5380),
  },
  [901] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18365),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18365),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5384),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [902] = {
    [ts_builtin_sym_end] = ACTIONS(5386),
    [sym_simple_identifier] = ACTIONS(5388),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5386),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5386),
    [anon_sym_BQUOTE] = ACTIONS(5388),
    [aux_sym_id_directive_token1] = ACTIONS(5386),
    [aux_sym_id_directive_token2] = ACTIONS(5386),
    [aux_sym_id_directive_token3] = ACTIONS(5386),
    [aux_sym_id_directive_token4] = ACTIONS(5388),
    [aux_sym_zero_directive_token1] = ACTIONS(5386),
    [aux_sym_zero_directive_token2] = ACTIONS(5386),
    [aux_sym_zero_directive_token3] = ACTIONS(5386),
    [aux_sym_zero_directive_token4] = ACTIONS(5386),
    [aux_sym_zero_directive_token5] = ACTIONS(5386),
    [aux_sym_zero_directive_token6] = ACTIONS(5386),
    [aux_sym_zero_directive_token7] = ACTIONS(5386),
    [aux_sym_zero_directive_token8] = ACTIONS(5386),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5386),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5386),
    [anon_sym_wire] = ACTIONS(5388),
    [anon_sym_tri] = ACTIONS(5388),
    [anon_sym_tri0] = ACTIONS(5388),
    [anon_sym_tri1] = ACTIONS(5388),
    [anon_sym_wand] = ACTIONS(5388),
    [anon_sym_triand] = ACTIONS(5388),
    [anon_sym_wor] = ACTIONS(5388),
    [anon_sym_trior] = ACTIONS(5388),
    [anon_sym_trireg] = ACTIONS(5388),
    [anon_sym_uwire] = ACTIONS(5388),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5386),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5386),
    [aux_sym_begin_keywords_token1] = ACTIONS(5386),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_endmodule] = ACTIONS(5388),
    [anon_sym_extern] = ACTIONS(5388),
    [anon_sym_module] = ACTIONS(5388),
    [anon_sym_macromodule] = ACTIONS(5388),
    [anon_sym_endinterface] = ACTIONS(5388),
    [anon_sym_interface] = ACTIONS(5388),
    [anon_sym_endprogram] = ACTIONS(5388),
    [anon_sym_program] = ACTIONS(5388),
    [anon_sym_checker] = ACTIONS(5388),
    [anon_sym_virtual] = ACTIONS(5388),
    [anon_sym_class] = ACTIONS(5388),
    [anon_sym_package] = ACTIONS(5388),
    [anon_sym_endpackage] = ACTIONS(5388),
    [anon_sym_timeunit] = ACTIONS(5388),
    [anon_sym_timeprecision] = ACTIONS(5388),
    [anon_sym_type] = ACTIONS(5388),
    [anon_sym_input] = ACTIONS(5388),
    [anon_sym_output] = ACTIONS(5388),
    [anon_sym_inout] = ACTIONS(5388),
    [anon_sym_ref] = ACTIONS(5388),
    [anon_sym_DOLLARfatal] = ACTIONS(5386),
    [anon_sym_DOLLARerror] = ACTIONS(5386),
    [anon_sym_DOLLARwarning] = ACTIONS(5386),
    [anon_sym_DOLLARinfo] = ACTIONS(5386),
    [anon_sym_default] = ACTIONS(5388),
    [anon_sym_clocking] = ACTIONS(5388),
    [anon_sym_defparam] = ACTIONS(5388),
    [anon_sym_bind] = ACTIONS(5388),
    [anon_sym_const] = ACTIONS(5388),
    [anon_sym_function] = ACTIONS(5388),
    [anon_sym_static] = ACTIONS(5388),
    [anon_sym_constraint] = ACTIONS(5388),
    [anon_sym_if] = ACTIONS(5388),
    [anon_sym_else] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [anon_sym_localparam] = ACTIONS(5388),
    [anon_sym_parameter] = ACTIONS(5388),
    [anon_sym_specparam] = ACTIONS(5388),
    [anon_sym_var] = ACTIONS(5388),
    [anon_sym_import] = ACTIONS(5388),
    [anon_sym_export] = ACTIONS(5388),
    [anon_sym_genvar] = ACTIONS(5388),
    [anon_sym_interconnect] = ACTIONS(5388),
    [anon_sym_typedef] = ACTIONS(5388),
    [anon_sym_enum] = ACTIONS(5388),
    [anon_sym_struct] = ACTIONS(5388),
    [anon_sym_union] = ACTIONS(5388),
    [anon_sym_nettype] = ACTIONS(5388),
    [anon_sym_automatic] = ACTIONS(5388),
    [anon_sym_string] = ACTIONS(5388),
    [anon_sym_chandle] = ACTIONS(5388),
    [anon_sym_event] = ACTIONS(5388),
    [anon_sym_byte] = ACTIONS(5388),
    [anon_sym_shortint] = ACTIONS(5388),
    [anon_sym_int] = ACTIONS(5388),
    [anon_sym_longint] = ACTIONS(5388),
    [anon_sym_integer] = ACTIONS(5388),
    [anon_sym_time] = ACTIONS(5388),
    [anon_sym_bit] = ACTIONS(5388),
    [anon_sym_logic] = ACTIONS(5388),
    [anon_sym_reg] = ACTIONS(5388),
    [anon_sym_shortreal] = ACTIONS(5388),
    [anon_sym_real] = ACTIONS(5388),
    [anon_sym_realtime] = ACTIONS(5388),
    [anon_sym_supply0] = ACTIONS(5388),
    [anon_sym_supply1] = ACTIONS(5388),
    [anon_sym_signed] = ACTIONS(5388),
    [anon_sym_unsigned] = ACTIONS(5388),
    [anon_sym_task] = ACTIONS(5388),
    [anon_sym_modport] = ACTIONS(5388),
    [anon_sym_assert] = ACTIONS(5388),
    [anon_sym_property] = ACTIONS(5388),
    [anon_sym_assume] = ACTIONS(5388),
    [anon_sym_cover] = ACTIONS(5388),
    [anon_sym_sequence] = ACTIONS(5388),
    [anon_sym_restrict] = ACTIONS(5388),
    [anon_sym_not] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_case] = ACTIONS(5388),
    [anon_sym_always] = ACTIONS(5388),
    [anon_sym_covergroup] = ACTIONS(5388),
    [anon_sym_let] = ACTIONS(5388),
    [anon_sym_pulldown] = ACTIONS(5388),
    [anon_sym_pullup] = ACTIONS(5388),
    [anon_sym_cmos] = ACTIONS(5388),
    [anon_sym_rcmos] = ACTIONS(5388),
    [anon_sym_bufif0] = ACTIONS(5388),
    [anon_sym_bufif1] = ACTIONS(5388),
    [anon_sym_notif0] = ACTIONS(5388),
    [anon_sym_notif1] = ACTIONS(5388),
    [anon_sym_nmos] = ACTIONS(5388),
    [anon_sym_pmos] = ACTIONS(5388),
    [anon_sym_rnmos] = ACTIONS(5388),
    [anon_sym_rpmos] = ACTIONS(5388),
    [anon_sym_nand] = ACTIONS(5388),
    [anon_sym_nor] = ACTIONS(5388),
    [anon_sym_xor] = ACTIONS(5388),
    [anon_sym_xnor] = ACTIONS(5388),
    [anon_sym_buf] = ACTIONS(5388),
    [anon_sym_tranif0] = ACTIONS(5388),
    [anon_sym_tranif1] = ACTIONS(5388),
    [anon_sym_rtranif1] = ACTIONS(5388),
    [anon_sym_rtranif0] = ACTIONS(5388),
    [anon_sym_tran] = ACTIONS(5388),
    [anon_sym_rtran] = ACTIONS(5388),
    [anon_sym_generate] = ACTIONS(5388),
    [anon_sym_for] = ACTIONS(5388),
    [anon_sym_primitive] = ACTIONS(5388),
    [anon_sym_initial] = ACTIONS(5388),
    [anon_sym_assign] = ACTIONS(5388),
    [anon_sym_alias] = ACTIONS(5388),
    [anon_sym_always_comb] = ACTIONS(5388),
    [anon_sym_always_latch] = ACTIONS(5388),
    [anon_sym_always_ff] = ACTIONS(5388),
    [anon_sym_final] = ACTIONS(5388),
    [anon_sym_global] = ACTIONS(5388),
    [anon_sym_specify] = ACTIONS(5388),
    [anon_sym_LPAREN_STAR] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5386),
    [anon_sym_DOLLARunit] = ACTIONS(5386),
  },
  [903] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18743),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18743),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5390),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [904] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18568),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18568),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5392),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [905] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18750),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18750),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5394),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [906] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18571),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18571),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5396),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [907] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18338),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18338),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5398),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [908] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18751),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18751),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5400),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [909] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18356),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18356),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5402),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [910] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18754),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18754),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5404),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [911] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18906),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18906),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5406),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [912] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18914),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18914),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5408),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [913] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18913),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18913),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5410),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [914] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18917),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18917),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5412),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [915] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19028),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19028),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5414),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [916] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19035),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19035),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [917] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19034),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19034),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5418),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [918] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19038),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19038),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5420),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [919] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19083),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19083),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5422),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [920] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19088),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19088),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [921] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19087),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19087),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5426),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [922] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19090),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19090),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5428),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [923] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19131),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19131),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5430),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [924] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19136),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19136),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5432),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [925] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19135),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19135),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5434),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [926] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19138),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19138),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7372),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5436),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [927] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18338),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18338),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7377),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5438),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [928] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18356),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18356),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7364),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5440),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [929] = {
    [ts_builtin_sym_end] = ACTIONS(4422),
    [sym_simple_identifier] = ACTIONS(4424),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4422),
    [anon_sym_BQUOTE] = ACTIONS(4424),
    [aux_sym_id_directive_token1] = ACTIONS(4422),
    [aux_sym_id_directive_token2] = ACTIONS(4422),
    [aux_sym_id_directive_token3] = ACTIONS(4422),
    [aux_sym_id_directive_token4] = ACTIONS(4424),
    [aux_sym_zero_directive_token1] = ACTIONS(4422),
    [aux_sym_zero_directive_token2] = ACTIONS(4422),
    [aux_sym_zero_directive_token3] = ACTIONS(4422),
    [aux_sym_zero_directive_token4] = ACTIONS(4422),
    [aux_sym_zero_directive_token5] = ACTIONS(4422),
    [aux_sym_zero_directive_token6] = ACTIONS(4422),
    [aux_sym_zero_directive_token7] = ACTIONS(4422),
    [aux_sym_zero_directive_token8] = ACTIONS(4422),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4422),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4422),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4422),
    [aux_sym_begin_keywords_token1] = ACTIONS(4422),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_endmodule] = ACTIONS(4424),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_module] = ACTIONS(4424),
    [anon_sym_macromodule] = ACTIONS(4424),
    [anon_sym_endinterface] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_endprogram] = ACTIONS(4424),
    [anon_sym_program] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_package] = ACTIONS(4424),
    [anon_sym_endpackage] = ACTIONS(4424),
    [anon_sym_timeunit] = ACTIONS(4424),
    [anon_sym_timeprecision] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_input] = ACTIONS(4424),
    [anon_sym_output] = ACTIONS(4424),
    [anon_sym_inout] = ACTIONS(4424),
    [anon_sym_ref] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_specparam] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_modport] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_primitive] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_specify] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [930] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19083),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19083),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7377),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5442),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [931] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19087),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19087),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7364),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5444),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [932] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19131),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19131),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7377),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5446),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [933] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(19135),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(19135),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7364),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5448),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [934] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18560),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18560),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7377),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5450),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [935] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(18567),
    [sym_property_expr] = STATE(11692),
    [sym_sequence_expr] = STATE(10939),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(18567),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7364),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5760),
    [sym_package_scope] = STATE(12307),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13058),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_RPAREN] = ACTIONS(5452),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(4840),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [936] = {
    [ts_builtin_sym_end] = ACTIONS(4628),
    [sym_simple_identifier] = ACTIONS(4630),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4628),
    [anon_sym_BQUOTE] = ACTIONS(4630),
    [aux_sym_id_directive_token1] = ACTIONS(4628),
    [aux_sym_id_directive_token2] = ACTIONS(4628),
    [aux_sym_id_directive_token3] = ACTIONS(4628),
    [aux_sym_id_directive_token4] = ACTIONS(4630),
    [aux_sym_zero_directive_token1] = ACTIONS(4628),
    [aux_sym_zero_directive_token2] = ACTIONS(4628),
    [aux_sym_zero_directive_token3] = ACTIONS(4628),
    [aux_sym_zero_directive_token4] = ACTIONS(4628),
    [aux_sym_zero_directive_token5] = ACTIONS(4628),
    [aux_sym_zero_directive_token6] = ACTIONS(4628),
    [aux_sym_zero_directive_token7] = ACTIONS(4628),
    [aux_sym_zero_directive_token8] = ACTIONS(4628),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4628),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4628),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4628),
    [aux_sym_begin_keywords_token1] = ACTIONS(4628),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_endmodule] = ACTIONS(4630),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_module] = ACTIONS(4630),
    [anon_sym_macromodule] = ACTIONS(4630),
    [anon_sym_endinterface] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_endprogram] = ACTIONS(4630),
    [anon_sym_program] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_package] = ACTIONS(4630),
    [anon_sym_endpackage] = ACTIONS(4630),
    [anon_sym_timeunit] = ACTIONS(4630),
    [anon_sym_timeprecision] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_input] = ACTIONS(4630),
    [anon_sym_output] = ACTIONS(4630),
    [anon_sym_inout] = ACTIONS(4630),
    [anon_sym_ref] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_specparam] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_modport] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_primitive] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_specify] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [937] = {
    [ts_builtin_sym_end] = ACTIONS(4644),
    [sym_simple_identifier] = ACTIONS(4646),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4644),
    [anon_sym_BQUOTE] = ACTIONS(4646),
    [aux_sym_id_directive_token1] = ACTIONS(4644),
    [aux_sym_id_directive_token2] = ACTIONS(4644),
    [aux_sym_id_directive_token3] = ACTIONS(4644),
    [aux_sym_id_directive_token4] = ACTIONS(4646),
    [aux_sym_zero_directive_token1] = ACTIONS(4644),
    [aux_sym_zero_directive_token2] = ACTIONS(4644),
    [aux_sym_zero_directive_token3] = ACTIONS(4644),
    [aux_sym_zero_directive_token4] = ACTIONS(4644),
    [aux_sym_zero_directive_token5] = ACTIONS(4644),
    [aux_sym_zero_directive_token6] = ACTIONS(4644),
    [aux_sym_zero_directive_token7] = ACTIONS(4644),
    [aux_sym_zero_directive_token8] = ACTIONS(4644),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4644),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4644),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4644),
    [aux_sym_begin_keywords_token1] = ACTIONS(4644),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_endmodule] = ACTIONS(4646),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_module] = ACTIONS(4646),
    [anon_sym_macromodule] = ACTIONS(4646),
    [anon_sym_endinterface] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_endprogram] = ACTIONS(4646),
    [anon_sym_program] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_package] = ACTIONS(4646),
    [anon_sym_endpackage] = ACTIONS(4646),
    [anon_sym_timeunit] = ACTIONS(4646),
    [anon_sym_timeprecision] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_input] = ACTIONS(4646),
    [anon_sym_output] = ACTIONS(4646),
    [anon_sym_inout] = ACTIONS(4646),
    [anon_sym_ref] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_specparam] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_modport] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_primitive] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_specify] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [938] = {
    [ts_builtin_sym_end] = ACTIONS(4694),
    [sym_simple_identifier] = ACTIONS(4696),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_text_macro_definition_token1] = ACTIONS(4694),
    [anon_sym_BQUOTE] = ACTIONS(4696),
    [aux_sym_id_directive_token1] = ACTIONS(4694),
    [aux_sym_id_directive_token2] = ACTIONS(4694),
    [aux_sym_id_directive_token3] = ACTIONS(4694),
    [aux_sym_id_directive_token4] = ACTIONS(4696),
    [aux_sym_zero_directive_token1] = ACTIONS(4694),
    [aux_sym_zero_directive_token2] = ACTIONS(4694),
    [aux_sym_zero_directive_token3] = ACTIONS(4694),
    [aux_sym_zero_directive_token4] = ACTIONS(4694),
    [aux_sym_zero_directive_token5] = ACTIONS(4694),
    [aux_sym_zero_directive_token6] = ACTIONS(4694),
    [aux_sym_zero_directive_token7] = ACTIONS(4694),
    [aux_sym_zero_directive_token8] = ACTIONS(4694),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(4694),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [aux_sym_unconnected_drive_token1] = ACTIONS(4694),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(4694),
    [aux_sym_begin_keywords_token1] = ACTIONS(4694),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_endmodule] = ACTIONS(4696),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_module] = ACTIONS(4696),
    [anon_sym_macromodule] = ACTIONS(4696),
    [anon_sym_endinterface] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_endprogram] = ACTIONS(4696),
    [anon_sym_program] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_package] = ACTIONS(4696),
    [anon_sym_endpackage] = ACTIONS(4696),
    [anon_sym_timeunit] = ACTIONS(4696),
    [anon_sym_timeprecision] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_input] = ACTIONS(4696),
    [anon_sym_output] = ACTIONS(4696),
    [anon_sym_inout] = ACTIONS(4696),
    [anon_sym_ref] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_specparam] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_modport] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_primitive] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_specify] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [939] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(819),
    [sym_elaboration_system_task] = STATE(5643),
    [sym__module_or_generate_item_declaration] = STATE(5643),
    [sym_non_port_program_item] = STATE(828),
    [sym__program_generate_item] = STATE(5643),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5643),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5643),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5643),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_generate_region] = STATE(5643),
    [sym_loop_generate_construct] = STATE(5643),
    [sym__conditional_generate_construct] = STATE(5643),
    [sym_if_generate_construct] = STATE(5643),
    [sym_case_generate_construct] = STATE(5643),
    [sym_continuous_assign] = STATE(5643),
    [sym_initial_construct] = STATE(5643),
    [sym_final_construct] = STATE(5643),
    [sym_clocking_declaration] = STATE(5643),
    [sym_attribute_instance] = STATE(1501),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(1501),
    [aux_sym_program_declaration_repeat2] = STATE(828),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_endprogram] = ACTIONS(3683),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(137),
    [anon_sym_DOLLARerror] = ACTIONS(139),
    [anon_sym_DOLLARwarning] = ACTIONS(139),
    [anon_sym_DOLLARinfo] = ACTIONS(139),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(167),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_generate] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(187),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [940] = {
    [sym_simple_identifier] = ACTIONS(5454),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5456),
    [anon_sym_RPAREN] = ACTIONS(5456),
    [anon_sym_COMMA] = ACTIONS(5456),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5456),
    [anon_sym_BQUOTE] = ACTIONS(5454),
    [aux_sym_id_directive_token1] = ACTIONS(5456),
    [aux_sym_id_directive_token2] = ACTIONS(5456),
    [aux_sym_id_directive_token3] = ACTIONS(5456),
    [aux_sym_id_directive_token4] = ACTIONS(5454),
    [aux_sym_zero_directive_token1] = ACTIONS(5456),
    [aux_sym_zero_directive_token2] = ACTIONS(5456),
    [aux_sym_zero_directive_token3] = ACTIONS(5456),
    [aux_sym_zero_directive_token4] = ACTIONS(5456),
    [aux_sym_zero_directive_token5] = ACTIONS(5456),
    [aux_sym_zero_directive_token6] = ACTIONS(5456),
    [aux_sym_zero_directive_token7] = ACTIONS(5456),
    [aux_sym_zero_directive_token8] = ACTIONS(5456),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5456),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5456),
    [anon_sym_wire] = ACTIONS(5454),
    [anon_sym_tri] = ACTIONS(5454),
    [anon_sym_tri0] = ACTIONS(5454),
    [anon_sym_tri1] = ACTIONS(5454),
    [anon_sym_wand] = ACTIONS(5454),
    [anon_sym_triand] = ACTIONS(5454),
    [anon_sym_wor] = ACTIONS(5454),
    [anon_sym_trior] = ACTIONS(5454),
    [anon_sym_trireg] = ACTIONS(5454),
    [anon_sym_uwire] = ACTIONS(5454),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5456),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5456),
    [aux_sym_begin_keywords_token1] = ACTIONS(5456),
    [anon_sym_SEMI] = ACTIONS(5456),
    [anon_sym_endmodule] = ACTIONS(5454),
    [anon_sym_extern] = ACTIONS(5454),
    [anon_sym_module] = ACTIONS(5454),
    [anon_sym_macromodule] = ACTIONS(5454),
    [anon_sym_endinterface] = ACTIONS(5454),
    [anon_sym_interface] = ACTIONS(5454),
    [anon_sym_endprogram] = ACTIONS(5454),
    [anon_sym_program] = ACTIONS(5454),
    [anon_sym_checker] = ACTIONS(5454),
    [anon_sym_virtual] = ACTIONS(5454),
    [anon_sym_class] = ACTIONS(5454),
    [anon_sym_timeunit] = ACTIONS(5454),
    [anon_sym_timeprecision] = ACTIONS(5454),
    [anon_sym_type] = ACTIONS(5454),
    [anon_sym_input] = ACTIONS(5454),
    [anon_sym_output] = ACTIONS(5454),
    [anon_sym_inout] = ACTIONS(5454),
    [anon_sym_ref] = ACTIONS(5454),
    [anon_sym_DOLLARfatal] = ACTIONS(5456),
    [anon_sym_DOLLARerror] = ACTIONS(5456),
    [anon_sym_DOLLARwarning] = ACTIONS(5456),
    [anon_sym_DOLLARinfo] = ACTIONS(5456),
    [anon_sym_default] = ACTIONS(5454),
    [anon_sym_clocking] = ACTIONS(5454),
    [anon_sym_defparam] = ACTIONS(5454),
    [anon_sym_bind] = ACTIONS(5454),
    [anon_sym_const] = ACTIONS(5454),
    [anon_sym_function] = ACTIONS(5454),
    [anon_sym_static] = ACTIONS(5454),
    [anon_sym_constraint] = ACTIONS(5454),
    [anon_sym_if] = ACTIONS(5454),
    [anon_sym_else] = ACTIONS(5454),
    [anon_sym_LBRACK] = ACTIONS(5456),
    [anon_sym_localparam] = ACTIONS(5454),
    [anon_sym_parameter] = ACTIONS(5454),
    [anon_sym_specparam] = ACTIONS(5454),
    [anon_sym_var] = ACTIONS(5454),
    [anon_sym_import] = ACTIONS(5454),
    [anon_sym_export] = ACTIONS(5454),
    [anon_sym_genvar] = ACTIONS(5454),
    [anon_sym_interconnect] = ACTIONS(5454),
    [anon_sym_typedef] = ACTIONS(5454),
    [anon_sym_enum] = ACTIONS(5454),
    [anon_sym_struct] = ACTIONS(5454),
    [anon_sym_union] = ACTIONS(5454),
    [anon_sym_nettype] = ACTIONS(5454),
    [anon_sym_automatic] = ACTIONS(5454),
    [anon_sym_string] = ACTIONS(5454),
    [anon_sym_chandle] = ACTIONS(5454),
    [anon_sym_event] = ACTIONS(5454),
    [anon_sym_byte] = ACTIONS(5454),
    [anon_sym_shortint] = ACTIONS(5454),
    [anon_sym_int] = ACTIONS(5454),
    [anon_sym_longint] = ACTIONS(5454),
    [anon_sym_integer] = ACTIONS(5454),
    [anon_sym_time] = ACTIONS(5454),
    [anon_sym_bit] = ACTIONS(5454),
    [anon_sym_logic] = ACTIONS(5454),
    [anon_sym_reg] = ACTIONS(5454),
    [anon_sym_shortreal] = ACTIONS(5454),
    [anon_sym_real] = ACTIONS(5454),
    [anon_sym_realtime] = ACTIONS(5454),
    [anon_sym_supply0] = ACTIONS(5454),
    [anon_sym_supply1] = ACTIONS(5454),
    [anon_sym_signed] = ACTIONS(5454),
    [anon_sym_unsigned] = ACTIONS(5454),
    [anon_sym_task] = ACTIONS(5454),
    [anon_sym_modport] = ACTIONS(5454),
    [anon_sym_assert] = ACTIONS(5454),
    [anon_sym_property] = ACTIONS(5454),
    [anon_sym_assume] = ACTIONS(5454),
    [anon_sym_cover] = ACTIONS(5454),
    [anon_sym_sequence] = ACTIONS(5454),
    [anon_sym_restrict] = ACTIONS(5454),
    [anon_sym_not] = ACTIONS(5454),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_and] = ACTIONS(5454),
    [anon_sym_case] = ACTIONS(5454),
    [anon_sym_always] = ACTIONS(5454),
    [anon_sym_covergroup] = ACTIONS(5454),
    [anon_sym_let] = ACTIONS(5454),
    [anon_sym_pulldown] = ACTIONS(5454),
    [anon_sym_pullup] = ACTIONS(5454),
    [anon_sym_cmos] = ACTIONS(5454),
    [anon_sym_rcmos] = ACTIONS(5454),
    [anon_sym_bufif0] = ACTIONS(5454),
    [anon_sym_bufif1] = ACTIONS(5454),
    [anon_sym_notif0] = ACTIONS(5454),
    [anon_sym_notif1] = ACTIONS(5454),
    [anon_sym_nmos] = ACTIONS(5454),
    [anon_sym_pmos] = ACTIONS(5454),
    [anon_sym_rnmos] = ACTIONS(5454),
    [anon_sym_rpmos] = ACTIONS(5454),
    [anon_sym_nand] = ACTIONS(5454),
    [anon_sym_nor] = ACTIONS(5454),
    [anon_sym_xor] = ACTIONS(5454),
    [anon_sym_xnor] = ACTIONS(5454),
    [anon_sym_buf] = ACTIONS(5454),
    [anon_sym_tranif0] = ACTIONS(5454),
    [anon_sym_tranif1] = ACTIONS(5454),
    [anon_sym_rtranif1] = ACTIONS(5454),
    [anon_sym_rtranif0] = ACTIONS(5454),
    [anon_sym_tran] = ACTIONS(5454),
    [anon_sym_rtran] = ACTIONS(5454),
    [anon_sym_generate] = ACTIONS(5454),
    [anon_sym_for] = ACTIONS(5454),
    [anon_sym_initial] = ACTIONS(5454),
    [anon_sym_assign] = ACTIONS(5454),
    [anon_sym_alias] = ACTIONS(5454),
    [anon_sym_always_comb] = ACTIONS(5454),
    [anon_sym_always_latch] = ACTIONS(5454),
    [anon_sym_always_ff] = ACTIONS(5454),
    [anon_sym_final] = ACTIONS(5454),
    [anon_sym_AT] = ACTIONS(5456),
    [anon_sym_global] = ACTIONS(5454),
    [anon_sym_specify] = ACTIONS(5454),
    [anon_sym_LPAREN_STAR] = ACTIONS(5456),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5456),
    [anon_sym_DOLLARunit] = ACTIONS(5456),
  },
  [941] = {
    [ts_builtin_sym_end] = ACTIONS(5458),
    [sym_simple_identifier] = ACTIONS(5460),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5458),
    [anon_sym_RPAREN] = ACTIONS(5458),
    [anon_sym_COMMA] = ACTIONS(5458),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5458),
    [anon_sym_BQUOTE] = ACTIONS(5460),
    [aux_sym_id_directive_token1] = ACTIONS(5458),
    [aux_sym_id_directive_token2] = ACTIONS(5458),
    [aux_sym_id_directive_token3] = ACTIONS(5458),
    [aux_sym_id_directive_token4] = ACTIONS(5460),
    [aux_sym_zero_directive_token1] = ACTIONS(5458),
    [aux_sym_zero_directive_token2] = ACTIONS(5458),
    [aux_sym_zero_directive_token3] = ACTIONS(5458),
    [aux_sym_zero_directive_token4] = ACTIONS(5458),
    [aux_sym_zero_directive_token5] = ACTIONS(5458),
    [aux_sym_zero_directive_token6] = ACTIONS(5458),
    [aux_sym_zero_directive_token7] = ACTIONS(5458),
    [aux_sym_zero_directive_token8] = ACTIONS(5458),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5458),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5458),
    [anon_sym_wire] = ACTIONS(5460),
    [anon_sym_tri] = ACTIONS(5460),
    [anon_sym_tri0] = ACTIONS(5460),
    [anon_sym_tri1] = ACTIONS(5460),
    [anon_sym_wand] = ACTIONS(5460),
    [anon_sym_triand] = ACTIONS(5460),
    [anon_sym_wor] = ACTIONS(5460),
    [anon_sym_trior] = ACTIONS(5460),
    [anon_sym_trireg] = ACTIONS(5460),
    [anon_sym_uwire] = ACTIONS(5460),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5458),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5458),
    [aux_sym_begin_keywords_token1] = ACTIONS(5458),
    [anon_sym_SEMI] = ACTIONS(5458),
    [anon_sym_endmodule] = ACTIONS(5460),
    [anon_sym_extern] = ACTIONS(5460),
    [anon_sym_module] = ACTIONS(5460),
    [anon_sym_macromodule] = ACTIONS(5460),
    [anon_sym_interface] = ACTIONS(5460),
    [anon_sym_program] = ACTIONS(5460),
    [anon_sym_checker] = ACTIONS(5460),
    [anon_sym_virtual] = ACTIONS(5460),
    [anon_sym_class] = ACTIONS(5460),
    [anon_sym_package] = ACTIONS(5460),
    [anon_sym_timeunit] = ACTIONS(5460),
    [anon_sym_timeprecision] = ACTIONS(5460),
    [anon_sym_type] = ACTIONS(5460),
    [anon_sym_DOT] = ACTIONS(5458),
    [anon_sym_LBRACE] = ACTIONS(5458),
    [anon_sym_input] = ACTIONS(5460),
    [anon_sym_output] = ACTIONS(5460),
    [anon_sym_inout] = ACTIONS(5460),
    [anon_sym_ref] = ACTIONS(5460),
    [anon_sym_DOLLARfatal] = ACTIONS(5458),
    [anon_sym_DOLLARerror] = ACTIONS(5458),
    [anon_sym_DOLLARwarning] = ACTIONS(5458),
    [anon_sym_DOLLARinfo] = ACTIONS(5458),
    [anon_sym_default] = ACTIONS(5460),
    [anon_sym_clocking] = ACTIONS(5460),
    [anon_sym_defparam] = ACTIONS(5460),
    [anon_sym_bind] = ACTIONS(5460),
    [anon_sym_const] = ACTIONS(5460),
    [anon_sym_function] = ACTIONS(5460),
    [anon_sym_static] = ACTIONS(5460),
    [anon_sym_constraint] = ACTIONS(5460),
    [anon_sym_if] = ACTIONS(5460),
    [anon_sym_LBRACK] = ACTIONS(5458),
    [anon_sym_localparam] = ACTIONS(5460),
    [anon_sym_parameter] = ACTIONS(5460),
    [anon_sym_specparam] = ACTIONS(5460),
    [anon_sym_var] = ACTIONS(5460),
    [anon_sym_import] = ACTIONS(5460),
    [anon_sym_export] = ACTIONS(5460),
    [anon_sym_genvar] = ACTIONS(5460),
    [anon_sym_interconnect] = ACTIONS(5460),
    [anon_sym_typedef] = ACTIONS(5460),
    [anon_sym_enum] = ACTIONS(5460),
    [anon_sym_struct] = ACTIONS(5460),
    [anon_sym_union] = ACTIONS(5460),
    [anon_sym_nettype] = ACTIONS(5460),
    [anon_sym_automatic] = ACTIONS(5460),
    [anon_sym_string] = ACTIONS(5460),
    [anon_sym_chandle] = ACTIONS(5460),
    [anon_sym_event] = ACTIONS(5460),
    [anon_sym_byte] = ACTIONS(5460),
    [anon_sym_shortint] = ACTIONS(5460),
    [anon_sym_int] = ACTIONS(5460),
    [anon_sym_longint] = ACTIONS(5460),
    [anon_sym_integer] = ACTIONS(5460),
    [anon_sym_time] = ACTIONS(5460),
    [anon_sym_bit] = ACTIONS(5460),
    [anon_sym_logic] = ACTIONS(5460),
    [anon_sym_reg] = ACTIONS(5460),
    [anon_sym_shortreal] = ACTIONS(5460),
    [anon_sym_real] = ACTIONS(5460),
    [anon_sym_realtime] = ACTIONS(5460),
    [anon_sym_supply0] = ACTIONS(5460),
    [anon_sym_supply1] = ACTIONS(5460),
    [anon_sym_signed] = ACTIONS(5460),
    [anon_sym_unsigned] = ACTIONS(5460),
    [anon_sym_task] = ACTIONS(5460),
    [anon_sym_assert] = ACTIONS(5460),
    [anon_sym_property] = ACTIONS(5460),
    [anon_sym_assume] = ACTIONS(5460),
    [anon_sym_cover] = ACTIONS(5460),
    [anon_sym_sequence] = ACTIONS(5460),
    [anon_sym_restrict] = ACTIONS(5460),
    [anon_sym_not] = ACTIONS(5460),
    [anon_sym_or] = ACTIONS(5460),
    [anon_sym_and] = ACTIONS(5460),
    [anon_sym_case] = ACTIONS(5460),
    [anon_sym_always] = ACTIONS(5460),
    [anon_sym_covergroup] = ACTIONS(5460),
    [anon_sym_let] = ACTIONS(5460),
    [anon_sym_pulldown] = ACTIONS(5460),
    [anon_sym_pullup] = ACTIONS(5460),
    [anon_sym_cmos] = ACTIONS(5460),
    [anon_sym_rcmos] = ACTIONS(5460),
    [anon_sym_bufif0] = ACTIONS(5460),
    [anon_sym_bufif1] = ACTIONS(5460),
    [anon_sym_notif0] = ACTIONS(5460),
    [anon_sym_notif1] = ACTIONS(5460),
    [anon_sym_nmos] = ACTIONS(5460),
    [anon_sym_pmos] = ACTIONS(5460),
    [anon_sym_rnmos] = ACTIONS(5460),
    [anon_sym_rpmos] = ACTIONS(5460),
    [anon_sym_nand] = ACTIONS(5460),
    [anon_sym_nor] = ACTIONS(5460),
    [anon_sym_xor] = ACTIONS(5460),
    [anon_sym_xnor] = ACTIONS(5460),
    [anon_sym_buf] = ACTIONS(5460),
    [anon_sym_tranif0] = ACTIONS(5460),
    [anon_sym_tranif1] = ACTIONS(5460),
    [anon_sym_rtranif1] = ACTIONS(5460),
    [anon_sym_rtranif0] = ACTIONS(5460),
    [anon_sym_tran] = ACTIONS(5460),
    [anon_sym_rtran] = ACTIONS(5460),
    [anon_sym_generate] = ACTIONS(5460),
    [anon_sym_for] = ACTIONS(5460),
    [anon_sym_primitive] = ACTIONS(5460),
    [anon_sym_initial] = ACTIONS(5460),
    [anon_sym_assign] = ACTIONS(5460),
    [anon_sym_alias] = ACTIONS(5460),
    [anon_sym_always_comb] = ACTIONS(5460),
    [anon_sym_always_latch] = ACTIONS(5460),
    [anon_sym_always_ff] = ACTIONS(5460),
    [anon_sym_final] = ACTIONS(5460),
    [anon_sym_global] = ACTIONS(5460),
    [anon_sym_specify] = ACTIONS(5460),
    [anon_sym_LPAREN_STAR] = ACTIONS(5458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5458),
    [anon_sym_DOLLARunit] = ACTIONS(5458),
  },
  [942] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8793),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_SEMI] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2648),
    [anon_sym_RBRACE] = ACTIONS(2648),
    [anon_sym_iff] = ACTIONS(2644),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_u2013_GT] = ACTIONS(2648),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_dist] = ACTIONS(2644),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [943] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8834),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_LBRACK_STAR] = ACTIONS(2648),
    [anon_sym_LBRACK_EQ] = ACTIONS(2648),
    [anon_sym_EQ_GT] = ACTIONS(2648),
    [anon_sym_LBRACKu2013_GT] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [944] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17057),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17057),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [945] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17236),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17236),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [946] = {
    [ts_builtin_sym_end] = ACTIONS(5466),
    [sym_simple_identifier] = ACTIONS(5468),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5466),
    [anon_sym_BQUOTE] = ACTIONS(5468),
    [aux_sym_id_directive_token1] = ACTIONS(5466),
    [aux_sym_id_directive_token2] = ACTIONS(5466),
    [aux_sym_id_directive_token3] = ACTIONS(5466),
    [aux_sym_id_directive_token4] = ACTIONS(5468),
    [aux_sym_zero_directive_token1] = ACTIONS(5466),
    [aux_sym_zero_directive_token2] = ACTIONS(5466),
    [aux_sym_zero_directive_token3] = ACTIONS(5466),
    [aux_sym_zero_directive_token4] = ACTIONS(5466),
    [aux_sym_zero_directive_token5] = ACTIONS(5466),
    [aux_sym_zero_directive_token6] = ACTIONS(5466),
    [aux_sym_zero_directive_token7] = ACTIONS(5466),
    [aux_sym_zero_directive_token8] = ACTIONS(5466),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5466),
    [anon_sym_wire] = ACTIONS(5468),
    [anon_sym_tri] = ACTIONS(5468),
    [anon_sym_tri0] = ACTIONS(5468),
    [anon_sym_tri1] = ACTIONS(5468),
    [anon_sym_wand] = ACTIONS(5468),
    [anon_sym_triand] = ACTIONS(5468),
    [anon_sym_wor] = ACTIONS(5468),
    [anon_sym_trior] = ACTIONS(5468),
    [anon_sym_trireg] = ACTIONS(5468),
    [anon_sym_uwire] = ACTIONS(5468),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5466),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_begin_keywords_token1] = ACTIONS(5466),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_endmodule] = ACTIONS(5468),
    [anon_sym_extern] = ACTIONS(5468),
    [anon_sym_module] = ACTIONS(5468),
    [anon_sym_macromodule] = ACTIONS(5468),
    [anon_sym_endinterface] = ACTIONS(5468),
    [anon_sym_interface] = ACTIONS(5468),
    [anon_sym_endprogram] = ACTIONS(5468),
    [anon_sym_program] = ACTIONS(5468),
    [anon_sym_checker] = ACTIONS(5468),
    [anon_sym_virtual] = ACTIONS(5468),
    [anon_sym_class] = ACTIONS(5468),
    [anon_sym_package] = ACTIONS(5468),
    [anon_sym_endpackage] = ACTIONS(5468),
    [anon_sym_timeunit] = ACTIONS(5468),
    [anon_sym_timeprecision] = ACTIONS(5468),
    [anon_sym_type] = ACTIONS(5468),
    [anon_sym_input] = ACTIONS(5468),
    [anon_sym_output] = ACTIONS(5468),
    [anon_sym_inout] = ACTIONS(5468),
    [anon_sym_ref] = ACTIONS(5468),
    [anon_sym_DOLLARfatal] = ACTIONS(5466),
    [anon_sym_DOLLARerror] = ACTIONS(5466),
    [anon_sym_DOLLARwarning] = ACTIONS(5466),
    [anon_sym_DOLLARinfo] = ACTIONS(5466),
    [anon_sym_default] = ACTIONS(5468),
    [anon_sym_clocking] = ACTIONS(5468),
    [anon_sym_defparam] = ACTIONS(5468),
    [anon_sym_bind] = ACTIONS(5468),
    [anon_sym_const] = ACTIONS(5468),
    [anon_sym_function] = ACTIONS(5468),
    [anon_sym_static] = ACTIONS(5468),
    [anon_sym_constraint] = ACTIONS(5468),
    [anon_sym_if] = ACTIONS(5468),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_localparam] = ACTIONS(5468),
    [anon_sym_parameter] = ACTIONS(5468),
    [anon_sym_specparam] = ACTIONS(5468),
    [anon_sym_var] = ACTIONS(5468),
    [anon_sym_import] = ACTIONS(5468),
    [anon_sym_export] = ACTIONS(5468),
    [anon_sym_genvar] = ACTIONS(5468),
    [anon_sym_interconnect] = ACTIONS(5468),
    [anon_sym_typedef] = ACTIONS(5468),
    [anon_sym_enum] = ACTIONS(5468),
    [anon_sym_struct] = ACTIONS(5468),
    [anon_sym_union] = ACTIONS(5468),
    [anon_sym_nettype] = ACTIONS(5468),
    [anon_sym_automatic] = ACTIONS(5468),
    [anon_sym_string] = ACTIONS(5468),
    [anon_sym_chandle] = ACTIONS(5468),
    [anon_sym_event] = ACTIONS(5468),
    [anon_sym_byte] = ACTIONS(5468),
    [anon_sym_shortint] = ACTIONS(5468),
    [anon_sym_int] = ACTIONS(5468),
    [anon_sym_longint] = ACTIONS(5468),
    [anon_sym_integer] = ACTIONS(5468),
    [anon_sym_time] = ACTIONS(5468),
    [anon_sym_bit] = ACTIONS(5468),
    [anon_sym_logic] = ACTIONS(5468),
    [anon_sym_reg] = ACTIONS(5468),
    [anon_sym_shortreal] = ACTIONS(5468),
    [anon_sym_real] = ACTIONS(5468),
    [anon_sym_realtime] = ACTIONS(5468),
    [anon_sym_supply0] = ACTIONS(5468),
    [anon_sym_supply1] = ACTIONS(5468),
    [anon_sym_signed] = ACTIONS(5468),
    [anon_sym_unsigned] = ACTIONS(5468),
    [anon_sym_task] = ACTIONS(5468),
    [anon_sym_modport] = ACTIONS(5468),
    [anon_sym_assert] = ACTIONS(5468),
    [anon_sym_property] = ACTIONS(5468),
    [anon_sym_assume] = ACTIONS(5468),
    [anon_sym_cover] = ACTIONS(5468),
    [anon_sym_sequence] = ACTIONS(5468),
    [anon_sym_restrict] = ACTIONS(5468),
    [anon_sym_not] = ACTIONS(5468),
    [anon_sym_or] = ACTIONS(5468),
    [anon_sym_and] = ACTIONS(5468),
    [anon_sym_case] = ACTIONS(5468),
    [anon_sym_always] = ACTIONS(5468),
    [anon_sym_covergroup] = ACTIONS(5468),
    [anon_sym_let] = ACTIONS(5468),
    [anon_sym_pulldown] = ACTIONS(5468),
    [anon_sym_pullup] = ACTIONS(5468),
    [anon_sym_cmos] = ACTIONS(5468),
    [anon_sym_rcmos] = ACTIONS(5468),
    [anon_sym_bufif0] = ACTIONS(5468),
    [anon_sym_bufif1] = ACTIONS(5468),
    [anon_sym_notif0] = ACTIONS(5468),
    [anon_sym_notif1] = ACTIONS(5468),
    [anon_sym_nmos] = ACTIONS(5468),
    [anon_sym_pmos] = ACTIONS(5468),
    [anon_sym_rnmos] = ACTIONS(5468),
    [anon_sym_rpmos] = ACTIONS(5468),
    [anon_sym_nand] = ACTIONS(5468),
    [anon_sym_nor] = ACTIONS(5468),
    [anon_sym_xor] = ACTIONS(5468),
    [anon_sym_xnor] = ACTIONS(5468),
    [anon_sym_buf] = ACTIONS(5468),
    [anon_sym_tranif0] = ACTIONS(5468),
    [anon_sym_tranif1] = ACTIONS(5468),
    [anon_sym_rtranif1] = ACTIONS(5468),
    [anon_sym_rtranif0] = ACTIONS(5468),
    [anon_sym_tran] = ACTIONS(5468),
    [anon_sym_rtran] = ACTIONS(5468),
    [anon_sym_generate] = ACTIONS(5468),
    [anon_sym_for] = ACTIONS(5468),
    [anon_sym_primitive] = ACTIONS(5468),
    [anon_sym_initial] = ACTIONS(5468),
    [anon_sym_assign] = ACTIONS(5468),
    [anon_sym_alias] = ACTIONS(5468),
    [anon_sym_always_comb] = ACTIONS(5468),
    [anon_sym_always_latch] = ACTIONS(5468),
    [anon_sym_always_ff] = ACTIONS(5468),
    [anon_sym_final] = ACTIONS(5468),
    [anon_sym_global] = ACTIONS(5468),
    [anon_sym_specify] = ACTIONS(5468),
    [anon_sym_LPAREN_STAR] = ACTIONS(5466),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5466),
    [anon_sym_DOLLARunit] = ACTIONS(5466),
  },
  [947] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17032),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17032),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [948] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17041),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17041),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [949] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17141),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17141),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [950] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17142),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17142),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [951] = {
    [ts_builtin_sym_end] = ACTIONS(5466),
    [sym_simple_identifier] = ACTIONS(5468),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5466),
    [anon_sym_BQUOTE] = ACTIONS(5468),
    [aux_sym_id_directive_token1] = ACTIONS(5466),
    [aux_sym_id_directive_token2] = ACTIONS(5466),
    [aux_sym_id_directive_token3] = ACTIONS(5466),
    [aux_sym_id_directive_token4] = ACTIONS(5468),
    [aux_sym_zero_directive_token1] = ACTIONS(5466),
    [aux_sym_zero_directive_token2] = ACTIONS(5466),
    [aux_sym_zero_directive_token3] = ACTIONS(5466),
    [aux_sym_zero_directive_token4] = ACTIONS(5466),
    [aux_sym_zero_directive_token5] = ACTIONS(5466),
    [aux_sym_zero_directive_token6] = ACTIONS(5466),
    [aux_sym_zero_directive_token7] = ACTIONS(5466),
    [aux_sym_zero_directive_token8] = ACTIONS(5466),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5466),
    [anon_sym_wire] = ACTIONS(5468),
    [anon_sym_tri] = ACTIONS(5468),
    [anon_sym_tri0] = ACTIONS(5468),
    [anon_sym_tri1] = ACTIONS(5468),
    [anon_sym_wand] = ACTIONS(5468),
    [anon_sym_triand] = ACTIONS(5468),
    [anon_sym_wor] = ACTIONS(5468),
    [anon_sym_trior] = ACTIONS(5468),
    [anon_sym_trireg] = ACTIONS(5468),
    [anon_sym_uwire] = ACTIONS(5468),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5466),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5466),
    [aux_sym_begin_keywords_token1] = ACTIONS(5466),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_endmodule] = ACTIONS(5468),
    [anon_sym_extern] = ACTIONS(5468),
    [anon_sym_module] = ACTIONS(5468),
    [anon_sym_macromodule] = ACTIONS(5468),
    [anon_sym_endinterface] = ACTIONS(5468),
    [anon_sym_interface] = ACTIONS(5468),
    [anon_sym_endprogram] = ACTIONS(5468),
    [anon_sym_program] = ACTIONS(5468),
    [anon_sym_checker] = ACTIONS(5468),
    [anon_sym_virtual] = ACTIONS(5468),
    [anon_sym_class] = ACTIONS(5468),
    [anon_sym_package] = ACTIONS(5468),
    [anon_sym_endpackage] = ACTIONS(5468),
    [anon_sym_timeunit] = ACTIONS(5468),
    [anon_sym_timeprecision] = ACTIONS(5468),
    [anon_sym_type] = ACTIONS(5468),
    [anon_sym_input] = ACTIONS(5468),
    [anon_sym_output] = ACTIONS(5468),
    [anon_sym_inout] = ACTIONS(5468),
    [anon_sym_ref] = ACTIONS(5468),
    [anon_sym_DOLLARfatal] = ACTIONS(5466),
    [anon_sym_DOLLARerror] = ACTIONS(5466),
    [anon_sym_DOLLARwarning] = ACTIONS(5466),
    [anon_sym_DOLLARinfo] = ACTIONS(5466),
    [anon_sym_default] = ACTIONS(5468),
    [anon_sym_clocking] = ACTIONS(5468),
    [anon_sym_defparam] = ACTIONS(5468),
    [anon_sym_bind] = ACTIONS(5468),
    [anon_sym_const] = ACTIONS(5468),
    [anon_sym_function] = ACTIONS(5468),
    [anon_sym_static] = ACTIONS(5468),
    [anon_sym_constraint] = ACTIONS(5468),
    [anon_sym_if] = ACTIONS(5468),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_localparam] = ACTIONS(5468),
    [anon_sym_parameter] = ACTIONS(5468),
    [anon_sym_specparam] = ACTIONS(5468),
    [anon_sym_var] = ACTIONS(5468),
    [anon_sym_import] = ACTIONS(5468),
    [anon_sym_export] = ACTIONS(5468),
    [anon_sym_genvar] = ACTIONS(5468),
    [anon_sym_interconnect] = ACTIONS(5468),
    [anon_sym_typedef] = ACTIONS(5468),
    [anon_sym_enum] = ACTIONS(5468),
    [anon_sym_struct] = ACTIONS(5468),
    [anon_sym_union] = ACTIONS(5468),
    [anon_sym_nettype] = ACTIONS(5468),
    [anon_sym_automatic] = ACTIONS(5468),
    [anon_sym_string] = ACTIONS(5468),
    [anon_sym_chandle] = ACTIONS(5468),
    [anon_sym_event] = ACTIONS(5468),
    [anon_sym_byte] = ACTIONS(5468),
    [anon_sym_shortint] = ACTIONS(5468),
    [anon_sym_int] = ACTIONS(5468),
    [anon_sym_longint] = ACTIONS(5468),
    [anon_sym_integer] = ACTIONS(5468),
    [anon_sym_time] = ACTIONS(5468),
    [anon_sym_bit] = ACTIONS(5468),
    [anon_sym_logic] = ACTIONS(5468),
    [anon_sym_reg] = ACTIONS(5468),
    [anon_sym_shortreal] = ACTIONS(5468),
    [anon_sym_real] = ACTIONS(5468),
    [anon_sym_realtime] = ACTIONS(5468),
    [anon_sym_supply0] = ACTIONS(5468),
    [anon_sym_supply1] = ACTIONS(5468),
    [anon_sym_signed] = ACTIONS(5468),
    [anon_sym_unsigned] = ACTIONS(5468),
    [anon_sym_task] = ACTIONS(5468),
    [anon_sym_modport] = ACTIONS(5468),
    [anon_sym_assert] = ACTIONS(5468),
    [anon_sym_property] = ACTIONS(5468),
    [anon_sym_assume] = ACTIONS(5468),
    [anon_sym_cover] = ACTIONS(5468),
    [anon_sym_sequence] = ACTIONS(5468),
    [anon_sym_restrict] = ACTIONS(5468),
    [anon_sym_not] = ACTIONS(5468),
    [anon_sym_or] = ACTIONS(5468),
    [anon_sym_and] = ACTIONS(5468),
    [anon_sym_case] = ACTIONS(5468),
    [anon_sym_always] = ACTIONS(5468),
    [anon_sym_covergroup] = ACTIONS(5468),
    [anon_sym_let] = ACTIONS(5468),
    [anon_sym_pulldown] = ACTIONS(5468),
    [anon_sym_pullup] = ACTIONS(5468),
    [anon_sym_cmos] = ACTIONS(5468),
    [anon_sym_rcmos] = ACTIONS(5468),
    [anon_sym_bufif0] = ACTIONS(5468),
    [anon_sym_bufif1] = ACTIONS(5468),
    [anon_sym_notif0] = ACTIONS(5468),
    [anon_sym_notif1] = ACTIONS(5468),
    [anon_sym_nmos] = ACTIONS(5468),
    [anon_sym_pmos] = ACTIONS(5468),
    [anon_sym_rnmos] = ACTIONS(5468),
    [anon_sym_rpmos] = ACTIONS(5468),
    [anon_sym_nand] = ACTIONS(5468),
    [anon_sym_nor] = ACTIONS(5468),
    [anon_sym_xor] = ACTIONS(5468),
    [anon_sym_xnor] = ACTIONS(5468),
    [anon_sym_buf] = ACTIONS(5468),
    [anon_sym_tranif0] = ACTIONS(5468),
    [anon_sym_tranif1] = ACTIONS(5468),
    [anon_sym_rtranif1] = ACTIONS(5468),
    [anon_sym_rtranif0] = ACTIONS(5468),
    [anon_sym_tran] = ACTIONS(5468),
    [anon_sym_rtran] = ACTIONS(5468),
    [anon_sym_generate] = ACTIONS(5468),
    [anon_sym_for] = ACTIONS(5468),
    [anon_sym_primitive] = ACTIONS(5468),
    [anon_sym_initial] = ACTIONS(5468),
    [anon_sym_assign] = ACTIONS(5468),
    [anon_sym_alias] = ACTIONS(5468),
    [anon_sym_always_comb] = ACTIONS(5468),
    [anon_sym_always_latch] = ACTIONS(5468),
    [anon_sym_always_ff] = ACTIONS(5468),
    [anon_sym_final] = ACTIONS(5468),
    [anon_sym_global] = ACTIONS(5468),
    [anon_sym_specify] = ACTIONS(5468),
    [anon_sym_LPAREN_STAR] = ACTIONS(5466),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5466),
    [anon_sym_DOLLARunit] = ACTIONS(5466),
  },
  [952] = {
    [ts_builtin_sym_end] = ACTIONS(5470),
    [sym_simple_identifier] = ACTIONS(5472),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5470),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5470),
    [anon_sym_BQUOTE] = ACTIONS(5472),
    [aux_sym_id_directive_token1] = ACTIONS(5470),
    [aux_sym_id_directive_token2] = ACTIONS(5470),
    [aux_sym_id_directive_token3] = ACTIONS(5470),
    [aux_sym_id_directive_token4] = ACTIONS(5472),
    [aux_sym_zero_directive_token1] = ACTIONS(5470),
    [aux_sym_zero_directive_token2] = ACTIONS(5470),
    [aux_sym_zero_directive_token3] = ACTIONS(5470),
    [aux_sym_zero_directive_token4] = ACTIONS(5470),
    [aux_sym_zero_directive_token5] = ACTIONS(5470),
    [aux_sym_zero_directive_token6] = ACTIONS(5470),
    [aux_sym_zero_directive_token7] = ACTIONS(5470),
    [aux_sym_zero_directive_token8] = ACTIONS(5470),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5470),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5470),
    [anon_sym_wire] = ACTIONS(5472),
    [anon_sym_tri] = ACTIONS(5472),
    [anon_sym_tri0] = ACTIONS(5472),
    [anon_sym_tri1] = ACTIONS(5472),
    [anon_sym_wand] = ACTIONS(5472),
    [anon_sym_triand] = ACTIONS(5472),
    [anon_sym_wor] = ACTIONS(5472),
    [anon_sym_trior] = ACTIONS(5472),
    [anon_sym_trireg] = ACTIONS(5472),
    [anon_sym_uwire] = ACTIONS(5472),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5470),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5470),
    [aux_sym_begin_keywords_token1] = ACTIONS(5470),
    [anon_sym_SEMI] = ACTIONS(5470),
    [anon_sym_endmodule] = ACTIONS(5472),
    [anon_sym_extern] = ACTIONS(5472),
    [anon_sym_module] = ACTIONS(5472),
    [anon_sym_macromodule] = ACTIONS(5472),
    [anon_sym_endinterface] = ACTIONS(5472),
    [anon_sym_interface] = ACTIONS(5472),
    [anon_sym_endprogram] = ACTIONS(5472),
    [anon_sym_program] = ACTIONS(5472),
    [anon_sym_checker] = ACTIONS(5472),
    [anon_sym_virtual] = ACTIONS(5472),
    [anon_sym_class] = ACTIONS(5472),
    [anon_sym_package] = ACTIONS(5472),
    [anon_sym_endpackage] = ACTIONS(5472),
    [anon_sym_timeunit] = ACTIONS(5472),
    [anon_sym_timeprecision] = ACTIONS(5472),
    [anon_sym_type] = ACTIONS(5472),
    [anon_sym_input] = ACTIONS(5472),
    [anon_sym_output] = ACTIONS(5472),
    [anon_sym_inout] = ACTIONS(5472),
    [anon_sym_ref] = ACTIONS(5472),
    [anon_sym_DOLLARfatal] = ACTIONS(5470),
    [anon_sym_DOLLARerror] = ACTIONS(5470),
    [anon_sym_DOLLARwarning] = ACTIONS(5470),
    [anon_sym_DOLLARinfo] = ACTIONS(5470),
    [anon_sym_default] = ACTIONS(5472),
    [anon_sym_clocking] = ACTIONS(5472),
    [anon_sym_defparam] = ACTIONS(5472),
    [anon_sym_bind] = ACTIONS(5472),
    [anon_sym_const] = ACTIONS(5472),
    [anon_sym_function] = ACTIONS(5472),
    [anon_sym_static] = ACTIONS(5472),
    [anon_sym_constraint] = ACTIONS(5472),
    [anon_sym_if] = ACTIONS(5472),
    [anon_sym_LBRACK] = ACTIONS(5470),
    [anon_sym_localparam] = ACTIONS(5472),
    [anon_sym_parameter] = ACTIONS(5472),
    [anon_sym_specparam] = ACTIONS(5472),
    [anon_sym_var] = ACTIONS(5472),
    [anon_sym_import] = ACTIONS(5472),
    [anon_sym_export] = ACTIONS(5472),
    [anon_sym_genvar] = ACTIONS(5472),
    [anon_sym_interconnect] = ACTIONS(5472),
    [anon_sym_typedef] = ACTIONS(5472),
    [anon_sym_enum] = ACTIONS(5472),
    [anon_sym_struct] = ACTIONS(5472),
    [anon_sym_union] = ACTIONS(5472),
    [anon_sym_nettype] = ACTIONS(5472),
    [anon_sym_automatic] = ACTIONS(5472),
    [anon_sym_string] = ACTIONS(5472),
    [anon_sym_chandle] = ACTIONS(5472),
    [anon_sym_event] = ACTIONS(5472),
    [anon_sym_byte] = ACTIONS(5472),
    [anon_sym_shortint] = ACTIONS(5472),
    [anon_sym_int] = ACTIONS(5472),
    [anon_sym_longint] = ACTIONS(5472),
    [anon_sym_integer] = ACTIONS(5472),
    [anon_sym_time] = ACTIONS(5472),
    [anon_sym_bit] = ACTIONS(5472),
    [anon_sym_logic] = ACTIONS(5472),
    [anon_sym_reg] = ACTIONS(5472),
    [anon_sym_shortreal] = ACTIONS(5472),
    [anon_sym_real] = ACTIONS(5472),
    [anon_sym_realtime] = ACTIONS(5472),
    [anon_sym_supply0] = ACTIONS(5472),
    [anon_sym_supply1] = ACTIONS(5472),
    [anon_sym_signed] = ACTIONS(5472),
    [anon_sym_unsigned] = ACTIONS(5472),
    [anon_sym_task] = ACTIONS(5472),
    [anon_sym_modport] = ACTIONS(5472),
    [anon_sym_assert] = ACTIONS(5472),
    [anon_sym_property] = ACTIONS(5472),
    [anon_sym_assume] = ACTIONS(5472),
    [anon_sym_cover] = ACTIONS(5472),
    [anon_sym_sequence] = ACTIONS(5472),
    [anon_sym_restrict] = ACTIONS(5472),
    [anon_sym_not] = ACTIONS(5472),
    [anon_sym_or] = ACTIONS(5472),
    [anon_sym_and] = ACTIONS(5472),
    [anon_sym_case] = ACTIONS(5472),
    [anon_sym_always] = ACTIONS(5472),
    [anon_sym_covergroup] = ACTIONS(5472),
    [anon_sym_let] = ACTIONS(5472),
    [anon_sym_pulldown] = ACTIONS(5472),
    [anon_sym_pullup] = ACTIONS(5472),
    [anon_sym_cmos] = ACTIONS(5472),
    [anon_sym_rcmos] = ACTIONS(5472),
    [anon_sym_bufif0] = ACTIONS(5472),
    [anon_sym_bufif1] = ACTIONS(5472),
    [anon_sym_notif0] = ACTIONS(5472),
    [anon_sym_notif1] = ACTIONS(5472),
    [anon_sym_nmos] = ACTIONS(5472),
    [anon_sym_pmos] = ACTIONS(5472),
    [anon_sym_rnmos] = ACTIONS(5472),
    [anon_sym_rpmos] = ACTIONS(5472),
    [anon_sym_nand] = ACTIONS(5472),
    [anon_sym_nor] = ACTIONS(5472),
    [anon_sym_xor] = ACTIONS(5472),
    [anon_sym_xnor] = ACTIONS(5472),
    [anon_sym_buf] = ACTIONS(5472),
    [anon_sym_tranif0] = ACTIONS(5472),
    [anon_sym_tranif1] = ACTIONS(5472),
    [anon_sym_rtranif1] = ACTIONS(5472),
    [anon_sym_rtranif0] = ACTIONS(5472),
    [anon_sym_tran] = ACTIONS(5472),
    [anon_sym_rtran] = ACTIONS(5472),
    [anon_sym_generate] = ACTIONS(5472),
    [anon_sym_for] = ACTIONS(5472),
    [anon_sym_primitive] = ACTIONS(5472),
    [anon_sym_initial] = ACTIONS(5472),
    [anon_sym_assign] = ACTIONS(5472),
    [anon_sym_alias] = ACTIONS(5472),
    [anon_sym_always_comb] = ACTIONS(5472),
    [anon_sym_always_latch] = ACTIONS(5472),
    [anon_sym_always_ff] = ACTIONS(5472),
    [anon_sym_final] = ACTIONS(5472),
    [anon_sym_global] = ACTIONS(5472),
    [anon_sym_specify] = ACTIONS(5472),
    [anon_sym_LPAREN_STAR] = ACTIONS(5470),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5470),
    [anon_sym_DOLLARunit] = ACTIONS(5470),
  },
  [953] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16849),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16849),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [954] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16851),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16851),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [955] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17220),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17220),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [956] = {
    [ts_builtin_sym_end] = ACTIONS(5474),
    [sym_simple_identifier] = ACTIONS(5476),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5474),
    [anon_sym_LPAREN] = ACTIONS(5476),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5474),
    [anon_sym_BQUOTE] = ACTIONS(5476),
    [aux_sym_id_directive_token1] = ACTIONS(5474),
    [aux_sym_id_directive_token2] = ACTIONS(5474),
    [aux_sym_id_directive_token3] = ACTIONS(5474),
    [aux_sym_id_directive_token4] = ACTIONS(5476),
    [aux_sym_zero_directive_token1] = ACTIONS(5474),
    [aux_sym_zero_directive_token2] = ACTIONS(5474),
    [aux_sym_zero_directive_token3] = ACTIONS(5474),
    [aux_sym_zero_directive_token4] = ACTIONS(5474),
    [aux_sym_zero_directive_token5] = ACTIONS(5474),
    [aux_sym_zero_directive_token6] = ACTIONS(5474),
    [aux_sym_zero_directive_token7] = ACTIONS(5474),
    [aux_sym_zero_directive_token8] = ACTIONS(5474),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5474),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5474),
    [anon_sym_wire] = ACTIONS(5476),
    [anon_sym_tri] = ACTIONS(5476),
    [anon_sym_tri0] = ACTIONS(5476),
    [anon_sym_tri1] = ACTIONS(5476),
    [anon_sym_wand] = ACTIONS(5476),
    [anon_sym_triand] = ACTIONS(5476),
    [anon_sym_wor] = ACTIONS(5476),
    [anon_sym_trior] = ACTIONS(5476),
    [anon_sym_trireg] = ACTIONS(5476),
    [anon_sym_uwire] = ACTIONS(5476),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5474),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5474),
    [aux_sym_begin_keywords_token1] = ACTIONS(5474),
    [anon_sym_SEMI] = ACTIONS(5474),
    [anon_sym_endmodule] = ACTIONS(5476),
    [anon_sym_extern] = ACTIONS(5476),
    [anon_sym_module] = ACTIONS(5476),
    [anon_sym_macromodule] = ACTIONS(5476),
    [anon_sym_interface] = ACTIONS(5476),
    [anon_sym_program] = ACTIONS(5476),
    [anon_sym_checker] = ACTIONS(5476),
    [anon_sym_virtual] = ACTIONS(5476),
    [anon_sym_class] = ACTIONS(5476),
    [anon_sym_extends] = ACTIONS(5476),
    [anon_sym_endclass] = ACTIONS(5476),
    [anon_sym_pure] = ACTIONS(5476),
    [anon_sym_package] = ACTIONS(5476),
    [anon_sym_timeunit] = ACTIONS(5476),
    [anon_sym_timeprecision] = ACTIONS(5476),
    [anon_sym_type] = ACTIONS(5476),
    [anon_sym_input] = ACTIONS(5476),
    [anon_sym_output] = ACTIONS(5476),
    [anon_sym_inout] = ACTIONS(5476),
    [anon_sym_ref] = ACTIONS(5476),
    [anon_sym_DOLLARfatal] = ACTIONS(5474),
    [anon_sym_DOLLARerror] = ACTIONS(5474),
    [anon_sym_DOLLARwarning] = ACTIONS(5474),
    [anon_sym_DOLLARinfo] = ACTIONS(5474),
    [anon_sym_default] = ACTIONS(5476),
    [anon_sym_clocking] = ACTIONS(5476),
    [anon_sym_defparam] = ACTIONS(5476),
    [anon_sym_bind] = ACTIONS(5476),
    [anon_sym_const] = ACTIONS(5476),
    [anon_sym_function] = ACTIONS(5476),
    [anon_sym_static] = ACTIONS(5476),
    [anon_sym_constraint] = ACTIONS(5476),
    [anon_sym_if] = ACTIONS(5476),
    [anon_sym_LBRACK] = ACTIONS(5474),
    [anon_sym_localparam] = ACTIONS(5476),
    [anon_sym_parameter] = ACTIONS(5476),
    [anon_sym_specparam] = ACTIONS(5476),
    [anon_sym_var] = ACTIONS(5476),
    [anon_sym_import] = ACTIONS(5476),
    [anon_sym_export] = ACTIONS(5476),
    [anon_sym_genvar] = ACTIONS(5476),
    [anon_sym_interconnect] = ACTIONS(5476),
    [anon_sym_typedef] = ACTIONS(5476),
    [anon_sym_enum] = ACTIONS(5476),
    [anon_sym_struct] = ACTIONS(5476),
    [anon_sym_union] = ACTIONS(5476),
    [anon_sym_nettype] = ACTIONS(5476),
    [anon_sym_automatic] = ACTIONS(5476),
    [anon_sym_string] = ACTIONS(5476),
    [anon_sym_chandle] = ACTIONS(5476),
    [anon_sym_event] = ACTIONS(5476),
    [anon_sym_byte] = ACTIONS(5476),
    [anon_sym_shortint] = ACTIONS(5476),
    [anon_sym_int] = ACTIONS(5476),
    [anon_sym_longint] = ACTIONS(5476),
    [anon_sym_integer] = ACTIONS(5476),
    [anon_sym_time] = ACTIONS(5476),
    [anon_sym_bit] = ACTIONS(5476),
    [anon_sym_logic] = ACTIONS(5476),
    [anon_sym_reg] = ACTIONS(5476),
    [anon_sym_shortreal] = ACTIONS(5476),
    [anon_sym_real] = ACTIONS(5476),
    [anon_sym_realtime] = ACTIONS(5476),
    [anon_sym_supply0] = ACTIONS(5476),
    [anon_sym_supply1] = ACTIONS(5476),
    [anon_sym_signed] = ACTIONS(5476),
    [anon_sym_unsigned] = ACTIONS(5476),
    [anon_sym_task] = ACTIONS(5476),
    [anon_sym_assert] = ACTIONS(5476),
    [anon_sym_property] = ACTIONS(5476),
    [anon_sym_assume] = ACTIONS(5476),
    [anon_sym_cover] = ACTIONS(5476),
    [anon_sym_sequence] = ACTIONS(5476),
    [anon_sym_restrict] = ACTIONS(5476),
    [anon_sym_not] = ACTIONS(5476),
    [anon_sym_or] = ACTIONS(5476),
    [anon_sym_and] = ACTIONS(5476),
    [anon_sym_case] = ACTIONS(5476),
    [anon_sym_always] = ACTIONS(5476),
    [anon_sym_covergroup] = ACTIONS(5476),
    [anon_sym_let] = ACTIONS(5476),
    [anon_sym_pulldown] = ACTIONS(5476),
    [anon_sym_pullup] = ACTIONS(5476),
    [anon_sym_cmos] = ACTIONS(5476),
    [anon_sym_rcmos] = ACTIONS(5476),
    [anon_sym_bufif0] = ACTIONS(5476),
    [anon_sym_bufif1] = ACTIONS(5476),
    [anon_sym_notif0] = ACTIONS(5476),
    [anon_sym_notif1] = ACTIONS(5476),
    [anon_sym_nmos] = ACTIONS(5476),
    [anon_sym_pmos] = ACTIONS(5476),
    [anon_sym_rnmos] = ACTIONS(5476),
    [anon_sym_rpmos] = ACTIONS(5476),
    [anon_sym_nand] = ACTIONS(5476),
    [anon_sym_nor] = ACTIONS(5476),
    [anon_sym_xor] = ACTIONS(5476),
    [anon_sym_xnor] = ACTIONS(5476),
    [anon_sym_buf] = ACTIONS(5476),
    [anon_sym_tranif0] = ACTIONS(5476),
    [anon_sym_tranif1] = ACTIONS(5476),
    [anon_sym_rtranif1] = ACTIONS(5476),
    [anon_sym_rtranif0] = ACTIONS(5476),
    [anon_sym_tran] = ACTIONS(5476),
    [anon_sym_rtran] = ACTIONS(5476),
    [anon_sym_generate] = ACTIONS(5476),
    [anon_sym_for] = ACTIONS(5476),
    [anon_sym_primitive] = ACTIONS(5476),
    [anon_sym_initial] = ACTIONS(5476),
    [anon_sym_assign] = ACTIONS(5476),
    [anon_sym_alias] = ACTIONS(5476),
    [anon_sym_always_comb] = ACTIONS(5476),
    [anon_sym_always_latch] = ACTIONS(5476),
    [anon_sym_always_ff] = ACTIONS(5476),
    [anon_sym_final] = ACTIONS(5476),
    [anon_sym_global] = ACTIONS(5476),
    [anon_sym_specify] = ACTIONS(5476),
    [anon_sym_LPAREN_STAR] = ACTIONS(5474),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5474),
    [anon_sym_DOLLARunit] = ACTIONS(5474),
  },
  [957] = {
    [ts_builtin_sym_end] = ACTIONS(5478),
    [sym_simple_identifier] = ACTIONS(5480),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5478),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5478),
    [anon_sym_BQUOTE] = ACTIONS(5480),
    [aux_sym_id_directive_token1] = ACTIONS(5478),
    [aux_sym_id_directive_token2] = ACTIONS(5478),
    [aux_sym_id_directive_token3] = ACTIONS(5478),
    [aux_sym_id_directive_token4] = ACTIONS(5480),
    [aux_sym_zero_directive_token1] = ACTIONS(5478),
    [aux_sym_zero_directive_token2] = ACTIONS(5478),
    [aux_sym_zero_directive_token3] = ACTIONS(5478),
    [aux_sym_zero_directive_token4] = ACTIONS(5478),
    [aux_sym_zero_directive_token5] = ACTIONS(5478),
    [aux_sym_zero_directive_token6] = ACTIONS(5478),
    [aux_sym_zero_directive_token7] = ACTIONS(5478),
    [aux_sym_zero_directive_token8] = ACTIONS(5478),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5478),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5478),
    [anon_sym_wire] = ACTIONS(5480),
    [anon_sym_tri] = ACTIONS(5480),
    [anon_sym_tri0] = ACTIONS(5480),
    [anon_sym_tri1] = ACTIONS(5480),
    [anon_sym_wand] = ACTIONS(5480),
    [anon_sym_triand] = ACTIONS(5480),
    [anon_sym_wor] = ACTIONS(5480),
    [anon_sym_trior] = ACTIONS(5480),
    [anon_sym_trireg] = ACTIONS(5480),
    [anon_sym_uwire] = ACTIONS(5480),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5478),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5478),
    [aux_sym_begin_keywords_token1] = ACTIONS(5478),
    [anon_sym_SEMI] = ACTIONS(5478),
    [anon_sym_endmodule] = ACTIONS(5480),
    [anon_sym_extern] = ACTIONS(5480),
    [anon_sym_module] = ACTIONS(5480),
    [anon_sym_macromodule] = ACTIONS(5480),
    [anon_sym_endinterface] = ACTIONS(5480),
    [anon_sym_interface] = ACTIONS(5480),
    [anon_sym_endprogram] = ACTIONS(5480),
    [anon_sym_program] = ACTIONS(5480),
    [anon_sym_checker] = ACTIONS(5480),
    [anon_sym_virtual] = ACTIONS(5480),
    [anon_sym_class] = ACTIONS(5480),
    [anon_sym_package] = ACTIONS(5480),
    [anon_sym_endpackage] = ACTIONS(5480),
    [anon_sym_timeunit] = ACTIONS(5480),
    [anon_sym_timeprecision] = ACTIONS(5480),
    [anon_sym_type] = ACTIONS(5480),
    [anon_sym_input] = ACTIONS(5480),
    [anon_sym_output] = ACTIONS(5480),
    [anon_sym_inout] = ACTIONS(5480),
    [anon_sym_ref] = ACTIONS(5480),
    [anon_sym_DOLLARfatal] = ACTIONS(5478),
    [anon_sym_DOLLARerror] = ACTIONS(5478),
    [anon_sym_DOLLARwarning] = ACTIONS(5478),
    [anon_sym_DOLLARinfo] = ACTIONS(5478),
    [anon_sym_default] = ACTIONS(5480),
    [anon_sym_clocking] = ACTIONS(5480),
    [anon_sym_defparam] = ACTIONS(5480),
    [anon_sym_bind] = ACTIONS(5480),
    [anon_sym_const] = ACTIONS(5480),
    [anon_sym_function] = ACTIONS(5480),
    [anon_sym_static] = ACTIONS(5480),
    [anon_sym_constraint] = ACTIONS(5480),
    [anon_sym_if] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5478),
    [anon_sym_localparam] = ACTIONS(5480),
    [anon_sym_parameter] = ACTIONS(5480),
    [anon_sym_specparam] = ACTIONS(5480),
    [anon_sym_var] = ACTIONS(5480),
    [anon_sym_import] = ACTIONS(5480),
    [anon_sym_export] = ACTIONS(5480),
    [anon_sym_genvar] = ACTIONS(5480),
    [anon_sym_interconnect] = ACTIONS(5480),
    [anon_sym_typedef] = ACTIONS(5480),
    [anon_sym_enum] = ACTIONS(5480),
    [anon_sym_struct] = ACTIONS(5480),
    [anon_sym_union] = ACTIONS(5480),
    [anon_sym_nettype] = ACTIONS(5480),
    [anon_sym_automatic] = ACTIONS(5480),
    [anon_sym_string] = ACTIONS(5480),
    [anon_sym_chandle] = ACTIONS(5480),
    [anon_sym_event] = ACTIONS(5480),
    [anon_sym_byte] = ACTIONS(5480),
    [anon_sym_shortint] = ACTIONS(5480),
    [anon_sym_int] = ACTIONS(5480),
    [anon_sym_longint] = ACTIONS(5480),
    [anon_sym_integer] = ACTIONS(5480),
    [anon_sym_time] = ACTIONS(5480),
    [anon_sym_bit] = ACTIONS(5480),
    [anon_sym_logic] = ACTIONS(5480),
    [anon_sym_reg] = ACTIONS(5480),
    [anon_sym_shortreal] = ACTIONS(5480),
    [anon_sym_real] = ACTIONS(5480),
    [anon_sym_realtime] = ACTIONS(5480),
    [anon_sym_supply0] = ACTIONS(5480),
    [anon_sym_supply1] = ACTIONS(5480),
    [anon_sym_signed] = ACTIONS(5480),
    [anon_sym_unsigned] = ACTIONS(5480),
    [anon_sym_task] = ACTIONS(5480),
    [anon_sym_modport] = ACTIONS(5480),
    [anon_sym_assert] = ACTIONS(5480),
    [anon_sym_property] = ACTIONS(5480),
    [anon_sym_assume] = ACTIONS(5480),
    [anon_sym_cover] = ACTIONS(5480),
    [anon_sym_sequence] = ACTIONS(5480),
    [anon_sym_restrict] = ACTIONS(5480),
    [anon_sym_not] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_case] = ACTIONS(5480),
    [anon_sym_always] = ACTIONS(5480),
    [anon_sym_covergroup] = ACTIONS(5480),
    [anon_sym_let] = ACTIONS(5480),
    [anon_sym_pulldown] = ACTIONS(5480),
    [anon_sym_pullup] = ACTIONS(5480),
    [anon_sym_cmos] = ACTIONS(5480),
    [anon_sym_rcmos] = ACTIONS(5480),
    [anon_sym_bufif0] = ACTIONS(5480),
    [anon_sym_bufif1] = ACTIONS(5480),
    [anon_sym_notif0] = ACTIONS(5480),
    [anon_sym_notif1] = ACTIONS(5480),
    [anon_sym_nmos] = ACTIONS(5480),
    [anon_sym_pmos] = ACTIONS(5480),
    [anon_sym_rnmos] = ACTIONS(5480),
    [anon_sym_rpmos] = ACTIONS(5480),
    [anon_sym_nand] = ACTIONS(5480),
    [anon_sym_nor] = ACTIONS(5480),
    [anon_sym_xor] = ACTIONS(5480),
    [anon_sym_xnor] = ACTIONS(5480),
    [anon_sym_buf] = ACTIONS(5480),
    [anon_sym_tranif0] = ACTIONS(5480),
    [anon_sym_tranif1] = ACTIONS(5480),
    [anon_sym_rtranif1] = ACTIONS(5480),
    [anon_sym_rtranif0] = ACTIONS(5480),
    [anon_sym_tran] = ACTIONS(5480),
    [anon_sym_rtran] = ACTIONS(5480),
    [anon_sym_generate] = ACTIONS(5480),
    [anon_sym_for] = ACTIONS(5480),
    [anon_sym_primitive] = ACTIONS(5480),
    [anon_sym_initial] = ACTIONS(5480),
    [anon_sym_assign] = ACTIONS(5480),
    [anon_sym_alias] = ACTIONS(5480),
    [anon_sym_always_comb] = ACTIONS(5480),
    [anon_sym_always_latch] = ACTIONS(5480),
    [anon_sym_always_ff] = ACTIONS(5480),
    [anon_sym_final] = ACTIONS(5480),
    [anon_sym_global] = ACTIONS(5480),
    [anon_sym_specify] = ACTIONS(5480),
    [anon_sym_LPAREN_STAR] = ACTIONS(5478),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5478),
    [anon_sym_DOLLARunit] = ACTIONS(5478),
  },
  [958] = {
    [ts_builtin_sym_end] = ACTIONS(5482),
    [sym_simple_identifier] = ACTIONS(5484),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5482),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5482),
    [anon_sym_BQUOTE] = ACTIONS(5484),
    [aux_sym_id_directive_token1] = ACTIONS(5482),
    [aux_sym_id_directive_token2] = ACTIONS(5482),
    [aux_sym_id_directive_token3] = ACTIONS(5482),
    [aux_sym_id_directive_token4] = ACTIONS(5484),
    [aux_sym_zero_directive_token1] = ACTIONS(5482),
    [aux_sym_zero_directive_token2] = ACTIONS(5482),
    [aux_sym_zero_directive_token3] = ACTIONS(5482),
    [aux_sym_zero_directive_token4] = ACTIONS(5482),
    [aux_sym_zero_directive_token5] = ACTIONS(5482),
    [aux_sym_zero_directive_token6] = ACTIONS(5482),
    [aux_sym_zero_directive_token7] = ACTIONS(5482),
    [aux_sym_zero_directive_token8] = ACTIONS(5482),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5482),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5482),
    [anon_sym_wire] = ACTIONS(5484),
    [anon_sym_tri] = ACTIONS(5484),
    [anon_sym_tri0] = ACTIONS(5484),
    [anon_sym_tri1] = ACTIONS(5484),
    [anon_sym_wand] = ACTIONS(5484),
    [anon_sym_triand] = ACTIONS(5484),
    [anon_sym_wor] = ACTIONS(5484),
    [anon_sym_trior] = ACTIONS(5484),
    [anon_sym_trireg] = ACTIONS(5484),
    [anon_sym_uwire] = ACTIONS(5484),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5482),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5482),
    [aux_sym_begin_keywords_token1] = ACTIONS(5482),
    [anon_sym_SEMI] = ACTIONS(5482),
    [anon_sym_endmodule] = ACTIONS(5484),
    [anon_sym_extern] = ACTIONS(5484),
    [anon_sym_module] = ACTIONS(5484),
    [anon_sym_macromodule] = ACTIONS(5484),
    [anon_sym_endinterface] = ACTIONS(5484),
    [anon_sym_interface] = ACTIONS(5484),
    [anon_sym_endprogram] = ACTIONS(5484),
    [anon_sym_program] = ACTIONS(5484),
    [anon_sym_checker] = ACTIONS(5484),
    [anon_sym_virtual] = ACTIONS(5484),
    [anon_sym_class] = ACTIONS(5484),
    [anon_sym_package] = ACTIONS(5484),
    [anon_sym_timeunit] = ACTIONS(5484),
    [anon_sym_timeprecision] = ACTIONS(5484),
    [anon_sym_type] = ACTIONS(5484),
    [anon_sym_input] = ACTIONS(5484),
    [anon_sym_output] = ACTIONS(5484),
    [anon_sym_inout] = ACTIONS(5484),
    [anon_sym_ref] = ACTIONS(5484),
    [anon_sym_DOLLARfatal] = ACTIONS(5482),
    [anon_sym_DOLLARerror] = ACTIONS(5482),
    [anon_sym_DOLLARwarning] = ACTIONS(5482),
    [anon_sym_DOLLARinfo] = ACTIONS(5482),
    [anon_sym_default] = ACTIONS(5484),
    [anon_sym_clocking] = ACTIONS(5484),
    [anon_sym_defparam] = ACTIONS(5484),
    [anon_sym_bind] = ACTIONS(5484),
    [anon_sym_const] = ACTIONS(5484),
    [anon_sym_function] = ACTIONS(5484),
    [anon_sym_static] = ACTIONS(5484),
    [anon_sym_constraint] = ACTIONS(5484),
    [anon_sym_if] = ACTIONS(5484),
    [anon_sym_else] = ACTIONS(5484),
    [anon_sym_LBRACK] = ACTIONS(5482),
    [anon_sym_localparam] = ACTIONS(5484),
    [anon_sym_parameter] = ACTIONS(5484),
    [anon_sym_specparam] = ACTIONS(5484),
    [anon_sym_var] = ACTIONS(5484),
    [anon_sym_import] = ACTIONS(5484),
    [anon_sym_export] = ACTIONS(5484),
    [anon_sym_genvar] = ACTIONS(5484),
    [anon_sym_interconnect] = ACTIONS(5484),
    [anon_sym_typedef] = ACTIONS(5484),
    [anon_sym_enum] = ACTIONS(5484),
    [anon_sym_struct] = ACTIONS(5484),
    [anon_sym_union] = ACTIONS(5484),
    [anon_sym_nettype] = ACTIONS(5484),
    [anon_sym_automatic] = ACTIONS(5484),
    [anon_sym_string] = ACTIONS(5484),
    [anon_sym_chandle] = ACTIONS(5484),
    [anon_sym_event] = ACTIONS(5484),
    [anon_sym_byte] = ACTIONS(5484),
    [anon_sym_shortint] = ACTIONS(5484),
    [anon_sym_int] = ACTIONS(5484),
    [anon_sym_longint] = ACTIONS(5484),
    [anon_sym_integer] = ACTIONS(5484),
    [anon_sym_time] = ACTIONS(5484),
    [anon_sym_bit] = ACTIONS(5484),
    [anon_sym_logic] = ACTIONS(5484),
    [anon_sym_reg] = ACTIONS(5484),
    [anon_sym_shortreal] = ACTIONS(5484),
    [anon_sym_real] = ACTIONS(5484),
    [anon_sym_realtime] = ACTIONS(5484),
    [anon_sym_supply0] = ACTIONS(5484),
    [anon_sym_supply1] = ACTIONS(5484),
    [anon_sym_signed] = ACTIONS(5484),
    [anon_sym_unsigned] = ACTIONS(5484),
    [anon_sym_task] = ACTIONS(5484),
    [anon_sym_modport] = ACTIONS(5484),
    [anon_sym_assert] = ACTIONS(5484),
    [anon_sym_property] = ACTIONS(5484),
    [anon_sym_assume] = ACTIONS(5484),
    [anon_sym_cover] = ACTIONS(5484),
    [anon_sym_sequence] = ACTIONS(5484),
    [anon_sym_restrict] = ACTIONS(5484),
    [anon_sym_not] = ACTIONS(5484),
    [anon_sym_or] = ACTIONS(5484),
    [anon_sym_and] = ACTIONS(5484),
    [anon_sym_case] = ACTIONS(5484),
    [anon_sym_always] = ACTIONS(5484),
    [anon_sym_covergroup] = ACTIONS(5484),
    [anon_sym_let] = ACTIONS(5484),
    [anon_sym_pulldown] = ACTIONS(5484),
    [anon_sym_pullup] = ACTIONS(5484),
    [anon_sym_cmos] = ACTIONS(5484),
    [anon_sym_rcmos] = ACTIONS(5484),
    [anon_sym_bufif0] = ACTIONS(5484),
    [anon_sym_bufif1] = ACTIONS(5484),
    [anon_sym_notif0] = ACTIONS(5484),
    [anon_sym_notif1] = ACTIONS(5484),
    [anon_sym_nmos] = ACTIONS(5484),
    [anon_sym_pmos] = ACTIONS(5484),
    [anon_sym_rnmos] = ACTIONS(5484),
    [anon_sym_rpmos] = ACTIONS(5484),
    [anon_sym_nand] = ACTIONS(5484),
    [anon_sym_nor] = ACTIONS(5484),
    [anon_sym_xor] = ACTIONS(5484),
    [anon_sym_xnor] = ACTIONS(5484),
    [anon_sym_buf] = ACTIONS(5484),
    [anon_sym_tranif0] = ACTIONS(5484),
    [anon_sym_tranif1] = ACTIONS(5484),
    [anon_sym_rtranif1] = ACTIONS(5484),
    [anon_sym_rtranif0] = ACTIONS(5484),
    [anon_sym_tran] = ACTIONS(5484),
    [anon_sym_rtran] = ACTIONS(5484),
    [anon_sym_generate] = ACTIONS(5484),
    [anon_sym_for] = ACTIONS(5484),
    [anon_sym_primitive] = ACTIONS(5484),
    [anon_sym_initial] = ACTIONS(5484),
    [anon_sym_assign] = ACTIONS(5484),
    [anon_sym_alias] = ACTIONS(5484),
    [anon_sym_always_comb] = ACTIONS(5484),
    [anon_sym_always_latch] = ACTIONS(5484),
    [anon_sym_always_ff] = ACTIONS(5484),
    [anon_sym_final] = ACTIONS(5484),
    [anon_sym_global] = ACTIONS(5484),
    [anon_sym_specify] = ACTIONS(5484),
    [anon_sym_LPAREN_STAR] = ACTIONS(5482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5482),
    [anon_sym_DOLLARunit] = ACTIONS(5482),
  },
  [959] = {
    [ts_builtin_sym_end] = ACTIONS(5486),
    [sym_simple_identifier] = ACTIONS(5488),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5488),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5486),
    [anon_sym_BQUOTE] = ACTIONS(5488),
    [aux_sym_id_directive_token1] = ACTIONS(5486),
    [aux_sym_id_directive_token2] = ACTIONS(5486),
    [aux_sym_id_directive_token3] = ACTIONS(5486),
    [aux_sym_id_directive_token4] = ACTIONS(5488),
    [aux_sym_zero_directive_token1] = ACTIONS(5486),
    [aux_sym_zero_directive_token2] = ACTIONS(5486),
    [aux_sym_zero_directive_token3] = ACTIONS(5486),
    [aux_sym_zero_directive_token4] = ACTIONS(5486),
    [aux_sym_zero_directive_token5] = ACTIONS(5486),
    [aux_sym_zero_directive_token6] = ACTIONS(5486),
    [aux_sym_zero_directive_token7] = ACTIONS(5486),
    [aux_sym_zero_directive_token8] = ACTIONS(5486),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5486),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5486),
    [anon_sym_wire] = ACTIONS(5488),
    [anon_sym_tri] = ACTIONS(5488),
    [anon_sym_tri0] = ACTIONS(5488),
    [anon_sym_tri1] = ACTIONS(5488),
    [anon_sym_wand] = ACTIONS(5488),
    [anon_sym_triand] = ACTIONS(5488),
    [anon_sym_wor] = ACTIONS(5488),
    [anon_sym_trior] = ACTIONS(5488),
    [anon_sym_trireg] = ACTIONS(5488),
    [anon_sym_uwire] = ACTIONS(5488),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5486),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5486),
    [aux_sym_begin_keywords_token1] = ACTIONS(5486),
    [anon_sym_SEMI] = ACTIONS(5486),
    [anon_sym_endmodule] = ACTIONS(5488),
    [anon_sym_extern] = ACTIONS(5488),
    [anon_sym_module] = ACTIONS(5488),
    [anon_sym_macromodule] = ACTIONS(5488),
    [anon_sym_interface] = ACTIONS(5488),
    [anon_sym_program] = ACTIONS(5488),
    [anon_sym_checker] = ACTIONS(5488),
    [anon_sym_virtual] = ACTIONS(5488),
    [anon_sym_class] = ACTIONS(5488),
    [anon_sym_extends] = ACTIONS(5488),
    [anon_sym_endclass] = ACTIONS(5488),
    [anon_sym_pure] = ACTIONS(5488),
    [anon_sym_package] = ACTIONS(5488),
    [anon_sym_timeunit] = ACTIONS(5488),
    [anon_sym_timeprecision] = ACTIONS(5488),
    [anon_sym_type] = ACTIONS(5488),
    [anon_sym_input] = ACTIONS(5488),
    [anon_sym_output] = ACTIONS(5488),
    [anon_sym_inout] = ACTIONS(5488),
    [anon_sym_ref] = ACTIONS(5488),
    [anon_sym_DOLLARfatal] = ACTIONS(5486),
    [anon_sym_DOLLARerror] = ACTIONS(5486),
    [anon_sym_DOLLARwarning] = ACTIONS(5486),
    [anon_sym_DOLLARinfo] = ACTIONS(5486),
    [anon_sym_default] = ACTIONS(5488),
    [anon_sym_clocking] = ACTIONS(5488),
    [anon_sym_defparam] = ACTIONS(5488),
    [anon_sym_bind] = ACTIONS(5488),
    [anon_sym_const] = ACTIONS(5488),
    [anon_sym_function] = ACTIONS(5488),
    [anon_sym_static] = ACTIONS(5488),
    [anon_sym_constraint] = ACTIONS(5488),
    [anon_sym_if] = ACTIONS(5488),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_localparam] = ACTIONS(5488),
    [anon_sym_parameter] = ACTIONS(5488),
    [anon_sym_specparam] = ACTIONS(5488),
    [anon_sym_var] = ACTIONS(5488),
    [anon_sym_import] = ACTIONS(5488),
    [anon_sym_export] = ACTIONS(5488),
    [anon_sym_genvar] = ACTIONS(5488),
    [anon_sym_interconnect] = ACTIONS(5488),
    [anon_sym_typedef] = ACTIONS(5488),
    [anon_sym_enum] = ACTIONS(5488),
    [anon_sym_struct] = ACTIONS(5488),
    [anon_sym_union] = ACTIONS(5488),
    [anon_sym_nettype] = ACTIONS(5488),
    [anon_sym_automatic] = ACTIONS(5488),
    [anon_sym_string] = ACTIONS(5488),
    [anon_sym_chandle] = ACTIONS(5488),
    [anon_sym_event] = ACTIONS(5488),
    [anon_sym_byte] = ACTIONS(5488),
    [anon_sym_shortint] = ACTIONS(5488),
    [anon_sym_int] = ACTIONS(5488),
    [anon_sym_longint] = ACTIONS(5488),
    [anon_sym_integer] = ACTIONS(5488),
    [anon_sym_time] = ACTIONS(5488),
    [anon_sym_bit] = ACTIONS(5488),
    [anon_sym_logic] = ACTIONS(5488),
    [anon_sym_reg] = ACTIONS(5488),
    [anon_sym_shortreal] = ACTIONS(5488),
    [anon_sym_real] = ACTIONS(5488),
    [anon_sym_realtime] = ACTIONS(5488),
    [anon_sym_supply0] = ACTIONS(5488),
    [anon_sym_supply1] = ACTIONS(5488),
    [anon_sym_signed] = ACTIONS(5488),
    [anon_sym_unsigned] = ACTIONS(5488),
    [anon_sym_task] = ACTIONS(5488),
    [anon_sym_assert] = ACTIONS(5488),
    [anon_sym_property] = ACTIONS(5488),
    [anon_sym_assume] = ACTIONS(5488),
    [anon_sym_cover] = ACTIONS(5488),
    [anon_sym_sequence] = ACTIONS(5488),
    [anon_sym_restrict] = ACTIONS(5488),
    [anon_sym_not] = ACTIONS(5488),
    [anon_sym_or] = ACTIONS(5488),
    [anon_sym_and] = ACTIONS(5488),
    [anon_sym_case] = ACTIONS(5488),
    [anon_sym_always] = ACTIONS(5488),
    [anon_sym_covergroup] = ACTIONS(5488),
    [anon_sym_let] = ACTIONS(5488),
    [anon_sym_pulldown] = ACTIONS(5488),
    [anon_sym_pullup] = ACTIONS(5488),
    [anon_sym_cmos] = ACTIONS(5488),
    [anon_sym_rcmos] = ACTIONS(5488),
    [anon_sym_bufif0] = ACTIONS(5488),
    [anon_sym_bufif1] = ACTIONS(5488),
    [anon_sym_notif0] = ACTIONS(5488),
    [anon_sym_notif1] = ACTIONS(5488),
    [anon_sym_nmos] = ACTIONS(5488),
    [anon_sym_pmos] = ACTIONS(5488),
    [anon_sym_rnmos] = ACTIONS(5488),
    [anon_sym_rpmos] = ACTIONS(5488),
    [anon_sym_nand] = ACTIONS(5488),
    [anon_sym_nor] = ACTIONS(5488),
    [anon_sym_xor] = ACTIONS(5488),
    [anon_sym_xnor] = ACTIONS(5488),
    [anon_sym_buf] = ACTIONS(5488),
    [anon_sym_tranif0] = ACTIONS(5488),
    [anon_sym_tranif1] = ACTIONS(5488),
    [anon_sym_rtranif1] = ACTIONS(5488),
    [anon_sym_rtranif0] = ACTIONS(5488),
    [anon_sym_tran] = ACTIONS(5488),
    [anon_sym_rtran] = ACTIONS(5488),
    [anon_sym_generate] = ACTIONS(5488),
    [anon_sym_for] = ACTIONS(5488),
    [anon_sym_primitive] = ACTIONS(5488),
    [anon_sym_initial] = ACTIONS(5488),
    [anon_sym_assign] = ACTIONS(5488),
    [anon_sym_alias] = ACTIONS(5488),
    [anon_sym_always_comb] = ACTIONS(5488),
    [anon_sym_always_latch] = ACTIONS(5488),
    [anon_sym_always_ff] = ACTIONS(5488),
    [anon_sym_final] = ACTIONS(5488),
    [anon_sym_global] = ACTIONS(5488),
    [anon_sym_specify] = ACTIONS(5488),
    [anon_sym_LPAREN_STAR] = ACTIONS(5486),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5486),
    [anon_sym_DOLLARunit] = ACTIONS(5486),
  },
  [960] = {
    [ts_builtin_sym_end] = ACTIONS(5490),
    [sym_simple_identifier] = ACTIONS(5492),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5492),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5490),
    [anon_sym_BQUOTE] = ACTIONS(5492),
    [aux_sym_id_directive_token1] = ACTIONS(5490),
    [aux_sym_id_directive_token2] = ACTIONS(5490),
    [aux_sym_id_directive_token3] = ACTIONS(5490),
    [aux_sym_id_directive_token4] = ACTIONS(5492),
    [aux_sym_zero_directive_token1] = ACTIONS(5490),
    [aux_sym_zero_directive_token2] = ACTIONS(5490),
    [aux_sym_zero_directive_token3] = ACTIONS(5490),
    [aux_sym_zero_directive_token4] = ACTIONS(5490),
    [aux_sym_zero_directive_token5] = ACTIONS(5490),
    [aux_sym_zero_directive_token6] = ACTIONS(5490),
    [aux_sym_zero_directive_token7] = ACTIONS(5490),
    [aux_sym_zero_directive_token8] = ACTIONS(5490),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5490),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5490),
    [anon_sym_wire] = ACTIONS(5492),
    [anon_sym_tri] = ACTIONS(5492),
    [anon_sym_tri0] = ACTIONS(5492),
    [anon_sym_tri1] = ACTIONS(5492),
    [anon_sym_wand] = ACTIONS(5492),
    [anon_sym_triand] = ACTIONS(5492),
    [anon_sym_wor] = ACTIONS(5492),
    [anon_sym_trior] = ACTIONS(5492),
    [anon_sym_trireg] = ACTIONS(5492),
    [anon_sym_uwire] = ACTIONS(5492),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5490),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5490),
    [aux_sym_begin_keywords_token1] = ACTIONS(5490),
    [anon_sym_SEMI] = ACTIONS(5490),
    [anon_sym_endmodule] = ACTIONS(5492),
    [anon_sym_extern] = ACTIONS(5492),
    [anon_sym_module] = ACTIONS(5492),
    [anon_sym_macromodule] = ACTIONS(5492),
    [anon_sym_interface] = ACTIONS(5492),
    [anon_sym_program] = ACTIONS(5492),
    [anon_sym_checker] = ACTIONS(5492),
    [anon_sym_virtual] = ACTIONS(5492),
    [anon_sym_class] = ACTIONS(5492),
    [anon_sym_extends] = ACTIONS(5492),
    [anon_sym_endclass] = ACTIONS(5492),
    [anon_sym_pure] = ACTIONS(5492),
    [anon_sym_package] = ACTIONS(5492),
    [anon_sym_timeunit] = ACTIONS(5492),
    [anon_sym_timeprecision] = ACTIONS(5492),
    [anon_sym_type] = ACTIONS(5492),
    [anon_sym_input] = ACTIONS(5492),
    [anon_sym_output] = ACTIONS(5492),
    [anon_sym_inout] = ACTIONS(5492),
    [anon_sym_ref] = ACTIONS(5492),
    [anon_sym_DOLLARfatal] = ACTIONS(5490),
    [anon_sym_DOLLARerror] = ACTIONS(5490),
    [anon_sym_DOLLARwarning] = ACTIONS(5490),
    [anon_sym_DOLLARinfo] = ACTIONS(5490),
    [anon_sym_default] = ACTIONS(5492),
    [anon_sym_clocking] = ACTIONS(5492),
    [anon_sym_defparam] = ACTIONS(5492),
    [anon_sym_bind] = ACTIONS(5492),
    [anon_sym_const] = ACTIONS(5492),
    [anon_sym_function] = ACTIONS(5492),
    [anon_sym_static] = ACTIONS(5492),
    [anon_sym_constraint] = ACTIONS(5492),
    [anon_sym_if] = ACTIONS(5492),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_localparam] = ACTIONS(5492),
    [anon_sym_parameter] = ACTIONS(5492),
    [anon_sym_specparam] = ACTIONS(5492),
    [anon_sym_var] = ACTIONS(5492),
    [anon_sym_import] = ACTIONS(5492),
    [anon_sym_export] = ACTIONS(5492),
    [anon_sym_genvar] = ACTIONS(5492),
    [anon_sym_interconnect] = ACTIONS(5492),
    [anon_sym_typedef] = ACTIONS(5492),
    [anon_sym_enum] = ACTIONS(5492),
    [anon_sym_struct] = ACTIONS(5492),
    [anon_sym_union] = ACTIONS(5492),
    [anon_sym_nettype] = ACTIONS(5492),
    [anon_sym_automatic] = ACTIONS(5492),
    [anon_sym_string] = ACTIONS(5492),
    [anon_sym_chandle] = ACTIONS(5492),
    [anon_sym_event] = ACTIONS(5492),
    [anon_sym_byte] = ACTIONS(5492),
    [anon_sym_shortint] = ACTIONS(5492),
    [anon_sym_int] = ACTIONS(5492),
    [anon_sym_longint] = ACTIONS(5492),
    [anon_sym_integer] = ACTIONS(5492),
    [anon_sym_time] = ACTIONS(5492),
    [anon_sym_bit] = ACTIONS(5492),
    [anon_sym_logic] = ACTIONS(5492),
    [anon_sym_reg] = ACTIONS(5492),
    [anon_sym_shortreal] = ACTIONS(5492),
    [anon_sym_real] = ACTIONS(5492),
    [anon_sym_realtime] = ACTIONS(5492),
    [anon_sym_supply0] = ACTIONS(5492),
    [anon_sym_supply1] = ACTIONS(5492),
    [anon_sym_signed] = ACTIONS(5492),
    [anon_sym_unsigned] = ACTIONS(5492),
    [anon_sym_task] = ACTIONS(5492),
    [anon_sym_assert] = ACTIONS(5492),
    [anon_sym_property] = ACTIONS(5492),
    [anon_sym_assume] = ACTIONS(5492),
    [anon_sym_cover] = ACTIONS(5492),
    [anon_sym_sequence] = ACTIONS(5492),
    [anon_sym_restrict] = ACTIONS(5492),
    [anon_sym_not] = ACTIONS(5492),
    [anon_sym_or] = ACTIONS(5492),
    [anon_sym_and] = ACTIONS(5492),
    [anon_sym_case] = ACTIONS(5492),
    [anon_sym_always] = ACTIONS(5492),
    [anon_sym_covergroup] = ACTIONS(5492),
    [anon_sym_let] = ACTIONS(5492),
    [anon_sym_pulldown] = ACTIONS(5492),
    [anon_sym_pullup] = ACTIONS(5492),
    [anon_sym_cmos] = ACTIONS(5492),
    [anon_sym_rcmos] = ACTIONS(5492),
    [anon_sym_bufif0] = ACTIONS(5492),
    [anon_sym_bufif1] = ACTIONS(5492),
    [anon_sym_notif0] = ACTIONS(5492),
    [anon_sym_notif1] = ACTIONS(5492),
    [anon_sym_nmos] = ACTIONS(5492),
    [anon_sym_pmos] = ACTIONS(5492),
    [anon_sym_rnmos] = ACTIONS(5492),
    [anon_sym_rpmos] = ACTIONS(5492),
    [anon_sym_nand] = ACTIONS(5492),
    [anon_sym_nor] = ACTIONS(5492),
    [anon_sym_xor] = ACTIONS(5492),
    [anon_sym_xnor] = ACTIONS(5492),
    [anon_sym_buf] = ACTIONS(5492),
    [anon_sym_tranif0] = ACTIONS(5492),
    [anon_sym_tranif1] = ACTIONS(5492),
    [anon_sym_rtranif1] = ACTIONS(5492),
    [anon_sym_rtranif0] = ACTIONS(5492),
    [anon_sym_tran] = ACTIONS(5492),
    [anon_sym_rtran] = ACTIONS(5492),
    [anon_sym_generate] = ACTIONS(5492),
    [anon_sym_for] = ACTIONS(5492),
    [anon_sym_primitive] = ACTIONS(5492),
    [anon_sym_initial] = ACTIONS(5492),
    [anon_sym_assign] = ACTIONS(5492),
    [anon_sym_alias] = ACTIONS(5492),
    [anon_sym_always_comb] = ACTIONS(5492),
    [anon_sym_always_latch] = ACTIONS(5492),
    [anon_sym_always_ff] = ACTIONS(5492),
    [anon_sym_final] = ACTIONS(5492),
    [anon_sym_global] = ACTIONS(5492),
    [anon_sym_specify] = ACTIONS(5492),
    [anon_sym_LPAREN_STAR] = ACTIONS(5490),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5490),
    [anon_sym_DOLLARunit] = ACTIONS(5490),
  },
  [961] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17194),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17194),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [962] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17197),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17197),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [963] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16820),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16820),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [964] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16821),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16821),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [965] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16660),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16660),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [966] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17192),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17192),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [967] = {
    [ts_builtin_sym_end] = ACTIONS(5494),
    [sym_simple_identifier] = ACTIONS(5496),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5494),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5494),
    [anon_sym_BQUOTE] = ACTIONS(5496),
    [aux_sym_id_directive_token1] = ACTIONS(5494),
    [aux_sym_id_directive_token2] = ACTIONS(5494),
    [aux_sym_id_directive_token3] = ACTIONS(5494),
    [aux_sym_id_directive_token4] = ACTIONS(5496),
    [aux_sym_zero_directive_token1] = ACTIONS(5494),
    [aux_sym_zero_directive_token2] = ACTIONS(5494),
    [aux_sym_zero_directive_token3] = ACTIONS(5494),
    [aux_sym_zero_directive_token4] = ACTIONS(5494),
    [aux_sym_zero_directive_token5] = ACTIONS(5494),
    [aux_sym_zero_directive_token6] = ACTIONS(5494),
    [aux_sym_zero_directive_token7] = ACTIONS(5494),
    [aux_sym_zero_directive_token8] = ACTIONS(5494),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5494),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5494),
    [anon_sym_wire] = ACTIONS(5496),
    [anon_sym_tri] = ACTIONS(5496),
    [anon_sym_tri0] = ACTIONS(5496),
    [anon_sym_tri1] = ACTIONS(5496),
    [anon_sym_wand] = ACTIONS(5496),
    [anon_sym_triand] = ACTIONS(5496),
    [anon_sym_wor] = ACTIONS(5496),
    [anon_sym_trior] = ACTIONS(5496),
    [anon_sym_trireg] = ACTIONS(5496),
    [anon_sym_uwire] = ACTIONS(5496),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5494),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5494),
    [aux_sym_begin_keywords_token1] = ACTIONS(5494),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_endmodule] = ACTIONS(5496),
    [anon_sym_extern] = ACTIONS(5496),
    [anon_sym_module] = ACTIONS(5496),
    [anon_sym_macromodule] = ACTIONS(5496),
    [anon_sym_endinterface] = ACTIONS(5496),
    [anon_sym_interface] = ACTIONS(5496),
    [anon_sym_endprogram] = ACTIONS(5496),
    [anon_sym_program] = ACTIONS(5496),
    [anon_sym_checker] = ACTIONS(5496),
    [anon_sym_virtual] = ACTIONS(5496),
    [anon_sym_class] = ACTIONS(5496),
    [anon_sym_package] = ACTIONS(5496),
    [anon_sym_timeunit] = ACTIONS(5496),
    [anon_sym_timeprecision] = ACTIONS(5496),
    [anon_sym_type] = ACTIONS(5496),
    [anon_sym_input] = ACTIONS(5496),
    [anon_sym_output] = ACTIONS(5496),
    [anon_sym_inout] = ACTIONS(5496),
    [anon_sym_ref] = ACTIONS(5496),
    [anon_sym_DOLLARfatal] = ACTIONS(5494),
    [anon_sym_DOLLARerror] = ACTIONS(5494),
    [anon_sym_DOLLARwarning] = ACTIONS(5494),
    [anon_sym_DOLLARinfo] = ACTIONS(5494),
    [anon_sym_default] = ACTIONS(5496),
    [anon_sym_clocking] = ACTIONS(5496),
    [anon_sym_defparam] = ACTIONS(5496),
    [anon_sym_bind] = ACTIONS(5496),
    [anon_sym_const] = ACTIONS(5496),
    [anon_sym_function] = ACTIONS(5496),
    [anon_sym_static] = ACTIONS(5496),
    [anon_sym_constraint] = ACTIONS(5496),
    [anon_sym_if] = ACTIONS(5496),
    [anon_sym_else] = ACTIONS(5496),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_localparam] = ACTIONS(5496),
    [anon_sym_parameter] = ACTIONS(5496),
    [anon_sym_specparam] = ACTIONS(5496),
    [anon_sym_var] = ACTIONS(5496),
    [anon_sym_import] = ACTIONS(5496),
    [anon_sym_export] = ACTIONS(5496),
    [anon_sym_genvar] = ACTIONS(5496),
    [anon_sym_interconnect] = ACTIONS(5496),
    [anon_sym_typedef] = ACTIONS(5496),
    [anon_sym_enum] = ACTIONS(5496),
    [anon_sym_struct] = ACTIONS(5496),
    [anon_sym_union] = ACTIONS(5496),
    [anon_sym_nettype] = ACTIONS(5496),
    [anon_sym_automatic] = ACTIONS(5496),
    [anon_sym_string] = ACTIONS(5496),
    [anon_sym_chandle] = ACTIONS(5496),
    [anon_sym_event] = ACTIONS(5496),
    [anon_sym_byte] = ACTIONS(5496),
    [anon_sym_shortint] = ACTIONS(5496),
    [anon_sym_int] = ACTIONS(5496),
    [anon_sym_longint] = ACTIONS(5496),
    [anon_sym_integer] = ACTIONS(5496),
    [anon_sym_time] = ACTIONS(5496),
    [anon_sym_bit] = ACTIONS(5496),
    [anon_sym_logic] = ACTIONS(5496),
    [anon_sym_reg] = ACTIONS(5496),
    [anon_sym_shortreal] = ACTIONS(5496),
    [anon_sym_real] = ACTIONS(5496),
    [anon_sym_realtime] = ACTIONS(5496),
    [anon_sym_supply0] = ACTIONS(5496),
    [anon_sym_supply1] = ACTIONS(5496),
    [anon_sym_signed] = ACTIONS(5496),
    [anon_sym_unsigned] = ACTIONS(5496),
    [anon_sym_task] = ACTIONS(5496),
    [anon_sym_modport] = ACTIONS(5496),
    [anon_sym_assert] = ACTIONS(5496),
    [anon_sym_property] = ACTIONS(5496),
    [anon_sym_assume] = ACTIONS(5496),
    [anon_sym_cover] = ACTIONS(5496),
    [anon_sym_sequence] = ACTIONS(5496),
    [anon_sym_restrict] = ACTIONS(5496),
    [anon_sym_not] = ACTIONS(5496),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_and] = ACTIONS(5496),
    [anon_sym_case] = ACTIONS(5496),
    [anon_sym_always] = ACTIONS(5496),
    [anon_sym_covergroup] = ACTIONS(5496),
    [anon_sym_let] = ACTIONS(5496),
    [anon_sym_pulldown] = ACTIONS(5496),
    [anon_sym_pullup] = ACTIONS(5496),
    [anon_sym_cmos] = ACTIONS(5496),
    [anon_sym_rcmos] = ACTIONS(5496),
    [anon_sym_bufif0] = ACTIONS(5496),
    [anon_sym_bufif1] = ACTIONS(5496),
    [anon_sym_notif0] = ACTIONS(5496),
    [anon_sym_notif1] = ACTIONS(5496),
    [anon_sym_nmos] = ACTIONS(5496),
    [anon_sym_pmos] = ACTIONS(5496),
    [anon_sym_rnmos] = ACTIONS(5496),
    [anon_sym_rpmos] = ACTIONS(5496),
    [anon_sym_nand] = ACTIONS(5496),
    [anon_sym_nor] = ACTIONS(5496),
    [anon_sym_xor] = ACTIONS(5496),
    [anon_sym_xnor] = ACTIONS(5496),
    [anon_sym_buf] = ACTIONS(5496),
    [anon_sym_tranif0] = ACTIONS(5496),
    [anon_sym_tranif1] = ACTIONS(5496),
    [anon_sym_rtranif1] = ACTIONS(5496),
    [anon_sym_rtranif0] = ACTIONS(5496),
    [anon_sym_tran] = ACTIONS(5496),
    [anon_sym_rtran] = ACTIONS(5496),
    [anon_sym_generate] = ACTIONS(5496),
    [anon_sym_for] = ACTIONS(5496),
    [anon_sym_primitive] = ACTIONS(5496),
    [anon_sym_initial] = ACTIONS(5496),
    [anon_sym_assign] = ACTIONS(5496),
    [anon_sym_alias] = ACTIONS(5496),
    [anon_sym_always_comb] = ACTIONS(5496),
    [anon_sym_always_latch] = ACTIONS(5496),
    [anon_sym_always_ff] = ACTIONS(5496),
    [anon_sym_final] = ACTIONS(5496),
    [anon_sym_global] = ACTIONS(5496),
    [anon_sym_specify] = ACTIONS(5496),
    [anon_sym_LPAREN_STAR] = ACTIONS(5494),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5494),
    [anon_sym_DOLLARunit] = ACTIONS(5494),
  },
  [968] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(17196),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(17196),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [969] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16902),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16902),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [970] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym__property_actual_arg] = STATE(16903),
    [sym_property_expr] = STATE(11567),
    [sym_sequence_expr] = STATE(10860),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym__sequence_actual_arg] = STATE(16903),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7373),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [971] = {
    [ts_builtin_sym_end] = ACTIONS(5498),
    [sym_simple_identifier] = ACTIONS(5500),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5498),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5498),
    [anon_sym_BQUOTE] = ACTIONS(5500),
    [aux_sym_id_directive_token1] = ACTIONS(5498),
    [aux_sym_id_directive_token2] = ACTIONS(5498),
    [aux_sym_id_directive_token3] = ACTIONS(5498),
    [aux_sym_id_directive_token4] = ACTIONS(5500),
    [aux_sym_zero_directive_token1] = ACTIONS(5498),
    [aux_sym_zero_directive_token2] = ACTIONS(5498),
    [aux_sym_zero_directive_token3] = ACTIONS(5498),
    [aux_sym_zero_directive_token4] = ACTIONS(5498),
    [aux_sym_zero_directive_token5] = ACTIONS(5498),
    [aux_sym_zero_directive_token6] = ACTIONS(5498),
    [aux_sym_zero_directive_token7] = ACTIONS(5498),
    [aux_sym_zero_directive_token8] = ACTIONS(5498),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5498),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5498),
    [anon_sym_wire] = ACTIONS(5500),
    [anon_sym_tri] = ACTIONS(5500),
    [anon_sym_tri0] = ACTIONS(5500),
    [anon_sym_tri1] = ACTIONS(5500),
    [anon_sym_wand] = ACTIONS(5500),
    [anon_sym_triand] = ACTIONS(5500),
    [anon_sym_wor] = ACTIONS(5500),
    [anon_sym_trior] = ACTIONS(5500),
    [anon_sym_trireg] = ACTIONS(5500),
    [anon_sym_uwire] = ACTIONS(5500),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5498),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5498),
    [aux_sym_begin_keywords_token1] = ACTIONS(5498),
    [anon_sym_SEMI] = ACTIONS(5498),
    [anon_sym_endmodule] = ACTIONS(5500),
    [anon_sym_COLON] = ACTIONS(5502),
    [anon_sym_extern] = ACTIONS(5500),
    [anon_sym_module] = ACTIONS(5500),
    [anon_sym_macromodule] = ACTIONS(5500),
    [anon_sym_endinterface] = ACTIONS(5500),
    [anon_sym_interface] = ACTIONS(5500),
    [anon_sym_program] = ACTIONS(5500),
    [anon_sym_checker] = ACTIONS(5500),
    [anon_sym_virtual] = ACTIONS(5500),
    [anon_sym_class] = ACTIONS(5500),
    [anon_sym_package] = ACTIONS(5500),
    [anon_sym_timeunit] = ACTIONS(5500),
    [anon_sym_timeprecision] = ACTIONS(5500),
    [anon_sym_type] = ACTIONS(5500),
    [anon_sym_input] = ACTIONS(5500),
    [anon_sym_output] = ACTIONS(5500),
    [anon_sym_inout] = ACTIONS(5500),
    [anon_sym_ref] = ACTIONS(5500),
    [anon_sym_DOLLARfatal] = ACTIONS(5498),
    [anon_sym_DOLLARerror] = ACTIONS(5498),
    [anon_sym_DOLLARwarning] = ACTIONS(5498),
    [anon_sym_DOLLARinfo] = ACTIONS(5498),
    [anon_sym_default] = ACTIONS(5500),
    [anon_sym_clocking] = ACTIONS(5500),
    [anon_sym_defparam] = ACTIONS(5500),
    [anon_sym_bind] = ACTIONS(5500),
    [anon_sym_const] = ACTIONS(5500),
    [anon_sym_function] = ACTIONS(5500),
    [anon_sym_static] = ACTIONS(5500),
    [anon_sym_constraint] = ACTIONS(5500),
    [anon_sym_if] = ACTIONS(5500),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_localparam] = ACTIONS(5500),
    [anon_sym_parameter] = ACTIONS(5500),
    [anon_sym_specparam] = ACTIONS(5500),
    [anon_sym_var] = ACTIONS(5500),
    [anon_sym_import] = ACTIONS(5500),
    [anon_sym_export] = ACTIONS(5500),
    [anon_sym_genvar] = ACTIONS(5500),
    [anon_sym_interconnect] = ACTIONS(5500),
    [anon_sym_typedef] = ACTIONS(5500),
    [anon_sym_enum] = ACTIONS(5500),
    [anon_sym_struct] = ACTIONS(5500),
    [anon_sym_union] = ACTIONS(5500),
    [anon_sym_nettype] = ACTIONS(5500),
    [anon_sym_automatic] = ACTIONS(5500),
    [anon_sym_string] = ACTIONS(5500),
    [anon_sym_chandle] = ACTIONS(5500),
    [anon_sym_event] = ACTIONS(5500),
    [anon_sym_byte] = ACTIONS(5500),
    [anon_sym_shortint] = ACTIONS(5500),
    [anon_sym_int] = ACTIONS(5500),
    [anon_sym_longint] = ACTIONS(5500),
    [anon_sym_integer] = ACTIONS(5500),
    [anon_sym_time] = ACTIONS(5500),
    [anon_sym_bit] = ACTIONS(5500),
    [anon_sym_logic] = ACTIONS(5500),
    [anon_sym_reg] = ACTIONS(5500),
    [anon_sym_shortreal] = ACTIONS(5500),
    [anon_sym_real] = ACTIONS(5500),
    [anon_sym_realtime] = ACTIONS(5500),
    [anon_sym_supply0] = ACTIONS(5500),
    [anon_sym_supply1] = ACTIONS(5500),
    [anon_sym_signed] = ACTIONS(5500),
    [anon_sym_unsigned] = ACTIONS(5500),
    [anon_sym_task] = ACTIONS(5500),
    [anon_sym_modport] = ACTIONS(5500),
    [anon_sym_assert] = ACTIONS(5500),
    [anon_sym_property] = ACTIONS(5500),
    [anon_sym_assume] = ACTIONS(5500),
    [anon_sym_cover] = ACTIONS(5500),
    [anon_sym_sequence] = ACTIONS(5500),
    [anon_sym_restrict] = ACTIONS(5500),
    [anon_sym_not] = ACTIONS(5500),
    [anon_sym_or] = ACTIONS(5500),
    [anon_sym_and] = ACTIONS(5500),
    [anon_sym_case] = ACTIONS(5500),
    [anon_sym_always] = ACTIONS(5500),
    [anon_sym_covergroup] = ACTIONS(5500),
    [anon_sym_let] = ACTIONS(5500),
    [anon_sym_pulldown] = ACTIONS(5500),
    [anon_sym_pullup] = ACTIONS(5500),
    [anon_sym_cmos] = ACTIONS(5500),
    [anon_sym_rcmos] = ACTIONS(5500),
    [anon_sym_bufif0] = ACTIONS(5500),
    [anon_sym_bufif1] = ACTIONS(5500),
    [anon_sym_notif0] = ACTIONS(5500),
    [anon_sym_notif1] = ACTIONS(5500),
    [anon_sym_nmos] = ACTIONS(5500),
    [anon_sym_pmos] = ACTIONS(5500),
    [anon_sym_rnmos] = ACTIONS(5500),
    [anon_sym_rpmos] = ACTIONS(5500),
    [anon_sym_nand] = ACTIONS(5500),
    [anon_sym_nor] = ACTIONS(5500),
    [anon_sym_xor] = ACTIONS(5500),
    [anon_sym_xnor] = ACTIONS(5500),
    [anon_sym_buf] = ACTIONS(5500),
    [anon_sym_tranif0] = ACTIONS(5500),
    [anon_sym_tranif1] = ACTIONS(5500),
    [anon_sym_rtranif1] = ACTIONS(5500),
    [anon_sym_rtranif0] = ACTIONS(5500),
    [anon_sym_tran] = ACTIONS(5500),
    [anon_sym_rtran] = ACTIONS(5500),
    [anon_sym_generate] = ACTIONS(5500),
    [anon_sym_for] = ACTIONS(5500),
    [anon_sym_primitive] = ACTIONS(5500),
    [anon_sym_initial] = ACTIONS(5500),
    [anon_sym_assign] = ACTIONS(5500),
    [anon_sym_alias] = ACTIONS(5500),
    [anon_sym_always_comb] = ACTIONS(5500),
    [anon_sym_always_latch] = ACTIONS(5500),
    [anon_sym_always_ff] = ACTIONS(5500),
    [anon_sym_final] = ACTIONS(5500),
    [anon_sym_global] = ACTIONS(5500),
    [anon_sym_specify] = ACTIONS(5500),
    [anon_sym_LPAREN_STAR] = ACTIONS(5498),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5498),
    [anon_sym_DOLLARunit] = ACTIONS(5498),
  },
  [972] = {
    [ts_builtin_sym_end] = ACTIONS(5504),
    [sym_simple_identifier] = ACTIONS(5506),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5504),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5504),
    [anon_sym_BQUOTE] = ACTIONS(5506),
    [aux_sym_id_directive_token1] = ACTIONS(5504),
    [aux_sym_id_directive_token2] = ACTIONS(5504),
    [aux_sym_id_directive_token3] = ACTIONS(5504),
    [aux_sym_id_directive_token4] = ACTIONS(5506),
    [aux_sym_zero_directive_token1] = ACTIONS(5504),
    [aux_sym_zero_directive_token2] = ACTIONS(5504),
    [aux_sym_zero_directive_token3] = ACTIONS(5504),
    [aux_sym_zero_directive_token4] = ACTIONS(5504),
    [aux_sym_zero_directive_token5] = ACTIONS(5504),
    [aux_sym_zero_directive_token6] = ACTIONS(5504),
    [aux_sym_zero_directive_token7] = ACTIONS(5504),
    [aux_sym_zero_directive_token8] = ACTIONS(5504),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5504),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5504),
    [anon_sym_wire] = ACTIONS(5506),
    [anon_sym_tri] = ACTIONS(5506),
    [anon_sym_tri0] = ACTIONS(5506),
    [anon_sym_tri1] = ACTIONS(5506),
    [anon_sym_wand] = ACTIONS(5506),
    [anon_sym_triand] = ACTIONS(5506),
    [anon_sym_wor] = ACTIONS(5506),
    [anon_sym_trior] = ACTIONS(5506),
    [anon_sym_trireg] = ACTIONS(5506),
    [anon_sym_uwire] = ACTIONS(5506),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5504),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5504),
    [aux_sym_begin_keywords_token1] = ACTIONS(5504),
    [anon_sym_SEMI] = ACTIONS(5504),
    [anon_sym_endmodule] = ACTIONS(5506),
    [anon_sym_COLON] = ACTIONS(5508),
    [anon_sym_extern] = ACTIONS(5506),
    [anon_sym_module] = ACTIONS(5506),
    [anon_sym_macromodule] = ACTIONS(5506),
    [anon_sym_endinterface] = ACTIONS(5506),
    [anon_sym_interface] = ACTIONS(5506),
    [anon_sym_program] = ACTIONS(5506),
    [anon_sym_checker] = ACTIONS(5506),
    [anon_sym_virtual] = ACTIONS(5506),
    [anon_sym_class] = ACTIONS(5506),
    [anon_sym_package] = ACTIONS(5506),
    [anon_sym_timeunit] = ACTIONS(5506),
    [anon_sym_timeprecision] = ACTIONS(5506),
    [anon_sym_type] = ACTIONS(5506),
    [anon_sym_input] = ACTIONS(5506),
    [anon_sym_output] = ACTIONS(5506),
    [anon_sym_inout] = ACTIONS(5506),
    [anon_sym_ref] = ACTIONS(5506),
    [anon_sym_DOLLARfatal] = ACTIONS(5504),
    [anon_sym_DOLLARerror] = ACTIONS(5504),
    [anon_sym_DOLLARwarning] = ACTIONS(5504),
    [anon_sym_DOLLARinfo] = ACTIONS(5504),
    [anon_sym_default] = ACTIONS(5506),
    [anon_sym_clocking] = ACTIONS(5506),
    [anon_sym_defparam] = ACTIONS(5506),
    [anon_sym_bind] = ACTIONS(5506),
    [anon_sym_const] = ACTIONS(5506),
    [anon_sym_function] = ACTIONS(5506),
    [anon_sym_static] = ACTIONS(5506),
    [anon_sym_constraint] = ACTIONS(5506),
    [anon_sym_if] = ACTIONS(5506),
    [anon_sym_LBRACK] = ACTIONS(5504),
    [anon_sym_localparam] = ACTIONS(5506),
    [anon_sym_parameter] = ACTIONS(5506),
    [anon_sym_specparam] = ACTIONS(5506),
    [anon_sym_var] = ACTIONS(5506),
    [anon_sym_import] = ACTIONS(5506),
    [anon_sym_export] = ACTIONS(5506),
    [anon_sym_genvar] = ACTIONS(5506),
    [anon_sym_interconnect] = ACTIONS(5506),
    [anon_sym_typedef] = ACTIONS(5506),
    [anon_sym_enum] = ACTIONS(5506),
    [anon_sym_struct] = ACTIONS(5506),
    [anon_sym_union] = ACTIONS(5506),
    [anon_sym_nettype] = ACTIONS(5506),
    [anon_sym_automatic] = ACTIONS(5506),
    [anon_sym_string] = ACTIONS(5506),
    [anon_sym_chandle] = ACTIONS(5506),
    [anon_sym_event] = ACTIONS(5506),
    [anon_sym_byte] = ACTIONS(5506),
    [anon_sym_shortint] = ACTIONS(5506),
    [anon_sym_int] = ACTIONS(5506),
    [anon_sym_longint] = ACTIONS(5506),
    [anon_sym_integer] = ACTIONS(5506),
    [anon_sym_time] = ACTIONS(5506),
    [anon_sym_bit] = ACTIONS(5506),
    [anon_sym_logic] = ACTIONS(5506),
    [anon_sym_reg] = ACTIONS(5506),
    [anon_sym_shortreal] = ACTIONS(5506),
    [anon_sym_real] = ACTIONS(5506),
    [anon_sym_realtime] = ACTIONS(5506),
    [anon_sym_supply0] = ACTIONS(5506),
    [anon_sym_supply1] = ACTIONS(5506),
    [anon_sym_signed] = ACTIONS(5506),
    [anon_sym_unsigned] = ACTIONS(5506),
    [anon_sym_task] = ACTIONS(5506),
    [anon_sym_modport] = ACTIONS(5506),
    [anon_sym_assert] = ACTIONS(5506),
    [anon_sym_property] = ACTIONS(5506),
    [anon_sym_assume] = ACTIONS(5506),
    [anon_sym_cover] = ACTIONS(5506),
    [anon_sym_sequence] = ACTIONS(5506),
    [anon_sym_restrict] = ACTIONS(5506),
    [anon_sym_not] = ACTIONS(5506),
    [anon_sym_or] = ACTIONS(5506),
    [anon_sym_and] = ACTIONS(5506),
    [anon_sym_case] = ACTIONS(5506),
    [anon_sym_always] = ACTIONS(5506),
    [anon_sym_covergroup] = ACTIONS(5506),
    [anon_sym_let] = ACTIONS(5506),
    [anon_sym_pulldown] = ACTIONS(5506),
    [anon_sym_pullup] = ACTIONS(5506),
    [anon_sym_cmos] = ACTIONS(5506),
    [anon_sym_rcmos] = ACTIONS(5506),
    [anon_sym_bufif0] = ACTIONS(5506),
    [anon_sym_bufif1] = ACTIONS(5506),
    [anon_sym_notif0] = ACTIONS(5506),
    [anon_sym_notif1] = ACTIONS(5506),
    [anon_sym_nmos] = ACTIONS(5506),
    [anon_sym_pmos] = ACTIONS(5506),
    [anon_sym_rnmos] = ACTIONS(5506),
    [anon_sym_rpmos] = ACTIONS(5506),
    [anon_sym_nand] = ACTIONS(5506),
    [anon_sym_nor] = ACTIONS(5506),
    [anon_sym_xor] = ACTIONS(5506),
    [anon_sym_xnor] = ACTIONS(5506),
    [anon_sym_buf] = ACTIONS(5506),
    [anon_sym_tranif0] = ACTIONS(5506),
    [anon_sym_tranif1] = ACTIONS(5506),
    [anon_sym_rtranif1] = ACTIONS(5506),
    [anon_sym_rtranif0] = ACTIONS(5506),
    [anon_sym_tran] = ACTIONS(5506),
    [anon_sym_rtran] = ACTIONS(5506),
    [anon_sym_generate] = ACTIONS(5506),
    [anon_sym_for] = ACTIONS(5506),
    [anon_sym_primitive] = ACTIONS(5506),
    [anon_sym_initial] = ACTIONS(5506),
    [anon_sym_assign] = ACTIONS(5506),
    [anon_sym_alias] = ACTIONS(5506),
    [anon_sym_always_comb] = ACTIONS(5506),
    [anon_sym_always_latch] = ACTIONS(5506),
    [anon_sym_always_ff] = ACTIONS(5506),
    [anon_sym_final] = ACTIONS(5506),
    [anon_sym_global] = ACTIONS(5506),
    [anon_sym_specify] = ACTIONS(5506),
    [anon_sym_LPAREN_STAR] = ACTIONS(5504),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5504),
    [anon_sym_DOLLARunit] = ACTIONS(5504),
  },
  [973] = {
    [ts_builtin_sym_end] = ACTIONS(5510),
    [sym_simple_identifier] = ACTIONS(5512),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5510),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5510),
    [anon_sym_BQUOTE] = ACTIONS(5512),
    [aux_sym_id_directive_token1] = ACTIONS(5510),
    [aux_sym_id_directive_token2] = ACTIONS(5510),
    [aux_sym_id_directive_token3] = ACTIONS(5510),
    [aux_sym_id_directive_token4] = ACTIONS(5512),
    [aux_sym_zero_directive_token1] = ACTIONS(5510),
    [aux_sym_zero_directive_token2] = ACTIONS(5510),
    [aux_sym_zero_directive_token3] = ACTIONS(5510),
    [aux_sym_zero_directive_token4] = ACTIONS(5510),
    [aux_sym_zero_directive_token5] = ACTIONS(5510),
    [aux_sym_zero_directive_token6] = ACTIONS(5510),
    [aux_sym_zero_directive_token7] = ACTIONS(5510),
    [aux_sym_zero_directive_token8] = ACTIONS(5510),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5510),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5510),
    [anon_sym_wire] = ACTIONS(5512),
    [anon_sym_tri] = ACTIONS(5512),
    [anon_sym_tri0] = ACTIONS(5512),
    [anon_sym_tri1] = ACTIONS(5512),
    [anon_sym_wand] = ACTIONS(5512),
    [anon_sym_triand] = ACTIONS(5512),
    [anon_sym_wor] = ACTIONS(5512),
    [anon_sym_trior] = ACTIONS(5512),
    [anon_sym_trireg] = ACTIONS(5512),
    [anon_sym_uwire] = ACTIONS(5512),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5510),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5510),
    [aux_sym_begin_keywords_token1] = ACTIONS(5510),
    [anon_sym_SEMI] = ACTIONS(5510),
    [anon_sym_endmodule] = ACTIONS(5512),
    [anon_sym_extern] = ACTIONS(5512),
    [anon_sym_module] = ACTIONS(5512),
    [anon_sym_macromodule] = ACTIONS(5512),
    [anon_sym_endinterface] = ACTIONS(5512),
    [anon_sym_interface] = ACTIONS(5512),
    [anon_sym_endprogram] = ACTIONS(5512),
    [anon_sym_program] = ACTIONS(5512),
    [anon_sym_checker] = ACTIONS(5512),
    [anon_sym_virtual] = ACTIONS(5512),
    [anon_sym_class] = ACTIONS(5512),
    [anon_sym_package] = ACTIONS(5512),
    [anon_sym_timeunit] = ACTIONS(5512),
    [anon_sym_timeprecision] = ACTIONS(5512),
    [anon_sym_type] = ACTIONS(5512),
    [anon_sym_input] = ACTIONS(5512),
    [anon_sym_output] = ACTIONS(5512),
    [anon_sym_inout] = ACTIONS(5512),
    [anon_sym_ref] = ACTIONS(5512),
    [anon_sym_DOLLARfatal] = ACTIONS(5510),
    [anon_sym_DOLLARerror] = ACTIONS(5510),
    [anon_sym_DOLLARwarning] = ACTIONS(5510),
    [anon_sym_DOLLARinfo] = ACTIONS(5510),
    [anon_sym_default] = ACTIONS(5512),
    [anon_sym_clocking] = ACTIONS(5512),
    [anon_sym_defparam] = ACTIONS(5512),
    [anon_sym_bind] = ACTIONS(5512),
    [anon_sym_const] = ACTIONS(5512),
    [anon_sym_function] = ACTIONS(5512),
    [anon_sym_static] = ACTIONS(5512),
    [anon_sym_constraint] = ACTIONS(5512),
    [anon_sym_if] = ACTIONS(5512),
    [anon_sym_LBRACK] = ACTIONS(5510),
    [anon_sym_localparam] = ACTIONS(5512),
    [anon_sym_parameter] = ACTIONS(5512),
    [anon_sym_specparam] = ACTIONS(5512),
    [anon_sym_var] = ACTIONS(5512),
    [anon_sym_import] = ACTIONS(5512),
    [anon_sym_export] = ACTIONS(5512),
    [anon_sym_genvar] = ACTIONS(5512),
    [anon_sym_interconnect] = ACTIONS(5512),
    [anon_sym_typedef] = ACTIONS(5512),
    [anon_sym_enum] = ACTIONS(5512),
    [anon_sym_struct] = ACTIONS(5512),
    [anon_sym_union] = ACTIONS(5512),
    [anon_sym_nettype] = ACTIONS(5512),
    [anon_sym_automatic] = ACTIONS(5512),
    [anon_sym_string] = ACTIONS(5512),
    [anon_sym_chandle] = ACTIONS(5512),
    [anon_sym_event] = ACTIONS(5512),
    [anon_sym_byte] = ACTIONS(5512),
    [anon_sym_shortint] = ACTIONS(5512),
    [anon_sym_int] = ACTIONS(5512),
    [anon_sym_longint] = ACTIONS(5512),
    [anon_sym_integer] = ACTIONS(5512),
    [anon_sym_time] = ACTIONS(5512),
    [anon_sym_bit] = ACTIONS(5512),
    [anon_sym_logic] = ACTIONS(5512),
    [anon_sym_reg] = ACTIONS(5512),
    [anon_sym_shortreal] = ACTIONS(5512),
    [anon_sym_real] = ACTIONS(5512),
    [anon_sym_realtime] = ACTIONS(5512),
    [anon_sym_supply0] = ACTIONS(5512),
    [anon_sym_supply1] = ACTIONS(5512),
    [anon_sym_signed] = ACTIONS(5512),
    [anon_sym_unsigned] = ACTIONS(5512),
    [anon_sym_task] = ACTIONS(5512),
    [anon_sym_modport] = ACTIONS(5512),
    [anon_sym_assert] = ACTIONS(5512),
    [anon_sym_property] = ACTIONS(5512),
    [anon_sym_assume] = ACTIONS(5512),
    [anon_sym_cover] = ACTIONS(5512),
    [anon_sym_sequence] = ACTIONS(5512),
    [anon_sym_restrict] = ACTIONS(5512),
    [anon_sym_not] = ACTIONS(5512),
    [anon_sym_or] = ACTIONS(5512),
    [anon_sym_and] = ACTIONS(5512),
    [anon_sym_case] = ACTIONS(5512),
    [anon_sym_always] = ACTIONS(5512),
    [anon_sym_covergroup] = ACTIONS(5512),
    [anon_sym_let] = ACTIONS(5512),
    [anon_sym_pulldown] = ACTIONS(5512),
    [anon_sym_pullup] = ACTIONS(5512),
    [anon_sym_cmos] = ACTIONS(5512),
    [anon_sym_rcmos] = ACTIONS(5512),
    [anon_sym_bufif0] = ACTIONS(5512),
    [anon_sym_bufif1] = ACTIONS(5512),
    [anon_sym_notif0] = ACTIONS(5512),
    [anon_sym_notif1] = ACTIONS(5512),
    [anon_sym_nmos] = ACTIONS(5512),
    [anon_sym_pmos] = ACTIONS(5512),
    [anon_sym_rnmos] = ACTIONS(5512),
    [anon_sym_rpmos] = ACTIONS(5512),
    [anon_sym_nand] = ACTIONS(5512),
    [anon_sym_nor] = ACTIONS(5512),
    [anon_sym_xor] = ACTIONS(5512),
    [anon_sym_xnor] = ACTIONS(5512),
    [anon_sym_buf] = ACTIONS(5512),
    [anon_sym_tranif0] = ACTIONS(5512),
    [anon_sym_tranif1] = ACTIONS(5512),
    [anon_sym_rtranif1] = ACTIONS(5512),
    [anon_sym_rtranif0] = ACTIONS(5512),
    [anon_sym_tran] = ACTIONS(5512),
    [anon_sym_rtran] = ACTIONS(5512),
    [anon_sym_generate] = ACTIONS(5512),
    [anon_sym_for] = ACTIONS(5512),
    [anon_sym_primitive] = ACTIONS(5512),
    [anon_sym_initial] = ACTIONS(5512),
    [anon_sym_assign] = ACTIONS(5512),
    [anon_sym_alias] = ACTIONS(5512),
    [anon_sym_always_comb] = ACTIONS(5512),
    [anon_sym_always_latch] = ACTIONS(5512),
    [anon_sym_always_ff] = ACTIONS(5512),
    [anon_sym_final] = ACTIONS(5512),
    [anon_sym_global] = ACTIONS(5512),
    [anon_sym_specify] = ACTIONS(5512),
    [anon_sym_LPAREN_STAR] = ACTIONS(5510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5510),
    [anon_sym_DOLLARunit] = ACTIONS(5510),
  },
  [974] = {
    [ts_builtin_sym_end] = ACTIONS(5514),
    [sym_simple_identifier] = ACTIONS(5516),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5514),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5514),
    [anon_sym_BQUOTE] = ACTIONS(5516),
    [aux_sym_id_directive_token1] = ACTIONS(5514),
    [aux_sym_id_directive_token2] = ACTIONS(5514),
    [aux_sym_id_directive_token3] = ACTIONS(5514),
    [aux_sym_id_directive_token4] = ACTIONS(5516),
    [aux_sym_zero_directive_token1] = ACTIONS(5514),
    [aux_sym_zero_directive_token2] = ACTIONS(5514),
    [aux_sym_zero_directive_token3] = ACTIONS(5514),
    [aux_sym_zero_directive_token4] = ACTIONS(5514),
    [aux_sym_zero_directive_token5] = ACTIONS(5514),
    [aux_sym_zero_directive_token6] = ACTIONS(5514),
    [aux_sym_zero_directive_token7] = ACTIONS(5514),
    [aux_sym_zero_directive_token8] = ACTIONS(5514),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5514),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5514),
    [anon_sym_wire] = ACTIONS(5516),
    [anon_sym_tri] = ACTIONS(5516),
    [anon_sym_tri0] = ACTIONS(5516),
    [anon_sym_tri1] = ACTIONS(5516),
    [anon_sym_wand] = ACTIONS(5516),
    [anon_sym_triand] = ACTIONS(5516),
    [anon_sym_wor] = ACTIONS(5516),
    [anon_sym_trior] = ACTIONS(5516),
    [anon_sym_trireg] = ACTIONS(5516),
    [anon_sym_uwire] = ACTIONS(5516),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5514),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5514),
    [aux_sym_begin_keywords_token1] = ACTIONS(5514),
    [anon_sym_SEMI] = ACTIONS(5514),
    [anon_sym_endmodule] = ACTIONS(5516),
    [anon_sym_extern] = ACTIONS(5516),
    [anon_sym_module] = ACTIONS(5516),
    [anon_sym_macromodule] = ACTIONS(5516),
    [anon_sym_endinterface] = ACTIONS(5516),
    [anon_sym_interface] = ACTIONS(5516),
    [anon_sym_endprogram] = ACTIONS(5516),
    [anon_sym_program] = ACTIONS(5516),
    [anon_sym_checker] = ACTIONS(5516),
    [anon_sym_virtual] = ACTIONS(5516),
    [anon_sym_class] = ACTIONS(5516),
    [anon_sym_package] = ACTIONS(5516),
    [anon_sym_timeunit] = ACTIONS(5516),
    [anon_sym_timeprecision] = ACTIONS(5516),
    [anon_sym_type] = ACTIONS(5516),
    [anon_sym_input] = ACTIONS(5516),
    [anon_sym_output] = ACTIONS(5516),
    [anon_sym_inout] = ACTIONS(5516),
    [anon_sym_ref] = ACTIONS(5516),
    [anon_sym_DOLLARfatal] = ACTIONS(5514),
    [anon_sym_DOLLARerror] = ACTIONS(5514),
    [anon_sym_DOLLARwarning] = ACTIONS(5514),
    [anon_sym_DOLLARinfo] = ACTIONS(5514),
    [anon_sym_default] = ACTIONS(5516),
    [anon_sym_clocking] = ACTIONS(5516),
    [anon_sym_defparam] = ACTIONS(5516),
    [anon_sym_bind] = ACTIONS(5516),
    [anon_sym_const] = ACTIONS(5516),
    [anon_sym_function] = ACTIONS(5516),
    [anon_sym_static] = ACTIONS(5516),
    [anon_sym_constraint] = ACTIONS(5516),
    [anon_sym_if] = ACTIONS(5516),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_localparam] = ACTIONS(5516),
    [anon_sym_parameter] = ACTIONS(5516),
    [anon_sym_specparam] = ACTIONS(5516),
    [anon_sym_var] = ACTIONS(5516),
    [anon_sym_import] = ACTIONS(5516),
    [anon_sym_export] = ACTIONS(5516),
    [anon_sym_genvar] = ACTIONS(5516),
    [anon_sym_interconnect] = ACTIONS(5516),
    [anon_sym_typedef] = ACTIONS(5516),
    [anon_sym_enum] = ACTIONS(5516),
    [anon_sym_struct] = ACTIONS(5516),
    [anon_sym_union] = ACTIONS(5516),
    [anon_sym_nettype] = ACTIONS(5516),
    [anon_sym_automatic] = ACTIONS(5516),
    [anon_sym_string] = ACTIONS(5516),
    [anon_sym_chandle] = ACTIONS(5516),
    [anon_sym_event] = ACTIONS(5516),
    [anon_sym_byte] = ACTIONS(5516),
    [anon_sym_shortint] = ACTIONS(5516),
    [anon_sym_int] = ACTIONS(5516),
    [anon_sym_longint] = ACTIONS(5516),
    [anon_sym_integer] = ACTIONS(5516),
    [anon_sym_time] = ACTIONS(5516),
    [anon_sym_bit] = ACTIONS(5516),
    [anon_sym_logic] = ACTIONS(5516),
    [anon_sym_reg] = ACTIONS(5516),
    [anon_sym_shortreal] = ACTIONS(5516),
    [anon_sym_real] = ACTIONS(5516),
    [anon_sym_realtime] = ACTIONS(5516),
    [anon_sym_supply0] = ACTIONS(5516),
    [anon_sym_supply1] = ACTIONS(5516),
    [anon_sym_signed] = ACTIONS(5516),
    [anon_sym_unsigned] = ACTIONS(5516),
    [anon_sym_task] = ACTIONS(5516),
    [anon_sym_modport] = ACTIONS(5516),
    [anon_sym_assert] = ACTIONS(5516),
    [anon_sym_property] = ACTIONS(5516),
    [anon_sym_assume] = ACTIONS(5516),
    [anon_sym_cover] = ACTIONS(5516),
    [anon_sym_sequence] = ACTIONS(5516),
    [anon_sym_restrict] = ACTIONS(5516),
    [anon_sym_not] = ACTIONS(5516),
    [anon_sym_or] = ACTIONS(5516),
    [anon_sym_and] = ACTIONS(5516),
    [anon_sym_case] = ACTIONS(5516),
    [anon_sym_always] = ACTIONS(5516),
    [anon_sym_covergroup] = ACTIONS(5516),
    [anon_sym_let] = ACTIONS(5516),
    [anon_sym_pulldown] = ACTIONS(5516),
    [anon_sym_pullup] = ACTIONS(5516),
    [anon_sym_cmos] = ACTIONS(5516),
    [anon_sym_rcmos] = ACTIONS(5516),
    [anon_sym_bufif0] = ACTIONS(5516),
    [anon_sym_bufif1] = ACTIONS(5516),
    [anon_sym_notif0] = ACTIONS(5516),
    [anon_sym_notif1] = ACTIONS(5516),
    [anon_sym_nmos] = ACTIONS(5516),
    [anon_sym_pmos] = ACTIONS(5516),
    [anon_sym_rnmos] = ACTIONS(5516),
    [anon_sym_rpmos] = ACTIONS(5516),
    [anon_sym_nand] = ACTIONS(5516),
    [anon_sym_nor] = ACTIONS(5516),
    [anon_sym_xor] = ACTIONS(5516),
    [anon_sym_xnor] = ACTIONS(5516),
    [anon_sym_buf] = ACTIONS(5516),
    [anon_sym_tranif0] = ACTIONS(5516),
    [anon_sym_tranif1] = ACTIONS(5516),
    [anon_sym_rtranif1] = ACTIONS(5516),
    [anon_sym_rtranif0] = ACTIONS(5516),
    [anon_sym_tran] = ACTIONS(5516),
    [anon_sym_rtran] = ACTIONS(5516),
    [anon_sym_generate] = ACTIONS(5516),
    [anon_sym_for] = ACTIONS(5516),
    [anon_sym_primitive] = ACTIONS(5516),
    [anon_sym_initial] = ACTIONS(5516),
    [anon_sym_assign] = ACTIONS(5516),
    [anon_sym_alias] = ACTIONS(5516),
    [anon_sym_always_comb] = ACTIONS(5516),
    [anon_sym_always_latch] = ACTIONS(5516),
    [anon_sym_always_ff] = ACTIONS(5516),
    [anon_sym_final] = ACTIONS(5516),
    [anon_sym_global] = ACTIONS(5516),
    [anon_sym_specify] = ACTIONS(5516),
    [anon_sym_LPAREN_STAR] = ACTIONS(5514),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5514),
    [anon_sym_DOLLARunit] = ACTIONS(5514),
  },
  [975] = {
    [ts_builtin_sym_end] = ACTIONS(5518),
    [sym_simple_identifier] = ACTIONS(5520),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5518),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5518),
    [anon_sym_BQUOTE] = ACTIONS(5520),
    [aux_sym_id_directive_token1] = ACTIONS(5518),
    [aux_sym_id_directive_token2] = ACTIONS(5518),
    [aux_sym_id_directive_token3] = ACTIONS(5518),
    [aux_sym_id_directive_token4] = ACTIONS(5520),
    [aux_sym_zero_directive_token1] = ACTIONS(5518),
    [aux_sym_zero_directive_token2] = ACTIONS(5518),
    [aux_sym_zero_directive_token3] = ACTIONS(5518),
    [aux_sym_zero_directive_token4] = ACTIONS(5518),
    [aux_sym_zero_directive_token5] = ACTIONS(5518),
    [aux_sym_zero_directive_token6] = ACTIONS(5518),
    [aux_sym_zero_directive_token7] = ACTIONS(5518),
    [aux_sym_zero_directive_token8] = ACTIONS(5518),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5518),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5518),
    [anon_sym_wire] = ACTIONS(5520),
    [anon_sym_tri] = ACTIONS(5520),
    [anon_sym_tri0] = ACTIONS(5520),
    [anon_sym_tri1] = ACTIONS(5520),
    [anon_sym_wand] = ACTIONS(5520),
    [anon_sym_triand] = ACTIONS(5520),
    [anon_sym_wor] = ACTIONS(5520),
    [anon_sym_trior] = ACTIONS(5520),
    [anon_sym_trireg] = ACTIONS(5520),
    [anon_sym_uwire] = ACTIONS(5520),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5518),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5518),
    [aux_sym_begin_keywords_token1] = ACTIONS(5518),
    [anon_sym_SEMI] = ACTIONS(5518),
    [anon_sym_endmodule] = ACTIONS(5520),
    [anon_sym_COLON] = ACTIONS(5522),
    [anon_sym_extern] = ACTIONS(5520),
    [anon_sym_module] = ACTIONS(5520),
    [anon_sym_macromodule] = ACTIONS(5520),
    [anon_sym_endinterface] = ACTIONS(5520),
    [anon_sym_interface] = ACTIONS(5520),
    [anon_sym_program] = ACTIONS(5520),
    [anon_sym_checker] = ACTIONS(5520),
    [anon_sym_virtual] = ACTIONS(5520),
    [anon_sym_class] = ACTIONS(5520),
    [anon_sym_package] = ACTIONS(5520),
    [anon_sym_timeunit] = ACTIONS(5520),
    [anon_sym_timeprecision] = ACTIONS(5520),
    [anon_sym_type] = ACTIONS(5520),
    [anon_sym_input] = ACTIONS(5520),
    [anon_sym_output] = ACTIONS(5520),
    [anon_sym_inout] = ACTIONS(5520),
    [anon_sym_ref] = ACTIONS(5520),
    [anon_sym_DOLLARfatal] = ACTIONS(5518),
    [anon_sym_DOLLARerror] = ACTIONS(5518),
    [anon_sym_DOLLARwarning] = ACTIONS(5518),
    [anon_sym_DOLLARinfo] = ACTIONS(5518),
    [anon_sym_default] = ACTIONS(5520),
    [anon_sym_clocking] = ACTIONS(5520),
    [anon_sym_defparam] = ACTIONS(5520),
    [anon_sym_bind] = ACTIONS(5520),
    [anon_sym_const] = ACTIONS(5520),
    [anon_sym_function] = ACTIONS(5520),
    [anon_sym_static] = ACTIONS(5520),
    [anon_sym_constraint] = ACTIONS(5520),
    [anon_sym_if] = ACTIONS(5520),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_localparam] = ACTIONS(5520),
    [anon_sym_parameter] = ACTIONS(5520),
    [anon_sym_specparam] = ACTIONS(5520),
    [anon_sym_var] = ACTIONS(5520),
    [anon_sym_import] = ACTIONS(5520),
    [anon_sym_export] = ACTIONS(5520),
    [anon_sym_genvar] = ACTIONS(5520),
    [anon_sym_interconnect] = ACTIONS(5520),
    [anon_sym_typedef] = ACTIONS(5520),
    [anon_sym_enum] = ACTIONS(5520),
    [anon_sym_struct] = ACTIONS(5520),
    [anon_sym_union] = ACTIONS(5520),
    [anon_sym_nettype] = ACTIONS(5520),
    [anon_sym_automatic] = ACTIONS(5520),
    [anon_sym_string] = ACTIONS(5520),
    [anon_sym_chandle] = ACTIONS(5520),
    [anon_sym_event] = ACTIONS(5520),
    [anon_sym_byte] = ACTIONS(5520),
    [anon_sym_shortint] = ACTIONS(5520),
    [anon_sym_int] = ACTIONS(5520),
    [anon_sym_longint] = ACTIONS(5520),
    [anon_sym_integer] = ACTIONS(5520),
    [anon_sym_time] = ACTIONS(5520),
    [anon_sym_bit] = ACTIONS(5520),
    [anon_sym_logic] = ACTIONS(5520),
    [anon_sym_reg] = ACTIONS(5520),
    [anon_sym_shortreal] = ACTIONS(5520),
    [anon_sym_real] = ACTIONS(5520),
    [anon_sym_realtime] = ACTIONS(5520),
    [anon_sym_supply0] = ACTIONS(5520),
    [anon_sym_supply1] = ACTIONS(5520),
    [anon_sym_signed] = ACTIONS(5520),
    [anon_sym_unsigned] = ACTIONS(5520),
    [anon_sym_task] = ACTIONS(5520),
    [anon_sym_modport] = ACTIONS(5520),
    [anon_sym_assert] = ACTIONS(5520),
    [anon_sym_property] = ACTIONS(5520),
    [anon_sym_assume] = ACTIONS(5520),
    [anon_sym_cover] = ACTIONS(5520),
    [anon_sym_sequence] = ACTIONS(5520),
    [anon_sym_restrict] = ACTIONS(5520),
    [anon_sym_not] = ACTIONS(5520),
    [anon_sym_or] = ACTIONS(5520),
    [anon_sym_and] = ACTIONS(5520),
    [anon_sym_case] = ACTIONS(5520),
    [anon_sym_always] = ACTIONS(5520),
    [anon_sym_covergroup] = ACTIONS(5520),
    [anon_sym_let] = ACTIONS(5520),
    [anon_sym_pulldown] = ACTIONS(5520),
    [anon_sym_pullup] = ACTIONS(5520),
    [anon_sym_cmos] = ACTIONS(5520),
    [anon_sym_rcmos] = ACTIONS(5520),
    [anon_sym_bufif0] = ACTIONS(5520),
    [anon_sym_bufif1] = ACTIONS(5520),
    [anon_sym_notif0] = ACTIONS(5520),
    [anon_sym_notif1] = ACTIONS(5520),
    [anon_sym_nmos] = ACTIONS(5520),
    [anon_sym_pmos] = ACTIONS(5520),
    [anon_sym_rnmos] = ACTIONS(5520),
    [anon_sym_rpmos] = ACTIONS(5520),
    [anon_sym_nand] = ACTIONS(5520),
    [anon_sym_nor] = ACTIONS(5520),
    [anon_sym_xor] = ACTIONS(5520),
    [anon_sym_xnor] = ACTIONS(5520),
    [anon_sym_buf] = ACTIONS(5520),
    [anon_sym_tranif0] = ACTIONS(5520),
    [anon_sym_tranif1] = ACTIONS(5520),
    [anon_sym_rtranif1] = ACTIONS(5520),
    [anon_sym_rtranif0] = ACTIONS(5520),
    [anon_sym_tran] = ACTIONS(5520),
    [anon_sym_rtran] = ACTIONS(5520),
    [anon_sym_generate] = ACTIONS(5520),
    [anon_sym_for] = ACTIONS(5520),
    [anon_sym_primitive] = ACTIONS(5520),
    [anon_sym_initial] = ACTIONS(5520),
    [anon_sym_assign] = ACTIONS(5520),
    [anon_sym_alias] = ACTIONS(5520),
    [anon_sym_always_comb] = ACTIONS(5520),
    [anon_sym_always_latch] = ACTIONS(5520),
    [anon_sym_always_ff] = ACTIONS(5520),
    [anon_sym_final] = ACTIONS(5520),
    [anon_sym_global] = ACTIONS(5520),
    [anon_sym_specify] = ACTIONS(5520),
    [anon_sym_LPAREN_STAR] = ACTIONS(5518),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5518),
    [anon_sym_DOLLARunit] = ACTIONS(5518),
  },
  [976] = {
    [ts_builtin_sym_end] = ACTIONS(5524),
    [sym_simple_identifier] = ACTIONS(5526),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5524),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5524),
    [anon_sym_BQUOTE] = ACTIONS(5526),
    [aux_sym_id_directive_token1] = ACTIONS(5524),
    [aux_sym_id_directive_token2] = ACTIONS(5524),
    [aux_sym_id_directive_token3] = ACTIONS(5524),
    [aux_sym_id_directive_token4] = ACTIONS(5526),
    [aux_sym_zero_directive_token1] = ACTIONS(5524),
    [aux_sym_zero_directive_token2] = ACTIONS(5524),
    [aux_sym_zero_directive_token3] = ACTIONS(5524),
    [aux_sym_zero_directive_token4] = ACTIONS(5524),
    [aux_sym_zero_directive_token5] = ACTIONS(5524),
    [aux_sym_zero_directive_token6] = ACTIONS(5524),
    [aux_sym_zero_directive_token7] = ACTIONS(5524),
    [aux_sym_zero_directive_token8] = ACTIONS(5524),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5524),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5524),
    [anon_sym_wire] = ACTIONS(5526),
    [anon_sym_tri] = ACTIONS(5526),
    [anon_sym_tri0] = ACTIONS(5526),
    [anon_sym_tri1] = ACTIONS(5526),
    [anon_sym_wand] = ACTIONS(5526),
    [anon_sym_triand] = ACTIONS(5526),
    [anon_sym_wor] = ACTIONS(5526),
    [anon_sym_trior] = ACTIONS(5526),
    [anon_sym_trireg] = ACTIONS(5526),
    [anon_sym_uwire] = ACTIONS(5526),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5524),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5524),
    [aux_sym_begin_keywords_token1] = ACTIONS(5524),
    [anon_sym_SEMI] = ACTIONS(5524),
    [anon_sym_endmodule] = ACTIONS(5526),
    [anon_sym_COLON] = ACTIONS(5528),
    [anon_sym_extern] = ACTIONS(5526),
    [anon_sym_module] = ACTIONS(5526),
    [anon_sym_macromodule] = ACTIONS(5526),
    [anon_sym_endinterface] = ACTIONS(5526),
    [anon_sym_interface] = ACTIONS(5526),
    [anon_sym_program] = ACTIONS(5526),
    [anon_sym_checker] = ACTIONS(5526),
    [anon_sym_virtual] = ACTIONS(5526),
    [anon_sym_class] = ACTIONS(5526),
    [anon_sym_package] = ACTIONS(5526),
    [anon_sym_timeunit] = ACTIONS(5526),
    [anon_sym_timeprecision] = ACTIONS(5526),
    [anon_sym_type] = ACTIONS(5526),
    [anon_sym_input] = ACTIONS(5526),
    [anon_sym_output] = ACTIONS(5526),
    [anon_sym_inout] = ACTIONS(5526),
    [anon_sym_ref] = ACTIONS(5526),
    [anon_sym_DOLLARfatal] = ACTIONS(5524),
    [anon_sym_DOLLARerror] = ACTIONS(5524),
    [anon_sym_DOLLARwarning] = ACTIONS(5524),
    [anon_sym_DOLLARinfo] = ACTIONS(5524),
    [anon_sym_default] = ACTIONS(5526),
    [anon_sym_clocking] = ACTIONS(5526),
    [anon_sym_defparam] = ACTIONS(5526),
    [anon_sym_bind] = ACTIONS(5526),
    [anon_sym_const] = ACTIONS(5526),
    [anon_sym_function] = ACTIONS(5526),
    [anon_sym_static] = ACTIONS(5526),
    [anon_sym_constraint] = ACTIONS(5526),
    [anon_sym_if] = ACTIONS(5526),
    [anon_sym_LBRACK] = ACTIONS(5524),
    [anon_sym_localparam] = ACTIONS(5526),
    [anon_sym_parameter] = ACTIONS(5526),
    [anon_sym_specparam] = ACTIONS(5526),
    [anon_sym_var] = ACTIONS(5526),
    [anon_sym_import] = ACTIONS(5526),
    [anon_sym_export] = ACTIONS(5526),
    [anon_sym_genvar] = ACTIONS(5526),
    [anon_sym_interconnect] = ACTIONS(5526),
    [anon_sym_typedef] = ACTIONS(5526),
    [anon_sym_enum] = ACTIONS(5526),
    [anon_sym_struct] = ACTIONS(5526),
    [anon_sym_union] = ACTIONS(5526),
    [anon_sym_nettype] = ACTIONS(5526),
    [anon_sym_automatic] = ACTIONS(5526),
    [anon_sym_string] = ACTIONS(5526),
    [anon_sym_chandle] = ACTIONS(5526),
    [anon_sym_event] = ACTIONS(5526),
    [anon_sym_byte] = ACTIONS(5526),
    [anon_sym_shortint] = ACTIONS(5526),
    [anon_sym_int] = ACTIONS(5526),
    [anon_sym_longint] = ACTIONS(5526),
    [anon_sym_integer] = ACTIONS(5526),
    [anon_sym_time] = ACTIONS(5526),
    [anon_sym_bit] = ACTIONS(5526),
    [anon_sym_logic] = ACTIONS(5526),
    [anon_sym_reg] = ACTIONS(5526),
    [anon_sym_shortreal] = ACTIONS(5526),
    [anon_sym_real] = ACTIONS(5526),
    [anon_sym_realtime] = ACTIONS(5526),
    [anon_sym_supply0] = ACTIONS(5526),
    [anon_sym_supply1] = ACTIONS(5526),
    [anon_sym_signed] = ACTIONS(5526),
    [anon_sym_unsigned] = ACTIONS(5526),
    [anon_sym_task] = ACTIONS(5526),
    [anon_sym_modport] = ACTIONS(5526),
    [anon_sym_assert] = ACTIONS(5526),
    [anon_sym_property] = ACTIONS(5526),
    [anon_sym_assume] = ACTIONS(5526),
    [anon_sym_cover] = ACTIONS(5526),
    [anon_sym_sequence] = ACTIONS(5526),
    [anon_sym_restrict] = ACTIONS(5526),
    [anon_sym_not] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_case] = ACTIONS(5526),
    [anon_sym_always] = ACTIONS(5526),
    [anon_sym_covergroup] = ACTIONS(5526),
    [anon_sym_let] = ACTIONS(5526),
    [anon_sym_pulldown] = ACTIONS(5526),
    [anon_sym_pullup] = ACTIONS(5526),
    [anon_sym_cmos] = ACTIONS(5526),
    [anon_sym_rcmos] = ACTIONS(5526),
    [anon_sym_bufif0] = ACTIONS(5526),
    [anon_sym_bufif1] = ACTIONS(5526),
    [anon_sym_notif0] = ACTIONS(5526),
    [anon_sym_notif1] = ACTIONS(5526),
    [anon_sym_nmos] = ACTIONS(5526),
    [anon_sym_pmos] = ACTIONS(5526),
    [anon_sym_rnmos] = ACTIONS(5526),
    [anon_sym_rpmos] = ACTIONS(5526),
    [anon_sym_nand] = ACTIONS(5526),
    [anon_sym_nor] = ACTIONS(5526),
    [anon_sym_xor] = ACTIONS(5526),
    [anon_sym_xnor] = ACTIONS(5526),
    [anon_sym_buf] = ACTIONS(5526),
    [anon_sym_tranif0] = ACTIONS(5526),
    [anon_sym_tranif1] = ACTIONS(5526),
    [anon_sym_rtranif1] = ACTIONS(5526),
    [anon_sym_rtranif0] = ACTIONS(5526),
    [anon_sym_tran] = ACTIONS(5526),
    [anon_sym_rtran] = ACTIONS(5526),
    [anon_sym_generate] = ACTIONS(5526),
    [anon_sym_for] = ACTIONS(5526),
    [anon_sym_primitive] = ACTIONS(5526),
    [anon_sym_initial] = ACTIONS(5526),
    [anon_sym_assign] = ACTIONS(5526),
    [anon_sym_alias] = ACTIONS(5526),
    [anon_sym_always_comb] = ACTIONS(5526),
    [anon_sym_always_latch] = ACTIONS(5526),
    [anon_sym_always_ff] = ACTIONS(5526),
    [anon_sym_final] = ACTIONS(5526),
    [anon_sym_global] = ACTIONS(5526),
    [anon_sym_specify] = ACTIONS(5526),
    [anon_sym_LPAREN_STAR] = ACTIONS(5524),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5524),
    [anon_sym_DOLLARunit] = ACTIONS(5524),
  },
  [977] = {
    [ts_builtin_sym_end] = ACTIONS(5530),
    [sym_simple_identifier] = ACTIONS(5532),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5530),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5530),
    [anon_sym_BQUOTE] = ACTIONS(5532),
    [aux_sym_id_directive_token1] = ACTIONS(5530),
    [aux_sym_id_directive_token2] = ACTIONS(5530),
    [aux_sym_id_directive_token3] = ACTIONS(5530),
    [aux_sym_id_directive_token4] = ACTIONS(5532),
    [aux_sym_zero_directive_token1] = ACTIONS(5530),
    [aux_sym_zero_directive_token2] = ACTIONS(5530),
    [aux_sym_zero_directive_token3] = ACTIONS(5530),
    [aux_sym_zero_directive_token4] = ACTIONS(5530),
    [aux_sym_zero_directive_token5] = ACTIONS(5530),
    [aux_sym_zero_directive_token6] = ACTIONS(5530),
    [aux_sym_zero_directive_token7] = ACTIONS(5530),
    [aux_sym_zero_directive_token8] = ACTIONS(5530),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5530),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5530),
    [anon_sym_wire] = ACTIONS(5532),
    [anon_sym_tri] = ACTIONS(5532),
    [anon_sym_tri0] = ACTIONS(5532),
    [anon_sym_tri1] = ACTIONS(5532),
    [anon_sym_wand] = ACTIONS(5532),
    [anon_sym_triand] = ACTIONS(5532),
    [anon_sym_wor] = ACTIONS(5532),
    [anon_sym_trior] = ACTIONS(5532),
    [anon_sym_trireg] = ACTIONS(5532),
    [anon_sym_uwire] = ACTIONS(5532),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5530),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5530),
    [aux_sym_begin_keywords_token1] = ACTIONS(5530),
    [anon_sym_SEMI] = ACTIONS(5530),
    [anon_sym_endmodule] = ACTIONS(5532),
    [anon_sym_extern] = ACTIONS(5532),
    [anon_sym_module] = ACTIONS(5532),
    [anon_sym_macromodule] = ACTIONS(5532),
    [anon_sym_endinterface] = ACTIONS(5532),
    [anon_sym_interface] = ACTIONS(5532),
    [anon_sym_endprogram] = ACTIONS(5532),
    [anon_sym_program] = ACTIONS(5532),
    [anon_sym_checker] = ACTIONS(5532),
    [anon_sym_virtual] = ACTIONS(5532),
    [anon_sym_class] = ACTIONS(5532),
    [anon_sym_package] = ACTIONS(5532),
    [anon_sym_timeunit] = ACTIONS(5532),
    [anon_sym_timeprecision] = ACTIONS(5532),
    [anon_sym_type] = ACTIONS(5532),
    [anon_sym_input] = ACTIONS(5532),
    [anon_sym_output] = ACTIONS(5532),
    [anon_sym_inout] = ACTIONS(5532),
    [anon_sym_ref] = ACTIONS(5532),
    [anon_sym_DOLLARfatal] = ACTIONS(5530),
    [anon_sym_DOLLARerror] = ACTIONS(5530),
    [anon_sym_DOLLARwarning] = ACTIONS(5530),
    [anon_sym_DOLLARinfo] = ACTIONS(5530),
    [anon_sym_default] = ACTIONS(5532),
    [anon_sym_clocking] = ACTIONS(5532),
    [anon_sym_defparam] = ACTIONS(5532),
    [anon_sym_bind] = ACTIONS(5532),
    [anon_sym_const] = ACTIONS(5532),
    [anon_sym_function] = ACTIONS(5532),
    [anon_sym_static] = ACTIONS(5532),
    [anon_sym_constraint] = ACTIONS(5532),
    [anon_sym_if] = ACTIONS(5532),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_localparam] = ACTIONS(5532),
    [anon_sym_parameter] = ACTIONS(5532),
    [anon_sym_specparam] = ACTIONS(5532),
    [anon_sym_var] = ACTIONS(5532),
    [anon_sym_import] = ACTIONS(5532),
    [anon_sym_export] = ACTIONS(5532),
    [anon_sym_genvar] = ACTIONS(5532),
    [anon_sym_interconnect] = ACTIONS(5532),
    [anon_sym_typedef] = ACTIONS(5532),
    [anon_sym_enum] = ACTIONS(5532),
    [anon_sym_struct] = ACTIONS(5532),
    [anon_sym_union] = ACTIONS(5532),
    [anon_sym_nettype] = ACTIONS(5532),
    [anon_sym_automatic] = ACTIONS(5532),
    [anon_sym_string] = ACTIONS(5532),
    [anon_sym_chandle] = ACTIONS(5532),
    [anon_sym_event] = ACTIONS(5532),
    [anon_sym_byte] = ACTIONS(5532),
    [anon_sym_shortint] = ACTIONS(5532),
    [anon_sym_int] = ACTIONS(5532),
    [anon_sym_longint] = ACTIONS(5532),
    [anon_sym_integer] = ACTIONS(5532),
    [anon_sym_time] = ACTIONS(5532),
    [anon_sym_bit] = ACTIONS(5532),
    [anon_sym_logic] = ACTIONS(5532),
    [anon_sym_reg] = ACTIONS(5532),
    [anon_sym_shortreal] = ACTIONS(5532),
    [anon_sym_real] = ACTIONS(5532),
    [anon_sym_realtime] = ACTIONS(5532),
    [anon_sym_supply0] = ACTIONS(5532),
    [anon_sym_supply1] = ACTIONS(5532),
    [anon_sym_signed] = ACTIONS(5532),
    [anon_sym_unsigned] = ACTIONS(5532),
    [anon_sym_task] = ACTIONS(5532),
    [anon_sym_modport] = ACTIONS(5532),
    [anon_sym_assert] = ACTIONS(5532),
    [anon_sym_property] = ACTIONS(5532),
    [anon_sym_assume] = ACTIONS(5532),
    [anon_sym_cover] = ACTIONS(5532),
    [anon_sym_sequence] = ACTIONS(5532),
    [anon_sym_restrict] = ACTIONS(5532),
    [anon_sym_not] = ACTIONS(5532),
    [anon_sym_or] = ACTIONS(5532),
    [anon_sym_and] = ACTIONS(5532),
    [anon_sym_case] = ACTIONS(5532),
    [anon_sym_always] = ACTIONS(5532),
    [anon_sym_covergroup] = ACTIONS(5532),
    [anon_sym_let] = ACTIONS(5532),
    [anon_sym_pulldown] = ACTIONS(5532),
    [anon_sym_pullup] = ACTIONS(5532),
    [anon_sym_cmos] = ACTIONS(5532),
    [anon_sym_rcmos] = ACTIONS(5532),
    [anon_sym_bufif0] = ACTIONS(5532),
    [anon_sym_bufif1] = ACTIONS(5532),
    [anon_sym_notif0] = ACTIONS(5532),
    [anon_sym_notif1] = ACTIONS(5532),
    [anon_sym_nmos] = ACTIONS(5532),
    [anon_sym_pmos] = ACTIONS(5532),
    [anon_sym_rnmos] = ACTIONS(5532),
    [anon_sym_rpmos] = ACTIONS(5532),
    [anon_sym_nand] = ACTIONS(5532),
    [anon_sym_nor] = ACTIONS(5532),
    [anon_sym_xor] = ACTIONS(5532),
    [anon_sym_xnor] = ACTIONS(5532),
    [anon_sym_buf] = ACTIONS(5532),
    [anon_sym_tranif0] = ACTIONS(5532),
    [anon_sym_tranif1] = ACTIONS(5532),
    [anon_sym_rtranif1] = ACTIONS(5532),
    [anon_sym_rtranif0] = ACTIONS(5532),
    [anon_sym_tran] = ACTIONS(5532),
    [anon_sym_rtran] = ACTIONS(5532),
    [anon_sym_generate] = ACTIONS(5532),
    [anon_sym_for] = ACTIONS(5532),
    [anon_sym_primitive] = ACTIONS(5532),
    [anon_sym_initial] = ACTIONS(5532),
    [anon_sym_assign] = ACTIONS(5532),
    [anon_sym_alias] = ACTIONS(5532),
    [anon_sym_always_comb] = ACTIONS(5532),
    [anon_sym_always_latch] = ACTIONS(5532),
    [anon_sym_always_ff] = ACTIONS(5532),
    [anon_sym_final] = ACTIONS(5532),
    [anon_sym_global] = ACTIONS(5532),
    [anon_sym_specify] = ACTIONS(5532),
    [anon_sym_LPAREN_STAR] = ACTIONS(5530),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5530),
    [anon_sym_DOLLARunit] = ACTIONS(5530),
  },
  [978] = {
    [ts_builtin_sym_end] = ACTIONS(5534),
    [sym_simple_identifier] = ACTIONS(5536),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5534),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5534),
    [anon_sym_BQUOTE] = ACTIONS(5536),
    [aux_sym_id_directive_token1] = ACTIONS(5534),
    [aux_sym_id_directive_token2] = ACTIONS(5534),
    [aux_sym_id_directive_token3] = ACTIONS(5534),
    [aux_sym_id_directive_token4] = ACTIONS(5536),
    [aux_sym_zero_directive_token1] = ACTIONS(5534),
    [aux_sym_zero_directive_token2] = ACTIONS(5534),
    [aux_sym_zero_directive_token3] = ACTIONS(5534),
    [aux_sym_zero_directive_token4] = ACTIONS(5534),
    [aux_sym_zero_directive_token5] = ACTIONS(5534),
    [aux_sym_zero_directive_token6] = ACTIONS(5534),
    [aux_sym_zero_directive_token7] = ACTIONS(5534),
    [aux_sym_zero_directive_token8] = ACTIONS(5534),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5534),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5534),
    [anon_sym_wire] = ACTIONS(5536),
    [anon_sym_tri] = ACTIONS(5536),
    [anon_sym_tri0] = ACTIONS(5536),
    [anon_sym_tri1] = ACTIONS(5536),
    [anon_sym_wand] = ACTIONS(5536),
    [anon_sym_triand] = ACTIONS(5536),
    [anon_sym_wor] = ACTIONS(5536),
    [anon_sym_trior] = ACTIONS(5536),
    [anon_sym_trireg] = ACTIONS(5536),
    [anon_sym_uwire] = ACTIONS(5536),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5534),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5534),
    [aux_sym_begin_keywords_token1] = ACTIONS(5534),
    [anon_sym_SEMI] = ACTIONS(5534),
    [anon_sym_endmodule] = ACTIONS(5536),
    [anon_sym_extern] = ACTIONS(5536),
    [anon_sym_module] = ACTIONS(5536),
    [anon_sym_macromodule] = ACTIONS(5536),
    [anon_sym_endinterface] = ACTIONS(5536),
    [anon_sym_interface] = ACTIONS(5536),
    [anon_sym_endprogram] = ACTIONS(5536),
    [anon_sym_program] = ACTIONS(5536),
    [anon_sym_checker] = ACTIONS(5536),
    [anon_sym_virtual] = ACTIONS(5536),
    [anon_sym_class] = ACTIONS(5536),
    [anon_sym_package] = ACTIONS(5536),
    [anon_sym_timeunit] = ACTIONS(5536),
    [anon_sym_timeprecision] = ACTIONS(5536),
    [anon_sym_type] = ACTIONS(5536),
    [anon_sym_input] = ACTIONS(5536),
    [anon_sym_output] = ACTIONS(5536),
    [anon_sym_inout] = ACTIONS(5536),
    [anon_sym_ref] = ACTIONS(5536),
    [anon_sym_DOLLARfatal] = ACTIONS(5534),
    [anon_sym_DOLLARerror] = ACTIONS(5534),
    [anon_sym_DOLLARwarning] = ACTIONS(5534),
    [anon_sym_DOLLARinfo] = ACTIONS(5534),
    [anon_sym_default] = ACTIONS(5536),
    [anon_sym_clocking] = ACTIONS(5536),
    [anon_sym_defparam] = ACTIONS(5536),
    [anon_sym_bind] = ACTIONS(5536),
    [anon_sym_const] = ACTIONS(5536),
    [anon_sym_function] = ACTIONS(5536),
    [anon_sym_static] = ACTIONS(5536),
    [anon_sym_constraint] = ACTIONS(5536),
    [anon_sym_if] = ACTIONS(5536),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_localparam] = ACTIONS(5536),
    [anon_sym_parameter] = ACTIONS(5536),
    [anon_sym_specparam] = ACTIONS(5536),
    [anon_sym_var] = ACTIONS(5536),
    [anon_sym_import] = ACTIONS(5536),
    [anon_sym_export] = ACTIONS(5536),
    [anon_sym_genvar] = ACTIONS(5536),
    [anon_sym_interconnect] = ACTIONS(5536),
    [anon_sym_typedef] = ACTIONS(5536),
    [anon_sym_enum] = ACTIONS(5536),
    [anon_sym_struct] = ACTIONS(5536),
    [anon_sym_union] = ACTIONS(5536),
    [anon_sym_nettype] = ACTIONS(5536),
    [anon_sym_automatic] = ACTIONS(5536),
    [anon_sym_string] = ACTIONS(5536),
    [anon_sym_chandle] = ACTIONS(5536),
    [anon_sym_event] = ACTIONS(5536),
    [anon_sym_byte] = ACTIONS(5536),
    [anon_sym_shortint] = ACTIONS(5536),
    [anon_sym_int] = ACTIONS(5536),
    [anon_sym_longint] = ACTIONS(5536),
    [anon_sym_integer] = ACTIONS(5536),
    [anon_sym_time] = ACTIONS(5536),
    [anon_sym_bit] = ACTIONS(5536),
    [anon_sym_logic] = ACTIONS(5536),
    [anon_sym_reg] = ACTIONS(5536),
    [anon_sym_shortreal] = ACTIONS(5536),
    [anon_sym_real] = ACTIONS(5536),
    [anon_sym_realtime] = ACTIONS(5536),
    [anon_sym_supply0] = ACTIONS(5536),
    [anon_sym_supply1] = ACTIONS(5536),
    [anon_sym_signed] = ACTIONS(5536),
    [anon_sym_unsigned] = ACTIONS(5536),
    [anon_sym_task] = ACTIONS(5536),
    [anon_sym_modport] = ACTIONS(5536),
    [anon_sym_assert] = ACTIONS(5536),
    [anon_sym_property] = ACTIONS(5536),
    [anon_sym_assume] = ACTIONS(5536),
    [anon_sym_cover] = ACTIONS(5536),
    [anon_sym_sequence] = ACTIONS(5536),
    [anon_sym_restrict] = ACTIONS(5536),
    [anon_sym_not] = ACTIONS(5536),
    [anon_sym_or] = ACTIONS(5536),
    [anon_sym_and] = ACTIONS(5536),
    [anon_sym_case] = ACTIONS(5536),
    [anon_sym_always] = ACTIONS(5536),
    [anon_sym_covergroup] = ACTIONS(5536),
    [anon_sym_let] = ACTIONS(5536),
    [anon_sym_pulldown] = ACTIONS(5536),
    [anon_sym_pullup] = ACTIONS(5536),
    [anon_sym_cmos] = ACTIONS(5536),
    [anon_sym_rcmos] = ACTIONS(5536),
    [anon_sym_bufif0] = ACTIONS(5536),
    [anon_sym_bufif1] = ACTIONS(5536),
    [anon_sym_notif0] = ACTIONS(5536),
    [anon_sym_notif1] = ACTIONS(5536),
    [anon_sym_nmos] = ACTIONS(5536),
    [anon_sym_pmos] = ACTIONS(5536),
    [anon_sym_rnmos] = ACTIONS(5536),
    [anon_sym_rpmos] = ACTIONS(5536),
    [anon_sym_nand] = ACTIONS(5536),
    [anon_sym_nor] = ACTIONS(5536),
    [anon_sym_xor] = ACTIONS(5536),
    [anon_sym_xnor] = ACTIONS(5536),
    [anon_sym_buf] = ACTIONS(5536),
    [anon_sym_tranif0] = ACTIONS(5536),
    [anon_sym_tranif1] = ACTIONS(5536),
    [anon_sym_rtranif1] = ACTIONS(5536),
    [anon_sym_rtranif0] = ACTIONS(5536),
    [anon_sym_tran] = ACTIONS(5536),
    [anon_sym_rtran] = ACTIONS(5536),
    [anon_sym_generate] = ACTIONS(5536),
    [anon_sym_for] = ACTIONS(5536),
    [anon_sym_primitive] = ACTIONS(5536),
    [anon_sym_initial] = ACTIONS(5536),
    [anon_sym_assign] = ACTIONS(5536),
    [anon_sym_alias] = ACTIONS(5536),
    [anon_sym_always_comb] = ACTIONS(5536),
    [anon_sym_always_latch] = ACTIONS(5536),
    [anon_sym_always_ff] = ACTIONS(5536),
    [anon_sym_final] = ACTIONS(5536),
    [anon_sym_global] = ACTIONS(5536),
    [anon_sym_specify] = ACTIONS(5536),
    [anon_sym_LPAREN_STAR] = ACTIONS(5534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5534),
    [anon_sym_DOLLARunit] = ACTIONS(5534),
  },
  [979] = {
    [ts_builtin_sym_end] = ACTIONS(5538),
    [sym_simple_identifier] = ACTIONS(5540),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5538),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5538),
    [anon_sym_BQUOTE] = ACTIONS(5540),
    [aux_sym_id_directive_token1] = ACTIONS(5538),
    [aux_sym_id_directive_token2] = ACTIONS(5538),
    [aux_sym_id_directive_token3] = ACTIONS(5538),
    [aux_sym_id_directive_token4] = ACTIONS(5540),
    [aux_sym_zero_directive_token1] = ACTIONS(5538),
    [aux_sym_zero_directive_token2] = ACTIONS(5538),
    [aux_sym_zero_directive_token3] = ACTIONS(5538),
    [aux_sym_zero_directive_token4] = ACTIONS(5538),
    [aux_sym_zero_directive_token5] = ACTIONS(5538),
    [aux_sym_zero_directive_token6] = ACTIONS(5538),
    [aux_sym_zero_directive_token7] = ACTIONS(5538),
    [aux_sym_zero_directive_token8] = ACTIONS(5538),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5538),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5538),
    [anon_sym_wire] = ACTIONS(5540),
    [anon_sym_tri] = ACTIONS(5540),
    [anon_sym_tri0] = ACTIONS(5540),
    [anon_sym_tri1] = ACTIONS(5540),
    [anon_sym_wand] = ACTIONS(5540),
    [anon_sym_triand] = ACTIONS(5540),
    [anon_sym_wor] = ACTIONS(5540),
    [anon_sym_trior] = ACTIONS(5540),
    [anon_sym_trireg] = ACTIONS(5540),
    [anon_sym_uwire] = ACTIONS(5540),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5538),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5538),
    [aux_sym_begin_keywords_token1] = ACTIONS(5538),
    [anon_sym_SEMI] = ACTIONS(5538),
    [anon_sym_endmodule] = ACTIONS(5540),
    [anon_sym_extern] = ACTIONS(5540),
    [anon_sym_module] = ACTIONS(5540),
    [anon_sym_macromodule] = ACTIONS(5540),
    [anon_sym_endinterface] = ACTIONS(5540),
    [anon_sym_interface] = ACTIONS(5540),
    [anon_sym_endprogram] = ACTIONS(5540),
    [anon_sym_program] = ACTIONS(5540),
    [anon_sym_checker] = ACTIONS(5540),
    [anon_sym_virtual] = ACTIONS(5540),
    [anon_sym_class] = ACTIONS(5540),
    [anon_sym_package] = ACTIONS(5540),
    [anon_sym_timeunit] = ACTIONS(5540),
    [anon_sym_timeprecision] = ACTIONS(5540),
    [anon_sym_type] = ACTIONS(5540),
    [anon_sym_input] = ACTIONS(5540),
    [anon_sym_output] = ACTIONS(5540),
    [anon_sym_inout] = ACTIONS(5540),
    [anon_sym_ref] = ACTIONS(5540),
    [anon_sym_DOLLARfatal] = ACTIONS(5538),
    [anon_sym_DOLLARerror] = ACTIONS(5538),
    [anon_sym_DOLLARwarning] = ACTIONS(5538),
    [anon_sym_DOLLARinfo] = ACTIONS(5538),
    [anon_sym_default] = ACTIONS(5540),
    [anon_sym_clocking] = ACTIONS(5540),
    [anon_sym_defparam] = ACTIONS(5540),
    [anon_sym_bind] = ACTIONS(5540),
    [anon_sym_const] = ACTIONS(5540),
    [anon_sym_function] = ACTIONS(5540),
    [anon_sym_static] = ACTIONS(5540),
    [anon_sym_constraint] = ACTIONS(5540),
    [anon_sym_if] = ACTIONS(5540),
    [anon_sym_LBRACK] = ACTIONS(5538),
    [anon_sym_localparam] = ACTIONS(5540),
    [anon_sym_parameter] = ACTIONS(5540),
    [anon_sym_specparam] = ACTIONS(5540),
    [anon_sym_var] = ACTIONS(5540),
    [anon_sym_import] = ACTIONS(5540),
    [anon_sym_export] = ACTIONS(5540),
    [anon_sym_genvar] = ACTIONS(5540),
    [anon_sym_interconnect] = ACTIONS(5540),
    [anon_sym_typedef] = ACTIONS(5540),
    [anon_sym_enum] = ACTIONS(5540),
    [anon_sym_struct] = ACTIONS(5540),
    [anon_sym_union] = ACTIONS(5540),
    [anon_sym_nettype] = ACTIONS(5540),
    [anon_sym_automatic] = ACTIONS(5540),
    [anon_sym_string] = ACTIONS(5540),
    [anon_sym_chandle] = ACTIONS(5540),
    [anon_sym_event] = ACTIONS(5540),
    [anon_sym_byte] = ACTIONS(5540),
    [anon_sym_shortint] = ACTIONS(5540),
    [anon_sym_int] = ACTIONS(5540),
    [anon_sym_longint] = ACTIONS(5540),
    [anon_sym_integer] = ACTIONS(5540),
    [anon_sym_time] = ACTIONS(5540),
    [anon_sym_bit] = ACTIONS(5540),
    [anon_sym_logic] = ACTIONS(5540),
    [anon_sym_reg] = ACTIONS(5540),
    [anon_sym_shortreal] = ACTIONS(5540),
    [anon_sym_real] = ACTIONS(5540),
    [anon_sym_realtime] = ACTIONS(5540),
    [anon_sym_supply0] = ACTIONS(5540),
    [anon_sym_supply1] = ACTIONS(5540),
    [anon_sym_signed] = ACTIONS(5540),
    [anon_sym_unsigned] = ACTIONS(5540),
    [anon_sym_task] = ACTIONS(5540),
    [anon_sym_modport] = ACTIONS(5540),
    [anon_sym_assert] = ACTIONS(5540),
    [anon_sym_property] = ACTIONS(5540),
    [anon_sym_assume] = ACTIONS(5540),
    [anon_sym_cover] = ACTIONS(5540),
    [anon_sym_sequence] = ACTIONS(5540),
    [anon_sym_restrict] = ACTIONS(5540),
    [anon_sym_not] = ACTIONS(5540),
    [anon_sym_or] = ACTIONS(5540),
    [anon_sym_and] = ACTIONS(5540),
    [anon_sym_case] = ACTIONS(5540),
    [anon_sym_always] = ACTIONS(5540),
    [anon_sym_covergroup] = ACTIONS(5540),
    [anon_sym_let] = ACTIONS(5540),
    [anon_sym_pulldown] = ACTIONS(5540),
    [anon_sym_pullup] = ACTIONS(5540),
    [anon_sym_cmos] = ACTIONS(5540),
    [anon_sym_rcmos] = ACTIONS(5540),
    [anon_sym_bufif0] = ACTIONS(5540),
    [anon_sym_bufif1] = ACTIONS(5540),
    [anon_sym_notif0] = ACTIONS(5540),
    [anon_sym_notif1] = ACTIONS(5540),
    [anon_sym_nmos] = ACTIONS(5540),
    [anon_sym_pmos] = ACTIONS(5540),
    [anon_sym_rnmos] = ACTIONS(5540),
    [anon_sym_rpmos] = ACTIONS(5540),
    [anon_sym_nand] = ACTIONS(5540),
    [anon_sym_nor] = ACTIONS(5540),
    [anon_sym_xor] = ACTIONS(5540),
    [anon_sym_xnor] = ACTIONS(5540),
    [anon_sym_buf] = ACTIONS(5540),
    [anon_sym_tranif0] = ACTIONS(5540),
    [anon_sym_tranif1] = ACTIONS(5540),
    [anon_sym_rtranif1] = ACTIONS(5540),
    [anon_sym_rtranif0] = ACTIONS(5540),
    [anon_sym_tran] = ACTIONS(5540),
    [anon_sym_rtran] = ACTIONS(5540),
    [anon_sym_generate] = ACTIONS(5540),
    [anon_sym_for] = ACTIONS(5540),
    [anon_sym_primitive] = ACTIONS(5540),
    [anon_sym_initial] = ACTIONS(5540),
    [anon_sym_assign] = ACTIONS(5540),
    [anon_sym_alias] = ACTIONS(5540),
    [anon_sym_always_comb] = ACTIONS(5540),
    [anon_sym_always_latch] = ACTIONS(5540),
    [anon_sym_always_ff] = ACTIONS(5540),
    [anon_sym_final] = ACTIONS(5540),
    [anon_sym_global] = ACTIONS(5540),
    [anon_sym_specify] = ACTIONS(5540),
    [anon_sym_LPAREN_STAR] = ACTIONS(5538),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5538),
    [anon_sym_DOLLARunit] = ACTIONS(5538),
  },
  [980] = {
    [ts_builtin_sym_end] = ACTIONS(5542),
    [sym_simple_identifier] = ACTIONS(5544),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5542),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5542),
    [anon_sym_BQUOTE] = ACTIONS(5544),
    [aux_sym_id_directive_token1] = ACTIONS(5542),
    [aux_sym_id_directive_token2] = ACTIONS(5542),
    [aux_sym_id_directive_token3] = ACTIONS(5542),
    [aux_sym_id_directive_token4] = ACTIONS(5544),
    [aux_sym_zero_directive_token1] = ACTIONS(5542),
    [aux_sym_zero_directive_token2] = ACTIONS(5542),
    [aux_sym_zero_directive_token3] = ACTIONS(5542),
    [aux_sym_zero_directive_token4] = ACTIONS(5542),
    [aux_sym_zero_directive_token5] = ACTIONS(5542),
    [aux_sym_zero_directive_token6] = ACTIONS(5542),
    [aux_sym_zero_directive_token7] = ACTIONS(5542),
    [aux_sym_zero_directive_token8] = ACTIONS(5542),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5542),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5542),
    [anon_sym_wire] = ACTIONS(5544),
    [anon_sym_tri] = ACTIONS(5544),
    [anon_sym_tri0] = ACTIONS(5544),
    [anon_sym_tri1] = ACTIONS(5544),
    [anon_sym_wand] = ACTIONS(5544),
    [anon_sym_triand] = ACTIONS(5544),
    [anon_sym_wor] = ACTIONS(5544),
    [anon_sym_trior] = ACTIONS(5544),
    [anon_sym_trireg] = ACTIONS(5544),
    [anon_sym_uwire] = ACTIONS(5544),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5542),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5542),
    [aux_sym_begin_keywords_token1] = ACTIONS(5542),
    [anon_sym_SEMI] = ACTIONS(5542),
    [anon_sym_endmodule] = ACTIONS(5544),
    [anon_sym_COLON] = ACTIONS(5546),
    [anon_sym_extern] = ACTIONS(5544),
    [anon_sym_module] = ACTIONS(5544),
    [anon_sym_macromodule] = ACTIONS(5544),
    [anon_sym_endinterface] = ACTIONS(5544),
    [anon_sym_interface] = ACTIONS(5544),
    [anon_sym_program] = ACTIONS(5544),
    [anon_sym_checker] = ACTIONS(5544),
    [anon_sym_virtual] = ACTIONS(5544),
    [anon_sym_class] = ACTIONS(5544),
    [anon_sym_package] = ACTIONS(5544),
    [anon_sym_timeunit] = ACTIONS(5544),
    [anon_sym_timeprecision] = ACTIONS(5544),
    [anon_sym_type] = ACTIONS(5544),
    [anon_sym_input] = ACTIONS(5544),
    [anon_sym_output] = ACTIONS(5544),
    [anon_sym_inout] = ACTIONS(5544),
    [anon_sym_ref] = ACTIONS(5544),
    [anon_sym_DOLLARfatal] = ACTIONS(5542),
    [anon_sym_DOLLARerror] = ACTIONS(5542),
    [anon_sym_DOLLARwarning] = ACTIONS(5542),
    [anon_sym_DOLLARinfo] = ACTIONS(5542),
    [anon_sym_default] = ACTIONS(5544),
    [anon_sym_clocking] = ACTIONS(5544),
    [anon_sym_defparam] = ACTIONS(5544),
    [anon_sym_bind] = ACTIONS(5544),
    [anon_sym_const] = ACTIONS(5544),
    [anon_sym_function] = ACTIONS(5544),
    [anon_sym_static] = ACTIONS(5544),
    [anon_sym_constraint] = ACTIONS(5544),
    [anon_sym_if] = ACTIONS(5544),
    [anon_sym_LBRACK] = ACTIONS(5542),
    [anon_sym_localparam] = ACTIONS(5544),
    [anon_sym_parameter] = ACTIONS(5544),
    [anon_sym_specparam] = ACTIONS(5544),
    [anon_sym_var] = ACTIONS(5544),
    [anon_sym_import] = ACTIONS(5544),
    [anon_sym_export] = ACTIONS(5544),
    [anon_sym_genvar] = ACTIONS(5544),
    [anon_sym_interconnect] = ACTIONS(5544),
    [anon_sym_typedef] = ACTIONS(5544),
    [anon_sym_enum] = ACTIONS(5544),
    [anon_sym_struct] = ACTIONS(5544),
    [anon_sym_union] = ACTIONS(5544),
    [anon_sym_nettype] = ACTIONS(5544),
    [anon_sym_automatic] = ACTIONS(5544),
    [anon_sym_string] = ACTIONS(5544),
    [anon_sym_chandle] = ACTIONS(5544),
    [anon_sym_event] = ACTIONS(5544),
    [anon_sym_byte] = ACTIONS(5544),
    [anon_sym_shortint] = ACTIONS(5544),
    [anon_sym_int] = ACTIONS(5544),
    [anon_sym_longint] = ACTIONS(5544),
    [anon_sym_integer] = ACTIONS(5544),
    [anon_sym_time] = ACTIONS(5544),
    [anon_sym_bit] = ACTIONS(5544),
    [anon_sym_logic] = ACTIONS(5544),
    [anon_sym_reg] = ACTIONS(5544),
    [anon_sym_shortreal] = ACTIONS(5544),
    [anon_sym_real] = ACTIONS(5544),
    [anon_sym_realtime] = ACTIONS(5544),
    [anon_sym_supply0] = ACTIONS(5544),
    [anon_sym_supply1] = ACTIONS(5544),
    [anon_sym_signed] = ACTIONS(5544),
    [anon_sym_unsigned] = ACTIONS(5544),
    [anon_sym_task] = ACTIONS(5544),
    [anon_sym_modport] = ACTIONS(5544),
    [anon_sym_assert] = ACTIONS(5544),
    [anon_sym_property] = ACTIONS(5544),
    [anon_sym_assume] = ACTIONS(5544),
    [anon_sym_cover] = ACTIONS(5544),
    [anon_sym_sequence] = ACTIONS(5544),
    [anon_sym_restrict] = ACTIONS(5544),
    [anon_sym_not] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_case] = ACTIONS(5544),
    [anon_sym_always] = ACTIONS(5544),
    [anon_sym_covergroup] = ACTIONS(5544),
    [anon_sym_let] = ACTIONS(5544),
    [anon_sym_pulldown] = ACTIONS(5544),
    [anon_sym_pullup] = ACTIONS(5544),
    [anon_sym_cmos] = ACTIONS(5544),
    [anon_sym_rcmos] = ACTIONS(5544),
    [anon_sym_bufif0] = ACTIONS(5544),
    [anon_sym_bufif1] = ACTIONS(5544),
    [anon_sym_notif0] = ACTIONS(5544),
    [anon_sym_notif1] = ACTIONS(5544),
    [anon_sym_nmos] = ACTIONS(5544),
    [anon_sym_pmos] = ACTIONS(5544),
    [anon_sym_rnmos] = ACTIONS(5544),
    [anon_sym_rpmos] = ACTIONS(5544),
    [anon_sym_nand] = ACTIONS(5544),
    [anon_sym_nor] = ACTIONS(5544),
    [anon_sym_xor] = ACTIONS(5544),
    [anon_sym_xnor] = ACTIONS(5544),
    [anon_sym_buf] = ACTIONS(5544),
    [anon_sym_tranif0] = ACTIONS(5544),
    [anon_sym_tranif1] = ACTIONS(5544),
    [anon_sym_rtranif1] = ACTIONS(5544),
    [anon_sym_rtranif0] = ACTIONS(5544),
    [anon_sym_tran] = ACTIONS(5544),
    [anon_sym_rtran] = ACTIONS(5544),
    [anon_sym_generate] = ACTIONS(5544),
    [anon_sym_for] = ACTIONS(5544),
    [anon_sym_primitive] = ACTIONS(5544),
    [anon_sym_initial] = ACTIONS(5544),
    [anon_sym_assign] = ACTIONS(5544),
    [anon_sym_alias] = ACTIONS(5544),
    [anon_sym_always_comb] = ACTIONS(5544),
    [anon_sym_always_latch] = ACTIONS(5544),
    [anon_sym_always_ff] = ACTIONS(5544),
    [anon_sym_final] = ACTIONS(5544),
    [anon_sym_global] = ACTIONS(5544),
    [anon_sym_specify] = ACTIONS(5544),
    [anon_sym_LPAREN_STAR] = ACTIONS(5542),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5542),
    [anon_sym_DOLLARunit] = ACTIONS(5542),
  },
  [981] = {
    [ts_builtin_sym_end] = ACTIONS(5548),
    [sym_simple_identifier] = ACTIONS(5550),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5548),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5548),
    [anon_sym_BQUOTE] = ACTIONS(5550),
    [aux_sym_id_directive_token1] = ACTIONS(5548),
    [aux_sym_id_directive_token2] = ACTIONS(5548),
    [aux_sym_id_directive_token3] = ACTIONS(5548),
    [aux_sym_id_directive_token4] = ACTIONS(5550),
    [aux_sym_zero_directive_token1] = ACTIONS(5548),
    [aux_sym_zero_directive_token2] = ACTIONS(5548),
    [aux_sym_zero_directive_token3] = ACTIONS(5548),
    [aux_sym_zero_directive_token4] = ACTIONS(5548),
    [aux_sym_zero_directive_token5] = ACTIONS(5548),
    [aux_sym_zero_directive_token6] = ACTIONS(5548),
    [aux_sym_zero_directive_token7] = ACTIONS(5548),
    [aux_sym_zero_directive_token8] = ACTIONS(5548),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5548),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5548),
    [anon_sym_wire] = ACTIONS(5550),
    [anon_sym_tri] = ACTIONS(5550),
    [anon_sym_tri0] = ACTIONS(5550),
    [anon_sym_tri1] = ACTIONS(5550),
    [anon_sym_wand] = ACTIONS(5550),
    [anon_sym_triand] = ACTIONS(5550),
    [anon_sym_wor] = ACTIONS(5550),
    [anon_sym_trior] = ACTIONS(5550),
    [anon_sym_trireg] = ACTIONS(5550),
    [anon_sym_uwire] = ACTIONS(5550),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5548),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5548),
    [aux_sym_begin_keywords_token1] = ACTIONS(5548),
    [anon_sym_SEMI] = ACTIONS(5548),
    [anon_sym_endmodule] = ACTIONS(5550),
    [anon_sym_extern] = ACTIONS(5550),
    [anon_sym_module] = ACTIONS(5550),
    [anon_sym_macromodule] = ACTIONS(5550),
    [anon_sym_endinterface] = ACTIONS(5550),
    [anon_sym_interface] = ACTIONS(5550),
    [anon_sym_endprogram] = ACTIONS(5550),
    [anon_sym_program] = ACTIONS(5550),
    [anon_sym_checker] = ACTIONS(5550),
    [anon_sym_virtual] = ACTIONS(5550),
    [anon_sym_class] = ACTIONS(5550),
    [anon_sym_package] = ACTIONS(5550),
    [anon_sym_timeunit] = ACTIONS(5550),
    [anon_sym_timeprecision] = ACTIONS(5550),
    [anon_sym_type] = ACTIONS(5550),
    [anon_sym_input] = ACTIONS(5550),
    [anon_sym_output] = ACTIONS(5550),
    [anon_sym_inout] = ACTIONS(5550),
    [anon_sym_ref] = ACTIONS(5550),
    [anon_sym_DOLLARfatal] = ACTIONS(5548),
    [anon_sym_DOLLARerror] = ACTIONS(5548),
    [anon_sym_DOLLARwarning] = ACTIONS(5548),
    [anon_sym_DOLLARinfo] = ACTIONS(5548),
    [anon_sym_default] = ACTIONS(5550),
    [anon_sym_clocking] = ACTIONS(5550),
    [anon_sym_defparam] = ACTIONS(5550),
    [anon_sym_bind] = ACTIONS(5550),
    [anon_sym_const] = ACTIONS(5550),
    [anon_sym_function] = ACTIONS(5550),
    [anon_sym_static] = ACTIONS(5550),
    [anon_sym_constraint] = ACTIONS(5550),
    [anon_sym_if] = ACTIONS(5550),
    [anon_sym_LBRACK] = ACTIONS(5548),
    [anon_sym_localparam] = ACTIONS(5550),
    [anon_sym_parameter] = ACTIONS(5550),
    [anon_sym_specparam] = ACTIONS(5550),
    [anon_sym_var] = ACTIONS(5550),
    [anon_sym_import] = ACTIONS(5550),
    [anon_sym_export] = ACTIONS(5550),
    [anon_sym_genvar] = ACTIONS(5550),
    [anon_sym_interconnect] = ACTIONS(5550),
    [anon_sym_typedef] = ACTIONS(5550),
    [anon_sym_enum] = ACTIONS(5550),
    [anon_sym_struct] = ACTIONS(5550),
    [anon_sym_union] = ACTIONS(5550),
    [anon_sym_nettype] = ACTIONS(5550),
    [anon_sym_automatic] = ACTIONS(5550),
    [anon_sym_string] = ACTIONS(5550),
    [anon_sym_chandle] = ACTIONS(5550),
    [anon_sym_event] = ACTIONS(5550),
    [anon_sym_byte] = ACTIONS(5550),
    [anon_sym_shortint] = ACTIONS(5550),
    [anon_sym_int] = ACTIONS(5550),
    [anon_sym_longint] = ACTIONS(5550),
    [anon_sym_integer] = ACTIONS(5550),
    [anon_sym_time] = ACTIONS(5550),
    [anon_sym_bit] = ACTIONS(5550),
    [anon_sym_logic] = ACTIONS(5550),
    [anon_sym_reg] = ACTIONS(5550),
    [anon_sym_shortreal] = ACTIONS(5550),
    [anon_sym_real] = ACTIONS(5550),
    [anon_sym_realtime] = ACTIONS(5550),
    [anon_sym_supply0] = ACTIONS(5550),
    [anon_sym_supply1] = ACTIONS(5550),
    [anon_sym_signed] = ACTIONS(5550),
    [anon_sym_unsigned] = ACTIONS(5550),
    [anon_sym_task] = ACTIONS(5550),
    [anon_sym_modport] = ACTIONS(5550),
    [anon_sym_assert] = ACTIONS(5550),
    [anon_sym_property] = ACTIONS(5550),
    [anon_sym_assume] = ACTIONS(5550),
    [anon_sym_cover] = ACTIONS(5550),
    [anon_sym_sequence] = ACTIONS(5550),
    [anon_sym_restrict] = ACTIONS(5550),
    [anon_sym_not] = ACTIONS(5550),
    [anon_sym_or] = ACTIONS(5550),
    [anon_sym_and] = ACTIONS(5550),
    [anon_sym_case] = ACTIONS(5550),
    [anon_sym_always] = ACTIONS(5550),
    [anon_sym_covergroup] = ACTIONS(5550),
    [anon_sym_let] = ACTIONS(5550),
    [anon_sym_pulldown] = ACTIONS(5550),
    [anon_sym_pullup] = ACTIONS(5550),
    [anon_sym_cmos] = ACTIONS(5550),
    [anon_sym_rcmos] = ACTIONS(5550),
    [anon_sym_bufif0] = ACTIONS(5550),
    [anon_sym_bufif1] = ACTIONS(5550),
    [anon_sym_notif0] = ACTIONS(5550),
    [anon_sym_notif1] = ACTIONS(5550),
    [anon_sym_nmos] = ACTIONS(5550),
    [anon_sym_pmos] = ACTIONS(5550),
    [anon_sym_rnmos] = ACTIONS(5550),
    [anon_sym_rpmos] = ACTIONS(5550),
    [anon_sym_nand] = ACTIONS(5550),
    [anon_sym_nor] = ACTIONS(5550),
    [anon_sym_xor] = ACTIONS(5550),
    [anon_sym_xnor] = ACTIONS(5550),
    [anon_sym_buf] = ACTIONS(5550),
    [anon_sym_tranif0] = ACTIONS(5550),
    [anon_sym_tranif1] = ACTIONS(5550),
    [anon_sym_rtranif1] = ACTIONS(5550),
    [anon_sym_rtranif0] = ACTIONS(5550),
    [anon_sym_tran] = ACTIONS(5550),
    [anon_sym_rtran] = ACTIONS(5550),
    [anon_sym_generate] = ACTIONS(5550),
    [anon_sym_for] = ACTIONS(5550),
    [anon_sym_primitive] = ACTIONS(5550),
    [anon_sym_initial] = ACTIONS(5550),
    [anon_sym_assign] = ACTIONS(5550),
    [anon_sym_alias] = ACTIONS(5550),
    [anon_sym_always_comb] = ACTIONS(5550),
    [anon_sym_always_latch] = ACTIONS(5550),
    [anon_sym_always_ff] = ACTIONS(5550),
    [anon_sym_final] = ACTIONS(5550),
    [anon_sym_global] = ACTIONS(5550),
    [anon_sym_specify] = ACTIONS(5550),
    [anon_sym_LPAREN_STAR] = ACTIONS(5548),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5548),
    [anon_sym_DOLLARunit] = ACTIONS(5548),
  },
  [982] = {
    [ts_builtin_sym_end] = ACTIONS(5552),
    [sym_simple_identifier] = ACTIONS(5554),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5552),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5552),
    [anon_sym_BQUOTE] = ACTIONS(5554),
    [aux_sym_id_directive_token1] = ACTIONS(5552),
    [aux_sym_id_directive_token2] = ACTIONS(5552),
    [aux_sym_id_directive_token3] = ACTIONS(5552),
    [aux_sym_id_directive_token4] = ACTIONS(5554),
    [aux_sym_zero_directive_token1] = ACTIONS(5552),
    [aux_sym_zero_directive_token2] = ACTIONS(5552),
    [aux_sym_zero_directive_token3] = ACTIONS(5552),
    [aux_sym_zero_directive_token4] = ACTIONS(5552),
    [aux_sym_zero_directive_token5] = ACTIONS(5552),
    [aux_sym_zero_directive_token6] = ACTIONS(5552),
    [aux_sym_zero_directive_token7] = ACTIONS(5552),
    [aux_sym_zero_directive_token8] = ACTIONS(5552),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5552),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5552),
    [anon_sym_wire] = ACTIONS(5554),
    [anon_sym_tri] = ACTIONS(5554),
    [anon_sym_tri0] = ACTIONS(5554),
    [anon_sym_tri1] = ACTIONS(5554),
    [anon_sym_wand] = ACTIONS(5554),
    [anon_sym_triand] = ACTIONS(5554),
    [anon_sym_wor] = ACTIONS(5554),
    [anon_sym_trior] = ACTIONS(5554),
    [anon_sym_trireg] = ACTIONS(5554),
    [anon_sym_uwire] = ACTIONS(5554),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5552),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5552),
    [aux_sym_begin_keywords_token1] = ACTIONS(5552),
    [anon_sym_SEMI] = ACTIONS(5552),
    [anon_sym_endmodule] = ACTIONS(5554),
    [anon_sym_extern] = ACTIONS(5554),
    [anon_sym_module] = ACTIONS(5554),
    [anon_sym_macromodule] = ACTIONS(5554),
    [anon_sym_endinterface] = ACTIONS(5554),
    [anon_sym_interface] = ACTIONS(5554),
    [anon_sym_endprogram] = ACTIONS(5554),
    [anon_sym_program] = ACTIONS(5554),
    [anon_sym_checker] = ACTIONS(5554),
    [anon_sym_virtual] = ACTIONS(5554),
    [anon_sym_class] = ACTIONS(5554),
    [anon_sym_package] = ACTIONS(5554),
    [anon_sym_timeunit] = ACTIONS(5554),
    [anon_sym_timeprecision] = ACTIONS(5554),
    [anon_sym_type] = ACTIONS(5554),
    [anon_sym_input] = ACTIONS(5554),
    [anon_sym_output] = ACTIONS(5554),
    [anon_sym_inout] = ACTIONS(5554),
    [anon_sym_ref] = ACTIONS(5554),
    [anon_sym_DOLLARfatal] = ACTIONS(5552),
    [anon_sym_DOLLARerror] = ACTIONS(5552),
    [anon_sym_DOLLARwarning] = ACTIONS(5552),
    [anon_sym_DOLLARinfo] = ACTIONS(5552),
    [anon_sym_default] = ACTIONS(5554),
    [anon_sym_clocking] = ACTIONS(5554),
    [anon_sym_defparam] = ACTIONS(5554),
    [anon_sym_bind] = ACTIONS(5554),
    [anon_sym_const] = ACTIONS(5554),
    [anon_sym_function] = ACTIONS(5554),
    [anon_sym_static] = ACTIONS(5554),
    [anon_sym_constraint] = ACTIONS(5554),
    [anon_sym_if] = ACTIONS(5554),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_localparam] = ACTIONS(5554),
    [anon_sym_parameter] = ACTIONS(5554),
    [anon_sym_specparam] = ACTIONS(5554),
    [anon_sym_var] = ACTIONS(5554),
    [anon_sym_import] = ACTIONS(5554),
    [anon_sym_export] = ACTIONS(5554),
    [anon_sym_genvar] = ACTIONS(5554),
    [anon_sym_interconnect] = ACTIONS(5554),
    [anon_sym_typedef] = ACTIONS(5554),
    [anon_sym_enum] = ACTIONS(5554),
    [anon_sym_struct] = ACTIONS(5554),
    [anon_sym_union] = ACTIONS(5554),
    [anon_sym_nettype] = ACTIONS(5554),
    [anon_sym_automatic] = ACTIONS(5554),
    [anon_sym_string] = ACTIONS(5554),
    [anon_sym_chandle] = ACTIONS(5554),
    [anon_sym_event] = ACTIONS(5554),
    [anon_sym_byte] = ACTIONS(5554),
    [anon_sym_shortint] = ACTIONS(5554),
    [anon_sym_int] = ACTIONS(5554),
    [anon_sym_longint] = ACTIONS(5554),
    [anon_sym_integer] = ACTIONS(5554),
    [anon_sym_time] = ACTIONS(5554),
    [anon_sym_bit] = ACTIONS(5554),
    [anon_sym_logic] = ACTIONS(5554),
    [anon_sym_reg] = ACTIONS(5554),
    [anon_sym_shortreal] = ACTIONS(5554),
    [anon_sym_real] = ACTIONS(5554),
    [anon_sym_realtime] = ACTIONS(5554),
    [anon_sym_supply0] = ACTIONS(5554),
    [anon_sym_supply1] = ACTIONS(5554),
    [anon_sym_signed] = ACTIONS(5554),
    [anon_sym_unsigned] = ACTIONS(5554),
    [anon_sym_task] = ACTIONS(5554),
    [anon_sym_modport] = ACTIONS(5554),
    [anon_sym_assert] = ACTIONS(5554),
    [anon_sym_property] = ACTIONS(5554),
    [anon_sym_assume] = ACTIONS(5554),
    [anon_sym_cover] = ACTIONS(5554),
    [anon_sym_sequence] = ACTIONS(5554),
    [anon_sym_restrict] = ACTIONS(5554),
    [anon_sym_not] = ACTIONS(5554),
    [anon_sym_or] = ACTIONS(5554),
    [anon_sym_and] = ACTIONS(5554),
    [anon_sym_case] = ACTIONS(5554),
    [anon_sym_always] = ACTIONS(5554),
    [anon_sym_covergroup] = ACTIONS(5554),
    [anon_sym_let] = ACTIONS(5554),
    [anon_sym_pulldown] = ACTIONS(5554),
    [anon_sym_pullup] = ACTIONS(5554),
    [anon_sym_cmos] = ACTIONS(5554),
    [anon_sym_rcmos] = ACTIONS(5554),
    [anon_sym_bufif0] = ACTIONS(5554),
    [anon_sym_bufif1] = ACTIONS(5554),
    [anon_sym_notif0] = ACTIONS(5554),
    [anon_sym_notif1] = ACTIONS(5554),
    [anon_sym_nmos] = ACTIONS(5554),
    [anon_sym_pmos] = ACTIONS(5554),
    [anon_sym_rnmos] = ACTIONS(5554),
    [anon_sym_rpmos] = ACTIONS(5554),
    [anon_sym_nand] = ACTIONS(5554),
    [anon_sym_nor] = ACTIONS(5554),
    [anon_sym_xor] = ACTIONS(5554),
    [anon_sym_xnor] = ACTIONS(5554),
    [anon_sym_buf] = ACTIONS(5554),
    [anon_sym_tranif0] = ACTIONS(5554),
    [anon_sym_tranif1] = ACTIONS(5554),
    [anon_sym_rtranif1] = ACTIONS(5554),
    [anon_sym_rtranif0] = ACTIONS(5554),
    [anon_sym_tran] = ACTIONS(5554),
    [anon_sym_rtran] = ACTIONS(5554),
    [anon_sym_generate] = ACTIONS(5554),
    [anon_sym_for] = ACTIONS(5554),
    [anon_sym_primitive] = ACTIONS(5554),
    [anon_sym_initial] = ACTIONS(5554),
    [anon_sym_assign] = ACTIONS(5554),
    [anon_sym_alias] = ACTIONS(5554),
    [anon_sym_always_comb] = ACTIONS(5554),
    [anon_sym_always_latch] = ACTIONS(5554),
    [anon_sym_always_ff] = ACTIONS(5554),
    [anon_sym_final] = ACTIONS(5554),
    [anon_sym_global] = ACTIONS(5554),
    [anon_sym_specify] = ACTIONS(5554),
    [anon_sym_LPAREN_STAR] = ACTIONS(5552),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5552),
    [anon_sym_DOLLARunit] = ACTIONS(5552),
  },
  [983] = {
    [ts_builtin_sym_end] = ACTIONS(5556),
    [sym_simple_identifier] = ACTIONS(5558),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5556),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5556),
    [anon_sym_BQUOTE] = ACTIONS(5558),
    [aux_sym_id_directive_token1] = ACTIONS(5556),
    [aux_sym_id_directive_token2] = ACTIONS(5556),
    [aux_sym_id_directive_token3] = ACTIONS(5556),
    [aux_sym_id_directive_token4] = ACTIONS(5558),
    [aux_sym_zero_directive_token1] = ACTIONS(5556),
    [aux_sym_zero_directive_token2] = ACTIONS(5556),
    [aux_sym_zero_directive_token3] = ACTIONS(5556),
    [aux_sym_zero_directive_token4] = ACTIONS(5556),
    [aux_sym_zero_directive_token5] = ACTIONS(5556),
    [aux_sym_zero_directive_token6] = ACTIONS(5556),
    [aux_sym_zero_directive_token7] = ACTIONS(5556),
    [aux_sym_zero_directive_token8] = ACTIONS(5556),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5556),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5556),
    [anon_sym_wire] = ACTIONS(5558),
    [anon_sym_tri] = ACTIONS(5558),
    [anon_sym_tri0] = ACTIONS(5558),
    [anon_sym_tri1] = ACTIONS(5558),
    [anon_sym_wand] = ACTIONS(5558),
    [anon_sym_triand] = ACTIONS(5558),
    [anon_sym_wor] = ACTIONS(5558),
    [anon_sym_trior] = ACTIONS(5558),
    [anon_sym_trireg] = ACTIONS(5558),
    [anon_sym_uwire] = ACTIONS(5558),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5556),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5556),
    [aux_sym_begin_keywords_token1] = ACTIONS(5556),
    [anon_sym_SEMI] = ACTIONS(5556),
    [anon_sym_endmodule] = ACTIONS(5558),
    [anon_sym_extern] = ACTIONS(5558),
    [anon_sym_module] = ACTIONS(5558),
    [anon_sym_macromodule] = ACTIONS(5558),
    [anon_sym_endinterface] = ACTIONS(5558),
    [anon_sym_interface] = ACTIONS(5558),
    [anon_sym_endprogram] = ACTIONS(5558),
    [anon_sym_program] = ACTIONS(5558),
    [anon_sym_checker] = ACTIONS(5558),
    [anon_sym_virtual] = ACTIONS(5558),
    [anon_sym_class] = ACTIONS(5558),
    [anon_sym_package] = ACTIONS(5558),
    [anon_sym_timeunit] = ACTIONS(5558),
    [anon_sym_timeprecision] = ACTIONS(5558),
    [anon_sym_type] = ACTIONS(5558),
    [anon_sym_input] = ACTIONS(5558),
    [anon_sym_output] = ACTIONS(5558),
    [anon_sym_inout] = ACTIONS(5558),
    [anon_sym_ref] = ACTIONS(5558),
    [anon_sym_DOLLARfatal] = ACTIONS(5556),
    [anon_sym_DOLLARerror] = ACTIONS(5556),
    [anon_sym_DOLLARwarning] = ACTIONS(5556),
    [anon_sym_DOLLARinfo] = ACTIONS(5556),
    [anon_sym_default] = ACTIONS(5558),
    [anon_sym_clocking] = ACTIONS(5558),
    [anon_sym_defparam] = ACTIONS(5558),
    [anon_sym_bind] = ACTIONS(5558),
    [anon_sym_const] = ACTIONS(5558),
    [anon_sym_function] = ACTIONS(5558),
    [anon_sym_static] = ACTIONS(5558),
    [anon_sym_constraint] = ACTIONS(5558),
    [anon_sym_if] = ACTIONS(5558),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_localparam] = ACTIONS(5558),
    [anon_sym_parameter] = ACTIONS(5558),
    [anon_sym_specparam] = ACTIONS(5558),
    [anon_sym_var] = ACTIONS(5558),
    [anon_sym_import] = ACTIONS(5558),
    [anon_sym_export] = ACTIONS(5558),
    [anon_sym_genvar] = ACTIONS(5558),
    [anon_sym_interconnect] = ACTIONS(5558),
    [anon_sym_typedef] = ACTIONS(5558),
    [anon_sym_enum] = ACTIONS(5558),
    [anon_sym_struct] = ACTIONS(5558),
    [anon_sym_union] = ACTIONS(5558),
    [anon_sym_nettype] = ACTIONS(5558),
    [anon_sym_automatic] = ACTIONS(5558),
    [anon_sym_string] = ACTIONS(5558),
    [anon_sym_chandle] = ACTIONS(5558),
    [anon_sym_event] = ACTIONS(5558),
    [anon_sym_byte] = ACTIONS(5558),
    [anon_sym_shortint] = ACTIONS(5558),
    [anon_sym_int] = ACTIONS(5558),
    [anon_sym_longint] = ACTIONS(5558),
    [anon_sym_integer] = ACTIONS(5558),
    [anon_sym_time] = ACTIONS(5558),
    [anon_sym_bit] = ACTIONS(5558),
    [anon_sym_logic] = ACTIONS(5558),
    [anon_sym_reg] = ACTIONS(5558),
    [anon_sym_shortreal] = ACTIONS(5558),
    [anon_sym_real] = ACTIONS(5558),
    [anon_sym_realtime] = ACTIONS(5558),
    [anon_sym_supply0] = ACTIONS(5558),
    [anon_sym_supply1] = ACTIONS(5558),
    [anon_sym_signed] = ACTIONS(5558),
    [anon_sym_unsigned] = ACTIONS(5558),
    [anon_sym_task] = ACTIONS(5558),
    [anon_sym_modport] = ACTIONS(5558),
    [anon_sym_assert] = ACTIONS(5558),
    [anon_sym_property] = ACTIONS(5558),
    [anon_sym_assume] = ACTIONS(5558),
    [anon_sym_cover] = ACTIONS(5558),
    [anon_sym_sequence] = ACTIONS(5558),
    [anon_sym_restrict] = ACTIONS(5558),
    [anon_sym_not] = ACTIONS(5558),
    [anon_sym_or] = ACTIONS(5558),
    [anon_sym_and] = ACTIONS(5558),
    [anon_sym_case] = ACTIONS(5558),
    [anon_sym_always] = ACTIONS(5558),
    [anon_sym_covergroup] = ACTIONS(5558),
    [anon_sym_let] = ACTIONS(5558),
    [anon_sym_pulldown] = ACTIONS(5558),
    [anon_sym_pullup] = ACTIONS(5558),
    [anon_sym_cmos] = ACTIONS(5558),
    [anon_sym_rcmos] = ACTIONS(5558),
    [anon_sym_bufif0] = ACTIONS(5558),
    [anon_sym_bufif1] = ACTIONS(5558),
    [anon_sym_notif0] = ACTIONS(5558),
    [anon_sym_notif1] = ACTIONS(5558),
    [anon_sym_nmos] = ACTIONS(5558),
    [anon_sym_pmos] = ACTIONS(5558),
    [anon_sym_rnmos] = ACTIONS(5558),
    [anon_sym_rpmos] = ACTIONS(5558),
    [anon_sym_nand] = ACTIONS(5558),
    [anon_sym_nor] = ACTIONS(5558),
    [anon_sym_xor] = ACTIONS(5558),
    [anon_sym_xnor] = ACTIONS(5558),
    [anon_sym_buf] = ACTIONS(5558),
    [anon_sym_tranif0] = ACTIONS(5558),
    [anon_sym_tranif1] = ACTIONS(5558),
    [anon_sym_rtranif1] = ACTIONS(5558),
    [anon_sym_rtranif0] = ACTIONS(5558),
    [anon_sym_tran] = ACTIONS(5558),
    [anon_sym_rtran] = ACTIONS(5558),
    [anon_sym_generate] = ACTIONS(5558),
    [anon_sym_for] = ACTIONS(5558),
    [anon_sym_primitive] = ACTIONS(5558),
    [anon_sym_initial] = ACTIONS(5558),
    [anon_sym_assign] = ACTIONS(5558),
    [anon_sym_alias] = ACTIONS(5558),
    [anon_sym_always_comb] = ACTIONS(5558),
    [anon_sym_always_latch] = ACTIONS(5558),
    [anon_sym_always_ff] = ACTIONS(5558),
    [anon_sym_final] = ACTIONS(5558),
    [anon_sym_global] = ACTIONS(5558),
    [anon_sym_specify] = ACTIONS(5558),
    [anon_sym_LPAREN_STAR] = ACTIONS(5556),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5556),
    [anon_sym_DOLLARunit] = ACTIONS(5556),
  },
  [984] = {
    [ts_builtin_sym_end] = ACTIONS(5560),
    [sym_simple_identifier] = ACTIONS(5562),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5560),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5560),
    [anon_sym_BQUOTE] = ACTIONS(5562),
    [aux_sym_id_directive_token1] = ACTIONS(5560),
    [aux_sym_id_directive_token2] = ACTIONS(5560),
    [aux_sym_id_directive_token3] = ACTIONS(5560),
    [aux_sym_id_directive_token4] = ACTIONS(5562),
    [aux_sym_zero_directive_token1] = ACTIONS(5560),
    [aux_sym_zero_directive_token2] = ACTIONS(5560),
    [aux_sym_zero_directive_token3] = ACTIONS(5560),
    [aux_sym_zero_directive_token4] = ACTIONS(5560),
    [aux_sym_zero_directive_token5] = ACTIONS(5560),
    [aux_sym_zero_directive_token6] = ACTIONS(5560),
    [aux_sym_zero_directive_token7] = ACTIONS(5560),
    [aux_sym_zero_directive_token8] = ACTIONS(5560),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5560),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5560),
    [anon_sym_wire] = ACTIONS(5562),
    [anon_sym_tri] = ACTIONS(5562),
    [anon_sym_tri0] = ACTIONS(5562),
    [anon_sym_tri1] = ACTIONS(5562),
    [anon_sym_wand] = ACTIONS(5562),
    [anon_sym_triand] = ACTIONS(5562),
    [anon_sym_wor] = ACTIONS(5562),
    [anon_sym_trior] = ACTIONS(5562),
    [anon_sym_trireg] = ACTIONS(5562),
    [anon_sym_uwire] = ACTIONS(5562),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5560),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5560),
    [aux_sym_begin_keywords_token1] = ACTIONS(5560),
    [anon_sym_SEMI] = ACTIONS(5560),
    [anon_sym_endmodule] = ACTIONS(5562),
    [anon_sym_extern] = ACTIONS(5562),
    [anon_sym_module] = ACTIONS(5562),
    [anon_sym_macromodule] = ACTIONS(5562),
    [anon_sym_endinterface] = ACTIONS(5562),
    [anon_sym_interface] = ACTIONS(5562),
    [anon_sym_endprogram] = ACTIONS(5562),
    [anon_sym_program] = ACTIONS(5562),
    [anon_sym_checker] = ACTIONS(5562),
    [anon_sym_virtual] = ACTIONS(5562),
    [anon_sym_class] = ACTIONS(5562),
    [anon_sym_package] = ACTIONS(5562),
    [anon_sym_timeunit] = ACTIONS(5562),
    [anon_sym_timeprecision] = ACTIONS(5562),
    [anon_sym_type] = ACTIONS(5562),
    [anon_sym_input] = ACTIONS(5562),
    [anon_sym_output] = ACTIONS(5562),
    [anon_sym_inout] = ACTIONS(5562),
    [anon_sym_ref] = ACTIONS(5562),
    [anon_sym_DOLLARfatal] = ACTIONS(5560),
    [anon_sym_DOLLARerror] = ACTIONS(5560),
    [anon_sym_DOLLARwarning] = ACTIONS(5560),
    [anon_sym_DOLLARinfo] = ACTIONS(5560),
    [anon_sym_default] = ACTIONS(5562),
    [anon_sym_clocking] = ACTIONS(5562),
    [anon_sym_defparam] = ACTIONS(5562),
    [anon_sym_bind] = ACTIONS(5562),
    [anon_sym_const] = ACTIONS(5562),
    [anon_sym_function] = ACTIONS(5562),
    [anon_sym_static] = ACTIONS(5562),
    [anon_sym_constraint] = ACTIONS(5562),
    [anon_sym_if] = ACTIONS(5562),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_localparam] = ACTIONS(5562),
    [anon_sym_parameter] = ACTIONS(5562),
    [anon_sym_specparam] = ACTIONS(5562),
    [anon_sym_var] = ACTIONS(5562),
    [anon_sym_import] = ACTIONS(5562),
    [anon_sym_export] = ACTIONS(5562),
    [anon_sym_genvar] = ACTIONS(5562),
    [anon_sym_interconnect] = ACTIONS(5562),
    [anon_sym_typedef] = ACTIONS(5562),
    [anon_sym_enum] = ACTIONS(5562),
    [anon_sym_struct] = ACTIONS(5562),
    [anon_sym_union] = ACTIONS(5562),
    [anon_sym_nettype] = ACTIONS(5562),
    [anon_sym_automatic] = ACTIONS(5562),
    [anon_sym_string] = ACTIONS(5562),
    [anon_sym_chandle] = ACTIONS(5562),
    [anon_sym_event] = ACTIONS(5562),
    [anon_sym_byte] = ACTIONS(5562),
    [anon_sym_shortint] = ACTIONS(5562),
    [anon_sym_int] = ACTIONS(5562),
    [anon_sym_longint] = ACTIONS(5562),
    [anon_sym_integer] = ACTIONS(5562),
    [anon_sym_time] = ACTIONS(5562),
    [anon_sym_bit] = ACTIONS(5562),
    [anon_sym_logic] = ACTIONS(5562),
    [anon_sym_reg] = ACTIONS(5562),
    [anon_sym_shortreal] = ACTIONS(5562),
    [anon_sym_real] = ACTIONS(5562),
    [anon_sym_realtime] = ACTIONS(5562),
    [anon_sym_supply0] = ACTIONS(5562),
    [anon_sym_supply1] = ACTIONS(5562),
    [anon_sym_signed] = ACTIONS(5562),
    [anon_sym_unsigned] = ACTIONS(5562),
    [anon_sym_task] = ACTIONS(5562),
    [anon_sym_modport] = ACTIONS(5562),
    [anon_sym_assert] = ACTIONS(5562),
    [anon_sym_property] = ACTIONS(5562),
    [anon_sym_assume] = ACTIONS(5562),
    [anon_sym_cover] = ACTIONS(5562),
    [anon_sym_sequence] = ACTIONS(5562),
    [anon_sym_restrict] = ACTIONS(5562),
    [anon_sym_not] = ACTIONS(5562),
    [anon_sym_or] = ACTIONS(5562),
    [anon_sym_and] = ACTIONS(5562),
    [anon_sym_case] = ACTIONS(5562),
    [anon_sym_always] = ACTIONS(5562),
    [anon_sym_covergroup] = ACTIONS(5562),
    [anon_sym_let] = ACTIONS(5562),
    [anon_sym_pulldown] = ACTIONS(5562),
    [anon_sym_pullup] = ACTIONS(5562),
    [anon_sym_cmos] = ACTIONS(5562),
    [anon_sym_rcmos] = ACTIONS(5562),
    [anon_sym_bufif0] = ACTIONS(5562),
    [anon_sym_bufif1] = ACTIONS(5562),
    [anon_sym_notif0] = ACTIONS(5562),
    [anon_sym_notif1] = ACTIONS(5562),
    [anon_sym_nmos] = ACTIONS(5562),
    [anon_sym_pmos] = ACTIONS(5562),
    [anon_sym_rnmos] = ACTIONS(5562),
    [anon_sym_rpmos] = ACTIONS(5562),
    [anon_sym_nand] = ACTIONS(5562),
    [anon_sym_nor] = ACTIONS(5562),
    [anon_sym_xor] = ACTIONS(5562),
    [anon_sym_xnor] = ACTIONS(5562),
    [anon_sym_buf] = ACTIONS(5562),
    [anon_sym_tranif0] = ACTIONS(5562),
    [anon_sym_tranif1] = ACTIONS(5562),
    [anon_sym_rtranif1] = ACTIONS(5562),
    [anon_sym_rtranif0] = ACTIONS(5562),
    [anon_sym_tran] = ACTIONS(5562),
    [anon_sym_rtran] = ACTIONS(5562),
    [anon_sym_generate] = ACTIONS(5562),
    [anon_sym_for] = ACTIONS(5562),
    [anon_sym_primitive] = ACTIONS(5562),
    [anon_sym_initial] = ACTIONS(5562),
    [anon_sym_assign] = ACTIONS(5562),
    [anon_sym_alias] = ACTIONS(5562),
    [anon_sym_always_comb] = ACTIONS(5562),
    [anon_sym_always_latch] = ACTIONS(5562),
    [anon_sym_always_ff] = ACTIONS(5562),
    [anon_sym_final] = ACTIONS(5562),
    [anon_sym_global] = ACTIONS(5562),
    [anon_sym_specify] = ACTIONS(5562),
    [anon_sym_LPAREN_STAR] = ACTIONS(5560),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5560),
    [anon_sym_DOLLARunit] = ACTIONS(5560),
  },
  [985] = {
    [ts_builtin_sym_end] = ACTIONS(5564),
    [sym_simple_identifier] = ACTIONS(5566),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5564),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5564),
    [anon_sym_BQUOTE] = ACTIONS(5566),
    [aux_sym_id_directive_token1] = ACTIONS(5564),
    [aux_sym_id_directive_token2] = ACTIONS(5564),
    [aux_sym_id_directive_token3] = ACTIONS(5564),
    [aux_sym_id_directive_token4] = ACTIONS(5566),
    [aux_sym_zero_directive_token1] = ACTIONS(5564),
    [aux_sym_zero_directive_token2] = ACTIONS(5564),
    [aux_sym_zero_directive_token3] = ACTIONS(5564),
    [aux_sym_zero_directive_token4] = ACTIONS(5564),
    [aux_sym_zero_directive_token5] = ACTIONS(5564),
    [aux_sym_zero_directive_token6] = ACTIONS(5564),
    [aux_sym_zero_directive_token7] = ACTIONS(5564),
    [aux_sym_zero_directive_token8] = ACTIONS(5564),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5564),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5564),
    [anon_sym_wire] = ACTIONS(5566),
    [anon_sym_tri] = ACTIONS(5566),
    [anon_sym_tri0] = ACTIONS(5566),
    [anon_sym_tri1] = ACTIONS(5566),
    [anon_sym_wand] = ACTIONS(5566),
    [anon_sym_triand] = ACTIONS(5566),
    [anon_sym_wor] = ACTIONS(5566),
    [anon_sym_trior] = ACTIONS(5566),
    [anon_sym_trireg] = ACTIONS(5566),
    [anon_sym_uwire] = ACTIONS(5566),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5564),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5564),
    [aux_sym_begin_keywords_token1] = ACTIONS(5564),
    [anon_sym_SEMI] = ACTIONS(5564),
    [anon_sym_endmodule] = ACTIONS(5566),
    [anon_sym_extern] = ACTIONS(5566),
    [anon_sym_module] = ACTIONS(5566),
    [anon_sym_macromodule] = ACTIONS(5566),
    [anon_sym_endinterface] = ACTIONS(5566),
    [anon_sym_interface] = ACTIONS(5566),
    [anon_sym_endprogram] = ACTIONS(5566),
    [anon_sym_program] = ACTIONS(5566),
    [anon_sym_checker] = ACTIONS(5566),
    [anon_sym_virtual] = ACTIONS(5566),
    [anon_sym_class] = ACTIONS(5566),
    [anon_sym_package] = ACTIONS(5566),
    [anon_sym_timeunit] = ACTIONS(5566),
    [anon_sym_timeprecision] = ACTIONS(5566),
    [anon_sym_type] = ACTIONS(5566),
    [anon_sym_input] = ACTIONS(5566),
    [anon_sym_output] = ACTIONS(5566),
    [anon_sym_inout] = ACTIONS(5566),
    [anon_sym_ref] = ACTIONS(5566),
    [anon_sym_DOLLARfatal] = ACTIONS(5564),
    [anon_sym_DOLLARerror] = ACTIONS(5564),
    [anon_sym_DOLLARwarning] = ACTIONS(5564),
    [anon_sym_DOLLARinfo] = ACTIONS(5564),
    [anon_sym_default] = ACTIONS(5566),
    [anon_sym_clocking] = ACTIONS(5566),
    [anon_sym_defparam] = ACTIONS(5566),
    [anon_sym_bind] = ACTIONS(5566),
    [anon_sym_const] = ACTIONS(5566),
    [anon_sym_function] = ACTIONS(5566),
    [anon_sym_static] = ACTIONS(5566),
    [anon_sym_constraint] = ACTIONS(5566),
    [anon_sym_if] = ACTIONS(5566),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_localparam] = ACTIONS(5566),
    [anon_sym_parameter] = ACTIONS(5566),
    [anon_sym_specparam] = ACTIONS(5566),
    [anon_sym_var] = ACTIONS(5566),
    [anon_sym_import] = ACTIONS(5566),
    [anon_sym_export] = ACTIONS(5566),
    [anon_sym_genvar] = ACTIONS(5566),
    [anon_sym_interconnect] = ACTIONS(5566),
    [anon_sym_typedef] = ACTIONS(5566),
    [anon_sym_enum] = ACTIONS(5566),
    [anon_sym_struct] = ACTIONS(5566),
    [anon_sym_union] = ACTIONS(5566),
    [anon_sym_nettype] = ACTIONS(5566),
    [anon_sym_automatic] = ACTIONS(5566),
    [anon_sym_string] = ACTIONS(5566),
    [anon_sym_chandle] = ACTIONS(5566),
    [anon_sym_event] = ACTIONS(5566),
    [anon_sym_byte] = ACTIONS(5566),
    [anon_sym_shortint] = ACTIONS(5566),
    [anon_sym_int] = ACTIONS(5566),
    [anon_sym_longint] = ACTIONS(5566),
    [anon_sym_integer] = ACTIONS(5566),
    [anon_sym_time] = ACTIONS(5566),
    [anon_sym_bit] = ACTIONS(5566),
    [anon_sym_logic] = ACTIONS(5566),
    [anon_sym_reg] = ACTIONS(5566),
    [anon_sym_shortreal] = ACTIONS(5566),
    [anon_sym_real] = ACTIONS(5566),
    [anon_sym_realtime] = ACTIONS(5566),
    [anon_sym_supply0] = ACTIONS(5566),
    [anon_sym_supply1] = ACTIONS(5566),
    [anon_sym_signed] = ACTIONS(5566),
    [anon_sym_unsigned] = ACTIONS(5566),
    [anon_sym_task] = ACTIONS(5566),
    [anon_sym_modport] = ACTIONS(5566),
    [anon_sym_assert] = ACTIONS(5566),
    [anon_sym_property] = ACTIONS(5566),
    [anon_sym_assume] = ACTIONS(5566),
    [anon_sym_cover] = ACTIONS(5566),
    [anon_sym_sequence] = ACTIONS(5566),
    [anon_sym_restrict] = ACTIONS(5566),
    [anon_sym_not] = ACTIONS(5566),
    [anon_sym_or] = ACTIONS(5566),
    [anon_sym_and] = ACTIONS(5566),
    [anon_sym_case] = ACTIONS(5566),
    [anon_sym_always] = ACTIONS(5566),
    [anon_sym_covergroup] = ACTIONS(5566),
    [anon_sym_let] = ACTIONS(5566),
    [anon_sym_pulldown] = ACTIONS(5566),
    [anon_sym_pullup] = ACTIONS(5566),
    [anon_sym_cmos] = ACTIONS(5566),
    [anon_sym_rcmos] = ACTIONS(5566),
    [anon_sym_bufif0] = ACTIONS(5566),
    [anon_sym_bufif1] = ACTIONS(5566),
    [anon_sym_notif0] = ACTIONS(5566),
    [anon_sym_notif1] = ACTIONS(5566),
    [anon_sym_nmos] = ACTIONS(5566),
    [anon_sym_pmos] = ACTIONS(5566),
    [anon_sym_rnmos] = ACTIONS(5566),
    [anon_sym_rpmos] = ACTIONS(5566),
    [anon_sym_nand] = ACTIONS(5566),
    [anon_sym_nor] = ACTIONS(5566),
    [anon_sym_xor] = ACTIONS(5566),
    [anon_sym_xnor] = ACTIONS(5566),
    [anon_sym_buf] = ACTIONS(5566),
    [anon_sym_tranif0] = ACTIONS(5566),
    [anon_sym_tranif1] = ACTIONS(5566),
    [anon_sym_rtranif1] = ACTIONS(5566),
    [anon_sym_rtranif0] = ACTIONS(5566),
    [anon_sym_tran] = ACTIONS(5566),
    [anon_sym_rtran] = ACTIONS(5566),
    [anon_sym_generate] = ACTIONS(5566),
    [anon_sym_for] = ACTIONS(5566),
    [anon_sym_primitive] = ACTIONS(5566),
    [anon_sym_initial] = ACTIONS(5566),
    [anon_sym_assign] = ACTIONS(5566),
    [anon_sym_alias] = ACTIONS(5566),
    [anon_sym_always_comb] = ACTIONS(5566),
    [anon_sym_always_latch] = ACTIONS(5566),
    [anon_sym_always_ff] = ACTIONS(5566),
    [anon_sym_final] = ACTIONS(5566),
    [anon_sym_global] = ACTIONS(5566),
    [anon_sym_specify] = ACTIONS(5566),
    [anon_sym_LPAREN_STAR] = ACTIONS(5564),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5564),
    [anon_sym_DOLLARunit] = ACTIONS(5564),
  },
  [986] = {
    [ts_builtin_sym_end] = ACTIONS(5568),
    [sym_simple_identifier] = ACTIONS(5570),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5568),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5568),
    [anon_sym_BQUOTE] = ACTIONS(5570),
    [aux_sym_id_directive_token1] = ACTIONS(5568),
    [aux_sym_id_directive_token2] = ACTIONS(5568),
    [aux_sym_id_directive_token3] = ACTIONS(5568),
    [aux_sym_id_directive_token4] = ACTIONS(5570),
    [aux_sym_zero_directive_token1] = ACTIONS(5568),
    [aux_sym_zero_directive_token2] = ACTIONS(5568),
    [aux_sym_zero_directive_token3] = ACTIONS(5568),
    [aux_sym_zero_directive_token4] = ACTIONS(5568),
    [aux_sym_zero_directive_token5] = ACTIONS(5568),
    [aux_sym_zero_directive_token6] = ACTIONS(5568),
    [aux_sym_zero_directive_token7] = ACTIONS(5568),
    [aux_sym_zero_directive_token8] = ACTIONS(5568),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5568),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5568),
    [anon_sym_wire] = ACTIONS(5570),
    [anon_sym_tri] = ACTIONS(5570),
    [anon_sym_tri0] = ACTIONS(5570),
    [anon_sym_tri1] = ACTIONS(5570),
    [anon_sym_wand] = ACTIONS(5570),
    [anon_sym_triand] = ACTIONS(5570),
    [anon_sym_wor] = ACTIONS(5570),
    [anon_sym_trior] = ACTIONS(5570),
    [anon_sym_trireg] = ACTIONS(5570),
    [anon_sym_uwire] = ACTIONS(5570),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5568),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5568),
    [aux_sym_begin_keywords_token1] = ACTIONS(5568),
    [anon_sym_SEMI] = ACTIONS(5568),
    [anon_sym_endmodule] = ACTIONS(5570),
    [anon_sym_extern] = ACTIONS(5570),
    [anon_sym_module] = ACTIONS(5570),
    [anon_sym_macromodule] = ACTIONS(5570),
    [anon_sym_endinterface] = ACTIONS(5570),
    [anon_sym_interface] = ACTIONS(5570),
    [anon_sym_endprogram] = ACTIONS(5570),
    [anon_sym_program] = ACTIONS(5570),
    [anon_sym_checker] = ACTIONS(5570),
    [anon_sym_virtual] = ACTIONS(5570),
    [anon_sym_class] = ACTIONS(5570),
    [anon_sym_package] = ACTIONS(5570),
    [anon_sym_timeunit] = ACTIONS(5570),
    [anon_sym_timeprecision] = ACTIONS(5570),
    [anon_sym_type] = ACTIONS(5570),
    [anon_sym_input] = ACTIONS(5570),
    [anon_sym_output] = ACTIONS(5570),
    [anon_sym_inout] = ACTIONS(5570),
    [anon_sym_ref] = ACTIONS(5570),
    [anon_sym_DOLLARfatal] = ACTIONS(5568),
    [anon_sym_DOLLARerror] = ACTIONS(5568),
    [anon_sym_DOLLARwarning] = ACTIONS(5568),
    [anon_sym_DOLLARinfo] = ACTIONS(5568),
    [anon_sym_default] = ACTIONS(5570),
    [anon_sym_clocking] = ACTIONS(5570),
    [anon_sym_defparam] = ACTIONS(5570),
    [anon_sym_bind] = ACTIONS(5570),
    [anon_sym_const] = ACTIONS(5570),
    [anon_sym_function] = ACTIONS(5570),
    [anon_sym_static] = ACTIONS(5570),
    [anon_sym_constraint] = ACTIONS(5570),
    [anon_sym_if] = ACTIONS(5570),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_localparam] = ACTIONS(5570),
    [anon_sym_parameter] = ACTIONS(5570),
    [anon_sym_specparam] = ACTIONS(5570),
    [anon_sym_var] = ACTIONS(5570),
    [anon_sym_import] = ACTIONS(5570),
    [anon_sym_export] = ACTIONS(5570),
    [anon_sym_genvar] = ACTIONS(5570),
    [anon_sym_interconnect] = ACTIONS(5570),
    [anon_sym_typedef] = ACTIONS(5570),
    [anon_sym_enum] = ACTIONS(5570),
    [anon_sym_struct] = ACTIONS(5570),
    [anon_sym_union] = ACTIONS(5570),
    [anon_sym_nettype] = ACTIONS(5570),
    [anon_sym_automatic] = ACTIONS(5570),
    [anon_sym_string] = ACTIONS(5570),
    [anon_sym_chandle] = ACTIONS(5570),
    [anon_sym_event] = ACTIONS(5570),
    [anon_sym_byte] = ACTIONS(5570),
    [anon_sym_shortint] = ACTIONS(5570),
    [anon_sym_int] = ACTIONS(5570),
    [anon_sym_longint] = ACTIONS(5570),
    [anon_sym_integer] = ACTIONS(5570),
    [anon_sym_time] = ACTIONS(5570),
    [anon_sym_bit] = ACTIONS(5570),
    [anon_sym_logic] = ACTIONS(5570),
    [anon_sym_reg] = ACTIONS(5570),
    [anon_sym_shortreal] = ACTIONS(5570),
    [anon_sym_real] = ACTIONS(5570),
    [anon_sym_realtime] = ACTIONS(5570),
    [anon_sym_supply0] = ACTIONS(5570),
    [anon_sym_supply1] = ACTIONS(5570),
    [anon_sym_signed] = ACTIONS(5570),
    [anon_sym_unsigned] = ACTIONS(5570),
    [anon_sym_task] = ACTIONS(5570),
    [anon_sym_modport] = ACTIONS(5570),
    [anon_sym_assert] = ACTIONS(5570),
    [anon_sym_property] = ACTIONS(5570),
    [anon_sym_assume] = ACTIONS(5570),
    [anon_sym_cover] = ACTIONS(5570),
    [anon_sym_sequence] = ACTIONS(5570),
    [anon_sym_restrict] = ACTIONS(5570),
    [anon_sym_not] = ACTIONS(5570),
    [anon_sym_or] = ACTIONS(5570),
    [anon_sym_and] = ACTIONS(5570),
    [anon_sym_case] = ACTIONS(5570),
    [anon_sym_always] = ACTIONS(5570),
    [anon_sym_covergroup] = ACTIONS(5570),
    [anon_sym_let] = ACTIONS(5570),
    [anon_sym_pulldown] = ACTIONS(5570),
    [anon_sym_pullup] = ACTIONS(5570),
    [anon_sym_cmos] = ACTIONS(5570),
    [anon_sym_rcmos] = ACTIONS(5570),
    [anon_sym_bufif0] = ACTIONS(5570),
    [anon_sym_bufif1] = ACTIONS(5570),
    [anon_sym_notif0] = ACTIONS(5570),
    [anon_sym_notif1] = ACTIONS(5570),
    [anon_sym_nmos] = ACTIONS(5570),
    [anon_sym_pmos] = ACTIONS(5570),
    [anon_sym_rnmos] = ACTIONS(5570),
    [anon_sym_rpmos] = ACTIONS(5570),
    [anon_sym_nand] = ACTIONS(5570),
    [anon_sym_nor] = ACTIONS(5570),
    [anon_sym_xor] = ACTIONS(5570),
    [anon_sym_xnor] = ACTIONS(5570),
    [anon_sym_buf] = ACTIONS(5570),
    [anon_sym_tranif0] = ACTIONS(5570),
    [anon_sym_tranif1] = ACTIONS(5570),
    [anon_sym_rtranif1] = ACTIONS(5570),
    [anon_sym_rtranif0] = ACTIONS(5570),
    [anon_sym_tran] = ACTIONS(5570),
    [anon_sym_rtran] = ACTIONS(5570),
    [anon_sym_generate] = ACTIONS(5570),
    [anon_sym_for] = ACTIONS(5570),
    [anon_sym_primitive] = ACTIONS(5570),
    [anon_sym_initial] = ACTIONS(5570),
    [anon_sym_assign] = ACTIONS(5570),
    [anon_sym_alias] = ACTIONS(5570),
    [anon_sym_always_comb] = ACTIONS(5570),
    [anon_sym_always_latch] = ACTIONS(5570),
    [anon_sym_always_ff] = ACTIONS(5570),
    [anon_sym_final] = ACTIONS(5570),
    [anon_sym_global] = ACTIONS(5570),
    [anon_sym_specify] = ACTIONS(5570),
    [anon_sym_LPAREN_STAR] = ACTIONS(5568),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5568),
    [anon_sym_DOLLARunit] = ACTIONS(5568),
  },
  [987] = {
    [ts_builtin_sym_end] = ACTIONS(5572),
    [sym_simple_identifier] = ACTIONS(5574),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5572),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5572),
    [anon_sym_BQUOTE] = ACTIONS(5574),
    [aux_sym_id_directive_token1] = ACTIONS(5572),
    [aux_sym_id_directive_token2] = ACTIONS(5572),
    [aux_sym_id_directive_token3] = ACTIONS(5572),
    [aux_sym_id_directive_token4] = ACTIONS(5574),
    [aux_sym_zero_directive_token1] = ACTIONS(5572),
    [aux_sym_zero_directive_token2] = ACTIONS(5572),
    [aux_sym_zero_directive_token3] = ACTIONS(5572),
    [aux_sym_zero_directive_token4] = ACTIONS(5572),
    [aux_sym_zero_directive_token5] = ACTIONS(5572),
    [aux_sym_zero_directive_token6] = ACTIONS(5572),
    [aux_sym_zero_directive_token7] = ACTIONS(5572),
    [aux_sym_zero_directive_token8] = ACTIONS(5572),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5572),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5572),
    [anon_sym_wire] = ACTIONS(5574),
    [anon_sym_tri] = ACTIONS(5574),
    [anon_sym_tri0] = ACTIONS(5574),
    [anon_sym_tri1] = ACTIONS(5574),
    [anon_sym_wand] = ACTIONS(5574),
    [anon_sym_triand] = ACTIONS(5574),
    [anon_sym_wor] = ACTIONS(5574),
    [anon_sym_trior] = ACTIONS(5574),
    [anon_sym_trireg] = ACTIONS(5574),
    [anon_sym_uwire] = ACTIONS(5574),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5572),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5572),
    [aux_sym_begin_keywords_token1] = ACTIONS(5572),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_endmodule] = ACTIONS(5574),
    [anon_sym_extern] = ACTIONS(5574),
    [anon_sym_module] = ACTIONS(5574),
    [anon_sym_macromodule] = ACTIONS(5574),
    [anon_sym_endinterface] = ACTIONS(5574),
    [anon_sym_interface] = ACTIONS(5574),
    [anon_sym_endprogram] = ACTIONS(5574),
    [anon_sym_program] = ACTIONS(5574),
    [anon_sym_checker] = ACTIONS(5574),
    [anon_sym_virtual] = ACTIONS(5574),
    [anon_sym_class] = ACTIONS(5574),
    [anon_sym_package] = ACTIONS(5574),
    [anon_sym_timeunit] = ACTIONS(5574),
    [anon_sym_timeprecision] = ACTIONS(5574),
    [anon_sym_type] = ACTIONS(5574),
    [anon_sym_input] = ACTIONS(5574),
    [anon_sym_output] = ACTIONS(5574),
    [anon_sym_inout] = ACTIONS(5574),
    [anon_sym_ref] = ACTIONS(5574),
    [anon_sym_DOLLARfatal] = ACTIONS(5572),
    [anon_sym_DOLLARerror] = ACTIONS(5572),
    [anon_sym_DOLLARwarning] = ACTIONS(5572),
    [anon_sym_DOLLARinfo] = ACTIONS(5572),
    [anon_sym_default] = ACTIONS(5574),
    [anon_sym_clocking] = ACTIONS(5574),
    [anon_sym_defparam] = ACTIONS(5574),
    [anon_sym_bind] = ACTIONS(5574),
    [anon_sym_const] = ACTIONS(5574),
    [anon_sym_function] = ACTIONS(5574),
    [anon_sym_static] = ACTIONS(5574),
    [anon_sym_constraint] = ACTIONS(5574),
    [anon_sym_if] = ACTIONS(5574),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_localparam] = ACTIONS(5574),
    [anon_sym_parameter] = ACTIONS(5574),
    [anon_sym_specparam] = ACTIONS(5574),
    [anon_sym_var] = ACTIONS(5574),
    [anon_sym_import] = ACTIONS(5574),
    [anon_sym_export] = ACTIONS(5574),
    [anon_sym_genvar] = ACTIONS(5574),
    [anon_sym_interconnect] = ACTIONS(5574),
    [anon_sym_typedef] = ACTIONS(5574),
    [anon_sym_enum] = ACTIONS(5574),
    [anon_sym_struct] = ACTIONS(5574),
    [anon_sym_union] = ACTIONS(5574),
    [anon_sym_nettype] = ACTIONS(5574),
    [anon_sym_automatic] = ACTIONS(5574),
    [anon_sym_string] = ACTIONS(5574),
    [anon_sym_chandle] = ACTIONS(5574),
    [anon_sym_event] = ACTIONS(5574),
    [anon_sym_byte] = ACTIONS(5574),
    [anon_sym_shortint] = ACTIONS(5574),
    [anon_sym_int] = ACTIONS(5574),
    [anon_sym_longint] = ACTIONS(5574),
    [anon_sym_integer] = ACTIONS(5574),
    [anon_sym_time] = ACTIONS(5574),
    [anon_sym_bit] = ACTIONS(5574),
    [anon_sym_logic] = ACTIONS(5574),
    [anon_sym_reg] = ACTIONS(5574),
    [anon_sym_shortreal] = ACTIONS(5574),
    [anon_sym_real] = ACTIONS(5574),
    [anon_sym_realtime] = ACTIONS(5574),
    [anon_sym_supply0] = ACTIONS(5574),
    [anon_sym_supply1] = ACTIONS(5574),
    [anon_sym_signed] = ACTIONS(5574),
    [anon_sym_unsigned] = ACTIONS(5574),
    [anon_sym_task] = ACTIONS(5574),
    [anon_sym_modport] = ACTIONS(5574),
    [anon_sym_assert] = ACTIONS(5574),
    [anon_sym_property] = ACTIONS(5574),
    [anon_sym_assume] = ACTIONS(5574),
    [anon_sym_cover] = ACTIONS(5574),
    [anon_sym_sequence] = ACTIONS(5574),
    [anon_sym_restrict] = ACTIONS(5574),
    [anon_sym_not] = ACTIONS(5574),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_and] = ACTIONS(5574),
    [anon_sym_case] = ACTIONS(5574),
    [anon_sym_always] = ACTIONS(5574),
    [anon_sym_covergroup] = ACTIONS(5574),
    [anon_sym_let] = ACTIONS(5574),
    [anon_sym_pulldown] = ACTIONS(5574),
    [anon_sym_pullup] = ACTIONS(5574),
    [anon_sym_cmos] = ACTIONS(5574),
    [anon_sym_rcmos] = ACTIONS(5574),
    [anon_sym_bufif0] = ACTIONS(5574),
    [anon_sym_bufif1] = ACTIONS(5574),
    [anon_sym_notif0] = ACTIONS(5574),
    [anon_sym_notif1] = ACTIONS(5574),
    [anon_sym_nmos] = ACTIONS(5574),
    [anon_sym_pmos] = ACTIONS(5574),
    [anon_sym_rnmos] = ACTIONS(5574),
    [anon_sym_rpmos] = ACTIONS(5574),
    [anon_sym_nand] = ACTIONS(5574),
    [anon_sym_nor] = ACTIONS(5574),
    [anon_sym_xor] = ACTIONS(5574),
    [anon_sym_xnor] = ACTIONS(5574),
    [anon_sym_buf] = ACTIONS(5574),
    [anon_sym_tranif0] = ACTIONS(5574),
    [anon_sym_tranif1] = ACTIONS(5574),
    [anon_sym_rtranif1] = ACTIONS(5574),
    [anon_sym_rtranif0] = ACTIONS(5574),
    [anon_sym_tran] = ACTIONS(5574),
    [anon_sym_rtran] = ACTIONS(5574),
    [anon_sym_generate] = ACTIONS(5574),
    [anon_sym_for] = ACTIONS(5574),
    [anon_sym_primitive] = ACTIONS(5574),
    [anon_sym_initial] = ACTIONS(5574),
    [anon_sym_assign] = ACTIONS(5574),
    [anon_sym_alias] = ACTIONS(5574),
    [anon_sym_always_comb] = ACTIONS(5574),
    [anon_sym_always_latch] = ACTIONS(5574),
    [anon_sym_always_ff] = ACTIONS(5574),
    [anon_sym_final] = ACTIONS(5574),
    [anon_sym_global] = ACTIONS(5574),
    [anon_sym_specify] = ACTIONS(5574),
    [anon_sym_LPAREN_STAR] = ACTIONS(5572),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5572),
    [anon_sym_DOLLARunit] = ACTIONS(5572),
  },
  [988] = {
    [ts_builtin_sym_end] = ACTIONS(5576),
    [sym_simple_identifier] = ACTIONS(5578),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5576),
    [anon_sym_BQUOTE] = ACTIONS(5578),
    [aux_sym_id_directive_token1] = ACTIONS(5576),
    [aux_sym_id_directive_token2] = ACTIONS(5576),
    [aux_sym_id_directive_token3] = ACTIONS(5576),
    [aux_sym_id_directive_token4] = ACTIONS(5578),
    [aux_sym_zero_directive_token1] = ACTIONS(5576),
    [aux_sym_zero_directive_token2] = ACTIONS(5576),
    [aux_sym_zero_directive_token3] = ACTIONS(5576),
    [aux_sym_zero_directive_token4] = ACTIONS(5576),
    [aux_sym_zero_directive_token5] = ACTIONS(5576),
    [aux_sym_zero_directive_token6] = ACTIONS(5576),
    [aux_sym_zero_directive_token7] = ACTIONS(5576),
    [aux_sym_zero_directive_token8] = ACTIONS(5576),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5576),
    [anon_sym_wire] = ACTIONS(5578),
    [anon_sym_tri] = ACTIONS(5578),
    [anon_sym_tri0] = ACTIONS(5578),
    [anon_sym_tri1] = ACTIONS(5578),
    [anon_sym_wand] = ACTIONS(5578),
    [anon_sym_triand] = ACTIONS(5578),
    [anon_sym_wor] = ACTIONS(5578),
    [anon_sym_trior] = ACTIONS(5578),
    [anon_sym_trireg] = ACTIONS(5578),
    [anon_sym_uwire] = ACTIONS(5578),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5576),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_begin_keywords_token1] = ACTIONS(5576),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_endmodule] = ACTIONS(5578),
    [anon_sym_COLON] = ACTIONS(5580),
    [anon_sym_extern] = ACTIONS(5578),
    [anon_sym_module] = ACTIONS(5578),
    [anon_sym_macromodule] = ACTIONS(5578),
    [anon_sym_endinterface] = ACTIONS(5578),
    [anon_sym_interface] = ACTIONS(5578),
    [anon_sym_program] = ACTIONS(5578),
    [anon_sym_checker] = ACTIONS(5578),
    [anon_sym_virtual] = ACTIONS(5578),
    [anon_sym_class] = ACTIONS(5578),
    [anon_sym_package] = ACTIONS(5578),
    [anon_sym_timeunit] = ACTIONS(5578),
    [anon_sym_timeprecision] = ACTIONS(5578),
    [anon_sym_type] = ACTIONS(5578),
    [anon_sym_input] = ACTIONS(5578),
    [anon_sym_output] = ACTIONS(5578),
    [anon_sym_inout] = ACTIONS(5578),
    [anon_sym_ref] = ACTIONS(5578),
    [anon_sym_DOLLARfatal] = ACTIONS(5576),
    [anon_sym_DOLLARerror] = ACTIONS(5576),
    [anon_sym_DOLLARwarning] = ACTIONS(5576),
    [anon_sym_DOLLARinfo] = ACTIONS(5576),
    [anon_sym_default] = ACTIONS(5578),
    [anon_sym_clocking] = ACTIONS(5578),
    [anon_sym_defparam] = ACTIONS(5578),
    [anon_sym_bind] = ACTIONS(5578),
    [anon_sym_const] = ACTIONS(5578),
    [anon_sym_function] = ACTIONS(5578),
    [anon_sym_static] = ACTIONS(5578),
    [anon_sym_constraint] = ACTIONS(5578),
    [anon_sym_if] = ACTIONS(5578),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_localparam] = ACTIONS(5578),
    [anon_sym_parameter] = ACTIONS(5578),
    [anon_sym_specparam] = ACTIONS(5578),
    [anon_sym_var] = ACTIONS(5578),
    [anon_sym_import] = ACTIONS(5578),
    [anon_sym_export] = ACTIONS(5578),
    [anon_sym_genvar] = ACTIONS(5578),
    [anon_sym_interconnect] = ACTIONS(5578),
    [anon_sym_typedef] = ACTIONS(5578),
    [anon_sym_enum] = ACTIONS(5578),
    [anon_sym_struct] = ACTIONS(5578),
    [anon_sym_union] = ACTIONS(5578),
    [anon_sym_nettype] = ACTIONS(5578),
    [anon_sym_automatic] = ACTIONS(5578),
    [anon_sym_string] = ACTIONS(5578),
    [anon_sym_chandle] = ACTIONS(5578),
    [anon_sym_event] = ACTIONS(5578),
    [anon_sym_byte] = ACTIONS(5578),
    [anon_sym_shortint] = ACTIONS(5578),
    [anon_sym_int] = ACTIONS(5578),
    [anon_sym_longint] = ACTIONS(5578),
    [anon_sym_integer] = ACTIONS(5578),
    [anon_sym_time] = ACTIONS(5578),
    [anon_sym_bit] = ACTIONS(5578),
    [anon_sym_logic] = ACTIONS(5578),
    [anon_sym_reg] = ACTIONS(5578),
    [anon_sym_shortreal] = ACTIONS(5578),
    [anon_sym_real] = ACTIONS(5578),
    [anon_sym_realtime] = ACTIONS(5578),
    [anon_sym_supply0] = ACTIONS(5578),
    [anon_sym_supply1] = ACTIONS(5578),
    [anon_sym_signed] = ACTIONS(5578),
    [anon_sym_unsigned] = ACTIONS(5578),
    [anon_sym_task] = ACTIONS(5578),
    [anon_sym_modport] = ACTIONS(5578),
    [anon_sym_assert] = ACTIONS(5578),
    [anon_sym_property] = ACTIONS(5578),
    [anon_sym_assume] = ACTIONS(5578),
    [anon_sym_cover] = ACTIONS(5578),
    [anon_sym_sequence] = ACTIONS(5578),
    [anon_sym_restrict] = ACTIONS(5578),
    [anon_sym_not] = ACTIONS(5578),
    [anon_sym_or] = ACTIONS(5578),
    [anon_sym_and] = ACTIONS(5578),
    [anon_sym_case] = ACTIONS(5578),
    [anon_sym_always] = ACTIONS(5578),
    [anon_sym_covergroup] = ACTIONS(5578),
    [anon_sym_let] = ACTIONS(5578),
    [anon_sym_pulldown] = ACTIONS(5578),
    [anon_sym_pullup] = ACTIONS(5578),
    [anon_sym_cmos] = ACTIONS(5578),
    [anon_sym_rcmos] = ACTIONS(5578),
    [anon_sym_bufif0] = ACTIONS(5578),
    [anon_sym_bufif1] = ACTIONS(5578),
    [anon_sym_notif0] = ACTIONS(5578),
    [anon_sym_notif1] = ACTIONS(5578),
    [anon_sym_nmos] = ACTIONS(5578),
    [anon_sym_pmos] = ACTIONS(5578),
    [anon_sym_rnmos] = ACTIONS(5578),
    [anon_sym_rpmos] = ACTIONS(5578),
    [anon_sym_nand] = ACTIONS(5578),
    [anon_sym_nor] = ACTIONS(5578),
    [anon_sym_xor] = ACTIONS(5578),
    [anon_sym_xnor] = ACTIONS(5578),
    [anon_sym_buf] = ACTIONS(5578),
    [anon_sym_tranif0] = ACTIONS(5578),
    [anon_sym_tranif1] = ACTIONS(5578),
    [anon_sym_rtranif1] = ACTIONS(5578),
    [anon_sym_rtranif0] = ACTIONS(5578),
    [anon_sym_tran] = ACTIONS(5578),
    [anon_sym_rtran] = ACTIONS(5578),
    [anon_sym_generate] = ACTIONS(5578),
    [anon_sym_for] = ACTIONS(5578),
    [anon_sym_primitive] = ACTIONS(5578),
    [anon_sym_initial] = ACTIONS(5578),
    [anon_sym_assign] = ACTIONS(5578),
    [anon_sym_alias] = ACTIONS(5578),
    [anon_sym_always_comb] = ACTIONS(5578),
    [anon_sym_always_latch] = ACTIONS(5578),
    [anon_sym_always_ff] = ACTIONS(5578),
    [anon_sym_final] = ACTIONS(5578),
    [anon_sym_global] = ACTIONS(5578),
    [anon_sym_specify] = ACTIONS(5578),
    [anon_sym_LPAREN_STAR] = ACTIONS(5576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5576),
    [anon_sym_DOLLARunit] = ACTIONS(5576),
  },
  [989] = {
    [ts_builtin_sym_end] = ACTIONS(5582),
    [sym_simple_identifier] = ACTIONS(5584),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5582),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5582),
    [anon_sym_BQUOTE] = ACTIONS(5584),
    [aux_sym_id_directive_token1] = ACTIONS(5582),
    [aux_sym_id_directive_token2] = ACTIONS(5582),
    [aux_sym_id_directive_token3] = ACTIONS(5582),
    [aux_sym_id_directive_token4] = ACTIONS(5584),
    [aux_sym_zero_directive_token1] = ACTIONS(5582),
    [aux_sym_zero_directive_token2] = ACTIONS(5582),
    [aux_sym_zero_directive_token3] = ACTIONS(5582),
    [aux_sym_zero_directive_token4] = ACTIONS(5582),
    [aux_sym_zero_directive_token5] = ACTIONS(5582),
    [aux_sym_zero_directive_token6] = ACTIONS(5582),
    [aux_sym_zero_directive_token7] = ACTIONS(5582),
    [aux_sym_zero_directive_token8] = ACTIONS(5582),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5582),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5582),
    [anon_sym_wire] = ACTIONS(5584),
    [anon_sym_tri] = ACTIONS(5584),
    [anon_sym_tri0] = ACTIONS(5584),
    [anon_sym_tri1] = ACTIONS(5584),
    [anon_sym_wand] = ACTIONS(5584),
    [anon_sym_triand] = ACTIONS(5584),
    [anon_sym_wor] = ACTIONS(5584),
    [anon_sym_trior] = ACTIONS(5584),
    [anon_sym_trireg] = ACTIONS(5584),
    [anon_sym_uwire] = ACTIONS(5584),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5582),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5582),
    [aux_sym_begin_keywords_token1] = ACTIONS(5582),
    [anon_sym_SEMI] = ACTIONS(5582),
    [anon_sym_endmodule] = ACTIONS(5584),
    [anon_sym_COLON] = ACTIONS(5586),
    [anon_sym_extern] = ACTIONS(5584),
    [anon_sym_module] = ACTIONS(5584),
    [anon_sym_macromodule] = ACTIONS(5584),
    [anon_sym_endinterface] = ACTIONS(5584),
    [anon_sym_interface] = ACTIONS(5584),
    [anon_sym_program] = ACTIONS(5584),
    [anon_sym_checker] = ACTIONS(5584),
    [anon_sym_virtual] = ACTIONS(5584),
    [anon_sym_class] = ACTIONS(5584),
    [anon_sym_package] = ACTIONS(5584),
    [anon_sym_timeunit] = ACTIONS(5584),
    [anon_sym_timeprecision] = ACTIONS(5584),
    [anon_sym_type] = ACTIONS(5584),
    [anon_sym_input] = ACTIONS(5584),
    [anon_sym_output] = ACTIONS(5584),
    [anon_sym_inout] = ACTIONS(5584),
    [anon_sym_ref] = ACTIONS(5584),
    [anon_sym_DOLLARfatal] = ACTIONS(5582),
    [anon_sym_DOLLARerror] = ACTIONS(5582),
    [anon_sym_DOLLARwarning] = ACTIONS(5582),
    [anon_sym_DOLLARinfo] = ACTIONS(5582),
    [anon_sym_default] = ACTIONS(5584),
    [anon_sym_clocking] = ACTIONS(5584),
    [anon_sym_defparam] = ACTIONS(5584),
    [anon_sym_bind] = ACTIONS(5584),
    [anon_sym_const] = ACTIONS(5584),
    [anon_sym_function] = ACTIONS(5584),
    [anon_sym_static] = ACTIONS(5584),
    [anon_sym_constraint] = ACTIONS(5584),
    [anon_sym_if] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5582),
    [anon_sym_localparam] = ACTIONS(5584),
    [anon_sym_parameter] = ACTIONS(5584),
    [anon_sym_specparam] = ACTIONS(5584),
    [anon_sym_var] = ACTIONS(5584),
    [anon_sym_import] = ACTIONS(5584),
    [anon_sym_export] = ACTIONS(5584),
    [anon_sym_genvar] = ACTIONS(5584),
    [anon_sym_interconnect] = ACTIONS(5584),
    [anon_sym_typedef] = ACTIONS(5584),
    [anon_sym_enum] = ACTIONS(5584),
    [anon_sym_struct] = ACTIONS(5584),
    [anon_sym_union] = ACTIONS(5584),
    [anon_sym_nettype] = ACTIONS(5584),
    [anon_sym_automatic] = ACTIONS(5584),
    [anon_sym_string] = ACTIONS(5584),
    [anon_sym_chandle] = ACTIONS(5584),
    [anon_sym_event] = ACTIONS(5584),
    [anon_sym_byte] = ACTIONS(5584),
    [anon_sym_shortint] = ACTIONS(5584),
    [anon_sym_int] = ACTIONS(5584),
    [anon_sym_longint] = ACTIONS(5584),
    [anon_sym_integer] = ACTIONS(5584),
    [anon_sym_time] = ACTIONS(5584),
    [anon_sym_bit] = ACTIONS(5584),
    [anon_sym_logic] = ACTIONS(5584),
    [anon_sym_reg] = ACTIONS(5584),
    [anon_sym_shortreal] = ACTIONS(5584),
    [anon_sym_real] = ACTIONS(5584),
    [anon_sym_realtime] = ACTIONS(5584),
    [anon_sym_supply0] = ACTIONS(5584),
    [anon_sym_supply1] = ACTIONS(5584),
    [anon_sym_signed] = ACTIONS(5584),
    [anon_sym_unsigned] = ACTIONS(5584),
    [anon_sym_task] = ACTIONS(5584),
    [anon_sym_modport] = ACTIONS(5584),
    [anon_sym_assert] = ACTIONS(5584),
    [anon_sym_property] = ACTIONS(5584),
    [anon_sym_assume] = ACTIONS(5584),
    [anon_sym_cover] = ACTIONS(5584),
    [anon_sym_sequence] = ACTIONS(5584),
    [anon_sym_restrict] = ACTIONS(5584),
    [anon_sym_not] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_case] = ACTIONS(5584),
    [anon_sym_always] = ACTIONS(5584),
    [anon_sym_covergroup] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_pulldown] = ACTIONS(5584),
    [anon_sym_pullup] = ACTIONS(5584),
    [anon_sym_cmos] = ACTIONS(5584),
    [anon_sym_rcmos] = ACTIONS(5584),
    [anon_sym_bufif0] = ACTIONS(5584),
    [anon_sym_bufif1] = ACTIONS(5584),
    [anon_sym_notif0] = ACTIONS(5584),
    [anon_sym_notif1] = ACTIONS(5584),
    [anon_sym_nmos] = ACTIONS(5584),
    [anon_sym_pmos] = ACTIONS(5584),
    [anon_sym_rnmos] = ACTIONS(5584),
    [anon_sym_rpmos] = ACTIONS(5584),
    [anon_sym_nand] = ACTIONS(5584),
    [anon_sym_nor] = ACTIONS(5584),
    [anon_sym_xor] = ACTIONS(5584),
    [anon_sym_xnor] = ACTIONS(5584),
    [anon_sym_buf] = ACTIONS(5584),
    [anon_sym_tranif0] = ACTIONS(5584),
    [anon_sym_tranif1] = ACTIONS(5584),
    [anon_sym_rtranif1] = ACTIONS(5584),
    [anon_sym_rtranif0] = ACTIONS(5584),
    [anon_sym_tran] = ACTIONS(5584),
    [anon_sym_rtran] = ACTIONS(5584),
    [anon_sym_generate] = ACTIONS(5584),
    [anon_sym_for] = ACTIONS(5584),
    [anon_sym_primitive] = ACTIONS(5584),
    [anon_sym_initial] = ACTIONS(5584),
    [anon_sym_assign] = ACTIONS(5584),
    [anon_sym_alias] = ACTIONS(5584),
    [anon_sym_always_comb] = ACTIONS(5584),
    [anon_sym_always_latch] = ACTIONS(5584),
    [anon_sym_always_ff] = ACTIONS(5584),
    [anon_sym_final] = ACTIONS(5584),
    [anon_sym_global] = ACTIONS(5584),
    [anon_sym_specify] = ACTIONS(5584),
    [anon_sym_LPAREN_STAR] = ACTIONS(5582),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5582),
    [anon_sym_DOLLARunit] = ACTIONS(5582),
  },
  [990] = {
    [sym_simple_identifier] = ACTIONS(5588),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5590),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5590),
    [anon_sym_BQUOTE] = ACTIONS(5588),
    [aux_sym_id_directive_token1] = ACTIONS(5590),
    [aux_sym_id_directive_token2] = ACTIONS(5590),
    [aux_sym_id_directive_token3] = ACTIONS(5590),
    [aux_sym_id_directive_token4] = ACTIONS(5588),
    [aux_sym_zero_directive_token1] = ACTIONS(5590),
    [aux_sym_zero_directive_token2] = ACTIONS(5590),
    [aux_sym_zero_directive_token3] = ACTIONS(5590),
    [aux_sym_zero_directive_token4] = ACTIONS(5590),
    [aux_sym_zero_directive_token5] = ACTIONS(5590),
    [aux_sym_zero_directive_token6] = ACTIONS(5590),
    [aux_sym_zero_directive_token7] = ACTIONS(5590),
    [aux_sym_zero_directive_token8] = ACTIONS(5590),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5590),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5590),
    [anon_sym_wire] = ACTIONS(5588),
    [anon_sym_tri] = ACTIONS(5588),
    [anon_sym_tri0] = ACTIONS(5588),
    [anon_sym_tri1] = ACTIONS(5588),
    [anon_sym_wand] = ACTIONS(5588),
    [anon_sym_triand] = ACTIONS(5588),
    [anon_sym_wor] = ACTIONS(5588),
    [anon_sym_trior] = ACTIONS(5588),
    [anon_sym_trireg] = ACTIONS(5588),
    [anon_sym_uwire] = ACTIONS(5588),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5590),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5590),
    [aux_sym_begin_keywords_token1] = ACTIONS(5590),
    [anon_sym_SEMI] = ACTIONS(5590),
    [anon_sym_endmodule] = ACTIONS(5588),
    [anon_sym_COLON] = ACTIONS(5592),
    [anon_sym_extern] = ACTIONS(5588),
    [anon_sym_module] = ACTIONS(5588),
    [anon_sym_macromodule] = ACTIONS(5588),
    [anon_sym_endinterface] = ACTIONS(5588),
    [anon_sym_interface] = ACTIONS(5588),
    [anon_sym_endprogram] = ACTIONS(5588),
    [anon_sym_program] = ACTIONS(5588),
    [anon_sym_checker] = ACTIONS(5588),
    [anon_sym_virtual] = ACTIONS(5588),
    [anon_sym_class] = ACTIONS(5588),
    [anon_sym_timeunit] = ACTIONS(5588),
    [anon_sym_timeprecision] = ACTIONS(5588),
    [anon_sym_type] = ACTIONS(5588),
    [anon_sym_input] = ACTIONS(5588),
    [anon_sym_output] = ACTIONS(5588),
    [anon_sym_inout] = ACTIONS(5588),
    [anon_sym_ref] = ACTIONS(5588),
    [anon_sym_DOLLARfatal] = ACTIONS(5590),
    [anon_sym_DOLLARerror] = ACTIONS(5590),
    [anon_sym_DOLLARwarning] = ACTIONS(5590),
    [anon_sym_DOLLARinfo] = ACTIONS(5590),
    [anon_sym_default] = ACTIONS(5588),
    [anon_sym_clocking] = ACTIONS(5588),
    [anon_sym_defparam] = ACTIONS(5588),
    [anon_sym_bind] = ACTIONS(5588),
    [anon_sym_const] = ACTIONS(5588),
    [anon_sym_function] = ACTIONS(5588),
    [anon_sym_static] = ACTIONS(5588),
    [anon_sym_constraint] = ACTIONS(5588),
    [anon_sym_if] = ACTIONS(5588),
    [anon_sym_else] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5590),
    [anon_sym_localparam] = ACTIONS(5588),
    [anon_sym_parameter] = ACTIONS(5588),
    [anon_sym_specparam] = ACTIONS(5588),
    [anon_sym_var] = ACTIONS(5588),
    [anon_sym_import] = ACTIONS(5588),
    [anon_sym_export] = ACTIONS(5588),
    [anon_sym_genvar] = ACTIONS(5588),
    [anon_sym_interconnect] = ACTIONS(5588),
    [anon_sym_typedef] = ACTIONS(5588),
    [anon_sym_enum] = ACTIONS(5588),
    [anon_sym_struct] = ACTIONS(5588),
    [anon_sym_union] = ACTIONS(5588),
    [anon_sym_nettype] = ACTIONS(5588),
    [anon_sym_automatic] = ACTIONS(5588),
    [anon_sym_string] = ACTIONS(5588),
    [anon_sym_chandle] = ACTIONS(5588),
    [anon_sym_event] = ACTIONS(5588),
    [anon_sym_byte] = ACTIONS(5588),
    [anon_sym_shortint] = ACTIONS(5588),
    [anon_sym_int] = ACTIONS(5588),
    [anon_sym_longint] = ACTIONS(5588),
    [anon_sym_integer] = ACTIONS(5588),
    [anon_sym_time] = ACTIONS(5588),
    [anon_sym_bit] = ACTIONS(5588),
    [anon_sym_logic] = ACTIONS(5588),
    [anon_sym_reg] = ACTIONS(5588),
    [anon_sym_shortreal] = ACTIONS(5588),
    [anon_sym_real] = ACTIONS(5588),
    [anon_sym_realtime] = ACTIONS(5588),
    [anon_sym_supply0] = ACTIONS(5588),
    [anon_sym_supply1] = ACTIONS(5588),
    [anon_sym_signed] = ACTIONS(5588),
    [anon_sym_unsigned] = ACTIONS(5588),
    [anon_sym_task] = ACTIONS(5588),
    [anon_sym_modport] = ACTIONS(5588),
    [anon_sym_assert] = ACTIONS(5588),
    [anon_sym_property] = ACTIONS(5588),
    [anon_sym_assume] = ACTIONS(5588),
    [anon_sym_cover] = ACTIONS(5588),
    [anon_sym_sequence] = ACTIONS(5588),
    [anon_sym_restrict] = ACTIONS(5588),
    [anon_sym_not] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_case] = ACTIONS(5588),
    [anon_sym_always] = ACTIONS(5588),
    [anon_sym_covergroup] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_pulldown] = ACTIONS(5588),
    [anon_sym_pullup] = ACTIONS(5588),
    [anon_sym_cmos] = ACTIONS(5588),
    [anon_sym_rcmos] = ACTIONS(5588),
    [anon_sym_bufif0] = ACTIONS(5588),
    [anon_sym_bufif1] = ACTIONS(5588),
    [anon_sym_notif0] = ACTIONS(5588),
    [anon_sym_notif1] = ACTIONS(5588),
    [anon_sym_nmos] = ACTIONS(5588),
    [anon_sym_pmos] = ACTIONS(5588),
    [anon_sym_rnmos] = ACTIONS(5588),
    [anon_sym_rpmos] = ACTIONS(5588),
    [anon_sym_nand] = ACTIONS(5588),
    [anon_sym_nor] = ACTIONS(5588),
    [anon_sym_xor] = ACTIONS(5588),
    [anon_sym_xnor] = ACTIONS(5588),
    [anon_sym_buf] = ACTIONS(5588),
    [anon_sym_tranif0] = ACTIONS(5588),
    [anon_sym_tranif1] = ACTIONS(5588),
    [anon_sym_rtranif1] = ACTIONS(5588),
    [anon_sym_rtranif0] = ACTIONS(5588),
    [anon_sym_tran] = ACTIONS(5588),
    [anon_sym_rtran] = ACTIONS(5588),
    [anon_sym_generate] = ACTIONS(5588),
    [anon_sym_for] = ACTIONS(5588),
    [anon_sym_initial] = ACTIONS(5588),
    [anon_sym_assign] = ACTIONS(5588),
    [anon_sym_alias] = ACTIONS(5588),
    [anon_sym_always_comb] = ACTIONS(5588),
    [anon_sym_always_latch] = ACTIONS(5588),
    [anon_sym_always_ff] = ACTIONS(5588),
    [anon_sym_final] = ACTIONS(5588),
    [anon_sym_while] = ACTIONS(5588),
    [anon_sym_global] = ACTIONS(5588),
    [anon_sym_specify] = ACTIONS(5588),
    [anon_sym_LPAREN_STAR] = ACTIONS(5590),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5590),
    [anon_sym_DOLLARunit] = ACTIONS(5590),
  },
  [991] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5596),
    [anon_sym_BQUOTE] = ACTIONS(5594),
    [aux_sym_id_directive_token1] = ACTIONS(5596),
    [aux_sym_id_directive_token2] = ACTIONS(5596),
    [aux_sym_id_directive_token3] = ACTIONS(5596),
    [aux_sym_id_directive_token4] = ACTIONS(5594),
    [aux_sym_zero_directive_token1] = ACTIONS(5596),
    [aux_sym_zero_directive_token2] = ACTIONS(5596),
    [aux_sym_zero_directive_token3] = ACTIONS(5596),
    [aux_sym_zero_directive_token4] = ACTIONS(5596),
    [aux_sym_zero_directive_token5] = ACTIONS(5596),
    [aux_sym_zero_directive_token6] = ACTIONS(5596),
    [aux_sym_zero_directive_token7] = ACTIONS(5596),
    [aux_sym_zero_directive_token8] = ACTIONS(5596),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5596),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5596),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_begin_keywords_token1] = ACTIONS(5596),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_endmodule] = ACTIONS(5594),
    [anon_sym_COLON] = ACTIONS(5598),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_module] = ACTIONS(5594),
    [anon_sym_macromodule] = ACTIONS(5594),
    [anon_sym_endinterface] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_endprogram] = ACTIONS(5594),
    [anon_sym_program] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_timeunit] = ACTIONS(5594),
    [anon_sym_timeprecision] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_input] = ACTIONS(5594),
    [anon_sym_output] = ACTIONS(5594),
    [anon_sym_inout] = ACTIONS(5594),
    [anon_sym_ref] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_specparam] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_modport] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_while] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_specify] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [992] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5602),
    [anon_sym_BQUOTE] = ACTIONS(5600),
    [aux_sym_id_directive_token1] = ACTIONS(5602),
    [aux_sym_id_directive_token2] = ACTIONS(5602),
    [aux_sym_id_directive_token3] = ACTIONS(5602),
    [aux_sym_id_directive_token4] = ACTIONS(5600),
    [aux_sym_zero_directive_token1] = ACTIONS(5602),
    [aux_sym_zero_directive_token2] = ACTIONS(5602),
    [aux_sym_zero_directive_token3] = ACTIONS(5602),
    [aux_sym_zero_directive_token4] = ACTIONS(5602),
    [aux_sym_zero_directive_token5] = ACTIONS(5602),
    [aux_sym_zero_directive_token6] = ACTIONS(5602),
    [aux_sym_zero_directive_token7] = ACTIONS(5602),
    [aux_sym_zero_directive_token8] = ACTIONS(5602),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5602),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5602),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_begin_keywords_token1] = ACTIONS(5602),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_endmodule] = ACTIONS(5600),
    [anon_sym_COLON] = ACTIONS(5604),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_module] = ACTIONS(5600),
    [anon_sym_macromodule] = ACTIONS(5600),
    [anon_sym_endinterface] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_endprogram] = ACTIONS(5600),
    [anon_sym_program] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_timeunit] = ACTIONS(5600),
    [anon_sym_timeprecision] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_input] = ACTIONS(5600),
    [anon_sym_output] = ACTIONS(5600),
    [anon_sym_inout] = ACTIONS(5600),
    [anon_sym_ref] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_specparam] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_modport] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_while] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_specify] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [993] = {
    [ts_builtin_sym_end] = ACTIONS(5606),
    [sym_simple_identifier] = ACTIONS(5608),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5606),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5606),
    [anon_sym_BQUOTE] = ACTIONS(5608),
    [aux_sym_id_directive_token1] = ACTIONS(5606),
    [aux_sym_id_directive_token2] = ACTIONS(5606),
    [aux_sym_id_directive_token3] = ACTIONS(5606),
    [aux_sym_id_directive_token4] = ACTIONS(5608),
    [aux_sym_zero_directive_token1] = ACTIONS(5606),
    [aux_sym_zero_directive_token2] = ACTIONS(5606),
    [aux_sym_zero_directive_token3] = ACTIONS(5606),
    [aux_sym_zero_directive_token4] = ACTIONS(5606),
    [aux_sym_zero_directive_token5] = ACTIONS(5606),
    [aux_sym_zero_directive_token6] = ACTIONS(5606),
    [aux_sym_zero_directive_token7] = ACTIONS(5606),
    [aux_sym_zero_directive_token8] = ACTIONS(5606),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5606),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5606),
    [anon_sym_wire] = ACTIONS(5608),
    [anon_sym_tri] = ACTIONS(5608),
    [anon_sym_tri0] = ACTIONS(5608),
    [anon_sym_tri1] = ACTIONS(5608),
    [anon_sym_wand] = ACTIONS(5608),
    [anon_sym_triand] = ACTIONS(5608),
    [anon_sym_wor] = ACTIONS(5608),
    [anon_sym_trior] = ACTIONS(5608),
    [anon_sym_trireg] = ACTIONS(5608),
    [anon_sym_uwire] = ACTIONS(5608),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5606),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5606),
    [aux_sym_begin_keywords_token1] = ACTIONS(5606),
    [anon_sym_SEMI] = ACTIONS(5606),
    [anon_sym_endmodule] = ACTIONS(5608),
    [anon_sym_COLON] = ACTIONS(5610),
    [anon_sym_extern] = ACTIONS(5608),
    [anon_sym_module] = ACTIONS(5608),
    [anon_sym_macromodule] = ACTIONS(5608),
    [anon_sym_endinterface] = ACTIONS(5608),
    [anon_sym_interface] = ACTIONS(5608),
    [anon_sym_program] = ACTIONS(5608),
    [anon_sym_checker] = ACTIONS(5608),
    [anon_sym_virtual] = ACTIONS(5608),
    [anon_sym_class] = ACTIONS(5608),
    [anon_sym_package] = ACTIONS(5608),
    [anon_sym_timeunit] = ACTIONS(5608),
    [anon_sym_timeprecision] = ACTIONS(5608),
    [anon_sym_type] = ACTIONS(5608),
    [anon_sym_input] = ACTIONS(5608),
    [anon_sym_output] = ACTIONS(5608),
    [anon_sym_inout] = ACTIONS(5608),
    [anon_sym_ref] = ACTIONS(5608),
    [anon_sym_DOLLARfatal] = ACTIONS(5606),
    [anon_sym_DOLLARerror] = ACTIONS(5606),
    [anon_sym_DOLLARwarning] = ACTIONS(5606),
    [anon_sym_DOLLARinfo] = ACTIONS(5606),
    [anon_sym_default] = ACTIONS(5608),
    [anon_sym_clocking] = ACTIONS(5608),
    [anon_sym_defparam] = ACTIONS(5608),
    [anon_sym_bind] = ACTIONS(5608),
    [anon_sym_const] = ACTIONS(5608),
    [anon_sym_function] = ACTIONS(5608),
    [anon_sym_static] = ACTIONS(5608),
    [anon_sym_constraint] = ACTIONS(5608),
    [anon_sym_if] = ACTIONS(5608),
    [anon_sym_LBRACK] = ACTIONS(5606),
    [anon_sym_localparam] = ACTIONS(5608),
    [anon_sym_parameter] = ACTIONS(5608),
    [anon_sym_specparam] = ACTIONS(5608),
    [anon_sym_var] = ACTIONS(5608),
    [anon_sym_import] = ACTIONS(5608),
    [anon_sym_export] = ACTIONS(5608),
    [anon_sym_genvar] = ACTIONS(5608),
    [anon_sym_interconnect] = ACTIONS(5608),
    [anon_sym_typedef] = ACTIONS(5608),
    [anon_sym_enum] = ACTIONS(5608),
    [anon_sym_struct] = ACTIONS(5608),
    [anon_sym_union] = ACTIONS(5608),
    [anon_sym_nettype] = ACTIONS(5608),
    [anon_sym_automatic] = ACTIONS(5608),
    [anon_sym_string] = ACTIONS(5608),
    [anon_sym_chandle] = ACTIONS(5608),
    [anon_sym_event] = ACTIONS(5608),
    [anon_sym_byte] = ACTIONS(5608),
    [anon_sym_shortint] = ACTIONS(5608),
    [anon_sym_int] = ACTIONS(5608),
    [anon_sym_longint] = ACTIONS(5608),
    [anon_sym_integer] = ACTIONS(5608),
    [anon_sym_time] = ACTIONS(5608),
    [anon_sym_bit] = ACTIONS(5608),
    [anon_sym_logic] = ACTIONS(5608),
    [anon_sym_reg] = ACTIONS(5608),
    [anon_sym_shortreal] = ACTIONS(5608),
    [anon_sym_real] = ACTIONS(5608),
    [anon_sym_realtime] = ACTIONS(5608),
    [anon_sym_supply0] = ACTIONS(5608),
    [anon_sym_supply1] = ACTIONS(5608),
    [anon_sym_signed] = ACTIONS(5608),
    [anon_sym_unsigned] = ACTIONS(5608),
    [anon_sym_task] = ACTIONS(5608),
    [anon_sym_modport] = ACTIONS(5608),
    [anon_sym_assert] = ACTIONS(5608),
    [anon_sym_property] = ACTIONS(5608),
    [anon_sym_assume] = ACTIONS(5608),
    [anon_sym_cover] = ACTIONS(5608),
    [anon_sym_sequence] = ACTIONS(5608),
    [anon_sym_restrict] = ACTIONS(5608),
    [anon_sym_not] = ACTIONS(5608),
    [anon_sym_or] = ACTIONS(5608),
    [anon_sym_and] = ACTIONS(5608),
    [anon_sym_case] = ACTIONS(5608),
    [anon_sym_always] = ACTIONS(5608),
    [anon_sym_covergroup] = ACTIONS(5608),
    [anon_sym_let] = ACTIONS(5608),
    [anon_sym_pulldown] = ACTIONS(5608),
    [anon_sym_pullup] = ACTIONS(5608),
    [anon_sym_cmos] = ACTIONS(5608),
    [anon_sym_rcmos] = ACTIONS(5608),
    [anon_sym_bufif0] = ACTIONS(5608),
    [anon_sym_bufif1] = ACTIONS(5608),
    [anon_sym_notif0] = ACTIONS(5608),
    [anon_sym_notif1] = ACTIONS(5608),
    [anon_sym_nmos] = ACTIONS(5608),
    [anon_sym_pmos] = ACTIONS(5608),
    [anon_sym_rnmos] = ACTIONS(5608),
    [anon_sym_rpmos] = ACTIONS(5608),
    [anon_sym_nand] = ACTIONS(5608),
    [anon_sym_nor] = ACTIONS(5608),
    [anon_sym_xor] = ACTIONS(5608),
    [anon_sym_xnor] = ACTIONS(5608),
    [anon_sym_buf] = ACTIONS(5608),
    [anon_sym_tranif0] = ACTIONS(5608),
    [anon_sym_tranif1] = ACTIONS(5608),
    [anon_sym_rtranif1] = ACTIONS(5608),
    [anon_sym_rtranif0] = ACTIONS(5608),
    [anon_sym_tran] = ACTIONS(5608),
    [anon_sym_rtran] = ACTIONS(5608),
    [anon_sym_generate] = ACTIONS(5608),
    [anon_sym_for] = ACTIONS(5608),
    [anon_sym_primitive] = ACTIONS(5608),
    [anon_sym_initial] = ACTIONS(5608),
    [anon_sym_assign] = ACTIONS(5608),
    [anon_sym_alias] = ACTIONS(5608),
    [anon_sym_always_comb] = ACTIONS(5608),
    [anon_sym_always_latch] = ACTIONS(5608),
    [anon_sym_always_ff] = ACTIONS(5608),
    [anon_sym_final] = ACTIONS(5608),
    [anon_sym_global] = ACTIONS(5608),
    [anon_sym_specify] = ACTIONS(5608),
    [anon_sym_LPAREN_STAR] = ACTIONS(5606),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5606),
    [anon_sym_DOLLARunit] = ACTIONS(5606),
  },
  [994] = {
    [sym_simple_identifier] = ACTIONS(5612),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5614),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5614),
    [anon_sym_BQUOTE] = ACTIONS(5612),
    [aux_sym_id_directive_token1] = ACTIONS(5614),
    [aux_sym_id_directive_token2] = ACTIONS(5614),
    [aux_sym_id_directive_token3] = ACTIONS(5614),
    [aux_sym_id_directive_token4] = ACTIONS(5612),
    [aux_sym_zero_directive_token1] = ACTIONS(5614),
    [aux_sym_zero_directive_token2] = ACTIONS(5614),
    [aux_sym_zero_directive_token3] = ACTIONS(5614),
    [aux_sym_zero_directive_token4] = ACTIONS(5614),
    [aux_sym_zero_directive_token5] = ACTIONS(5614),
    [aux_sym_zero_directive_token6] = ACTIONS(5614),
    [aux_sym_zero_directive_token7] = ACTIONS(5614),
    [aux_sym_zero_directive_token8] = ACTIONS(5614),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5614),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5614),
    [anon_sym_wire] = ACTIONS(5612),
    [anon_sym_tri] = ACTIONS(5612),
    [anon_sym_tri0] = ACTIONS(5612),
    [anon_sym_tri1] = ACTIONS(5612),
    [anon_sym_wand] = ACTIONS(5612),
    [anon_sym_triand] = ACTIONS(5612),
    [anon_sym_wor] = ACTIONS(5612),
    [anon_sym_trior] = ACTIONS(5612),
    [anon_sym_trireg] = ACTIONS(5612),
    [anon_sym_uwire] = ACTIONS(5612),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5614),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5614),
    [aux_sym_begin_keywords_token1] = ACTIONS(5614),
    [anon_sym_SEMI] = ACTIONS(5614),
    [anon_sym_endmodule] = ACTIONS(5612),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_extern] = ACTIONS(5612),
    [anon_sym_module] = ACTIONS(5612),
    [anon_sym_macromodule] = ACTIONS(5612),
    [anon_sym_endinterface] = ACTIONS(5612),
    [anon_sym_interface] = ACTIONS(5612),
    [anon_sym_endprogram] = ACTIONS(5612),
    [anon_sym_program] = ACTIONS(5612),
    [anon_sym_checker] = ACTIONS(5612),
    [anon_sym_virtual] = ACTIONS(5612),
    [anon_sym_class] = ACTIONS(5612),
    [anon_sym_timeunit] = ACTIONS(5612),
    [anon_sym_timeprecision] = ACTIONS(5612),
    [anon_sym_type] = ACTIONS(5612),
    [anon_sym_input] = ACTIONS(5612),
    [anon_sym_output] = ACTIONS(5612),
    [anon_sym_inout] = ACTIONS(5612),
    [anon_sym_ref] = ACTIONS(5612),
    [anon_sym_DOLLARfatal] = ACTIONS(5614),
    [anon_sym_DOLLARerror] = ACTIONS(5614),
    [anon_sym_DOLLARwarning] = ACTIONS(5614),
    [anon_sym_DOLLARinfo] = ACTIONS(5614),
    [anon_sym_default] = ACTIONS(5612),
    [anon_sym_clocking] = ACTIONS(5612),
    [anon_sym_defparam] = ACTIONS(5612),
    [anon_sym_bind] = ACTIONS(5612),
    [anon_sym_const] = ACTIONS(5612),
    [anon_sym_function] = ACTIONS(5612),
    [anon_sym_static] = ACTIONS(5612),
    [anon_sym_constraint] = ACTIONS(5612),
    [anon_sym_if] = ACTIONS(5612),
    [anon_sym_else] = ACTIONS(5612),
    [anon_sym_LBRACK] = ACTIONS(5614),
    [anon_sym_localparam] = ACTIONS(5612),
    [anon_sym_parameter] = ACTIONS(5612),
    [anon_sym_specparam] = ACTIONS(5612),
    [anon_sym_var] = ACTIONS(5612),
    [anon_sym_import] = ACTIONS(5612),
    [anon_sym_export] = ACTIONS(5612),
    [anon_sym_genvar] = ACTIONS(5612),
    [anon_sym_interconnect] = ACTIONS(5612),
    [anon_sym_typedef] = ACTIONS(5612),
    [anon_sym_enum] = ACTIONS(5612),
    [anon_sym_struct] = ACTIONS(5612),
    [anon_sym_union] = ACTIONS(5612),
    [anon_sym_nettype] = ACTIONS(5612),
    [anon_sym_automatic] = ACTIONS(5612),
    [anon_sym_string] = ACTIONS(5612),
    [anon_sym_chandle] = ACTIONS(5612),
    [anon_sym_event] = ACTIONS(5612),
    [anon_sym_byte] = ACTIONS(5612),
    [anon_sym_shortint] = ACTIONS(5612),
    [anon_sym_int] = ACTIONS(5612),
    [anon_sym_longint] = ACTIONS(5612),
    [anon_sym_integer] = ACTIONS(5612),
    [anon_sym_time] = ACTIONS(5612),
    [anon_sym_bit] = ACTIONS(5612),
    [anon_sym_logic] = ACTIONS(5612),
    [anon_sym_reg] = ACTIONS(5612),
    [anon_sym_shortreal] = ACTIONS(5612),
    [anon_sym_real] = ACTIONS(5612),
    [anon_sym_realtime] = ACTIONS(5612),
    [anon_sym_supply0] = ACTIONS(5612),
    [anon_sym_supply1] = ACTIONS(5612),
    [anon_sym_signed] = ACTIONS(5612),
    [anon_sym_unsigned] = ACTIONS(5612),
    [anon_sym_task] = ACTIONS(5612),
    [anon_sym_modport] = ACTIONS(5612),
    [anon_sym_assert] = ACTIONS(5612),
    [anon_sym_property] = ACTIONS(5612),
    [anon_sym_assume] = ACTIONS(5612),
    [anon_sym_cover] = ACTIONS(5612),
    [anon_sym_sequence] = ACTIONS(5612),
    [anon_sym_restrict] = ACTIONS(5612),
    [anon_sym_not] = ACTIONS(5612),
    [anon_sym_or] = ACTIONS(5612),
    [anon_sym_and] = ACTIONS(5612),
    [anon_sym_case] = ACTIONS(5612),
    [anon_sym_always] = ACTIONS(5612),
    [anon_sym_covergroup] = ACTIONS(5612),
    [anon_sym_let] = ACTIONS(5612),
    [anon_sym_pulldown] = ACTIONS(5612),
    [anon_sym_pullup] = ACTIONS(5612),
    [anon_sym_cmos] = ACTIONS(5612),
    [anon_sym_rcmos] = ACTIONS(5612),
    [anon_sym_bufif0] = ACTIONS(5612),
    [anon_sym_bufif1] = ACTIONS(5612),
    [anon_sym_notif0] = ACTIONS(5612),
    [anon_sym_notif1] = ACTIONS(5612),
    [anon_sym_nmos] = ACTIONS(5612),
    [anon_sym_pmos] = ACTIONS(5612),
    [anon_sym_rnmos] = ACTIONS(5612),
    [anon_sym_rpmos] = ACTIONS(5612),
    [anon_sym_nand] = ACTIONS(5612),
    [anon_sym_nor] = ACTIONS(5612),
    [anon_sym_xor] = ACTIONS(5612),
    [anon_sym_xnor] = ACTIONS(5612),
    [anon_sym_buf] = ACTIONS(5612),
    [anon_sym_tranif0] = ACTIONS(5612),
    [anon_sym_tranif1] = ACTIONS(5612),
    [anon_sym_rtranif1] = ACTIONS(5612),
    [anon_sym_rtranif0] = ACTIONS(5612),
    [anon_sym_tran] = ACTIONS(5612),
    [anon_sym_rtran] = ACTIONS(5612),
    [anon_sym_generate] = ACTIONS(5612),
    [anon_sym_for] = ACTIONS(5612),
    [anon_sym_initial] = ACTIONS(5612),
    [anon_sym_assign] = ACTIONS(5612),
    [anon_sym_alias] = ACTIONS(5612),
    [anon_sym_always_comb] = ACTIONS(5612),
    [anon_sym_always_latch] = ACTIONS(5612),
    [anon_sym_always_ff] = ACTIONS(5612),
    [anon_sym_final] = ACTIONS(5612),
    [anon_sym_while] = ACTIONS(5612),
    [anon_sym_global] = ACTIONS(5612),
    [anon_sym_specify] = ACTIONS(5612),
    [anon_sym_LPAREN_STAR] = ACTIONS(5614),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5614),
    [anon_sym_DOLLARunit] = ACTIONS(5614),
  },
  [995] = {
    [ts_builtin_sym_end] = ACTIONS(5618),
    [sym_simple_identifier] = ACTIONS(5620),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5618),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5618),
    [anon_sym_BQUOTE] = ACTIONS(5620),
    [aux_sym_id_directive_token1] = ACTIONS(5618),
    [aux_sym_id_directive_token2] = ACTIONS(5618),
    [aux_sym_id_directive_token3] = ACTIONS(5618),
    [aux_sym_id_directive_token4] = ACTIONS(5620),
    [aux_sym_zero_directive_token1] = ACTIONS(5618),
    [aux_sym_zero_directive_token2] = ACTIONS(5618),
    [aux_sym_zero_directive_token3] = ACTIONS(5618),
    [aux_sym_zero_directive_token4] = ACTIONS(5618),
    [aux_sym_zero_directive_token5] = ACTIONS(5618),
    [aux_sym_zero_directive_token6] = ACTIONS(5618),
    [aux_sym_zero_directive_token7] = ACTIONS(5618),
    [aux_sym_zero_directive_token8] = ACTIONS(5618),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5618),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5618),
    [anon_sym_wire] = ACTIONS(5620),
    [anon_sym_tri] = ACTIONS(5620),
    [anon_sym_tri0] = ACTIONS(5620),
    [anon_sym_tri1] = ACTIONS(5620),
    [anon_sym_wand] = ACTIONS(5620),
    [anon_sym_triand] = ACTIONS(5620),
    [anon_sym_wor] = ACTIONS(5620),
    [anon_sym_trior] = ACTIONS(5620),
    [anon_sym_trireg] = ACTIONS(5620),
    [anon_sym_uwire] = ACTIONS(5620),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5618),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5618),
    [aux_sym_begin_keywords_token1] = ACTIONS(5618),
    [anon_sym_SEMI] = ACTIONS(5618),
    [anon_sym_endmodule] = ACTIONS(5620),
    [anon_sym_extern] = ACTIONS(5620),
    [anon_sym_module] = ACTIONS(5620),
    [anon_sym_macromodule] = ACTIONS(5620),
    [anon_sym_endinterface] = ACTIONS(5620),
    [anon_sym_interface] = ACTIONS(5620),
    [anon_sym_endprogram] = ACTIONS(5620),
    [anon_sym_program] = ACTIONS(5620),
    [anon_sym_checker] = ACTIONS(5620),
    [anon_sym_virtual] = ACTIONS(5620),
    [anon_sym_class] = ACTIONS(5620),
    [anon_sym_package] = ACTIONS(5620),
    [anon_sym_timeunit] = ACTIONS(5620),
    [anon_sym_timeprecision] = ACTIONS(5620),
    [anon_sym_type] = ACTIONS(5620),
    [anon_sym_input] = ACTIONS(5620),
    [anon_sym_output] = ACTIONS(5620),
    [anon_sym_inout] = ACTIONS(5620),
    [anon_sym_ref] = ACTIONS(5620),
    [anon_sym_DOLLARfatal] = ACTIONS(5618),
    [anon_sym_DOLLARerror] = ACTIONS(5618),
    [anon_sym_DOLLARwarning] = ACTIONS(5618),
    [anon_sym_DOLLARinfo] = ACTIONS(5618),
    [anon_sym_default] = ACTIONS(5620),
    [anon_sym_clocking] = ACTIONS(5620),
    [anon_sym_defparam] = ACTIONS(5620),
    [anon_sym_bind] = ACTIONS(5620),
    [anon_sym_const] = ACTIONS(5620),
    [anon_sym_function] = ACTIONS(5620),
    [anon_sym_static] = ACTIONS(5620),
    [anon_sym_constraint] = ACTIONS(5620),
    [anon_sym_if] = ACTIONS(5620),
    [anon_sym_LBRACK] = ACTIONS(5618),
    [anon_sym_localparam] = ACTIONS(5620),
    [anon_sym_parameter] = ACTIONS(5620),
    [anon_sym_specparam] = ACTIONS(5620),
    [anon_sym_var] = ACTIONS(5620),
    [anon_sym_import] = ACTIONS(5620),
    [anon_sym_export] = ACTIONS(5620),
    [anon_sym_genvar] = ACTIONS(5620),
    [anon_sym_interconnect] = ACTIONS(5620),
    [anon_sym_typedef] = ACTIONS(5620),
    [anon_sym_enum] = ACTIONS(5620),
    [anon_sym_struct] = ACTIONS(5620),
    [anon_sym_union] = ACTIONS(5620),
    [anon_sym_nettype] = ACTIONS(5620),
    [anon_sym_automatic] = ACTIONS(5620),
    [anon_sym_string] = ACTIONS(5620),
    [anon_sym_chandle] = ACTIONS(5620),
    [anon_sym_event] = ACTIONS(5620),
    [anon_sym_byte] = ACTIONS(5620),
    [anon_sym_shortint] = ACTIONS(5620),
    [anon_sym_int] = ACTIONS(5620),
    [anon_sym_longint] = ACTIONS(5620),
    [anon_sym_integer] = ACTIONS(5620),
    [anon_sym_time] = ACTIONS(5620),
    [anon_sym_bit] = ACTIONS(5620),
    [anon_sym_logic] = ACTIONS(5620),
    [anon_sym_reg] = ACTIONS(5620),
    [anon_sym_shortreal] = ACTIONS(5620),
    [anon_sym_real] = ACTIONS(5620),
    [anon_sym_realtime] = ACTIONS(5620),
    [anon_sym_supply0] = ACTIONS(5620),
    [anon_sym_supply1] = ACTIONS(5620),
    [anon_sym_signed] = ACTIONS(5620),
    [anon_sym_unsigned] = ACTIONS(5620),
    [anon_sym_task] = ACTIONS(5620),
    [anon_sym_modport] = ACTIONS(5620),
    [anon_sym_assert] = ACTIONS(5620),
    [anon_sym_property] = ACTIONS(5620),
    [anon_sym_assume] = ACTIONS(5620),
    [anon_sym_cover] = ACTIONS(5620),
    [anon_sym_sequence] = ACTIONS(5620),
    [anon_sym_restrict] = ACTIONS(5620),
    [anon_sym_not] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_case] = ACTIONS(5620),
    [anon_sym_always] = ACTIONS(5620),
    [anon_sym_covergroup] = ACTIONS(5620),
    [anon_sym_let] = ACTIONS(5620),
    [anon_sym_pulldown] = ACTIONS(5620),
    [anon_sym_pullup] = ACTIONS(5620),
    [anon_sym_cmos] = ACTIONS(5620),
    [anon_sym_rcmos] = ACTIONS(5620),
    [anon_sym_bufif0] = ACTIONS(5620),
    [anon_sym_bufif1] = ACTIONS(5620),
    [anon_sym_notif0] = ACTIONS(5620),
    [anon_sym_notif1] = ACTIONS(5620),
    [anon_sym_nmos] = ACTIONS(5620),
    [anon_sym_pmos] = ACTIONS(5620),
    [anon_sym_rnmos] = ACTIONS(5620),
    [anon_sym_rpmos] = ACTIONS(5620),
    [anon_sym_nand] = ACTIONS(5620),
    [anon_sym_nor] = ACTIONS(5620),
    [anon_sym_xor] = ACTIONS(5620),
    [anon_sym_xnor] = ACTIONS(5620),
    [anon_sym_buf] = ACTIONS(5620),
    [anon_sym_tranif0] = ACTIONS(5620),
    [anon_sym_tranif1] = ACTIONS(5620),
    [anon_sym_rtranif1] = ACTIONS(5620),
    [anon_sym_rtranif0] = ACTIONS(5620),
    [anon_sym_tran] = ACTIONS(5620),
    [anon_sym_rtran] = ACTIONS(5620),
    [anon_sym_generate] = ACTIONS(5620),
    [anon_sym_for] = ACTIONS(5620),
    [anon_sym_primitive] = ACTIONS(5620),
    [anon_sym_initial] = ACTIONS(5620),
    [anon_sym_assign] = ACTIONS(5620),
    [anon_sym_alias] = ACTIONS(5620),
    [anon_sym_always_comb] = ACTIONS(5620),
    [anon_sym_always_latch] = ACTIONS(5620),
    [anon_sym_always_ff] = ACTIONS(5620),
    [anon_sym_final] = ACTIONS(5620),
    [anon_sym_global] = ACTIONS(5620),
    [anon_sym_specify] = ACTIONS(5620),
    [anon_sym_LPAREN_STAR] = ACTIONS(5618),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5618),
    [anon_sym_DOLLARunit] = ACTIONS(5618),
  },
  [996] = {
    [ts_builtin_sym_end] = ACTIONS(5622),
    [sym_simple_identifier] = ACTIONS(5624),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5622),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5622),
    [anon_sym_BQUOTE] = ACTIONS(5624),
    [aux_sym_id_directive_token1] = ACTIONS(5622),
    [aux_sym_id_directive_token2] = ACTIONS(5622),
    [aux_sym_id_directive_token3] = ACTIONS(5622),
    [aux_sym_id_directive_token4] = ACTIONS(5624),
    [aux_sym_zero_directive_token1] = ACTIONS(5622),
    [aux_sym_zero_directive_token2] = ACTIONS(5622),
    [aux_sym_zero_directive_token3] = ACTIONS(5622),
    [aux_sym_zero_directive_token4] = ACTIONS(5622),
    [aux_sym_zero_directive_token5] = ACTIONS(5622),
    [aux_sym_zero_directive_token6] = ACTIONS(5622),
    [aux_sym_zero_directive_token7] = ACTIONS(5622),
    [aux_sym_zero_directive_token8] = ACTIONS(5622),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5622),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5622),
    [anon_sym_wire] = ACTIONS(5624),
    [anon_sym_tri] = ACTIONS(5624),
    [anon_sym_tri0] = ACTIONS(5624),
    [anon_sym_tri1] = ACTIONS(5624),
    [anon_sym_wand] = ACTIONS(5624),
    [anon_sym_triand] = ACTIONS(5624),
    [anon_sym_wor] = ACTIONS(5624),
    [anon_sym_trior] = ACTIONS(5624),
    [anon_sym_trireg] = ACTIONS(5624),
    [anon_sym_uwire] = ACTIONS(5624),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5622),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5622),
    [aux_sym_begin_keywords_token1] = ACTIONS(5622),
    [anon_sym_SEMI] = ACTIONS(5622),
    [anon_sym_endmodule] = ACTIONS(5624),
    [anon_sym_extern] = ACTIONS(5624),
    [anon_sym_module] = ACTIONS(5624),
    [anon_sym_macromodule] = ACTIONS(5624),
    [anon_sym_endinterface] = ACTIONS(5624),
    [anon_sym_interface] = ACTIONS(5624),
    [anon_sym_endprogram] = ACTIONS(5624),
    [anon_sym_program] = ACTIONS(5624),
    [anon_sym_checker] = ACTIONS(5624),
    [anon_sym_virtual] = ACTIONS(5624),
    [anon_sym_class] = ACTIONS(5624),
    [anon_sym_package] = ACTIONS(5624),
    [anon_sym_timeunit] = ACTIONS(5624),
    [anon_sym_timeprecision] = ACTIONS(5624),
    [anon_sym_type] = ACTIONS(5624),
    [anon_sym_input] = ACTIONS(5624),
    [anon_sym_output] = ACTIONS(5624),
    [anon_sym_inout] = ACTIONS(5624),
    [anon_sym_ref] = ACTIONS(5624),
    [anon_sym_DOLLARfatal] = ACTIONS(5622),
    [anon_sym_DOLLARerror] = ACTIONS(5622),
    [anon_sym_DOLLARwarning] = ACTIONS(5622),
    [anon_sym_DOLLARinfo] = ACTIONS(5622),
    [anon_sym_default] = ACTIONS(5624),
    [anon_sym_clocking] = ACTIONS(5624),
    [anon_sym_defparam] = ACTIONS(5624),
    [anon_sym_bind] = ACTIONS(5624),
    [anon_sym_const] = ACTIONS(5624),
    [anon_sym_function] = ACTIONS(5624),
    [anon_sym_static] = ACTIONS(5624),
    [anon_sym_constraint] = ACTIONS(5624),
    [anon_sym_if] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5622),
    [anon_sym_localparam] = ACTIONS(5624),
    [anon_sym_parameter] = ACTIONS(5624),
    [anon_sym_specparam] = ACTIONS(5624),
    [anon_sym_var] = ACTIONS(5624),
    [anon_sym_import] = ACTIONS(5624),
    [anon_sym_export] = ACTIONS(5624),
    [anon_sym_genvar] = ACTIONS(5624),
    [anon_sym_interconnect] = ACTIONS(5624),
    [anon_sym_typedef] = ACTIONS(5624),
    [anon_sym_enum] = ACTIONS(5624),
    [anon_sym_struct] = ACTIONS(5624),
    [anon_sym_union] = ACTIONS(5624),
    [anon_sym_nettype] = ACTIONS(5624),
    [anon_sym_automatic] = ACTIONS(5624),
    [anon_sym_string] = ACTIONS(5624),
    [anon_sym_chandle] = ACTIONS(5624),
    [anon_sym_event] = ACTIONS(5624),
    [anon_sym_byte] = ACTIONS(5624),
    [anon_sym_shortint] = ACTIONS(5624),
    [anon_sym_int] = ACTIONS(5624),
    [anon_sym_longint] = ACTIONS(5624),
    [anon_sym_integer] = ACTIONS(5624),
    [anon_sym_time] = ACTIONS(5624),
    [anon_sym_bit] = ACTIONS(5624),
    [anon_sym_logic] = ACTIONS(5624),
    [anon_sym_reg] = ACTIONS(5624),
    [anon_sym_shortreal] = ACTIONS(5624),
    [anon_sym_real] = ACTIONS(5624),
    [anon_sym_realtime] = ACTIONS(5624),
    [anon_sym_supply0] = ACTIONS(5624),
    [anon_sym_supply1] = ACTIONS(5624),
    [anon_sym_signed] = ACTIONS(5624),
    [anon_sym_unsigned] = ACTIONS(5624),
    [anon_sym_task] = ACTIONS(5624),
    [anon_sym_modport] = ACTIONS(5624),
    [anon_sym_assert] = ACTIONS(5624),
    [anon_sym_property] = ACTIONS(5624),
    [anon_sym_assume] = ACTIONS(5624),
    [anon_sym_cover] = ACTIONS(5624),
    [anon_sym_sequence] = ACTIONS(5624),
    [anon_sym_restrict] = ACTIONS(5624),
    [anon_sym_not] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_case] = ACTIONS(5624),
    [anon_sym_always] = ACTIONS(5624),
    [anon_sym_covergroup] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_pulldown] = ACTIONS(5624),
    [anon_sym_pullup] = ACTIONS(5624),
    [anon_sym_cmos] = ACTIONS(5624),
    [anon_sym_rcmos] = ACTIONS(5624),
    [anon_sym_bufif0] = ACTIONS(5624),
    [anon_sym_bufif1] = ACTIONS(5624),
    [anon_sym_notif0] = ACTIONS(5624),
    [anon_sym_notif1] = ACTIONS(5624),
    [anon_sym_nmos] = ACTIONS(5624),
    [anon_sym_pmos] = ACTIONS(5624),
    [anon_sym_rnmos] = ACTIONS(5624),
    [anon_sym_rpmos] = ACTIONS(5624),
    [anon_sym_nand] = ACTIONS(5624),
    [anon_sym_nor] = ACTIONS(5624),
    [anon_sym_xor] = ACTIONS(5624),
    [anon_sym_xnor] = ACTIONS(5624),
    [anon_sym_buf] = ACTIONS(5624),
    [anon_sym_tranif0] = ACTIONS(5624),
    [anon_sym_tranif1] = ACTIONS(5624),
    [anon_sym_rtranif1] = ACTIONS(5624),
    [anon_sym_rtranif0] = ACTIONS(5624),
    [anon_sym_tran] = ACTIONS(5624),
    [anon_sym_rtran] = ACTIONS(5624),
    [anon_sym_generate] = ACTIONS(5624),
    [anon_sym_for] = ACTIONS(5624),
    [anon_sym_primitive] = ACTIONS(5624),
    [anon_sym_initial] = ACTIONS(5624),
    [anon_sym_assign] = ACTIONS(5624),
    [anon_sym_alias] = ACTIONS(5624),
    [anon_sym_always_comb] = ACTIONS(5624),
    [anon_sym_always_latch] = ACTIONS(5624),
    [anon_sym_always_ff] = ACTIONS(5624),
    [anon_sym_final] = ACTIONS(5624),
    [anon_sym_global] = ACTIONS(5624),
    [anon_sym_specify] = ACTIONS(5624),
    [anon_sym_LPAREN_STAR] = ACTIONS(5622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5622),
    [anon_sym_DOLLARunit] = ACTIONS(5622),
  },
  [997] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_wire] = ACTIONS(1688),
    [anon_sym_tri] = ACTIONS(1688),
    [anon_sym_tri0] = ACTIONS(1688),
    [anon_sym_tri1] = ACTIONS(1688),
    [anon_sym_wand] = ACTIONS(1688),
    [anon_sym_triand] = ACTIONS(1688),
    [anon_sym_wor] = ACTIONS(1688),
    [anon_sym_trior] = ACTIONS(1688),
    [anon_sym_trireg] = ACTIONS(1688),
    [anon_sym_uwire] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_extern] = ACTIONS(1688),
    [anon_sym_interface] = ACTIONS(1688),
    [anon_sym_checker] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_class] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_DOLLARfatal] = ACTIONS(1686),
    [anon_sym_DOLLARerror] = ACTIONS(1686),
    [anon_sym_DOLLARwarning] = ACTIONS(1686),
    [anon_sym_DOLLARinfo] = ACTIONS(1686),
    [anon_sym_default] = ACTIONS(1688),
    [anon_sym_clocking] = ACTIONS(1688),
    [anon_sym_defparam] = ACTIONS(1688),
    [anon_sym_bind] = ACTIONS(1688),
    [anon_sym_rand] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_function] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_constraint] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_localparam] = ACTIONS(1688),
    [anon_sym_parameter] = ACTIONS(1688),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_export] = ACTIONS(1688),
    [anon_sym_genvar] = ACTIONS(1688),
    [anon_sym_interconnect] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_supply0] = ACTIONS(1688),
    [anon_sym_supply1] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_task] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_property] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_sequence] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_not] = ACTIONS(1688),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_and] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_always] = ACTIONS(1688),
    [anon_sym_covergroup] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1686),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_let] = ACTIONS(1688),
    [anon_sym_pulldown] = ACTIONS(1688),
    [anon_sym_pullup] = ACTIONS(1688),
    [anon_sym_cmos] = ACTIONS(1688),
    [anon_sym_rcmos] = ACTIONS(1688),
    [anon_sym_bufif0] = ACTIONS(1688),
    [anon_sym_bufif1] = ACTIONS(1688),
    [anon_sym_notif0] = ACTIONS(1688),
    [anon_sym_notif1] = ACTIONS(1688),
    [anon_sym_nmos] = ACTIONS(1688),
    [anon_sym_pmos] = ACTIONS(1688),
    [anon_sym_rnmos] = ACTIONS(1688),
    [anon_sym_rpmos] = ACTIONS(1688),
    [anon_sym_nand] = ACTIONS(1688),
    [anon_sym_nor] = ACTIONS(1688),
    [anon_sym_xor] = ACTIONS(1688),
    [anon_sym_xnor] = ACTIONS(1688),
    [anon_sym_buf] = ACTIONS(1688),
    [anon_sym_tranif0] = ACTIONS(1688),
    [anon_sym_tranif1] = ACTIONS(1688),
    [anon_sym_rtranif1] = ACTIONS(1688),
    [anon_sym_rtranif0] = ACTIONS(1688),
    [anon_sym_tran] = ACTIONS(1688),
    [anon_sym_rtran] = ACTIONS(1688),
    [anon_sym_generate] = ACTIONS(1688),
    [anon_sym_endgenerate] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_initial] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_alias] = ACTIONS(1688),
    [anon_sym_always_comb] = ACTIONS(1688),
    [anon_sym_always_latch] = ACTIONS(1688),
    [anon_sym_always_ff] = ACTIONS(1688),
    [anon_sym_final] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_global] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [anon_sym_STAR_RPAREN] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARunit] = ACTIONS(1686),
  },
  [998] = {
    [ts_builtin_sym_end] = ACTIONS(5626),
    [sym_simple_identifier] = ACTIONS(5628),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5626),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5626),
    [anon_sym_BQUOTE] = ACTIONS(5628),
    [aux_sym_id_directive_token1] = ACTIONS(5626),
    [aux_sym_id_directive_token2] = ACTIONS(5626),
    [aux_sym_id_directive_token3] = ACTIONS(5626),
    [aux_sym_id_directive_token4] = ACTIONS(5628),
    [aux_sym_zero_directive_token1] = ACTIONS(5626),
    [aux_sym_zero_directive_token2] = ACTIONS(5626),
    [aux_sym_zero_directive_token3] = ACTIONS(5626),
    [aux_sym_zero_directive_token4] = ACTIONS(5626),
    [aux_sym_zero_directive_token5] = ACTIONS(5626),
    [aux_sym_zero_directive_token6] = ACTIONS(5626),
    [aux_sym_zero_directive_token7] = ACTIONS(5626),
    [aux_sym_zero_directive_token8] = ACTIONS(5626),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5626),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5626),
    [anon_sym_wire] = ACTIONS(5628),
    [anon_sym_tri] = ACTIONS(5628),
    [anon_sym_tri0] = ACTIONS(5628),
    [anon_sym_tri1] = ACTIONS(5628),
    [anon_sym_wand] = ACTIONS(5628),
    [anon_sym_triand] = ACTIONS(5628),
    [anon_sym_wor] = ACTIONS(5628),
    [anon_sym_trior] = ACTIONS(5628),
    [anon_sym_trireg] = ACTIONS(5628),
    [anon_sym_uwire] = ACTIONS(5628),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5626),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5626),
    [aux_sym_begin_keywords_token1] = ACTIONS(5626),
    [anon_sym_SEMI] = ACTIONS(5626),
    [anon_sym_endmodule] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5630),
    [anon_sym_extern] = ACTIONS(5628),
    [anon_sym_module] = ACTIONS(5628),
    [anon_sym_macromodule] = ACTIONS(5628),
    [anon_sym_endinterface] = ACTIONS(5628),
    [anon_sym_interface] = ACTIONS(5628),
    [anon_sym_program] = ACTIONS(5628),
    [anon_sym_checker] = ACTIONS(5628),
    [anon_sym_virtual] = ACTIONS(5628),
    [anon_sym_class] = ACTIONS(5628),
    [anon_sym_package] = ACTIONS(5628),
    [anon_sym_timeunit] = ACTIONS(5628),
    [anon_sym_timeprecision] = ACTIONS(5628),
    [anon_sym_type] = ACTIONS(5628),
    [anon_sym_input] = ACTIONS(5628),
    [anon_sym_output] = ACTIONS(5628),
    [anon_sym_inout] = ACTIONS(5628),
    [anon_sym_ref] = ACTIONS(5628),
    [anon_sym_DOLLARfatal] = ACTIONS(5626),
    [anon_sym_DOLLARerror] = ACTIONS(5626),
    [anon_sym_DOLLARwarning] = ACTIONS(5626),
    [anon_sym_DOLLARinfo] = ACTIONS(5626),
    [anon_sym_default] = ACTIONS(5628),
    [anon_sym_clocking] = ACTIONS(5628),
    [anon_sym_defparam] = ACTIONS(5628),
    [anon_sym_bind] = ACTIONS(5628),
    [anon_sym_const] = ACTIONS(5628),
    [anon_sym_function] = ACTIONS(5628),
    [anon_sym_static] = ACTIONS(5628),
    [anon_sym_constraint] = ACTIONS(5628),
    [anon_sym_if] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5626),
    [anon_sym_localparam] = ACTIONS(5628),
    [anon_sym_parameter] = ACTIONS(5628),
    [anon_sym_specparam] = ACTIONS(5628),
    [anon_sym_var] = ACTIONS(5628),
    [anon_sym_import] = ACTIONS(5628),
    [anon_sym_export] = ACTIONS(5628),
    [anon_sym_genvar] = ACTIONS(5628),
    [anon_sym_interconnect] = ACTIONS(5628),
    [anon_sym_typedef] = ACTIONS(5628),
    [anon_sym_enum] = ACTIONS(5628),
    [anon_sym_struct] = ACTIONS(5628),
    [anon_sym_union] = ACTIONS(5628),
    [anon_sym_nettype] = ACTIONS(5628),
    [anon_sym_automatic] = ACTIONS(5628),
    [anon_sym_string] = ACTIONS(5628),
    [anon_sym_chandle] = ACTIONS(5628),
    [anon_sym_event] = ACTIONS(5628),
    [anon_sym_byte] = ACTIONS(5628),
    [anon_sym_shortint] = ACTIONS(5628),
    [anon_sym_int] = ACTIONS(5628),
    [anon_sym_longint] = ACTIONS(5628),
    [anon_sym_integer] = ACTIONS(5628),
    [anon_sym_time] = ACTIONS(5628),
    [anon_sym_bit] = ACTIONS(5628),
    [anon_sym_logic] = ACTIONS(5628),
    [anon_sym_reg] = ACTIONS(5628),
    [anon_sym_shortreal] = ACTIONS(5628),
    [anon_sym_real] = ACTIONS(5628),
    [anon_sym_realtime] = ACTIONS(5628),
    [anon_sym_supply0] = ACTIONS(5628),
    [anon_sym_supply1] = ACTIONS(5628),
    [anon_sym_signed] = ACTIONS(5628),
    [anon_sym_unsigned] = ACTIONS(5628),
    [anon_sym_task] = ACTIONS(5628),
    [anon_sym_modport] = ACTIONS(5628),
    [anon_sym_assert] = ACTIONS(5628),
    [anon_sym_property] = ACTIONS(5628),
    [anon_sym_assume] = ACTIONS(5628),
    [anon_sym_cover] = ACTIONS(5628),
    [anon_sym_sequence] = ACTIONS(5628),
    [anon_sym_restrict] = ACTIONS(5628),
    [anon_sym_not] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_case] = ACTIONS(5628),
    [anon_sym_always] = ACTIONS(5628),
    [anon_sym_covergroup] = ACTIONS(5628),
    [anon_sym_let] = ACTIONS(5628),
    [anon_sym_pulldown] = ACTIONS(5628),
    [anon_sym_pullup] = ACTIONS(5628),
    [anon_sym_cmos] = ACTIONS(5628),
    [anon_sym_rcmos] = ACTIONS(5628),
    [anon_sym_bufif0] = ACTIONS(5628),
    [anon_sym_bufif1] = ACTIONS(5628),
    [anon_sym_notif0] = ACTIONS(5628),
    [anon_sym_notif1] = ACTIONS(5628),
    [anon_sym_nmos] = ACTIONS(5628),
    [anon_sym_pmos] = ACTIONS(5628),
    [anon_sym_rnmos] = ACTIONS(5628),
    [anon_sym_rpmos] = ACTIONS(5628),
    [anon_sym_nand] = ACTIONS(5628),
    [anon_sym_nor] = ACTIONS(5628),
    [anon_sym_xor] = ACTIONS(5628),
    [anon_sym_xnor] = ACTIONS(5628),
    [anon_sym_buf] = ACTIONS(5628),
    [anon_sym_tranif0] = ACTIONS(5628),
    [anon_sym_tranif1] = ACTIONS(5628),
    [anon_sym_rtranif1] = ACTIONS(5628),
    [anon_sym_rtranif0] = ACTIONS(5628),
    [anon_sym_tran] = ACTIONS(5628),
    [anon_sym_rtran] = ACTIONS(5628),
    [anon_sym_generate] = ACTIONS(5628),
    [anon_sym_for] = ACTIONS(5628),
    [anon_sym_primitive] = ACTIONS(5628),
    [anon_sym_initial] = ACTIONS(5628),
    [anon_sym_assign] = ACTIONS(5628),
    [anon_sym_alias] = ACTIONS(5628),
    [anon_sym_always_comb] = ACTIONS(5628),
    [anon_sym_always_latch] = ACTIONS(5628),
    [anon_sym_always_ff] = ACTIONS(5628),
    [anon_sym_final] = ACTIONS(5628),
    [anon_sym_global] = ACTIONS(5628),
    [anon_sym_specify] = ACTIONS(5628),
    [anon_sym_LPAREN_STAR] = ACTIONS(5626),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5626),
    [anon_sym_DOLLARunit] = ACTIONS(5626),
  },
  [999] = {
    [ts_builtin_sym_end] = ACTIONS(5632),
    [sym_simple_identifier] = ACTIONS(5634),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5632),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5632),
    [anon_sym_BQUOTE] = ACTIONS(5634),
    [aux_sym_id_directive_token1] = ACTIONS(5632),
    [aux_sym_id_directive_token2] = ACTIONS(5632),
    [aux_sym_id_directive_token3] = ACTIONS(5632),
    [aux_sym_id_directive_token4] = ACTIONS(5634),
    [aux_sym_zero_directive_token1] = ACTIONS(5632),
    [aux_sym_zero_directive_token2] = ACTIONS(5632),
    [aux_sym_zero_directive_token3] = ACTIONS(5632),
    [aux_sym_zero_directive_token4] = ACTIONS(5632),
    [aux_sym_zero_directive_token5] = ACTIONS(5632),
    [aux_sym_zero_directive_token6] = ACTIONS(5632),
    [aux_sym_zero_directive_token7] = ACTIONS(5632),
    [aux_sym_zero_directive_token8] = ACTIONS(5632),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5632),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5632),
    [anon_sym_wire] = ACTIONS(5634),
    [anon_sym_tri] = ACTIONS(5634),
    [anon_sym_tri0] = ACTIONS(5634),
    [anon_sym_tri1] = ACTIONS(5634),
    [anon_sym_wand] = ACTIONS(5634),
    [anon_sym_triand] = ACTIONS(5634),
    [anon_sym_wor] = ACTIONS(5634),
    [anon_sym_trior] = ACTIONS(5634),
    [anon_sym_trireg] = ACTIONS(5634),
    [anon_sym_uwire] = ACTIONS(5634),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5632),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5632),
    [aux_sym_begin_keywords_token1] = ACTIONS(5632),
    [anon_sym_SEMI] = ACTIONS(5632),
    [anon_sym_endmodule] = ACTIONS(5634),
    [anon_sym_COLON] = ACTIONS(5636),
    [anon_sym_extern] = ACTIONS(5634),
    [anon_sym_module] = ACTIONS(5634),
    [anon_sym_macromodule] = ACTIONS(5634),
    [anon_sym_endinterface] = ACTIONS(5634),
    [anon_sym_interface] = ACTIONS(5634),
    [anon_sym_program] = ACTIONS(5634),
    [anon_sym_checker] = ACTIONS(5634),
    [anon_sym_virtual] = ACTIONS(5634),
    [anon_sym_class] = ACTIONS(5634),
    [anon_sym_package] = ACTIONS(5634),
    [anon_sym_timeunit] = ACTIONS(5634),
    [anon_sym_timeprecision] = ACTIONS(5634),
    [anon_sym_type] = ACTIONS(5634),
    [anon_sym_input] = ACTIONS(5634),
    [anon_sym_output] = ACTIONS(5634),
    [anon_sym_inout] = ACTIONS(5634),
    [anon_sym_ref] = ACTIONS(5634),
    [anon_sym_DOLLARfatal] = ACTIONS(5632),
    [anon_sym_DOLLARerror] = ACTIONS(5632),
    [anon_sym_DOLLARwarning] = ACTIONS(5632),
    [anon_sym_DOLLARinfo] = ACTIONS(5632),
    [anon_sym_default] = ACTIONS(5634),
    [anon_sym_clocking] = ACTIONS(5634),
    [anon_sym_defparam] = ACTIONS(5634),
    [anon_sym_bind] = ACTIONS(5634),
    [anon_sym_const] = ACTIONS(5634),
    [anon_sym_function] = ACTIONS(5634),
    [anon_sym_static] = ACTIONS(5634),
    [anon_sym_constraint] = ACTIONS(5634),
    [anon_sym_if] = ACTIONS(5634),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_localparam] = ACTIONS(5634),
    [anon_sym_parameter] = ACTIONS(5634),
    [anon_sym_specparam] = ACTIONS(5634),
    [anon_sym_var] = ACTIONS(5634),
    [anon_sym_import] = ACTIONS(5634),
    [anon_sym_export] = ACTIONS(5634),
    [anon_sym_genvar] = ACTIONS(5634),
    [anon_sym_interconnect] = ACTIONS(5634),
    [anon_sym_typedef] = ACTIONS(5634),
    [anon_sym_enum] = ACTIONS(5634),
    [anon_sym_struct] = ACTIONS(5634),
    [anon_sym_union] = ACTIONS(5634),
    [anon_sym_nettype] = ACTIONS(5634),
    [anon_sym_automatic] = ACTIONS(5634),
    [anon_sym_string] = ACTIONS(5634),
    [anon_sym_chandle] = ACTIONS(5634),
    [anon_sym_event] = ACTIONS(5634),
    [anon_sym_byte] = ACTIONS(5634),
    [anon_sym_shortint] = ACTIONS(5634),
    [anon_sym_int] = ACTIONS(5634),
    [anon_sym_longint] = ACTIONS(5634),
    [anon_sym_integer] = ACTIONS(5634),
    [anon_sym_time] = ACTIONS(5634),
    [anon_sym_bit] = ACTIONS(5634),
    [anon_sym_logic] = ACTIONS(5634),
    [anon_sym_reg] = ACTIONS(5634),
    [anon_sym_shortreal] = ACTIONS(5634),
    [anon_sym_real] = ACTIONS(5634),
    [anon_sym_realtime] = ACTIONS(5634),
    [anon_sym_supply0] = ACTIONS(5634),
    [anon_sym_supply1] = ACTIONS(5634),
    [anon_sym_signed] = ACTIONS(5634),
    [anon_sym_unsigned] = ACTIONS(5634),
    [anon_sym_task] = ACTIONS(5634),
    [anon_sym_modport] = ACTIONS(5634),
    [anon_sym_assert] = ACTIONS(5634),
    [anon_sym_property] = ACTIONS(5634),
    [anon_sym_assume] = ACTIONS(5634),
    [anon_sym_cover] = ACTIONS(5634),
    [anon_sym_sequence] = ACTIONS(5634),
    [anon_sym_restrict] = ACTIONS(5634),
    [anon_sym_not] = ACTIONS(5634),
    [anon_sym_or] = ACTIONS(5634),
    [anon_sym_and] = ACTIONS(5634),
    [anon_sym_case] = ACTIONS(5634),
    [anon_sym_always] = ACTIONS(5634),
    [anon_sym_covergroup] = ACTIONS(5634),
    [anon_sym_let] = ACTIONS(5634),
    [anon_sym_pulldown] = ACTIONS(5634),
    [anon_sym_pullup] = ACTIONS(5634),
    [anon_sym_cmos] = ACTIONS(5634),
    [anon_sym_rcmos] = ACTIONS(5634),
    [anon_sym_bufif0] = ACTIONS(5634),
    [anon_sym_bufif1] = ACTIONS(5634),
    [anon_sym_notif0] = ACTIONS(5634),
    [anon_sym_notif1] = ACTIONS(5634),
    [anon_sym_nmos] = ACTIONS(5634),
    [anon_sym_pmos] = ACTIONS(5634),
    [anon_sym_rnmos] = ACTIONS(5634),
    [anon_sym_rpmos] = ACTIONS(5634),
    [anon_sym_nand] = ACTIONS(5634),
    [anon_sym_nor] = ACTIONS(5634),
    [anon_sym_xor] = ACTIONS(5634),
    [anon_sym_xnor] = ACTIONS(5634),
    [anon_sym_buf] = ACTIONS(5634),
    [anon_sym_tranif0] = ACTIONS(5634),
    [anon_sym_tranif1] = ACTIONS(5634),
    [anon_sym_rtranif1] = ACTIONS(5634),
    [anon_sym_rtranif0] = ACTIONS(5634),
    [anon_sym_tran] = ACTIONS(5634),
    [anon_sym_rtran] = ACTIONS(5634),
    [anon_sym_generate] = ACTIONS(5634),
    [anon_sym_for] = ACTIONS(5634),
    [anon_sym_primitive] = ACTIONS(5634),
    [anon_sym_initial] = ACTIONS(5634),
    [anon_sym_assign] = ACTIONS(5634),
    [anon_sym_alias] = ACTIONS(5634),
    [anon_sym_always_comb] = ACTIONS(5634),
    [anon_sym_always_latch] = ACTIONS(5634),
    [anon_sym_always_ff] = ACTIONS(5634),
    [anon_sym_final] = ACTIONS(5634),
    [anon_sym_global] = ACTIONS(5634),
    [anon_sym_specify] = ACTIONS(5634),
    [anon_sym_LPAREN_STAR] = ACTIONS(5632),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5632),
    [anon_sym_DOLLARunit] = ACTIONS(5632),
  },
  [1000] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_wire] = ACTIONS(1684),
    [anon_sym_tri] = ACTIONS(1684),
    [anon_sym_tri0] = ACTIONS(1684),
    [anon_sym_tri1] = ACTIONS(1684),
    [anon_sym_wand] = ACTIONS(1684),
    [anon_sym_triand] = ACTIONS(1684),
    [anon_sym_wor] = ACTIONS(1684),
    [anon_sym_trior] = ACTIONS(1684),
    [anon_sym_trireg] = ACTIONS(1684),
    [anon_sym_uwire] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_extern] = ACTIONS(1684),
    [anon_sym_interface] = ACTIONS(1684),
    [anon_sym_checker] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_class] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_DOLLARfatal] = ACTIONS(1682),
    [anon_sym_DOLLARerror] = ACTIONS(1682),
    [anon_sym_DOLLARwarning] = ACTIONS(1682),
    [anon_sym_DOLLARinfo] = ACTIONS(1682),
    [anon_sym_default] = ACTIONS(1684),
    [anon_sym_clocking] = ACTIONS(1684),
    [anon_sym_defparam] = ACTIONS(1684),
    [anon_sym_bind] = ACTIONS(1684),
    [anon_sym_rand] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_function] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_constraint] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_localparam] = ACTIONS(1684),
    [anon_sym_parameter] = ACTIONS(1684),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_export] = ACTIONS(1684),
    [anon_sym_genvar] = ACTIONS(1684),
    [anon_sym_interconnect] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_supply0] = ACTIONS(1684),
    [anon_sym_supply1] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_task] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_property] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_sequence] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_not] = ACTIONS(1684),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_and] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_always] = ACTIONS(1684),
    [anon_sym_covergroup] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1682),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_let] = ACTIONS(1684),
    [anon_sym_pulldown] = ACTIONS(1684),
    [anon_sym_pullup] = ACTIONS(1684),
    [anon_sym_cmos] = ACTIONS(1684),
    [anon_sym_rcmos] = ACTIONS(1684),
    [anon_sym_bufif0] = ACTIONS(1684),
    [anon_sym_bufif1] = ACTIONS(1684),
    [anon_sym_notif0] = ACTIONS(1684),
    [anon_sym_notif1] = ACTIONS(1684),
    [anon_sym_nmos] = ACTIONS(1684),
    [anon_sym_pmos] = ACTIONS(1684),
    [anon_sym_rnmos] = ACTIONS(1684),
    [anon_sym_rpmos] = ACTIONS(1684),
    [anon_sym_nand] = ACTIONS(1684),
    [anon_sym_nor] = ACTIONS(1684),
    [anon_sym_xor] = ACTIONS(1684),
    [anon_sym_xnor] = ACTIONS(1684),
    [anon_sym_buf] = ACTIONS(1684),
    [anon_sym_tranif0] = ACTIONS(1684),
    [anon_sym_tranif1] = ACTIONS(1684),
    [anon_sym_rtranif1] = ACTIONS(1684),
    [anon_sym_rtranif0] = ACTIONS(1684),
    [anon_sym_tran] = ACTIONS(1684),
    [anon_sym_rtran] = ACTIONS(1684),
    [anon_sym_generate] = ACTIONS(1684),
    [anon_sym_endgenerate] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_initial] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_alias] = ACTIONS(1684),
    [anon_sym_always_comb] = ACTIONS(1684),
    [anon_sym_always_latch] = ACTIONS(1684),
    [anon_sym_always_ff] = ACTIONS(1684),
    [anon_sym_final] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_global] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [anon_sym_STAR_RPAREN] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARunit] = ACTIONS(1682),
  },
  [1001] = {
    [ts_builtin_sym_end] = ACTIONS(5638),
    [sym_simple_identifier] = ACTIONS(5640),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5638),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5638),
    [anon_sym_BQUOTE] = ACTIONS(5640),
    [aux_sym_id_directive_token1] = ACTIONS(5638),
    [aux_sym_id_directive_token2] = ACTIONS(5638),
    [aux_sym_id_directive_token3] = ACTIONS(5638),
    [aux_sym_id_directive_token4] = ACTIONS(5640),
    [aux_sym_zero_directive_token1] = ACTIONS(5638),
    [aux_sym_zero_directive_token2] = ACTIONS(5638),
    [aux_sym_zero_directive_token3] = ACTIONS(5638),
    [aux_sym_zero_directive_token4] = ACTIONS(5638),
    [aux_sym_zero_directive_token5] = ACTIONS(5638),
    [aux_sym_zero_directive_token6] = ACTIONS(5638),
    [aux_sym_zero_directive_token7] = ACTIONS(5638),
    [aux_sym_zero_directive_token8] = ACTIONS(5638),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5638),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5638),
    [anon_sym_wire] = ACTIONS(5640),
    [anon_sym_tri] = ACTIONS(5640),
    [anon_sym_tri0] = ACTIONS(5640),
    [anon_sym_tri1] = ACTIONS(5640),
    [anon_sym_wand] = ACTIONS(5640),
    [anon_sym_triand] = ACTIONS(5640),
    [anon_sym_wor] = ACTIONS(5640),
    [anon_sym_trior] = ACTIONS(5640),
    [anon_sym_trireg] = ACTIONS(5640),
    [anon_sym_uwire] = ACTIONS(5640),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5638),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5638),
    [aux_sym_begin_keywords_token1] = ACTIONS(5638),
    [anon_sym_SEMI] = ACTIONS(5638),
    [anon_sym_endmodule] = ACTIONS(5640),
    [anon_sym_extern] = ACTIONS(5640),
    [anon_sym_module] = ACTIONS(5640),
    [anon_sym_macromodule] = ACTIONS(5640),
    [anon_sym_endinterface] = ACTIONS(5640),
    [anon_sym_interface] = ACTIONS(5640),
    [anon_sym_endprogram] = ACTIONS(5640),
    [anon_sym_program] = ACTIONS(5640),
    [anon_sym_checker] = ACTIONS(5640),
    [anon_sym_virtual] = ACTIONS(5640),
    [anon_sym_class] = ACTIONS(5640),
    [anon_sym_package] = ACTIONS(5640),
    [anon_sym_timeunit] = ACTIONS(5640),
    [anon_sym_timeprecision] = ACTIONS(5640),
    [anon_sym_type] = ACTIONS(5640),
    [anon_sym_input] = ACTIONS(5640),
    [anon_sym_output] = ACTIONS(5640),
    [anon_sym_inout] = ACTIONS(5640),
    [anon_sym_ref] = ACTIONS(5640),
    [anon_sym_DOLLARfatal] = ACTIONS(5638),
    [anon_sym_DOLLARerror] = ACTIONS(5638),
    [anon_sym_DOLLARwarning] = ACTIONS(5638),
    [anon_sym_DOLLARinfo] = ACTIONS(5638),
    [anon_sym_default] = ACTIONS(5640),
    [anon_sym_clocking] = ACTIONS(5640),
    [anon_sym_defparam] = ACTIONS(5640),
    [anon_sym_bind] = ACTIONS(5640),
    [anon_sym_const] = ACTIONS(5640),
    [anon_sym_function] = ACTIONS(5640),
    [anon_sym_static] = ACTIONS(5640),
    [anon_sym_constraint] = ACTIONS(5640),
    [anon_sym_if] = ACTIONS(5640),
    [anon_sym_LBRACK] = ACTIONS(5638),
    [anon_sym_localparam] = ACTIONS(5640),
    [anon_sym_parameter] = ACTIONS(5640),
    [anon_sym_specparam] = ACTIONS(5640),
    [anon_sym_var] = ACTIONS(5640),
    [anon_sym_import] = ACTIONS(5640),
    [anon_sym_export] = ACTIONS(5640),
    [anon_sym_genvar] = ACTIONS(5640),
    [anon_sym_interconnect] = ACTIONS(5640),
    [anon_sym_typedef] = ACTIONS(5640),
    [anon_sym_enum] = ACTIONS(5640),
    [anon_sym_struct] = ACTIONS(5640),
    [anon_sym_union] = ACTIONS(5640),
    [anon_sym_nettype] = ACTIONS(5640),
    [anon_sym_automatic] = ACTIONS(5640),
    [anon_sym_string] = ACTIONS(5640),
    [anon_sym_chandle] = ACTIONS(5640),
    [anon_sym_event] = ACTIONS(5640),
    [anon_sym_byte] = ACTIONS(5640),
    [anon_sym_shortint] = ACTIONS(5640),
    [anon_sym_int] = ACTIONS(5640),
    [anon_sym_longint] = ACTIONS(5640),
    [anon_sym_integer] = ACTIONS(5640),
    [anon_sym_time] = ACTIONS(5640),
    [anon_sym_bit] = ACTIONS(5640),
    [anon_sym_logic] = ACTIONS(5640),
    [anon_sym_reg] = ACTIONS(5640),
    [anon_sym_shortreal] = ACTIONS(5640),
    [anon_sym_real] = ACTIONS(5640),
    [anon_sym_realtime] = ACTIONS(5640),
    [anon_sym_supply0] = ACTIONS(5640),
    [anon_sym_supply1] = ACTIONS(5640),
    [anon_sym_signed] = ACTIONS(5640),
    [anon_sym_unsigned] = ACTIONS(5640),
    [anon_sym_task] = ACTIONS(5640),
    [anon_sym_modport] = ACTIONS(5640),
    [anon_sym_assert] = ACTIONS(5640),
    [anon_sym_property] = ACTIONS(5640),
    [anon_sym_assume] = ACTIONS(5640),
    [anon_sym_cover] = ACTIONS(5640),
    [anon_sym_sequence] = ACTIONS(5640),
    [anon_sym_restrict] = ACTIONS(5640),
    [anon_sym_not] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_case] = ACTIONS(5640),
    [anon_sym_always] = ACTIONS(5640),
    [anon_sym_covergroup] = ACTIONS(5640),
    [anon_sym_let] = ACTIONS(5640),
    [anon_sym_pulldown] = ACTIONS(5640),
    [anon_sym_pullup] = ACTIONS(5640),
    [anon_sym_cmos] = ACTIONS(5640),
    [anon_sym_rcmos] = ACTIONS(5640),
    [anon_sym_bufif0] = ACTIONS(5640),
    [anon_sym_bufif1] = ACTIONS(5640),
    [anon_sym_notif0] = ACTIONS(5640),
    [anon_sym_notif1] = ACTIONS(5640),
    [anon_sym_nmos] = ACTIONS(5640),
    [anon_sym_pmos] = ACTIONS(5640),
    [anon_sym_rnmos] = ACTIONS(5640),
    [anon_sym_rpmos] = ACTIONS(5640),
    [anon_sym_nand] = ACTIONS(5640),
    [anon_sym_nor] = ACTIONS(5640),
    [anon_sym_xor] = ACTIONS(5640),
    [anon_sym_xnor] = ACTIONS(5640),
    [anon_sym_buf] = ACTIONS(5640),
    [anon_sym_tranif0] = ACTIONS(5640),
    [anon_sym_tranif1] = ACTIONS(5640),
    [anon_sym_rtranif1] = ACTIONS(5640),
    [anon_sym_rtranif0] = ACTIONS(5640),
    [anon_sym_tran] = ACTIONS(5640),
    [anon_sym_rtran] = ACTIONS(5640),
    [anon_sym_generate] = ACTIONS(5640),
    [anon_sym_for] = ACTIONS(5640),
    [anon_sym_primitive] = ACTIONS(5640),
    [anon_sym_initial] = ACTIONS(5640),
    [anon_sym_assign] = ACTIONS(5640),
    [anon_sym_alias] = ACTIONS(5640),
    [anon_sym_always_comb] = ACTIONS(5640),
    [anon_sym_always_latch] = ACTIONS(5640),
    [anon_sym_always_ff] = ACTIONS(5640),
    [anon_sym_final] = ACTIONS(5640),
    [anon_sym_global] = ACTIONS(5640),
    [anon_sym_specify] = ACTIONS(5640),
    [anon_sym_LPAREN_STAR] = ACTIONS(5638),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5638),
    [anon_sym_DOLLARunit] = ACTIONS(5638),
  },
  [1002] = {
    [ts_builtin_sym_end] = ACTIONS(5642),
    [sym_simple_identifier] = ACTIONS(5644),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5642),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5642),
    [anon_sym_BQUOTE] = ACTIONS(5644),
    [aux_sym_id_directive_token1] = ACTIONS(5642),
    [aux_sym_id_directive_token2] = ACTIONS(5642),
    [aux_sym_id_directive_token3] = ACTIONS(5642),
    [aux_sym_id_directive_token4] = ACTIONS(5644),
    [aux_sym_zero_directive_token1] = ACTIONS(5642),
    [aux_sym_zero_directive_token2] = ACTIONS(5642),
    [aux_sym_zero_directive_token3] = ACTIONS(5642),
    [aux_sym_zero_directive_token4] = ACTIONS(5642),
    [aux_sym_zero_directive_token5] = ACTIONS(5642),
    [aux_sym_zero_directive_token6] = ACTIONS(5642),
    [aux_sym_zero_directive_token7] = ACTIONS(5642),
    [aux_sym_zero_directive_token8] = ACTIONS(5642),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5642),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5642),
    [anon_sym_wire] = ACTIONS(5644),
    [anon_sym_tri] = ACTIONS(5644),
    [anon_sym_tri0] = ACTIONS(5644),
    [anon_sym_tri1] = ACTIONS(5644),
    [anon_sym_wand] = ACTIONS(5644),
    [anon_sym_triand] = ACTIONS(5644),
    [anon_sym_wor] = ACTIONS(5644),
    [anon_sym_trior] = ACTIONS(5644),
    [anon_sym_trireg] = ACTIONS(5644),
    [anon_sym_uwire] = ACTIONS(5644),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5642),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5642),
    [aux_sym_begin_keywords_token1] = ACTIONS(5642),
    [anon_sym_SEMI] = ACTIONS(5642),
    [anon_sym_endmodule] = ACTIONS(5644),
    [anon_sym_extern] = ACTIONS(5644),
    [anon_sym_module] = ACTIONS(5644),
    [anon_sym_macromodule] = ACTIONS(5644),
    [anon_sym_endinterface] = ACTIONS(5644),
    [anon_sym_interface] = ACTIONS(5644),
    [anon_sym_endprogram] = ACTIONS(5644),
    [anon_sym_program] = ACTIONS(5644),
    [anon_sym_checker] = ACTIONS(5644),
    [anon_sym_virtual] = ACTIONS(5644),
    [anon_sym_class] = ACTIONS(5644),
    [anon_sym_package] = ACTIONS(5644),
    [anon_sym_timeunit] = ACTIONS(5644),
    [anon_sym_timeprecision] = ACTIONS(5644),
    [anon_sym_type] = ACTIONS(5644),
    [anon_sym_input] = ACTIONS(5644),
    [anon_sym_output] = ACTIONS(5644),
    [anon_sym_inout] = ACTIONS(5644),
    [anon_sym_ref] = ACTIONS(5644),
    [anon_sym_DOLLARfatal] = ACTIONS(5642),
    [anon_sym_DOLLARerror] = ACTIONS(5642),
    [anon_sym_DOLLARwarning] = ACTIONS(5642),
    [anon_sym_DOLLARinfo] = ACTIONS(5642),
    [anon_sym_default] = ACTIONS(5644),
    [anon_sym_clocking] = ACTIONS(5644),
    [anon_sym_defparam] = ACTIONS(5644),
    [anon_sym_bind] = ACTIONS(5644),
    [anon_sym_const] = ACTIONS(5644),
    [anon_sym_function] = ACTIONS(5644),
    [anon_sym_static] = ACTIONS(5644),
    [anon_sym_constraint] = ACTIONS(5644),
    [anon_sym_if] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5642),
    [anon_sym_localparam] = ACTIONS(5644),
    [anon_sym_parameter] = ACTIONS(5644),
    [anon_sym_specparam] = ACTIONS(5644),
    [anon_sym_var] = ACTIONS(5644),
    [anon_sym_import] = ACTIONS(5644),
    [anon_sym_export] = ACTIONS(5644),
    [anon_sym_genvar] = ACTIONS(5644),
    [anon_sym_interconnect] = ACTIONS(5644),
    [anon_sym_typedef] = ACTIONS(5644),
    [anon_sym_enum] = ACTIONS(5644),
    [anon_sym_struct] = ACTIONS(5644),
    [anon_sym_union] = ACTIONS(5644),
    [anon_sym_nettype] = ACTIONS(5644),
    [anon_sym_automatic] = ACTIONS(5644),
    [anon_sym_string] = ACTIONS(5644),
    [anon_sym_chandle] = ACTIONS(5644),
    [anon_sym_event] = ACTIONS(5644),
    [anon_sym_byte] = ACTIONS(5644),
    [anon_sym_shortint] = ACTIONS(5644),
    [anon_sym_int] = ACTIONS(5644),
    [anon_sym_longint] = ACTIONS(5644),
    [anon_sym_integer] = ACTIONS(5644),
    [anon_sym_time] = ACTIONS(5644),
    [anon_sym_bit] = ACTIONS(5644),
    [anon_sym_logic] = ACTIONS(5644),
    [anon_sym_reg] = ACTIONS(5644),
    [anon_sym_shortreal] = ACTIONS(5644),
    [anon_sym_real] = ACTIONS(5644),
    [anon_sym_realtime] = ACTIONS(5644),
    [anon_sym_supply0] = ACTIONS(5644),
    [anon_sym_supply1] = ACTIONS(5644),
    [anon_sym_signed] = ACTIONS(5644),
    [anon_sym_unsigned] = ACTIONS(5644),
    [anon_sym_task] = ACTIONS(5644),
    [anon_sym_modport] = ACTIONS(5644),
    [anon_sym_assert] = ACTIONS(5644),
    [anon_sym_property] = ACTIONS(5644),
    [anon_sym_assume] = ACTIONS(5644),
    [anon_sym_cover] = ACTIONS(5644),
    [anon_sym_sequence] = ACTIONS(5644),
    [anon_sym_restrict] = ACTIONS(5644),
    [anon_sym_not] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_case] = ACTIONS(5644),
    [anon_sym_always] = ACTIONS(5644),
    [anon_sym_covergroup] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_pulldown] = ACTIONS(5644),
    [anon_sym_pullup] = ACTIONS(5644),
    [anon_sym_cmos] = ACTIONS(5644),
    [anon_sym_rcmos] = ACTIONS(5644),
    [anon_sym_bufif0] = ACTIONS(5644),
    [anon_sym_bufif1] = ACTIONS(5644),
    [anon_sym_notif0] = ACTIONS(5644),
    [anon_sym_notif1] = ACTIONS(5644),
    [anon_sym_nmos] = ACTIONS(5644),
    [anon_sym_pmos] = ACTIONS(5644),
    [anon_sym_rnmos] = ACTIONS(5644),
    [anon_sym_rpmos] = ACTIONS(5644),
    [anon_sym_nand] = ACTIONS(5644),
    [anon_sym_nor] = ACTIONS(5644),
    [anon_sym_xor] = ACTIONS(5644),
    [anon_sym_xnor] = ACTIONS(5644),
    [anon_sym_buf] = ACTIONS(5644),
    [anon_sym_tranif0] = ACTIONS(5644),
    [anon_sym_tranif1] = ACTIONS(5644),
    [anon_sym_rtranif1] = ACTIONS(5644),
    [anon_sym_rtranif0] = ACTIONS(5644),
    [anon_sym_tran] = ACTIONS(5644),
    [anon_sym_rtran] = ACTIONS(5644),
    [anon_sym_generate] = ACTIONS(5644),
    [anon_sym_for] = ACTIONS(5644),
    [anon_sym_primitive] = ACTIONS(5644),
    [anon_sym_initial] = ACTIONS(5644),
    [anon_sym_assign] = ACTIONS(5644),
    [anon_sym_alias] = ACTIONS(5644),
    [anon_sym_always_comb] = ACTIONS(5644),
    [anon_sym_always_latch] = ACTIONS(5644),
    [anon_sym_always_ff] = ACTIONS(5644),
    [anon_sym_final] = ACTIONS(5644),
    [anon_sym_global] = ACTIONS(5644),
    [anon_sym_specify] = ACTIONS(5644),
    [anon_sym_LPAREN_STAR] = ACTIONS(5642),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5642),
    [anon_sym_DOLLARunit] = ACTIONS(5642),
  },
  [1003] = {
    [ts_builtin_sym_end] = ACTIONS(5646),
    [sym_simple_identifier] = ACTIONS(5648),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5646),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5646),
    [anon_sym_BQUOTE] = ACTIONS(5648),
    [aux_sym_id_directive_token1] = ACTIONS(5646),
    [aux_sym_id_directive_token2] = ACTIONS(5646),
    [aux_sym_id_directive_token3] = ACTIONS(5646),
    [aux_sym_id_directive_token4] = ACTIONS(5648),
    [aux_sym_zero_directive_token1] = ACTIONS(5646),
    [aux_sym_zero_directive_token2] = ACTIONS(5646),
    [aux_sym_zero_directive_token3] = ACTIONS(5646),
    [aux_sym_zero_directive_token4] = ACTIONS(5646),
    [aux_sym_zero_directive_token5] = ACTIONS(5646),
    [aux_sym_zero_directive_token6] = ACTIONS(5646),
    [aux_sym_zero_directive_token7] = ACTIONS(5646),
    [aux_sym_zero_directive_token8] = ACTIONS(5646),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5646),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5646),
    [anon_sym_wire] = ACTIONS(5648),
    [anon_sym_tri] = ACTIONS(5648),
    [anon_sym_tri0] = ACTIONS(5648),
    [anon_sym_tri1] = ACTIONS(5648),
    [anon_sym_wand] = ACTIONS(5648),
    [anon_sym_triand] = ACTIONS(5648),
    [anon_sym_wor] = ACTIONS(5648),
    [anon_sym_trior] = ACTIONS(5648),
    [anon_sym_trireg] = ACTIONS(5648),
    [anon_sym_uwire] = ACTIONS(5648),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5646),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5646),
    [aux_sym_begin_keywords_token1] = ACTIONS(5646),
    [anon_sym_SEMI] = ACTIONS(5646),
    [anon_sym_endmodule] = ACTIONS(5648),
    [anon_sym_COLON] = ACTIONS(5650),
    [anon_sym_extern] = ACTIONS(5648),
    [anon_sym_module] = ACTIONS(5648),
    [anon_sym_macromodule] = ACTIONS(5648),
    [anon_sym_endinterface] = ACTIONS(5648),
    [anon_sym_interface] = ACTIONS(5648),
    [anon_sym_program] = ACTIONS(5648),
    [anon_sym_checker] = ACTIONS(5648),
    [anon_sym_virtual] = ACTIONS(5648),
    [anon_sym_class] = ACTIONS(5648),
    [anon_sym_package] = ACTIONS(5648),
    [anon_sym_timeunit] = ACTIONS(5648),
    [anon_sym_timeprecision] = ACTIONS(5648),
    [anon_sym_type] = ACTIONS(5648),
    [anon_sym_input] = ACTIONS(5648),
    [anon_sym_output] = ACTIONS(5648),
    [anon_sym_inout] = ACTIONS(5648),
    [anon_sym_ref] = ACTIONS(5648),
    [anon_sym_DOLLARfatal] = ACTIONS(5646),
    [anon_sym_DOLLARerror] = ACTIONS(5646),
    [anon_sym_DOLLARwarning] = ACTIONS(5646),
    [anon_sym_DOLLARinfo] = ACTIONS(5646),
    [anon_sym_default] = ACTIONS(5648),
    [anon_sym_clocking] = ACTIONS(5648),
    [anon_sym_defparam] = ACTIONS(5648),
    [anon_sym_bind] = ACTIONS(5648),
    [anon_sym_const] = ACTIONS(5648),
    [anon_sym_function] = ACTIONS(5648),
    [anon_sym_static] = ACTIONS(5648),
    [anon_sym_constraint] = ACTIONS(5648),
    [anon_sym_if] = ACTIONS(5648),
    [anon_sym_LBRACK] = ACTIONS(5646),
    [anon_sym_localparam] = ACTIONS(5648),
    [anon_sym_parameter] = ACTIONS(5648),
    [anon_sym_specparam] = ACTIONS(5648),
    [anon_sym_var] = ACTIONS(5648),
    [anon_sym_import] = ACTIONS(5648),
    [anon_sym_export] = ACTIONS(5648),
    [anon_sym_genvar] = ACTIONS(5648),
    [anon_sym_interconnect] = ACTIONS(5648),
    [anon_sym_typedef] = ACTIONS(5648),
    [anon_sym_enum] = ACTIONS(5648),
    [anon_sym_struct] = ACTIONS(5648),
    [anon_sym_union] = ACTIONS(5648),
    [anon_sym_nettype] = ACTIONS(5648),
    [anon_sym_automatic] = ACTIONS(5648),
    [anon_sym_string] = ACTIONS(5648),
    [anon_sym_chandle] = ACTIONS(5648),
    [anon_sym_event] = ACTIONS(5648),
    [anon_sym_byte] = ACTIONS(5648),
    [anon_sym_shortint] = ACTIONS(5648),
    [anon_sym_int] = ACTIONS(5648),
    [anon_sym_longint] = ACTIONS(5648),
    [anon_sym_integer] = ACTIONS(5648),
    [anon_sym_time] = ACTIONS(5648),
    [anon_sym_bit] = ACTIONS(5648),
    [anon_sym_logic] = ACTIONS(5648),
    [anon_sym_reg] = ACTIONS(5648),
    [anon_sym_shortreal] = ACTIONS(5648),
    [anon_sym_real] = ACTIONS(5648),
    [anon_sym_realtime] = ACTIONS(5648),
    [anon_sym_supply0] = ACTIONS(5648),
    [anon_sym_supply1] = ACTIONS(5648),
    [anon_sym_signed] = ACTIONS(5648),
    [anon_sym_unsigned] = ACTIONS(5648),
    [anon_sym_task] = ACTIONS(5648),
    [anon_sym_modport] = ACTIONS(5648),
    [anon_sym_assert] = ACTIONS(5648),
    [anon_sym_property] = ACTIONS(5648),
    [anon_sym_assume] = ACTIONS(5648),
    [anon_sym_cover] = ACTIONS(5648),
    [anon_sym_sequence] = ACTIONS(5648),
    [anon_sym_restrict] = ACTIONS(5648),
    [anon_sym_not] = ACTIONS(5648),
    [anon_sym_or] = ACTIONS(5648),
    [anon_sym_and] = ACTIONS(5648),
    [anon_sym_case] = ACTIONS(5648),
    [anon_sym_always] = ACTIONS(5648),
    [anon_sym_covergroup] = ACTIONS(5648),
    [anon_sym_let] = ACTIONS(5648),
    [anon_sym_pulldown] = ACTIONS(5648),
    [anon_sym_pullup] = ACTIONS(5648),
    [anon_sym_cmos] = ACTIONS(5648),
    [anon_sym_rcmos] = ACTIONS(5648),
    [anon_sym_bufif0] = ACTIONS(5648),
    [anon_sym_bufif1] = ACTIONS(5648),
    [anon_sym_notif0] = ACTIONS(5648),
    [anon_sym_notif1] = ACTIONS(5648),
    [anon_sym_nmos] = ACTIONS(5648),
    [anon_sym_pmos] = ACTIONS(5648),
    [anon_sym_rnmos] = ACTIONS(5648),
    [anon_sym_rpmos] = ACTIONS(5648),
    [anon_sym_nand] = ACTIONS(5648),
    [anon_sym_nor] = ACTIONS(5648),
    [anon_sym_xor] = ACTIONS(5648),
    [anon_sym_xnor] = ACTIONS(5648),
    [anon_sym_buf] = ACTIONS(5648),
    [anon_sym_tranif0] = ACTIONS(5648),
    [anon_sym_tranif1] = ACTIONS(5648),
    [anon_sym_rtranif1] = ACTIONS(5648),
    [anon_sym_rtranif0] = ACTIONS(5648),
    [anon_sym_tran] = ACTIONS(5648),
    [anon_sym_rtran] = ACTIONS(5648),
    [anon_sym_generate] = ACTIONS(5648),
    [anon_sym_for] = ACTIONS(5648),
    [anon_sym_primitive] = ACTIONS(5648),
    [anon_sym_initial] = ACTIONS(5648),
    [anon_sym_assign] = ACTIONS(5648),
    [anon_sym_alias] = ACTIONS(5648),
    [anon_sym_always_comb] = ACTIONS(5648),
    [anon_sym_always_latch] = ACTIONS(5648),
    [anon_sym_always_ff] = ACTIONS(5648),
    [anon_sym_final] = ACTIONS(5648),
    [anon_sym_global] = ACTIONS(5648),
    [anon_sym_specify] = ACTIONS(5648),
    [anon_sym_LPAREN_STAR] = ACTIONS(5646),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5646),
    [anon_sym_DOLLARunit] = ACTIONS(5646),
  },
  [1004] = {
    [ts_builtin_sym_end] = ACTIONS(5652),
    [sym_simple_identifier] = ACTIONS(5654),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5652),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5652),
    [anon_sym_BQUOTE] = ACTIONS(5654),
    [aux_sym_id_directive_token1] = ACTIONS(5652),
    [aux_sym_id_directive_token2] = ACTIONS(5652),
    [aux_sym_id_directive_token3] = ACTIONS(5652),
    [aux_sym_id_directive_token4] = ACTIONS(5654),
    [aux_sym_zero_directive_token1] = ACTIONS(5652),
    [aux_sym_zero_directive_token2] = ACTIONS(5652),
    [aux_sym_zero_directive_token3] = ACTIONS(5652),
    [aux_sym_zero_directive_token4] = ACTIONS(5652),
    [aux_sym_zero_directive_token5] = ACTIONS(5652),
    [aux_sym_zero_directive_token6] = ACTIONS(5652),
    [aux_sym_zero_directive_token7] = ACTIONS(5652),
    [aux_sym_zero_directive_token8] = ACTIONS(5652),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5652),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5652),
    [anon_sym_wire] = ACTIONS(5654),
    [anon_sym_tri] = ACTIONS(5654),
    [anon_sym_tri0] = ACTIONS(5654),
    [anon_sym_tri1] = ACTIONS(5654),
    [anon_sym_wand] = ACTIONS(5654),
    [anon_sym_triand] = ACTIONS(5654),
    [anon_sym_wor] = ACTIONS(5654),
    [anon_sym_trior] = ACTIONS(5654),
    [anon_sym_trireg] = ACTIONS(5654),
    [anon_sym_uwire] = ACTIONS(5654),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5652),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5652),
    [aux_sym_begin_keywords_token1] = ACTIONS(5652),
    [anon_sym_SEMI] = ACTIONS(5652),
    [anon_sym_endmodule] = ACTIONS(5654),
    [anon_sym_extern] = ACTIONS(5654),
    [anon_sym_module] = ACTIONS(5654),
    [anon_sym_macromodule] = ACTIONS(5654),
    [anon_sym_endinterface] = ACTIONS(5654),
    [anon_sym_interface] = ACTIONS(5654),
    [anon_sym_endprogram] = ACTIONS(5654),
    [anon_sym_program] = ACTIONS(5654),
    [anon_sym_checker] = ACTIONS(5654),
    [anon_sym_virtual] = ACTIONS(5654),
    [anon_sym_class] = ACTIONS(5654),
    [anon_sym_package] = ACTIONS(5654),
    [anon_sym_timeunit] = ACTIONS(5654),
    [anon_sym_timeprecision] = ACTIONS(5654),
    [anon_sym_type] = ACTIONS(5654),
    [anon_sym_input] = ACTIONS(5654),
    [anon_sym_output] = ACTIONS(5654),
    [anon_sym_inout] = ACTIONS(5654),
    [anon_sym_ref] = ACTIONS(5654),
    [anon_sym_DOLLARfatal] = ACTIONS(5652),
    [anon_sym_DOLLARerror] = ACTIONS(5652),
    [anon_sym_DOLLARwarning] = ACTIONS(5652),
    [anon_sym_DOLLARinfo] = ACTIONS(5652),
    [anon_sym_default] = ACTIONS(5654),
    [anon_sym_clocking] = ACTIONS(5654),
    [anon_sym_defparam] = ACTIONS(5654),
    [anon_sym_bind] = ACTIONS(5654),
    [anon_sym_const] = ACTIONS(5654),
    [anon_sym_function] = ACTIONS(5654),
    [anon_sym_static] = ACTIONS(5654),
    [anon_sym_constraint] = ACTIONS(5654),
    [anon_sym_if] = ACTIONS(5654),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_localparam] = ACTIONS(5654),
    [anon_sym_parameter] = ACTIONS(5654),
    [anon_sym_specparam] = ACTIONS(5654),
    [anon_sym_var] = ACTIONS(5654),
    [anon_sym_import] = ACTIONS(5654),
    [anon_sym_export] = ACTIONS(5654),
    [anon_sym_genvar] = ACTIONS(5654),
    [anon_sym_interconnect] = ACTIONS(5654),
    [anon_sym_typedef] = ACTIONS(5654),
    [anon_sym_enum] = ACTIONS(5654),
    [anon_sym_struct] = ACTIONS(5654),
    [anon_sym_union] = ACTIONS(5654),
    [anon_sym_nettype] = ACTIONS(5654),
    [anon_sym_automatic] = ACTIONS(5654),
    [anon_sym_string] = ACTIONS(5654),
    [anon_sym_chandle] = ACTIONS(5654),
    [anon_sym_event] = ACTIONS(5654),
    [anon_sym_byte] = ACTIONS(5654),
    [anon_sym_shortint] = ACTIONS(5654),
    [anon_sym_int] = ACTIONS(5654),
    [anon_sym_longint] = ACTIONS(5654),
    [anon_sym_integer] = ACTIONS(5654),
    [anon_sym_time] = ACTIONS(5654),
    [anon_sym_bit] = ACTIONS(5654),
    [anon_sym_logic] = ACTIONS(5654),
    [anon_sym_reg] = ACTIONS(5654),
    [anon_sym_shortreal] = ACTIONS(5654),
    [anon_sym_real] = ACTIONS(5654),
    [anon_sym_realtime] = ACTIONS(5654),
    [anon_sym_supply0] = ACTIONS(5654),
    [anon_sym_supply1] = ACTIONS(5654),
    [anon_sym_signed] = ACTIONS(5654),
    [anon_sym_unsigned] = ACTIONS(5654),
    [anon_sym_task] = ACTIONS(5654),
    [anon_sym_modport] = ACTIONS(5654),
    [anon_sym_assert] = ACTIONS(5654),
    [anon_sym_property] = ACTIONS(5654),
    [anon_sym_assume] = ACTIONS(5654),
    [anon_sym_cover] = ACTIONS(5654),
    [anon_sym_sequence] = ACTIONS(5654),
    [anon_sym_restrict] = ACTIONS(5654),
    [anon_sym_not] = ACTIONS(5654),
    [anon_sym_or] = ACTIONS(5654),
    [anon_sym_and] = ACTIONS(5654),
    [anon_sym_case] = ACTIONS(5654),
    [anon_sym_always] = ACTIONS(5654),
    [anon_sym_covergroup] = ACTIONS(5654),
    [anon_sym_let] = ACTIONS(5654),
    [anon_sym_pulldown] = ACTIONS(5654),
    [anon_sym_pullup] = ACTIONS(5654),
    [anon_sym_cmos] = ACTIONS(5654),
    [anon_sym_rcmos] = ACTIONS(5654),
    [anon_sym_bufif0] = ACTIONS(5654),
    [anon_sym_bufif1] = ACTIONS(5654),
    [anon_sym_notif0] = ACTIONS(5654),
    [anon_sym_notif1] = ACTIONS(5654),
    [anon_sym_nmos] = ACTIONS(5654),
    [anon_sym_pmos] = ACTIONS(5654),
    [anon_sym_rnmos] = ACTIONS(5654),
    [anon_sym_rpmos] = ACTIONS(5654),
    [anon_sym_nand] = ACTIONS(5654),
    [anon_sym_nor] = ACTIONS(5654),
    [anon_sym_xor] = ACTIONS(5654),
    [anon_sym_xnor] = ACTIONS(5654),
    [anon_sym_buf] = ACTIONS(5654),
    [anon_sym_tranif0] = ACTIONS(5654),
    [anon_sym_tranif1] = ACTIONS(5654),
    [anon_sym_rtranif1] = ACTIONS(5654),
    [anon_sym_rtranif0] = ACTIONS(5654),
    [anon_sym_tran] = ACTIONS(5654),
    [anon_sym_rtran] = ACTIONS(5654),
    [anon_sym_generate] = ACTIONS(5654),
    [anon_sym_for] = ACTIONS(5654),
    [anon_sym_primitive] = ACTIONS(5654),
    [anon_sym_initial] = ACTIONS(5654),
    [anon_sym_assign] = ACTIONS(5654),
    [anon_sym_alias] = ACTIONS(5654),
    [anon_sym_always_comb] = ACTIONS(5654),
    [anon_sym_always_latch] = ACTIONS(5654),
    [anon_sym_always_ff] = ACTIONS(5654),
    [anon_sym_final] = ACTIONS(5654),
    [anon_sym_global] = ACTIONS(5654),
    [anon_sym_specify] = ACTIONS(5654),
    [anon_sym_LPAREN_STAR] = ACTIONS(5652),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5652),
    [anon_sym_DOLLARunit] = ACTIONS(5652),
  },
  [1005] = {
    [ts_builtin_sym_end] = ACTIONS(5656),
    [sym_simple_identifier] = ACTIONS(5658),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5656),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5656),
    [anon_sym_BQUOTE] = ACTIONS(5658),
    [aux_sym_id_directive_token1] = ACTIONS(5656),
    [aux_sym_id_directive_token2] = ACTIONS(5656),
    [aux_sym_id_directive_token3] = ACTIONS(5656),
    [aux_sym_id_directive_token4] = ACTIONS(5658),
    [aux_sym_zero_directive_token1] = ACTIONS(5656),
    [aux_sym_zero_directive_token2] = ACTIONS(5656),
    [aux_sym_zero_directive_token3] = ACTIONS(5656),
    [aux_sym_zero_directive_token4] = ACTIONS(5656),
    [aux_sym_zero_directive_token5] = ACTIONS(5656),
    [aux_sym_zero_directive_token6] = ACTIONS(5656),
    [aux_sym_zero_directive_token7] = ACTIONS(5656),
    [aux_sym_zero_directive_token8] = ACTIONS(5656),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5656),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5656),
    [anon_sym_wire] = ACTIONS(5658),
    [anon_sym_tri] = ACTIONS(5658),
    [anon_sym_tri0] = ACTIONS(5658),
    [anon_sym_tri1] = ACTIONS(5658),
    [anon_sym_wand] = ACTIONS(5658),
    [anon_sym_triand] = ACTIONS(5658),
    [anon_sym_wor] = ACTIONS(5658),
    [anon_sym_trior] = ACTIONS(5658),
    [anon_sym_trireg] = ACTIONS(5658),
    [anon_sym_uwire] = ACTIONS(5658),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5656),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5656),
    [aux_sym_begin_keywords_token1] = ACTIONS(5656),
    [anon_sym_SEMI] = ACTIONS(5656),
    [anon_sym_endmodule] = ACTIONS(5658),
    [anon_sym_extern] = ACTIONS(5658),
    [anon_sym_module] = ACTIONS(5658),
    [anon_sym_macromodule] = ACTIONS(5658),
    [anon_sym_endinterface] = ACTIONS(5658),
    [anon_sym_interface] = ACTIONS(5658),
    [anon_sym_endprogram] = ACTIONS(5658),
    [anon_sym_program] = ACTIONS(5658),
    [anon_sym_checker] = ACTIONS(5658),
    [anon_sym_virtual] = ACTIONS(5658),
    [anon_sym_class] = ACTIONS(5658),
    [anon_sym_package] = ACTIONS(5658),
    [anon_sym_timeunit] = ACTIONS(5658),
    [anon_sym_timeprecision] = ACTIONS(5658),
    [anon_sym_type] = ACTIONS(5658),
    [anon_sym_input] = ACTIONS(5658),
    [anon_sym_output] = ACTIONS(5658),
    [anon_sym_inout] = ACTIONS(5658),
    [anon_sym_ref] = ACTIONS(5658),
    [anon_sym_DOLLARfatal] = ACTIONS(5656),
    [anon_sym_DOLLARerror] = ACTIONS(5656),
    [anon_sym_DOLLARwarning] = ACTIONS(5656),
    [anon_sym_DOLLARinfo] = ACTIONS(5656),
    [anon_sym_default] = ACTIONS(5658),
    [anon_sym_clocking] = ACTIONS(5658),
    [anon_sym_defparam] = ACTIONS(5658),
    [anon_sym_bind] = ACTIONS(5658),
    [anon_sym_const] = ACTIONS(5658),
    [anon_sym_function] = ACTIONS(5658),
    [anon_sym_static] = ACTIONS(5658),
    [anon_sym_constraint] = ACTIONS(5658),
    [anon_sym_if] = ACTIONS(5658),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_localparam] = ACTIONS(5658),
    [anon_sym_parameter] = ACTIONS(5658),
    [anon_sym_specparam] = ACTIONS(5658),
    [anon_sym_var] = ACTIONS(5658),
    [anon_sym_import] = ACTIONS(5658),
    [anon_sym_export] = ACTIONS(5658),
    [anon_sym_genvar] = ACTIONS(5658),
    [anon_sym_interconnect] = ACTIONS(5658),
    [anon_sym_typedef] = ACTIONS(5658),
    [anon_sym_enum] = ACTIONS(5658),
    [anon_sym_struct] = ACTIONS(5658),
    [anon_sym_union] = ACTIONS(5658),
    [anon_sym_nettype] = ACTIONS(5658),
    [anon_sym_automatic] = ACTIONS(5658),
    [anon_sym_string] = ACTIONS(5658),
    [anon_sym_chandle] = ACTIONS(5658),
    [anon_sym_event] = ACTIONS(5658),
    [anon_sym_byte] = ACTIONS(5658),
    [anon_sym_shortint] = ACTIONS(5658),
    [anon_sym_int] = ACTIONS(5658),
    [anon_sym_longint] = ACTIONS(5658),
    [anon_sym_integer] = ACTIONS(5658),
    [anon_sym_time] = ACTIONS(5658),
    [anon_sym_bit] = ACTIONS(5658),
    [anon_sym_logic] = ACTIONS(5658),
    [anon_sym_reg] = ACTIONS(5658),
    [anon_sym_shortreal] = ACTIONS(5658),
    [anon_sym_real] = ACTIONS(5658),
    [anon_sym_realtime] = ACTIONS(5658),
    [anon_sym_supply0] = ACTIONS(5658),
    [anon_sym_supply1] = ACTIONS(5658),
    [anon_sym_signed] = ACTIONS(5658),
    [anon_sym_unsigned] = ACTIONS(5658),
    [anon_sym_task] = ACTIONS(5658),
    [anon_sym_modport] = ACTIONS(5658),
    [anon_sym_assert] = ACTIONS(5658),
    [anon_sym_property] = ACTIONS(5658),
    [anon_sym_assume] = ACTIONS(5658),
    [anon_sym_cover] = ACTIONS(5658),
    [anon_sym_sequence] = ACTIONS(5658),
    [anon_sym_restrict] = ACTIONS(5658),
    [anon_sym_not] = ACTIONS(5658),
    [anon_sym_or] = ACTIONS(5658),
    [anon_sym_and] = ACTIONS(5658),
    [anon_sym_case] = ACTIONS(5658),
    [anon_sym_always] = ACTIONS(5658),
    [anon_sym_covergroup] = ACTIONS(5658),
    [anon_sym_let] = ACTIONS(5658),
    [anon_sym_pulldown] = ACTIONS(5658),
    [anon_sym_pullup] = ACTIONS(5658),
    [anon_sym_cmos] = ACTIONS(5658),
    [anon_sym_rcmos] = ACTIONS(5658),
    [anon_sym_bufif0] = ACTIONS(5658),
    [anon_sym_bufif1] = ACTIONS(5658),
    [anon_sym_notif0] = ACTIONS(5658),
    [anon_sym_notif1] = ACTIONS(5658),
    [anon_sym_nmos] = ACTIONS(5658),
    [anon_sym_pmos] = ACTIONS(5658),
    [anon_sym_rnmos] = ACTIONS(5658),
    [anon_sym_rpmos] = ACTIONS(5658),
    [anon_sym_nand] = ACTIONS(5658),
    [anon_sym_nor] = ACTIONS(5658),
    [anon_sym_xor] = ACTIONS(5658),
    [anon_sym_xnor] = ACTIONS(5658),
    [anon_sym_buf] = ACTIONS(5658),
    [anon_sym_tranif0] = ACTIONS(5658),
    [anon_sym_tranif1] = ACTIONS(5658),
    [anon_sym_rtranif1] = ACTIONS(5658),
    [anon_sym_rtranif0] = ACTIONS(5658),
    [anon_sym_tran] = ACTIONS(5658),
    [anon_sym_rtran] = ACTIONS(5658),
    [anon_sym_generate] = ACTIONS(5658),
    [anon_sym_for] = ACTIONS(5658),
    [anon_sym_primitive] = ACTIONS(5658),
    [anon_sym_initial] = ACTIONS(5658),
    [anon_sym_assign] = ACTIONS(5658),
    [anon_sym_alias] = ACTIONS(5658),
    [anon_sym_always_comb] = ACTIONS(5658),
    [anon_sym_always_latch] = ACTIONS(5658),
    [anon_sym_always_ff] = ACTIONS(5658),
    [anon_sym_final] = ACTIONS(5658),
    [anon_sym_global] = ACTIONS(5658),
    [anon_sym_specify] = ACTIONS(5658),
    [anon_sym_LPAREN_STAR] = ACTIONS(5656),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5656),
    [anon_sym_DOLLARunit] = ACTIONS(5656),
  },
  [1006] = {
    [sym_simple_identifier] = ACTIONS(5660),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5662),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5662),
    [anon_sym_BQUOTE] = ACTIONS(5660),
    [aux_sym_id_directive_token1] = ACTIONS(5662),
    [aux_sym_id_directive_token2] = ACTIONS(5662),
    [aux_sym_id_directive_token3] = ACTIONS(5662),
    [aux_sym_id_directive_token4] = ACTIONS(5660),
    [aux_sym_zero_directive_token1] = ACTIONS(5662),
    [aux_sym_zero_directive_token2] = ACTIONS(5662),
    [aux_sym_zero_directive_token3] = ACTIONS(5662),
    [aux_sym_zero_directive_token4] = ACTIONS(5662),
    [aux_sym_zero_directive_token5] = ACTIONS(5662),
    [aux_sym_zero_directive_token6] = ACTIONS(5662),
    [aux_sym_zero_directive_token7] = ACTIONS(5662),
    [aux_sym_zero_directive_token8] = ACTIONS(5662),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5662),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5662),
    [anon_sym_wire] = ACTIONS(5660),
    [anon_sym_tri] = ACTIONS(5660),
    [anon_sym_tri0] = ACTIONS(5660),
    [anon_sym_tri1] = ACTIONS(5660),
    [anon_sym_wand] = ACTIONS(5660),
    [anon_sym_triand] = ACTIONS(5660),
    [anon_sym_wor] = ACTIONS(5660),
    [anon_sym_trior] = ACTIONS(5660),
    [anon_sym_trireg] = ACTIONS(5660),
    [anon_sym_uwire] = ACTIONS(5660),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5662),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5662),
    [aux_sym_begin_keywords_token1] = ACTIONS(5662),
    [anon_sym_SEMI] = ACTIONS(5662),
    [anon_sym_endmodule] = ACTIONS(5660),
    [anon_sym_COLON] = ACTIONS(5664),
    [anon_sym_extern] = ACTIONS(5660),
    [anon_sym_module] = ACTIONS(5660),
    [anon_sym_macromodule] = ACTIONS(5660),
    [anon_sym_endinterface] = ACTIONS(5660),
    [anon_sym_interface] = ACTIONS(5660),
    [anon_sym_endprogram] = ACTIONS(5660),
    [anon_sym_program] = ACTIONS(5660),
    [anon_sym_checker] = ACTIONS(5660),
    [anon_sym_virtual] = ACTIONS(5660),
    [anon_sym_class] = ACTIONS(5660),
    [anon_sym_timeunit] = ACTIONS(5660),
    [anon_sym_timeprecision] = ACTIONS(5660),
    [anon_sym_type] = ACTIONS(5660),
    [anon_sym_input] = ACTIONS(5660),
    [anon_sym_output] = ACTIONS(5660),
    [anon_sym_inout] = ACTIONS(5660),
    [anon_sym_ref] = ACTIONS(5660),
    [anon_sym_DOLLARfatal] = ACTIONS(5662),
    [anon_sym_DOLLARerror] = ACTIONS(5662),
    [anon_sym_DOLLARwarning] = ACTIONS(5662),
    [anon_sym_DOLLARinfo] = ACTIONS(5662),
    [anon_sym_default] = ACTIONS(5660),
    [anon_sym_clocking] = ACTIONS(5660),
    [anon_sym_defparam] = ACTIONS(5660),
    [anon_sym_bind] = ACTIONS(5660),
    [anon_sym_const] = ACTIONS(5660),
    [anon_sym_function] = ACTIONS(5660),
    [anon_sym_static] = ACTIONS(5660),
    [anon_sym_constraint] = ACTIONS(5660),
    [anon_sym_if] = ACTIONS(5660),
    [anon_sym_else] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5662),
    [anon_sym_localparam] = ACTIONS(5660),
    [anon_sym_parameter] = ACTIONS(5660),
    [anon_sym_specparam] = ACTIONS(5660),
    [anon_sym_var] = ACTIONS(5660),
    [anon_sym_import] = ACTIONS(5660),
    [anon_sym_export] = ACTIONS(5660),
    [anon_sym_genvar] = ACTIONS(5660),
    [anon_sym_interconnect] = ACTIONS(5660),
    [anon_sym_typedef] = ACTIONS(5660),
    [anon_sym_enum] = ACTIONS(5660),
    [anon_sym_struct] = ACTIONS(5660),
    [anon_sym_union] = ACTIONS(5660),
    [anon_sym_nettype] = ACTIONS(5660),
    [anon_sym_automatic] = ACTIONS(5660),
    [anon_sym_string] = ACTIONS(5660),
    [anon_sym_chandle] = ACTIONS(5660),
    [anon_sym_event] = ACTIONS(5660),
    [anon_sym_byte] = ACTIONS(5660),
    [anon_sym_shortint] = ACTIONS(5660),
    [anon_sym_int] = ACTIONS(5660),
    [anon_sym_longint] = ACTIONS(5660),
    [anon_sym_integer] = ACTIONS(5660),
    [anon_sym_time] = ACTIONS(5660),
    [anon_sym_bit] = ACTIONS(5660),
    [anon_sym_logic] = ACTIONS(5660),
    [anon_sym_reg] = ACTIONS(5660),
    [anon_sym_shortreal] = ACTIONS(5660),
    [anon_sym_real] = ACTIONS(5660),
    [anon_sym_realtime] = ACTIONS(5660),
    [anon_sym_supply0] = ACTIONS(5660),
    [anon_sym_supply1] = ACTIONS(5660),
    [anon_sym_signed] = ACTIONS(5660),
    [anon_sym_unsigned] = ACTIONS(5660),
    [anon_sym_task] = ACTIONS(5660),
    [anon_sym_modport] = ACTIONS(5660),
    [anon_sym_assert] = ACTIONS(5660),
    [anon_sym_property] = ACTIONS(5660),
    [anon_sym_assume] = ACTIONS(5660),
    [anon_sym_cover] = ACTIONS(5660),
    [anon_sym_sequence] = ACTIONS(5660),
    [anon_sym_restrict] = ACTIONS(5660),
    [anon_sym_not] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_case] = ACTIONS(5660),
    [anon_sym_always] = ACTIONS(5660),
    [anon_sym_covergroup] = ACTIONS(5660),
    [anon_sym_let] = ACTIONS(5660),
    [anon_sym_pulldown] = ACTIONS(5660),
    [anon_sym_pullup] = ACTIONS(5660),
    [anon_sym_cmos] = ACTIONS(5660),
    [anon_sym_rcmos] = ACTIONS(5660),
    [anon_sym_bufif0] = ACTIONS(5660),
    [anon_sym_bufif1] = ACTIONS(5660),
    [anon_sym_notif0] = ACTIONS(5660),
    [anon_sym_notif1] = ACTIONS(5660),
    [anon_sym_nmos] = ACTIONS(5660),
    [anon_sym_pmos] = ACTIONS(5660),
    [anon_sym_rnmos] = ACTIONS(5660),
    [anon_sym_rpmos] = ACTIONS(5660),
    [anon_sym_nand] = ACTIONS(5660),
    [anon_sym_nor] = ACTIONS(5660),
    [anon_sym_xor] = ACTIONS(5660),
    [anon_sym_xnor] = ACTIONS(5660),
    [anon_sym_buf] = ACTIONS(5660),
    [anon_sym_tranif0] = ACTIONS(5660),
    [anon_sym_tranif1] = ACTIONS(5660),
    [anon_sym_rtranif1] = ACTIONS(5660),
    [anon_sym_rtranif0] = ACTIONS(5660),
    [anon_sym_tran] = ACTIONS(5660),
    [anon_sym_rtran] = ACTIONS(5660),
    [anon_sym_generate] = ACTIONS(5660),
    [anon_sym_for] = ACTIONS(5660),
    [anon_sym_initial] = ACTIONS(5660),
    [anon_sym_assign] = ACTIONS(5660),
    [anon_sym_alias] = ACTIONS(5660),
    [anon_sym_always_comb] = ACTIONS(5660),
    [anon_sym_always_latch] = ACTIONS(5660),
    [anon_sym_always_ff] = ACTIONS(5660),
    [anon_sym_final] = ACTIONS(5660),
    [anon_sym_while] = ACTIONS(5660),
    [anon_sym_global] = ACTIONS(5660),
    [anon_sym_specify] = ACTIONS(5660),
    [anon_sym_LPAREN_STAR] = ACTIONS(5662),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5662),
    [anon_sym_DOLLARunit] = ACTIONS(5662),
  },
  [1007] = {
    [ts_builtin_sym_end] = ACTIONS(5666),
    [sym_simple_identifier] = ACTIONS(5668),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5666),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5666),
    [anon_sym_BQUOTE] = ACTIONS(5668),
    [aux_sym_id_directive_token1] = ACTIONS(5666),
    [aux_sym_id_directive_token2] = ACTIONS(5666),
    [aux_sym_id_directive_token3] = ACTIONS(5666),
    [aux_sym_id_directive_token4] = ACTIONS(5668),
    [aux_sym_zero_directive_token1] = ACTIONS(5666),
    [aux_sym_zero_directive_token2] = ACTIONS(5666),
    [aux_sym_zero_directive_token3] = ACTIONS(5666),
    [aux_sym_zero_directive_token4] = ACTIONS(5666),
    [aux_sym_zero_directive_token5] = ACTIONS(5666),
    [aux_sym_zero_directive_token6] = ACTIONS(5666),
    [aux_sym_zero_directive_token7] = ACTIONS(5666),
    [aux_sym_zero_directive_token8] = ACTIONS(5666),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5666),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5666),
    [anon_sym_wire] = ACTIONS(5668),
    [anon_sym_tri] = ACTIONS(5668),
    [anon_sym_tri0] = ACTIONS(5668),
    [anon_sym_tri1] = ACTIONS(5668),
    [anon_sym_wand] = ACTIONS(5668),
    [anon_sym_triand] = ACTIONS(5668),
    [anon_sym_wor] = ACTIONS(5668),
    [anon_sym_trior] = ACTIONS(5668),
    [anon_sym_trireg] = ACTIONS(5668),
    [anon_sym_uwire] = ACTIONS(5668),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5666),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5666),
    [aux_sym_begin_keywords_token1] = ACTIONS(5666),
    [anon_sym_SEMI] = ACTIONS(5666),
    [anon_sym_endmodule] = ACTIONS(5668),
    [anon_sym_extern] = ACTIONS(5668),
    [anon_sym_module] = ACTIONS(5668),
    [anon_sym_macromodule] = ACTIONS(5668),
    [anon_sym_endinterface] = ACTIONS(5668),
    [anon_sym_interface] = ACTIONS(5668),
    [anon_sym_endprogram] = ACTIONS(5668),
    [anon_sym_program] = ACTIONS(5668),
    [anon_sym_checker] = ACTIONS(5668),
    [anon_sym_virtual] = ACTIONS(5668),
    [anon_sym_class] = ACTIONS(5668),
    [anon_sym_package] = ACTIONS(5668),
    [anon_sym_timeunit] = ACTIONS(5668),
    [anon_sym_timeprecision] = ACTIONS(5668),
    [anon_sym_type] = ACTIONS(5668),
    [anon_sym_input] = ACTIONS(5668),
    [anon_sym_output] = ACTIONS(5668),
    [anon_sym_inout] = ACTIONS(5668),
    [anon_sym_ref] = ACTIONS(5668),
    [anon_sym_DOLLARfatal] = ACTIONS(5666),
    [anon_sym_DOLLARerror] = ACTIONS(5666),
    [anon_sym_DOLLARwarning] = ACTIONS(5666),
    [anon_sym_DOLLARinfo] = ACTIONS(5666),
    [anon_sym_default] = ACTIONS(5668),
    [anon_sym_clocking] = ACTIONS(5668),
    [anon_sym_defparam] = ACTIONS(5668),
    [anon_sym_bind] = ACTIONS(5668),
    [anon_sym_const] = ACTIONS(5668),
    [anon_sym_function] = ACTIONS(5668),
    [anon_sym_static] = ACTIONS(5668),
    [anon_sym_constraint] = ACTIONS(5668),
    [anon_sym_if] = ACTIONS(5668),
    [anon_sym_LBRACK] = ACTIONS(5666),
    [anon_sym_localparam] = ACTIONS(5668),
    [anon_sym_parameter] = ACTIONS(5668),
    [anon_sym_specparam] = ACTIONS(5668),
    [anon_sym_var] = ACTIONS(5668),
    [anon_sym_import] = ACTIONS(5668),
    [anon_sym_export] = ACTIONS(5668),
    [anon_sym_genvar] = ACTIONS(5668),
    [anon_sym_interconnect] = ACTIONS(5668),
    [anon_sym_typedef] = ACTIONS(5668),
    [anon_sym_enum] = ACTIONS(5668),
    [anon_sym_struct] = ACTIONS(5668),
    [anon_sym_union] = ACTIONS(5668),
    [anon_sym_nettype] = ACTIONS(5668),
    [anon_sym_automatic] = ACTIONS(5668),
    [anon_sym_string] = ACTIONS(5668),
    [anon_sym_chandle] = ACTIONS(5668),
    [anon_sym_event] = ACTIONS(5668),
    [anon_sym_byte] = ACTIONS(5668),
    [anon_sym_shortint] = ACTIONS(5668),
    [anon_sym_int] = ACTIONS(5668),
    [anon_sym_longint] = ACTIONS(5668),
    [anon_sym_integer] = ACTIONS(5668),
    [anon_sym_time] = ACTIONS(5668),
    [anon_sym_bit] = ACTIONS(5668),
    [anon_sym_logic] = ACTIONS(5668),
    [anon_sym_reg] = ACTIONS(5668),
    [anon_sym_shortreal] = ACTIONS(5668),
    [anon_sym_real] = ACTIONS(5668),
    [anon_sym_realtime] = ACTIONS(5668),
    [anon_sym_supply0] = ACTIONS(5668),
    [anon_sym_supply1] = ACTIONS(5668),
    [anon_sym_signed] = ACTIONS(5668),
    [anon_sym_unsigned] = ACTIONS(5668),
    [anon_sym_task] = ACTIONS(5668),
    [anon_sym_modport] = ACTIONS(5668),
    [anon_sym_assert] = ACTIONS(5668),
    [anon_sym_property] = ACTIONS(5668),
    [anon_sym_assume] = ACTIONS(5668),
    [anon_sym_cover] = ACTIONS(5668),
    [anon_sym_sequence] = ACTIONS(5668),
    [anon_sym_restrict] = ACTIONS(5668),
    [anon_sym_not] = ACTIONS(5668),
    [anon_sym_or] = ACTIONS(5668),
    [anon_sym_and] = ACTIONS(5668),
    [anon_sym_case] = ACTIONS(5668),
    [anon_sym_always] = ACTIONS(5668),
    [anon_sym_covergroup] = ACTIONS(5668),
    [anon_sym_let] = ACTIONS(5668),
    [anon_sym_pulldown] = ACTIONS(5668),
    [anon_sym_pullup] = ACTIONS(5668),
    [anon_sym_cmos] = ACTIONS(5668),
    [anon_sym_rcmos] = ACTIONS(5668),
    [anon_sym_bufif0] = ACTIONS(5668),
    [anon_sym_bufif1] = ACTIONS(5668),
    [anon_sym_notif0] = ACTIONS(5668),
    [anon_sym_notif1] = ACTIONS(5668),
    [anon_sym_nmos] = ACTIONS(5668),
    [anon_sym_pmos] = ACTIONS(5668),
    [anon_sym_rnmos] = ACTIONS(5668),
    [anon_sym_rpmos] = ACTIONS(5668),
    [anon_sym_nand] = ACTIONS(5668),
    [anon_sym_nor] = ACTIONS(5668),
    [anon_sym_xor] = ACTIONS(5668),
    [anon_sym_xnor] = ACTIONS(5668),
    [anon_sym_buf] = ACTIONS(5668),
    [anon_sym_tranif0] = ACTIONS(5668),
    [anon_sym_tranif1] = ACTIONS(5668),
    [anon_sym_rtranif1] = ACTIONS(5668),
    [anon_sym_rtranif0] = ACTIONS(5668),
    [anon_sym_tran] = ACTIONS(5668),
    [anon_sym_rtran] = ACTIONS(5668),
    [anon_sym_generate] = ACTIONS(5668),
    [anon_sym_for] = ACTIONS(5668),
    [anon_sym_primitive] = ACTIONS(5668),
    [anon_sym_initial] = ACTIONS(5668),
    [anon_sym_assign] = ACTIONS(5668),
    [anon_sym_alias] = ACTIONS(5668),
    [anon_sym_always_comb] = ACTIONS(5668),
    [anon_sym_always_latch] = ACTIONS(5668),
    [anon_sym_always_ff] = ACTIONS(5668),
    [anon_sym_final] = ACTIONS(5668),
    [anon_sym_global] = ACTIONS(5668),
    [anon_sym_specify] = ACTIONS(5668),
    [anon_sym_LPAREN_STAR] = ACTIONS(5666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5666),
    [anon_sym_DOLLARunit] = ACTIONS(5666),
  },
  [1008] = {
    [sym_list_of_ports] = STATE(1275),
    [sym_list_of_port_declarations] = STATE(1288),
    [ts_builtin_sym_end] = ACTIONS(5670),
    [sym_simple_identifier] = ACTIONS(5672),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5670),
    [anon_sym_BQUOTE] = ACTIONS(5672),
    [aux_sym_id_directive_token1] = ACTIONS(5670),
    [aux_sym_id_directive_token2] = ACTIONS(5670),
    [aux_sym_id_directive_token3] = ACTIONS(5670),
    [aux_sym_id_directive_token4] = ACTIONS(5672),
    [aux_sym_zero_directive_token1] = ACTIONS(5670),
    [aux_sym_zero_directive_token2] = ACTIONS(5670),
    [aux_sym_zero_directive_token3] = ACTIONS(5670),
    [aux_sym_zero_directive_token4] = ACTIONS(5670),
    [aux_sym_zero_directive_token5] = ACTIONS(5670),
    [aux_sym_zero_directive_token6] = ACTIONS(5670),
    [aux_sym_zero_directive_token7] = ACTIONS(5670),
    [aux_sym_zero_directive_token8] = ACTIONS(5670),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5670),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5670),
    [anon_sym_wire] = ACTIONS(5672),
    [anon_sym_tri] = ACTIONS(5672),
    [anon_sym_tri0] = ACTIONS(5672),
    [anon_sym_tri1] = ACTIONS(5672),
    [anon_sym_wand] = ACTIONS(5672),
    [anon_sym_triand] = ACTIONS(5672),
    [anon_sym_wor] = ACTIONS(5672),
    [anon_sym_trior] = ACTIONS(5672),
    [anon_sym_trireg] = ACTIONS(5672),
    [anon_sym_uwire] = ACTIONS(5672),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5670),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5670),
    [aux_sym_begin_keywords_token1] = ACTIONS(5670),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_endmodule] = ACTIONS(5672),
    [anon_sym_extern] = ACTIONS(5672),
    [anon_sym_module] = ACTIONS(5672),
    [anon_sym_macromodule] = ACTIONS(5672),
    [anon_sym_interface] = ACTIONS(5672),
    [anon_sym_program] = ACTIONS(5672),
    [anon_sym_checker] = ACTIONS(5672),
    [anon_sym_virtual] = ACTIONS(5672),
    [anon_sym_class] = ACTIONS(5672),
    [anon_sym_package] = ACTIONS(5672),
    [anon_sym_timeunit] = ACTIONS(5672),
    [anon_sym_timeprecision] = ACTIONS(5672),
    [anon_sym_type] = ACTIONS(5672),
    [anon_sym_input] = ACTIONS(5672),
    [anon_sym_output] = ACTIONS(5672),
    [anon_sym_inout] = ACTIONS(5672),
    [anon_sym_ref] = ACTIONS(5672),
    [anon_sym_DOLLARfatal] = ACTIONS(5670),
    [anon_sym_DOLLARerror] = ACTIONS(5670),
    [anon_sym_DOLLARwarning] = ACTIONS(5670),
    [anon_sym_DOLLARinfo] = ACTIONS(5670),
    [anon_sym_default] = ACTIONS(5672),
    [anon_sym_clocking] = ACTIONS(5672),
    [anon_sym_defparam] = ACTIONS(5672),
    [anon_sym_bind] = ACTIONS(5672),
    [anon_sym_const] = ACTIONS(5672),
    [anon_sym_function] = ACTIONS(5672),
    [anon_sym_static] = ACTIONS(5672),
    [anon_sym_constraint] = ACTIONS(5672),
    [anon_sym_if] = ACTIONS(5672),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_localparam] = ACTIONS(5672),
    [anon_sym_parameter] = ACTIONS(5672),
    [anon_sym_specparam] = ACTIONS(5672),
    [anon_sym_var] = ACTIONS(5672),
    [anon_sym_import] = ACTIONS(5672),
    [anon_sym_export] = ACTIONS(5672),
    [anon_sym_genvar] = ACTIONS(5672),
    [anon_sym_interconnect] = ACTIONS(5672),
    [anon_sym_typedef] = ACTIONS(5672),
    [anon_sym_enum] = ACTIONS(5672),
    [anon_sym_struct] = ACTIONS(5672),
    [anon_sym_union] = ACTIONS(5672),
    [anon_sym_nettype] = ACTIONS(5672),
    [anon_sym_automatic] = ACTIONS(5672),
    [anon_sym_string] = ACTIONS(5672),
    [anon_sym_chandle] = ACTIONS(5672),
    [anon_sym_event] = ACTIONS(5672),
    [anon_sym_byte] = ACTIONS(5672),
    [anon_sym_shortint] = ACTIONS(5672),
    [anon_sym_int] = ACTIONS(5672),
    [anon_sym_longint] = ACTIONS(5672),
    [anon_sym_integer] = ACTIONS(5672),
    [anon_sym_time] = ACTIONS(5672),
    [anon_sym_bit] = ACTIONS(5672),
    [anon_sym_logic] = ACTIONS(5672),
    [anon_sym_reg] = ACTIONS(5672),
    [anon_sym_shortreal] = ACTIONS(5672),
    [anon_sym_real] = ACTIONS(5672),
    [anon_sym_realtime] = ACTIONS(5672),
    [anon_sym_supply0] = ACTIONS(5672),
    [anon_sym_supply1] = ACTIONS(5672),
    [anon_sym_signed] = ACTIONS(5672),
    [anon_sym_unsigned] = ACTIONS(5672),
    [anon_sym_task] = ACTIONS(5672),
    [anon_sym_assert] = ACTIONS(5672),
    [anon_sym_property] = ACTIONS(5672),
    [anon_sym_assume] = ACTIONS(5672),
    [anon_sym_cover] = ACTIONS(5672),
    [anon_sym_sequence] = ACTIONS(5672),
    [anon_sym_restrict] = ACTIONS(5672),
    [anon_sym_not] = ACTIONS(5672),
    [anon_sym_or] = ACTIONS(5672),
    [anon_sym_and] = ACTIONS(5672),
    [anon_sym_case] = ACTIONS(5672),
    [anon_sym_always] = ACTIONS(5672),
    [anon_sym_covergroup] = ACTIONS(5672),
    [anon_sym_let] = ACTIONS(5672),
    [anon_sym_pulldown] = ACTIONS(5672),
    [anon_sym_pullup] = ACTIONS(5672),
    [anon_sym_cmos] = ACTIONS(5672),
    [anon_sym_rcmos] = ACTIONS(5672),
    [anon_sym_bufif0] = ACTIONS(5672),
    [anon_sym_bufif1] = ACTIONS(5672),
    [anon_sym_notif0] = ACTIONS(5672),
    [anon_sym_notif1] = ACTIONS(5672),
    [anon_sym_nmos] = ACTIONS(5672),
    [anon_sym_pmos] = ACTIONS(5672),
    [anon_sym_rnmos] = ACTIONS(5672),
    [anon_sym_rpmos] = ACTIONS(5672),
    [anon_sym_nand] = ACTIONS(5672),
    [anon_sym_nor] = ACTIONS(5672),
    [anon_sym_xor] = ACTIONS(5672),
    [anon_sym_xnor] = ACTIONS(5672),
    [anon_sym_buf] = ACTIONS(5672),
    [anon_sym_tranif0] = ACTIONS(5672),
    [anon_sym_tranif1] = ACTIONS(5672),
    [anon_sym_rtranif1] = ACTIONS(5672),
    [anon_sym_rtranif0] = ACTIONS(5672),
    [anon_sym_tran] = ACTIONS(5672),
    [anon_sym_rtran] = ACTIONS(5672),
    [anon_sym_generate] = ACTIONS(5672),
    [anon_sym_for] = ACTIONS(5672),
    [anon_sym_primitive] = ACTIONS(5672),
    [anon_sym_initial] = ACTIONS(5672),
    [anon_sym_assign] = ACTIONS(5672),
    [anon_sym_alias] = ACTIONS(5672),
    [anon_sym_always_comb] = ACTIONS(5672),
    [anon_sym_always_latch] = ACTIONS(5672),
    [anon_sym_always_ff] = ACTIONS(5672),
    [anon_sym_final] = ACTIONS(5672),
    [anon_sym_global] = ACTIONS(5672),
    [anon_sym_specify] = ACTIONS(5672),
    [anon_sym_LPAREN_STAR] = ACTIONS(5670),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5670),
    [anon_sym_DOLLARunit] = ACTIONS(5670),
  },
  [1009] = {
    [ts_builtin_sym_end] = ACTIONS(5676),
    [sym_simple_identifier] = ACTIONS(5678),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5676),
    [anon_sym_BQUOTE] = ACTIONS(5678),
    [aux_sym_id_directive_token1] = ACTIONS(5676),
    [aux_sym_id_directive_token2] = ACTIONS(5676),
    [aux_sym_id_directive_token3] = ACTIONS(5676),
    [aux_sym_id_directive_token4] = ACTIONS(5678),
    [aux_sym_zero_directive_token1] = ACTIONS(5676),
    [aux_sym_zero_directive_token2] = ACTIONS(5676),
    [aux_sym_zero_directive_token3] = ACTIONS(5676),
    [aux_sym_zero_directive_token4] = ACTIONS(5676),
    [aux_sym_zero_directive_token5] = ACTIONS(5676),
    [aux_sym_zero_directive_token6] = ACTIONS(5676),
    [aux_sym_zero_directive_token7] = ACTIONS(5676),
    [aux_sym_zero_directive_token8] = ACTIONS(5676),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5676),
    [anon_sym_wire] = ACTIONS(5678),
    [anon_sym_tri] = ACTIONS(5678),
    [anon_sym_tri0] = ACTIONS(5678),
    [anon_sym_tri1] = ACTIONS(5678),
    [anon_sym_wand] = ACTIONS(5678),
    [anon_sym_triand] = ACTIONS(5678),
    [anon_sym_wor] = ACTIONS(5678),
    [anon_sym_trior] = ACTIONS(5678),
    [anon_sym_trireg] = ACTIONS(5678),
    [anon_sym_uwire] = ACTIONS(5678),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5676),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_begin_keywords_token1] = ACTIONS(5676),
    [anon_sym_SEMI] = ACTIONS(5676),
    [anon_sym_endmodule] = ACTIONS(5678),
    [anon_sym_COLON] = ACTIONS(5680),
    [anon_sym_extern] = ACTIONS(5678),
    [anon_sym_module] = ACTIONS(5678),
    [anon_sym_macromodule] = ACTIONS(5678),
    [anon_sym_endinterface] = ACTIONS(5678),
    [anon_sym_interface] = ACTIONS(5678),
    [anon_sym_program] = ACTIONS(5678),
    [anon_sym_checker] = ACTIONS(5678),
    [anon_sym_virtual] = ACTIONS(5678),
    [anon_sym_class] = ACTIONS(5678),
    [anon_sym_package] = ACTIONS(5678),
    [anon_sym_timeunit] = ACTIONS(5678),
    [anon_sym_timeprecision] = ACTIONS(5678),
    [anon_sym_type] = ACTIONS(5678),
    [anon_sym_input] = ACTIONS(5678),
    [anon_sym_output] = ACTIONS(5678),
    [anon_sym_inout] = ACTIONS(5678),
    [anon_sym_ref] = ACTIONS(5678),
    [anon_sym_DOLLARfatal] = ACTIONS(5676),
    [anon_sym_DOLLARerror] = ACTIONS(5676),
    [anon_sym_DOLLARwarning] = ACTIONS(5676),
    [anon_sym_DOLLARinfo] = ACTIONS(5676),
    [anon_sym_default] = ACTIONS(5678),
    [anon_sym_clocking] = ACTIONS(5678),
    [anon_sym_defparam] = ACTIONS(5678),
    [anon_sym_bind] = ACTIONS(5678),
    [anon_sym_const] = ACTIONS(5678),
    [anon_sym_function] = ACTIONS(5678),
    [anon_sym_static] = ACTIONS(5678),
    [anon_sym_constraint] = ACTIONS(5678),
    [anon_sym_if] = ACTIONS(5678),
    [anon_sym_LBRACK] = ACTIONS(5676),
    [anon_sym_localparam] = ACTIONS(5678),
    [anon_sym_parameter] = ACTIONS(5678),
    [anon_sym_specparam] = ACTIONS(5678),
    [anon_sym_var] = ACTIONS(5678),
    [anon_sym_import] = ACTIONS(5678),
    [anon_sym_export] = ACTIONS(5678),
    [anon_sym_genvar] = ACTIONS(5678),
    [anon_sym_interconnect] = ACTIONS(5678),
    [anon_sym_typedef] = ACTIONS(5678),
    [anon_sym_enum] = ACTIONS(5678),
    [anon_sym_struct] = ACTIONS(5678),
    [anon_sym_union] = ACTIONS(5678),
    [anon_sym_nettype] = ACTIONS(5678),
    [anon_sym_automatic] = ACTIONS(5678),
    [anon_sym_string] = ACTIONS(5678),
    [anon_sym_chandle] = ACTIONS(5678),
    [anon_sym_event] = ACTIONS(5678),
    [anon_sym_byte] = ACTIONS(5678),
    [anon_sym_shortint] = ACTIONS(5678),
    [anon_sym_int] = ACTIONS(5678),
    [anon_sym_longint] = ACTIONS(5678),
    [anon_sym_integer] = ACTIONS(5678),
    [anon_sym_time] = ACTIONS(5678),
    [anon_sym_bit] = ACTIONS(5678),
    [anon_sym_logic] = ACTIONS(5678),
    [anon_sym_reg] = ACTIONS(5678),
    [anon_sym_shortreal] = ACTIONS(5678),
    [anon_sym_real] = ACTIONS(5678),
    [anon_sym_realtime] = ACTIONS(5678),
    [anon_sym_supply0] = ACTIONS(5678),
    [anon_sym_supply1] = ACTIONS(5678),
    [anon_sym_signed] = ACTIONS(5678),
    [anon_sym_unsigned] = ACTIONS(5678),
    [anon_sym_task] = ACTIONS(5678),
    [anon_sym_modport] = ACTIONS(5678),
    [anon_sym_assert] = ACTIONS(5678),
    [anon_sym_property] = ACTIONS(5678),
    [anon_sym_assume] = ACTIONS(5678),
    [anon_sym_cover] = ACTIONS(5678),
    [anon_sym_sequence] = ACTIONS(5678),
    [anon_sym_restrict] = ACTIONS(5678),
    [anon_sym_not] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_case] = ACTIONS(5678),
    [anon_sym_always] = ACTIONS(5678),
    [anon_sym_covergroup] = ACTIONS(5678),
    [anon_sym_let] = ACTIONS(5678),
    [anon_sym_pulldown] = ACTIONS(5678),
    [anon_sym_pullup] = ACTIONS(5678),
    [anon_sym_cmos] = ACTIONS(5678),
    [anon_sym_rcmos] = ACTIONS(5678),
    [anon_sym_bufif0] = ACTIONS(5678),
    [anon_sym_bufif1] = ACTIONS(5678),
    [anon_sym_notif0] = ACTIONS(5678),
    [anon_sym_notif1] = ACTIONS(5678),
    [anon_sym_nmos] = ACTIONS(5678),
    [anon_sym_pmos] = ACTIONS(5678),
    [anon_sym_rnmos] = ACTIONS(5678),
    [anon_sym_rpmos] = ACTIONS(5678),
    [anon_sym_nand] = ACTIONS(5678),
    [anon_sym_nor] = ACTIONS(5678),
    [anon_sym_xor] = ACTIONS(5678),
    [anon_sym_xnor] = ACTIONS(5678),
    [anon_sym_buf] = ACTIONS(5678),
    [anon_sym_tranif0] = ACTIONS(5678),
    [anon_sym_tranif1] = ACTIONS(5678),
    [anon_sym_rtranif1] = ACTIONS(5678),
    [anon_sym_rtranif0] = ACTIONS(5678),
    [anon_sym_tran] = ACTIONS(5678),
    [anon_sym_rtran] = ACTIONS(5678),
    [anon_sym_generate] = ACTIONS(5678),
    [anon_sym_for] = ACTIONS(5678),
    [anon_sym_primitive] = ACTIONS(5678),
    [anon_sym_initial] = ACTIONS(5678),
    [anon_sym_assign] = ACTIONS(5678),
    [anon_sym_alias] = ACTIONS(5678),
    [anon_sym_always_comb] = ACTIONS(5678),
    [anon_sym_always_latch] = ACTIONS(5678),
    [anon_sym_always_ff] = ACTIONS(5678),
    [anon_sym_final] = ACTIONS(5678),
    [anon_sym_global] = ACTIONS(5678),
    [anon_sym_specify] = ACTIONS(5678),
    [anon_sym_LPAREN_STAR] = ACTIONS(5676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5676),
    [anon_sym_DOLLARunit] = ACTIONS(5676),
  },
  [1010] = {
    [sym_simple_identifier] = ACTIONS(5682),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5684),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5684),
    [anon_sym_BQUOTE] = ACTIONS(5682),
    [aux_sym_id_directive_token1] = ACTIONS(5684),
    [aux_sym_id_directive_token2] = ACTIONS(5684),
    [aux_sym_id_directive_token3] = ACTIONS(5684),
    [aux_sym_id_directive_token4] = ACTIONS(5682),
    [aux_sym_zero_directive_token1] = ACTIONS(5684),
    [aux_sym_zero_directive_token2] = ACTIONS(5684),
    [aux_sym_zero_directive_token3] = ACTIONS(5684),
    [aux_sym_zero_directive_token4] = ACTIONS(5684),
    [aux_sym_zero_directive_token5] = ACTIONS(5684),
    [aux_sym_zero_directive_token6] = ACTIONS(5684),
    [aux_sym_zero_directive_token7] = ACTIONS(5684),
    [aux_sym_zero_directive_token8] = ACTIONS(5684),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5684),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5684),
    [anon_sym_wire] = ACTIONS(5682),
    [anon_sym_tri] = ACTIONS(5682),
    [anon_sym_tri0] = ACTIONS(5682),
    [anon_sym_tri1] = ACTIONS(5682),
    [anon_sym_wand] = ACTIONS(5682),
    [anon_sym_triand] = ACTIONS(5682),
    [anon_sym_wor] = ACTIONS(5682),
    [anon_sym_trior] = ACTIONS(5682),
    [anon_sym_trireg] = ACTIONS(5682),
    [anon_sym_uwire] = ACTIONS(5682),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5684),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5684),
    [aux_sym_begin_keywords_token1] = ACTIONS(5684),
    [anon_sym_SEMI] = ACTIONS(5684),
    [anon_sym_endmodule] = ACTIONS(5682),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5682),
    [anon_sym_module] = ACTIONS(5682),
    [anon_sym_macromodule] = ACTIONS(5682),
    [anon_sym_endinterface] = ACTIONS(5682),
    [anon_sym_interface] = ACTIONS(5682),
    [anon_sym_endprogram] = ACTIONS(5682),
    [anon_sym_program] = ACTIONS(5682),
    [anon_sym_checker] = ACTIONS(5682),
    [anon_sym_virtual] = ACTIONS(5682),
    [anon_sym_class] = ACTIONS(5682),
    [anon_sym_timeunit] = ACTIONS(5682),
    [anon_sym_timeprecision] = ACTIONS(5682),
    [anon_sym_type] = ACTIONS(5682),
    [anon_sym_input] = ACTIONS(5682),
    [anon_sym_output] = ACTIONS(5682),
    [anon_sym_inout] = ACTIONS(5682),
    [anon_sym_ref] = ACTIONS(5682),
    [anon_sym_DOLLARfatal] = ACTIONS(5684),
    [anon_sym_DOLLARerror] = ACTIONS(5684),
    [anon_sym_DOLLARwarning] = ACTIONS(5684),
    [anon_sym_DOLLARinfo] = ACTIONS(5684),
    [anon_sym_default] = ACTIONS(5682),
    [anon_sym_clocking] = ACTIONS(5682),
    [anon_sym_defparam] = ACTIONS(5682),
    [anon_sym_bind] = ACTIONS(5682),
    [anon_sym_const] = ACTIONS(5682),
    [anon_sym_function] = ACTIONS(5682),
    [anon_sym_static] = ACTIONS(5682),
    [anon_sym_constraint] = ACTIONS(5682),
    [anon_sym_if] = ACTIONS(5682),
    [anon_sym_else] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_localparam] = ACTIONS(5682),
    [anon_sym_parameter] = ACTIONS(5682),
    [anon_sym_specparam] = ACTIONS(5682),
    [anon_sym_var] = ACTIONS(5682),
    [anon_sym_import] = ACTIONS(5682),
    [anon_sym_export] = ACTIONS(5682),
    [anon_sym_genvar] = ACTIONS(5682),
    [anon_sym_interconnect] = ACTIONS(5682),
    [anon_sym_typedef] = ACTIONS(5682),
    [anon_sym_enum] = ACTIONS(5682),
    [anon_sym_struct] = ACTIONS(5682),
    [anon_sym_union] = ACTIONS(5682),
    [anon_sym_nettype] = ACTIONS(5682),
    [anon_sym_automatic] = ACTIONS(5682),
    [anon_sym_string] = ACTIONS(5682),
    [anon_sym_chandle] = ACTIONS(5682),
    [anon_sym_event] = ACTIONS(5682),
    [anon_sym_byte] = ACTIONS(5682),
    [anon_sym_shortint] = ACTIONS(5682),
    [anon_sym_int] = ACTIONS(5682),
    [anon_sym_longint] = ACTIONS(5682),
    [anon_sym_integer] = ACTIONS(5682),
    [anon_sym_time] = ACTIONS(5682),
    [anon_sym_bit] = ACTIONS(5682),
    [anon_sym_logic] = ACTIONS(5682),
    [anon_sym_reg] = ACTIONS(5682),
    [anon_sym_shortreal] = ACTIONS(5682),
    [anon_sym_real] = ACTIONS(5682),
    [anon_sym_realtime] = ACTIONS(5682),
    [anon_sym_supply0] = ACTIONS(5682),
    [anon_sym_supply1] = ACTIONS(5682),
    [anon_sym_signed] = ACTIONS(5682),
    [anon_sym_unsigned] = ACTIONS(5682),
    [anon_sym_task] = ACTIONS(5682),
    [anon_sym_modport] = ACTIONS(5682),
    [anon_sym_assert] = ACTIONS(5682),
    [anon_sym_property] = ACTIONS(5682),
    [anon_sym_assume] = ACTIONS(5682),
    [anon_sym_cover] = ACTIONS(5682),
    [anon_sym_sequence] = ACTIONS(5682),
    [anon_sym_restrict] = ACTIONS(5682),
    [anon_sym_not] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_case] = ACTIONS(5682),
    [anon_sym_always] = ACTIONS(5682),
    [anon_sym_covergroup] = ACTIONS(5682),
    [anon_sym_let] = ACTIONS(5682),
    [anon_sym_pulldown] = ACTIONS(5682),
    [anon_sym_pullup] = ACTIONS(5682),
    [anon_sym_cmos] = ACTIONS(5682),
    [anon_sym_rcmos] = ACTIONS(5682),
    [anon_sym_bufif0] = ACTIONS(5682),
    [anon_sym_bufif1] = ACTIONS(5682),
    [anon_sym_notif0] = ACTIONS(5682),
    [anon_sym_notif1] = ACTIONS(5682),
    [anon_sym_nmos] = ACTIONS(5682),
    [anon_sym_pmos] = ACTIONS(5682),
    [anon_sym_rnmos] = ACTIONS(5682),
    [anon_sym_rpmos] = ACTIONS(5682),
    [anon_sym_nand] = ACTIONS(5682),
    [anon_sym_nor] = ACTIONS(5682),
    [anon_sym_xor] = ACTIONS(5682),
    [anon_sym_xnor] = ACTIONS(5682),
    [anon_sym_buf] = ACTIONS(5682),
    [anon_sym_tranif0] = ACTIONS(5682),
    [anon_sym_tranif1] = ACTIONS(5682),
    [anon_sym_rtranif1] = ACTIONS(5682),
    [anon_sym_rtranif0] = ACTIONS(5682),
    [anon_sym_tran] = ACTIONS(5682),
    [anon_sym_rtran] = ACTIONS(5682),
    [anon_sym_generate] = ACTIONS(5682),
    [anon_sym_for] = ACTIONS(5682),
    [anon_sym_initial] = ACTIONS(5682),
    [anon_sym_assign] = ACTIONS(5682),
    [anon_sym_alias] = ACTIONS(5682),
    [anon_sym_always_comb] = ACTIONS(5682),
    [anon_sym_always_latch] = ACTIONS(5682),
    [anon_sym_always_ff] = ACTIONS(5682),
    [anon_sym_final] = ACTIONS(5682),
    [anon_sym_while] = ACTIONS(5682),
    [anon_sym_global] = ACTIONS(5682),
    [anon_sym_specify] = ACTIONS(5682),
    [anon_sym_LPAREN_STAR] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5684),
    [anon_sym_DOLLARunit] = ACTIONS(5684),
  },
  [1011] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9008),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(2648),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_dist] = ACTIONS(2644),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1012] = {
    [sym_simple_identifier] = ACTIONS(5688),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5690),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5690),
    [anon_sym_BQUOTE] = ACTIONS(5688),
    [aux_sym_id_directive_token1] = ACTIONS(5690),
    [aux_sym_id_directive_token2] = ACTIONS(5690),
    [aux_sym_id_directive_token3] = ACTIONS(5690),
    [aux_sym_id_directive_token4] = ACTIONS(5688),
    [aux_sym_zero_directive_token1] = ACTIONS(5690),
    [aux_sym_zero_directive_token2] = ACTIONS(5690),
    [aux_sym_zero_directive_token3] = ACTIONS(5690),
    [aux_sym_zero_directive_token4] = ACTIONS(5690),
    [aux_sym_zero_directive_token5] = ACTIONS(5690),
    [aux_sym_zero_directive_token6] = ACTIONS(5690),
    [aux_sym_zero_directive_token7] = ACTIONS(5690),
    [aux_sym_zero_directive_token8] = ACTIONS(5690),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5690),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5690),
    [anon_sym_wire] = ACTIONS(5688),
    [anon_sym_tri] = ACTIONS(5688),
    [anon_sym_tri0] = ACTIONS(5688),
    [anon_sym_tri1] = ACTIONS(5688),
    [anon_sym_wand] = ACTIONS(5688),
    [anon_sym_triand] = ACTIONS(5688),
    [anon_sym_wor] = ACTIONS(5688),
    [anon_sym_trior] = ACTIONS(5688),
    [anon_sym_trireg] = ACTIONS(5688),
    [anon_sym_uwire] = ACTIONS(5688),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5690),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5690),
    [aux_sym_begin_keywords_token1] = ACTIONS(5690),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym_endmodule] = ACTIONS(5688),
    [anon_sym_COLON] = ACTIONS(5692),
    [anon_sym_extern] = ACTIONS(5688),
    [anon_sym_module] = ACTIONS(5688),
    [anon_sym_macromodule] = ACTIONS(5688),
    [anon_sym_endinterface] = ACTIONS(5688),
    [anon_sym_interface] = ACTIONS(5688),
    [anon_sym_endprogram] = ACTIONS(5688),
    [anon_sym_program] = ACTIONS(5688),
    [anon_sym_checker] = ACTIONS(5688),
    [anon_sym_virtual] = ACTIONS(5688),
    [anon_sym_class] = ACTIONS(5688),
    [anon_sym_timeunit] = ACTIONS(5688),
    [anon_sym_timeprecision] = ACTIONS(5688),
    [anon_sym_type] = ACTIONS(5688),
    [anon_sym_input] = ACTIONS(5688),
    [anon_sym_output] = ACTIONS(5688),
    [anon_sym_inout] = ACTIONS(5688),
    [anon_sym_ref] = ACTIONS(5688),
    [anon_sym_DOLLARfatal] = ACTIONS(5690),
    [anon_sym_DOLLARerror] = ACTIONS(5690),
    [anon_sym_DOLLARwarning] = ACTIONS(5690),
    [anon_sym_DOLLARinfo] = ACTIONS(5690),
    [anon_sym_default] = ACTIONS(5688),
    [anon_sym_clocking] = ACTIONS(5688),
    [anon_sym_defparam] = ACTIONS(5688),
    [anon_sym_bind] = ACTIONS(5688),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_function] = ACTIONS(5688),
    [anon_sym_static] = ACTIONS(5688),
    [anon_sym_constraint] = ACTIONS(5688),
    [anon_sym_if] = ACTIONS(5688),
    [anon_sym_else] = ACTIONS(5688),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_localparam] = ACTIONS(5688),
    [anon_sym_parameter] = ACTIONS(5688),
    [anon_sym_specparam] = ACTIONS(5688),
    [anon_sym_var] = ACTIONS(5688),
    [anon_sym_import] = ACTIONS(5688),
    [anon_sym_export] = ACTIONS(5688),
    [anon_sym_genvar] = ACTIONS(5688),
    [anon_sym_interconnect] = ACTIONS(5688),
    [anon_sym_typedef] = ACTIONS(5688),
    [anon_sym_enum] = ACTIONS(5688),
    [anon_sym_struct] = ACTIONS(5688),
    [anon_sym_union] = ACTIONS(5688),
    [anon_sym_nettype] = ACTIONS(5688),
    [anon_sym_automatic] = ACTIONS(5688),
    [anon_sym_string] = ACTIONS(5688),
    [anon_sym_chandle] = ACTIONS(5688),
    [anon_sym_event] = ACTIONS(5688),
    [anon_sym_byte] = ACTIONS(5688),
    [anon_sym_shortint] = ACTIONS(5688),
    [anon_sym_int] = ACTIONS(5688),
    [anon_sym_longint] = ACTIONS(5688),
    [anon_sym_integer] = ACTIONS(5688),
    [anon_sym_time] = ACTIONS(5688),
    [anon_sym_bit] = ACTIONS(5688),
    [anon_sym_logic] = ACTIONS(5688),
    [anon_sym_reg] = ACTIONS(5688),
    [anon_sym_shortreal] = ACTIONS(5688),
    [anon_sym_real] = ACTIONS(5688),
    [anon_sym_realtime] = ACTIONS(5688),
    [anon_sym_supply0] = ACTIONS(5688),
    [anon_sym_supply1] = ACTIONS(5688),
    [anon_sym_signed] = ACTIONS(5688),
    [anon_sym_unsigned] = ACTIONS(5688),
    [anon_sym_task] = ACTIONS(5688),
    [anon_sym_modport] = ACTIONS(5688),
    [anon_sym_assert] = ACTIONS(5688),
    [anon_sym_property] = ACTIONS(5688),
    [anon_sym_assume] = ACTIONS(5688),
    [anon_sym_cover] = ACTIONS(5688),
    [anon_sym_sequence] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym_not] = ACTIONS(5688),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_case] = ACTIONS(5688),
    [anon_sym_always] = ACTIONS(5688),
    [anon_sym_covergroup] = ACTIONS(5688),
    [anon_sym_let] = ACTIONS(5688),
    [anon_sym_pulldown] = ACTIONS(5688),
    [anon_sym_pullup] = ACTIONS(5688),
    [anon_sym_cmos] = ACTIONS(5688),
    [anon_sym_rcmos] = ACTIONS(5688),
    [anon_sym_bufif0] = ACTIONS(5688),
    [anon_sym_bufif1] = ACTIONS(5688),
    [anon_sym_notif0] = ACTIONS(5688),
    [anon_sym_notif1] = ACTIONS(5688),
    [anon_sym_nmos] = ACTIONS(5688),
    [anon_sym_pmos] = ACTIONS(5688),
    [anon_sym_rnmos] = ACTIONS(5688),
    [anon_sym_rpmos] = ACTIONS(5688),
    [anon_sym_nand] = ACTIONS(5688),
    [anon_sym_nor] = ACTIONS(5688),
    [anon_sym_xor] = ACTIONS(5688),
    [anon_sym_xnor] = ACTIONS(5688),
    [anon_sym_buf] = ACTIONS(5688),
    [anon_sym_tranif0] = ACTIONS(5688),
    [anon_sym_tranif1] = ACTIONS(5688),
    [anon_sym_rtranif1] = ACTIONS(5688),
    [anon_sym_rtranif0] = ACTIONS(5688),
    [anon_sym_tran] = ACTIONS(5688),
    [anon_sym_rtran] = ACTIONS(5688),
    [anon_sym_generate] = ACTIONS(5688),
    [anon_sym_for] = ACTIONS(5688),
    [anon_sym_initial] = ACTIONS(5688),
    [anon_sym_assign] = ACTIONS(5688),
    [anon_sym_alias] = ACTIONS(5688),
    [anon_sym_always_comb] = ACTIONS(5688),
    [anon_sym_always_latch] = ACTIONS(5688),
    [anon_sym_always_ff] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_while] = ACTIONS(5688),
    [anon_sym_global] = ACTIONS(5688),
    [anon_sym_specify] = ACTIONS(5688),
    [anon_sym_LPAREN_STAR] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5690),
    [anon_sym_DOLLARunit] = ACTIONS(5690),
  },
  [1013] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5696),
    [anon_sym_BQUOTE] = ACTIONS(5694),
    [aux_sym_id_directive_token1] = ACTIONS(5696),
    [aux_sym_id_directive_token2] = ACTIONS(5696),
    [aux_sym_id_directive_token3] = ACTIONS(5696),
    [aux_sym_id_directive_token4] = ACTIONS(5694),
    [aux_sym_zero_directive_token1] = ACTIONS(5696),
    [aux_sym_zero_directive_token2] = ACTIONS(5696),
    [aux_sym_zero_directive_token3] = ACTIONS(5696),
    [aux_sym_zero_directive_token4] = ACTIONS(5696),
    [aux_sym_zero_directive_token5] = ACTIONS(5696),
    [aux_sym_zero_directive_token6] = ACTIONS(5696),
    [aux_sym_zero_directive_token7] = ACTIONS(5696),
    [aux_sym_zero_directive_token8] = ACTIONS(5696),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5696),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5696),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_begin_keywords_token1] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_endmodule] = ACTIONS(5694),
    [anon_sym_COLON] = ACTIONS(5698),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_module] = ACTIONS(5694),
    [anon_sym_macromodule] = ACTIONS(5694),
    [anon_sym_endinterface] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_endprogram] = ACTIONS(5694),
    [anon_sym_program] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_timeunit] = ACTIONS(5694),
    [anon_sym_timeprecision] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_input] = ACTIONS(5694),
    [anon_sym_output] = ACTIONS(5694),
    [anon_sym_inout] = ACTIONS(5694),
    [anon_sym_ref] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_specparam] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_modport] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_while] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_specify] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [1014] = {
    [sym_list_of_ports] = STATE(1287),
    [sym_list_of_port_declarations] = STATE(1289),
    [ts_builtin_sym_end] = ACTIONS(5700),
    [sym_simple_identifier] = ACTIONS(5702),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5700),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5700),
    [anon_sym_BQUOTE] = ACTIONS(5702),
    [aux_sym_id_directive_token1] = ACTIONS(5700),
    [aux_sym_id_directive_token2] = ACTIONS(5700),
    [aux_sym_id_directive_token3] = ACTIONS(5700),
    [aux_sym_id_directive_token4] = ACTIONS(5702),
    [aux_sym_zero_directive_token1] = ACTIONS(5700),
    [aux_sym_zero_directive_token2] = ACTIONS(5700),
    [aux_sym_zero_directive_token3] = ACTIONS(5700),
    [aux_sym_zero_directive_token4] = ACTIONS(5700),
    [aux_sym_zero_directive_token5] = ACTIONS(5700),
    [aux_sym_zero_directive_token6] = ACTIONS(5700),
    [aux_sym_zero_directive_token7] = ACTIONS(5700),
    [aux_sym_zero_directive_token8] = ACTIONS(5700),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5700),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5700),
    [anon_sym_wire] = ACTIONS(5702),
    [anon_sym_tri] = ACTIONS(5702),
    [anon_sym_tri0] = ACTIONS(5702),
    [anon_sym_tri1] = ACTIONS(5702),
    [anon_sym_wand] = ACTIONS(5702),
    [anon_sym_triand] = ACTIONS(5702),
    [anon_sym_wor] = ACTIONS(5702),
    [anon_sym_trior] = ACTIONS(5702),
    [anon_sym_trireg] = ACTIONS(5702),
    [anon_sym_uwire] = ACTIONS(5702),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5700),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5700),
    [aux_sym_begin_keywords_token1] = ACTIONS(5700),
    [anon_sym_SEMI] = ACTIONS(5700),
    [anon_sym_endmodule] = ACTIONS(5702),
    [anon_sym_extern] = ACTIONS(5702),
    [anon_sym_module] = ACTIONS(5702),
    [anon_sym_macromodule] = ACTIONS(5702),
    [anon_sym_interface] = ACTIONS(5702),
    [anon_sym_program] = ACTIONS(5702),
    [anon_sym_checker] = ACTIONS(5702),
    [anon_sym_virtual] = ACTIONS(5702),
    [anon_sym_class] = ACTIONS(5702),
    [anon_sym_package] = ACTIONS(5702),
    [anon_sym_timeunit] = ACTIONS(5702),
    [anon_sym_timeprecision] = ACTIONS(5702),
    [anon_sym_type] = ACTIONS(5702),
    [anon_sym_input] = ACTIONS(5702),
    [anon_sym_output] = ACTIONS(5702),
    [anon_sym_inout] = ACTIONS(5702),
    [anon_sym_ref] = ACTIONS(5702),
    [anon_sym_DOLLARfatal] = ACTIONS(5700),
    [anon_sym_DOLLARerror] = ACTIONS(5700),
    [anon_sym_DOLLARwarning] = ACTIONS(5700),
    [anon_sym_DOLLARinfo] = ACTIONS(5700),
    [anon_sym_default] = ACTIONS(5702),
    [anon_sym_clocking] = ACTIONS(5702),
    [anon_sym_defparam] = ACTIONS(5702),
    [anon_sym_bind] = ACTIONS(5702),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_function] = ACTIONS(5702),
    [anon_sym_static] = ACTIONS(5702),
    [anon_sym_constraint] = ACTIONS(5702),
    [anon_sym_if] = ACTIONS(5702),
    [anon_sym_LBRACK] = ACTIONS(5700),
    [anon_sym_localparam] = ACTIONS(5702),
    [anon_sym_parameter] = ACTIONS(5702),
    [anon_sym_specparam] = ACTIONS(5702),
    [anon_sym_var] = ACTIONS(5702),
    [anon_sym_import] = ACTIONS(5702),
    [anon_sym_export] = ACTIONS(5702),
    [anon_sym_genvar] = ACTIONS(5702),
    [anon_sym_interconnect] = ACTIONS(5702),
    [anon_sym_typedef] = ACTIONS(5702),
    [anon_sym_enum] = ACTIONS(5702),
    [anon_sym_struct] = ACTIONS(5702),
    [anon_sym_union] = ACTIONS(5702),
    [anon_sym_nettype] = ACTIONS(5702),
    [anon_sym_automatic] = ACTIONS(5702),
    [anon_sym_string] = ACTIONS(5702),
    [anon_sym_chandle] = ACTIONS(5702),
    [anon_sym_event] = ACTIONS(5702),
    [anon_sym_byte] = ACTIONS(5702),
    [anon_sym_shortint] = ACTIONS(5702),
    [anon_sym_int] = ACTIONS(5702),
    [anon_sym_longint] = ACTIONS(5702),
    [anon_sym_integer] = ACTIONS(5702),
    [anon_sym_time] = ACTIONS(5702),
    [anon_sym_bit] = ACTIONS(5702),
    [anon_sym_logic] = ACTIONS(5702),
    [anon_sym_reg] = ACTIONS(5702),
    [anon_sym_shortreal] = ACTIONS(5702),
    [anon_sym_real] = ACTIONS(5702),
    [anon_sym_realtime] = ACTIONS(5702),
    [anon_sym_supply0] = ACTIONS(5702),
    [anon_sym_supply1] = ACTIONS(5702),
    [anon_sym_signed] = ACTIONS(5702),
    [anon_sym_unsigned] = ACTIONS(5702),
    [anon_sym_task] = ACTIONS(5702),
    [anon_sym_assert] = ACTIONS(5702),
    [anon_sym_property] = ACTIONS(5702),
    [anon_sym_assume] = ACTIONS(5702),
    [anon_sym_cover] = ACTIONS(5702),
    [anon_sym_sequence] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym_not] = ACTIONS(5702),
    [anon_sym_or] = ACTIONS(5702),
    [anon_sym_and] = ACTIONS(5702),
    [anon_sym_case] = ACTIONS(5702),
    [anon_sym_always] = ACTIONS(5702),
    [anon_sym_covergroup] = ACTIONS(5702),
    [anon_sym_let] = ACTIONS(5702),
    [anon_sym_pulldown] = ACTIONS(5702),
    [anon_sym_pullup] = ACTIONS(5702),
    [anon_sym_cmos] = ACTIONS(5702),
    [anon_sym_rcmos] = ACTIONS(5702),
    [anon_sym_bufif0] = ACTIONS(5702),
    [anon_sym_bufif1] = ACTIONS(5702),
    [anon_sym_notif0] = ACTIONS(5702),
    [anon_sym_notif1] = ACTIONS(5702),
    [anon_sym_nmos] = ACTIONS(5702),
    [anon_sym_pmos] = ACTIONS(5702),
    [anon_sym_rnmos] = ACTIONS(5702),
    [anon_sym_rpmos] = ACTIONS(5702),
    [anon_sym_nand] = ACTIONS(5702),
    [anon_sym_nor] = ACTIONS(5702),
    [anon_sym_xor] = ACTIONS(5702),
    [anon_sym_xnor] = ACTIONS(5702),
    [anon_sym_buf] = ACTIONS(5702),
    [anon_sym_tranif0] = ACTIONS(5702),
    [anon_sym_tranif1] = ACTIONS(5702),
    [anon_sym_rtranif1] = ACTIONS(5702),
    [anon_sym_rtranif0] = ACTIONS(5702),
    [anon_sym_tran] = ACTIONS(5702),
    [anon_sym_rtran] = ACTIONS(5702),
    [anon_sym_generate] = ACTIONS(5702),
    [anon_sym_for] = ACTIONS(5702),
    [anon_sym_primitive] = ACTIONS(5702),
    [anon_sym_initial] = ACTIONS(5702),
    [anon_sym_assign] = ACTIONS(5702),
    [anon_sym_alias] = ACTIONS(5702),
    [anon_sym_always_comb] = ACTIONS(5702),
    [anon_sym_always_latch] = ACTIONS(5702),
    [anon_sym_always_ff] = ACTIONS(5702),
    [anon_sym_final] = ACTIONS(5702),
    [anon_sym_global] = ACTIONS(5702),
    [anon_sym_specify] = ACTIONS(5702),
    [anon_sym_LPAREN_STAR] = ACTIONS(5700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5700),
    [anon_sym_DOLLARunit] = ACTIONS(5700),
  },
  [1015] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5706),
    [anon_sym_BQUOTE] = ACTIONS(5704),
    [aux_sym_id_directive_token1] = ACTIONS(5706),
    [aux_sym_id_directive_token2] = ACTIONS(5706),
    [aux_sym_id_directive_token3] = ACTIONS(5706),
    [aux_sym_id_directive_token4] = ACTIONS(5704),
    [aux_sym_zero_directive_token1] = ACTIONS(5706),
    [aux_sym_zero_directive_token2] = ACTIONS(5706),
    [aux_sym_zero_directive_token3] = ACTIONS(5706),
    [aux_sym_zero_directive_token4] = ACTIONS(5706),
    [aux_sym_zero_directive_token5] = ACTIONS(5706),
    [aux_sym_zero_directive_token6] = ACTIONS(5706),
    [aux_sym_zero_directive_token7] = ACTIONS(5706),
    [aux_sym_zero_directive_token8] = ACTIONS(5706),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5706),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5706),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_begin_keywords_token1] = ACTIONS(5706),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_endmodule] = ACTIONS(5704),
    [anon_sym_COLON] = ACTIONS(5708),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_module] = ACTIONS(5704),
    [anon_sym_macromodule] = ACTIONS(5704),
    [anon_sym_endinterface] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_endprogram] = ACTIONS(5704),
    [anon_sym_program] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_timeunit] = ACTIONS(5704),
    [anon_sym_timeprecision] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_input] = ACTIONS(5704),
    [anon_sym_output] = ACTIONS(5704),
    [anon_sym_inout] = ACTIONS(5704),
    [anon_sym_ref] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_specparam] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_modport] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_while] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_specify] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [1016] = {
    [ts_builtin_sym_end] = ACTIONS(5710),
    [sym_simple_identifier] = ACTIONS(5712),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5710),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5710),
    [anon_sym_BQUOTE] = ACTIONS(5712),
    [aux_sym_id_directive_token1] = ACTIONS(5710),
    [aux_sym_id_directive_token2] = ACTIONS(5710),
    [aux_sym_id_directive_token3] = ACTIONS(5710),
    [aux_sym_id_directive_token4] = ACTIONS(5712),
    [aux_sym_zero_directive_token1] = ACTIONS(5710),
    [aux_sym_zero_directive_token2] = ACTIONS(5710),
    [aux_sym_zero_directive_token3] = ACTIONS(5710),
    [aux_sym_zero_directive_token4] = ACTIONS(5710),
    [aux_sym_zero_directive_token5] = ACTIONS(5710),
    [aux_sym_zero_directive_token6] = ACTIONS(5710),
    [aux_sym_zero_directive_token7] = ACTIONS(5710),
    [aux_sym_zero_directive_token8] = ACTIONS(5710),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5710),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5710),
    [anon_sym_wire] = ACTIONS(5712),
    [anon_sym_tri] = ACTIONS(5712),
    [anon_sym_tri0] = ACTIONS(5712),
    [anon_sym_tri1] = ACTIONS(5712),
    [anon_sym_wand] = ACTIONS(5712),
    [anon_sym_triand] = ACTIONS(5712),
    [anon_sym_wor] = ACTIONS(5712),
    [anon_sym_trior] = ACTIONS(5712),
    [anon_sym_trireg] = ACTIONS(5712),
    [anon_sym_uwire] = ACTIONS(5712),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5710),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5710),
    [aux_sym_begin_keywords_token1] = ACTIONS(5710),
    [anon_sym_SEMI] = ACTIONS(5710),
    [anon_sym_endmodule] = ACTIONS(5712),
    [anon_sym_extern] = ACTIONS(5712),
    [anon_sym_module] = ACTIONS(5712),
    [anon_sym_macromodule] = ACTIONS(5712),
    [anon_sym_endinterface] = ACTIONS(5712),
    [anon_sym_interface] = ACTIONS(5712),
    [anon_sym_endprogram] = ACTIONS(5712),
    [anon_sym_program] = ACTIONS(5712),
    [anon_sym_checker] = ACTIONS(5712),
    [anon_sym_virtual] = ACTIONS(5712),
    [anon_sym_class] = ACTIONS(5712),
    [anon_sym_package] = ACTIONS(5712),
    [anon_sym_timeunit] = ACTIONS(5712),
    [anon_sym_timeprecision] = ACTIONS(5712),
    [anon_sym_type] = ACTIONS(5712),
    [anon_sym_input] = ACTIONS(5712),
    [anon_sym_output] = ACTIONS(5712),
    [anon_sym_inout] = ACTIONS(5712),
    [anon_sym_ref] = ACTIONS(5712),
    [anon_sym_DOLLARfatal] = ACTIONS(5710),
    [anon_sym_DOLLARerror] = ACTIONS(5710),
    [anon_sym_DOLLARwarning] = ACTIONS(5710),
    [anon_sym_DOLLARinfo] = ACTIONS(5710),
    [anon_sym_default] = ACTIONS(5712),
    [anon_sym_clocking] = ACTIONS(5712),
    [anon_sym_defparam] = ACTIONS(5712),
    [anon_sym_bind] = ACTIONS(5712),
    [anon_sym_const] = ACTIONS(5712),
    [anon_sym_function] = ACTIONS(5712),
    [anon_sym_static] = ACTIONS(5712),
    [anon_sym_constraint] = ACTIONS(5712),
    [anon_sym_if] = ACTIONS(5712),
    [anon_sym_LBRACK] = ACTIONS(5710),
    [anon_sym_localparam] = ACTIONS(5712),
    [anon_sym_parameter] = ACTIONS(5712),
    [anon_sym_specparam] = ACTIONS(5712),
    [anon_sym_var] = ACTIONS(5712),
    [anon_sym_import] = ACTIONS(5712),
    [anon_sym_export] = ACTIONS(5712),
    [anon_sym_genvar] = ACTIONS(5712),
    [anon_sym_interconnect] = ACTIONS(5712),
    [anon_sym_typedef] = ACTIONS(5712),
    [anon_sym_enum] = ACTIONS(5712),
    [anon_sym_struct] = ACTIONS(5712),
    [anon_sym_union] = ACTIONS(5712),
    [anon_sym_nettype] = ACTIONS(5712),
    [anon_sym_automatic] = ACTIONS(5712),
    [anon_sym_string] = ACTIONS(5712),
    [anon_sym_chandle] = ACTIONS(5712),
    [anon_sym_event] = ACTIONS(5712),
    [anon_sym_byte] = ACTIONS(5712),
    [anon_sym_shortint] = ACTIONS(5712),
    [anon_sym_int] = ACTIONS(5712),
    [anon_sym_longint] = ACTIONS(5712),
    [anon_sym_integer] = ACTIONS(5712),
    [anon_sym_time] = ACTIONS(5712),
    [anon_sym_bit] = ACTIONS(5712),
    [anon_sym_logic] = ACTIONS(5712),
    [anon_sym_reg] = ACTIONS(5712),
    [anon_sym_shortreal] = ACTIONS(5712),
    [anon_sym_real] = ACTIONS(5712),
    [anon_sym_realtime] = ACTIONS(5712),
    [anon_sym_supply0] = ACTIONS(5712),
    [anon_sym_supply1] = ACTIONS(5712),
    [anon_sym_signed] = ACTIONS(5712),
    [anon_sym_unsigned] = ACTIONS(5712),
    [anon_sym_task] = ACTIONS(5712),
    [anon_sym_modport] = ACTIONS(5712),
    [anon_sym_assert] = ACTIONS(5712),
    [anon_sym_property] = ACTIONS(5712),
    [anon_sym_assume] = ACTIONS(5712),
    [anon_sym_cover] = ACTIONS(5712),
    [anon_sym_sequence] = ACTIONS(5712),
    [anon_sym_restrict] = ACTIONS(5712),
    [anon_sym_not] = ACTIONS(5712),
    [anon_sym_or] = ACTIONS(5712),
    [anon_sym_and] = ACTIONS(5712),
    [anon_sym_case] = ACTIONS(5712),
    [anon_sym_always] = ACTIONS(5712),
    [anon_sym_covergroup] = ACTIONS(5712),
    [anon_sym_let] = ACTIONS(5712),
    [anon_sym_pulldown] = ACTIONS(5712),
    [anon_sym_pullup] = ACTIONS(5712),
    [anon_sym_cmos] = ACTIONS(5712),
    [anon_sym_rcmos] = ACTIONS(5712),
    [anon_sym_bufif0] = ACTIONS(5712),
    [anon_sym_bufif1] = ACTIONS(5712),
    [anon_sym_notif0] = ACTIONS(5712),
    [anon_sym_notif1] = ACTIONS(5712),
    [anon_sym_nmos] = ACTIONS(5712),
    [anon_sym_pmos] = ACTIONS(5712),
    [anon_sym_rnmos] = ACTIONS(5712),
    [anon_sym_rpmos] = ACTIONS(5712),
    [anon_sym_nand] = ACTIONS(5712),
    [anon_sym_nor] = ACTIONS(5712),
    [anon_sym_xor] = ACTIONS(5712),
    [anon_sym_xnor] = ACTIONS(5712),
    [anon_sym_buf] = ACTIONS(5712),
    [anon_sym_tranif0] = ACTIONS(5712),
    [anon_sym_tranif1] = ACTIONS(5712),
    [anon_sym_rtranif1] = ACTIONS(5712),
    [anon_sym_rtranif0] = ACTIONS(5712),
    [anon_sym_tran] = ACTIONS(5712),
    [anon_sym_rtran] = ACTIONS(5712),
    [anon_sym_generate] = ACTIONS(5712),
    [anon_sym_for] = ACTIONS(5712),
    [anon_sym_primitive] = ACTIONS(5712),
    [anon_sym_initial] = ACTIONS(5712),
    [anon_sym_assign] = ACTIONS(5712),
    [anon_sym_alias] = ACTIONS(5712),
    [anon_sym_always_comb] = ACTIONS(5712),
    [anon_sym_always_latch] = ACTIONS(5712),
    [anon_sym_always_ff] = ACTIONS(5712),
    [anon_sym_final] = ACTIONS(5712),
    [anon_sym_global] = ACTIONS(5712),
    [anon_sym_specify] = ACTIONS(5712),
    [anon_sym_LPAREN_STAR] = ACTIONS(5710),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5710),
    [anon_sym_DOLLARunit] = ACTIONS(5710),
  },
  [1017] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5716),
    [anon_sym_BQUOTE] = ACTIONS(5714),
    [aux_sym_id_directive_token1] = ACTIONS(5716),
    [aux_sym_id_directive_token2] = ACTIONS(5716),
    [aux_sym_id_directive_token3] = ACTIONS(5716),
    [aux_sym_id_directive_token4] = ACTIONS(5714),
    [aux_sym_zero_directive_token1] = ACTIONS(5716),
    [aux_sym_zero_directive_token2] = ACTIONS(5716),
    [aux_sym_zero_directive_token3] = ACTIONS(5716),
    [aux_sym_zero_directive_token4] = ACTIONS(5716),
    [aux_sym_zero_directive_token5] = ACTIONS(5716),
    [aux_sym_zero_directive_token6] = ACTIONS(5716),
    [aux_sym_zero_directive_token7] = ACTIONS(5716),
    [aux_sym_zero_directive_token8] = ACTIONS(5716),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5716),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5716),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_begin_keywords_token1] = ACTIONS(5716),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_endmodule] = ACTIONS(5714),
    [anon_sym_COLON] = ACTIONS(5718),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_module] = ACTIONS(5714),
    [anon_sym_macromodule] = ACTIONS(5714),
    [anon_sym_endinterface] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_endprogram] = ACTIONS(5714),
    [anon_sym_program] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_timeunit] = ACTIONS(5714),
    [anon_sym_timeprecision] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_input] = ACTIONS(5714),
    [anon_sym_output] = ACTIONS(5714),
    [anon_sym_inout] = ACTIONS(5714),
    [anon_sym_ref] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_specparam] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_modport] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_while] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_specify] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [1018] = {
    [ts_builtin_sym_end] = ACTIONS(5720),
    [sym_simple_identifier] = ACTIONS(5722),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5720),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5720),
    [anon_sym_BQUOTE] = ACTIONS(5722),
    [aux_sym_id_directive_token1] = ACTIONS(5720),
    [aux_sym_id_directive_token2] = ACTIONS(5720),
    [aux_sym_id_directive_token3] = ACTIONS(5720),
    [aux_sym_id_directive_token4] = ACTIONS(5722),
    [aux_sym_zero_directive_token1] = ACTIONS(5720),
    [aux_sym_zero_directive_token2] = ACTIONS(5720),
    [aux_sym_zero_directive_token3] = ACTIONS(5720),
    [aux_sym_zero_directive_token4] = ACTIONS(5720),
    [aux_sym_zero_directive_token5] = ACTIONS(5720),
    [aux_sym_zero_directive_token6] = ACTIONS(5720),
    [aux_sym_zero_directive_token7] = ACTIONS(5720),
    [aux_sym_zero_directive_token8] = ACTIONS(5720),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5720),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5720),
    [anon_sym_wire] = ACTIONS(5722),
    [anon_sym_tri] = ACTIONS(5722),
    [anon_sym_tri0] = ACTIONS(5722),
    [anon_sym_tri1] = ACTIONS(5722),
    [anon_sym_wand] = ACTIONS(5722),
    [anon_sym_triand] = ACTIONS(5722),
    [anon_sym_wor] = ACTIONS(5722),
    [anon_sym_trior] = ACTIONS(5722),
    [anon_sym_trireg] = ACTIONS(5722),
    [anon_sym_uwire] = ACTIONS(5722),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5720),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5720),
    [aux_sym_begin_keywords_token1] = ACTIONS(5720),
    [anon_sym_SEMI] = ACTIONS(5720),
    [anon_sym_endmodule] = ACTIONS(5722),
    [anon_sym_COLON] = ACTIONS(5724),
    [anon_sym_extern] = ACTIONS(5722),
    [anon_sym_module] = ACTIONS(5722),
    [anon_sym_macromodule] = ACTIONS(5722),
    [anon_sym_endinterface] = ACTIONS(5722),
    [anon_sym_interface] = ACTIONS(5722),
    [anon_sym_program] = ACTIONS(5722),
    [anon_sym_checker] = ACTIONS(5722),
    [anon_sym_virtual] = ACTIONS(5722),
    [anon_sym_class] = ACTIONS(5722),
    [anon_sym_package] = ACTIONS(5722),
    [anon_sym_timeunit] = ACTIONS(5722),
    [anon_sym_timeprecision] = ACTIONS(5722),
    [anon_sym_type] = ACTIONS(5722),
    [anon_sym_input] = ACTIONS(5722),
    [anon_sym_output] = ACTIONS(5722),
    [anon_sym_inout] = ACTIONS(5722),
    [anon_sym_ref] = ACTIONS(5722),
    [anon_sym_DOLLARfatal] = ACTIONS(5720),
    [anon_sym_DOLLARerror] = ACTIONS(5720),
    [anon_sym_DOLLARwarning] = ACTIONS(5720),
    [anon_sym_DOLLARinfo] = ACTIONS(5720),
    [anon_sym_default] = ACTIONS(5722),
    [anon_sym_clocking] = ACTIONS(5722),
    [anon_sym_defparam] = ACTIONS(5722),
    [anon_sym_bind] = ACTIONS(5722),
    [anon_sym_const] = ACTIONS(5722),
    [anon_sym_function] = ACTIONS(5722),
    [anon_sym_static] = ACTIONS(5722),
    [anon_sym_constraint] = ACTIONS(5722),
    [anon_sym_if] = ACTIONS(5722),
    [anon_sym_LBRACK] = ACTIONS(5720),
    [anon_sym_localparam] = ACTIONS(5722),
    [anon_sym_parameter] = ACTIONS(5722),
    [anon_sym_specparam] = ACTIONS(5722),
    [anon_sym_var] = ACTIONS(5722),
    [anon_sym_import] = ACTIONS(5722),
    [anon_sym_export] = ACTIONS(5722),
    [anon_sym_genvar] = ACTIONS(5722),
    [anon_sym_interconnect] = ACTIONS(5722),
    [anon_sym_typedef] = ACTIONS(5722),
    [anon_sym_enum] = ACTIONS(5722),
    [anon_sym_struct] = ACTIONS(5722),
    [anon_sym_union] = ACTIONS(5722),
    [anon_sym_nettype] = ACTIONS(5722),
    [anon_sym_automatic] = ACTIONS(5722),
    [anon_sym_string] = ACTIONS(5722),
    [anon_sym_chandle] = ACTIONS(5722),
    [anon_sym_event] = ACTIONS(5722),
    [anon_sym_byte] = ACTIONS(5722),
    [anon_sym_shortint] = ACTIONS(5722),
    [anon_sym_int] = ACTIONS(5722),
    [anon_sym_longint] = ACTIONS(5722),
    [anon_sym_integer] = ACTIONS(5722),
    [anon_sym_time] = ACTIONS(5722),
    [anon_sym_bit] = ACTIONS(5722),
    [anon_sym_logic] = ACTIONS(5722),
    [anon_sym_reg] = ACTIONS(5722),
    [anon_sym_shortreal] = ACTIONS(5722),
    [anon_sym_real] = ACTIONS(5722),
    [anon_sym_realtime] = ACTIONS(5722),
    [anon_sym_supply0] = ACTIONS(5722),
    [anon_sym_supply1] = ACTIONS(5722),
    [anon_sym_signed] = ACTIONS(5722),
    [anon_sym_unsigned] = ACTIONS(5722),
    [anon_sym_task] = ACTIONS(5722),
    [anon_sym_modport] = ACTIONS(5722),
    [anon_sym_assert] = ACTIONS(5722),
    [anon_sym_property] = ACTIONS(5722),
    [anon_sym_assume] = ACTIONS(5722),
    [anon_sym_cover] = ACTIONS(5722),
    [anon_sym_sequence] = ACTIONS(5722),
    [anon_sym_restrict] = ACTIONS(5722),
    [anon_sym_not] = ACTIONS(5722),
    [anon_sym_or] = ACTIONS(5722),
    [anon_sym_and] = ACTIONS(5722),
    [anon_sym_case] = ACTIONS(5722),
    [anon_sym_always] = ACTIONS(5722),
    [anon_sym_covergroup] = ACTIONS(5722),
    [anon_sym_let] = ACTIONS(5722),
    [anon_sym_pulldown] = ACTIONS(5722),
    [anon_sym_pullup] = ACTIONS(5722),
    [anon_sym_cmos] = ACTIONS(5722),
    [anon_sym_rcmos] = ACTIONS(5722),
    [anon_sym_bufif0] = ACTIONS(5722),
    [anon_sym_bufif1] = ACTIONS(5722),
    [anon_sym_notif0] = ACTIONS(5722),
    [anon_sym_notif1] = ACTIONS(5722),
    [anon_sym_nmos] = ACTIONS(5722),
    [anon_sym_pmos] = ACTIONS(5722),
    [anon_sym_rnmos] = ACTIONS(5722),
    [anon_sym_rpmos] = ACTIONS(5722),
    [anon_sym_nand] = ACTIONS(5722),
    [anon_sym_nor] = ACTIONS(5722),
    [anon_sym_xor] = ACTIONS(5722),
    [anon_sym_xnor] = ACTIONS(5722),
    [anon_sym_buf] = ACTIONS(5722),
    [anon_sym_tranif0] = ACTIONS(5722),
    [anon_sym_tranif1] = ACTIONS(5722),
    [anon_sym_rtranif1] = ACTIONS(5722),
    [anon_sym_rtranif0] = ACTIONS(5722),
    [anon_sym_tran] = ACTIONS(5722),
    [anon_sym_rtran] = ACTIONS(5722),
    [anon_sym_generate] = ACTIONS(5722),
    [anon_sym_for] = ACTIONS(5722),
    [anon_sym_primitive] = ACTIONS(5722),
    [anon_sym_initial] = ACTIONS(5722),
    [anon_sym_assign] = ACTIONS(5722),
    [anon_sym_alias] = ACTIONS(5722),
    [anon_sym_always_comb] = ACTIONS(5722),
    [anon_sym_always_latch] = ACTIONS(5722),
    [anon_sym_always_ff] = ACTIONS(5722),
    [anon_sym_final] = ACTIONS(5722),
    [anon_sym_global] = ACTIONS(5722),
    [anon_sym_specify] = ACTIONS(5722),
    [anon_sym_LPAREN_STAR] = ACTIONS(5720),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5720),
    [anon_sym_DOLLARunit] = ACTIONS(5720),
  },
  [1019] = {
    [ts_builtin_sym_end] = ACTIONS(5726),
    [sym_simple_identifier] = ACTIONS(5728),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5726),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5726),
    [anon_sym_BQUOTE] = ACTIONS(5728),
    [aux_sym_id_directive_token1] = ACTIONS(5726),
    [aux_sym_id_directive_token2] = ACTIONS(5726),
    [aux_sym_id_directive_token3] = ACTIONS(5726),
    [aux_sym_id_directive_token4] = ACTIONS(5728),
    [aux_sym_zero_directive_token1] = ACTIONS(5726),
    [aux_sym_zero_directive_token2] = ACTIONS(5726),
    [aux_sym_zero_directive_token3] = ACTIONS(5726),
    [aux_sym_zero_directive_token4] = ACTIONS(5726),
    [aux_sym_zero_directive_token5] = ACTIONS(5726),
    [aux_sym_zero_directive_token6] = ACTIONS(5726),
    [aux_sym_zero_directive_token7] = ACTIONS(5726),
    [aux_sym_zero_directive_token8] = ACTIONS(5726),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5726),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5726),
    [anon_sym_wire] = ACTIONS(5728),
    [anon_sym_tri] = ACTIONS(5728),
    [anon_sym_tri0] = ACTIONS(5728),
    [anon_sym_tri1] = ACTIONS(5728),
    [anon_sym_wand] = ACTIONS(5728),
    [anon_sym_triand] = ACTIONS(5728),
    [anon_sym_wor] = ACTIONS(5728),
    [anon_sym_trior] = ACTIONS(5728),
    [anon_sym_trireg] = ACTIONS(5728),
    [anon_sym_uwire] = ACTIONS(5728),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5726),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5726),
    [aux_sym_begin_keywords_token1] = ACTIONS(5726),
    [anon_sym_SEMI] = ACTIONS(5726),
    [anon_sym_endmodule] = ACTIONS(5728),
    [anon_sym_COLON] = ACTIONS(5730),
    [anon_sym_extern] = ACTIONS(5728),
    [anon_sym_module] = ACTIONS(5728),
    [anon_sym_macromodule] = ACTIONS(5728),
    [anon_sym_endinterface] = ACTIONS(5728),
    [anon_sym_interface] = ACTIONS(5728),
    [anon_sym_program] = ACTIONS(5728),
    [anon_sym_checker] = ACTIONS(5728),
    [anon_sym_virtual] = ACTIONS(5728),
    [anon_sym_class] = ACTIONS(5728),
    [anon_sym_package] = ACTIONS(5728),
    [anon_sym_timeunit] = ACTIONS(5728),
    [anon_sym_timeprecision] = ACTIONS(5728),
    [anon_sym_type] = ACTIONS(5728),
    [anon_sym_input] = ACTIONS(5728),
    [anon_sym_output] = ACTIONS(5728),
    [anon_sym_inout] = ACTIONS(5728),
    [anon_sym_ref] = ACTIONS(5728),
    [anon_sym_DOLLARfatal] = ACTIONS(5726),
    [anon_sym_DOLLARerror] = ACTIONS(5726),
    [anon_sym_DOLLARwarning] = ACTIONS(5726),
    [anon_sym_DOLLARinfo] = ACTIONS(5726),
    [anon_sym_default] = ACTIONS(5728),
    [anon_sym_clocking] = ACTIONS(5728),
    [anon_sym_defparam] = ACTIONS(5728),
    [anon_sym_bind] = ACTIONS(5728),
    [anon_sym_const] = ACTIONS(5728),
    [anon_sym_function] = ACTIONS(5728),
    [anon_sym_static] = ACTIONS(5728),
    [anon_sym_constraint] = ACTIONS(5728),
    [anon_sym_if] = ACTIONS(5728),
    [anon_sym_LBRACK] = ACTIONS(5726),
    [anon_sym_localparam] = ACTIONS(5728),
    [anon_sym_parameter] = ACTIONS(5728),
    [anon_sym_specparam] = ACTIONS(5728),
    [anon_sym_var] = ACTIONS(5728),
    [anon_sym_import] = ACTIONS(5728),
    [anon_sym_export] = ACTIONS(5728),
    [anon_sym_genvar] = ACTIONS(5728),
    [anon_sym_interconnect] = ACTIONS(5728),
    [anon_sym_typedef] = ACTIONS(5728),
    [anon_sym_enum] = ACTIONS(5728),
    [anon_sym_struct] = ACTIONS(5728),
    [anon_sym_union] = ACTIONS(5728),
    [anon_sym_nettype] = ACTIONS(5728),
    [anon_sym_automatic] = ACTIONS(5728),
    [anon_sym_string] = ACTIONS(5728),
    [anon_sym_chandle] = ACTIONS(5728),
    [anon_sym_event] = ACTIONS(5728),
    [anon_sym_byte] = ACTIONS(5728),
    [anon_sym_shortint] = ACTIONS(5728),
    [anon_sym_int] = ACTIONS(5728),
    [anon_sym_longint] = ACTIONS(5728),
    [anon_sym_integer] = ACTIONS(5728),
    [anon_sym_time] = ACTIONS(5728),
    [anon_sym_bit] = ACTIONS(5728),
    [anon_sym_logic] = ACTIONS(5728),
    [anon_sym_reg] = ACTIONS(5728),
    [anon_sym_shortreal] = ACTIONS(5728),
    [anon_sym_real] = ACTIONS(5728),
    [anon_sym_realtime] = ACTIONS(5728),
    [anon_sym_supply0] = ACTIONS(5728),
    [anon_sym_supply1] = ACTIONS(5728),
    [anon_sym_signed] = ACTIONS(5728),
    [anon_sym_unsigned] = ACTIONS(5728),
    [anon_sym_task] = ACTIONS(5728),
    [anon_sym_modport] = ACTIONS(5728),
    [anon_sym_assert] = ACTIONS(5728),
    [anon_sym_property] = ACTIONS(5728),
    [anon_sym_assume] = ACTIONS(5728),
    [anon_sym_cover] = ACTIONS(5728),
    [anon_sym_sequence] = ACTIONS(5728),
    [anon_sym_restrict] = ACTIONS(5728),
    [anon_sym_not] = ACTIONS(5728),
    [anon_sym_or] = ACTIONS(5728),
    [anon_sym_and] = ACTIONS(5728),
    [anon_sym_case] = ACTIONS(5728),
    [anon_sym_always] = ACTIONS(5728),
    [anon_sym_covergroup] = ACTIONS(5728),
    [anon_sym_let] = ACTIONS(5728),
    [anon_sym_pulldown] = ACTIONS(5728),
    [anon_sym_pullup] = ACTIONS(5728),
    [anon_sym_cmos] = ACTIONS(5728),
    [anon_sym_rcmos] = ACTIONS(5728),
    [anon_sym_bufif0] = ACTIONS(5728),
    [anon_sym_bufif1] = ACTIONS(5728),
    [anon_sym_notif0] = ACTIONS(5728),
    [anon_sym_notif1] = ACTIONS(5728),
    [anon_sym_nmos] = ACTIONS(5728),
    [anon_sym_pmos] = ACTIONS(5728),
    [anon_sym_rnmos] = ACTIONS(5728),
    [anon_sym_rpmos] = ACTIONS(5728),
    [anon_sym_nand] = ACTIONS(5728),
    [anon_sym_nor] = ACTIONS(5728),
    [anon_sym_xor] = ACTIONS(5728),
    [anon_sym_xnor] = ACTIONS(5728),
    [anon_sym_buf] = ACTIONS(5728),
    [anon_sym_tranif0] = ACTIONS(5728),
    [anon_sym_tranif1] = ACTIONS(5728),
    [anon_sym_rtranif1] = ACTIONS(5728),
    [anon_sym_rtranif0] = ACTIONS(5728),
    [anon_sym_tran] = ACTIONS(5728),
    [anon_sym_rtran] = ACTIONS(5728),
    [anon_sym_generate] = ACTIONS(5728),
    [anon_sym_for] = ACTIONS(5728),
    [anon_sym_primitive] = ACTIONS(5728),
    [anon_sym_initial] = ACTIONS(5728),
    [anon_sym_assign] = ACTIONS(5728),
    [anon_sym_alias] = ACTIONS(5728),
    [anon_sym_always_comb] = ACTIONS(5728),
    [anon_sym_always_latch] = ACTIONS(5728),
    [anon_sym_always_ff] = ACTIONS(5728),
    [anon_sym_final] = ACTIONS(5728),
    [anon_sym_global] = ACTIONS(5728),
    [anon_sym_specify] = ACTIONS(5728),
    [anon_sym_LPAREN_STAR] = ACTIONS(5726),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5726),
    [anon_sym_DOLLARunit] = ACTIONS(5726),
  },
  [1020] = {
    [ts_builtin_sym_end] = ACTIONS(5732),
    [sym_simple_identifier] = ACTIONS(5734),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5732),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5732),
    [anon_sym_BQUOTE] = ACTIONS(5734),
    [aux_sym_id_directive_token1] = ACTIONS(5732),
    [aux_sym_id_directive_token2] = ACTIONS(5732),
    [aux_sym_id_directive_token3] = ACTIONS(5732),
    [aux_sym_id_directive_token4] = ACTIONS(5734),
    [aux_sym_zero_directive_token1] = ACTIONS(5732),
    [aux_sym_zero_directive_token2] = ACTIONS(5732),
    [aux_sym_zero_directive_token3] = ACTIONS(5732),
    [aux_sym_zero_directive_token4] = ACTIONS(5732),
    [aux_sym_zero_directive_token5] = ACTIONS(5732),
    [aux_sym_zero_directive_token6] = ACTIONS(5732),
    [aux_sym_zero_directive_token7] = ACTIONS(5732),
    [aux_sym_zero_directive_token8] = ACTIONS(5732),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5732),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5732),
    [anon_sym_wire] = ACTIONS(5734),
    [anon_sym_tri] = ACTIONS(5734),
    [anon_sym_tri0] = ACTIONS(5734),
    [anon_sym_tri1] = ACTIONS(5734),
    [anon_sym_wand] = ACTIONS(5734),
    [anon_sym_triand] = ACTIONS(5734),
    [anon_sym_wor] = ACTIONS(5734),
    [anon_sym_trior] = ACTIONS(5734),
    [anon_sym_trireg] = ACTIONS(5734),
    [anon_sym_uwire] = ACTIONS(5734),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5732),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5732),
    [aux_sym_begin_keywords_token1] = ACTIONS(5732),
    [anon_sym_SEMI] = ACTIONS(5732),
    [anon_sym_endmodule] = ACTIONS(5734),
    [anon_sym_COLON] = ACTIONS(5736),
    [anon_sym_extern] = ACTIONS(5734),
    [anon_sym_module] = ACTIONS(5734),
    [anon_sym_macromodule] = ACTIONS(5734),
    [anon_sym_endinterface] = ACTIONS(5734),
    [anon_sym_interface] = ACTIONS(5734),
    [anon_sym_program] = ACTIONS(5734),
    [anon_sym_checker] = ACTIONS(5734),
    [anon_sym_virtual] = ACTIONS(5734),
    [anon_sym_class] = ACTIONS(5734),
    [anon_sym_package] = ACTIONS(5734),
    [anon_sym_timeunit] = ACTIONS(5734),
    [anon_sym_timeprecision] = ACTIONS(5734),
    [anon_sym_type] = ACTIONS(5734),
    [anon_sym_input] = ACTIONS(5734),
    [anon_sym_output] = ACTIONS(5734),
    [anon_sym_inout] = ACTIONS(5734),
    [anon_sym_ref] = ACTIONS(5734),
    [anon_sym_DOLLARfatal] = ACTIONS(5732),
    [anon_sym_DOLLARerror] = ACTIONS(5732),
    [anon_sym_DOLLARwarning] = ACTIONS(5732),
    [anon_sym_DOLLARinfo] = ACTIONS(5732),
    [anon_sym_default] = ACTIONS(5734),
    [anon_sym_clocking] = ACTIONS(5734),
    [anon_sym_defparam] = ACTIONS(5734),
    [anon_sym_bind] = ACTIONS(5734),
    [anon_sym_const] = ACTIONS(5734),
    [anon_sym_function] = ACTIONS(5734),
    [anon_sym_static] = ACTIONS(5734),
    [anon_sym_constraint] = ACTIONS(5734),
    [anon_sym_if] = ACTIONS(5734),
    [anon_sym_LBRACK] = ACTIONS(5732),
    [anon_sym_localparam] = ACTIONS(5734),
    [anon_sym_parameter] = ACTIONS(5734),
    [anon_sym_specparam] = ACTIONS(5734),
    [anon_sym_var] = ACTIONS(5734),
    [anon_sym_import] = ACTIONS(5734),
    [anon_sym_export] = ACTIONS(5734),
    [anon_sym_genvar] = ACTIONS(5734),
    [anon_sym_interconnect] = ACTIONS(5734),
    [anon_sym_typedef] = ACTIONS(5734),
    [anon_sym_enum] = ACTIONS(5734),
    [anon_sym_struct] = ACTIONS(5734),
    [anon_sym_union] = ACTIONS(5734),
    [anon_sym_nettype] = ACTIONS(5734),
    [anon_sym_automatic] = ACTIONS(5734),
    [anon_sym_string] = ACTIONS(5734),
    [anon_sym_chandle] = ACTIONS(5734),
    [anon_sym_event] = ACTIONS(5734),
    [anon_sym_byte] = ACTIONS(5734),
    [anon_sym_shortint] = ACTIONS(5734),
    [anon_sym_int] = ACTIONS(5734),
    [anon_sym_longint] = ACTIONS(5734),
    [anon_sym_integer] = ACTIONS(5734),
    [anon_sym_time] = ACTIONS(5734),
    [anon_sym_bit] = ACTIONS(5734),
    [anon_sym_logic] = ACTIONS(5734),
    [anon_sym_reg] = ACTIONS(5734),
    [anon_sym_shortreal] = ACTIONS(5734),
    [anon_sym_real] = ACTIONS(5734),
    [anon_sym_realtime] = ACTIONS(5734),
    [anon_sym_supply0] = ACTIONS(5734),
    [anon_sym_supply1] = ACTIONS(5734),
    [anon_sym_signed] = ACTIONS(5734),
    [anon_sym_unsigned] = ACTIONS(5734),
    [anon_sym_task] = ACTIONS(5734),
    [anon_sym_modport] = ACTIONS(5734),
    [anon_sym_assert] = ACTIONS(5734),
    [anon_sym_property] = ACTIONS(5734),
    [anon_sym_assume] = ACTIONS(5734),
    [anon_sym_cover] = ACTIONS(5734),
    [anon_sym_sequence] = ACTIONS(5734),
    [anon_sym_restrict] = ACTIONS(5734),
    [anon_sym_not] = ACTIONS(5734),
    [anon_sym_or] = ACTIONS(5734),
    [anon_sym_and] = ACTIONS(5734),
    [anon_sym_case] = ACTIONS(5734),
    [anon_sym_always] = ACTIONS(5734),
    [anon_sym_covergroup] = ACTIONS(5734),
    [anon_sym_let] = ACTIONS(5734),
    [anon_sym_pulldown] = ACTIONS(5734),
    [anon_sym_pullup] = ACTIONS(5734),
    [anon_sym_cmos] = ACTIONS(5734),
    [anon_sym_rcmos] = ACTIONS(5734),
    [anon_sym_bufif0] = ACTIONS(5734),
    [anon_sym_bufif1] = ACTIONS(5734),
    [anon_sym_notif0] = ACTIONS(5734),
    [anon_sym_notif1] = ACTIONS(5734),
    [anon_sym_nmos] = ACTIONS(5734),
    [anon_sym_pmos] = ACTIONS(5734),
    [anon_sym_rnmos] = ACTIONS(5734),
    [anon_sym_rpmos] = ACTIONS(5734),
    [anon_sym_nand] = ACTIONS(5734),
    [anon_sym_nor] = ACTIONS(5734),
    [anon_sym_xor] = ACTIONS(5734),
    [anon_sym_xnor] = ACTIONS(5734),
    [anon_sym_buf] = ACTIONS(5734),
    [anon_sym_tranif0] = ACTIONS(5734),
    [anon_sym_tranif1] = ACTIONS(5734),
    [anon_sym_rtranif1] = ACTIONS(5734),
    [anon_sym_rtranif0] = ACTIONS(5734),
    [anon_sym_tran] = ACTIONS(5734),
    [anon_sym_rtran] = ACTIONS(5734),
    [anon_sym_generate] = ACTIONS(5734),
    [anon_sym_for] = ACTIONS(5734),
    [anon_sym_primitive] = ACTIONS(5734),
    [anon_sym_initial] = ACTIONS(5734),
    [anon_sym_assign] = ACTIONS(5734),
    [anon_sym_alias] = ACTIONS(5734),
    [anon_sym_always_comb] = ACTIONS(5734),
    [anon_sym_always_latch] = ACTIONS(5734),
    [anon_sym_always_ff] = ACTIONS(5734),
    [anon_sym_final] = ACTIONS(5734),
    [anon_sym_global] = ACTIONS(5734),
    [anon_sym_specify] = ACTIONS(5734),
    [anon_sym_LPAREN_STAR] = ACTIONS(5732),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5732),
    [anon_sym_DOLLARunit] = ACTIONS(5732),
  },
  [1021] = {
    [ts_builtin_sym_end] = ACTIONS(5738),
    [sym_simple_identifier] = ACTIONS(5740),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5738),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5738),
    [anon_sym_BQUOTE] = ACTIONS(5740),
    [aux_sym_id_directive_token1] = ACTIONS(5738),
    [aux_sym_id_directive_token2] = ACTIONS(5738),
    [aux_sym_id_directive_token3] = ACTIONS(5738),
    [aux_sym_id_directive_token4] = ACTIONS(5740),
    [aux_sym_zero_directive_token1] = ACTIONS(5738),
    [aux_sym_zero_directive_token2] = ACTIONS(5738),
    [aux_sym_zero_directive_token3] = ACTIONS(5738),
    [aux_sym_zero_directive_token4] = ACTIONS(5738),
    [aux_sym_zero_directive_token5] = ACTIONS(5738),
    [aux_sym_zero_directive_token6] = ACTIONS(5738),
    [aux_sym_zero_directive_token7] = ACTIONS(5738),
    [aux_sym_zero_directive_token8] = ACTIONS(5738),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5738),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5738),
    [anon_sym_wire] = ACTIONS(5740),
    [anon_sym_tri] = ACTIONS(5740),
    [anon_sym_tri0] = ACTIONS(5740),
    [anon_sym_tri1] = ACTIONS(5740),
    [anon_sym_wand] = ACTIONS(5740),
    [anon_sym_triand] = ACTIONS(5740),
    [anon_sym_wor] = ACTIONS(5740),
    [anon_sym_trior] = ACTIONS(5740),
    [anon_sym_trireg] = ACTIONS(5740),
    [anon_sym_uwire] = ACTIONS(5740),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5738),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5738),
    [aux_sym_begin_keywords_token1] = ACTIONS(5738),
    [anon_sym_SEMI] = ACTIONS(5738),
    [anon_sym_endmodule] = ACTIONS(5740),
    [anon_sym_COLON] = ACTIONS(5742),
    [anon_sym_extern] = ACTIONS(5740),
    [anon_sym_module] = ACTIONS(5740),
    [anon_sym_macromodule] = ACTIONS(5740),
    [anon_sym_endinterface] = ACTIONS(5740),
    [anon_sym_interface] = ACTIONS(5740),
    [anon_sym_program] = ACTIONS(5740),
    [anon_sym_checker] = ACTIONS(5740),
    [anon_sym_virtual] = ACTIONS(5740),
    [anon_sym_class] = ACTIONS(5740),
    [anon_sym_package] = ACTIONS(5740),
    [anon_sym_timeunit] = ACTIONS(5740),
    [anon_sym_timeprecision] = ACTIONS(5740),
    [anon_sym_type] = ACTIONS(5740),
    [anon_sym_input] = ACTIONS(5740),
    [anon_sym_output] = ACTIONS(5740),
    [anon_sym_inout] = ACTIONS(5740),
    [anon_sym_ref] = ACTIONS(5740),
    [anon_sym_DOLLARfatal] = ACTIONS(5738),
    [anon_sym_DOLLARerror] = ACTIONS(5738),
    [anon_sym_DOLLARwarning] = ACTIONS(5738),
    [anon_sym_DOLLARinfo] = ACTIONS(5738),
    [anon_sym_default] = ACTIONS(5740),
    [anon_sym_clocking] = ACTIONS(5740),
    [anon_sym_defparam] = ACTIONS(5740),
    [anon_sym_bind] = ACTIONS(5740),
    [anon_sym_const] = ACTIONS(5740),
    [anon_sym_function] = ACTIONS(5740),
    [anon_sym_static] = ACTIONS(5740),
    [anon_sym_constraint] = ACTIONS(5740),
    [anon_sym_if] = ACTIONS(5740),
    [anon_sym_LBRACK] = ACTIONS(5738),
    [anon_sym_localparam] = ACTIONS(5740),
    [anon_sym_parameter] = ACTIONS(5740),
    [anon_sym_specparam] = ACTIONS(5740),
    [anon_sym_var] = ACTIONS(5740),
    [anon_sym_import] = ACTIONS(5740),
    [anon_sym_export] = ACTIONS(5740),
    [anon_sym_genvar] = ACTIONS(5740),
    [anon_sym_interconnect] = ACTIONS(5740),
    [anon_sym_typedef] = ACTIONS(5740),
    [anon_sym_enum] = ACTIONS(5740),
    [anon_sym_struct] = ACTIONS(5740),
    [anon_sym_union] = ACTIONS(5740),
    [anon_sym_nettype] = ACTIONS(5740),
    [anon_sym_automatic] = ACTIONS(5740),
    [anon_sym_string] = ACTIONS(5740),
    [anon_sym_chandle] = ACTIONS(5740),
    [anon_sym_event] = ACTIONS(5740),
    [anon_sym_byte] = ACTIONS(5740),
    [anon_sym_shortint] = ACTIONS(5740),
    [anon_sym_int] = ACTIONS(5740),
    [anon_sym_longint] = ACTIONS(5740),
    [anon_sym_integer] = ACTIONS(5740),
    [anon_sym_time] = ACTIONS(5740),
    [anon_sym_bit] = ACTIONS(5740),
    [anon_sym_logic] = ACTIONS(5740),
    [anon_sym_reg] = ACTIONS(5740),
    [anon_sym_shortreal] = ACTIONS(5740),
    [anon_sym_real] = ACTIONS(5740),
    [anon_sym_realtime] = ACTIONS(5740),
    [anon_sym_supply0] = ACTIONS(5740),
    [anon_sym_supply1] = ACTIONS(5740),
    [anon_sym_signed] = ACTIONS(5740),
    [anon_sym_unsigned] = ACTIONS(5740),
    [anon_sym_task] = ACTIONS(5740),
    [anon_sym_modport] = ACTIONS(5740),
    [anon_sym_assert] = ACTIONS(5740),
    [anon_sym_property] = ACTIONS(5740),
    [anon_sym_assume] = ACTIONS(5740),
    [anon_sym_cover] = ACTIONS(5740),
    [anon_sym_sequence] = ACTIONS(5740),
    [anon_sym_restrict] = ACTIONS(5740),
    [anon_sym_not] = ACTIONS(5740),
    [anon_sym_or] = ACTIONS(5740),
    [anon_sym_and] = ACTIONS(5740),
    [anon_sym_case] = ACTIONS(5740),
    [anon_sym_always] = ACTIONS(5740),
    [anon_sym_covergroup] = ACTIONS(5740),
    [anon_sym_let] = ACTIONS(5740),
    [anon_sym_pulldown] = ACTIONS(5740),
    [anon_sym_pullup] = ACTIONS(5740),
    [anon_sym_cmos] = ACTIONS(5740),
    [anon_sym_rcmos] = ACTIONS(5740),
    [anon_sym_bufif0] = ACTIONS(5740),
    [anon_sym_bufif1] = ACTIONS(5740),
    [anon_sym_notif0] = ACTIONS(5740),
    [anon_sym_notif1] = ACTIONS(5740),
    [anon_sym_nmos] = ACTIONS(5740),
    [anon_sym_pmos] = ACTIONS(5740),
    [anon_sym_rnmos] = ACTIONS(5740),
    [anon_sym_rpmos] = ACTIONS(5740),
    [anon_sym_nand] = ACTIONS(5740),
    [anon_sym_nor] = ACTIONS(5740),
    [anon_sym_xor] = ACTIONS(5740),
    [anon_sym_xnor] = ACTIONS(5740),
    [anon_sym_buf] = ACTIONS(5740),
    [anon_sym_tranif0] = ACTIONS(5740),
    [anon_sym_tranif1] = ACTIONS(5740),
    [anon_sym_rtranif1] = ACTIONS(5740),
    [anon_sym_rtranif0] = ACTIONS(5740),
    [anon_sym_tran] = ACTIONS(5740),
    [anon_sym_rtran] = ACTIONS(5740),
    [anon_sym_generate] = ACTIONS(5740),
    [anon_sym_for] = ACTIONS(5740),
    [anon_sym_primitive] = ACTIONS(5740),
    [anon_sym_initial] = ACTIONS(5740),
    [anon_sym_assign] = ACTIONS(5740),
    [anon_sym_alias] = ACTIONS(5740),
    [anon_sym_always_comb] = ACTIONS(5740),
    [anon_sym_always_latch] = ACTIONS(5740),
    [anon_sym_always_ff] = ACTIONS(5740),
    [anon_sym_final] = ACTIONS(5740),
    [anon_sym_global] = ACTIONS(5740),
    [anon_sym_specify] = ACTIONS(5740),
    [anon_sym_LPAREN_STAR] = ACTIONS(5738),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5738),
    [anon_sym_DOLLARunit] = ACTIONS(5738),
  },
  [1022] = {
    [ts_builtin_sym_end] = ACTIONS(5744),
    [sym_simple_identifier] = ACTIONS(5746),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5744),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5744),
    [anon_sym_BQUOTE] = ACTIONS(5746),
    [aux_sym_id_directive_token1] = ACTIONS(5744),
    [aux_sym_id_directive_token2] = ACTIONS(5744),
    [aux_sym_id_directive_token3] = ACTIONS(5744),
    [aux_sym_id_directive_token4] = ACTIONS(5746),
    [aux_sym_zero_directive_token1] = ACTIONS(5744),
    [aux_sym_zero_directive_token2] = ACTIONS(5744),
    [aux_sym_zero_directive_token3] = ACTIONS(5744),
    [aux_sym_zero_directive_token4] = ACTIONS(5744),
    [aux_sym_zero_directive_token5] = ACTIONS(5744),
    [aux_sym_zero_directive_token6] = ACTIONS(5744),
    [aux_sym_zero_directive_token7] = ACTIONS(5744),
    [aux_sym_zero_directive_token8] = ACTIONS(5744),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5744),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5744),
    [anon_sym_wire] = ACTIONS(5746),
    [anon_sym_tri] = ACTIONS(5746),
    [anon_sym_tri0] = ACTIONS(5746),
    [anon_sym_tri1] = ACTIONS(5746),
    [anon_sym_wand] = ACTIONS(5746),
    [anon_sym_triand] = ACTIONS(5746),
    [anon_sym_wor] = ACTIONS(5746),
    [anon_sym_trior] = ACTIONS(5746),
    [anon_sym_trireg] = ACTIONS(5746),
    [anon_sym_uwire] = ACTIONS(5746),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5744),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5744),
    [aux_sym_begin_keywords_token1] = ACTIONS(5744),
    [anon_sym_SEMI] = ACTIONS(5744),
    [anon_sym_endmodule] = ACTIONS(5746),
    [anon_sym_COLON] = ACTIONS(5748),
    [anon_sym_extern] = ACTIONS(5746),
    [anon_sym_module] = ACTIONS(5746),
    [anon_sym_macromodule] = ACTIONS(5746),
    [anon_sym_endinterface] = ACTIONS(5746),
    [anon_sym_interface] = ACTIONS(5746),
    [anon_sym_program] = ACTIONS(5746),
    [anon_sym_checker] = ACTIONS(5746),
    [anon_sym_virtual] = ACTIONS(5746),
    [anon_sym_class] = ACTIONS(5746),
    [anon_sym_package] = ACTIONS(5746),
    [anon_sym_timeunit] = ACTIONS(5746),
    [anon_sym_timeprecision] = ACTIONS(5746),
    [anon_sym_type] = ACTIONS(5746),
    [anon_sym_input] = ACTIONS(5746),
    [anon_sym_output] = ACTIONS(5746),
    [anon_sym_inout] = ACTIONS(5746),
    [anon_sym_ref] = ACTIONS(5746),
    [anon_sym_DOLLARfatal] = ACTIONS(5744),
    [anon_sym_DOLLARerror] = ACTIONS(5744),
    [anon_sym_DOLLARwarning] = ACTIONS(5744),
    [anon_sym_DOLLARinfo] = ACTIONS(5744),
    [anon_sym_default] = ACTIONS(5746),
    [anon_sym_clocking] = ACTIONS(5746),
    [anon_sym_defparam] = ACTIONS(5746),
    [anon_sym_bind] = ACTIONS(5746),
    [anon_sym_const] = ACTIONS(5746),
    [anon_sym_function] = ACTIONS(5746),
    [anon_sym_static] = ACTIONS(5746),
    [anon_sym_constraint] = ACTIONS(5746),
    [anon_sym_if] = ACTIONS(5746),
    [anon_sym_LBRACK] = ACTIONS(5744),
    [anon_sym_localparam] = ACTIONS(5746),
    [anon_sym_parameter] = ACTIONS(5746),
    [anon_sym_specparam] = ACTIONS(5746),
    [anon_sym_var] = ACTIONS(5746),
    [anon_sym_import] = ACTIONS(5746),
    [anon_sym_export] = ACTIONS(5746),
    [anon_sym_genvar] = ACTIONS(5746),
    [anon_sym_interconnect] = ACTIONS(5746),
    [anon_sym_typedef] = ACTIONS(5746),
    [anon_sym_enum] = ACTIONS(5746),
    [anon_sym_struct] = ACTIONS(5746),
    [anon_sym_union] = ACTIONS(5746),
    [anon_sym_nettype] = ACTIONS(5746),
    [anon_sym_automatic] = ACTIONS(5746),
    [anon_sym_string] = ACTIONS(5746),
    [anon_sym_chandle] = ACTIONS(5746),
    [anon_sym_event] = ACTIONS(5746),
    [anon_sym_byte] = ACTIONS(5746),
    [anon_sym_shortint] = ACTIONS(5746),
    [anon_sym_int] = ACTIONS(5746),
    [anon_sym_longint] = ACTIONS(5746),
    [anon_sym_integer] = ACTIONS(5746),
    [anon_sym_time] = ACTIONS(5746),
    [anon_sym_bit] = ACTIONS(5746),
    [anon_sym_logic] = ACTIONS(5746),
    [anon_sym_reg] = ACTIONS(5746),
    [anon_sym_shortreal] = ACTIONS(5746),
    [anon_sym_real] = ACTIONS(5746),
    [anon_sym_realtime] = ACTIONS(5746),
    [anon_sym_supply0] = ACTIONS(5746),
    [anon_sym_supply1] = ACTIONS(5746),
    [anon_sym_signed] = ACTIONS(5746),
    [anon_sym_unsigned] = ACTIONS(5746),
    [anon_sym_task] = ACTIONS(5746),
    [anon_sym_modport] = ACTIONS(5746),
    [anon_sym_assert] = ACTIONS(5746),
    [anon_sym_property] = ACTIONS(5746),
    [anon_sym_assume] = ACTIONS(5746),
    [anon_sym_cover] = ACTIONS(5746),
    [anon_sym_sequence] = ACTIONS(5746),
    [anon_sym_restrict] = ACTIONS(5746),
    [anon_sym_not] = ACTIONS(5746),
    [anon_sym_or] = ACTIONS(5746),
    [anon_sym_and] = ACTIONS(5746),
    [anon_sym_case] = ACTIONS(5746),
    [anon_sym_always] = ACTIONS(5746),
    [anon_sym_covergroup] = ACTIONS(5746),
    [anon_sym_let] = ACTIONS(5746),
    [anon_sym_pulldown] = ACTIONS(5746),
    [anon_sym_pullup] = ACTIONS(5746),
    [anon_sym_cmos] = ACTIONS(5746),
    [anon_sym_rcmos] = ACTIONS(5746),
    [anon_sym_bufif0] = ACTIONS(5746),
    [anon_sym_bufif1] = ACTIONS(5746),
    [anon_sym_notif0] = ACTIONS(5746),
    [anon_sym_notif1] = ACTIONS(5746),
    [anon_sym_nmos] = ACTIONS(5746),
    [anon_sym_pmos] = ACTIONS(5746),
    [anon_sym_rnmos] = ACTIONS(5746),
    [anon_sym_rpmos] = ACTIONS(5746),
    [anon_sym_nand] = ACTIONS(5746),
    [anon_sym_nor] = ACTIONS(5746),
    [anon_sym_xor] = ACTIONS(5746),
    [anon_sym_xnor] = ACTIONS(5746),
    [anon_sym_buf] = ACTIONS(5746),
    [anon_sym_tranif0] = ACTIONS(5746),
    [anon_sym_tranif1] = ACTIONS(5746),
    [anon_sym_rtranif1] = ACTIONS(5746),
    [anon_sym_rtranif0] = ACTIONS(5746),
    [anon_sym_tran] = ACTIONS(5746),
    [anon_sym_rtran] = ACTIONS(5746),
    [anon_sym_generate] = ACTIONS(5746),
    [anon_sym_for] = ACTIONS(5746),
    [anon_sym_primitive] = ACTIONS(5746),
    [anon_sym_initial] = ACTIONS(5746),
    [anon_sym_assign] = ACTIONS(5746),
    [anon_sym_alias] = ACTIONS(5746),
    [anon_sym_always_comb] = ACTIONS(5746),
    [anon_sym_always_latch] = ACTIONS(5746),
    [anon_sym_always_ff] = ACTIONS(5746),
    [anon_sym_final] = ACTIONS(5746),
    [anon_sym_global] = ACTIONS(5746),
    [anon_sym_specify] = ACTIONS(5746),
    [anon_sym_LPAREN_STAR] = ACTIONS(5744),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5744),
    [anon_sym_DOLLARunit] = ACTIONS(5744),
  },
  [1023] = {
    [ts_builtin_sym_end] = ACTIONS(5750),
    [sym_simple_identifier] = ACTIONS(5752),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5750),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5750),
    [anon_sym_BQUOTE] = ACTIONS(5752),
    [aux_sym_id_directive_token1] = ACTIONS(5750),
    [aux_sym_id_directive_token2] = ACTIONS(5750),
    [aux_sym_id_directive_token3] = ACTIONS(5750),
    [aux_sym_id_directive_token4] = ACTIONS(5752),
    [aux_sym_zero_directive_token1] = ACTIONS(5750),
    [aux_sym_zero_directive_token2] = ACTIONS(5750),
    [aux_sym_zero_directive_token3] = ACTIONS(5750),
    [aux_sym_zero_directive_token4] = ACTIONS(5750),
    [aux_sym_zero_directive_token5] = ACTIONS(5750),
    [aux_sym_zero_directive_token6] = ACTIONS(5750),
    [aux_sym_zero_directive_token7] = ACTIONS(5750),
    [aux_sym_zero_directive_token8] = ACTIONS(5750),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5750),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5750),
    [anon_sym_wire] = ACTIONS(5752),
    [anon_sym_tri] = ACTIONS(5752),
    [anon_sym_tri0] = ACTIONS(5752),
    [anon_sym_tri1] = ACTIONS(5752),
    [anon_sym_wand] = ACTIONS(5752),
    [anon_sym_triand] = ACTIONS(5752),
    [anon_sym_wor] = ACTIONS(5752),
    [anon_sym_trior] = ACTIONS(5752),
    [anon_sym_trireg] = ACTIONS(5752),
    [anon_sym_uwire] = ACTIONS(5752),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5750),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5750),
    [aux_sym_begin_keywords_token1] = ACTIONS(5750),
    [anon_sym_SEMI] = ACTIONS(5750),
    [anon_sym_endmodule] = ACTIONS(5752),
    [anon_sym_COLON] = ACTIONS(5754),
    [anon_sym_extern] = ACTIONS(5752),
    [anon_sym_module] = ACTIONS(5752),
    [anon_sym_macromodule] = ACTIONS(5752),
    [anon_sym_endinterface] = ACTIONS(5752),
    [anon_sym_interface] = ACTIONS(5752),
    [anon_sym_program] = ACTIONS(5752),
    [anon_sym_checker] = ACTIONS(5752),
    [anon_sym_virtual] = ACTIONS(5752),
    [anon_sym_class] = ACTIONS(5752),
    [anon_sym_package] = ACTIONS(5752),
    [anon_sym_timeunit] = ACTIONS(5752),
    [anon_sym_timeprecision] = ACTIONS(5752),
    [anon_sym_type] = ACTIONS(5752),
    [anon_sym_input] = ACTIONS(5752),
    [anon_sym_output] = ACTIONS(5752),
    [anon_sym_inout] = ACTIONS(5752),
    [anon_sym_ref] = ACTIONS(5752),
    [anon_sym_DOLLARfatal] = ACTIONS(5750),
    [anon_sym_DOLLARerror] = ACTIONS(5750),
    [anon_sym_DOLLARwarning] = ACTIONS(5750),
    [anon_sym_DOLLARinfo] = ACTIONS(5750),
    [anon_sym_default] = ACTIONS(5752),
    [anon_sym_clocking] = ACTIONS(5752),
    [anon_sym_defparam] = ACTIONS(5752),
    [anon_sym_bind] = ACTIONS(5752),
    [anon_sym_const] = ACTIONS(5752),
    [anon_sym_function] = ACTIONS(5752),
    [anon_sym_static] = ACTIONS(5752),
    [anon_sym_constraint] = ACTIONS(5752),
    [anon_sym_if] = ACTIONS(5752),
    [anon_sym_LBRACK] = ACTIONS(5750),
    [anon_sym_localparam] = ACTIONS(5752),
    [anon_sym_parameter] = ACTIONS(5752),
    [anon_sym_specparam] = ACTIONS(5752),
    [anon_sym_var] = ACTIONS(5752),
    [anon_sym_import] = ACTIONS(5752),
    [anon_sym_export] = ACTIONS(5752),
    [anon_sym_genvar] = ACTIONS(5752),
    [anon_sym_interconnect] = ACTIONS(5752),
    [anon_sym_typedef] = ACTIONS(5752),
    [anon_sym_enum] = ACTIONS(5752),
    [anon_sym_struct] = ACTIONS(5752),
    [anon_sym_union] = ACTIONS(5752),
    [anon_sym_nettype] = ACTIONS(5752),
    [anon_sym_automatic] = ACTIONS(5752),
    [anon_sym_string] = ACTIONS(5752),
    [anon_sym_chandle] = ACTIONS(5752),
    [anon_sym_event] = ACTIONS(5752),
    [anon_sym_byte] = ACTIONS(5752),
    [anon_sym_shortint] = ACTIONS(5752),
    [anon_sym_int] = ACTIONS(5752),
    [anon_sym_longint] = ACTIONS(5752),
    [anon_sym_integer] = ACTIONS(5752),
    [anon_sym_time] = ACTIONS(5752),
    [anon_sym_bit] = ACTIONS(5752),
    [anon_sym_logic] = ACTIONS(5752),
    [anon_sym_reg] = ACTIONS(5752),
    [anon_sym_shortreal] = ACTIONS(5752),
    [anon_sym_real] = ACTIONS(5752),
    [anon_sym_realtime] = ACTIONS(5752),
    [anon_sym_supply0] = ACTIONS(5752),
    [anon_sym_supply1] = ACTIONS(5752),
    [anon_sym_signed] = ACTIONS(5752),
    [anon_sym_unsigned] = ACTIONS(5752),
    [anon_sym_task] = ACTIONS(5752),
    [anon_sym_modport] = ACTIONS(5752),
    [anon_sym_assert] = ACTIONS(5752),
    [anon_sym_property] = ACTIONS(5752),
    [anon_sym_assume] = ACTIONS(5752),
    [anon_sym_cover] = ACTIONS(5752),
    [anon_sym_sequence] = ACTIONS(5752),
    [anon_sym_restrict] = ACTIONS(5752),
    [anon_sym_not] = ACTIONS(5752),
    [anon_sym_or] = ACTIONS(5752),
    [anon_sym_and] = ACTIONS(5752),
    [anon_sym_case] = ACTIONS(5752),
    [anon_sym_always] = ACTIONS(5752),
    [anon_sym_covergroup] = ACTIONS(5752),
    [anon_sym_let] = ACTIONS(5752),
    [anon_sym_pulldown] = ACTIONS(5752),
    [anon_sym_pullup] = ACTIONS(5752),
    [anon_sym_cmos] = ACTIONS(5752),
    [anon_sym_rcmos] = ACTIONS(5752),
    [anon_sym_bufif0] = ACTIONS(5752),
    [anon_sym_bufif1] = ACTIONS(5752),
    [anon_sym_notif0] = ACTIONS(5752),
    [anon_sym_notif1] = ACTIONS(5752),
    [anon_sym_nmos] = ACTIONS(5752),
    [anon_sym_pmos] = ACTIONS(5752),
    [anon_sym_rnmos] = ACTIONS(5752),
    [anon_sym_rpmos] = ACTIONS(5752),
    [anon_sym_nand] = ACTIONS(5752),
    [anon_sym_nor] = ACTIONS(5752),
    [anon_sym_xor] = ACTIONS(5752),
    [anon_sym_xnor] = ACTIONS(5752),
    [anon_sym_buf] = ACTIONS(5752),
    [anon_sym_tranif0] = ACTIONS(5752),
    [anon_sym_tranif1] = ACTIONS(5752),
    [anon_sym_rtranif1] = ACTIONS(5752),
    [anon_sym_rtranif0] = ACTIONS(5752),
    [anon_sym_tran] = ACTIONS(5752),
    [anon_sym_rtran] = ACTIONS(5752),
    [anon_sym_generate] = ACTIONS(5752),
    [anon_sym_for] = ACTIONS(5752),
    [anon_sym_primitive] = ACTIONS(5752),
    [anon_sym_initial] = ACTIONS(5752),
    [anon_sym_assign] = ACTIONS(5752),
    [anon_sym_alias] = ACTIONS(5752),
    [anon_sym_always_comb] = ACTIONS(5752),
    [anon_sym_always_latch] = ACTIONS(5752),
    [anon_sym_always_ff] = ACTIONS(5752),
    [anon_sym_final] = ACTIONS(5752),
    [anon_sym_global] = ACTIONS(5752),
    [anon_sym_specify] = ACTIONS(5752),
    [anon_sym_LPAREN_STAR] = ACTIONS(5750),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5750),
    [anon_sym_DOLLARunit] = ACTIONS(5750),
  },
  [1024] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5758),
    [anon_sym_BQUOTE] = ACTIONS(5756),
    [aux_sym_id_directive_token1] = ACTIONS(5758),
    [aux_sym_id_directive_token2] = ACTIONS(5758),
    [aux_sym_id_directive_token3] = ACTIONS(5758),
    [aux_sym_id_directive_token4] = ACTIONS(5756),
    [aux_sym_zero_directive_token1] = ACTIONS(5758),
    [aux_sym_zero_directive_token2] = ACTIONS(5758),
    [aux_sym_zero_directive_token3] = ACTIONS(5758),
    [aux_sym_zero_directive_token4] = ACTIONS(5758),
    [aux_sym_zero_directive_token5] = ACTIONS(5758),
    [aux_sym_zero_directive_token6] = ACTIONS(5758),
    [aux_sym_zero_directive_token7] = ACTIONS(5758),
    [aux_sym_zero_directive_token8] = ACTIONS(5758),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5758),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5758),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_begin_keywords_token1] = ACTIONS(5758),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_endmodule] = ACTIONS(5756),
    [anon_sym_COLON] = ACTIONS(5760),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_module] = ACTIONS(5756),
    [anon_sym_macromodule] = ACTIONS(5756),
    [anon_sym_endinterface] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_endprogram] = ACTIONS(5756),
    [anon_sym_program] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_timeunit] = ACTIONS(5756),
    [anon_sym_timeprecision] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_input] = ACTIONS(5756),
    [anon_sym_output] = ACTIONS(5756),
    [anon_sym_inout] = ACTIONS(5756),
    [anon_sym_ref] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_specparam] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_modport] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_while] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_specify] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [1025] = {
    [ts_builtin_sym_end] = ACTIONS(5762),
    [sym_simple_identifier] = ACTIONS(5764),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5762),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5762),
    [anon_sym_BQUOTE] = ACTIONS(5764),
    [aux_sym_id_directive_token1] = ACTIONS(5762),
    [aux_sym_id_directive_token2] = ACTIONS(5762),
    [aux_sym_id_directive_token3] = ACTIONS(5762),
    [aux_sym_id_directive_token4] = ACTIONS(5764),
    [aux_sym_zero_directive_token1] = ACTIONS(5762),
    [aux_sym_zero_directive_token2] = ACTIONS(5762),
    [aux_sym_zero_directive_token3] = ACTIONS(5762),
    [aux_sym_zero_directive_token4] = ACTIONS(5762),
    [aux_sym_zero_directive_token5] = ACTIONS(5762),
    [aux_sym_zero_directive_token6] = ACTIONS(5762),
    [aux_sym_zero_directive_token7] = ACTIONS(5762),
    [aux_sym_zero_directive_token8] = ACTIONS(5762),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5762),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5762),
    [anon_sym_wire] = ACTIONS(5764),
    [anon_sym_tri] = ACTIONS(5764),
    [anon_sym_tri0] = ACTIONS(5764),
    [anon_sym_tri1] = ACTIONS(5764),
    [anon_sym_wand] = ACTIONS(5764),
    [anon_sym_triand] = ACTIONS(5764),
    [anon_sym_wor] = ACTIONS(5764),
    [anon_sym_trior] = ACTIONS(5764),
    [anon_sym_trireg] = ACTIONS(5764),
    [anon_sym_uwire] = ACTIONS(5764),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5762),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5762),
    [aux_sym_begin_keywords_token1] = ACTIONS(5762),
    [anon_sym_SEMI] = ACTIONS(5762),
    [anon_sym_endmodule] = ACTIONS(5764),
    [anon_sym_extern] = ACTIONS(5764),
    [anon_sym_module] = ACTIONS(5764),
    [anon_sym_macromodule] = ACTIONS(5764),
    [anon_sym_endinterface] = ACTIONS(5764),
    [anon_sym_interface] = ACTIONS(5764),
    [anon_sym_endprogram] = ACTIONS(5764),
    [anon_sym_program] = ACTIONS(5764),
    [anon_sym_checker] = ACTIONS(5764),
    [anon_sym_virtual] = ACTIONS(5764),
    [anon_sym_class] = ACTIONS(5764),
    [anon_sym_package] = ACTIONS(5764),
    [anon_sym_timeunit] = ACTIONS(5764),
    [anon_sym_timeprecision] = ACTIONS(5764),
    [anon_sym_type] = ACTIONS(5764),
    [anon_sym_input] = ACTIONS(5764),
    [anon_sym_output] = ACTIONS(5764),
    [anon_sym_inout] = ACTIONS(5764),
    [anon_sym_ref] = ACTIONS(5764),
    [anon_sym_DOLLARfatal] = ACTIONS(5762),
    [anon_sym_DOLLARerror] = ACTIONS(5762),
    [anon_sym_DOLLARwarning] = ACTIONS(5762),
    [anon_sym_DOLLARinfo] = ACTIONS(5762),
    [anon_sym_default] = ACTIONS(5764),
    [anon_sym_clocking] = ACTIONS(5764),
    [anon_sym_defparam] = ACTIONS(5764),
    [anon_sym_bind] = ACTIONS(5764),
    [anon_sym_const] = ACTIONS(5764),
    [anon_sym_function] = ACTIONS(5764),
    [anon_sym_static] = ACTIONS(5764),
    [anon_sym_constraint] = ACTIONS(5764),
    [anon_sym_if] = ACTIONS(5764),
    [anon_sym_LBRACK] = ACTIONS(5762),
    [anon_sym_localparam] = ACTIONS(5764),
    [anon_sym_parameter] = ACTIONS(5764),
    [anon_sym_specparam] = ACTIONS(5764),
    [anon_sym_var] = ACTIONS(5764),
    [anon_sym_import] = ACTIONS(5764),
    [anon_sym_export] = ACTIONS(5764),
    [anon_sym_genvar] = ACTIONS(5764),
    [anon_sym_interconnect] = ACTIONS(5764),
    [anon_sym_typedef] = ACTIONS(5764),
    [anon_sym_enum] = ACTIONS(5764),
    [anon_sym_struct] = ACTIONS(5764),
    [anon_sym_union] = ACTIONS(5764),
    [anon_sym_nettype] = ACTIONS(5764),
    [anon_sym_automatic] = ACTIONS(5764),
    [anon_sym_string] = ACTIONS(5764),
    [anon_sym_chandle] = ACTIONS(5764),
    [anon_sym_event] = ACTIONS(5764),
    [anon_sym_byte] = ACTIONS(5764),
    [anon_sym_shortint] = ACTIONS(5764),
    [anon_sym_int] = ACTIONS(5764),
    [anon_sym_longint] = ACTIONS(5764),
    [anon_sym_integer] = ACTIONS(5764),
    [anon_sym_time] = ACTIONS(5764),
    [anon_sym_bit] = ACTIONS(5764),
    [anon_sym_logic] = ACTIONS(5764),
    [anon_sym_reg] = ACTIONS(5764),
    [anon_sym_shortreal] = ACTIONS(5764),
    [anon_sym_real] = ACTIONS(5764),
    [anon_sym_realtime] = ACTIONS(5764),
    [anon_sym_supply0] = ACTIONS(5764),
    [anon_sym_supply1] = ACTIONS(5764),
    [anon_sym_signed] = ACTIONS(5764),
    [anon_sym_unsigned] = ACTIONS(5764),
    [anon_sym_task] = ACTIONS(5764),
    [anon_sym_modport] = ACTIONS(5764),
    [anon_sym_assert] = ACTIONS(5764),
    [anon_sym_property] = ACTIONS(5764),
    [anon_sym_assume] = ACTIONS(5764),
    [anon_sym_cover] = ACTIONS(5764),
    [anon_sym_sequence] = ACTIONS(5764),
    [anon_sym_restrict] = ACTIONS(5764),
    [anon_sym_not] = ACTIONS(5764),
    [anon_sym_or] = ACTIONS(5764),
    [anon_sym_and] = ACTIONS(5764),
    [anon_sym_case] = ACTIONS(5764),
    [anon_sym_always] = ACTIONS(5764),
    [anon_sym_covergroup] = ACTIONS(5764),
    [anon_sym_let] = ACTIONS(5764),
    [anon_sym_pulldown] = ACTIONS(5764),
    [anon_sym_pullup] = ACTIONS(5764),
    [anon_sym_cmos] = ACTIONS(5764),
    [anon_sym_rcmos] = ACTIONS(5764),
    [anon_sym_bufif0] = ACTIONS(5764),
    [anon_sym_bufif1] = ACTIONS(5764),
    [anon_sym_notif0] = ACTIONS(5764),
    [anon_sym_notif1] = ACTIONS(5764),
    [anon_sym_nmos] = ACTIONS(5764),
    [anon_sym_pmos] = ACTIONS(5764),
    [anon_sym_rnmos] = ACTIONS(5764),
    [anon_sym_rpmos] = ACTIONS(5764),
    [anon_sym_nand] = ACTIONS(5764),
    [anon_sym_nor] = ACTIONS(5764),
    [anon_sym_xor] = ACTIONS(5764),
    [anon_sym_xnor] = ACTIONS(5764),
    [anon_sym_buf] = ACTIONS(5764),
    [anon_sym_tranif0] = ACTIONS(5764),
    [anon_sym_tranif1] = ACTIONS(5764),
    [anon_sym_rtranif1] = ACTIONS(5764),
    [anon_sym_rtranif0] = ACTIONS(5764),
    [anon_sym_tran] = ACTIONS(5764),
    [anon_sym_rtran] = ACTIONS(5764),
    [anon_sym_generate] = ACTIONS(5764),
    [anon_sym_for] = ACTIONS(5764),
    [anon_sym_primitive] = ACTIONS(5764),
    [anon_sym_initial] = ACTIONS(5764),
    [anon_sym_assign] = ACTIONS(5764),
    [anon_sym_alias] = ACTIONS(5764),
    [anon_sym_always_comb] = ACTIONS(5764),
    [anon_sym_always_latch] = ACTIONS(5764),
    [anon_sym_always_ff] = ACTIONS(5764),
    [anon_sym_final] = ACTIONS(5764),
    [anon_sym_global] = ACTIONS(5764),
    [anon_sym_specify] = ACTIONS(5764),
    [anon_sym_LPAREN_STAR] = ACTIONS(5762),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5762),
    [anon_sym_DOLLARunit] = ACTIONS(5762),
  },
  [1026] = {
    [ts_builtin_sym_end] = ACTIONS(5766),
    [sym_simple_identifier] = ACTIONS(5768),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5766),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5766),
    [anon_sym_BQUOTE] = ACTIONS(5768),
    [aux_sym_id_directive_token1] = ACTIONS(5766),
    [aux_sym_id_directive_token2] = ACTIONS(5766),
    [aux_sym_id_directive_token3] = ACTIONS(5766),
    [aux_sym_id_directive_token4] = ACTIONS(5768),
    [aux_sym_zero_directive_token1] = ACTIONS(5766),
    [aux_sym_zero_directive_token2] = ACTIONS(5766),
    [aux_sym_zero_directive_token3] = ACTIONS(5766),
    [aux_sym_zero_directive_token4] = ACTIONS(5766),
    [aux_sym_zero_directive_token5] = ACTIONS(5766),
    [aux_sym_zero_directive_token6] = ACTIONS(5766),
    [aux_sym_zero_directive_token7] = ACTIONS(5766),
    [aux_sym_zero_directive_token8] = ACTIONS(5766),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5766),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5766),
    [anon_sym_wire] = ACTIONS(5768),
    [anon_sym_tri] = ACTIONS(5768),
    [anon_sym_tri0] = ACTIONS(5768),
    [anon_sym_tri1] = ACTIONS(5768),
    [anon_sym_wand] = ACTIONS(5768),
    [anon_sym_triand] = ACTIONS(5768),
    [anon_sym_wor] = ACTIONS(5768),
    [anon_sym_trior] = ACTIONS(5768),
    [anon_sym_trireg] = ACTIONS(5768),
    [anon_sym_uwire] = ACTIONS(5768),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5766),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5766),
    [aux_sym_begin_keywords_token1] = ACTIONS(5766),
    [anon_sym_SEMI] = ACTIONS(5766),
    [anon_sym_endmodule] = ACTIONS(5768),
    [anon_sym_extern] = ACTIONS(5768),
    [anon_sym_module] = ACTIONS(5768),
    [anon_sym_macromodule] = ACTIONS(5768),
    [anon_sym_endinterface] = ACTIONS(5768),
    [anon_sym_interface] = ACTIONS(5768),
    [anon_sym_program] = ACTIONS(5768),
    [anon_sym_checker] = ACTIONS(5768),
    [anon_sym_virtual] = ACTIONS(5768),
    [anon_sym_class] = ACTIONS(5768),
    [anon_sym_package] = ACTIONS(5768),
    [anon_sym_timeunit] = ACTIONS(5768),
    [anon_sym_timeprecision] = ACTIONS(5768),
    [anon_sym_type] = ACTIONS(5768),
    [anon_sym_input] = ACTIONS(5768),
    [anon_sym_output] = ACTIONS(5768),
    [anon_sym_inout] = ACTIONS(5768),
    [anon_sym_ref] = ACTIONS(5768),
    [anon_sym_DOLLARfatal] = ACTIONS(5766),
    [anon_sym_DOLLARerror] = ACTIONS(5766),
    [anon_sym_DOLLARwarning] = ACTIONS(5766),
    [anon_sym_DOLLARinfo] = ACTIONS(5766),
    [anon_sym_default] = ACTIONS(5768),
    [anon_sym_clocking] = ACTIONS(5768),
    [anon_sym_defparam] = ACTIONS(5768),
    [anon_sym_bind] = ACTIONS(5768),
    [anon_sym_const] = ACTIONS(5768),
    [anon_sym_function] = ACTIONS(5768),
    [anon_sym_static] = ACTIONS(5768),
    [anon_sym_constraint] = ACTIONS(5768),
    [anon_sym_if] = ACTIONS(5768),
    [anon_sym_LBRACK] = ACTIONS(5766),
    [anon_sym_localparam] = ACTIONS(5768),
    [anon_sym_parameter] = ACTIONS(5768),
    [anon_sym_specparam] = ACTIONS(5768),
    [anon_sym_var] = ACTIONS(5768),
    [anon_sym_import] = ACTIONS(5768),
    [anon_sym_export] = ACTIONS(5768),
    [anon_sym_genvar] = ACTIONS(5768),
    [anon_sym_interconnect] = ACTIONS(5768),
    [anon_sym_typedef] = ACTIONS(5768),
    [anon_sym_enum] = ACTIONS(5768),
    [anon_sym_struct] = ACTIONS(5768),
    [anon_sym_union] = ACTIONS(5768),
    [anon_sym_nettype] = ACTIONS(5768),
    [anon_sym_automatic] = ACTIONS(5768),
    [anon_sym_string] = ACTIONS(5768),
    [anon_sym_chandle] = ACTIONS(5768),
    [anon_sym_event] = ACTIONS(5768),
    [anon_sym_byte] = ACTIONS(5768),
    [anon_sym_shortint] = ACTIONS(5768),
    [anon_sym_int] = ACTIONS(5768),
    [anon_sym_longint] = ACTIONS(5768),
    [anon_sym_integer] = ACTIONS(5768),
    [anon_sym_time] = ACTIONS(5768),
    [anon_sym_bit] = ACTIONS(5768),
    [anon_sym_logic] = ACTIONS(5768),
    [anon_sym_reg] = ACTIONS(5768),
    [anon_sym_shortreal] = ACTIONS(5768),
    [anon_sym_real] = ACTIONS(5768),
    [anon_sym_realtime] = ACTIONS(5768),
    [anon_sym_supply0] = ACTIONS(5768),
    [anon_sym_supply1] = ACTIONS(5768),
    [anon_sym_signed] = ACTIONS(5768),
    [anon_sym_unsigned] = ACTIONS(5768),
    [anon_sym_task] = ACTIONS(5768),
    [anon_sym_modport] = ACTIONS(5768),
    [anon_sym_assert] = ACTIONS(5768),
    [anon_sym_property] = ACTIONS(5768),
    [anon_sym_assume] = ACTIONS(5768),
    [anon_sym_cover] = ACTIONS(5768),
    [anon_sym_sequence] = ACTIONS(5768),
    [anon_sym_restrict] = ACTIONS(5768),
    [anon_sym_not] = ACTIONS(5768),
    [anon_sym_or] = ACTIONS(5768),
    [anon_sym_and] = ACTIONS(5768),
    [anon_sym_case] = ACTIONS(5768),
    [anon_sym_always] = ACTIONS(5768),
    [anon_sym_covergroup] = ACTIONS(5768),
    [anon_sym_let] = ACTIONS(5768),
    [anon_sym_pulldown] = ACTIONS(5768),
    [anon_sym_pullup] = ACTIONS(5768),
    [anon_sym_cmos] = ACTIONS(5768),
    [anon_sym_rcmos] = ACTIONS(5768),
    [anon_sym_bufif0] = ACTIONS(5768),
    [anon_sym_bufif1] = ACTIONS(5768),
    [anon_sym_notif0] = ACTIONS(5768),
    [anon_sym_notif1] = ACTIONS(5768),
    [anon_sym_nmos] = ACTIONS(5768),
    [anon_sym_pmos] = ACTIONS(5768),
    [anon_sym_rnmos] = ACTIONS(5768),
    [anon_sym_rpmos] = ACTIONS(5768),
    [anon_sym_nand] = ACTIONS(5768),
    [anon_sym_nor] = ACTIONS(5768),
    [anon_sym_xor] = ACTIONS(5768),
    [anon_sym_xnor] = ACTIONS(5768),
    [anon_sym_buf] = ACTIONS(5768),
    [anon_sym_tranif0] = ACTIONS(5768),
    [anon_sym_tranif1] = ACTIONS(5768),
    [anon_sym_rtranif1] = ACTIONS(5768),
    [anon_sym_rtranif0] = ACTIONS(5768),
    [anon_sym_tran] = ACTIONS(5768),
    [anon_sym_rtran] = ACTIONS(5768),
    [anon_sym_generate] = ACTIONS(5768),
    [anon_sym_for] = ACTIONS(5768),
    [anon_sym_primitive] = ACTIONS(5768),
    [anon_sym_initial] = ACTIONS(5768),
    [anon_sym_assign] = ACTIONS(5768),
    [anon_sym_alias] = ACTIONS(5768),
    [anon_sym_always_comb] = ACTIONS(5768),
    [anon_sym_always_latch] = ACTIONS(5768),
    [anon_sym_always_ff] = ACTIONS(5768),
    [anon_sym_final] = ACTIONS(5768),
    [anon_sym_global] = ACTIONS(5768),
    [anon_sym_specify] = ACTIONS(5768),
    [anon_sym_LPAREN_STAR] = ACTIONS(5766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5766),
    [anon_sym_DOLLARunit] = ACTIONS(5766),
  },
  [1027] = {
    [sym_simple_identifier] = ACTIONS(5770),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5772),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5772),
    [anon_sym_BQUOTE] = ACTIONS(5770),
    [aux_sym_id_directive_token1] = ACTIONS(5772),
    [aux_sym_id_directive_token2] = ACTIONS(5772),
    [aux_sym_id_directive_token3] = ACTIONS(5772),
    [aux_sym_id_directive_token4] = ACTIONS(5770),
    [aux_sym_zero_directive_token1] = ACTIONS(5772),
    [aux_sym_zero_directive_token2] = ACTIONS(5772),
    [aux_sym_zero_directive_token3] = ACTIONS(5772),
    [aux_sym_zero_directive_token4] = ACTIONS(5772),
    [aux_sym_zero_directive_token5] = ACTIONS(5772),
    [aux_sym_zero_directive_token6] = ACTIONS(5772),
    [aux_sym_zero_directive_token7] = ACTIONS(5772),
    [aux_sym_zero_directive_token8] = ACTIONS(5772),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5772),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5772),
    [anon_sym_wire] = ACTIONS(5770),
    [anon_sym_tri] = ACTIONS(5770),
    [anon_sym_tri0] = ACTIONS(5770),
    [anon_sym_tri1] = ACTIONS(5770),
    [anon_sym_wand] = ACTIONS(5770),
    [anon_sym_triand] = ACTIONS(5770),
    [anon_sym_wor] = ACTIONS(5770),
    [anon_sym_trior] = ACTIONS(5770),
    [anon_sym_trireg] = ACTIONS(5770),
    [anon_sym_uwire] = ACTIONS(5770),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5772),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5772),
    [aux_sym_begin_keywords_token1] = ACTIONS(5772),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym_endmodule] = ACTIONS(5770),
    [anon_sym_extern] = ACTIONS(5770),
    [anon_sym_module] = ACTIONS(5770),
    [anon_sym_macromodule] = ACTIONS(5770),
    [anon_sym_endinterface] = ACTIONS(5770),
    [anon_sym_interface] = ACTIONS(5770),
    [anon_sym_endprogram] = ACTIONS(5770),
    [anon_sym_program] = ACTIONS(5770),
    [anon_sym_checker] = ACTIONS(5770),
    [anon_sym_virtual] = ACTIONS(5770),
    [anon_sym_class] = ACTIONS(5770),
    [anon_sym_timeunit] = ACTIONS(5770),
    [anon_sym_timeprecision] = ACTIONS(5770),
    [anon_sym_type] = ACTIONS(5770),
    [anon_sym_input] = ACTIONS(5770),
    [anon_sym_output] = ACTIONS(5770),
    [anon_sym_inout] = ACTIONS(5770),
    [anon_sym_ref] = ACTIONS(5770),
    [anon_sym_DOLLARfatal] = ACTIONS(5772),
    [anon_sym_DOLLARerror] = ACTIONS(5772),
    [anon_sym_DOLLARwarning] = ACTIONS(5772),
    [anon_sym_DOLLARinfo] = ACTIONS(5772),
    [anon_sym_default] = ACTIONS(5770),
    [anon_sym_clocking] = ACTIONS(5770),
    [anon_sym_defparam] = ACTIONS(5770),
    [anon_sym_bind] = ACTIONS(5770),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_function] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5770),
    [anon_sym_constraint] = ACTIONS(5770),
    [anon_sym_if] = ACTIONS(5770),
    [anon_sym_else] = ACTIONS(5770),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_localparam] = ACTIONS(5770),
    [anon_sym_parameter] = ACTIONS(5770),
    [anon_sym_specparam] = ACTIONS(5770),
    [anon_sym_var] = ACTIONS(5770),
    [anon_sym_import] = ACTIONS(5770),
    [anon_sym_export] = ACTIONS(5770),
    [anon_sym_genvar] = ACTIONS(5770),
    [anon_sym_interconnect] = ACTIONS(5770),
    [anon_sym_typedef] = ACTIONS(5770),
    [anon_sym_enum] = ACTIONS(5770),
    [anon_sym_struct] = ACTIONS(5770),
    [anon_sym_union] = ACTIONS(5770),
    [anon_sym_nettype] = ACTIONS(5770),
    [anon_sym_automatic] = ACTIONS(5770),
    [anon_sym_string] = ACTIONS(5770),
    [anon_sym_chandle] = ACTIONS(5770),
    [anon_sym_event] = ACTIONS(5770),
    [anon_sym_byte] = ACTIONS(5770),
    [anon_sym_shortint] = ACTIONS(5770),
    [anon_sym_int] = ACTIONS(5770),
    [anon_sym_longint] = ACTIONS(5770),
    [anon_sym_integer] = ACTIONS(5770),
    [anon_sym_time] = ACTIONS(5770),
    [anon_sym_bit] = ACTIONS(5770),
    [anon_sym_logic] = ACTIONS(5770),
    [anon_sym_reg] = ACTIONS(5770),
    [anon_sym_shortreal] = ACTIONS(5770),
    [anon_sym_real] = ACTIONS(5770),
    [anon_sym_realtime] = ACTIONS(5770),
    [anon_sym_supply0] = ACTIONS(5770),
    [anon_sym_supply1] = ACTIONS(5770),
    [anon_sym_signed] = ACTIONS(5770),
    [anon_sym_unsigned] = ACTIONS(5770),
    [anon_sym_task] = ACTIONS(5770),
    [anon_sym_modport] = ACTIONS(5770),
    [anon_sym_assert] = ACTIONS(5770),
    [anon_sym_property] = ACTIONS(5770),
    [anon_sym_assume] = ACTIONS(5770),
    [anon_sym_cover] = ACTIONS(5770),
    [anon_sym_sequence] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym_not] = ACTIONS(5770),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_case] = ACTIONS(5770),
    [anon_sym_always] = ACTIONS(5770),
    [anon_sym_covergroup] = ACTIONS(5770),
    [anon_sym_let] = ACTIONS(5770),
    [anon_sym_pulldown] = ACTIONS(5770),
    [anon_sym_pullup] = ACTIONS(5770),
    [anon_sym_cmos] = ACTIONS(5770),
    [anon_sym_rcmos] = ACTIONS(5770),
    [anon_sym_bufif0] = ACTIONS(5770),
    [anon_sym_bufif1] = ACTIONS(5770),
    [anon_sym_notif0] = ACTIONS(5770),
    [anon_sym_notif1] = ACTIONS(5770),
    [anon_sym_nmos] = ACTIONS(5770),
    [anon_sym_pmos] = ACTIONS(5770),
    [anon_sym_rnmos] = ACTIONS(5770),
    [anon_sym_rpmos] = ACTIONS(5770),
    [anon_sym_nand] = ACTIONS(5770),
    [anon_sym_nor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_xnor] = ACTIONS(5770),
    [anon_sym_buf] = ACTIONS(5770),
    [anon_sym_tranif0] = ACTIONS(5770),
    [anon_sym_tranif1] = ACTIONS(5770),
    [anon_sym_rtranif1] = ACTIONS(5770),
    [anon_sym_rtranif0] = ACTIONS(5770),
    [anon_sym_tran] = ACTIONS(5770),
    [anon_sym_rtran] = ACTIONS(5770),
    [anon_sym_generate] = ACTIONS(5770),
    [anon_sym_for] = ACTIONS(5770),
    [anon_sym_initial] = ACTIONS(5770),
    [anon_sym_assign] = ACTIONS(5770),
    [anon_sym_alias] = ACTIONS(5770),
    [anon_sym_always_comb] = ACTIONS(5770),
    [anon_sym_always_latch] = ACTIONS(5770),
    [anon_sym_always_ff] = ACTIONS(5770),
    [anon_sym_final] = ACTIONS(5770),
    [anon_sym_while] = ACTIONS(5770),
    [anon_sym_global] = ACTIONS(5770),
    [anon_sym_specify] = ACTIONS(5770),
    [anon_sym_LPAREN_STAR] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5772),
    [anon_sym_DOLLARunit] = ACTIONS(5772),
  },
  [1028] = {
    [ts_builtin_sym_end] = ACTIONS(5774),
    [sym_simple_identifier] = ACTIONS(5776),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5774),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5774),
    [anon_sym_BQUOTE] = ACTIONS(5776),
    [aux_sym_id_directive_token1] = ACTIONS(5774),
    [aux_sym_id_directive_token2] = ACTIONS(5774),
    [aux_sym_id_directive_token3] = ACTIONS(5774),
    [aux_sym_id_directive_token4] = ACTIONS(5776),
    [aux_sym_zero_directive_token1] = ACTIONS(5774),
    [aux_sym_zero_directive_token2] = ACTIONS(5774),
    [aux_sym_zero_directive_token3] = ACTIONS(5774),
    [aux_sym_zero_directive_token4] = ACTIONS(5774),
    [aux_sym_zero_directive_token5] = ACTIONS(5774),
    [aux_sym_zero_directive_token6] = ACTIONS(5774),
    [aux_sym_zero_directive_token7] = ACTIONS(5774),
    [aux_sym_zero_directive_token8] = ACTIONS(5774),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5774),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5774),
    [anon_sym_wire] = ACTIONS(5776),
    [anon_sym_tri] = ACTIONS(5776),
    [anon_sym_tri0] = ACTIONS(5776),
    [anon_sym_tri1] = ACTIONS(5776),
    [anon_sym_wand] = ACTIONS(5776),
    [anon_sym_triand] = ACTIONS(5776),
    [anon_sym_wor] = ACTIONS(5776),
    [anon_sym_trior] = ACTIONS(5776),
    [anon_sym_trireg] = ACTIONS(5776),
    [anon_sym_uwire] = ACTIONS(5776),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5774),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5774),
    [aux_sym_begin_keywords_token1] = ACTIONS(5774),
    [anon_sym_SEMI] = ACTIONS(5774),
    [anon_sym_endmodule] = ACTIONS(5776),
    [anon_sym_extern] = ACTIONS(5776),
    [anon_sym_module] = ACTIONS(5776),
    [anon_sym_macromodule] = ACTIONS(5776),
    [anon_sym_endinterface] = ACTIONS(5776),
    [anon_sym_interface] = ACTIONS(5776),
    [anon_sym_program] = ACTIONS(5776),
    [anon_sym_checker] = ACTIONS(5776),
    [anon_sym_virtual] = ACTIONS(5776),
    [anon_sym_class] = ACTIONS(5776),
    [anon_sym_package] = ACTIONS(5776),
    [anon_sym_timeunit] = ACTIONS(5776),
    [anon_sym_timeprecision] = ACTIONS(5776),
    [anon_sym_type] = ACTIONS(5776),
    [anon_sym_input] = ACTIONS(5776),
    [anon_sym_output] = ACTIONS(5776),
    [anon_sym_inout] = ACTIONS(5776),
    [anon_sym_ref] = ACTIONS(5776),
    [anon_sym_DOLLARfatal] = ACTIONS(5774),
    [anon_sym_DOLLARerror] = ACTIONS(5774),
    [anon_sym_DOLLARwarning] = ACTIONS(5774),
    [anon_sym_DOLLARinfo] = ACTIONS(5774),
    [anon_sym_default] = ACTIONS(5776),
    [anon_sym_clocking] = ACTIONS(5776),
    [anon_sym_defparam] = ACTIONS(5776),
    [anon_sym_bind] = ACTIONS(5776),
    [anon_sym_const] = ACTIONS(5776),
    [anon_sym_function] = ACTIONS(5776),
    [anon_sym_static] = ACTIONS(5776),
    [anon_sym_constraint] = ACTIONS(5776),
    [anon_sym_if] = ACTIONS(5776),
    [anon_sym_LBRACK] = ACTIONS(5774),
    [anon_sym_localparam] = ACTIONS(5776),
    [anon_sym_parameter] = ACTIONS(5776),
    [anon_sym_specparam] = ACTIONS(5776),
    [anon_sym_var] = ACTIONS(5776),
    [anon_sym_import] = ACTIONS(5776),
    [anon_sym_export] = ACTIONS(5776),
    [anon_sym_genvar] = ACTIONS(5776),
    [anon_sym_interconnect] = ACTIONS(5776),
    [anon_sym_typedef] = ACTIONS(5776),
    [anon_sym_enum] = ACTIONS(5776),
    [anon_sym_struct] = ACTIONS(5776),
    [anon_sym_union] = ACTIONS(5776),
    [anon_sym_nettype] = ACTIONS(5776),
    [anon_sym_automatic] = ACTIONS(5776),
    [anon_sym_string] = ACTIONS(5776),
    [anon_sym_chandle] = ACTIONS(5776),
    [anon_sym_event] = ACTIONS(5776),
    [anon_sym_byte] = ACTIONS(5776),
    [anon_sym_shortint] = ACTIONS(5776),
    [anon_sym_int] = ACTIONS(5776),
    [anon_sym_longint] = ACTIONS(5776),
    [anon_sym_integer] = ACTIONS(5776),
    [anon_sym_time] = ACTIONS(5776),
    [anon_sym_bit] = ACTIONS(5776),
    [anon_sym_logic] = ACTIONS(5776),
    [anon_sym_reg] = ACTIONS(5776),
    [anon_sym_shortreal] = ACTIONS(5776),
    [anon_sym_real] = ACTIONS(5776),
    [anon_sym_realtime] = ACTIONS(5776),
    [anon_sym_supply0] = ACTIONS(5776),
    [anon_sym_supply1] = ACTIONS(5776),
    [anon_sym_signed] = ACTIONS(5776),
    [anon_sym_unsigned] = ACTIONS(5776),
    [anon_sym_task] = ACTIONS(5776),
    [anon_sym_modport] = ACTIONS(5776),
    [anon_sym_assert] = ACTIONS(5776),
    [anon_sym_property] = ACTIONS(5776),
    [anon_sym_assume] = ACTIONS(5776),
    [anon_sym_cover] = ACTIONS(5776),
    [anon_sym_sequence] = ACTIONS(5776),
    [anon_sym_restrict] = ACTIONS(5776),
    [anon_sym_not] = ACTIONS(5776),
    [anon_sym_or] = ACTIONS(5776),
    [anon_sym_and] = ACTIONS(5776),
    [anon_sym_case] = ACTIONS(5776),
    [anon_sym_always] = ACTIONS(5776),
    [anon_sym_covergroup] = ACTIONS(5776),
    [anon_sym_let] = ACTIONS(5776),
    [anon_sym_pulldown] = ACTIONS(5776),
    [anon_sym_pullup] = ACTIONS(5776),
    [anon_sym_cmos] = ACTIONS(5776),
    [anon_sym_rcmos] = ACTIONS(5776),
    [anon_sym_bufif0] = ACTIONS(5776),
    [anon_sym_bufif1] = ACTIONS(5776),
    [anon_sym_notif0] = ACTIONS(5776),
    [anon_sym_notif1] = ACTIONS(5776),
    [anon_sym_nmos] = ACTIONS(5776),
    [anon_sym_pmos] = ACTIONS(5776),
    [anon_sym_rnmos] = ACTIONS(5776),
    [anon_sym_rpmos] = ACTIONS(5776),
    [anon_sym_nand] = ACTIONS(5776),
    [anon_sym_nor] = ACTIONS(5776),
    [anon_sym_xor] = ACTIONS(5776),
    [anon_sym_xnor] = ACTIONS(5776),
    [anon_sym_buf] = ACTIONS(5776),
    [anon_sym_tranif0] = ACTIONS(5776),
    [anon_sym_tranif1] = ACTIONS(5776),
    [anon_sym_rtranif1] = ACTIONS(5776),
    [anon_sym_rtranif0] = ACTIONS(5776),
    [anon_sym_tran] = ACTIONS(5776),
    [anon_sym_rtran] = ACTIONS(5776),
    [anon_sym_generate] = ACTIONS(5776),
    [anon_sym_for] = ACTIONS(5776),
    [anon_sym_primitive] = ACTIONS(5776),
    [anon_sym_initial] = ACTIONS(5776),
    [anon_sym_assign] = ACTIONS(5776),
    [anon_sym_alias] = ACTIONS(5776),
    [anon_sym_always_comb] = ACTIONS(5776),
    [anon_sym_always_latch] = ACTIONS(5776),
    [anon_sym_always_ff] = ACTIONS(5776),
    [anon_sym_final] = ACTIONS(5776),
    [anon_sym_global] = ACTIONS(5776),
    [anon_sym_specify] = ACTIONS(5776),
    [anon_sym_LPAREN_STAR] = ACTIONS(5774),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5774),
    [anon_sym_DOLLARunit] = ACTIONS(5774),
  },
  [1029] = {
    [ts_builtin_sym_end] = ACTIONS(5778),
    [sym_simple_identifier] = ACTIONS(5780),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5778),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5778),
    [anon_sym_BQUOTE] = ACTIONS(5780),
    [aux_sym_id_directive_token1] = ACTIONS(5778),
    [aux_sym_id_directive_token2] = ACTIONS(5778),
    [aux_sym_id_directive_token3] = ACTIONS(5778),
    [aux_sym_id_directive_token4] = ACTIONS(5780),
    [aux_sym_zero_directive_token1] = ACTIONS(5778),
    [aux_sym_zero_directive_token2] = ACTIONS(5778),
    [aux_sym_zero_directive_token3] = ACTIONS(5778),
    [aux_sym_zero_directive_token4] = ACTIONS(5778),
    [aux_sym_zero_directive_token5] = ACTIONS(5778),
    [aux_sym_zero_directive_token6] = ACTIONS(5778),
    [aux_sym_zero_directive_token7] = ACTIONS(5778),
    [aux_sym_zero_directive_token8] = ACTIONS(5778),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5778),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5778),
    [anon_sym_wire] = ACTIONS(5780),
    [anon_sym_tri] = ACTIONS(5780),
    [anon_sym_tri0] = ACTIONS(5780),
    [anon_sym_tri1] = ACTIONS(5780),
    [anon_sym_wand] = ACTIONS(5780),
    [anon_sym_triand] = ACTIONS(5780),
    [anon_sym_wor] = ACTIONS(5780),
    [anon_sym_trior] = ACTIONS(5780),
    [anon_sym_trireg] = ACTIONS(5780),
    [anon_sym_uwire] = ACTIONS(5780),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5778),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5778),
    [aux_sym_begin_keywords_token1] = ACTIONS(5778),
    [anon_sym_SEMI] = ACTIONS(5778),
    [anon_sym_endmodule] = ACTIONS(5780),
    [anon_sym_extern] = ACTIONS(5780),
    [anon_sym_module] = ACTIONS(5780),
    [anon_sym_macromodule] = ACTIONS(5780),
    [anon_sym_endinterface] = ACTIONS(5780),
    [anon_sym_interface] = ACTIONS(5780),
    [anon_sym_program] = ACTIONS(5780),
    [anon_sym_checker] = ACTIONS(5780),
    [anon_sym_virtual] = ACTIONS(5780),
    [anon_sym_class] = ACTIONS(5780),
    [anon_sym_package] = ACTIONS(5780),
    [anon_sym_timeunit] = ACTIONS(5780),
    [anon_sym_timeprecision] = ACTIONS(5780),
    [anon_sym_type] = ACTIONS(5780),
    [anon_sym_input] = ACTIONS(5780),
    [anon_sym_output] = ACTIONS(5780),
    [anon_sym_inout] = ACTIONS(5780),
    [anon_sym_ref] = ACTIONS(5780),
    [anon_sym_DOLLARfatal] = ACTIONS(5778),
    [anon_sym_DOLLARerror] = ACTIONS(5778),
    [anon_sym_DOLLARwarning] = ACTIONS(5778),
    [anon_sym_DOLLARinfo] = ACTIONS(5778),
    [anon_sym_default] = ACTIONS(5780),
    [anon_sym_clocking] = ACTIONS(5780),
    [anon_sym_defparam] = ACTIONS(5780),
    [anon_sym_bind] = ACTIONS(5780),
    [anon_sym_const] = ACTIONS(5780),
    [anon_sym_function] = ACTIONS(5780),
    [anon_sym_static] = ACTIONS(5780),
    [anon_sym_constraint] = ACTIONS(5780),
    [anon_sym_if] = ACTIONS(5780),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_localparam] = ACTIONS(5780),
    [anon_sym_parameter] = ACTIONS(5780),
    [anon_sym_specparam] = ACTIONS(5780),
    [anon_sym_var] = ACTIONS(5780),
    [anon_sym_import] = ACTIONS(5780),
    [anon_sym_export] = ACTIONS(5780),
    [anon_sym_genvar] = ACTIONS(5780),
    [anon_sym_interconnect] = ACTIONS(5780),
    [anon_sym_typedef] = ACTIONS(5780),
    [anon_sym_enum] = ACTIONS(5780),
    [anon_sym_struct] = ACTIONS(5780),
    [anon_sym_union] = ACTIONS(5780),
    [anon_sym_nettype] = ACTIONS(5780),
    [anon_sym_automatic] = ACTIONS(5780),
    [anon_sym_string] = ACTIONS(5780),
    [anon_sym_chandle] = ACTIONS(5780),
    [anon_sym_event] = ACTIONS(5780),
    [anon_sym_byte] = ACTIONS(5780),
    [anon_sym_shortint] = ACTIONS(5780),
    [anon_sym_int] = ACTIONS(5780),
    [anon_sym_longint] = ACTIONS(5780),
    [anon_sym_integer] = ACTIONS(5780),
    [anon_sym_time] = ACTIONS(5780),
    [anon_sym_bit] = ACTIONS(5780),
    [anon_sym_logic] = ACTIONS(5780),
    [anon_sym_reg] = ACTIONS(5780),
    [anon_sym_shortreal] = ACTIONS(5780),
    [anon_sym_real] = ACTIONS(5780),
    [anon_sym_realtime] = ACTIONS(5780),
    [anon_sym_supply0] = ACTIONS(5780),
    [anon_sym_supply1] = ACTIONS(5780),
    [anon_sym_signed] = ACTIONS(5780),
    [anon_sym_unsigned] = ACTIONS(5780),
    [anon_sym_task] = ACTIONS(5780),
    [anon_sym_modport] = ACTIONS(5780),
    [anon_sym_assert] = ACTIONS(5780),
    [anon_sym_property] = ACTIONS(5780),
    [anon_sym_assume] = ACTIONS(5780),
    [anon_sym_cover] = ACTIONS(5780),
    [anon_sym_sequence] = ACTIONS(5780),
    [anon_sym_restrict] = ACTIONS(5780),
    [anon_sym_not] = ACTIONS(5780),
    [anon_sym_or] = ACTIONS(5780),
    [anon_sym_and] = ACTIONS(5780),
    [anon_sym_case] = ACTIONS(5780),
    [anon_sym_always] = ACTIONS(5780),
    [anon_sym_covergroup] = ACTIONS(5780),
    [anon_sym_let] = ACTIONS(5780),
    [anon_sym_pulldown] = ACTIONS(5780),
    [anon_sym_pullup] = ACTIONS(5780),
    [anon_sym_cmos] = ACTIONS(5780),
    [anon_sym_rcmos] = ACTIONS(5780),
    [anon_sym_bufif0] = ACTIONS(5780),
    [anon_sym_bufif1] = ACTIONS(5780),
    [anon_sym_notif0] = ACTIONS(5780),
    [anon_sym_notif1] = ACTIONS(5780),
    [anon_sym_nmos] = ACTIONS(5780),
    [anon_sym_pmos] = ACTIONS(5780),
    [anon_sym_rnmos] = ACTIONS(5780),
    [anon_sym_rpmos] = ACTIONS(5780),
    [anon_sym_nand] = ACTIONS(5780),
    [anon_sym_nor] = ACTIONS(5780),
    [anon_sym_xor] = ACTIONS(5780),
    [anon_sym_xnor] = ACTIONS(5780),
    [anon_sym_buf] = ACTIONS(5780),
    [anon_sym_tranif0] = ACTIONS(5780),
    [anon_sym_tranif1] = ACTIONS(5780),
    [anon_sym_rtranif1] = ACTIONS(5780),
    [anon_sym_rtranif0] = ACTIONS(5780),
    [anon_sym_tran] = ACTIONS(5780),
    [anon_sym_rtran] = ACTIONS(5780),
    [anon_sym_generate] = ACTIONS(5780),
    [anon_sym_for] = ACTIONS(5780),
    [anon_sym_primitive] = ACTIONS(5780),
    [anon_sym_initial] = ACTIONS(5780),
    [anon_sym_assign] = ACTIONS(5780),
    [anon_sym_alias] = ACTIONS(5780),
    [anon_sym_always_comb] = ACTIONS(5780),
    [anon_sym_always_latch] = ACTIONS(5780),
    [anon_sym_always_ff] = ACTIONS(5780),
    [anon_sym_final] = ACTIONS(5780),
    [anon_sym_global] = ACTIONS(5780),
    [anon_sym_specify] = ACTIONS(5780),
    [anon_sym_LPAREN_STAR] = ACTIONS(5778),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5778),
    [anon_sym_DOLLARunit] = ACTIONS(5778),
  },
  [1030] = {
    [sym_simple_identifier] = ACTIONS(5782),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5784),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5784),
    [anon_sym_BQUOTE] = ACTIONS(5782),
    [aux_sym_id_directive_token1] = ACTIONS(5784),
    [aux_sym_id_directive_token2] = ACTIONS(5784),
    [aux_sym_id_directive_token3] = ACTIONS(5784),
    [aux_sym_id_directive_token4] = ACTIONS(5782),
    [aux_sym_zero_directive_token1] = ACTIONS(5784),
    [aux_sym_zero_directive_token2] = ACTIONS(5784),
    [aux_sym_zero_directive_token3] = ACTIONS(5784),
    [aux_sym_zero_directive_token4] = ACTIONS(5784),
    [aux_sym_zero_directive_token5] = ACTIONS(5784),
    [aux_sym_zero_directive_token6] = ACTIONS(5784),
    [aux_sym_zero_directive_token7] = ACTIONS(5784),
    [aux_sym_zero_directive_token8] = ACTIONS(5784),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5784),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5784),
    [anon_sym_wire] = ACTIONS(5782),
    [anon_sym_tri] = ACTIONS(5782),
    [anon_sym_tri0] = ACTIONS(5782),
    [anon_sym_tri1] = ACTIONS(5782),
    [anon_sym_wand] = ACTIONS(5782),
    [anon_sym_triand] = ACTIONS(5782),
    [anon_sym_wor] = ACTIONS(5782),
    [anon_sym_trior] = ACTIONS(5782),
    [anon_sym_trireg] = ACTIONS(5782),
    [anon_sym_uwire] = ACTIONS(5782),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5784),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5784),
    [aux_sym_begin_keywords_token1] = ACTIONS(5784),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym_endmodule] = ACTIONS(5782),
    [anon_sym_extern] = ACTIONS(5782),
    [anon_sym_module] = ACTIONS(5782),
    [anon_sym_macromodule] = ACTIONS(5782),
    [anon_sym_endinterface] = ACTIONS(5782),
    [anon_sym_interface] = ACTIONS(5782),
    [anon_sym_endprogram] = ACTIONS(5782),
    [anon_sym_program] = ACTIONS(5782),
    [anon_sym_checker] = ACTIONS(5782),
    [anon_sym_virtual] = ACTIONS(5782),
    [anon_sym_class] = ACTIONS(5782),
    [anon_sym_timeunit] = ACTIONS(5782),
    [anon_sym_timeprecision] = ACTIONS(5782),
    [anon_sym_type] = ACTIONS(5782),
    [anon_sym_input] = ACTIONS(5782),
    [anon_sym_output] = ACTIONS(5782),
    [anon_sym_inout] = ACTIONS(5782),
    [anon_sym_ref] = ACTIONS(5782),
    [anon_sym_DOLLARfatal] = ACTIONS(5784),
    [anon_sym_DOLLARerror] = ACTIONS(5784),
    [anon_sym_DOLLARwarning] = ACTIONS(5784),
    [anon_sym_DOLLARinfo] = ACTIONS(5784),
    [anon_sym_default] = ACTIONS(5782),
    [anon_sym_clocking] = ACTIONS(5782),
    [anon_sym_defparam] = ACTIONS(5782),
    [anon_sym_bind] = ACTIONS(5782),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_function] = ACTIONS(5782),
    [anon_sym_static] = ACTIONS(5782),
    [anon_sym_constraint] = ACTIONS(5782),
    [anon_sym_if] = ACTIONS(5782),
    [anon_sym_else] = ACTIONS(5782),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_localparam] = ACTIONS(5782),
    [anon_sym_parameter] = ACTIONS(5782),
    [anon_sym_specparam] = ACTIONS(5782),
    [anon_sym_var] = ACTIONS(5782),
    [anon_sym_import] = ACTIONS(5782),
    [anon_sym_export] = ACTIONS(5782),
    [anon_sym_genvar] = ACTIONS(5782),
    [anon_sym_interconnect] = ACTIONS(5782),
    [anon_sym_typedef] = ACTIONS(5782),
    [anon_sym_enum] = ACTIONS(5782),
    [anon_sym_struct] = ACTIONS(5782),
    [anon_sym_union] = ACTIONS(5782),
    [anon_sym_nettype] = ACTIONS(5782),
    [anon_sym_automatic] = ACTIONS(5782),
    [anon_sym_string] = ACTIONS(5782),
    [anon_sym_chandle] = ACTIONS(5782),
    [anon_sym_event] = ACTIONS(5782),
    [anon_sym_byte] = ACTIONS(5782),
    [anon_sym_shortint] = ACTIONS(5782),
    [anon_sym_int] = ACTIONS(5782),
    [anon_sym_longint] = ACTIONS(5782),
    [anon_sym_integer] = ACTIONS(5782),
    [anon_sym_time] = ACTIONS(5782),
    [anon_sym_bit] = ACTIONS(5782),
    [anon_sym_logic] = ACTIONS(5782),
    [anon_sym_reg] = ACTIONS(5782),
    [anon_sym_shortreal] = ACTIONS(5782),
    [anon_sym_real] = ACTIONS(5782),
    [anon_sym_realtime] = ACTIONS(5782),
    [anon_sym_supply0] = ACTIONS(5782),
    [anon_sym_supply1] = ACTIONS(5782),
    [anon_sym_signed] = ACTIONS(5782),
    [anon_sym_unsigned] = ACTIONS(5782),
    [anon_sym_task] = ACTIONS(5782),
    [anon_sym_modport] = ACTIONS(5782),
    [anon_sym_assert] = ACTIONS(5782),
    [anon_sym_property] = ACTIONS(5782),
    [anon_sym_assume] = ACTIONS(5782),
    [anon_sym_cover] = ACTIONS(5782),
    [anon_sym_sequence] = ACTIONS(5782),
    [anon_sym_restrict] = ACTIONS(5782),
    [anon_sym_not] = ACTIONS(5782),
    [anon_sym_or] = ACTIONS(5782),
    [anon_sym_and] = ACTIONS(5782),
    [anon_sym_case] = ACTIONS(5782),
    [anon_sym_always] = ACTIONS(5782),
    [anon_sym_covergroup] = ACTIONS(5782),
    [anon_sym_let] = ACTIONS(5782),
    [anon_sym_pulldown] = ACTIONS(5782),
    [anon_sym_pullup] = ACTIONS(5782),
    [anon_sym_cmos] = ACTIONS(5782),
    [anon_sym_rcmos] = ACTIONS(5782),
    [anon_sym_bufif0] = ACTIONS(5782),
    [anon_sym_bufif1] = ACTIONS(5782),
    [anon_sym_notif0] = ACTIONS(5782),
    [anon_sym_notif1] = ACTIONS(5782),
    [anon_sym_nmos] = ACTIONS(5782),
    [anon_sym_pmos] = ACTIONS(5782),
    [anon_sym_rnmos] = ACTIONS(5782),
    [anon_sym_rpmos] = ACTIONS(5782),
    [anon_sym_nand] = ACTIONS(5782),
    [anon_sym_nor] = ACTIONS(5782),
    [anon_sym_xor] = ACTIONS(5782),
    [anon_sym_xnor] = ACTIONS(5782),
    [anon_sym_buf] = ACTIONS(5782),
    [anon_sym_tranif0] = ACTIONS(5782),
    [anon_sym_tranif1] = ACTIONS(5782),
    [anon_sym_rtranif1] = ACTIONS(5782),
    [anon_sym_rtranif0] = ACTIONS(5782),
    [anon_sym_tran] = ACTIONS(5782),
    [anon_sym_rtran] = ACTIONS(5782),
    [anon_sym_generate] = ACTIONS(5782),
    [anon_sym_for] = ACTIONS(5782),
    [anon_sym_initial] = ACTIONS(5782),
    [anon_sym_assign] = ACTIONS(5782),
    [anon_sym_alias] = ACTIONS(5782),
    [anon_sym_always_comb] = ACTIONS(5782),
    [anon_sym_always_latch] = ACTIONS(5782),
    [anon_sym_always_ff] = ACTIONS(5782),
    [anon_sym_final] = ACTIONS(5782),
    [anon_sym_while] = ACTIONS(5782),
    [anon_sym_global] = ACTIONS(5782),
    [anon_sym_specify] = ACTIONS(5782),
    [anon_sym_LPAREN_STAR] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5784),
    [anon_sym_DOLLARunit] = ACTIONS(5784),
  },
  [1031] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5788),
    [anon_sym_BQUOTE] = ACTIONS(5786),
    [aux_sym_id_directive_token1] = ACTIONS(5788),
    [aux_sym_id_directive_token2] = ACTIONS(5788),
    [aux_sym_id_directive_token3] = ACTIONS(5788),
    [aux_sym_id_directive_token4] = ACTIONS(5786),
    [aux_sym_zero_directive_token1] = ACTIONS(5788),
    [aux_sym_zero_directive_token2] = ACTIONS(5788),
    [aux_sym_zero_directive_token3] = ACTIONS(5788),
    [aux_sym_zero_directive_token4] = ACTIONS(5788),
    [aux_sym_zero_directive_token5] = ACTIONS(5788),
    [aux_sym_zero_directive_token6] = ACTIONS(5788),
    [aux_sym_zero_directive_token7] = ACTIONS(5788),
    [aux_sym_zero_directive_token8] = ACTIONS(5788),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5788),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5788),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_begin_keywords_token1] = ACTIONS(5788),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_endmodule] = ACTIONS(5786),
    [anon_sym_COLON] = ACTIONS(5790),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_module] = ACTIONS(5786),
    [anon_sym_macromodule] = ACTIONS(5786),
    [anon_sym_endinterface] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_endprogram] = ACTIONS(5786),
    [anon_sym_program] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_timeunit] = ACTIONS(5786),
    [anon_sym_timeprecision] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_input] = ACTIONS(5786),
    [anon_sym_output] = ACTIONS(5786),
    [anon_sym_inout] = ACTIONS(5786),
    [anon_sym_ref] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_specparam] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_modport] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_specify] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [1032] = {
    [sym_simple_identifier] = ACTIONS(5792),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5794),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5794),
    [anon_sym_BQUOTE] = ACTIONS(5792),
    [aux_sym_id_directive_token1] = ACTIONS(5794),
    [aux_sym_id_directive_token2] = ACTIONS(5794),
    [aux_sym_id_directive_token3] = ACTIONS(5794),
    [aux_sym_id_directive_token4] = ACTIONS(5792),
    [aux_sym_zero_directive_token1] = ACTIONS(5794),
    [aux_sym_zero_directive_token2] = ACTIONS(5794),
    [aux_sym_zero_directive_token3] = ACTIONS(5794),
    [aux_sym_zero_directive_token4] = ACTIONS(5794),
    [aux_sym_zero_directive_token5] = ACTIONS(5794),
    [aux_sym_zero_directive_token6] = ACTIONS(5794),
    [aux_sym_zero_directive_token7] = ACTIONS(5794),
    [aux_sym_zero_directive_token8] = ACTIONS(5794),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5794),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5794),
    [anon_sym_wire] = ACTIONS(5792),
    [anon_sym_tri] = ACTIONS(5792),
    [anon_sym_tri0] = ACTIONS(5792),
    [anon_sym_tri1] = ACTIONS(5792),
    [anon_sym_wand] = ACTIONS(5792),
    [anon_sym_triand] = ACTIONS(5792),
    [anon_sym_wor] = ACTIONS(5792),
    [anon_sym_trior] = ACTIONS(5792),
    [anon_sym_trireg] = ACTIONS(5792),
    [anon_sym_uwire] = ACTIONS(5792),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5794),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5794),
    [aux_sym_begin_keywords_token1] = ACTIONS(5794),
    [anon_sym_SEMI] = ACTIONS(5794),
    [anon_sym_endmodule] = ACTIONS(5792),
    [anon_sym_COLON] = ACTIONS(5796),
    [anon_sym_extern] = ACTIONS(5792),
    [anon_sym_module] = ACTIONS(5792),
    [anon_sym_macromodule] = ACTIONS(5792),
    [anon_sym_endinterface] = ACTIONS(5792),
    [anon_sym_interface] = ACTIONS(5792),
    [anon_sym_endprogram] = ACTIONS(5792),
    [anon_sym_program] = ACTIONS(5792),
    [anon_sym_checker] = ACTIONS(5792),
    [anon_sym_virtual] = ACTIONS(5792),
    [anon_sym_class] = ACTIONS(5792),
    [anon_sym_timeunit] = ACTIONS(5792),
    [anon_sym_timeprecision] = ACTIONS(5792),
    [anon_sym_type] = ACTIONS(5792),
    [anon_sym_input] = ACTIONS(5792),
    [anon_sym_output] = ACTIONS(5792),
    [anon_sym_inout] = ACTIONS(5792),
    [anon_sym_ref] = ACTIONS(5792),
    [anon_sym_DOLLARfatal] = ACTIONS(5794),
    [anon_sym_DOLLARerror] = ACTIONS(5794),
    [anon_sym_DOLLARwarning] = ACTIONS(5794),
    [anon_sym_DOLLARinfo] = ACTIONS(5794),
    [anon_sym_default] = ACTIONS(5792),
    [anon_sym_clocking] = ACTIONS(5792),
    [anon_sym_defparam] = ACTIONS(5792),
    [anon_sym_bind] = ACTIONS(5792),
    [anon_sym_const] = ACTIONS(5792),
    [anon_sym_function] = ACTIONS(5792),
    [anon_sym_static] = ACTIONS(5792),
    [anon_sym_constraint] = ACTIONS(5792),
    [anon_sym_if] = ACTIONS(5792),
    [anon_sym_else] = ACTIONS(5792),
    [anon_sym_LBRACK] = ACTIONS(5794),
    [anon_sym_localparam] = ACTIONS(5792),
    [anon_sym_parameter] = ACTIONS(5792),
    [anon_sym_specparam] = ACTIONS(5792),
    [anon_sym_var] = ACTIONS(5792),
    [anon_sym_import] = ACTIONS(5792),
    [anon_sym_export] = ACTIONS(5792),
    [anon_sym_genvar] = ACTIONS(5792),
    [anon_sym_interconnect] = ACTIONS(5792),
    [anon_sym_typedef] = ACTIONS(5792),
    [anon_sym_enum] = ACTIONS(5792),
    [anon_sym_struct] = ACTIONS(5792),
    [anon_sym_union] = ACTIONS(5792),
    [anon_sym_nettype] = ACTIONS(5792),
    [anon_sym_automatic] = ACTIONS(5792),
    [anon_sym_string] = ACTIONS(5792),
    [anon_sym_chandle] = ACTIONS(5792),
    [anon_sym_event] = ACTIONS(5792),
    [anon_sym_byte] = ACTIONS(5792),
    [anon_sym_shortint] = ACTIONS(5792),
    [anon_sym_int] = ACTIONS(5792),
    [anon_sym_longint] = ACTIONS(5792),
    [anon_sym_integer] = ACTIONS(5792),
    [anon_sym_time] = ACTIONS(5792),
    [anon_sym_bit] = ACTIONS(5792),
    [anon_sym_logic] = ACTIONS(5792),
    [anon_sym_reg] = ACTIONS(5792),
    [anon_sym_shortreal] = ACTIONS(5792),
    [anon_sym_real] = ACTIONS(5792),
    [anon_sym_realtime] = ACTIONS(5792),
    [anon_sym_supply0] = ACTIONS(5792),
    [anon_sym_supply1] = ACTIONS(5792),
    [anon_sym_signed] = ACTIONS(5792),
    [anon_sym_unsigned] = ACTIONS(5792),
    [anon_sym_task] = ACTIONS(5792),
    [anon_sym_modport] = ACTIONS(5792),
    [anon_sym_assert] = ACTIONS(5792),
    [anon_sym_property] = ACTIONS(5792),
    [anon_sym_assume] = ACTIONS(5792),
    [anon_sym_cover] = ACTIONS(5792),
    [anon_sym_sequence] = ACTIONS(5792),
    [anon_sym_restrict] = ACTIONS(5792),
    [anon_sym_not] = ACTIONS(5792),
    [anon_sym_or] = ACTIONS(5792),
    [anon_sym_and] = ACTIONS(5792),
    [anon_sym_case] = ACTIONS(5792),
    [anon_sym_always] = ACTIONS(5792),
    [anon_sym_covergroup] = ACTIONS(5792),
    [anon_sym_let] = ACTIONS(5792),
    [anon_sym_pulldown] = ACTIONS(5792),
    [anon_sym_pullup] = ACTIONS(5792),
    [anon_sym_cmos] = ACTIONS(5792),
    [anon_sym_rcmos] = ACTIONS(5792),
    [anon_sym_bufif0] = ACTIONS(5792),
    [anon_sym_bufif1] = ACTIONS(5792),
    [anon_sym_notif0] = ACTIONS(5792),
    [anon_sym_notif1] = ACTIONS(5792),
    [anon_sym_nmos] = ACTIONS(5792),
    [anon_sym_pmos] = ACTIONS(5792),
    [anon_sym_rnmos] = ACTIONS(5792),
    [anon_sym_rpmos] = ACTIONS(5792),
    [anon_sym_nand] = ACTIONS(5792),
    [anon_sym_nor] = ACTIONS(5792),
    [anon_sym_xor] = ACTIONS(5792),
    [anon_sym_xnor] = ACTIONS(5792),
    [anon_sym_buf] = ACTIONS(5792),
    [anon_sym_tranif0] = ACTIONS(5792),
    [anon_sym_tranif1] = ACTIONS(5792),
    [anon_sym_rtranif1] = ACTIONS(5792),
    [anon_sym_rtranif0] = ACTIONS(5792),
    [anon_sym_tran] = ACTIONS(5792),
    [anon_sym_rtran] = ACTIONS(5792),
    [anon_sym_generate] = ACTIONS(5792),
    [anon_sym_for] = ACTIONS(5792),
    [anon_sym_initial] = ACTIONS(5792),
    [anon_sym_assign] = ACTIONS(5792),
    [anon_sym_alias] = ACTIONS(5792),
    [anon_sym_always_comb] = ACTIONS(5792),
    [anon_sym_always_latch] = ACTIONS(5792),
    [anon_sym_always_ff] = ACTIONS(5792),
    [anon_sym_final] = ACTIONS(5792),
    [anon_sym_global] = ACTIONS(5792),
    [anon_sym_specify] = ACTIONS(5792),
    [anon_sym_LPAREN_STAR] = ACTIONS(5794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5794),
    [anon_sym_DOLLARunit] = ACTIONS(5794),
  },
  [1033] = {
    [ts_builtin_sym_end] = ACTIONS(5798),
    [sym_simple_identifier] = ACTIONS(5800),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5798),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5798),
    [anon_sym_BQUOTE] = ACTIONS(5800),
    [aux_sym_id_directive_token1] = ACTIONS(5798),
    [aux_sym_id_directive_token2] = ACTIONS(5798),
    [aux_sym_id_directive_token3] = ACTIONS(5798),
    [aux_sym_id_directive_token4] = ACTIONS(5800),
    [aux_sym_zero_directive_token1] = ACTIONS(5798),
    [aux_sym_zero_directive_token2] = ACTIONS(5798),
    [aux_sym_zero_directive_token3] = ACTIONS(5798),
    [aux_sym_zero_directive_token4] = ACTIONS(5798),
    [aux_sym_zero_directive_token5] = ACTIONS(5798),
    [aux_sym_zero_directive_token6] = ACTIONS(5798),
    [aux_sym_zero_directive_token7] = ACTIONS(5798),
    [aux_sym_zero_directive_token8] = ACTIONS(5798),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5798),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5798),
    [anon_sym_wire] = ACTIONS(5800),
    [anon_sym_tri] = ACTIONS(5800),
    [anon_sym_tri0] = ACTIONS(5800),
    [anon_sym_tri1] = ACTIONS(5800),
    [anon_sym_wand] = ACTIONS(5800),
    [anon_sym_triand] = ACTIONS(5800),
    [anon_sym_wor] = ACTIONS(5800),
    [anon_sym_trior] = ACTIONS(5800),
    [anon_sym_trireg] = ACTIONS(5800),
    [anon_sym_uwire] = ACTIONS(5800),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5798),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5798),
    [aux_sym_begin_keywords_token1] = ACTIONS(5798),
    [anon_sym_SEMI] = ACTIONS(5798),
    [anon_sym_endmodule] = ACTIONS(5800),
    [anon_sym_extern] = ACTIONS(5800),
    [anon_sym_module] = ACTIONS(5800),
    [anon_sym_macromodule] = ACTIONS(5800),
    [anon_sym_endinterface] = ACTIONS(5800),
    [anon_sym_interface] = ACTIONS(5800),
    [anon_sym_program] = ACTIONS(5800),
    [anon_sym_checker] = ACTIONS(5800),
    [anon_sym_virtual] = ACTIONS(5800),
    [anon_sym_class] = ACTIONS(5800),
    [anon_sym_package] = ACTIONS(5800),
    [anon_sym_timeunit] = ACTIONS(5800),
    [anon_sym_timeprecision] = ACTIONS(5800),
    [anon_sym_type] = ACTIONS(5800),
    [anon_sym_input] = ACTIONS(5800),
    [anon_sym_output] = ACTIONS(5800),
    [anon_sym_inout] = ACTIONS(5800),
    [anon_sym_ref] = ACTIONS(5800),
    [anon_sym_DOLLARfatal] = ACTIONS(5798),
    [anon_sym_DOLLARerror] = ACTIONS(5798),
    [anon_sym_DOLLARwarning] = ACTIONS(5798),
    [anon_sym_DOLLARinfo] = ACTIONS(5798),
    [anon_sym_default] = ACTIONS(5800),
    [anon_sym_clocking] = ACTIONS(5800),
    [anon_sym_defparam] = ACTIONS(5800),
    [anon_sym_bind] = ACTIONS(5800),
    [anon_sym_const] = ACTIONS(5800),
    [anon_sym_function] = ACTIONS(5800),
    [anon_sym_static] = ACTIONS(5800),
    [anon_sym_constraint] = ACTIONS(5800),
    [anon_sym_if] = ACTIONS(5800),
    [anon_sym_LBRACK] = ACTIONS(5798),
    [anon_sym_localparam] = ACTIONS(5800),
    [anon_sym_parameter] = ACTIONS(5800),
    [anon_sym_specparam] = ACTIONS(5800),
    [anon_sym_var] = ACTIONS(5800),
    [anon_sym_import] = ACTIONS(5800),
    [anon_sym_export] = ACTIONS(5800),
    [anon_sym_genvar] = ACTIONS(5800),
    [anon_sym_interconnect] = ACTIONS(5800),
    [anon_sym_typedef] = ACTIONS(5800),
    [anon_sym_enum] = ACTIONS(5800),
    [anon_sym_struct] = ACTIONS(5800),
    [anon_sym_union] = ACTIONS(5800),
    [anon_sym_nettype] = ACTIONS(5800),
    [anon_sym_automatic] = ACTIONS(5800),
    [anon_sym_string] = ACTIONS(5800),
    [anon_sym_chandle] = ACTIONS(5800),
    [anon_sym_event] = ACTIONS(5800),
    [anon_sym_byte] = ACTIONS(5800),
    [anon_sym_shortint] = ACTIONS(5800),
    [anon_sym_int] = ACTIONS(5800),
    [anon_sym_longint] = ACTIONS(5800),
    [anon_sym_integer] = ACTIONS(5800),
    [anon_sym_time] = ACTIONS(5800),
    [anon_sym_bit] = ACTIONS(5800),
    [anon_sym_logic] = ACTIONS(5800),
    [anon_sym_reg] = ACTIONS(5800),
    [anon_sym_shortreal] = ACTIONS(5800),
    [anon_sym_real] = ACTIONS(5800),
    [anon_sym_realtime] = ACTIONS(5800),
    [anon_sym_supply0] = ACTIONS(5800),
    [anon_sym_supply1] = ACTIONS(5800),
    [anon_sym_signed] = ACTIONS(5800),
    [anon_sym_unsigned] = ACTIONS(5800),
    [anon_sym_task] = ACTIONS(5800),
    [anon_sym_modport] = ACTIONS(5800),
    [anon_sym_assert] = ACTIONS(5800),
    [anon_sym_property] = ACTIONS(5800),
    [anon_sym_assume] = ACTIONS(5800),
    [anon_sym_cover] = ACTIONS(5800),
    [anon_sym_sequence] = ACTIONS(5800),
    [anon_sym_restrict] = ACTIONS(5800),
    [anon_sym_not] = ACTIONS(5800),
    [anon_sym_or] = ACTIONS(5800),
    [anon_sym_and] = ACTIONS(5800),
    [anon_sym_case] = ACTIONS(5800),
    [anon_sym_always] = ACTIONS(5800),
    [anon_sym_covergroup] = ACTIONS(5800),
    [anon_sym_let] = ACTIONS(5800),
    [anon_sym_pulldown] = ACTIONS(5800),
    [anon_sym_pullup] = ACTIONS(5800),
    [anon_sym_cmos] = ACTIONS(5800),
    [anon_sym_rcmos] = ACTIONS(5800),
    [anon_sym_bufif0] = ACTIONS(5800),
    [anon_sym_bufif1] = ACTIONS(5800),
    [anon_sym_notif0] = ACTIONS(5800),
    [anon_sym_notif1] = ACTIONS(5800),
    [anon_sym_nmos] = ACTIONS(5800),
    [anon_sym_pmos] = ACTIONS(5800),
    [anon_sym_rnmos] = ACTIONS(5800),
    [anon_sym_rpmos] = ACTIONS(5800),
    [anon_sym_nand] = ACTIONS(5800),
    [anon_sym_nor] = ACTIONS(5800),
    [anon_sym_xor] = ACTIONS(5800),
    [anon_sym_xnor] = ACTIONS(5800),
    [anon_sym_buf] = ACTIONS(5800),
    [anon_sym_tranif0] = ACTIONS(5800),
    [anon_sym_tranif1] = ACTIONS(5800),
    [anon_sym_rtranif1] = ACTIONS(5800),
    [anon_sym_rtranif0] = ACTIONS(5800),
    [anon_sym_tran] = ACTIONS(5800),
    [anon_sym_rtran] = ACTIONS(5800),
    [anon_sym_generate] = ACTIONS(5800),
    [anon_sym_for] = ACTIONS(5800),
    [anon_sym_primitive] = ACTIONS(5800),
    [anon_sym_initial] = ACTIONS(5800),
    [anon_sym_assign] = ACTIONS(5800),
    [anon_sym_alias] = ACTIONS(5800),
    [anon_sym_always_comb] = ACTIONS(5800),
    [anon_sym_always_latch] = ACTIONS(5800),
    [anon_sym_always_ff] = ACTIONS(5800),
    [anon_sym_final] = ACTIONS(5800),
    [anon_sym_global] = ACTIONS(5800),
    [anon_sym_specify] = ACTIONS(5800),
    [anon_sym_LPAREN_STAR] = ACTIONS(5798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5798),
    [anon_sym_DOLLARunit] = ACTIONS(5798),
  },
  [1034] = {
    [sym_simple_identifier] = ACTIONS(5802),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5804),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5804),
    [anon_sym_BQUOTE] = ACTIONS(5802),
    [aux_sym_id_directive_token1] = ACTIONS(5804),
    [aux_sym_id_directive_token2] = ACTIONS(5804),
    [aux_sym_id_directive_token3] = ACTIONS(5804),
    [aux_sym_id_directive_token4] = ACTIONS(5802),
    [aux_sym_zero_directive_token1] = ACTIONS(5804),
    [aux_sym_zero_directive_token2] = ACTIONS(5804),
    [aux_sym_zero_directive_token3] = ACTIONS(5804),
    [aux_sym_zero_directive_token4] = ACTIONS(5804),
    [aux_sym_zero_directive_token5] = ACTIONS(5804),
    [aux_sym_zero_directive_token6] = ACTIONS(5804),
    [aux_sym_zero_directive_token7] = ACTIONS(5804),
    [aux_sym_zero_directive_token8] = ACTIONS(5804),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5804),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5804),
    [anon_sym_wire] = ACTIONS(5802),
    [anon_sym_tri] = ACTIONS(5802),
    [anon_sym_tri0] = ACTIONS(5802),
    [anon_sym_tri1] = ACTIONS(5802),
    [anon_sym_wand] = ACTIONS(5802),
    [anon_sym_triand] = ACTIONS(5802),
    [anon_sym_wor] = ACTIONS(5802),
    [anon_sym_trior] = ACTIONS(5802),
    [anon_sym_trireg] = ACTIONS(5802),
    [anon_sym_uwire] = ACTIONS(5802),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5804),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5804),
    [aux_sym_begin_keywords_token1] = ACTIONS(5804),
    [anon_sym_SEMI] = ACTIONS(5804),
    [anon_sym_endmodule] = ACTIONS(5802),
    [anon_sym_extern] = ACTIONS(5802),
    [anon_sym_module] = ACTIONS(5802),
    [anon_sym_macromodule] = ACTIONS(5802),
    [anon_sym_endinterface] = ACTIONS(5802),
    [anon_sym_interface] = ACTIONS(5802),
    [anon_sym_endprogram] = ACTIONS(5802),
    [anon_sym_program] = ACTIONS(5802),
    [anon_sym_checker] = ACTIONS(5802),
    [anon_sym_virtual] = ACTIONS(5802),
    [anon_sym_class] = ACTIONS(5802),
    [anon_sym_timeunit] = ACTIONS(5802),
    [anon_sym_timeprecision] = ACTIONS(5802),
    [anon_sym_type] = ACTIONS(5802),
    [anon_sym_input] = ACTIONS(5802),
    [anon_sym_output] = ACTIONS(5802),
    [anon_sym_inout] = ACTIONS(5802),
    [anon_sym_ref] = ACTIONS(5802),
    [anon_sym_DOLLARfatal] = ACTIONS(5804),
    [anon_sym_DOLLARerror] = ACTIONS(5804),
    [anon_sym_DOLLARwarning] = ACTIONS(5804),
    [anon_sym_DOLLARinfo] = ACTIONS(5804),
    [anon_sym_default] = ACTIONS(5802),
    [anon_sym_clocking] = ACTIONS(5802),
    [anon_sym_defparam] = ACTIONS(5802),
    [anon_sym_bind] = ACTIONS(5802),
    [anon_sym_const] = ACTIONS(5802),
    [anon_sym_function] = ACTIONS(5802),
    [anon_sym_static] = ACTIONS(5802),
    [anon_sym_constraint] = ACTIONS(5802),
    [anon_sym_if] = ACTIONS(5802),
    [anon_sym_else] = ACTIONS(5802),
    [anon_sym_LBRACK] = ACTIONS(5804),
    [anon_sym_localparam] = ACTIONS(5802),
    [anon_sym_parameter] = ACTIONS(5802),
    [anon_sym_specparam] = ACTIONS(5802),
    [anon_sym_var] = ACTIONS(5802),
    [anon_sym_import] = ACTIONS(5802),
    [anon_sym_export] = ACTIONS(5802),
    [anon_sym_genvar] = ACTIONS(5802),
    [anon_sym_interconnect] = ACTIONS(5802),
    [anon_sym_typedef] = ACTIONS(5802),
    [anon_sym_enum] = ACTIONS(5802),
    [anon_sym_struct] = ACTIONS(5802),
    [anon_sym_union] = ACTIONS(5802),
    [anon_sym_nettype] = ACTIONS(5802),
    [anon_sym_automatic] = ACTIONS(5802),
    [anon_sym_string] = ACTIONS(5802),
    [anon_sym_chandle] = ACTIONS(5802),
    [anon_sym_event] = ACTIONS(5802),
    [anon_sym_byte] = ACTIONS(5802),
    [anon_sym_shortint] = ACTIONS(5802),
    [anon_sym_int] = ACTIONS(5802),
    [anon_sym_longint] = ACTIONS(5802),
    [anon_sym_integer] = ACTIONS(5802),
    [anon_sym_time] = ACTIONS(5802),
    [anon_sym_bit] = ACTIONS(5802),
    [anon_sym_logic] = ACTIONS(5802),
    [anon_sym_reg] = ACTIONS(5802),
    [anon_sym_shortreal] = ACTIONS(5802),
    [anon_sym_real] = ACTIONS(5802),
    [anon_sym_realtime] = ACTIONS(5802),
    [anon_sym_supply0] = ACTIONS(5802),
    [anon_sym_supply1] = ACTIONS(5802),
    [anon_sym_signed] = ACTIONS(5802),
    [anon_sym_unsigned] = ACTIONS(5802),
    [anon_sym_task] = ACTIONS(5802),
    [anon_sym_modport] = ACTIONS(5802),
    [anon_sym_assert] = ACTIONS(5802),
    [anon_sym_property] = ACTIONS(5802),
    [anon_sym_assume] = ACTIONS(5802),
    [anon_sym_cover] = ACTIONS(5802),
    [anon_sym_sequence] = ACTIONS(5802),
    [anon_sym_restrict] = ACTIONS(5802),
    [anon_sym_not] = ACTIONS(5802),
    [anon_sym_or] = ACTIONS(5802),
    [anon_sym_and] = ACTIONS(5802),
    [anon_sym_case] = ACTIONS(5802),
    [anon_sym_always] = ACTIONS(5802),
    [anon_sym_covergroup] = ACTIONS(5802),
    [anon_sym_let] = ACTIONS(5802),
    [anon_sym_pulldown] = ACTIONS(5802),
    [anon_sym_pullup] = ACTIONS(5802),
    [anon_sym_cmos] = ACTIONS(5802),
    [anon_sym_rcmos] = ACTIONS(5802),
    [anon_sym_bufif0] = ACTIONS(5802),
    [anon_sym_bufif1] = ACTIONS(5802),
    [anon_sym_notif0] = ACTIONS(5802),
    [anon_sym_notif1] = ACTIONS(5802),
    [anon_sym_nmos] = ACTIONS(5802),
    [anon_sym_pmos] = ACTIONS(5802),
    [anon_sym_rnmos] = ACTIONS(5802),
    [anon_sym_rpmos] = ACTIONS(5802),
    [anon_sym_nand] = ACTIONS(5802),
    [anon_sym_nor] = ACTIONS(5802),
    [anon_sym_xor] = ACTIONS(5802),
    [anon_sym_xnor] = ACTIONS(5802),
    [anon_sym_buf] = ACTIONS(5802),
    [anon_sym_tranif0] = ACTIONS(5802),
    [anon_sym_tranif1] = ACTIONS(5802),
    [anon_sym_rtranif1] = ACTIONS(5802),
    [anon_sym_rtranif0] = ACTIONS(5802),
    [anon_sym_tran] = ACTIONS(5802),
    [anon_sym_rtran] = ACTIONS(5802),
    [anon_sym_generate] = ACTIONS(5802),
    [anon_sym_for] = ACTIONS(5802),
    [anon_sym_initial] = ACTIONS(5802),
    [anon_sym_assign] = ACTIONS(5802),
    [anon_sym_alias] = ACTIONS(5802),
    [anon_sym_always_comb] = ACTIONS(5802),
    [anon_sym_always_latch] = ACTIONS(5802),
    [anon_sym_always_ff] = ACTIONS(5802),
    [anon_sym_final] = ACTIONS(5802),
    [anon_sym_while] = ACTIONS(5802),
    [anon_sym_global] = ACTIONS(5802),
    [anon_sym_specify] = ACTIONS(5802),
    [anon_sym_LPAREN_STAR] = ACTIONS(5804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5804),
    [anon_sym_DOLLARunit] = ACTIONS(5804),
  },
  [1035] = {
    [sym_simple_identifier] = ACTIONS(5806),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5808),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5808),
    [anon_sym_BQUOTE] = ACTIONS(5806),
    [aux_sym_id_directive_token1] = ACTIONS(5808),
    [aux_sym_id_directive_token2] = ACTIONS(5808),
    [aux_sym_id_directive_token3] = ACTIONS(5808),
    [aux_sym_id_directive_token4] = ACTIONS(5806),
    [aux_sym_zero_directive_token1] = ACTIONS(5808),
    [aux_sym_zero_directive_token2] = ACTIONS(5808),
    [aux_sym_zero_directive_token3] = ACTIONS(5808),
    [aux_sym_zero_directive_token4] = ACTIONS(5808),
    [aux_sym_zero_directive_token5] = ACTIONS(5808),
    [aux_sym_zero_directive_token6] = ACTIONS(5808),
    [aux_sym_zero_directive_token7] = ACTIONS(5808),
    [aux_sym_zero_directive_token8] = ACTIONS(5808),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5808),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5808),
    [anon_sym_wire] = ACTIONS(5806),
    [anon_sym_tri] = ACTIONS(5806),
    [anon_sym_tri0] = ACTIONS(5806),
    [anon_sym_tri1] = ACTIONS(5806),
    [anon_sym_wand] = ACTIONS(5806),
    [anon_sym_triand] = ACTIONS(5806),
    [anon_sym_wor] = ACTIONS(5806),
    [anon_sym_trior] = ACTIONS(5806),
    [anon_sym_trireg] = ACTIONS(5806),
    [anon_sym_uwire] = ACTIONS(5806),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5808),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5808),
    [aux_sym_begin_keywords_token1] = ACTIONS(5808),
    [anon_sym_SEMI] = ACTIONS(5808),
    [anon_sym_endmodule] = ACTIONS(5806),
    [anon_sym_extern] = ACTIONS(5806),
    [anon_sym_module] = ACTIONS(5806),
    [anon_sym_macromodule] = ACTIONS(5806),
    [anon_sym_endinterface] = ACTIONS(5806),
    [anon_sym_interface] = ACTIONS(5806),
    [anon_sym_endprogram] = ACTIONS(5806),
    [anon_sym_program] = ACTIONS(5806),
    [anon_sym_checker] = ACTIONS(5806),
    [anon_sym_virtual] = ACTIONS(5806),
    [anon_sym_class] = ACTIONS(5806),
    [anon_sym_timeunit] = ACTIONS(5806),
    [anon_sym_timeprecision] = ACTIONS(5806),
    [anon_sym_type] = ACTIONS(5806),
    [anon_sym_input] = ACTIONS(5806),
    [anon_sym_output] = ACTIONS(5806),
    [anon_sym_inout] = ACTIONS(5806),
    [anon_sym_ref] = ACTIONS(5806),
    [anon_sym_DOLLARfatal] = ACTIONS(5808),
    [anon_sym_DOLLARerror] = ACTIONS(5808),
    [anon_sym_DOLLARwarning] = ACTIONS(5808),
    [anon_sym_DOLLARinfo] = ACTIONS(5808),
    [anon_sym_default] = ACTIONS(5806),
    [anon_sym_clocking] = ACTIONS(5806),
    [anon_sym_defparam] = ACTIONS(5806),
    [anon_sym_bind] = ACTIONS(5806),
    [anon_sym_const] = ACTIONS(5806),
    [anon_sym_function] = ACTIONS(5806),
    [anon_sym_static] = ACTIONS(5806),
    [anon_sym_constraint] = ACTIONS(5806),
    [anon_sym_if] = ACTIONS(5806),
    [anon_sym_else] = ACTIONS(5806),
    [anon_sym_LBRACK] = ACTIONS(5808),
    [anon_sym_localparam] = ACTIONS(5806),
    [anon_sym_parameter] = ACTIONS(5806),
    [anon_sym_specparam] = ACTIONS(5806),
    [anon_sym_var] = ACTIONS(5806),
    [anon_sym_import] = ACTIONS(5806),
    [anon_sym_export] = ACTIONS(5806),
    [anon_sym_genvar] = ACTIONS(5806),
    [anon_sym_interconnect] = ACTIONS(5806),
    [anon_sym_typedef] = ACTIONS(5806),
    [anon_sym_enum] = ACTIONS(5806),
    [anon_sym_struct] = ACTIONS(5806),
    [anon_sym_union] = ACTIONS(5806),
    [anon_sym_nettype] = ACTIONS(5806),
    [anon_sym_automatic] = ACTIONS(5806),
    [anon_sym_string] = ACTIONS(5806),
    [anon_sym_chandle] = ACTIONS(5806),
    [anon_sym_event] = ACTIONS(5806),
    [anon_sym_byte] = ACTIONS(5806),
    [anon_sym_shortint] = ACTIONS(5806),
    [anon_sym_int] = ACTIONS(5806),
    [anon_sym_longint] = ACTIONS(5806),
    [anon_sym_integer] = ACTIONS(5806),
    [anon_sym_time] = ACTIONS(5806),
    [anon_sym_bit] = ACTIONS(5806),
    [anon_sym_logic] = ACTIONS(5806),
    [anon_sym_reg] = ACTIONS(5806),
    [anon_sym_shortreal] = ACTIONS(5806),
    [anon_sym_real] = ACTIONS(5806),
    [anon_sym_realtime] = ACTIONS(5806),
    [anon_sym_supply0] = ACTIONS(5806),
    [anon_sym_supply1] = ACTIONS(5806),
    [anon_sym_signed] = ACTIONS(5806),
    [anon_sym_unsigned] = ACTIONS(5806),
    [anon_sym_task] = ACTIONS(5806),
    [anon_sym_modport] = ACTIONS(5806),
    [anon_sym_assert] = ACTIONS(5806),
    [anon_sym_property] = ACTIONS(5806),
    [anon_sym_assume] = ACTIONS(5806),
    [anon_sym_cover] = ACTIONS(5806),
    [anon_sym_sequence] = ACTIONS(5806),
    [anon_sym_restrict] = ACTIONS(5806),
    [anon_sym_not] = ACTIONS(5806),
    [anon_sym_or] = ACTIONS(5806),
    [anon_sym_and] = ACTIONS(5806),
    [anon_sym_case] = ACTIONS(5806),
    [anon_sym_always] = ACTIONS(5806),
    [anon_sym_covergroup] = ACTIONS(5806),
    [anon_sym_let] = ACTIONS(5806),
    [anon_sym_pulldown] = ACTIONS(5806),
    [anon_sym_pullup] = ACTIONS(5806),
    [anon_sym_cmos] = ACTIONS(5806),
    [anon_sym_rcmos] = ACTIONS(5806),
    [anon_sym_bufif0] = ACTIONS(5806),
    [anon_sym_bufif1] = ACTIONS(5806),
    [anon_sym_notif0] = ACTIONS(5806),
    [anon_sym_notif1] = ACTIONS(5806),
    [anon_sym_nmos] = ACTIONS(5806),
    [anon_sym_pmos] = ACTIONS(5806),
    [anon_sym_rnmos] = ACTIONS(5806),
    [anon_sym_rpmos] = ACTIONS(5806),
    [anon_sym_nand] = ACTIONS(5806),
    [anon_sym_nor] = ACTIONS(5806),
    [anon_sym_xor] = ACTIONS(5806),
    [anon_sym_xnor] = ACTIONS(5806),
    [anon_sym_buf] = ACTIONS(5806),
    [anon_sym_tranif0] = ACTIONS(5806),
    [anon_sym_tranif1] = ACTIONS(5806),
    [anon_sym_rtranif1] = ACTIONS(5806),
    [anon_sym_rtranif0] = ACTIONS(5806),
    [anon_sym_tran] = ACTIONS(5806),
    [anon_sym_rtran] = ACTIONS(5806),
    [anon_sym_generate] = ACTIONS(5806),
    [anon_sym_for] = ACTIONS(5806),
    [anon_sym_initial] = ACTIONS(5806),
    [anon_sym_assign] = ACTIONS(5806),
    [anon_sym_alias] = ACTIONS(5806),
    [anon_sym_always_comb] = ACTIONS(5806),
    [anon_sym_always_latch] = ACTIONS(5806),
    [anon_sym_always_ff] = ACTIONS(5806),
    [anon_sym_final] = ACTIONS(5806),
    [anon_sym_while] = ACTIONS(5806),
    [anon_sym_global] = ACTIONS(5806),
    [anon_sym_specify] = ACTIONS(5806),
    [anon_sym_LPAREN_STAR] = ACTIONS(5808),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5808),
    [anon_sym_DOLLARunit] = ACTIONS(5808),
  },
  [1036] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5812),
    [anon_sym_BQUOTE] = ACTIONS(5810),
    [aux_sym_id_directive_token1] = ACTIONS(5812),
    [aux_sym_id_directive_token2] = ACTIONS(5812),
    [aux_sym_id_directive_token3] = ACTIONS(5812),
    [aux_sym_id_directive_token4] = ACTIONS(5810),
    [aux_sym_zero_directive_token1] = ACTIONS(5812),
    [aux_sym_zero_directive_token2] = ACTIONS(5812),
    [aux_sym_zero_directive_token3] = ACTIONS(5812),
    [aux_sym_zero_directive_token4] = ACTIONS(5812),
    [aux_sym_zero_directive_token5] = ACTIONS(5812),
    [aux_sym_zero_directive_token6] = ACTIONS(5812),
    [aux_sym_zero_directive_token7] = ACTIONS(5812),
    [aux_sym_zero_directive_token8] = ACTIONS(5812),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5812),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5812),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_begin_keywords_token1] = ACTIONS(5812),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_endmodule] = ACTIONS(5810),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_module] = ACTIONS(5810),
    [anon_sym_macromodule] = ACTIONS(5810),
    [anon_sym_endinterface] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_endprogram] = ACTIONS(5810),
    [anon_sym_program] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_timeunit] = ACTIONS(5810),
    [anon_sym_timeprecision] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_input] = ACTIONS(5810),
    [anon_sym_output] = ACTIONS(5810),
    [anon_sym_inout] = ACTIONS(5810),
    [anon_sym_ref] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(5814),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_specparam] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_modport] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_while] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_specify] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [1037] = {
    [sym_simple_identifier] = ACTIONS(5816),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5818),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5818),
    [anon_sym_BQUOTE] = ACTIONS(5816),
    [aux_sym_id_directive_token1] = ACTIONS(5818),
    [aux_sym_id_directive_token2] = ACTIONS(5818),
    [aux_sym_id_directive_token3] = ACTIONS(5818),
    [aux_sym_id_directive_token4] = ACTIONS(5816),
    [aux_sym_zero_directive_token1] = ACTIONS(5818),
    [aux_sym_zero_directive_token2] = ACTIONS(5818),
    [aux_sym_zero_directive_token3] = ACTIONS(5818),
    [aux_sym_zero_directive_token4] = ACTIONS(5818),
    [aux_sym_zero_directive_token5] = ACTIONS(5818),
    [aux_sym_zero_directive_token6] = ACTIONS(5818),
    [aux_sym_zero_directive_token7] = ACTIONS(5818),
    [aux_sym_zero_directive_token8] = ACTIONS(5818),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5818),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5818),
    [anon_sym_wire] = ACTIONS(5816),
    [anon_sym_tri] = ACTIONS(5816),
    [anon_sym_tri0] = ACTIONS(5816),
    [anon_sym_tri1] = ACTIONS(5816),
    [anon_sym_wand] = ACTIONS(5816),
    [anon_sym_triand] = ACTIONS(5816),
    [anon_sym_wor] = ACTIONS(5816),
    [anon_sym_trior] = ACTIONS(5816),
    [anon_sym_trireg] = ACTIONS(5816),
    [anon_sym_uwire] = ACTIONS(5816),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5818),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5818),
    [aux_sym_begin_keywords_token1] = ACTIONS(5818),
    [anon_sym_SEMI] = ACTIONS(5818),
    [anon_sym_endmodule] = ACTIONS(5816),
    [anon_sym_extern] = ACTIONS(5816),
    [anon_sym_module] = ACTIONS(5816),
    [anon_sym_macromodule] = ACTIONS(5816),
    [anon_sym_endinterface] = ACTIONS(5816),
    [anon_sym_interface] = ACTIONS(5816),
    [anon_sym_endprogram] = ACTIONS(5816),
    [anon_sym_program] = ACTIONS(5816),
    [anon_sym_checker] = ACTIONS(5816),
    [anon_sym_virtual] = ACTIONS(5816),
    [anon_sym_class] = ACTIONS(5816),
    [anon_sym_timeunit] = ACTIONS(5816),
    [anon_sym_timeprecision] = ACTIONS(5816),
    [anon_sym_type] = ACTIONS(5816),
    [anon_sym_input] = ACTIONS(5816),
    [anon_sym_output] = ACTIONS(5816),
    [anon_sym_inout] = ACTIONS(5816),
    [anon_sym_ref] = ACTIONS(5816),
    [anon_sym_DOLLARfatal] = ACTIONS(5818),
    [anon_sym_DOLLARerror] = ACTIONS(5818),
    [anon_sym_DOLLARwarning] = ACTIONS(5818),
    [anon_sym_DOLLARinfo] = ACTIONS(5818),
    [anon_sym_default] = ACTIONS(5816),
    [anon_sym_clocking] = ACTIONS(5816),
    [anon_sym_defparam] = ACTIONS(5816),
    [anon_sym_bind] = ACTIONS(5816),
    [anon_sym_const] = ACTIONS(5816),
    [anon_sym_function] = ACTIONS(5816),
    [anon_sym_static] = ACTIONS(5816),
    [anon_sym_constraint] = ACTIONS(5816),
    [anon_sym_if] = ACTIONS(5816),
    [anon_sym_else] = ACTIONS(5816),
    [anon_sym_LBRACK] = ACTIONS(5818),
    [anon_sym_localparam] = ACTIONS(5816),
    [anon_sym_parameter] = ACTIONS(5816),
    [anon_sym_specparam] = ACTIONS(5816),
    [anon_sym_var] = ACTIONS(5816),
    [anon_sym_import] = ACTIONS(5816),
    [anon_sym_export] = ACTIONS(5816),
    [anon_sym_genvar] = ACTIONS(5816),
    [anon_sym_interconnect] = ACTIONS(5816),
    [anon_sym_typedef] = ACTIONS(5816),
    [anon_sym_enum] = ACTIONS(5816),
    [anon_sym_struct] = ACTIONS(5816),
    [anon_sym_union] = ACTIONS(5816),
    [anon_sym_nettype] = ACTIONS(5816),
    [anon_sym_automatic] = ACTIONS(5816),
    [anon_sym_string] = ACTIONS(5816),
    [anon_sym_chandle] = ACTIONS(5816),
    [anon_sym_event] = ACTIONS(5816),
    [anon_sym_byte] = ACTIONS(5816),
    [anon_sym_shortint] = ACTIONS(5816),
    [anon_sym_int] = ACTIONS(5816),
    [anon_sym_longint] = ACTIONS(5816),
    [anon_sym_integer] = ACTIONS(5816),
    [anon_sym_time] = ACTIONS(5816),
    [anon_sym_bit] = ACTIONS(5816),
    [anon_sym_logic] = ACTIONS(5816),
    [anon_sym_reg] = ACTIONS(5816),
    [anon_sym_shortreal] = ACTIONS(5816),
    [anon_sym_real] = ACTIONS(5816),
    [anon_sym_realtime] = ACTIONS(5816),
    [anon_sym_supply0] = ACTIONS(5816),
    [anon_sym_supply1] = ACTIONS(5816),
    [anon_sym_signed] = ACTIONS(5816),
    [anon_sym_unsigned] = ACTIONS(5816),
    [anon_sym_task] = ACTIONS(5816),
    [anon_sym_modport] = ACTIONS(5816),
    [anon_sym_assert] = ACTIONS(5816),
    [anon_sym_property] = ACTIONS(5816),
    [anon_sym_assume] = ACTIONS(5816),
    [anon_sym_cover] = ACTIONS(5816),
    [anon_sym_sequence] = ACTIONS(5816),
    [anon_sym_restrict] = ACTIONS(5816),
    [anon_sym_not] = ACTIONS(5816),
    [anon_sym_or] = ACTIONS(5816),
    [anon_sym_and] = ACTIONS(5816),
    [anon_sym_case] = ACTIONS(5816),
    [anon_sym_always] = ACTIONS(5816),
    [anon_sym_covergroup] = ACTIONS(5816),
    [anon_sym_let] = ACTIONS(5816),
    [anon_sym_pulldown] = ACTIONS(5816),
    [anon_sym_pullup] = ACTIONS(5816),
    [anon_sym_cmos] = ACTIONS(5816),
    [anon_sym_rcmos] = ACTIONS(5816),
    [anon_sym_bufif0] = ACTIONS(5816),
    [anon_sym_bufif1] = ACTIONS(5816),
    [anon_sym_notif0] = ACTIONS(5816),
    [anon_sym_notif1] = ACTIONS(5816),
    [anon_sym_nmos] = ACTIONS(5816),
    [anon_sym_pmos] = ACTIONS(5816),
    [anon_sym_rnmos] = ACTIONS(5816),
    [anon_sym_rpmos] = ACTIONS(5816),
    [anon_sym_nand] = ACTIONS(5816),
    [anon_sym_nor] = ACTIONS(5816),
    [anon_sym_xor] = ACTIONS(5816),
    [anon_sym_xnor] = ACTIONS(5816),
    [anon_sym_buf] = ACTIONS(5816),
    [anon_sym_tranif0] = ACTIONS(5816),
    [anon_sym_tranif1] = ACTIONS(5816),
    [anon_sym_rtranif1] = ACTIONS(5816),
    [anon_sym_rtranif0] = ACTIONS(5816),
    [anon_sym_tran] = ACTIONS(5816),
    [anon_sym_rtran] = ACTIONS(5816),
    [anon_sym_generate] = ACTIONS(5816),
    [anon_sym_for] = ACTIONS(5816),
    [anon_sym_initial] = ACTIONS(5816),
    [anon_sym_assign] = ACTIONS(5816),
    [anon_sym_alias] = ACTIONS(5816),
    [anon_sym_always_comb] = ACTIONS(5816),
    [anon_sym_always_latch] = ACTIONS(5816),
    [anon_sym_always_ff] = ACTIONS(5816),
    [anon_sym_final] = ACTIONS(5816),
    [anon_sym_while] = ACTIONS(5816),
    [anon_sym_global] = ACTIONS(5816),
    [anon_sym_specify] = ACTIONS(5816),
    [anon_sym_LPAREN_STAR] = ACTIONS(5818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5818),
    [anon_sym_DOLLARunit] = ACTIONS(5818),
  },
  [1038] = {
    [sym_simple_identifier] = ACTIONS(5820),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5822),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5822),
    [anon_sym_BQUOTE] = ACTIONS(5820),
    [aux_sym_id_directive_token1] = ACTIONS(5822),
    [aux_sym_id_directive_token2] = ACTIONS(5822),
    [aux_sym_id_directive_token3] = ACTIONS(5822),
    [aux_sym_id_directive_token4] = ACTIONS(5820),
    [aux_sym_zero_directive_token1] = ACTIONS(5822),
    [aux_sym_zero_directive_token2] = ACTIONS(5822),
    [aux_sym_zero_directive_token3] = ACTIONS(5822),
    [aux_sym_zero_directive_token4] = ACTIONS(5822),
    [aux_sym_zero_directive_token5] = ACTIONS(5822),
    [aux_sym_zero_directive_token6] = ACTIONS(5822),
    [aux_sym_zero_directive_token7] = ACTIONS(5822),
    [aux_sym_zero_directive_token8] = ACTIONS(5822),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5822),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5822),
    [anon_sym_wire] = ACTIONS(5820),
    [anon_sym_tri] = ACTIONS(5820),
    [anon_sym_tri0] = ACTIONS(5820),
    [anon_sym_tri1] = ACTIONS(5820),
    [anon_sym_wand] = ACTIONS(5820),
    [anon_sym_triand] = ACTIONS(5820),
    [anon_sym_wor] = ACTIONS(5820),
    [anon_sym_trior] = ACTIONS(5820),
    [anon_sym_trireg] = ACTIONS(5820),
    [anon_sym_uwire] = ACTIONS(5820),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5822),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5822),
    [aux_sym_begin_keywords_token1] = ACTIONS(5822),
    [anon_sym_SEMI] = ACTIONS(5822),
    [anon_sym_endmodule] = ACTIONS(5820),
    [anon_sym_extern] = ACTIONS(5820),
    [anon_sym_module] = ACTIONS(5820),
    [anon_sym_macromodule] = ACTIONS(5820),
    [anon_sym_endinterface] = ACTIONS(5820),
    [anon_sym_interface] = ACTIONS(5820),
    [anon_sym_endprogram] = ACTIONS(5820),
    [anon_sym_program] = ACTIONS(5820),
    [anon_sym_checker] = ACTIONS(5820),
    [anon_sym_virtual] = ACTIONS(5820),
    [anon_sym_class] = ACTIONS(5820),
    [anon_sym_timeunit] = ACTIONS(5820),
    [anon_sym_timeprecision] = ACTIONS(5820),
    [anon_sym_type] = ACTIONS(5820),
    [anon_sym_input] = ACTIONS(5820),
    [anon_sym_output] = ACTIONS(5820),
    [anon_sym_inout] = ACTIONS(5820),
    [anon_sym_ref] = ACTIONS(5820),
    [anon_sym_DOLLARfatal] = ACTIONS(5822),
    [anon_sym_DOLLARerror] = ACTIONS(5822),
    [anon_sym_DOLLARwarning] = ACTIONS(5822),
    [anon_sym_DOLLARinfo] = ACTIONS(5822),
    [anon_sym_default] = ACTIONS(5820),
    [anon_sym_clocking] = ACTIONS(5820),
    [anon_sym_defparam] = ACTIONS(5820),
    [anon_sym_bind] = ACTIONS(5820),
    [anon_sym_const] = ACTIONS(5820),
    [anon_sym_function] = ACTIONS(5820),
    [anon_sym_static] = ACTIONS(5820),
    [anon_sym_constraint] = ACTIONS(5820),
    [anon_sym_if] = ACTIONS(5820),
    [anon_sym_else] = ACTIONS(5820),
    [anon_sym_LBRACK] = ACTIONS(5822),
    [anon_sym_localparam] = ACTIONS(5820),
    [anon_sym_parameter] = ACTIONS(5820),
    [anon_sym_specparam] = ACTIONS(5820),
    [anon_sym_var] = ACTIONS(5820),
    [anon_sym_import] = ACTIONS(5820),
    [anon_sym_export] = ACTIONS(5820),
    [anon_sym_genvar] = ACTIONS(5820),
    [anon_sym_interconnect] = ACTIONS(5820),
    [anon_sym_typedef] = ACTIONS(5820),
    [anon_sym_enum] = ACTIONS(5820),
    [anon_sym_struct] = ACTIONS(5820),
    [anon_sym_union] = ACTIONS(5820),
    [anon_sym_nettype] = ACTIONS(5820),
    [anon_sym_automatic] = ACTIONS(5820),
    [anon_sym_string] = ACTIONS(5820),
    [anon_sym_chandle] = ACTIONS(5820),
    [anon_sym_event] = ACTIONS(5820),
    [anon_sym_byte] = ACTIONS(5820),
    [anon_sym_shortint] = ACTIONS(5820),
    [anon_sym_int] = ACTIONS(5820),
    [anon_sym_longint] = ACTIONS(5820),
    [anon_sym_integer] = ACTIONS(5820),
    [anon_sym_time] = ACTIONS(5820),
    [anon_sym_bit] = ACTIONS(5820),
    [anon_sym_logic] = ACTIONS(5820),
    [anon_sym_reg] = ACTIONS(5820),
    [anon_sym_shortreal] = ACTIONS(5820),
    [anon_sym_real] = ACTIONS(5820),
    [anon_sym_realtime] = ACTIONS(5820),
    [anon_sym_supply0] = ACTIONS(5820),
    [anon_sym_supply1] = ACTIONS(5820),
    [anon_sym_signed] = ACTIONS(5820),
    [anon_sym_unsigned] = ACTIONS(5820),
    [anon_sym_task] = ACTIONS(5820),
    [anon_sym_modport] = ACTIONS(5820),
    [anon_sym_assert] = ACTIONS(5820),
    [anon_sym_property] = ACTIONS(5820),
    [anon_sym_assume] = ACTIONS(5820),
    [anon_sym_cover] = ACTIONS(5820),
    [anon_sym_sequence] = ACTIONS(5820),
    [anon_sym_restrict] = ACTIONS(5820),
    [anon_sym_not] = ACTIONS(5820),
    [anon_sym_or] = ACTIONS(5820),
    [anon_sym_and] = ACTIONS(5820),
    [anon_sym_case] = ACTIONS(5820),
    [anon_sym_always] = ACTIONS(5820),
    [anon_sym_covergroup] = ACTIONS(5820),
    [anon_sym_let] = ACTIONS(5820),
    [anon_sym_pulldown] = ACTIONS(5820),
    [anon_sym_pullup] = ACTIONS(5820),
    [anon_sym_cmos] = ACTIONS(5820),
    [anon_sym_rcmos] = ACTIONS(5820),
    [anon_sym_bufif0] = ACTIONS(5820),
    [anon_sym_bufif1] = ACTIONS(5820),
    [anon_sym_notif0] = ACTIONS(5820),
    [anon_sym_notif1] = ACTIONS(5820),
    [anon_sym_nmos] = ACTIONS(5820),
    [anon_sym_pmos] = ACTIONS(5820),
    [anon_sym_rnmos] = ACTIONS(5820),
    [anon_sym_rpmos] = ACTIONS(5820),
    [anon_sym_nand] = ACTIONS(5820),
    [anon_sym_nor] = ACTIONS(5820),
    [anon_sym_xor] = ACTIONS(5820),
    [anon_sym_xnor] = ACTIONS(5820),
    [anon_sym_buf] = ACTIONS(5820),
    [anon_sym_tranif0] = ACTIONS(5820),
    [anon_sym_tranif1] = ACTIONS(5820),
    [anon_sym_rtranif1] = ACTIONS(5820),
    [anon_sym_rtranif0] = ACTIONS(5820),
    [anon_sym_tran] = ACTIONS(5820),
    [anon_sym_rtran] = ACTIONS(5820),
    [anon_sym_generate] = ACTIONS(5820),
    [anon_sym_for] = ACTIONS(5820),
    [anon_sym_initial] = ACTIONS(5820),
    [anon_sym_assign] = ACTIONS(5820),
    [anon_sym_alias] = ACTIONS(5820),
    [anon_sym_always_comb] = ACTIONS(5820),
    [anon_sym_always_latch] = ACTIONS(5820),
    [anon_sym_always_ff] = ACTIONS(5820),
    [anon_sym_final] = ACTIONS(5820),
    [anon_sym_while] = ACTIONS(5820),
    [anon_sym_global] = ACTIONS(5820),
    [anon_sym_specify] = ACTIONS(5820),
    [anon_sym_LPAREN_STAR] = ACTIONS(5822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5822),
    [anon_sym_DOLLARunit] = ACTIONS(5822),
  },
  [1039] = {
    [sym_simple_identifier] = ACTIONS(5824),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5826),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5826),
    [anon_sym_BQUOTE] = ACTIONS(5824),
    [aux_sym_id_directive_token1] = ACTIONS(5826),
    [aux_sym_id_directive_token2] = ACTIONS(5826),
    [aux_sym_id_directive_token3] = ACTIONS(5826),
    [aux_sym_id_directive_token4] = ACTIONS(5824),
    [aux_sym_zero_directive_token1] = ACTIONS(5826),
    [aux_sym_zero_directive_token2] = ACTIONS(5826),
    [aux_sym_zero_directive_token3] = ACTIONS(5826),
    [aux_sym_zero_directive_token4] = ACTIONS(5826),
    [aux_sym_zero_directive_token5] = ACTIONS(5826),
    [aux_sym_zero_directive_token6] = ACTIONS(5826),
    [aux_sym_zero_directive_token7] = ACTIONS(5826),
    [aux_sym_zero_directive_token8] = ACTIONS(5826),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5826),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5826),
    [anon_sym_wire] = ACTIONS(5824),
    [anon_sym_tri] = ACTIONS(5824),
    [anon_sym_tri0] = ACTIONS(5824),
    [anon_sym_tri1] = ACTIONS(5824),
    [anon_sym_wand] = ACTIONS(5824),
    [anon_sym_triand] = ACTIONS(5824),
    [anon_sym_wor] = ACTIONS(5824),
    [anon_sym_trior] = ACTIONS(5824),
    [anon_sym_trireg] = ACTIONS(5824),
    [anon_sym_uwire] = ACTIONS(5824),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5826),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5826),
    [aux_sym_begin_keywords_token1] = ACTIONS(5826),
    [anon_sym_SEMI] = ACTIONS(5826),
    [anon_sym_endmodule] = ACTIONS(5824),
    [anon_sym_extern] = ACTIONS(5824),
    [anon_sym_module] = ACTIONS(5824),
    [anon_sym_macromodule] = ACTIONS(5824),
    [anon_sym_endinterface] = ACTIONS(5824),
    [anon_sym_interface] = ACTIONS(5824),
    [anon_sym_endprogram] = ACTIONS(5824),
    [anon_sym_program] = ACTIONS(5824),
    [anon_sym_checker] = ACTIONS(5824),
    [anon_sym_virtual] = ACTIONS(5824),
    [anon_sym_class] = ACTIONS(5824),
    [anon_sym_timeunit] = ACTIONS(5824),
    [anon_sym_timeprecision] = ACTIONS(5824),
    [anon_sym_type] = ACTIONS(5824),
    [anon_sym_input] = ACTIONS(5824),
    [anon_sym_output] = ACTIONS(5824),
    [anon_sym_inout] = ACTIONS(5824),
    [anon_sym_ref] = ACTIONS(5824),
    [anon_sym_DOLLARfatal] = ACTIONS(5826),
    [anon_sym_DOLLARerror] = ACTIONS(5826),
    [anon_sym_DOLLARwarning] = ACTIONS(5826),
    [anon_sym_DOLLARinfo] = ACTIONS(5826),
    [anon_sym_default] = ACTIONS(5824),
    [anon_sym_clocking] = ACTIONS(5824),
    [anon_sym_defparam] = ACTIONS(5824),
    [anon_sym_bind] = ACTIONS(5824),
    [anon_sym_const] = ACTIONS(5824),
    [anon_sym_function] = ACTIONS(5824),
    [anon_sym_static] = ACTIONS(5824),
    [anon_sym_constraint] = ACTIONS(5824),
    [anon_sym_if] = ACTIONS(5824),
    [anon_sym_else] = ACTIONS(5824),
    [anon_sym_LBRACK] = ACTIONS(5826),
    [anon_sym_localparam] = ACTIONS(5824),
    [anon_sym_parameter] = ACTIONS(5824),
    [anon_sym_specparam] = ACTIONS(5824),
    [anon_sym_var] = ACTIONS(5824),
    [anon_sym_import] = ACTIONS(5824),
    [anon_sym_export] = ACTIONS(5824),
    [anon_sym_genvar] = ACTIONS(5824),
    [anon_sym_interconnect] = ACTIONS(5824),
    [anon_sym_typedef] = ACTIONS(5824),
    [anon_sym_enum] = ACTIONS(5824),
    [anon_sym_struct] = ACTIONS(5824),
    [anon_sym_union] = ACTIONS(5824),
    [anon_sym_nettype] = ACTIONS(5824),
    [anon_sym_automatic] = ACTIONS(5824),
    [anon_sym_string] = ACTIONS(5824),
    [anon_sym_chandle] = ACTIONS(5824),
    [anon_sym_event] = ACTIONS(5824),
    [anon_sym_byte] = ACTIONS(5824),
    [anon_sym_shortint] = ACTIONS(5824),
    [anon_sym_int] = ACTIONS(5824),
    [anon_sym_longint] = ACTIONS(5824),
    [anon_sym_integer] = ACTIONS(5824),
    [anon_sym_time] = ACTIONS(5824),
    [anon_sym_bit] = ACTIONS(5824),
    [anon_sym_logic] = ACTIONS(5824),
    [anon_sym_reg] = ACTIONS(5824),
    [anon_sym_shortreal] = ACTIONS(5824),
    [anon_sym_real] = ACTIONS(5824),
    [anon_sym_realtime] = ACTIONS(5824),
    [anon_sym_supply0] = ACTIONS(5824),
    [anon_sym_supply1] = ACTIONS(5824),
    [anon_sym_signed] = ACTIONS(5824),
    [anon_sym_unsigned] = ACTIONS(5824),
    [anon_sym_task] = ACTIONS(5824),
    [anon_sym_modport] = ACTIONS(5824),
    [anon_sym_assert] = ACTIONS(5824),
    [anon_sym_property] = ACTIONS(5824),
    [anon_sym_assume] = ACTIONS(5824),
    [anon_sym_cover] = ACTIONS(5824),
    [anon_sym_sequence] = ACTIONS(5824),
    [anon_sym_restrict] = ACTIONS(5824),
    [anon_sym_not] = ACTIONS(5824),
    [anon_sym_or] = ACTIONS(5824),
    [anon_sym_and] = ACTIONS(5824),
    [anon_sym_case] = ACTIONS(5824),
    [anon_sym_always] = ACTIONS(5824),
    [anon_sym_covergroup] = ACTIONS(5824),
    [anon_sym_let] = ACTIONS(5824),
    [anon_sym_pulldown] = ACTIONS(5824),
    [anon_sym_pullup] = ACTIONS(5824),
    [anon_sym_cmos] = ACTIONS(5824),
    [anon_sym_rcmos] = ACTIONS(5824),
    [anon_sym_bufif0] = ACTIONS(5824),
    [anon_sym_bufif1] = ACTIONS(5824),
    [anon_sym_notif0] = ACTIONS(5824),
    [anon_sym_notif1] = ACTIONS(5824),
    [anon_sym_nmos] = ACTIONS(5824),
    [anon_sym_pmos] = ACTIONS(5824),
    [anon_sym_rnmos] = ACTIONS(5824),
    [anon_sym_rpmos] = ACTIONS(5824),
    [anon_sym_nand] = ACTIONS(5824),
    [anon_sym_nor] = ACTIONS(5824),
    [anon_sym_xor] = ACTIONS(5824),
    [anon_sym_xnor] = ACTIONS(5824),
    [anon_sym_buf] = ACTIONS(5824),
    [anon_sym_tranif0] = ACTIONS(5824),
    [anon_sym_tranif1] = ACTIONS(5824),
    [anon_sym_rtranif1] = ACTIONS(5824),
    [anon_sym_rtranif0] = ACTIONS(5824),
    [anon_sym_tran] = ACTIONS(5824),
    [anon_sym_rtran] = ACTIONS(5824),
    [anon_sym_generate] = ACTIONS(5824),
    [anon_sym_for] = ACTIONS(5824),
    [anon_sym_initial] = ACTIONS(5824),
    [anon_sym_assign] = ACTIONS(5824),
    [anon_sym_alias] = ACTIONS(5824),
    [anon_sym_always_comb] = ACTIONS(5824),
    [anon_sym_always_latch] = ACTIONS(5824),
    [anon_sym_always_ff] = ACTIONS(5824),
    [anon_sym_final] = ACTIONS(5824),
    [anon_sym_while] = ACTIONS(5824),
    [anon_sym_global] = ACTIONS(5824),
    [anon_sym_specify] = ACTIONS(5824),
    [anon_sym_LPAREN_STAR] = ACTIONS(5826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5826),
    [anon_sym_DOLLARunit] = ACTIONS(5826),
  },
  [1040] = {
    [sym_simple_identifier] = ACTIONS(5828),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5830),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5830),
    [anon_sym_BQUOTE] = ACTIONS(5828),
    [aux_sym_id_directive_token1] = ACTIONS(5830),
    [aux_sym_id_directive_token2] = ACTIONS(5830),
    [aux_sym_id_directive_token3] = ACTIONS(5830),
    [aux_sym_id_directive_token4] = ACTIONS(5828),
    [aux_sym_zero_directive_token1] = ACTIONS(5830),
    [aux_sym_zero_directive_token2] = ACTIONS(5830),
    [aux_sym_zero_directive_token3] = ACTIONS(5830),
    [aux_sym_zero_directive_token4] = ACTIONS(5830),
    [aux_sym_zero_directive_token5] = ACTIONS(5830),
    [aux_sym_zero_directive_token6] = ACTIONS(5830),
    [aux_sym_zero_directive_token7] = ACTIONS(5830),
    [aux_sym_zero_directive_token8] = ACTIONS(5830),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5830),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5830),
    [anon_sym_wire] = ACTIONS(5828),
    [anon_sym_tri] = ACTIONS(5828),
    [anon_sym_tri0] = ACTIONS(5828),
    [anon_sym_tri1] = ACTIONS(5828),
    [anon_sym_wand] = ACTIONS(5828),
    [anon_sym_triand] = ACTIONS(5828),
    [anon_sym_wor] = ACTIONS(5828),
    [anon_sym_trior] = ACTIONS(5828),
    [anon_sym_trireg] = ACTIONS(5828),
    [anon_sym_uwire] = ACTIONS(5828),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5830),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5830),
    [aux_sym_begin_keywords_token1] = ACTIONS(5830),
    [anon_sym_SEMI] = ACTIONS(5830),
    [anon_sym_endmodule] = ACTIONS(5828),
    [anon_sym_extern] = ACTIONS(5828),
    [anon_sym_module] = ACTIONS(5828),
    [anon_sym_macromodule] = ACTIONS(5828),
    [anon_sym_endinterface] = ACTIONS(5828),
    [anon_sym_interface] = ACTIONS(5828),
    [anon_sym_endprogram] = ACTIONS(5828),
    [anon_sym_program] = ACTIONS(5828),
    [anon_sym_checker] = ACTIONS(5828),
    [anon_sym_virtual] = ACTIONS(5828),
    [anon_sym_class] = ACTIONS(5828),
    [anon_sym_timeunit] = ACTIONS(5828),
    [anon_sym_timeprecision] = ACTIONS(5828),
    [anon_sym_type] = ACTIONS(5828),
    [anon_sym_input] = ACTIONS(5828),
    [anon_sym_output] = ACTIONS(5828),
    [anon_sym_inout] = ACTIONS(5828),
    [anon_sym_ref] = ACTIONS(5828),
    [anon_sym_DOLLARfatal] = ACTIONS(5830),
    [anon_sym_DOLLARerror] = ACTIONS(5830),
    [anon_sym_DOLLARwarning] = ACTIONS(5830),
    [anon_sym_DOLLARinfo] = ACTIONS(5830),
    [anon_sym_default] = ACTIONS(5828),
    [anon_sym_clocking] = ACTIONS(5828),
    [anon_sym_defparam] = ACTIONS(5828),
    [anon_sym_bind] = ACTIONS(5828),
    [anon_sym_const] = ACTIONS(5828),
    [anon_sym_function] = ACTIONS(5828),
    [anon_sym_static] = ACTIONS(5828),
    [anon_sym_constraint] = ACTIONS(5828),
    [anon_sym_if] = ACTIONS(5828),
    [anon_sym_else] = ACTIONS(5828),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_localparam] = ACTIONS(5828),
    [anon_sym_parameter] = ACTIONS(5828),
    [anon_sym_specparam] = ACTIONS(5828),
    [anon_sym_var] = ACTIONS(5828),
    [anon_sym_import] = ACTIONS(5828),
    [anon_sym_export] = ACTIONS(5828),
    [anon_sym_genvar] = ACTIONS(5828),
    [anon_sym_interconnect] = ACTIONS(5828),
    [anon_sym_typedef] = ACTIONS(5828),
    [anon_sym_enum] = ACTIONS(5828),
    [anon_sym_struct] = ACTIONS(5828),
    [anon_sym_union] = ACTIONS(5828),
    [anon_sym_nettype] = ACTIONS(5828),
    [anon_sym_automatic] = ACTIONS(5828),
    [anon_sym_string] = ACTIONS(5828),
    [anon_sym_chandle] = ACTIONS(5828),
    [anon_sym_event] = ACTIONS(5828),
    [anon_sym_byte] = ACTIONS(5828),
    [anon_sym_shortint] = ACTIONS(5828),
    [anon_sym_int] = ACTIONS(5828),
    [anon_sym_longint] = ACTIONS(5828),
    [anon_sym_integer] = ACTIONS(5828),
    [anon_sym_time] = ACTIONS(5828),
    [anon_sym_bit] = ACTIONS(5828),
    [anon_sym_logic] = ACTIONS(5828),
    [anon_sym_reg] = ACTIONS(5828),
    [anon_sym_shortreal] = ACTIONS(5828),
    [anon_sym_real] = ACTIONS(5828),
    [anon_sym_realtime] = ACTIONS(5828),
    [anon_sym_supply0] = ACTIONS(5828),
    [anon_sym_supply1] = ACTIONS(5828),
    [anon_sym_signed] = ACTIONS(5828),
    [anon_sym_unsigned] = ACTIONS(5828),
    [anon_sym_task] = ACTIONS(5828),
    [anon_sym_modport] = ACTIONS(5828),
    [anon_sym_assert] = ACTIONS(5828),
    [anon_sym_property] = ACTIONS(5828),
    [anon_sym_assume] = ACTIONS(5828),
    [anon_sym_cover] = ACTIONS(5828),
    [anon_sym_sequence] = ACTIONS(5828),
    [anon_sym_restrict] = ACTIONS(5828),
    [anon_sym_not] = ACTIONS(5828),
    [anon_sym_or] = ACTIONS(5828),
    [anon_sym_and] = ACTIONS(5828),
    [anon_sym_case] = ACTIONS(5828),
    [anon_sym_always] = ACTIONS(5828),
    [anon_sym_covergroup] = ACTIONS(5828),
    [anon_sym_let] = ACTIONS(5828),
    [anon_sym_pulldown] = ACTIONS(5828),
    [anon_sym_pullup] = ACTIONS(5828),
    [anon_sym_cmos] = ACTIONS(5828),
    [anon_sym_rcmos] = ACTIONS(5828),
    [anon_sym_bufif0] = ACTIONS(5828),
    [anon_sym_bufif1] = ACTIONS(5828),
    [anon_sym_notif0] = ACTIONS(5828),
    [anon_sym_notif1] = ACTIONS(5828),
    [anon_sym_nmos] = ACTIONS(5828),
    [anon_sym_pmos] = ACTIONS(5828),
    [anon_sym_rnmos] = ACTIONS(5828),
    [anon_sym_rpmos] = ACTIONS(5828),
    [anon_sym_nand] = ACTIONS(5828),
    [anon_sym_nor] = ACTIONS(5828),
    [anon_sym_xor] = ACTIONS(5828),
    [anon_sym_xnor] = ACTIONS(5828),
    [anon_sym_buf] = ACTIONS(5828),
    [anon_sym_tranif0] = ACTIONS(5828),
    [anon_sym_tranif1] = ACTIONS(5828),
    [anon_sym_rtranif1] = ACTIONS(5828),
    [anon_sym_rtranif0] = ACTIONS(5828),
    [anon_sym_tran] = ACTIONS(5828),
    [anon_sym_rtran] = ACTIONS(5828),
    [anon_sym_generate] = ACTIONS(5828),
    [anon_sym_for] = ACTIONS(5828),
    [anon_sym_initial] = ACTIONS(5828),
    [anon_sym_assign] = ACTIONS(5828),
    [anon_sym_alias] = ACTIONS(5828),
    [anon_sym_always_comb] = ACTIONS(5828),
    [anon_sym_always_latch] = ACTIONS(5828),
    [anon_sym_always_ff] = ACTIONS(5828),
    [anon_sym_final] = ACTIONS(5828),
    [anon_sym_while] = ACTIONS(5828),
    [anon_sym_global] = ACTIONS(5828),
    [anon_sym_specify] = ACTIONS(5828),
    [anon_sym_LPAREN_STAR] = ACTIONS(5830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5830),
    [anon_sym_DOLLARunit] = ACTIONS(5830),
  },
  [1041] = {
    [sym_simple_identifier] = ACTIONS(5832),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5834),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5834),
    [anon_sym_BQUOTE] = ACTIONS(5832),
    [aux_sym_id_directive_token1] = ACTIONS(5834),
    [aux_sym_id_directive_token2] = ACTIONS(5834),
    [aux_sym_id_directive_token3] = ACTIONS(5834),
    [aux_sym_id_directive_token4] = ACTIONS(5832),
    [aux_sym_zero_directive_token1] = ACTIONS(5834),
    [aux_sym_zero_directive_token2] = ACTIONS(5834),
    [aux_sym_zero_directive_token3] = ACTIONS(5834),
    [aux_sym_zero_directive_token4] = ACTIONS(5834),
    [aux_sym_zero_directive_token5] = ACTIONS(5834),
    [aux_sym_zero_directive_token6] = ACTIONS(5834),
    [aux_sym_zero_directive_token7] = ACTIONS(5834),
    [aux_sym_zero_directive_token8] = ACTIONS(5834),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5834),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5834),
    [anon_sym_wire] = ACTIONS(5832),
    [anon_sym_tri] = ACTIONS(5832),
    [anon_sym_tri0] = ACTIONS(5832),
    [anon_sym_tri1] = ACTIONS(5832),
    [anon_sym_wand] = ACTIONS(5832),
    [anon_sym_triand] = ACTIONS(5832),
    [anon_sym_wor] = ACTIONS(5832),
    [anon_sym_trior] = ACTIONS(5832),
    [anon_sym_trireg] = ACTIONS(5832),
    [anon_sym_uwire] = ACTIONS(5832),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5834),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5834),
    [aux_sym_begin_keywords_token1] = ACTIONS(5834),
    [anon_sym_SEMI] = ACTIONS(5834),
    [anon_sym_endmodule] = ACTIONS(5832),
    [anon_sym_extern] = ACTIONS(5832),
    [anon_sym_module] = ACTIONS(5832),
    [anon_sym_macromodule] = ACTIONS(5832),
    [anon_sym_endinterface] = ACTIONS(5832),
    [anon_sym_interface] = ACTIONS(5832),
    [anon_sym_endprogram] = ACTIONS(5832),
    [anon_sym_program] = ACTIONS(5832),
    [anon_sym_checker] = ACTIONS(5832),
    [anon_sym_virtual] = ACTIONS(5832),
    [anon_sym_class] = ACTIONS(5832),
    [anon_sym_timeunit] = ACTIONS(5832),
    [anon_sym_timeprecision] = ACTIONS(5832),
    [anon_sym_type] = ACTIONS(5832),
    [anon_sym_input] = ACTIONS(5832),
    [anon_sym_output] = ACTIONS(5832),
    [anon_sym_inout] = ACTIONS(5832),
    [anon_sym_ref] = ACTIONS(5832),
    [anon_sym_DOLLARfatal] = ACTIONS(5834),
    [anon_sym_DOLLARerror] = ACTIONS(5834),
    [anon_sym_DOLLARwarning] = ACTIONS(5834),
    [anon_sym_DOLLARinfo] = ACTIONS(5834),
    [anon_sym_default] = ACTIONS(5832),
    [anon_sym_clocking] = ACTIONS(5832),
    [anon_sym_defparam] = ACTIONS(5832),
    [anon_sym_bind] = ACTIONS(5832),
    [anon_sym_const] = ACTIONS(5832),
    [anon_sym_function] = ACTIONS(5832),
    [anon_sym_static] = ACTIONS(5832),
    [anon_sym_constraint] = ACTIONS(5832),
    [anon_sym_if] = ACTIONS(5832),
    [anon_sym_else] = ACTIONS(5832),
    [anon_sym_LBRACK] = ACTIONS(5834),
    [anon_sym_localparam] = ACTIONS(5832),
    [anon_sym_parameter] = ACTIONS(5832),
    [anon_sym_specparam] = ACTIONS(5832),
    [anon_sym_var] = ACTIONS(5832),
    [anon_sym_import] = ACTIONS(5832),
    [anon_sym_export] = ACTIONS(5832),
    [anon_sym_genvar] = ACTIONS(5832),
    [anon_sym_interconnect] = ACTIONS(5832),
    [anon_sym_typedef] = ACTIONS(5832),
    [anon_sym_enum] = ACTIONS(5832),
    [anon_sym_struct] = ACTIONS(5832),
    [anon_sym_union] = ACTIONS(5832),
    [anon_sym_nettype] = ACTIONS(5832),
    [anon_sym_automatic] = ACTIONS(5832),
    [anon_sym_string] = ACTIONS(5832),
    [anon_sym_chandle] = ACTIONS(5832),
    [anon_sym_event] = ACTIONS(5832),
    [anon_sym_byte] = ACTIONS(5832),
    [anon_sym_shortint] = ACTIONS(5832),
    [anon_sym_int] = ACTIONS(5832),
    [anon_sym_longint] = ACTIONS(5832),
    [anon_sym_integer] = ACTIONS(5832),
    [anon_sym_time] = ACTIONS(5832),
    [anon_sym_bit] = ACTIONS(5832),
    [anon_sym_logic] = ACTIONS(5832),
    [anon_sym_reg] = ACTIONS(5832),
    [anon_sym_shortreal] = ACTIONS(5832),
    [anon_sym_real] = ACTIONS(5832),
    [anon_sym_realtime] = ACTIONS(5832),
    [anon_sym_supply0] = ACTIONS(5832),
    [anon_sym_supply1] = ACTIONS(5832),
    [anon_sym_signed] = ACTIONS(5832),
    [anon_sym_unsigned] = ACTIONS(5832),
    [anon_sym_task] = ACTIONS(5832),
    [anon_sym_modport] = ACTIONS(5832),
    [anon_sym_assert] = ACTIONS(5832),
    [anon_sym_property] = ACTIONS(5832),
    [anon_sym_assume] = ACTIONS(5832),
    [anon_sym_cover] = ACTIONS(5832),
    [anon_sym_sequence] = ACTIONS(5832),
    [anon_sym_restrict] = ACTIONS(5832),
    [anon_sym_not] = ACTIONS(5832),
    [anon_sym_or] = ACTIONS(5832),
    [anon_sym_and] = ACTIONS(5832),
    [anon_sym_case] = ACTIONS(5832),
    [anon_sym_always] = ACTIONS(5832),
    [anon_sym_covergroup] = ACTIONS(5832),
    [anon_sym_let] = ACTIONS(5832),
    [anon_sym_pulldown] = ACTIONS(5832),
    [anon_sym_pullup] = ACTIONS(5832),
    [anon_sym_cmos] = ACTIONS(5832),
    [anon_sym_rcmos] = ACTIONS(5832),
    [anon_sym_bufif0] = ACTIONS(5832),
    [anon_sym_bufif1] = ACTIONS(5832),
    [anon_sym_notif0] = ACTIONS(5832),
    [anon_sym_notif1] = ACTIONS(5832),
    [anon_sym_nmos] = ACTIONS(5832),
    [anon_sym_pmos] = ACTIONS(5832),
    [anon_sym_rnmos] = ACTIONS(5832),
    [anon_sym_rpmos] = ACTIONS(5832),
    [anon_sym_nand] = ACTIONS(5832),
    [anon_sym_nor] = ACTIONS(5832),
    [anon_sym_xor] = ACTIONS(5832),
    [anon_sym_xnor] = ACTIONS(5832),
    [anon_sym_buf] = ACTIONS(5832),
    [anon_sym_tranif0] = ACTIONS(5832),
    [anon_sym_tranif1] = ACTIONS(5832),
    [anon_sym_rtranif1] = ACTIONS(5832),
    [anon_sym_rtranif0] = ACTIONS(5832),
    [anon_sym_tran] = ACTIONS(5832),
    [anon_sym_rtran] = ACTIONS(5832),
    [anon_sym_generate] = ACTIONS(5832),
    [anon_sym_for] = ACTIONS(5832),
    [anon_sym_initial] = ACTIONS(5832),
    [anon_sym_assign] = ACTIONS(5832),
    [anon_sym_alias] = ACTIONS(5832),
    [anon_sym_always_comb] = ACTIONS(5832),
    [anon_sym_always_latch] = ACTIONS(5832),
    [anon_sym_always_ff] = ACTIONS(5832),
    [anon_sym_final] = ACTIONS(5832),
    [anon_sym_while] = ACTIONS(5832),
    [anon_sym_global] = ACTIONS(5832),
    [anon_sym_specify] = ACTIONS(5832),
    [anon_sym_LPAREN_STAR] = ACTIONS(5834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5834),
    [anon_sym_DOLLARunit] = ACTIONS(5834),
  },
  [1042] = {
    [sym_simple_identifier] = ACTIONS(5836),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5838),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5838),
    [anon_sym_BQUOTE] = ACTIONS(5836),
    [aux_sym_id_directive_token1] = ACTIONS(5838),
    [aux_sym_id_directive_token2] = ACTIONS(5838),
    [aux_sym_id_directive_token3] = ACTIONS(5838),
    [aux_sym_id_directive_token4] = ACTIONS(5836),
    [aux_sym_zero_directive_token1] = ACTIONS(5838),
    [aux_sym_zero_directive_token2] = ACTIONS(5838),
    [aux_sym_zero_directive_token3] = ACTIONS(5838),
    [aux_sym_zero_directive_token4] = ACTIONS(5838),
    [aux_sym_zero_directive_token5] = ACTIONS(5838),
    [aux_sym_zero_directive_token6] = ACTIONS(5838),
    [aux_sym_zero_directive_token7] = ACTIONS(5838),
    [aux_sym_zero_directive_token8] = ACTIONS(5838),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5838),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5838),
    [anon_sym_wire] = ACTIONS(5836),
    [anon_sym_tri] = ACTIONS(5836),
    [anon_sym_tri0] = ACTIONS(5836),
    [anon_sym_tri1] = ACTIONS(5836),
    [anon_sym_wand] = ACTIONS(5836),
    [anon_sym_triand] = ACTIONS(5836),
    [anon_sym_wor] = ACTIONS(5836),
    [anon_sym_trior] = ACTIONS(5836),
    [anon_sym_trireg] = ACTIONS(5836),
    [anon_sym_uwire] = ACTIONS(5836),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5838),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5838),
    [aux_sym_begin_keywords_token1] = ACTIONS(5838),
    [anon_sym_SEMI] = ACTIONS(5838),
    [anon_sym_endmodule] = ACTIONS(5836),
    [anon_sym_extern] = ACTIONS(5836),
    [anon_sym_module] = ACTIONS(5836),
    [anon_sym_macromodule] = ACTIONS(5836),
    [anon_sym_endinterface] = ACTIONS(5836),
    [anon_sym_interface] = ACTIONS(5836),
    [anon_sym_endprogram] = ACTIONS(5836),
    [anon_sym_program] = ACTIONS(5836),
    [anon_sym_checker] = ACTIONS(5836),
    [anon_sym_virtual] = ACTIONS(5836),
    [anon_sym_class] = ACTIONS(5836),
    [anon_sym_timeunit] = ACTIONS(5836),
    [anon_sym_timeprecision] = ACTIONS(5836),
    [anon_sym_type] = ACTIONS(5836),
    [anon_sym_input] = ACTIONS(5836),
    [anon_sym_output] = ACTIONS(5836),
    [anon_sym_inout] = ACTIONS(5836),
    [anon_sym_ref] = ACTIONS(5836),
    [anon_sym_DOLLARfatal] = ACTIONS(5838),
    [anon_sym_DOLLARerror] = ACTIONS(5838),
    [anon_sym_DOLLARwarning] = ACTIONS(5838),
    [anon_sym_DOLLARinfo] = ACTIONS(5838),
    [anon_sym_default] = ACTIONS(5836),
    [anon_sym_clocking] = ACTIONS(5836),
    [anon_sym_defparam] = ACTIONS(5836),
    [anon_sym_bind] = ACTIONS(5836),
    [anon_sym_const] = ACTIONS(5836),
    [anon_sym_function] = ACTIONS(5836),
    [anon_sym_static] = ACTIONS(5836),
    [anon_sym_constraint] = ACTIONS(5836),
    [anon_sym_if] = ACTIONS(5836),
    [anon_sym_else] = ACTIONS(5836),
    [anon_sym_LBRACK] = ACTIONS(5838),
    [anon_sym_localparam] = ACTIONS(5836),
    [anon_sym_parameter] = ACTIONS(5836),
    [anon_sym_specparam] = ACTIONS(5836),
    [anon_sym_var] = ACTIONS(5836),
    [anon_sym_import] = ACTIONS(5836),
    [anon_sym_export] = ACTIONS(5836),
    [anon_sym_genvar] = ACTIONS(5836),
    [anon_sym_interconnect] = ACTIONS(5836),
    [anon_sym_typedef] = ACTIONS(5836),
    [anon_sym_enum] = ACTIONS(5836),
    [anon_sym_struct] = ACTIONS(5836),
    [anon_sym_union] = ACTIONS(5836),
    [anon_sym_nettype] = ACTIONS(5836),
    [anon_sym_automatic] = ACTIONS(5836),
    [anon_sym_string] = ACTIONS(5836),
    [anon_sym_chandle] = ACTIONS(5836),
    [anon_sym_event] = ACTIONS(5836),
    [anon_sym_byte] = ACTIONS(5836),
    [anon_sym_shortint] = ACTIONS(5836),
    [anon_sym_int] = ACTIONS(5836),
    [anon_sym_longint] = ACTIONS(5836),
    [anon_sym_integer] = ACTIONS(5836),
    [anon_sym_time] = ACTIONS(5836),
    [anon_sym_bit] = ACTIONS(5836),
    [anon_sym_logic] = ACTIONS(5836),
    [anon_sym_reg] = ACTIONS(5836),
    [anon_sym_shortreal] = ACTIONS(5836),
    [anon_sym_real] = ACTIONS(5836),
    [anon_sym_realtime] = ACTIONS(5836),
    [anon_sym_supply0] = ACTIONS(5836),
    [anon_sym_supply1] = ACTIONS(5836),
    [anon_sym_signed] = ACTIONS(5836),
    [anon_sym_unsigned] = ACTIONS(5836),
    [anon_sym_task] = ACTIONS(5836),
    [anon_sym_modport] = ACTIONS(5836),
    [anon_sym_assert] = ACTIONS(5836),
    [anon_sym_property] = ACTIONS(5836),
    [anon_sym_assume] = ACTIONS(5836),
    [anon_sym_cover] = ACTIONS(5836),
    [anon_sym_sequence] = ACTIONS(5836),
    [anon_sym_restrict] = ACTIONS(5836),
    [anon_sym_not] = ACTIONS(5836),
    [anon_sym_or] = ACTIONS(5836),
    [anon_sym_and] = ACTIONS(5836),
    [anon_sym_case] = ACTIONS(5836),
    [anon_sym_always] = ACTIONS(5836),
    [anon_sym_covergroup] = ACTIONS(5836),
    [anon_sym_let] = ACTIONS(5836),
    [anon_sym_pulldown] = ACTIONS(5836),
    [anon_sym_pullup] = ACTIONS(5836),
    [anon_sym_cmos] = ACTIONS(5836),
    [anon_sym_rcmos] = ACTIONS(5836),
    [anon_sym_bufif0] = ACTIONS(5836),
    [anon_sym_bufif1] = ACTIONS(5836),
    [anon_sym_notif0] = ACTIONS(5836),
    [anon_sym_notif1] = ACTIONS(5836),
    [anon_sym_nmos] = ACTIONS(5836),
    [anon_sym_pmos] = ACTIONS(5836),
    [anon_sym_rnmos] = ACTIONS(5836),
    [anon_sym_rpmos] = ACTIONS(5836),
    [anon_sym_nand] = ACTIONS(5836),
    [anon_sym_nor] = ACTIONS(5836),
    [anon_sym_xor] = ACTIONS(5836),
    [anon_sym_xnor] = ACTIONS(5836),
    [anon_sym_buf] = ACTIONS(5836),
    [anon_sym_tranif0] = ACTIONS(5836),
    [anon_sym_tranif1] = ACTIONS(5836),
    [anon_sym_rtranif1] = ACTIONS(5836),
    [anon_sym_rtranif0] = ACTIONS(5836),
    [anon_sym_tran] = ACTIONS(5836),
    [anon_sym_rtran] = ACTIONS(5836),
    [anon_sym_generate] = ACTIONS(5836),
    [anon_sym_for] = ACTIONS(5836),
    [anon_sym_initial] = ACTIONS(5836),
    [anon_sym_assign] = ACTIONS(5836),
    [anon_sym_alias] = ACTIONS(5836),
    [anon_sym_always_comb] = ACTIONS(5836),
    [anon_sym_always_latch] = ACTIONS(5836),
    [anon_sym_always_ff] = ACTIONS(5836),
    [anon_sym_final] = ACTIONS(5836),
    [anon_sym_while] = ACTIONS(5836),
    [anon_sym_global] = ACTIONS(5836),
    [anon_sym_specify] = ACTIONS(5836),
    [anon_sym_LPAREN_STAR] = ACTIONS(5838),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5838),
    [anon_sym_DOLLARunit] = ACTIONS(5838),
  },
  [1043] = {
    [sym_simple_identifier] = ACTIONS(5840),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5842),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5842),
    [anon_sym_BQUOTE] = ACTIONS(5840),
    [aux_sym_id_directive_token1] = ACTIONS(5842),
    [aux_sym_id_directive_token2] = ACTIONS(5842),
    [aux_sym_id_directive_token3] = ACTIONS(5842),
    [aux_sym_id_directive_token4] = ACTIONS(5840),
    [aux_sym_zero_directive_token1] = ACTIONS(5842),
    [aux_sym_zero_directive_token2] = ACTIONS(5842),
    [aux_sym_zero_directive_token3] = ACTIONS(5842),
    [aux_sym_zero_directive_token4] = ACTIONS(5842),
    [aux_sym_zero_directive_token5] = ACTIONS(5842),
    [aux_sym_zero_directive_token6] = ACTIONS(5842),
    [aux_sym_zero_directive_token7] = ACTIONS(5842),
    [aux_sym_zero_directive_token8] = ACTIONS(5842),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5842),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5842),
    [anon_sym_wire] = ACTIONS(5840),
    [anon_sym_tri] = ACTIONS(5840),
    [anon_sym_tri0] = ACTIONS(5840),
    [anon_sym_tri1] = ACTIONS(5840),
    [anon_sym_wand] = ACTIONS(5840),
    [anon_sym_triand] = ACTIONS(5840),
    [anon_sym_wor] = ACTIONS(5840),
    [anon_sym_trior] = ACTIONS(5840),
    [anon_sym_trireg] = ACTIONS(5840),
    [anon_sym_uwire] = ACTIONS(5840),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5842),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5842),
    [aux_sym_begin_keywords_token1] = ACTIONS(5842),
    [anon_sym_SEMI] = ACTIONS(5842),
    [anon_sym_endmodule] = ACTIONS(5840),
    [anon_sym_extern] = ACTIONS(5840),
    [anon_sym_module] = ACTIONS(5840),
    [anon_sym_macromodule] = ACTIONS(5840),
    [anon_sym_endinterface] = ACTIONS(5840),
    [anon_sym_interface] = ACTIONS(5840),
    [anon_sym_endprogram] = ACTIONS(5840),
    [anon_sym_program] = ACTIONS(5840),
    [anon_sym_checker] = ACTIONS(5840),
    [anon_sym_virtual] = ACTIONS(5840),
    [anon_sym_class] = ACTIONS(5840),
    [anon_sym_timeunit] = ACTIONS(5840),
    [anon_sym_timeprecision] = ACTIONS(5840),
    [anon_sym_type] = ACTIONS(5840),
    [anon_sym_input] = ACTIONS(5840),
    [anon_sym_output] = ACTIONS(5840),
    [anon_sym_inout] = ACTIONS(5840),
    [anon_sym_ref] = ACTIONS(5840),
    [anon_sym_DOLLARfatal] = ACTIONS(5842),
    [anon_sym_DOLLARerror] = ACTIONS(5842),
    [anon_sym_DOLLARwarning] = ACTIONS(5842),
    [anon_sym_DOLLARinfo] = ACTIONS(5842),
    [anon_sym_default] = ACTIONS(5840),
    [anon_sym_clocking] = ACTIONS(5840),
    [anon_sym_defparam] = ACTIONS(5840),
    [anon_sym_bind] = ACTIONS(5840),
    [anon_sym_const] = ACTIONS(5840),
    [anon_sym_function] = ACTIONS(5840),
    [anon_sym_static] = ACTIONS(5840),
    [anon_sym_constraint] = ACTIONS(5840),
    [anon_sym_if] = ACTIONS(5840),
    [anon_sym_else] = ACTIONS(5840),
    [anon_sym_LBRACK] = ACTIONS(5842),
    [anon_sym_localparam] = ACTIONS(5840),
    [anon_sym_parameter] = ACTIONS(5840),
    [anon_sym_specparam] = ACTIONS(5840),
    [anon_sym_var] = ACTIONS(5840),
    [anon_sym_import] = ACTIONS(5840),
    [anon_sym_export] = ACTIONS(5840),
    [anon_sym_genvar] = ACTIONS(5840),
    [anon_sym_interconnect] = ACTIONS(5840),
    [anon_sym_typedef] = ACTIONS(5840),
    [anon_sym_enum] = ACTIONS(5840),
    [anon_sym_struct] = ACTIONS(5840),
    [anon_sym_union] = ACTIONS(5840),
    [anon_sym_nettype] = ACTIONS(5840),
    [anon_sym_automatic] = ACTIONS(5840),
    [anon_sym_string] = ACTIONS(5840),
    [anon_sym_chandle] = ACTIONS(5840),
    [anon_sym_event] = ACTIONS(5840),
    [anon_sym_byte] = ACTIONS(5840),
    [anon_sym_shortint] = ACTIONS(5840),
    [anon_sym_int] = ACTIONS(5840),
    [anon_sym_longint] = ACTIONS(5840),
    [anon_sym_integer] = ACTIONS(5840),
    [anon_sym_time] = ACTIONS(5840),
    [anon_sym_bit] = ACTIONS(5840),
    [anon_sym_logic] = ACTIONS(5840),
    [anon_sym_reg] = ACTIONS(5840),
    [anon_sym_shortreal] = ACTIONS(5840),
    [anon_sym_real] = ACTIONS(5840),
    [anon_sym_realtime] = ACTIONS(5840),
    [anon_sym_supply0] = ACTIONS(5840),
    [anon_sym_supply1] = ACTIONS(5840),
    [anon_sym_signed] = ACTIONS(5840),
    [anon_sym_unsigned] = ACTIONS(5840),
    [anon_sym_task] = ACTIONS(5840),
    [anon_sym_modport] = ACTIONS(5840),
    [anon_sym_assert] = ACTIONS(5840),
    [anon_sym_property] = ACTIONS(5840),
    [anon_sym_assume] = ACTIONS(5840),
    [anon_sym_cover] = ACTIONS(5840),
    [anon_sym_sequence] = ACTIONS(5840),
    [anon_sym_restrict] = ACTIONS(5840),
    [anon_sym_not] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5840),
    [anon_sym_and] = ACTIONS(5840),
    [anon_sym_case] = ACTIONS(5840),
    [anon_sym_always] = ACTIONS(5840),
    [anon_sym_covergroup] = ACTIONS(5840),
    [anon_sym_let] = ACTIONS(5840),
    [anon_sym_pulldown] = ACTIONS(5840),
    [anon_sym_pullup] = ACTIONS(5840),
    [anon_sym_cmos] = ACTIONS(5840),
    [anon_sym_rcmos] = ACTIONS(5840),
    [anon_sym_bufif0] = ACTIONS(5840),
    [anon_sym_bufif1] = ACTIONS(5840),
    [anon_sym_notif0] = ACTIONS(5840),
    [anon_sym_notif1] = ACTIONS(5840),
    [anon_sym_nmos] = ACTIONS(5840),
    [anon_sym_pmos] = ACTIONS(5840),
    [anon_sym_rnmos] = ACTIONS(5840),
    [anon_sym_rpmos] = ACTIONS(5840),
    [anon_sym_nand] = ACTIONS(5840),
    [anon_sym_nor] = ACTIONS(5840),
    [anon_sym_xor] = ACTIONS(5840),
    [anon_sym_xnor] = ACTIONS(5840),
    [anon_sym_buf] = ACTIONS(5840),
    [anon_sym_tranif0] = ACTIONS(5840),
    [anon_sym_tranif1] = ACTIONS(5840),
    [anon_sym_rtranif1] = ACTIONS(5840),
    [anon_sym_rtranif0] = ACTIONS(5840),
    [anon_sym_tran] = ACTIONS(5840),
    [anon_sym_rtran] = ACTIONS(5840),
    [anon_sym_generate] = ACTIONS(5840),
    [anon_sym_for] = ACTIONS(5840),
    [anon_sym_initial] = ACTIONS(5840),
    [anon_sym_assign] = ACTIONS(5840),
    [anon_sym_alias] = ACTIONS(5840),
    [anon_sym_always_comb] = ACTIONS(5840),
    [anon_sym_always_latch] = ACTIONS(5840),
    [anon_sym_always_ff] = ACTIONS(5840),
    [anon_sym_final] = ACTIONS(5840),
    [anon_sym_while] = ACTIONS(5840),
    [anon_sym_global] = ACTIONS(5840),
    [anon_sym_specify] = ACTIONS(5840),
    [anon_sym_LPAREN_STAR] = ACTIONS(5842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5842),
    [anon_sym_DOLLARunit] = ACTIONS(5842),
  },
  [1044] = {
    [sym_simple_identifier] = ACTIONS(5844),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5846),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5846),
    [anon_sym_BQUOTE] = ACTIONS(5844),
    [aux_sym_id_directive_token1] = ACTIONS(5846),
    [aux_sym_id_directive_token2] = ACTIONS(5846),
    [aux_sym_id_directive_token3] = ACTIONS(5846),
    [aux_sym_id_directive_token4] = ACTIONS(5844),
    [aux_sym_zero_directive_token1] = ACTIONS(5846),
    [aux_sym_zero_directive_token2] = ACTIONS(5846),
    [aux_sym_zero_directive_token3] = ACTIONS(5846),
    [aux_sym_zero_directive_token4] = ACTIONS(5846),
    [aux_sym_zero_directive_token5] = ACTIONS(5846),
    [aux_sym_zero_directive_token6] = ACTIONS(5846),
    [aux_sym_zero_directive_token7] = ACTIONS(5846),
    [aux_sym_zero_directive_token8] = ACTIONS(5846),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5846),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5846),
    [anon_sym_wire] = ACTIONS(5844),
    [anon_sym_tri] = ACTIONS(5844),
    [anon_sym_tri0] = ACTIONS(5844),
    [anon_sym_tri1] = ACTIONS(5844),
    [anon_sym_wand] = ACTIONS(5844),
    [anon_sym_triand] = ACTIONS(5844),
    [anon_sym_wor] = ACTIONS(5844),
    [anon_sym_trior] = ACTIONS(5844),
    [anon_sym_trireg] = ACTIONS(5844),
    [anon_sym_uwire] = ACTIONS(5844),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5846),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5846),
    [aux_sym_begin_keywords_token1] = ACTIONS(5846),
    [anon_sym_SEMI] = ACTIONS(5846),
    [anon_sym_endmodule] = ACTIONS(5844),
    [anon_sym_extern] = ACTIONS(5844),
    [anon_sym_module] = ACTIONS(5844),
    [anon_sym_macromodule] = ACTIONS(5844),
    [anon_sym_endinterface] = ACTIONS(5844),
    [anon_sym_interface] = ACTIONS(5844),
    [anon_sym_endprogram] = ACTIONS(5844),
    [anon_sym_program] = ACTIONS(5844),
    [anon_sym_checker] = ACTIONS(5844),
    [anon_sym_virtual] = ACTIONS(5844),
    [anon_sym_class] = ACTIONS(5844),
    [anon_sym_timeunit] = ACTIONS(5844),
    [anon_sym_timeprecision] = ACTIONS(5844),
    [anon_sym_type] = ACTIONS(5844),
    [anon_sym_input] = ACTIONS(5844),
    [anon_sym_output] = ACTIONS(5844),
    [anon_sym_inout] = ACTIONS(5844),
    [anon_sym_ref] = ACTIONS(5844),
    [anon_sym_DOLLARfatal] = ACTIONS(5846),
    [anon_sym_DOLLARerror] = ACTIONS(5846),
    [anon_sym_DOLLARwarning] = ACTIONS(5846),
    [anon_sym_DOLLARinfo] = ACTIONS(5846),
    [anon_sym_default] = ACTIONS(5844),
    [anon_sym_clocking] = ACTIONS(5844),
    [anon_sym_defparam] = ACTIONS(5844),
    [anon_sym_bind] = ACTIONS(5844),
    [anon_sym_const] = ACTIONS(5844),
    [anon_sym_function] = ACTIONS(5844),
    [anon_sym_static] = ACTIONS(5844),
    [anon_sym_constraint] = ACTIONS(5844),
    [anon_sym_if] = ACTIONS(5844),
    [anon_sym_else] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_localparam] = ACTIONS(5844),
    [anon_sym_parameter] = ACTIONS(5844),
    [anon_sym_specparam] = ACTIONS(5844),
    [anon_sym_var] = ACTIONS(5844),
    [anon_sym_import] = ACTIONS(5844),
    [anon_sym_export] = ACTIONS(5844),
    [anon_sym_genvar] = ACTIONS(5844),
    [anon_sym_interconnect] = ACTIONS(5844),
    [anon_sym_typedef] = ACTIONS(5844),
    [anon_sym_enum] = ACTIONS(5844),
    [anon_sym_struct] = ACTIONS(5844),
    [anon_sym_union] = ACTIONS(5844),
    [anon_sym_nettype] = ACTIONS(5844),
    [anon_sym_automatic] = ACTIONS(5844),
    [anon_sym_string] = ACTIONS(5844),
    [anon_sym_chandle] = ACTIONS(5844),
    [anon_sym_event] = ACTIONS(5844),
    [anon_sym_byte] = ACTIONS(5844),
    [anon_sym_shortint] = ACTIONS(5844),
    [anon_sym_int] = ACTIONS(5844),
    [anon_sym_longint] = ACTIONS(5844),
    [anon_sym_integer] = ACTIONS(5844),
    [anon_sym_time] = ACTIONS(5844),
    [anon_sym_bit] = ACTIONS(5844),
    [anon_sym_logic] = ACTIONS(5844),
    [anon_sym_reg] = ACTIONS(5844),
    [anon_sym_shortreal] = ACTIONS(5844),
    [anon_sym_real] = ACTIONS(5844),
    [anon_sym_realtime] = ACTIONS(5844),
    [anon_sym_supply0] = ACTIONS(5844),
    [anon_sym_supply1] = ACTIONS(5844),
    [anon_sym_signed] = ACTIONS(5844),
    [anon_sym_unsigned] = ACTIONS(5844),
    [anon_sym_task] = ACTIONS(5844),
    [anon_sym_modport] = ACTIONS(5844),
    [anon_sym_assert] = ACTIONS(5844),
    [anon_sym_property] = ACTIONS(5844),
    [anon_sym_assume] = ACTIONS(5844),
    [anon_sym_cover] = ACTIONS(5844),
    [anon_sym_sequence] = ACTIONS(5844),
    [anon_sym_restrict] = ACTIONS(5844),
    [anon_sym_not] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5844),
    [anon_sym_and] = ACTIONS(5844),
    [anon_sym_case] = ACTIONS(5844),
    [anon_sym_always] = ACTIONS(5844),
    [anon_sym_covergroup] = ACTIONS(5844),
    [anon_sym_let] = ACTIONS(5844),
    [anon_sym_pulldown] = ACTIONS(5844),
    [anon_sym_pullup] = ACTIONS(5844),
    [anon_sym_cmos] = ACTIONS(5844),
    [anon_sym_rcmos] = ACTIONS(5844),
    [anon_sym_bufif0] = ACTIONS(5844),
    [anon_sym_bufif1] = ACTIONS(5844),
    [anon_sym_notif0] = ACTIONS(5844),
    [anon_sym_notif1] = ACTIONS(5844),
    [anon_sym_nmos] = ACTIONS(5844),
    [anon_sym_pmos] = ACTIONS(5844),
    [anon_sym_rnmos] = ACTIONS(5844),
    [anon_sym_rpmos] = ACTIONS(5844),
    [anon_sym_nand] = ACTIONS(5844),
    [anon_sym_nor] = ACTIONS(5844),
    [anon_sym_xor] = ACTIONS(5844),
    [anon_sym_xnor] = ACTIONS(5844),
    [anon_sym_buf] = ACTIONS(5844),
    [anon_sym_tranif0] = ACTIONS(5844),
    [anon_sym_tranif1] = ACTIONS(5844),
    [anon_sym_rtranif1] = ACTIONS(5844),
    [anon_sym_rtranif0] = ACTIONS(5844),
    [anon_sym_tran] = ACTIONS(5844),
    [anon_sym_rtran] = ACTIONS(5844),
    [anon_sym_generate] = ACTIONS(5844),
    [anon_sym_for] = ACTIONS(5844),
    [anon_sym_initial] = ACTIONS(5844),
    [anon_sym_assign] = ACTIONS(5844),
    [anon_sym_alias] = ACTIONS(5844),
    [anon_sym_always_comb] = ACTIONS(5844),
    [anon_sym_always_latch] = ACTIONS(5844),
    [anon_sym_always_ff] = ACTIONS(5844),
    [anon_sym_final] = ACTIONS(5844),
    [anon_sym_while] = ACTIONS(5844),
    [anon_sym_global] = ACTIONS(5844),
    [anon_sym_specify] = ACTIONS(5844),
    [anon_sym_LPAREN_STAR] = ACTIONS(5846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5846),
    [anon_sym_DOLLARunit] = ACTIONS(5846),
  },
  [1045] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5850),
    [anon_sym_BQUOTE] = ACTIONS(5848),
    [aux_sym_id_directive_token1] = ACTIONS(5850),
    [aux_sym_id_directive_token2] = ACTIONS(5850),
    [aux_sym_id_directive_token3] = ACTIONS(5850),
    [aux_sym_id_directive_token4] = ACTIONS(5848),
    [aux_sym_zero_directive_token1] = ACTIONS(5850),
    [aux_sym_zero_directive_token2] = ACTIONS(5850),
    [aux_sym_zero_directive_token3] = ACTIONS(5850),
    [aux_sym_zero_directive_token4] = ACTIONS(5850),
    [aux_sym_zero_directive_token5] = ACTIONS(5850),
    [aux_sym_zero_directive_token6] = ACTIONS(5850),
    [aux_sym_zero_directive_token7] = ACTIONS(5850),
    [aux_sym_zero_directive_token8] = ACTIONS(5850),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5850),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5850),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_begin_keywords_token1] = ACTIONS(5850),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_endmodule] = ACTIONS(5848),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_module] = ACTIONS(5848),
    [anon_sym_macromodule] = ACTIONS(5848),
    [anon_sym_endinterface] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_endprogram] = ACTIONS(5848),
    [anon_sym_program] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_timeunit] = ACTIONS(5848),
    [anon_sym_timeprecision] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_input] = ACTIONS(5848),
    [anon_sym_output] = ACTIONS(5848),
    [anon_sym_inout] = ACTIONS(5848),
    [anon_sym_ref] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(5852),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_specparam] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_modport] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_while] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_specify] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [1046] = {
    [sym_simple_identifier] = ACTIONS(5854),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5856),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5856),
    [anon_sym_BQUOTE] = ACTIONS(5854),
    [aux_sym_id_directive_token1] = ACTIONS(5856),
    [aux_sym_id_directive_token2] = ACTIONS(5856),
    [aux_sym_id_directive_token3] = ACTIONS(5856),
    [aux_sym_id_directive_token4] = ACTIONS(5854),
    [aux_sym_zero_directive_token1] = ACTIONS(5856),
    [aux_sym_zero_directive_token2] = ACTIONS(5856),
    [aux_sym_zero_directive_token3] = ACTIONS(5856),
    [aux_sym_zero_directive_token4] = ACTIONS(5856),
    [aux_sym_zero_directive_token5] = ACTIONS(5856),
    [aux_sym_zero_directive_token6] = ACTIONS(5856),
    [aux_sym_zero_directive_token7] = ACTIONS(5856),
    [aux_sym_zero_directive_token8] = ACTIONS(5856),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5856),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5856),
    [anon_sym_wire] = ACTIONS(5854),
    [anon_sym_tri] = ACTIONS(5854),
    [anon_sym_tri0] = ACTIONS(5854),
    [anon_sym_tri1] = ACTIONS(5854),
    [anon_sym_wand] = ACTIONS(5854),
    [anon_sym_triand] = ACTIONS(5854),
    [anon_sym_wor] = ACTIONS(5854),
    [anon_sym_trior] = ACTIONS(5854),
    [anon_sym_trireg] = ACTIONS(5854),
    [anon_sym_uwire] = ACTIONS(5854),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5856),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5856),
    [aux_sym_begin_keywords_token1] = ACTIONS(5856),
    [anon_sym_SEMI] = ACTIONS(5856),
    [anon_sym_endmodule] = ACTIONS(5854),
    [anon_sym_extern] = ACTIONS(5854),
    [anon_sym_module] = ACTIONS(5854),
    [anon_sym_macromodule] = ACTIONS(5854),
    [anon_sym_endinterface] = ACTIONS(5854),
    [anon_sym_interface] = ACTIONS(5854),
    [anon_sym_endprogram] = ACTIONS(5854),
    [anon_sym_program] = ACTIONS(5854),
    [anon_sym_checker] = ACTIONS(5854),
    [anon_sym_virtual] = ACTIONS(5854),
    [anon_sym_class] = ACTIONS(5854),
    [anon_sym_timeunit] = ACTIONS(5854),
    [anon_sym_timeprecision] = ACTIONS(5854),
    [anon_sym_type] = ACTIONS(5854),
    [anon_sym_input] = ACTIONS(5854),
    [anon_sym_output] = ACTIONS(5854),
    [anon_sym_inout] = ACTIONS(5854),
    [anon_sym_ref] = ACTIONS(5854),
    [anon_sym_DOLLARfatal] = ACTIONS(5856),
    [anon_sym_DOLLARerror] = ACTIONS(5856),
    [anon_sym_DOLLARwarning] = ACTIONS(5856),
    [anon_sym_DOLLARinfo] = ACTIONS(5856),
    [anon_sym_default] = ACTIONS(5854),
    [anon_sym_clocking] = ACTIONS(5854),
    [anon_sym_defparam] = ACTIONS(5854),
    [anon_sym_bind] = ACTIONS(5854),
    [anon_sym_const] = ACTIONS(5854),
    [anon_sym_function] = ACTIONS(5854),
    [anon_sym_static] = ACTIONS(5854),
    [anon_sym_constraint] = ACTIONS(5854),
    [anon_sym_if] = ACTIONS(5854),
    [anon_sym_else] = ACTIONS(5854),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_localparam] = ACTIONS(5854),
    [anon_sym_parameter] = ACTIONS(5854),
    [anon_sym_specparam] = ACTIONS(5854),
    [anon_sym_var] = ACTIONS(5854),
    [anon_sym_import] = ACTIONS(5854),
    [anon_sym_export] = ACTIONS(5854),
    [anon_sym_genvar] = ACTIONS(5854),
    [anon_sym_interconnect] = ACTIONS(5854),
    [anon_sym_typedef] = ACTIONS(5854),
    [anon_sym_enum] = ACTIONS(5854),
    [anon_sym_struct] = ACTIONS(5854),
    [anon_sym_union] = ACTIONS(5854),
    [anon_sym_nettype] = ACTIONS(5854),
    [anon_sym_automatic] = ACTIONS(5854),
    [anon_sym_string] = ACTIONS(5854),
    [anon_sym_chandle] = ACTIONS(5854),
    [anon_sym_event] = ACTIONS(5854),
    [anon_sym_byte] = ACTIONS(5854),
    [anon_sym_shortint] = ACTIONS(5854),
    [anon_sym_int] = ACTIONS(5854),
    [anon_sym_longint] = ACTIONS(5854),
    [anon_sym_integer] = ACTIONS(5854),
    [anon_sym_time] = ACTIONS(5854),
    [anon_sym_bit] = ACTIONS(5854),
    [anon_sym_logic] = ACTIONS(5854),
    [anon_sym_reg] = ACTIONS(5854),
    [anon_sym_shortreal] = ACTIONS(5854),
    [anon_sym_real] = ACTIONS(5854),
    [anon_sym_realtime] = ACTIONS(5854),
    [anon_sym_supply0] = ACTIONS(5854),
    [anon_sym_supply1] = ACTIONS(5854),
    [anon_sym_signed] = ACTIONS(5854),
    [anon_sym_unsigned] = ACTIONS(5854),
    [anon_sym_task] = ACTIONS(5854),
    [anon_sym_modport] = ACTIONS(5854),
    [anon_sym_assert] = ACTIONS(5854),
    [anon_sym_property] = ACTIONS(5854),
    [anon_sym_assume] = ACTIONS(5854),
    [anon_sym_cover] = ACTIONS(5854),
    [anon_sym_sequence] = ACTIONS(5854),
    [anon_sym_restrict] = ACTIONS(5854),
    [anon_sym_not] = ACTIONS(5854),
    [anon_sym_or] = ACTIONS(5854),
    [anon_sym_and] = ACTIONS(5854),
    [anon_sym_case] = ACTIONS(5854),
    [anon_sym_always] = ACTIONS(5854),
    [anon_sym_covergroup] = ACTIONS(5854),
    [anon_sym_let] = ACTIONS(5854),
    [anon_sym_pulldown] = ACTIONS(5854),
    [anon_sym_pullup] = ACTIONS(5854),
    [anon_sym_cmos] = ACTIONS(5854),
    [anon_sym_rcmos] = ACTIONS(5854),
    [anon_sym_bufif0] = ACTIONS(5854),
    [anon_sym_bufif1] = ACTIONS(5854),
    [anon_sym_notif0] = ACTIONS(5854),
    [anon_sym_notif1] = ACTIONS(5854),
    [anon_sym_nmos] = ACTIONS(5854),
    [anon_sym_pmos] = ACTIONS(5854),
    [anon_sym_rnmos] = ACTIONS(5854),
    [anon_sym_rpmos] = ACTIONS(5854),
    [anon_sym_nand] = ACTIONS(5854),
    [anon_sym_nor] = ACTIONS(5854),
    [anon_sym_xor] = ACTIONS(5854),
    [anon_sym_xnor] = ACTIONS(5854),
    [anon_sym_buf] = ACTIONS(5854),
    [anon_sym_tranif0] = ACTIONS(5854),
    [anon_sym_tranif1] = ACTIONS(5854),
    [anon_sym_rtranif1] = ACTIONS(5854),
    [anon_sym_rtranif0] = ACTIONS(5854),
    [anon_sym_tran] = ACTIONS(5854),
    [anon_sym_rtran] = ACTIONS(5854),
    [anon_sym_generate] = ACTIONS(5854),
    [anon_sym_for] = ACTIONS(5854),
    [anon_sym_initial] = ACTIONS(5854),
    [anon_sym_assign] = ACTIONS(5854),
    [anon_sym_alias] = ACTIONS(5854),
    [anon_sym_always_comb] = ACTIONS(5854),
    [anon_sym_always_latch] = ACTIONS(5854),
    [anon_sym_always_ff] = ACTIONS(5854),
    [anon_sym_final] = ACTIONS(5854),
    [anon_sym_while] = ACTIONS(5854),
    [anon_sym_global] = ACTIONS(5854),
    [anon_sym_specify] = ACTIONS(5854),
    [anon_sym_LPAREN_STAR] = ACTIONS(5856),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5856),
    [anon_sym_DOLLARunit] = ACTIONS(5856),
  },
  [1047] = {
    [sym_simple_identifier] = ACTIONS(5858),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5860),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5860),
    [anon_sym_BQUOTE] = ACTIONS(5858),
    [aux_sym_id_directive_token1] = ACTIONS(5860),
    [aux_sym_id_directive_token2] = ACTIONS(5860),
    [aux_sym_id_directive_token3] = ACTIONS(5860),
    [aux_sym_id_directive_token4] = ACTIONS(5858),
    [aux_sym_zero_directive_token1] = ACTIONS(5860),
    [aux_sym_zero_directive_token2] = ACTIONS(5860),
    [aux_sym_zero_directive_token3] = ACTIONS(5860),
    [aux_sym_zero_directive_token4] = ACTIONS(5860),
    [aux_sym_zero_directive_token5] = ACTIONS(5860),
    [aux_sym_zero_directive_token6] = ACTIONS(5860),
    [aux_sym_zero_directive_token7] = ACTIONS(5860),
    [aux_sym_zero_directive_token8] = ACTIONS(5860),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5860),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5860),
    [anon_sym_wire] = ACTIONS(5858),
    [anon_sym_tri] = ACTIONS(5858),
    [anon_sym_tri0] = ACTIONS(5858),
    [anon_sym_tri1] = ACTIONS(5858),
    [anon_sym_wand] = ACTIONS(5858),
    [anon_sym_triand] = ACTIONS(5858),
    [anon_sym_wor] = ACTIONS(5858),
    [anon_sym_trior] = ACTIONS(5858),
    [anon_sym_trireg] = ACTIONS(5858),
    [anon_sym_uwire] = ACTIONS(5858),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5860),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5860),
    [aux_sym_begin_keywords_token1] = ACTIONS(5860),
    [anon_sym_SEMI] = ACTIONS(5860),
    [anon_sym_endmodule] = ACTIONS(5858),
    [anon_sym_extern] = ACTIONS(5858),
    [anon_sym_module] = ACTIONS(5858),
    [anon_sym_macromodule] = ACTIONS(5858),
    [anon_sym_endinterface] = ACTIONS(5858),
    [anon_sym_interface] = ACTIONS(5858),
    [anon_sym_endprogram] = ACTIONS(5858),
    [anon_sym_program] = ACTIONS(5858),
    [anon_sym_checker] = ACTIONS(5858),
    [anon_sym_virtual] = ACTIONS(5858),
    [anon_sym_class] = ACTIONS(5858),
    [anon_sym_timeunit] = ACTIONS(5858),
    [anon_sym_timeprecision] = ACTIONS(5858),
    [anon_sym_type] = ACTIONS(5858),
    [anon_sym_input] = ACTIONS(5858),
    [anon_sym_output] = ACTIONS(5858),
    [anon_sym_inout] = ACTIONS(5858),
    [anon_sym_ref] = ACTIONS(5858),
    [anon_sym_DOLLARfatal] = ACTIONS(5860),
    [anon_sym_DOLLARerror] = ACTIONS(5860),
    [anon_sym_DOLLARwarning] = ACTIONS(5860),
    [anon_sym_DOLLARinfo] = ACTIONS(5860),
    [anon_sym_default] = ACTIONS(5858),
    [anon_sym_clocking] = ACTIONS(5858),
    [anon_sym_defparam] = ACTIONS(5858),
    [anon_sym_bind] = ACTIONS(5858),
    [anon_sym_const] = ACTIONS(5858),
    [anon_sym_function] = ACTIONS(5858),
    [anon_sym_static] = ACTIONS(5858),
    [anon_sym_constraint] = ACTIONS(5858),
    [anon_sym_if] = ACTIONS(5858),
    [anon_sym_else] = ACTIONS(5858),
    [anon_sym_LBRACK] = ACTIONS(5860),
    [anon_sym_localparam] = ACTIONS(5858),
    [anon_sym_parameter] = ACTIONS(5858),
    [anon_sym_specparam] = ACTIONS(5858),
    [anon_sym_var] = ACTIONS(5858),
    [anon_sym_import] = ACTIONS(5858),
    [anon_sym_export] = ACTIONS(5858),
    [anon_sym_genvar] = ACTIONS(5858),
    [anon_sym_interconnect] = ACTIONS(5858),
    [anon_sym_typedef] = ACTIONS(5858),
    [anon_sym_enum] = ACTIONS(5858),
    [anon_sym_struct] = ACTIONS(5858),
    [anon_sym_union] = ACTIONS(5858),
    [anon_sym_nettype] = ACTIONS(5858),
    [anon_sym_automatic] = ACTIONS(5858),
    [anon_sym_string] = ACTIONS(5858),
    [anon_sym_chandle] = ACTIONS(5858),
    [anon_sym_event] = ACTIONS(5858),
    [anon_sym_byte] = ACTIONS(5858),
    [anon_sym_shortint] = ACTIONS(5858),
    [anon_sym_int] = ACTIONS(5858),
    [anon_sym_longint] = ACTIONS(5858),
    [anon_sym_integer] = ACTIONS(5858),
    [anon_sym_time] = ACTIONS(5858),
    [anon_sym_bit] = ACTIONS(5858),
    [anon_sym_logic] = ACTIONS(5858),
    [anon_sym_reg] = ACTIONS(5858),
    [anon_sym_shortreal] = ACTIONS(5858),
    [anon_sym_real] = ACTIONS(5858),
    [anon_sym_realtime] = ACTIONS(5858),
    [anon_sym_supply0] = ACTIONS(5858),
    [anon_sym_supply1] = ACTIONS(5858),
    [anon_sym_signed] = ACTIONS(5858),
    [anon_sym_unsigned] = ACTIONS(5858),
    [anon_sym_task] = ACTIONS(5858),
    [anon_sym_modport] = ACTIONS(5858),
    [anon_sym_assert] = ACTIONS(5858),
    [anon_sym_property] = ACTIONS(5858),
    [anon_sym_assume] = ACTIONS(5858),
    [anon_sym_cover] = ACTIONS(5858),
    [anon_sym_sequence] = ACTIONS(5858),
    [anon_sym_restrict] = ACTIONS(5858),
    [anon_sym_not] = ACTIONS(5858),
    [anon_sym_or] = ACTIONS(5858),
    [anon_sym_and] = ACTIONS(5858),
    [anon_sym_case] = ACTIONS(5858),
    [anon_sym_always] = ACTIONS(5858),
    [anon_sym_covergroup] = ACTIONS(5858),
    [anon_sym_let] = ACTIONS(5858),
    [anon_sym_pulldown] = ACTIONS(5858),
    [anon_sym_pullup] = ACTIONS(5858),
    [anon_sym_cmos] = ACTIONS(5858),
    [anon_sym_rcmos] = ACTIONS(5858),
    [anon_sym_bufif0] = ACTIONS(5858),
    [anon_sym_bufif1] = ACTIONS(5858),
    [anon_sym_notif0] = ACTIONS(5858),
    [anon_sym_notif1] = ACTIONS(5858),
    [anon_sym_nmos] = ACTIONS(5858),
    [anon_sym_pmos] = ACTIONS(5858),
    [anon_sym_rnmos] = ACTIONS(5858),
    [anon_sym_rpmos] = ACTIONS(5858),
    [anon_sym_nand] = ACTIONS(5858),
    [anon_sym_nor] = ACTIONS(5858),
    [anon_sym_xor] = ACTIONS(5858),
    [anon_sym_xnor] = ACTIONS(5858),
    [anon_sym_buf] = ACTIONS(5858),
    [anon_sym_tranif0] = ACTIONS(5858),
    [anon_sym_tranif1] = ACTIONS(5858),
    [anon_sym_rtranif1] = ACTIONS(5858),
    [anon_sym_rtranif0] = ACTIONS(5858),
    [anon_sym_tran] = ACTIONS(5858),
    [anon_sym_rtran] = ACTIONS(5858),
    [anon_sym_generate] = ACTIONS(5858),
    [anon_sym_for] = ACTIONS(5858),
    [anon_sym_initial] = ACTIONS(5858),
    [anon_sym_assign] = ACTIONS(5858),
    [anon_sym_alias] = ACTIONS(5858),
    [anon_sym_always_comb] = ACTIONS(5858),
    [anon_sym_always_latch] = ACTIONS(5858),
    [anon_sym_always_ff] = ACTIONS(5858),
    [anon_sym_final] = ACTIONS(5858),
    [anon_sym_while] = ACTIONS(5858),
    [anon_sym_global] = ACTIONS(5858),
    [anon_sym_specify] = ACTIONS(5858),
    [anon_sym_LPAREN_STAR] = ACTIONS(5860),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5860),
    [anon_sym_DOLLARunit] = ACTIONS(5860),
  },
  [1048] = {
    [sym_simple_identifier] = ACTIONS(5862),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5864),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5864),
    [anon_sym_BQUOTE] = ACTIONS(5862),
    [aux_sym_id_directive_token1] = ACTIONS(5864),
    [aux_sym_id_directive_token2] = ACTIONS(5864),
    [aux_sym_id_directive_token3] = ACTIONS(5864),
    [aux_sym_id_directive_token4] = ACTIONS(5862),
    [aux_sym_zero_directive_token1] = ACTIONS(5864),
    [aux_sym_zero_directive_token2] = ACTIONS(5864),
    [aux_sym_zero_directive_token3] = ACTIONS(5864),
    [aux_sym_zero_directive_token4] = ACTIONS(5864),
    [aux_sym_zero_directive_token5] = ACTIONS(5864),
    [aux_sym_zero_directive_token6] = ACTIONS(5864),
    [aux_sym_zero_directive_token7] = ACTIONS(5864),
    [aux_sym_zero_directive_token8] = ACTIONS(5864),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5864),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5864),
    [anon_sym_wire] = ACTIONS(5862),
    [anon_sym_tri] = ACTIONS(5862),
    [anon_sym_tri0] = ACTIONS(5862),
    [anon_sym_tri1] = ACTIONS(5862),
    [anon_sym_wand] = ACTIONS(5862),
    [anon_sym_triand] = ACTIONS(5862),
    [anon_sym_wor] = ACTIONS(5862),
    [anon_sym_trior] = ACTIONS(5862),
    [anon_sym_trireg] = ACTIONS(5862),
    [anon_sym_uwire] = ACTIONS(5862),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5864),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5864),
    [aux_sym_begin_keywords_token1] = ACTIONS(5864),
    [anon_sym_SEMI] = ACTIONS(5864),
    [anon_sym_endmodule] = ACTIONS(5862),
    [anon_sym_extern] = ACTIONS(5862),
    [anon_sym_module] = ACTIONS(5862),
    [anon_sym_macromodule] = ACTIONS(5862),
    [anon_sym_endinterface] = ACTIONS(5862),
    [anon_sym_interface] = ACTIONS(5862),
    [anon_sym_endprogram] = ACTIONS(5862),
    [anon_sym_program] = ACTIONS(5862),
    [anon_sym_checker] = ACTIONS(5862),
    [anon_sym_virtual] = ACTIONS(5862),
    [anon_sym_class] = ACTIONS(5862),
    [anon_sym_timeunit] = ACTIONS(5862),
    [anon_sym_timeprecision] = ACTIONS(5862),
    [anon_sym_type] = ACTIONS(5862),
    [anon_sym_input] = ACTIONS(5862),
    [anon_sym_output] = ACTIONS(5862),
    [anon_sym_inout] = ACTIONS(5862),
    [anon_sym_ref] = ACTIONS(5862),
    [anon_sym_DOLLARfatal] = ACTIONS(5864),
    [anon_sym_DOLLARerror] = ACTIONS(5864),
    [anon_sym_DOLLARwarning] = ACTIONS(5864),
    [anon_sym_DOLLARinfo] = ACTIONS(5864),
    [anon_sym_default] = ACTIONS(5862),
    [anon_sym_clocking] = ACTIONS(5862),
    [anon_sym_defparam] = ACTIONS(5862),
    [anon_sym_bind] = ACTIONS(5862),
    [anon_sym_const] = ACTIONS(5862),
    [anon_sym_function] = ACTIONS(5862),
    [anon_sym_static] = ACTIONS(5862),
    [anon_sym_constraint] = ACTIONS(5862),
    [anon_sym_if] = ACTIONS(5862),
    [anon_sym_else] = ACTIONS(5862),
    [anon_sym_LBRACK] = ACTIONS(5864),
    [anon_sym_localparam] = ACTIONS(5862),
    [anon_sym_parameter] = ACTIONS(5862),
    [anon_sym_specparam] = ACTIONS(5862),
    [anon_sym_var] = ACTIONS(5862),
    [anon_sym_import] = ACTIONS(5862),
    [anon_sym_export] = ACTIONS(5862),
    [anon_sym_genvar] = ACTIONS(5862),
    [anon_sym_interconnect] = ACTIONS(5862),
    [anon_sym_typedef] = ACTIONS(5862),
    [anon_sym_enum] = ACTIONS(5862),
    [anon_sym_struct] = ACTIONS(5862),
    [anon_sym_union] = ACTIONS(5862),
    [anon_sym_nettype] = ACTIONS(5862),
    [anon_sym_automatic] = ACTIONS(5862),
    [anon_sym_string] = ACTIONS(5862),
    [anon_sym_chandle] = ACTIONS(5862),
    [anon_sym_event] = ACTIONS(5862),
    [anon_sym_byte] = ACTIONS(5862),
    [anon_sym_shortint] = ACTIONS(5862),
    [anon_sym_int] = ACTIONS(5862),
    [anon_sym_longint] = ACTIONS(5862),
    [anon_sym_integer] = ACTIONS(5862),
    [anon_sym_time] = ACTIONS(5862),
    [anon_sym_bit] = ACTIONS(5862),
    [anon_sym_logic] = ACTIONS(5862),
    [anon_sym_reg] = ACTIONS(5862),
    [anon_sym_shortreal] = ACTIONS(5862),
    [anon_sym_real] = ACTIONS(5862),
    [anon_sym_realtime] = ACTIONS(5862),
    [anon_sym_supply0] = ACTIONS(5862),
    [anon_sym_supply1] = ACTIONS(5862),
    [anon_sym_signed] = ACTIONS(5862),
    [anon_sym_unsigned] = ACTIONS(5862),
    [anon_sym_task] = ACTIONS(5862),
    [anon_sym_modport] = ACTIONS(5862),
    [anon_sym_assert] = ACTIONS(5862),
    [anon_sym_property] = ACTIONS(5862),
    [anon_sym_assume] = ACTIONS(5862),
    [anon_sym_cover] = ACTIONS(5862),
    [anon_sym_sequence] = ACTIONS(5862),
    [anon_sym_restrict] = ACTIONS(5862),
    [anon_sym_not] = ACTIONS(5862),
    [anon_sym_or] = ACTIONS(5862),
    [anon_sym_and] = ACTIONS(5862),
    [anon_sym_case] = ACTIONS(5862),
    [anon_sym_always] = ACTIONS(5862),
    [anon_sym_covergroup] = ACTIONS(5862),
    [anon_sym_let] = ACTIONS(5862),
    [anon_sym_pulldown] = ACTIONS(5862),
    [anon_sym_pullup] = ACTIONS(5862),
    [anon_sym_cmos] = ACTIONS(5862),
    [anon_sym_rcmos] = ACTIONS(5862),
    [anon_sym_bufif0] = ACTIONS(5862),
    [anon_sym_bufif1] = ACTIONS(5862),
    [anon_sym_notif0] = ACTIONS(5862),
    [anon_sym_notif1] = ACTIONS(5862),
    [anon_sym_nmos] = ACTIONS(5862),
    [anon_sym_pmos] = ACTIONS(5862),
    [anon_sym_rnmos] = ACTIONS(5862),
    [anon_sym_rpmos] = ACTIONS(5862),
    [anon_sym_nand] = ACTIONS(5862),
    [anon_sym_nor] = ACTIONS(5862),
    [anon_sym_xor] = ACTIONS(5862),
    [anon_sym_xnor] = ACTIONS(5862),
    [anon_sym_buf] = ACTIONS(5862),
    [anon_sym_tranif0] = ACTIONS(5862),
    [anon_sym_tranif1] = ACTIONS(5862),
    [anon_sym_rtranif1] = ACTIONS(5862),
    [anon_sym_rtranif0] = ACTIONS(5862),
    [anon_sym_tran] = ACTIONS(5862),
    [anon_sym_rtran] = ACTIONS(5862),
    [anon_sym_generate] = ACTIONS(5862),
    [anon_sym_for] = ACTIONS(5862),
    [anon_sym_initial] = ACTIONS(5862),
    [anon_sym_assign] = ACTIONS(5862),
    [anon_sym_alias] = ACTIONS(5862),
    [anon_sym_always_comb] = ACTIONS(5862),
    [anon_sym_always_latch] = ACTIONS(5862),
    [anon_sym_always_ff] = ACTIONS(5862),
    [anon_sym_final] = ACTIONS(5862),
    [anon_sym_while] = ACTIONS(5862),
    [anon_sym_global] = ACTIONS(5862),
    [anon_sym_specify] = ACTIONS(5862),
    [anon_sym_LPAREN_STAR] = ACTIONS(5864),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5864),
    [anon_sym_DOLLARunit] = ACTIONS(5864),
  },
  [1049] = {
    [sym_simple_identifier] = ACTIONS(5866),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5868),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5868),
    [anon_sym_BQUOTE] = ACTIONS(5866),
    [aux_sym_id_directive_token1] = ACTIONS(5868),
    [aux_sym_id_directive_token2] = ACTIONS(5868),
    [aux_sym_id_directive_token3] = ACTIONS(5868),
    [aux_sym_id_directive_token4] = ACTIONS(5866),
    [aux_sym_zero_directive_token1] = ACTIONS(5868),
    [aux_sym_zero_directive_token2] = ACTIONS(5868),
    [aux_sym_zero_directive_token3] = ACTIONS(5868),
    [aux_sym_zero_directive_token4] = ACTIONS(5868),
    [aux_sym_zero_directive_token5] = ACTIONS(5868),
    [aux_sym_zero_directive_token6] = ACTIONS(5868),
    [aux_sym_zero_directive_token7] = ACTIONS(5868),
    [aux_sym_zero_directive_token8] = ACTIONS(5868),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5868),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5868),
    [anon_sym_wire] = ACTIONS(5866),
    [anon_sym_tri] = ACTIONS(5866),
    [anon_sym_tri0] = ACTIONS(5866),
    [anon_sym_tri1] = ACTIONS(5866),
    [anon_sym_wand] = ACTIONS(5866),
    [anon_sym_triand] = ACTIONS(5866),
    [anon_sym_wor] = ACTIONS(5866),
    [anon_sym_trior] = ACTIONS(5866),
    [anon_sym_trireg] = ACTIONS(5866),
    [anon_sym_uwire] = ACTIONS(5866),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5868),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5868),
    [aux_sym_begin_keywords_token1] = ACTIONS(5868),
    [anon_sym_SEMI] = ACTIONS(5868),
    [anon_sym_endmodule] = ACTIONS(5866),
    [anon_sym_extern] = ACTIONS(5866),
    [anon_sym_module] = ACTIONS(5866),
    [anon_sym_macromodule] = ACTIONS(5866),
    [anon_sym_endinterface] = ACTIONS(5866),
    [anon_sym_interface] = ACTIONS(5866),
    [anon_sym_endprogram] = ACTIONS(5866),
    [anon_sym_program] = ACTIONS(5866),
    [anon_sym_checker] = ACTIONS(5866),
    [anon_sym_virtual] = ACTIONS(5866),
    [anon_sym_class] = ACTIONS(5866),
    [anon_sym_timeunit] = ACTIONS(5866),
    [anon_sym_timeprecision] = ACTIONS(5866),
    [anon_sym_type] = ACTIONS(5866),
    [anon_sym_input] = ACTIONS(5866),
    [anon_sym_output] = ACTIONS(5866),
    [anon_sym_inout] = ACTIONS(5866),
    [anon_sym_ref] = ACTIONS(5866),
    [anon_sym_DOLLARfatal] = ACTIONS(5868),
    [anon_sym_DOLLARerror] = ACTIONS(5868),
    [anon_sym_DOLLARwarning] = ACTIONS(5868),
    [anon_sym_DOLLARinfo] = ACTIONS(5868),
    [anon_sym_default] = ACTIONS(5866),
    [anon_sym_clocking] = ACTIONS(5866),
    [anon_sym_defparam] = ACTIONS(5866),
    [anon_sym_bind] = ACTIONS(5866),
    [anon_sym_const] = ACTIONS(5866),
    [anon_sym_function] = ACTIONS(5866),
    [anon_sym_static] = ACTIONS(5866),
    [anon_sym_constraint] = ACTIONS(5866),
    [anon_sym_if] = ACTIONS(5866),
    [anon_sym_else] = ACTIONS(5866),
    [anon_sym_LBRACK] = ACTIONS(5868),
    [anon_sym_localparam] = ACTIONS(5866),
    [anon_sym_parameter] = ACTIONS(5866),
    [anon_sym_specparam] = ACTIONS(5866),
    [anon_sym_var] = ACTIONS(5866),
    [anon_sym_import] = ACTIONS(5866),
    [anon_sym_export] = ACTIONS(5866),
    [anon_sym_genvar] = ACTIONS(5866),
    [anon_sym_interconnect] = ACTIONS(5866),
    [anon_sym_typedef] = ACTIONS(5866),
    [anon_sym_enum] = ACTIONS(5866),
    [anon_sym_struct] = ACTIONS(5866),
    [anon_sym_union] = ACTIONS(5866),
    [anon_sym_nettype] = ACTIONS(5866),
    [anon_sym_automatic] = ACTIONS(5866),
    [anon_sym_string] = ACTIONS(5866),
    [anon_sym_chandle] = ACTIONS(5866),
    [anon_sym_event] = ACTIONS(5866),
    [anon_sym_byte] = ACTIONS(5866),
    [anon_sym_shortint] = ACTIONS(5866),
    [anon_sym_int] = ACTIONS(5866),
    [anon_sym_longint] = ACTIONS(5866),
    [anon_sym_integer] = ACTIONS(5866),
    [anon_sym_time] = ACTIONS(5866),
    [anon_sym_bit] = ACTIONS(5866),
    [anon_sym_logic] = ACTIONS(5866),
    [anon_sym_reg] = ACTIONS(5866),
    [anon_sym_shortreal] = ACTIONS(5866),
    [anon_sym_real] = ACTIONS(5866),
    [anon_sym_realtime] = ACTIONS(5866),
    [anon_sym_supply0] = ACTIONS(5866),
    [anon_sym_supply1] = ACTIONS(5866),
    [anon_sym_signed] = ACTIONS(5866),
    [anon_sym_unsigned] = ACTIONS(5866),
    [anon_sym_task] = ACTIONS(5866),
    [anon_sym_modport] = ACTIONS(5866),
    [anon_sym_assert] = ACTIONS(5866),
    [anon_sym_property] = ACTIONS(5866),
    [anon_sym_assume] = ACTIONS(5866),
    [anon_sym_cover] = ACTIONS(5866),
    [anon_sym_sequence] = ACTIONS(5866),
    [anon_sym_restrict] = ACTIONS(5866),
    [anon_sym_not] = ACTIONS(5866),
    [anon_sym_or] = ACTIONS(5866),
    [anon_sym_and] = ACTIONS(5866),
    [anon_sym_case] = ACTIONS(5866),
    [anon_sym_always] = ACTIONS(5866),
    [anon_sym_covergroup] = ACTIONS(5866),
    [anon_sym_let] = ACTIONS(5866),
    [anon_sym_pulldown] = ACTIONS(5866),
    [anon_sym_pullup] = ACTIONS(5866),
    [anon_sym_cmos] = ACTIONS(5866),
    [anon_sym_rcmos] = ACTIONS(5866),
    [anon_sym_bufif0] = ACTIONS(5866),
    [anon_sym_bufif1] = ACTIONS(5866),
    [anon_sym_notif0] = ACTIONS(5866),
    [anon_sym_notif1] = ACTIONS(5866),
    [anon_sym_nmos] = ACTIONS(5866),
    [anon_sym_pmos] = ACTIONS(5866),
    [anon_sym_rnmos] = ACTIONS(5866),
    [anon_sym_rpmos] = ACTIONS(5866),
    [anon_sym_nand] = ACTIONS(5866),
    [anon_sym_nor] = ACTIONS(5866),
    [anon_sym_xor] = ACTIONS(5866),
    [anon_sym_xnor] = ACTIONS(5866),
    [anon_sym_buf] = ACTIONS(5866),
    [anon_sym_tranif0] = ACTIONS(5866),
    [anon_sym_tranif1] = ACTIONS(5866),
    [anon_sym_rtranif1] = ACTIONS(5866),
    [anon_sym_rtranif0] = ACTIONS(5866),
    [anon_sym_tran] = ACTIONS(5866),
    [anon_sym_rtran] = ACTIONS(5866),
    [anon_sym_generate] = ACTIONS(5866),
    [anon_sym_for] = ACTIONS(5866),
    [anon_sym_initial] = ACTIONS(5866),
    [anon_sym_assign] = ACTIONS(5866),
    [anon_sym_alias] = ACTIONS(5866),
    [anon_sym_always_comb] = ACTIONS(5866),
    [anon_sym_always_latch] = ACTIONS(5866),
    [anon_sym_always_ff] = ACTIONS(5866),
    [anon_sym_final] = ACTIONS(5866),
    [anon_sym_while] = ACTIONS(5866),
    [anon_sym_global] = ACTIONS(5866),
    [anon_sym_specify] = ACTIONS(5866),
    [anon_sym_LPAREN_STAR] = ACTIONS(5868),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5868),
    [anon_sym_DOLLARunit] = ACTIONS(5868),
  },
  [1050] = {
    [sym_simple_identifier] = ACTIONS(5870),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5872),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5872),
    [anon_sym_BQUOTE] = ACTIONS(5870),
    [aux_sym_id_directive_token1] = ACTIONS(5872),
    [aux_sym_id_directive_token2] = ACTIONS(5872),
    [aux_sym_id_directive_token3] = ACTIONS(5872),
    [aux_sym_id_directive_token4] = ACTIONS(5870),
    [aux_sym_zero_directive_token1] = ACTIONS(5872),
    [aux_sym_zero_directive_token2] = ACTIONS(5872),
    [aux_sym_zero_directive_token3] = ACTIONS(5872),
    [aux_sym_zero_directive_token4] = ACTIONS(5872),
    [aux_sym_zero_directive_token5] = ACTIONS(5872),
    [aux_sym_zero_directive_token6] = ACTIONS(5872),
    [aux_sym_zero_directive_token7] = ACTIONS(5872),
    [aux_sym_zero_directive_token8] = ACTIONS(5872),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5872),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5872),
    [anon_sym_wire] = ACTIONS(5870),
    [anon_sym_tri] = ACTIONS(5870),
    [anon_sym_tri0] = ACTIONS(5870),
    [anon_sym_tri1] = ACTIONS(5870),
    [anon_sym_wand] = ACTIONS(5870),
    [anon_sym_triand] = ACTIONS(5870),
    [anon_sym_wor] = ACTIONS(5870),
    [anon_sym_trior] = ACTIONS(5870),
    [anon_sym_trireg] = ACTIONS(5870),
    [anon_sym_uwire] = ACTIONS(5870),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5872),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5872),
    [aux_sym_begin_keywords_token1] = ACTIONS(5872),
    [anon_sym_SEMI] = ACTIONS(5872),
    [anon_sym_endmodule] = ACTIONS(5870),
    [anon_sym_COLON] = ACTIONS(5874),
    [anon_sym_extern] = ACTIONS(5870),
    [anon_sym_module] = ACTIONS(5870),
    [anon_sym_macromodule] = ACTIONS(5870),
    [anon_sym_endinterface] = ACTIONS(5870),
    [anon_sym_interface] = ACTIONS(5870),
    [anon_sym_endprogram] = ACTIONS(5870),
    [anon_sym_program] = ACTIONS(5870),
    [anon_sym_checker] = ACTIONS(5870),
    [anon_sym_virtual] = ACTIONS(5870),
    [anon_sym_class] = ACTIONS(5870),
    [anon_sym_timeunit] = ACTIONS(5870),
    [anon_sym_timeprecision] = ACTIONS(5870),
    [anon_sym_type] = ACTIONS(5870),
    [anon_sym_input] = ACTIONS(5870),
    [anon_sym_output] = ACTIONS(5870),
    [anon_sym_inout] = ACTIONS(5870),
    [anon_sym_ref] = ACTIONS(5870),
    [anon_sym_DOLLARfatal] = ACTIONS(5872),
    [anon_sym_DOLLARerror] = ACTIONS(5872),
    [anon_sym_DOLLARwarning] = ACTIONS(5872),
    [anon_sym_DOLLARinfo] = ACTIONS(5872),
    [anon_sym_default] = ACTIONS(5870),
    [anon_sym_clocking] = ACTIONS(5870),
    [anon_sym_defparam] = ACTIONS(5870),
    [anon_sym_bind] = ACTIONS(5870),
    [anon_sym_const] = ACTIONS(5870),
    [anon_sym_function] = ACTIONS(5870),
    [anon_sym_static] = ACTIONS(5870),
    [anon_sym_constraint] = ACTIONS(5870),
    [anon_sym_if] = ACTIONS(5870),
    [anon_sym_else] = ACTIONS(5870),
    [anon_sym_LBRACK] = ACTIONS(5872),
    [anon_sym_localparam] = ACTIONS(5870),
    [anon_sym_parameter] = ACTIONS(5870),
    [anon_sym_specparam] = ACTIONS(5870),
    [anon_sym_var] = ACTIONS(5870),
    [anon_sym_import] = ACTIONS(5870),
    [anon_sym_export] = ACTIONS(5870),
    [anon_sym_genvar] = ACTIONS(5870),
    [anon_sym_interconnect] = ACTIONS(5870),
    [anon_sym_typedef] = ACTIONS(5870),
    [anon_sym_enum] = ACTIONS(5870),
    [anon_sym_struct] = ACTIONS(5870),
    [anon_sym_union] = ACTIONS(5870),
    [anon_sym_nettype] = ACTIONS(5870),
    [anon_sym_automatic] = ACTIONS(5870),
    [anon_sym_string] = ACTIONS(5870),
    [anon_sym_chandle] = ACTIONS(5870),
    [anon_sym_event] = ACTIONS(5870),
    [anon_sym_byte] = ACTIONS(5870),
    [anon_sym_shortint] = ACTIONS(5870),
    [anon_sym_int] = ACTIONS(5870),
    [anon_sym_longint] = ACTIONS(5870),
    [anon_sym_integer] = ACTIONS(5870),
    [anon_sym_time] = ACTIONS(5870),
    [anon_sym_bit] = ACTIONS(5870),
    [anon_sym_logic] = ACTIONS(5870),
    [anon_sym_reg] = ACTIONS(5870),
    [anon_sym_shortreal] = ACTIONS(5870),
    [anon_sym_real] = ACTIONS(5870),
    [anon_sym_realtime] = ACTIONS(5870),
    [anon_sym_supply0] = ACTIONS(5870),
    [anon_sym_supply1] = ACTIONS(5870),
    [anon_sym_signed] = ACTIONS(5870),
    [anon_sym_unsigned] = ACTIONS(5870),
    [anon_sym_task] = ACTIONS(5870),
    [anon_sym_modport] = ACTIONS(5870),
    [anon_sym_assert] = ACTIONS(5870),
    [anon_sym_property] = ACTIONS(5870),
    [anon_sym_assume] = ACTIONS(5870),
    [anon_sym_cover] = ACTIONS(5870),
    [anon_sym_sequence] = ACTIONS(5870),
    [anon_sym_restrict] = ACTIONS(5870),
    [anon_sym_not] = ACTIONS(5870),
    [anon_sym_or] = ACTIONS(5870),
    [anon_sym_and] = ACTIONS(5870),
    [anon_sym_case] = ACTIONS(5870),
    [anon_sym_always] = ACTIONS(5870),
    [anon_sym_covergroup] = ACTIONS(5870),
    [anon_sym_let] = ACTIONS(5870),
    [anon_sym_pulldown] = ACTIONS(5870),
    [anon_sym_pullup] = ACTIONS(5870),
    [anon_sym_cmos] = ACTIONS(5870),
    [anon_sym_rcmos] = ACTIONS(5870),
    [anon_sym_bufif0] = ACTIONS(5870),
    [anon_sym_bufif1] = ACTIONS(5870),
    [anon_sym_notif0] = ACTIONS(5870),
    [anon_sym_notif1] = ACTIONS(5870),
    [anon_sym_nmos] = ACTIONS(5870),
    [anon_sym_pmos] = ACTIONS(5870),
    [anon_sym_rnmos] = ACTIONS(5870),
    [anon_sym_rpmos] = ACTIONS(5870),
    [anon_sym_nand] = ACTIONS(5870),
    [anon_sym_nor] = ACTIONS(5870),
    [anon_sym_xor] = ACTIONS(5870),
    [anon_sym_xnor] = ACTIONS(5870),
    [anon_sym_buf] = ACTIONS(5870),
    [anon_sym_tranif0] = ACTIONS(5870),
    [anon_sym_tranif1] = ACTIONS(5870),
    [anon_sym_rtranif1] = ACTIONS(5870),
    [anon_sym_rtranif0] = ACTIONS(5870),
    [anon_sym_tran] = ACTIONS(5870),
    [anon_sym_rtran] = ACTIONS(5870),
    [anon_sym_generate] = ACTIONS(5870),
    [anon_sym_for] = ACTIONS(5870),
    [anon_sym_initial] = ACTIONS(5870),
    [anon_sym_assign] = ACTIONS(5870),
    [anon_sym_alias] = ACTIONS(5870),
    [anon_sym_always_comb] = ACTIONS(5870),
    [anon_sym_always_latch] = ACTIONS(5870),
    [anon_sym_always_ff] = ACTIONS(5870),
    [anon_sym_final] = ACTIONS(5870),
    [anon_sym_global] = ACTIONS(5870),
    [anon_sym_specify] = ACTIONS(5870),
    [anon_sym_LPAREN_STAR] = ACTIONS(5872),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5872),
    [anon_sym_DOLLARunit] = ACTIONS(5872),
  },
  [1051] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5596),
    [anon_sym_BQUOTE] = ACTIONS(5594),
    [aux_sym_id_directive_token1] = ACTIONS(5596),
    [aux_sym_id_directive_token2] = ACTIONS(5596),
    [aux_sym_id_directive_token3] = ACTIONS(5596),
    [aux_sym_id_directive_token4] = ACTIONS(5594),
    [aux_sym_zero_directive_token1] = ACTIONS(5596),
    [aux_sym_zero_directive_token2] = ACTIONS(5596),
    [aux_sym_zero_directive_token3] = ACTIONS(5596),
    [aux_sym_zero_directive_token4] = ACTIONS(5596),
    [aux_sym_zero_directive_token5] = ACTIONS(5596),
    [aux_sym_zero_directive_token6] = ACTIONS(5596),
    [aux_sym_zero_directive_token7] = ACTIONS(5596),
    [aux_sym_zero_directive_token8] = ACTIONS(5596),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5596),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5596),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5596),
    [aux_sym_begin_keywords_token1] = ACTIONS(5596),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_endmodule] = ACTIONS(5594),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_module] = ACTIONS(5594),
    [anon_sym_macromodule] = ACTIONS(5594),
    [anon_sym_endinterface] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_endprogram] = ACTIONS(5594),
    [anon_sym_program] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_timeunit] = ACTIONS(5594),
    [anon_sym_timeprecision] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_input] = ACTIONS(5594),
    [anon_sym_output] = ACTIONS(5594),
    [anon_sym_inout] = ACTIONS(5594),
    [anon_sym_ref] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_specparam] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_modport] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_while] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_specify] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [1052] = {
    [sym_simple_identifier] = ACTIONS(5876),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5878),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5878),
    [anon_sym_BQUOTE] = ACTIONS(5876),
    [aux_sym_id_directive_token1] = ACTIONS(5878),
    [aux_sym_id_directive_token2] = ACTIONS(5878),
    [aux_sym_id_directive_token3] = ACTIONS(5878),
    [aux_sym_id_directive_token4] = ACTIONS(5876),
    [aux_sym_zero_directive_token1] = ACTIONS(5878),
    [aux_sym_zero_directive_token2] = ACTIONS(5878),
    [aux_sym_zero_directive_token3] = ACTIONS(5878),
    [aux_sym_zero_directive_token4] = ACTIONS(5878),
    [aux_sym_zero_directive_token5] = ACTIONS(5878),
    [aux_sym_zero_directive_token6] = ACTIONS(5878),
    [aux_sym_zero_directive_token7] = ACTIONS(5878),
    [aux_sym_zero_directive_token8] = ACTIONS(5878),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5878),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5878),
    [anon_sym_wire] = ACTIONS(5876),
    [anon_sym_tri] = ACTIONS(5876),
    [anon_sym_tri0] = ACTIONS(5876),
    [anon_sym_tri1] = ACTIONS(5876),
    [anon_sym_wand] = ACTIONS(5876),
    [anon_sym_triand] = ACTIONS(5876),
    [anon_sym_wor] = ACTIONS(5876),
    [anon_sym_trior] = ACTIONS(5876),
    [anon_sym_trireg] = ACTIONS(5876),
    [anon_sym_uwire] = ACTIONS(5876),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5878),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5878),
    [aux_sym_begin_keywords_token1] = ACTIONS(5878),
    [anon_sym_SEMI] = ACTIONS(5878),
    [anon_sym_endmodule] = ACTIONS(5876),
    [anon_sym_extern] = ACTIONS(5876),
    [anon_sym_module] = ACTIONS(5876),
    [anon_sym_macromodule] = ACTIONS(5876),
    [anon_sym_endinterface] = ACTIONS(5876),
    [anon_sym_interface] = ACTIONS(5876),
    [anon_sym_endprogram] = ACTIONS(5876),
    [anon_sym_program] = ACTIONS(5876),
    [anon_sym_checker] = ACTIONS(5876),
    [anon_sym_virtual] = ACTIONS(5876),
    [anon_sym_class] = ACTIONS(5876),
    [anon_sym_timeunit] = ACTIONS(5876),
    [anon_sym_timeprecision] = ACTIONS(5876),
    [anon_sym_type] = ACTIONS(5876),
    [anon_sym_input] = ACTIONS(5876),
    [anon_sym_output] = ACTIONS(5876),
    [anon_sym_inout] = ACTIONS(5876),
    [anon_sym_ref] = ACTIONS(5876),
    [anon_sym_DOLLARfatal] = ACTIONS(5878),
    [anon_sym_DOLLARerror] = ACTIONS(5878),
    [anon_sym_DOLLARwarning] = ACTIONS(5878),
    [anon_sym_DOLLARinfo] = ACTIONS(5878),
    [anon_sym_default] = ACTIONS(5876),
    [anon_sym_clocking] = ACTIONS(5876),
    [anon_sym_defparam] = ACTIONS(5876),
    [anon_sym_bind] = ACTIONS(5876),
    [anon_sym_const] = ACTIONS(5876),
    [anon_sym_function] = ACTIONS(5876),
    [anon_sym_static] = ACTIONS(5876),
    [anon_sym_constraint] = ACTIONS(5876),
    [anon_sym_if] = ACTIONS(5876),
    [anon_sym_else] = ACTIONS(5876),
    [anon_sym_LBRACK] = ACTIONS(5878),
    [anon_sym_localparam] = ACTIONS(5876),
    [anon_sym_parameter] = ACTIONS(5876),
    [anon_sym_specparam] = ACTIONS(5876),
    [anon_sym_var] = ACTIONS(5876),
    [anon_sym_import] = ACTIONS(5876),
    [anon_sym_export] = ACTIONS(5876),
    [anon_sym_genvar] = ACTIONS(5876),
    [anon_sym_interconnect] = ACTIONS(5876),
    [anon_sym_typedef] = ACTIONS(5876),
    [anon_sym_enum] = ACTIONS(5876),
    [anon_sym_struct] = ACTIONS(5876),
    [anon_sym_union] = ACTIONS(5876),
    [anon_sym_nettype] = ACTIONS(5876),
    [anon_sym_automatic] = ACTIONS(5876),
    [anon_sym_string] = ACTIONS(5876),
    [anon_sym_chandle] = ACTIONS(5876),
    [anon_sym_event] = ACTIONS(5876),
    [anon_sym_byte] = ACTIONS(5876),
    [anon_sym_shortint] = ACTIONS(5876),
    [anon_sym_int] = ACTIONS(5876),
    [anon_sym_longint] = ACTIONS(5876),
    [anon_sym_integer] = ACTIONS(5876),
    [anon_sym_time] = ACTIONS(5876),
    [anon_sym_bit] = ACTIONS(5876),
    [anon_sym_logic] = ACTIONS(5876),
    [anon_sym_reg] = ACTIONS(5876),
    [anon_sym_shortreal] = ACTIONS(5876),
    [anon_sym_real] = ACTIONS(5876),
    [anon_sym_realtime] = ACTIONS(5876),
    [anon_sym_supply0] = ACTIONS(5876),
    [anon_sym_supply1] = ACTIONS(5876),
    [anon_sym_signed] = ACTIONS(5876),
    [anon_sym_unsigned] = ACTIONS(5876),
    [anon_sym_task] = ACTIONS(5876),
    [anon_sym_modport] = ACTIONS(5876),
    [anon_sym_assert] = ACTIONS(5876),
    [anon_sym_property] = ACTIONS(5876),
    [anon_sym_assume] = ACTIONS(5876),
    [anon_sym_cover] = ACTIONS(5876),
    [anon_sym_sequence] = ACTIONS(5876),
    [anon_sym_restrict] = ACTIONS(5876),
    [anon_sym_not] = ACTIONS(5876),
    [anon_sym_or] = ACTIONS(5876),
    [anon_sym_and] = ACTIONS(5876),
    [anon_sym_case] = ACTIONS(5876),
    [anon_sym_always] = ACTIONS(5876),
    [anon_sym_covergroup] = ACTIONS(5876),
    [anon_sym_let] = ACTIONS(5876),
    [anon_sym_pulldown] = ACTIONS(5876),
    [anon_sym_pullup] = ACTIONS(5876),
    [anon_sym_cmos] = ACTIONS(5876),
    [anon_sym_rcmos] = ACTIONS(5876),
    [anon_sym_bufif0] = ACTIONS(5876),
    [anon_sym_bufif1] = ACTIONS(5876),
    [anon_sym_notif0] = ACTIONS(5876),
    [anon_sym_notif1] = ACTIONS(5876),
    [anon_sym_nmos] = ACTIONS(5876),
    [anon_sym_pmos] = ACTIONS(5876),
    [anon_sym_rnmos] = ACTIONS(5876),
    [anon_sym_rpmos] = ACTIONS(5876),
    [anon_sym_nand] = ACTIONS(5876),
    [anon_sym_nor] = ACTIONS(5876),
    [anon_sym_xor] = ACTIONS(5876),
    [anon_sym_xnor] = ACTIONS(5876),
    [anon_sym_buf] = ACTIONS(5876),
    [anon_sym_tranif0] = ACTIONS(5876),
    [anon_sym_tranif1] = ACTIONS(5876),
    [anon_sym_rtranif1] = ACTIONS(5876),
    [anon_sym_rtranif0] = ACTIONS(5876),
    [anon_sym_tran] = ACTIONS(5876),
    [anon_sym_rtran] = ACTIONS(5876),
    [anon_sym_generate] = ACTIONS(5876),
    [anon_sym_for] = ACTIONS(5876),
    [anon_sym_initial] = ACTIONS(5876),
    [anon_sym_assign] = ACTIONS(5876),
    [anon_sym_alias] = ACTIONS(5876),
    [anon_sym_always_comb] = ACTIONS(5876),
    [anon_sym_always_latch] = ACTIONS(5876),
    [anon_sym_always_ff] = ACTIONS(5876),
    [anon_sym_final] = ACTIONS(5876),
    [anon_sym_while] = ACTIONS(5876),
    [anon_sym_global] = ACTIONS(5876),
    [anon_sym_specify] = ACTIONS(5876),
    [anon_sym_LPAREN_STAR] = ACTIONS(5878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5878),
    [anon_sym_DOLLARunit] = ACTIONS(5878),
  },
  [1053] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5602),
    [anon_sym_BQUOTE] = ACTIONS(5600),
    [aux_sym_id_directive_token1] = ACTIONS(5602),
    [aux_sym_id_directive_token2] = ACTIONS(5602),
    [aux_sym_id_directive_token3] = ACTIONS(5602),
    [aux_sym_id_directive_token4] = ACTIONS(5600),
    [aux_sym_zero_directive_token1] = ACTIONS(5602),
    [aux_sym_zero_directive_token2] = ACTIONS(5602),
    [aux_sym_zero_directive_token3] = ACTIONS(5602),
    [aux_sym_zero_directive_token4] = ACTIONS(5602),
    [aux_sym_zero_directive_token5] = ACTIONS(5602),
    [aux_sym_zero_directive_token6] = ACTIONS(5602),
    [aux_sym_zero_directive_token7] = ACTIONS(5602),
    [aux_sym_zero_directive_token8] = ACTIONS(5602),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5602),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5602),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5602),
    [aux_sym_begin_keywords_token1] = ACTIONS(5602),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_endmodule] = ACTIONS(5600),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_module] = ACTIONS(5600),
    [anon_sym_macromodule] = ACTIONS(5600),
    [anon_sym_endinterface] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_endprogram] = ACTIONS(5600),
    [anon_sym_program] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_timeunit] = ACTIONS(5600),
    [anon_sym_timeprecision] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_input] = ACTIONS(5600),
    [anon_sym_output] = ACTIONS(5600),
    [anon_sym_inout] = ACTIONS(5600),
    [anon_sym_ref] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_specparam] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_modport] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_while] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_specify] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [1054] = {
    [sym_simple_identifier] = ACTIONS(5880),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5882),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5882),
    [anon_sym_BQUOTE] = ACTIONS(5880),
    [aux_sym_id_directive_token1] = ACTIONS(5882),
    [aux_sym_id_directive_token2] = ACTIONS(5882),
    [aux_sym_id_directive_token3] = ACTIONS(5882),
    [aux_sym_id_directive_token4] = ACTIONS(5880),
    [aux_sym_zero_directive_token1] = ACTIONS(5882),
    [aux_sym_zero_directive_token2] = ACTIONS(5882),
    [aux_sym_zero_directive_token3] = ACTIONS(5882),
    [aux_sym_zero_directive_token4] = ACTIONS(5882),
    [aux_sym_zero_directive_token5] = ACTIONS(5882),
    [aux_sym_zero_directive_token6] = ACTIONS(5882),
    [aux_sym_zero_directive_token7] = ACTIONS(5882),
    [aux_sym_zero_directive_token8] = ACTIONS(5882),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5882),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5882),
    [anon_sym_wire] = ACTIONS(5880),
    [anon_sym_tri] = ACTIONS(5880),
    [anon_sym_tri0] = ACTIONS(5880),
    [anon_sym_tri1] = ACTIONS(5880),
    [anon_sym_wand] = ACTIONS(5880),
    [anon_sym_triand] = ACTIONS(5880),
    [anon_sym_wor] = ACTIONS(5880),
    [anon_sym_trior] = ACTIONS(5880),
    [anon_sym_trireg] = ACTIONS(5880),
    [anon_sym_uwire] = ACTIONS(5880),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5882),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5882),
    [aux_sym_begin_keywords_token1] = ACTIONS(5882),
    [anon_sym_SEMI] = ACTIONS(5882),
    [anon_sym_endmodule] = ACTIONS(5880),
    [anon_sym_extern] = ACTIONS(5880),
    [anon_sym_module] = ACTIONS(5880),
    [anon_sym_macromodule] = ACTIONS(5880),
    [anon_sym_endinterface] = ACTIONS(5880),
    [anon_sym_interface] = ACTIONS(5880),
    [anon_sym_endprogram] = ACTIONS(5880),
    [anon_sym_program] = ACTIONS(5880),
    [anon_sym_checker] = ACTIONS(5880),
    [anon_sym_virtual] = ACTIONS(5880),
    [anon_sym_class] = ACTIONS(5880),
    [anon_sym_timeunit] = ACTIONS(5880),
    [anon_sym_timeprecision] = ACTIONS(5880),
    [anon_sym_type] = ACTIONS(5880),
    [anon_sym_input] = ACTIONS(5880),
    [anon_sym_output] = ACTIONS(5880),
    [anon_sym_inout] = ACTIONS(5880),
    [anon_sym_ref] = ACTIONS(5880),
    [anon_sym_DOLLARfatal] = ACTIONS(5882),
    [anon_sym_DOLLARerror] = ACTIONS(5882),
    [anon_sym_DOLLARwarning] = ACTIONS(5882),
    [anon_sym_DOLLARinfo] = ACTIONS(5882),
    [anon_sym_default] = ACTIONS(5880),
    [anon_sym_clocking] = ACTIONS(5880),
    [anon_sym_defparam] = ACTIONS(5880),
    [anon_sym_bind] = ACTIONS(5880),
    [anon_sym_const] = ACTIONS(5880),
    [anon_sym_function] = ACTIONS(5880),
    [anon_sym_static] = ACTIONS(5880),
    [anon_sym_constraint] = ACTIONS(5880),
    [anon_sym_if] = ACTIONS(5880),
    [anon_sym_else] = ACTIONS(5880),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_localparam] = ACTIONS(5880),
    [anon_sym_parameter] = ACTIONS(5880),
    [anon_sym_specparam] = ACTIONS(5880),
    [anon_sym_var] = ACTIONS(5880),
    [anon_sym_import] = ACTIONS(5880),
    [anon_sym_export] = ACTIONS(5880),
    [anon_sym_genvar] = ACTIONS(5880),
    [anon_sym_interconnect] = ACTIONS(5880),
    [anon_sym_typedef] = ACTIONS(5880),
    [anon_sym_enum] = ACTIONS(5880),
    [anon_sym_struct] = ACTIONS(5880),
    [anon_sym_union] = ACTIONS(5880),
    [anon_sym_nettype] = ACTIONS(5880),
    [anon_sym_automatic] = ACTIONS(5880),
    [anon_sym_string] = ACTIONS(5880),
    [anon_sym_chandle] = ACTIONS(5880),
    [anon_sym_event] = ACTIONS(5880),
    [anon_sym_byte] = ACTIONS(5880),
    [anon_sym_shortint] = ACTIONS(5880),
    [anon_sym_int] = ACTIONS(5880),
    [anon_sym_longint] = ACTIONS(5880),
    [anon_sym_integer] = ACTIONS(5880),
    [anon_sym_time] = ACTIONS(5880),
    [anon_sym_bit] = ACTIONS(5880),
    [anon_sym_logic] = ACTIONS(5880),
    [anon_sym_reg] = ACTIONS(5880),
    [anon_sym_shortreal] = ACTIONS(5880),
    [anon_sym_real] = ACTIONS(5880),
    [anon_sym_realtime] = ACTIONS(5880),
    [anon_sym_supply0] = ACTIONS(5880),
    [anon_sym_supply1] = ACTIONS(5880),
    [anon_sym_signed] = ACTIONS(5880),
    [anon_sym_unsigned] = ACTIONS(5880),
    [anon_sym_task] = ACTIONS(5880),
    [anon_sym_modport] = ACTIONS(5880),
    [anon_sym_assert] = ACTIONS(5880),
    [anon_sym_property] = ACTIONS(5880),
    [anon_sym_assume] = ACTIONS(5880),
    [anon_sym_cover] = ACTIONS(5880),
    [anon_sym_sequence] = ACTIONS(5880),
    [anon_sym_restrict] = ACTIONS(5880),
    [anon_sym_not] = ACTIONS(5880),
    [anon_sym_or] = ACTIONS(5880),
    [anon_sym_and] = ACTIONS(5880),
    [anon_sym_case] = ACTIONS(5880),
    [anon_sym_always] = ACTIONS(5880),
    [anon_sym_covergroup] = ACTIONS(5880),
    [anon_sym_let] = ACTIONS(5880),
    [anon_sym_pulldown] = ACTIONS(5880),
    [anon_sym_pullup] = ACTIONS(5880),
    [anon_sym_cmos] = ACTIONS(5880),
    [anon_sym_rcmos] = ACTIONS(5880),
    [anon_sym_bufif0] = ACTIONS(5880),
    [anon_sym_bufif1] = ACTIONS(5880),
    [anon_sym_notif0] = ACTIONS(5880),
    [anon_sym_notif1] = ACTIONS(5880),
    [anon_sym_nmos] = ACTIONS(5880),
    [anon_sym_pmos] = ACTIONS(5880),
    [anon_sym_rnmos] = ACTIONS(5880),
    [anon_sym_rpmos] = ACTIONS(5880),
    [anon_sym_nand] = ACTIONS(5880),
    [anon_sym_nor] = ACTIONS(5880),
    [anon_sym_xor] = ACTIONS(5880),
    [anon_sym_xnor] = ACTIONS(5880),
    [anon_sym_buf] = ACTIONS(5880),
    [anon_sym_tranif0] = ACTIONS(5880),
    [anon_sym_tranif1] = ACTIONS(5880),
    [anon_sym_rtranif1] = ACTIONS(5880),
    [anon_sym_rtranif0] = ACTIONS(5880),
    [anon_sym_tran] = ACTIONS(5880),
    [anon_sym_rtran] = ACTIONS(5880),
    [anon_sym_generate] = ACTIONS(5880),
    [anon_sym_for] = ACTIONS(5880),
    [anon_sym_initial] = ACTIONS(5880),
    [anon_sym_assign] = ACTIONS(5880),
    [anon_sym_alias] = ACTIONS(5880),
    [anon_sym_always_comb] = ACTIONS(5880),
    [anon_sym_always_latch] = ACTIONS(5880),
    [anon_sym_always_ff] = ACTIONS(5880),
    [anon_sym_final] = ACTIONS(5880),
    [anon_sym_while] = ACTIONS(5880),
    [anon_sym_global] = ACTIONS(5880),
    [anon_sym_specify] = ACTIONS(5880),
    [anon_sym_LPAREN_STAR] = ACTIONS(5882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5882),
    [anon_sym_DOLLARunit] = ACTIONS(5882),
  },
  [1055] = {
    [sym_simple_identifier] = ACTIONS(5884),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5886),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5886),
    [anon_sym_BQUOTE] = ACTIONS(5884),
    [aux_sym_id_directive_token1] = ACTIONS(5886),
    [aux_sym_id_directive_token2] = ACTIONS(5886),
    [aux_sym_id_directive_token3] = ACTIONS(5886),
    [aux_sym_id_directive_token4] = ACTIONS(5884),
    [aux_sym_zero_directive_token1] = ACTIONS(5886),
    [aux_sym_zero_directive_token2] = ACTIONS(5886),
    [aux_sym_zero_directive_token3] = ACTIONS(5886),
    [aux_sym_zero_directive_token4] = ACTIONS(5886),
    [aux_sym_zero_directive_token5] = ACTIONS(5886),
    [aux_sym_zero_directive_token6] = ACTIONS(5886),
    [aux_sym_zero_directive_token7] = ACTIONS(5886),
    [aux_sym_zero_directive_token8] = ACTIONS(5886),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5886),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5886),
    [anon_sym_wire] = ACTIONS(5884),
    [anon_sym_tri] = ACTIONS(5884),
    [anon_sym_tri0] = ACTIONS(5884),
    [anon_sym_tri1] = ACTIONS(5884),
    [anon_sym_wand] = ACTIONS(5884),
    [anon_sym_triand] = ACTIONS(5884),
    [anon_sym_wor] = ACTIONS(5884),
    [anon_sym_trior] = ACTIONS(5884),
    [anon_sym_trireg] = ACTIONS(5884),
    [anon_sym_uwire] = ACTIONS(5884),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5886),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5886),
    [aux_sym_begin_keywords_token1] = ACTIONS(5886),
    [anon_sym_SEMI] = ACTIONS(5886),
    [anon_sym_endmodule] = ACTIONS(5884),
    [anon_sym_extern] = ACTIONS(5884),
    [anon_sym_module] = ACTIONS(5884),
    [anon_sym_macromodule] = ACTIONS(5884),
    [anon_sym_endinterface] = ACTIONS(5884),
    [anon_sym_interface] = ACTIONS(5884),
    [anon_sym_endprogram] = ACTIONS(5884),
    [anon_sym_program] = ACTIONS(5884),
    [anon_sym_checker] = ACTIONS(5884),
    [anon_sym_virtual] = ACTIONS(5884),
    [anon_sym_class] = ACTIONS(5884),
    [anon_sym_timeunit] = ACTIONS(5884),
    [anon_sym_timeprecision] = ACTIONS(5884),
    [anon_sym_type] = ACTIONS(5884),
    [anon_sym_input] = ACTIONS(5884),
    [anon_sym_output] = ACTIONS(5884),
    [anon_sym_inout] = ACTIONS(5884),
    [anon_sym_ref] = ACTIONS(5884),
    [anon_sym_DOLLARfatal] = ACTIONS(5886),
    [anon_sym_DOLLARerror] = ACTIONS(5886),
    [anon_sym_DOLLARwarning] = ACTIONS(5886),
    [anon_sym_DOLLARinfo] = ACTIONS(5886),
    [anon_sym_default] = ACTIONS(5884),
    [anon_sym_clocking] = ACTIONS(5884),
    [anon_sym_defparam] = ACTIONS(5884),
    [anon_sym_bind] = ACTIONS(5884),
    [anon_sym_const] = ACTIONS(5884),
    [anon_sym_function] = ACTIONS(5884),
    [anon_sym_static] = ACTIONS(5884),
    [anon_sym_constraint] = ACTIONS(5884),
    [anon_sym_if] = ACTIONS(5884),
    [anon_sym_else] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [anon_sym_localparam] = ACTIONS(5884),
    [anon_sym_parameter] = ACTIONS(5884),
    [anon_sym_specparam] = ACTIONS(5884),
    [anon_sym_var] = ACTIONS(5884),
    [anon_sym_import] = ACTIONS(5884),
    [anon_sym_export] = ACTIONS(5884),
    [anon_sym_genvar] = ACTIONS(5884),
    [anon_sym_interconnect] = ACTIONS(5884),
    [anon_sym_typedef] = ACTIONS(5884),
    [anon_sym_enum] = ACTIONS(5884),
    [anon_sym_struct] = ACTIONS(5884),
    [anon_sym_union] = ACTIONS(5884),
    [anon_sym_nettype] = ACTIONS(5884),
    [anon_sym_automatic] = ACTIONS(5884),
    [anon_sym_string] = ACTIONS(5884),
    [anon_sym_chandle] = ACTIONS(5884),
    [anon_sym_event] = ACTIONS(5884),
    [anon_sym_byte] = ACTIONS(5884),
    [anon_sym_shortint] = ACTIONS(5884),
    [anon_sym_int] = ACTIONS(5884),
    [anon_sym_longint] = ACTIONS(5884),
    [anon_sym_integer] = ACTIONS(5884),
    [anon_sym_time] = ACTIONS(5884),
    [anon_sym_bit] = ACTIONS(5884),
    [anon_sym_logic] = ACTIONS(5884),
    [anon_sym_reg] = ACTIONS(5884),
    [anon_sym_shortreal] = ACTIONS(5884),
    [anon_sym_real] = ACTIONS(5884),
    [anon_sym_realtime] = ACTIONS(5884),
    [anon_sym_supply0] = ACTIONS(5884),
    [anon_sym_supply1] = ACTIONS(5884),
    [anon_sym_signed] = ACTIONS(5884),
    [anon_sym_unsigned] = ACTIONS(5884),
    [anon_sym_task] = ACTIONS(5884),
    [anon_sym_modport] = ACTIONS(5884),
    [anon_sym_assert] = ACTIONS(5884),
    [anon_sym_property] = ACTIONS(5884),
    [anon_sym_assume] = ACTIONS(5884),
    [anon_sym_cover] = ACTIONS(5884),
    [anon_sym_sequence] = ACTIONS(5884),
    [anon_sym_restrict] = ACTIONS(5884),
    [anon_sym_not] = ACTIONS(5884),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_case] = ACTIONS(5884),
    [anon_sym_always] = ACTIONS(5884),
    [anon_sym_covergroup] = ACTIONS(5884),
    [anon_sym_let] = ACTIONS(5884),
    [anon_sym_pulldown] = ACTIONS(5884),
    [anon_sym_pullup] = ACTIONS(5884),
    [anon_sym_cmos] = ACTIONS(5884),
    [anon_sym_rcmos] = ACTIONS(5884),
    [anon_sym_bufif0] = ACTIONS(5884),
    [anon_sym_bufif1] = ACTIONS(5884),
    [anon_sym_notif0] = ACTIONS(5884),
    [anon_sym_notif1] = ACTIONS(5884),
    [anon_sym_nmos] = ACTIONS(5884),
    [anon_sym_pmos] = ACTIONS(5884),
    [anon_sym_rnmos] = ACTIONS(5884),
    [anon_sym_rpmos] = ACTIONS(5884),
    [anon_sym_nand] = ACTIONS(5884),
    [anon_sym_nor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_xnor] = ACTIONS(5884),
    [anon_sym_buf] = ACTIONS(5884),
    [anon_sym_tranif0] = ACTIONS(5884),
    [anon_sym_tranif1] = ACTIONS(5884),
    [anon_sym_rtranif1] = ACTIONS(5884),
    [anon_sym_rtranif0] = ACTIONS(5884),
    [anon_sym_tran] = ACTIONS(5884),
    [anon_sym_rtran] = ACTIONS(5884),
    [anon_sym_generate] = ACTIONS(5884),
    [anon_sym_for] = ACTIONS(5884),
    [anon_sym_initial] = ACTIONS(5884),
    [anon_sym_assign] = ACTIONS(5884),
    [anon_sym_alias] = ACTIONS(5884),
    [anon_sym_always_comb] = ACTIONS(5884),
    [anon_sym_always_latch] = ACTIONS(5884),
    [anon_sym_always_ff] = ACTIONS(5884),
    [anon_sym_final] = ACTIONS(5884),
    [anon_sym_while] = ACTIONS(5884),
    [anon_sym_global] = ACTIONS(5884),
    [anon_sym_specify] = ACTIONS(5884),
    [anon_sym_LPAREN_STAR] = ACTIONS(5886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5886),
    [anon_sym_DOLLARunit] = ACTIONS(5886),
  },
  [1056] = {
    [sym_simple_identifier] = ACTIONS(5888),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5890),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5890),
    [anon_sym_BQUOTE] = ACTIONS(5888),
    [aux_sym_id_directive_token1] = ACTIONS(5890),
    [aux_sym_id_directive_token2] = ACTIONS(5890),
    [aux_sym_id_directive_token3] = ACTIONS(5890),
    [aux_sym_id_directive_token4] = ACTIONS(5888),
    [aux_sym_zero_directive_token1] = ACTIONS(5890),
    [aux_sym_zero_directive_token2] = ACTIONS(5890),
    [aux_sym_zero_directive_token3] = ACTIONS(5890),
    [aux_sym_zero_directive_token4] = ACTIONS(5890),
    [aux_sym_zero_directive_token5] = ACTIONS(5890),
    [aux_sym_zero_directive_token6] = ACTIONS(5890),
    [aux_sym_zero_directive_token7] = ACTIONS(5890),
    [aux_sym_zero_directive_token8] = ACTIONS(5890),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5890),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5890),
    [anon_sym_wire] = ACTIONS(5888),
    [anon_sym_tri] = ACTIONS(5888),
    [anon_sym_tri0] = ACTIONS(5888),
    [anon_sym_tri1] = ACTIONS(5888),
    [anon_sym_wand] = ACTIONS(5888),
    [anon_sym_triand] = ACTIONS(5888),
    [anon_sym_wor] = ACTIONS(5888),
    [anon_sym_trior] = ACTIONS(5888),
    [anon_sym_trireg] = ACTIONS(5888),
    [anon_sym_uwire] = ACTIONS(5888),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5890),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5890),
    [aux_sym_begin_keywords_token1] = ACTIONS(5890),
    [anon_sym_SEMI] = ACTIONS(5890),
    [anon_sym_endmodule] = ACTIONS(5888),
    [anon_sym_extern] = ACTIONS(5888),
    [anon_sym_module] = ACTIONS(5888),
    [anon_sym_macromodule] = ACTIONS(5888),
    [anon_sym_endinterface] = ACTIONS(5888),
    [anon_sym_interface] = ACTIONS(5888),
    [anon_sym_endprogram] = ACTIONS(5888),
    [anon_sym_program] = ACTIONS(5888),
    [anon_sym_checker] = ACTIONS(5888),
    [anon_sym_virtual] = ACTIONS(5888),
    [anon_sym_class] = ACTIONS(5888),
    [anon_sym_timeunit] = ACTIONS(5888),
    [anon_sym_timeprecision] = ACTIONS(5888),
    [anon_sym_type] = ACTIONS(5888),
    [anon_sym_input] = ACTIONS(5888),
    [anon_sym_output] = ACTIONS(5888),
    [anon_sym_inout] = ACTIONS(5888),
    [anon_sym_ref] = ACTIONS(5888),
    [anon_sym_DOLLARfatal] = ACTIONS(5890),
    [anon_sym_DOLLARerror] = ACTIONS(5890),
    [anon_sym_DOLLARwarning] = ACTIONS(5890),
    [anon_sym_DOLLARinfo] = ACTIONS(5890),
    [anon_sym_default] = ACTIONS(5888),
    [anon_sym_clocking] = ACTIONS(5888),
    [anon_sym_defparam] = ACTIONS(5888),
    [anon_sym_bind] = ACTIONS(5888),
    [anon_sym_const] = ACTIONS(5888),
    [anon_sym_function] = ACTIONS(5888),
    [anon_sym_static] = ACTIONS(5888),
    [anon_sym_constraint] = ACTIONS(5888),
    [anon_sym_if] = ACTIONS(5888),
    [anon_sym_else] = ACTIONS(5888),
    [anon_sym_LBRACK] = ACTIONS(5890),
    [anon_sym_localparam] = ACTIONS(5888),
    [anon_sym_parameter] = ACTIONS(5888),
    [anon_sym_specparam] = ACTIONS(5888),
    [anon_sym_var] = ACTIONS(5888),
    [anon_sym_import] = ACTIONS(5888),
    [anon_sym_export] = ACTIONS(5888),
    [anon_sym_genvar] = ACTIONS(5888),
    [anon_sym_interconnect] = ACTIONS(5888),
    [anon_sym_typedef] = ACTIONS(5888),
    [anon_sym_enum] = ACTIONS(5888),
    [anon_sym_struct] = ACTIONS(5888),
    [anon_sym_union] = ACTIONS(5888),
    [anon_sym_nettype] = ACTIONS(5888),
    [anon_sym_automatic] = ACTIONS(5888),
    [anon_sym_string] = ACTIONS(5888),
    [anon_sym_chandle] = ACTIONS(5888),
    [anon_sym_event] = ACTIONS(5888),
    [anon_sym_byte] = ACTIONS(5888),
    [anon_sym_shortint] = ACTIONS(5888),
    [anon_sym_int] = ACTIONS(5888),
    [anon_sym_longint] = ACTIONS(5888),
    [anon_sym_integer] = ACTIONS(5888),
    [anon_sym_time] = ACTIONS(5888),
    [anon_sym_bit] = ACTIONS(5888),
    [anon_sym_logic] = ACTIONS(5888),
    [anon_sym_reg] = ACTIONS(5888),
    [anon_sym_shortreal] = ACTIONS(5888),
    [anon_sym_real] = ACTIONS(5888),
    [anon_sym_realtime] = ACTIONS(5888),
    [anon_sym_supply0] = ACTIONS(5888),
    [anon_sym_supply1] = ACTIONS(5888),
    [anon_sym_signed] = ACTIONS(5888),
    [anon_sym_unsigned] = ACTIONS(5888),
    [anon_sym_task] = ACTIONS(5888),
    [anon_sym_modport] = ACTIONS(5888),
    [anon_sym_assert] = ACTIONS(5888),
    [anon_sym_property] = ACTIONS(5888),
    [anon_sym_assume] = ACTIONS(5888),
    [anon_sym_cover] = ACTIONS(5888),
    [anon_sym_sequence] = ACTIONS(5888),
    [anon_sym_restrict] = ACTIONS(5888),
    [anon_sym_not] = ACTIONS(5888),
    [anon_sym_or] = ACTIONS(5888),
    [anon_sym_and] = ACTIONS(5888),
    [anon_sym_case] = ACTIONS(5888),
    [anon_sym_always] = ACTIONS(5888),
    [anon_sym_covergroup] = ACTIONS(5888),
    [anon_sym_let] = ACTIONS(5888),
    [anon_sym_pulldown] = ACTIONS(5888),
    [anon_sym_pullup] = ACTIONS(5888),
    [anon_sym_cmos] = ACTIONS(5888),
    [anon_sym_rcmos] = ACTIONS(5888),
    [anon_sym_bufif0] = ACTIONS(5888),
    [anon_sym_bufif1] = ACTIONS(5888),
    [anon_sym_notif0] = ACTIONS(5888),
    [anon_sym_notif1] = ACTIONS(5888),
    [anon_sym_nmos] = ACTIONS(5888),
    [anon_sym_pmos] = ACTIONS(5888),
    [anon_sym_rnmos] = ACTIONS(5888),
    [anon_sym_rpmos] = ACTIONS(5888),
    [anon_sym_nand] = ACTIONS(5888),
    [anon_sym_nor] = ACTIONS(5888),
    [anon_sym_xor] = ACTIONS(5888),
    [anon_sym_xnor] = ACTIONS(5888),
    [anon_sym_buf] = ACTIONS(5888),
    [anon_sym_tranif0] = ACTIONS(5888),
    [anon_sym_tranif1] = ACTIONS(5888),
    [anon_sym_rtranif1] = ACTIONS(5888),
    [anon_sym_rtranif0] = ACTIONS(5888),
    [anon_sym_tran] = ACTIONS(5888),
    [anon_sym_rtran] = ACTIONS(5888),
    [anon_sym_generate] = ACTIONS(5888),
    [anon_sym_for] = ACTIONS(5888),
    [anon_sym_initial] = ACTIONS(5888),
    [anon_sym_assign] = ACTIONS(5888),
    [anon_sym_alias] = ACTIONS(5888),
    [anon_sym_always_comb] = ACTIONS(5888),
    [anon_sym_always_latch] = ACTIONS(5888),
    [anon_sym_always_ff] = ACTIONS(5888),
    [anon_sym_final] = ACTIONS(5888),
    [anon_sym_while] = ACTIONS(5888),
    [anon_sym_global] = ACTIONS(5888),
    [anon_sym_specify] = ACTIONS(5888),
    [anon_sym_LPAREN_STAR] = ACTIONS(5890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5890),
    [anon_sym_DOLLARunit] = ACTIONS(5890),
  },
  [1057] = {
    [sym_simple_identifier] = ACTIONS(5892),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5894),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5894),
    [anon_sym_BQUOTE] = ACTIONS(5892),
    [aux_sym_id_directive_token1] = ACTIONS(5894),
    [aux_sym_id_directive_token2] = ACTIONS(5894),
    [aux_sym_id_directive_token3] = ACTIONS(5894),
    [aux_sym_id_directive_token4] = ACTIONS(5892),
    [aux_sym_zero_directive_token1] = ACTIONS(5894),
    [aux_sym_zero_directive_token2] = ACTIONS(5894),
    [aux_sym_zero_directive_token3] = ACTIONS(5894),
    [aux_sym_zero_directive_token4] = ACTIONS(5894),
    [aux_sym_zero_directive_token5] = ACTIONS(5894),
    [aux_sym_zero_directive_token6] = ACTIONS(5894),
    [aux_sym_zero_directive_token7] = ACTIONS(5894),
    [aux_sym_zero_directive_token8] = ACTIONS(5894),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5894),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5894),
    [anon_sym_wire] = ACTIONS(5892),
    [anon_sym_tri] = ACTIONS(5892),
    [anon_sym_tri0] = ACTIONS(5892),
    [anon_sym_tri1] = ACTIONS(5892),
    [anon_sym_wand] = ACTIONS(5892),
    [anon_sym_triand] = ACTIONS(5892),
    [anon_sym_wor] = ACTIONS(5892),
    [anon_sym_trior] = ACTIONS(5892),
    [anon_sym_trireg] = ACTIONS(5892),
    [anon_sym_uwire] = ACTIONS(5892),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5894),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5894),
    [aux_sym_begin_keywords_token1] = ACTIONS(5894),
    [anon_sym_SEMI] = ACTIONS(5894),
    [anon_sym_endmodule] = ACTIONS(5892),
    [anon_sym_extern] = ACTIONS(5892),
    [anon_sym_module] = ACTIONS(5892),
    [anon_sym_macromodule] = ACTIONS(5892),
    [anon_sym_endinterface] = ACTIONS(5892),
    [anon_sym_interface] = ACTIONS(5892),
    [anon_sym_endprogram] = ACTIONS(5892),
    [anon_sym_program] = ACTIONS(5892),
    [anon_sym_checker] = ACTIONS(5892),
    [anon_sym_virtual] = ACTIONS(5892),
    [anon_sym_class] = ACTIONS(5892),
    [anon_sym_timeunit] = ACTIONS(5892),
    [anon_sym_timeprecision] = ACTIONS(5892),
    [anon_sym_type] = ACTIONS(5892),
    [anon_sym_input] = ACTIONS(5892),
    [anon_sym_output] = ACTIONS(5892),
    [anon_sym_inout] = ACTIONS(5892),
    [anon_sym_ref] = ACTIONS(5892),
    [anon_sym_DOLLARfatal] = ACTIONS(5894),
    [anon_sym_DOLLARerror] = ACTIONS(5894),
    [anon_sym_DOLLARwarning] = ACTIONS(5894),
    [anon_sym_DOLLARinfo] = ACTIONS(5894),
    [anon_sym_default] = ACTIONS(5892),
    [anon_sym_clocking] = ACTIONS(5892),
    [anon_sym_defparam] = ACTIONS(5892),
    [anon_sym_bind] = ACTIONS(5892),
    [anon_sym_const] = ACTIONS(5892),
    [anon_sym_function] = ACTIONS(5892),
    [anon_sym_static] = ACTIONS(5892),
    [anon_sym_constraint] = ACTIONS(5892),
    [anon_sym_if] = ACTIONS(5892),
    [anon_sym_else] = ACTIONS(5892),
    [anon_sym_LBRACK] = ACTIONS(5894),
    [anon_sym_localparam] = ACTIONS(5892),
    [anon_sym_parameter] = ACTIONS(5892),
    [anon_sym_specparam] = ACTIONS(5892),
    [anon_sym_var] = ACTIONS(5892),
    [anon_sym_import] = ACTIONS(5892),
    [anon_sym_export] = ACTIONS(5892),
    [anon_sym_genvar] = ACTIONS(5892),
    [anon_sym_interconnect] = ACTIONS(5892),
    [anon_sym_typedef] = ACTIONS(5892),
    [anon_sym_enum] = ACTIONS(5892),
    [anon_sym_struct] = ACTIONS(5892),
    [anon_sym_union] = ACTIONS(5892),
    [anon_sym_nettype] = ACTIONS(5892),
    [anon_sym_automatic] = ACTIONS(5892),
    [anon_sym_string] = ACTIONS(5892),
    [anon_sym_chandle] = ACTIONS(5892),
    [anon_sym_event] = ACTIONS(5892),
    [anon_sym_byte] = ACTIONS(5892),
    [anon_sym_shortint] = ACTIONS(5892),
    [anon_sym_int] = ACTIONS(5892),
    [anon_sym_longint] = ACTIONS(5892),
    [anon_sym_integer] = ACTIONS(5892),
    [anon_sym_time] = ACTIONS(5892),
    [anon_sym_bit] = ACTIONS(5892),
    [anon_sym_logic] = ACTIONS(5892),
    [anon_sym_reg] = ACTIONS(5892),
    [anon_sym_shortreal] = ACTIONS(5892),
    [anon_sym_real] = ACTIONS(5892),
    [anon_sym_realtime] = ACTIONS(5892),
    [anon_sym_supply0] = ACTIONS(5892),
    [anon_sym_supply1] = ACTIONS(5892),
    [anon_sym_signed] = ACTIONS(5892),
    [anon_sym_unsigned] = ACTIONS(5892),
    [anon_sym_task] = ACTIONS(5892),
    [anon_sym_modport] = ACTIONS(5892),
    [anon_sym_assert] = ACTIONS(5892),
    [anon_sym_property] = ACTIONS(5892),
    [anon_sym_assume] = ACTIONS(5892),
    [anon_sym_cover] = ACTIONS(5892),
    [anon_sym_sequence] = ACTIONS(5892),
    [anon_sym_restrict] = ACTIONS(5892),
    [anon_sym_not] = ACTIONS(5892),
    [anon_sym_or] = ACTIONS(5892),
    [anon_sym_and] = ACTIONS(5892),
    [anon_sym_case] = ACTIONS(5892),
    [anon_sym_always] = ACTIONS(5892),
    [anon_sym_covergroup] = ACTIONS(5892),
    [anon_sym_let] = ACTIONS(5892),
    [anon_sym_pulldown] = ACTIONS(5892),
    [anon_sym_pullup] = ACTIONS(5892),
    [anon_sym_cmos] = ACTIONS(5892),
    [anon_sym_rcmos] = ACTIONS(5892),
    [anon_sym_bufif0] = ACTIONS(5892),
    [anon_sym_bufif1] = ACTIONS(5892),
    [anon_sym_notif0] = ACTIONS(5892),
    [anon_sym_notif1] = ACTIONS(5892),
    [anon_sym_nmos] = ACTIONS(5892),
    [anon_sym_pmos] = ACTIONS(5892),
    [anon_sym_rnmos] = ACTIONS(5892),
    [anon_sym_rpmos] = ACTIONS(5892),
    [anon_sym_nand] = ACTIONS(5892),
    [anon_sym_nor] = ACTIONS(5892),
    [anon_sym_xor] = ACTIONS(5892),
    [anon_sym_xnor] = ACTIONS(5892),
    [anon_sym_buf] = ACTIONS(5892),
    [anon_sym_tranif0] = ACTIONS(5892),
    [anon_sym_tranif1] = ACTIONS(5892),
    [anon_sym_rtranif1] = ACTIONS(5892),
    [anon_sym_rtranif0] = ACTIONS(5892),
    [anon_sym_tran] = ACTIONS(5892),
    [anon_sym_rtran] = ACTIONS(5892),
    [anon_sym_generate] = ACTIONS(5892),
    [anon_sym_for] = ACTIONS(5892),
    [anon_sym_initial] = ACTIONS(5892),
    [anon_sym_assign] = ACTIONS(5892),
    [anon_sym_alias] = ACTIONS(5892),
    [anon_sym_always_comb] = ACTIONS(5892),
    [anon_sym_always_latch] = ACTIONS(5892),
    [anon_sym_always_ff] = ACTIONS(5892),
    [anon_sym_final] = ACTIONS(5892),
    [anon_sym_while] = ACTIONS(5892),
    [anon_sym_global] = ACTIONS(5892),
    [anon_sym_specify] = ACTIONS(5892),
    [anon_sym_LPAREN_STAR] = ACTIONS(5894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5894),
    [anon_sym_DOLLARunit] = ACTIONS(5894),
  },
  [1058] = {
    [sym_simple_identifier] = ACTIONS(5896),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5898),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5898),
    [anon_sym_BQUOTE] = ACTIONS(5896),
    [aux_sym_id_directive_token1] = ACTIONS(5898),
    [aux_sym_id_directive_token2] = ACTIONS(5898),
    [aux_sym_id_directive_token3] = ACTIONS(5898),
    [aux_sym_id_directive_token4] = ACTIONS(5896),
    [aux_sym_zero_directive_token1] = ACTIONS(5898),
    [aux_sym_zero_directive_token2] = ACTIONS(5898),
    [aux_sym_zero_directive_token3] = ACTIONS(5898),
    [aux_sym_zero_directive_token4] = ACTIONS(5898),
    [aux_sym_zero_directive_token5] = ACTIONS(5898),
    [aux_sym_zero_directive_token6] = ACTIONS(5898),
    [aux_sym_zero_directive_token7] = ACTIONS(5898),
    [aux_sym_zero_directive_token8] = ACTIONS(5898),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5898),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5898),
    [anon_sym_wire] = ACTIONS(5896),
    [anon_sym_tri] = ACTIONS(5896),
    [anon_sym_tri0] = ACTIONS(5896),
    [anon_sym_tri1] = ACTIONS(5896),
    [anon_sym_wand] = ACTIONS(5896),
    [anon_sym_triand] = ACTIONS(5896),
    [anon_sym_wor] = ACTIONS(5896),
    [anon_sym_trior] = ACTIONS(5896),
    [anon_sym_trireg] = ACTIONS(5896),
    [anon_sym_uwire] = ACTIONS(5896),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5898),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5898),
    [aux_sym_begin_keywords_token1] = ACTIONS(5898),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym_endmodule] = ACTIONS(5896),
    [anon_sym_extern] = ACTIONS(5896),
    [anon_sym_module] = ACTIONS(5896),
    [anon_sym_macromodule] = ACTIONS(5896),
    [anon_sym_endinterface] = ACTIONS(5896),
    [anon_sym_interface] = ACTIONS(5896),
    [anon_sym_endprogram] = ACTIONS(5896),
    [anon_sym_program] = ACTIONS(5896),
    [anon_sym_checker] = ACTIONS(5896),
    [anon_sym_virtual] = ACTIONS(5896),
    [anon_sym_class] = ACTIONS(5896),
    [anon_sym_timeunit] = ACTIONS(5896),
    [anon_sym_timeprecision] = ACTIONS(5896),
    [anon_sym_type] = ACTIONS(5896),
    [anon_sym_input] = ACTIONS(5896),
    [anon_sym_output] = ACTIONS(5896),
    [anon_sym_inout] = ACTIONS(5896),
    [anon_sym_ref] = ACTIONS(5896),
    [anon_sym_DOLLARfatal] = ACTIONS(5898),
    [anon_sym_DOLLARerror] = ACTIONS(5898),
    [anon_sym_DOLLARwarning] = ACTIONS(5898),
    [anon_sym_DOLLARinfo] = ACTIONS(5898),
    [anon_sym_default] = ACTIONS(5896),
    [anon_sym_clocking] = ACTIONS(5896),
    [anon_sym_defparam] = ACTIONS(5896),
    [anon_sym_bind] = ACTIONS(5896),
    [anon_sym_const] = ACTIONS(5896),
    [anon_sym_function] = ACTIONS(5896),
    [anon_sym_static] = ACTIONS(5896),
    [anon_sym_constraint] = ACTIONS(5896),
    [anon_sym_if] = ACTIONS(5896),
    [anon_sym_else] = ACTIONS(5896),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_localparam] = ACTIONS(5896),
    [anon_sym_parameter] = ACTIONS(5896),
    [anon_sym_specparam] = ACTIONS(5896),
    [anon_sym_var] = ACTIONS(5896),
    [anon_sym_import] = ACTIONS(5896),
    [anon_sym_export] = ACTIONS(5896),
    [anon_sym_genvar] = ACTIONS(5896),
    [anon_sym_interconnect] = ACTIONS(5896),
    [anon_sym_typedef] = ACTIONS(5896),
    [anon_sym_enum] = ACTIONS(5896),
    [anon_sym_struct] = ACTIONS(5896),
    [anon_sym_union] = ACTIONS(5896),
    [anon_sym_nettype] = ACTIONS(5896),
    [anon_sym_automatic] = ACTIONS(5896),
    [anon_sym_string] = ACTIONS(5896),
    [anon_sym_chandle] = ACTIONS(5896),
    [anon_sym_event] = ACTIONS(5896),
    [anon_sym_byte] = ACTIONS(5896),
    [anon_sym_shortint] = ACTIONS(5896),
    [anon_sym_int] = ACTIONS(5896),
    [anon_sym_longint] = ACTIONS(5896),
    [anon_sym_integer] = ACTIONS(5896),
    [anon_sym_time] = ACTIONS(5896),
    [anon_sym_bit] = ACTIONS(5896),
    [anon_sym_logic] = ACTIONS(5896),
    [anon_sym_reg] = ACTIONS(5896),
    [anon_sym_shortreal] = ACTIONS(5896),
    [anon_sym_real] = ACTIONS(5896),
    [anon_sym_realtime] = ACTIONS(5896),
    [anon_sym_supply0] = ACTIONS(5896),
    [anon_sym_supply1] = ACTIONS(5896),
    [anon_sym_signed] = ACTIONS(5896),
    [anon_sym_unsigned] = ACTIONS(5896),
    [anon_sym_task] = ACTIONS(5896),
    [anon_sym_modport] = ACTIONS(5896),
    [anon_sym_assert] = ACTIONS(5896),
    [anon_sym_property] = ACTIONS(5896),
    [anon_sym_assume] = ACTIONS(5896),
    [anon_sym_cover] = ACTIONS(5896),
    [anon_sym_sequence] = ACTIONS(5896),
    [anon_sym_restrict] = ACTIONS(5896),
    [anon_sym_not] = ACTIONS(5896),
    [anon_sym_or] = ACTIONS(5896),
    [anon_sym_and] = ACTIONS(5896),
    [anon_sym_case] = ACTIONS(5896),
    [anon_sym_always] = ACTIONS(5896),
    [anon_sym_covergroup] = ACTIONS(5896),
    [anon_sym_let] = ACTIONS(5896),
    [anon_sym_pulldown] = ACTIONS(5896),
    [anon_sym_pullup] = ACTIONS(5896),
    [anon_sym_cmos] = ACTIONS(5896),
    [anon_sym_rcmos] = ACTIONS(5896),
    [anon_sym_bufif0] = ACTIONS(5896),
    [anon_sym_bufif1] = ACTIONS(5896),
    [anon_sym_notif0] = ACTIONS(5896),
    [anon_sym_notif1] = ACTIONS(5896),
    [anon_sym_nmos] = ACTIONS(5896),
    [anon_sym_pmos] = ACTIONS(5896),
    [anon_sym_rnmos] = ACTIONS(5896),
    [anon_sym_rpmos] = ACTIONS(5896),
    [anon_sym_nand] = ACTIONS(5896),
    [anon_sym_nor] = ACTIONS(5896),
    [anon_sym_xor] = ACTIONS(5896),
    [anon_sym_xnor] = ACTIONS(5896),
    [anon_sym_buf] = ACTIONS(5896),
    [anon_sym_tranif0] = ACTIONS(5896),
    [anon_sym_tranif1] = ACTIONS(5896),
    [anon_sym_rtranif1] = ACTIONS(5896),
    [anon_sym_rtranif0] = ACTIONS(5896),
    [anon_sym_tran] = ACTIONS(5896),
    [anon_sym_rtran] = ACTIONS(5896),
    [anon_sym_generate] = ACTIONS(5896),
    [anon_sym_for] = ACTIONS(5896),
    [anon_sym_initial] = ACTIONS(5896),
    [anon_sym_assign] = ACTIONS(5896),
    [anon_sym_alias] = ACTIONS(5896),
    [anon_sym_always_comb] = ACTIONS(5896),
    [anon_sym_always_latch] = ACTIONS(5896),
    [anon_sym_always_ff] = ACTIONS(5896),
    [anon_sym_final] = ACTIONS(5896),
    [anon_sym_while] = ACTIONS(5896),
    [anon_sym_global] = ACTIONS(5896),
    [anon_sym_specify] = ACTIONS(5896),
    [anon_sym_LPAREN_STAR] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5898),
    [anon_sym_DOLLARunit] = ACTIONS(5898),
  },
  [1059] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9283),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(2648),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_PLUS_COLON] = ACTIONS(2648),
    [anon_sym_DASH_COLON] = ACTIONS(2648),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1060] = {
    [ts_builtin_sym_end] = ACTIONS(5942),
    [sym_simple_identifier] = ACTIONS(5944),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5942),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5942),
    [anon_sym_BQUOTE] = ACTIONS(5944),
    [aux_sym_id_directive_token1] = ACTIONS(5942),
    [aux_sym_id_directive_token2] = ACTIONS(5942),
    [aux_sym_id_directive_token3] = ACTIONS(5942),
    [aux_sym_id_directive_token4] = ACTIONS(5944),
    [aux_sym_zero_directive_token1] = ACTIONS(5942),
    [aux_sym_zero_directive_token2] = ACTIONS(5942),
    [aux_sym_zero_directive_token3] = ACTIONS(5942),
    [aux_sym_zero_directive_token4] = ACTIONS(5942),
    [aux_sym_zero_directive_token5] = ACTIONS(5942),
    [aux_sym_zero_directive_token6] = ACTIONS(5942),
    [aux_sym_zero_directive_token7] = ACTIONS(5942),
    [aux_sym_zero_directive_token8] = ACTIONS(5942),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5942),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5942),
    [anon_sym_wire] = ACTIONS(5944),
    [anon_sym_tri] = ACTIONS(5944),
    [anon_sym_tri0] = ACTIONS(5944),
    [anon_sym_tri1] = ACTIONS(5944),
    [anon_sym_wand] = ACTIONS(5944),
    [anon_sym_triand] = ACTIONS(5944),
    [anon_sym_wor] = ACTIONS(5944),
    [anon_sym_trior] = ACTIONS(5944),
    [anon_sym_trireg] = ACTIONS(5944),
    [anon_sym_uwire] = ACTIONS(5944),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5942),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5942),
    [aux_sym_begin_keywords_token1] = ACTIONS(5942),
    [anon_sym_SEMI] = ACTIONS(5942),
    [anon_sym_endmodule] = ACTIONS(5944),
    [anon_sym_extern] = ACTIONS(5944),
    [anon_sym_module] = ACTIONS(5944),
    [anon_sym_macromodule] = ACTIONS(5944),
    [anon_sym_endinterface] = ACTIONS(5944),
    [anon_sym_interface] = ACTIONS(5944),
    [anon_sym_program] = ACTIONS(5944),
    [anon_sym_checker] = ACTIONS(5944),
    [anon_sym_virtual] = ACTIONS(5944),
    [anon_sym_class] = ACTIONS(5944),
    [anon_sym_package] = ACTIONS(5944),
    [anon_sym_timeunit] = ACTIONS(5944),
    [anon_sym_timeprecision] = ACTIONS(5944),
    [anon_sym_type] = ACTIONS(5944),
    [anon_sym_input] = ACTIONS(5944),
    [anon_sym_output] = ACTIONS(5944),
    [anon_sym_inout] = ACTIONS(5944),
    [anon_sym_ref] = ACTIONS(5944),
    [anon_sym_DOLLARfatal] = ACTIONS(5942),
    [anon_sym_DOLLARerror] = ACTIONS(5942),
    [anon_sym_DOLLARwarning] = ACTIONS(5942),
    [anon_sym_DOLLARinfo] = ACTIONS(5942),
    [anon_sym_default] = ACTIONS(5944),
    [anon_sym_clocking] = ACTIONS(5944),
    [anon_sym_defparam] = ACTIONS(5944),
    [anon_sym_bind] = ACTIONS(5944),
    [anon_sym_const] = ACTIONS(5944),
    [anon_sym_function] = ACTIONS(5944),
    [anon_sym_static] = ACTIONS(5944),
    [anon_sym_constraint] = ACTIONS(5944),
    [anon_sym_if] = ACTIONS(5944),
    [anon_sym_LBRACK] = ACTIONS(5942),
    [anon_sym_localparam] = ACTIONS(5944),
    [anon_sym_parameter] = ACTIONS(5944),
    [anon_sym_specparam] = ACTIONS(5944),
    [anon_sym_var] = ACTIONS(5944),
    [anon_sym_import] = ACTIONS(5944),
    [anon_sym_export] = ACTIONS(5944),
    [anon_sym_genvar] = ACTIONS(5944),
    [anon_sym_interconnect] = ACTIONS(5944),
    [anon_sym_typedef] = ACTIONS(5944),
    [anon_sym_enum] = ACTIONS(5944),
    [anon_sym_struct] = ACTIONS(5944),
    [anon_sym_union] = ACTIONS(5944),
    [anon_sym_nettype] = ACTIONS(5944),
    [anon_sym_automatic] = ACTIONS(5944),
    [anon_sym_string] = ACTIONS(5944),
    [anon_sym_chandle] = ACTIONS(5944),
    [anon_sym_event] = ACTIONS(5944),
    [anon_sym_byte] = ACTIONS(5944),
    [anon_sym_shortint] = ACTIONS(5944),
    [anon_sym_int] = ACTIONS(5944),
    [anon_sym_longint] = ACTIONS(5944),
    [anon_sym_integer] = ACTIONS(5944),
    [anon_sym_time] = ACTIONS(5944),
    [anon_sym_bit] = ACTIONS(5944),
    [anon_sym_logic] = ACTIONS(5944),
    [anon_sym_reg] = ACTIONS(5944),
    [anon_sym_shortreal] = ACTIONS(5944),
    [anon_sym_real] = ACTIONS(5944),
    [anon_sym_realtime] = ACTIONS(5944),
    [anon_sym_supply0] = ACTIONS(5944),
    [anon_sym_supply1] = ACTIONS(5944),
    [anon_sym_signed] = ACTIONS(5944),
    [anon_sym_unsigned] = ACTIONS(5944),
    [anon_sym_task] = ACTIONS(5944),
    [anon_sym_modport] = ACTIONS(5944),
    [anon_sym_assert] = ACTIONS(5944),
    [anon_sym_property] = ACTIONS(5944),
    [anon_sym_assume] = ACTIONS(5944),
    [anon_sym_cover] = ACTIONS(5944),
    [anon_sym_sequence] = ACTIONS(5944),
    [anon_sym_restrict] = ACTIONS(5944),
    [anon_sym_not] = ACTIONS(5944),
    [anon_sym_or] = ACTIONS(5944),
    [anon_sym_and] = ACTIONS(5944),
    [anon_sym_case] = ACTIONS(5944),
    [anon_sym_always] = ACTIONS(5944),
    [anon_sym_covergroup] = ACTIONS(5944),
    [anon_sym_let] = ACTIONS(5944),
    [anon_sym_pulldown] = ACTIONS(5944),
    [anon_sym_pullup] = ACTIONS(5944),
    [anon_sym_cmos] = ACTIONS(5944),
    [anon_sym_rcmos] = ACTIONS(5944),
    [anon_sym_bufif0] = ACTIONS(5944),
    [anon_sym_bufif1] = ACTIONS(5944),
    [anon_sym_notif0] = ACTIONS(5944),
    [anon_sym_notif1] = ACTIONS(5944),
    [anon_sym_nmos] = ACTIONS(5944),
    [anon_sym_pmos] = ACTIONS(5944),
    [anon_sym_rnmos] = ACTIONS(5944),
    [anon_sym_rpmos] = ACTIONS(5944),
    [anon_sym_nand] = ACTIONS(5944),
    [anon_sym_nor] = ACTIONS(5944),
    [anon_sym_xor] = ACTIONS(5944),
    [anon_sym_xnor] = ACTIONS(5944),
    [anon_sym_buf] = ACTIONS(5944),
    [anon_sym_tranif0] = ACTIONS(5944),
    [anon_sym_tranif1] = ACTIONS(5944),
    [anon_sym_rtranif1] = ACTIONS(5944),
    [anon_sym_rtranif0] = ACTIONS(5944),
    [anon_sym_tran] = ACTIONS(5944),
    [anon_sym_rtran] = ACTIONS(5944),
    [anon_sym_generate] = ACTIONS(5944),
    [anon_sym_for] = ACTIONS(5944),
    [anon_sym_primitive] = ACTIONS(5944),
    [anon_sym_initial] = ACTIONS(5944),
    [anon_sym_assign] = ACTIONS(5944),
    [anon_sym_alias] = ACTIONS(5944),
    [anon_sym_always_comb] = ACTIONS(5944),
    [anon_sym_always_latch] = ACTIONS(5944),
    [anon_sym_always_ff] = ACTIONS(5944),
    [anon_sym_final] = ACTIONS(5944),
    [anon_sym_global] = ACTIONS(5944),
    [anon_sym_specify] = ACTIONS(5944),
    [anon_sym_LPAREN_STAR] = ACTIONS(5942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5942),
    [anon_sym_DOLLARunit] = ACTIONS(5942),
  },
  [1061] = {
    [sym_simple_identifier] = ACTIONS(5946),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5948),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5948),
    [anon_sym_BQUOTE] = ACTIONS(5946),
    [aux_sym_id_directive_token1] = ACTIONS(5948),
    [aux_sym_id_directive_token2] = ACTIONS(5948),
    [aux_sym_id_directive_token3] = ACTIONS(5948),
    [aux_sym_id_directive_token4] = ACTIONS(5946),
    [aux_sym_zero_directive_token1] = ACTIONS(5948),
    [aux_sym_zero_directive_token2] = ACTIONS(5948),
    [aux_sym_zero_directive_token3] = ACTIONS(5948),
    [aux_sym_zero_directive_token4] = ACTIONS(5948),
    [aux_sym_zero_directive_token5] = ACTIONS(5948),
    [aux_sym_zero_directive_token6] = ACTIONS(5948),
    [aux_sym_zero_directive_token7] = ACTIONS(5948),
    [aux_sym_zero_directive_token8] = ACTIONS(5948),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5948),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5948),
    [anon_sym_wire] = ACTIONS(5946),
    [anon_sym_tri] = ACTIONS(5946),
    [anon_sym_tri0] = ACTIONS(5946),
    [anon_sym_tri1] = ACTIONS(5946),
    [anon_sym_wand] = ACTIONS(5946),
    [anon_sym_triand] = ACTIONS(5946),
    [anon_sym_wor] = ACTIONS(5946),
    [anon_sym_trior] = ACTIONS(5946),
    [anon_sym_trireg] = ACTIONS(5946),
    [anon_sym_uwire] = ACTIONS(5946),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5948),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5948),
    [aux_sym_begin_keywords_token1] = ACTIONS(5948),
    [anon_sym_SEMI] = ACTIONS(5948),
    [anon_sym_endmodule] = ACTIONS(5946),
    [anon_sym_extern] = ACTIONS(5946),
    [anon_sym_module] = ACTIONS(5946),
    [anon_sym_macromodule] = ACTIONS(5946),
    [anon_sym_endinterface] = ACTIONS(5946),
    [anon_sym_interface] = ACTIONS(5946),
    [anon_sym_endprogram] = ACTIONS(5946),
    [anon_sym_program] = ACTIONS(5946),
    [anon_sym_checker] = ACTIONS(5946),
    [anon_sym_virtual] = ACTIONS(5946),
    [anon_sym_class] = ACTIONS(5946),
    [anon_sym_timeunit] = ACTIONS(5946),
    [anon_sym_timeprecision] = ACTIONS(5946),
    [anon_sym_type] = ACTIONS(5946),
    [anon_sym_input] = ACTIONS(5946),
    [anon_sym_output] = ACTIONS(5946),
    [anon_sym_inout] = ACTIONS(5946),
    [anon_sym_ref] = ACTIONS(5946),
    [anon_sym_DOLLARfatal] = ACTIONS(5948),
    [anon_sym_DOLLARerror] = ACTIONS(5948),
    [anon_sym_DOLLARwarning] = ACTIONS(5948),
    [anon_sym_DOLLARinfo] = ACTIONS(5948),
    [anon_sym_default] = ACTIONS(5946),
    [anon_sym_clocking] = ACTIONS(5946),
    [anon_sym_defparam] = ACTIONS(5946),
    [anon_sym_bind] = ACTIONS(5946),
    [anon_sym_const] = ACTIONS(5946),
    [anon_sym_function] = ACTIONS(5946),
    [anon_sym_static] = ACTIONS(5946),
    [anon_sym_constraint] = ACTIONS(5946),
    [anon_sym_if] = ACTIONS(5946),
    [anon_sym_else] = ACTIONS(5946),
    [anon_sym_LBRACK] = ACTIONS(5948),
    [anon_sym_localparam] = ACTIONS(5946),
    [anon_sym_parameter] = ACTIONS(5946),
    [anon_sym_specparam] = ACTIONS(5946),
    [anon_sym_var] = ACTIONS(5946),
    [anon_sym_import] = ACTIONS(5946),
    [anon_sym_export] = ACTIONS(5946),
    [anon_sym_genvar] = ACTIONS(5946),
    [anon_sym_interconnect] = ACTIONS(5946),
    [anon_sym_typedef] = ACTIONS(5946),
    [anon_sym_enum] = ACTIONS(5946),
    [anon_sym_struct] = ACTIONS(5946),
    [anon_sym_union] = ACTIONS(5946),
    [anon_sym_nettype] = ACTIONS(5946),
    [anon_sym_automatic] = ACTIONS(5946),
    [anon_sym_string] = ACTIONS(5946),
    [anon_sym_chandle] = ACTIONS(5946),
    [anon_sym_event] = ACTIONS(5946),
    [anon_sym_byte] = ACTIONS(5946),
    [anon_sym_shortint] = ACTIONS(5946),
    [anon_sym_int] = ACTIONS(5946),
    [anon_sym_longint] = ACTIONS(5946),
    [anon_sym_integer] = ACTIONS(5946),
    [anon_sym_time] = ACTIONS(5946),
    [anon_sym_bit] = ACTIONS(5946),
    [anon_sym_logic] = ACTIONS(5946),
    [anon_sym_reg] = ACTIONS(5946),
    [anon_sym_shortreal] = ACTIONS(5946),
    [anon_sym_real] = ACTIONS(5946),
    [anon_sym_realtime] = ACTIONS(5946),
    [anon_sym_supply0] = ACTIONS(5946),
    [anon_sym_supply1] = ACTIONS(5946),
    [anon_sym_signed] = ACTIONS(5946),
    [anon_sym_unsigned] = ACTIONS(5946),
    [anon_sym_task] = ACTIONS(5946),
    [anon_sym_modport] = ACTIONS(5946),
    [anon_sym_assert] = ACTIONS(5946),
    [anon_sym_property] = ACTIONS(5946),
    [anon_sym_assume] = ACTIONS(5946),
    [anon_sym_cover] = ACTIONS(5946),
    [anon_sym_sequence] = ACTIONS(5946),
    [anon_sym_restrict] = ACTIONS(5946),
    [anon_sym_not] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_case] = ACTIONS(5946),
    [anon_sym_always] = ACTIONS(5946),
    [anon_sym_covergroup] = ACTIONS(5946),
    [anon_sym_let] = ACTIONS(5946),
    [anon_sym_pulldown] = ACTIONS(5946),
    [anon_sym_pullup] = ACTIONS(5946),
    [anon_sym_cmos] = ACTIONS(5946),
    [anon_sym_rcmos] = ACTIONS(5946),
    [anon_sym_bufif0] = ACTIONS(5946),
    [anon_sym_bufif1] = ACTIONS(5946),
    [anon_sym_notif0] = ACTIONS(5946),
    [anon_sym_notif1] = ACTIONS(5946),
    [anon_sym_nmos] = ACTIONS(5946),
    [anon_sym_pmos] = ACTIONS(5946),
    [anon_sym_rnmos] = ACTIONS(5946),
    [anon_sym_rpmos] = ACTIONS(5946),
    [anon_sym_nand] = ACTIONS(5946),
    [anon_sym_nor] = ACTIONS(5946),
    [anon_sym_xor] = ACTIONS(5946),
    [anon_sym_xnor] = ACTIONS(5946),
    [anon_sym_buf] = ACTIONS(5946),
    [anon_sym_tranif0] = ACTIONS(5946),
    [anon_sym_tranif1] = ACTIONS(5946),
    [anon_sym_rtranif1] = ACTIONS(5946),
    [anon_sym_rtranif0] = ACTIONS(5946),
    [anon_sym_tran] = ACTIONS(5946),
    [anon_sym_rtran] = ACTIONS(5946),
    [anon_sym_generate] = ACTIONS(5946),
    [anon_sym_for] = ACTIONS(5946),
    [anon_sym_initial] = ACTIONS(5946),
    [anon_sym_assign] = ACTIONS(5946),
    [anon_sym_alias] = ACTIONS(5946),
    [anon_sym_always_comb] = ACTIONS(5946),
    [anon_sym_always_latch] = ACTIONS(5946),
    [anon_sym_always_ff] = ACTIONS(5946),
    [anon_sym_final] = ACTIONS(5946),
    [anon_sym_while] = ACTIONS(5946),
    [anon_sym_global] = ACTIONS(5946),
    [anon_sym_specify] = ACTIONS(5946),
    [anon_sym_LPAREN_STAR] = ACTIONS(5948),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5948),
    [anon_sym_DOLLARunit] = ACTIONS(5948),
  },
  [1062] = {
    [sym_simple_identifier] = ACTIONS(5950),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5952),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5952),
    [anon_sym_BQUOTE] = ACTIONS(5950),
    [aux_sym_id_directive_token1] = ACTIONS(5952),
    [aux_sym_id_directive_token2] = ACTIONS(5952),
    [aux_sym_id_directive_token3] = ACTIONS(5952),
    [aux_sym_id_directive_token4] = ACTIONS(5950),
    [aux_sym_zero_directive_token1] = ACTIONS(5952),
    [aux_sym_zero_directive_token2] = ACTIONS(5952),
    [aux_sym_zero_directive_token3] = ACTIONS(5952),
    [aux_sym_zero_directive_token4] = ACTIONS(5952),
    [aux_sym_zero_directive_token5] = ACTIONS(5952),
    [aux_sym_zero_directive_token6] = ACTIONS(5952),
    [aux_sym_zero_directive_token7] = ACTIONS(5952),
    [aux_sym_zero_directive_token8] = ACTIONS(5952),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5952),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5952),
    [anon_sym_wire] = ACTIONS(5950),
    [anon_sym_tri] = ACTIONS(5950),
    [anon_sym_tri0] = ACTIONS(5950),
    [anon_sym_tri1] = ACTIONS(5950),
    [anon_sym_wand] = ACTIONS(5950),
    [anon_sym_triand] = ACTIONS(5950),
    [anon_sym_wor] = ACTIONS(5950),
    [anon_sym_trior] = ACTIONS(5950),
    [anon_sym_trireg] = ACTIONS(5950),
    [anon_sym_uwire] = ACTIONS(5950),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5952),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5952),
    [aux_sym_begin_keywords_token1] = ACTIONS(5952),
    [anon_sym_SEMI] = ACTIONS(5952),
    [anon_sym_endmodule] = ACTIONS(5950),
    [anon_sym_extern] = ACTIONS(5950),
    [anon_sym_module] = ACTIONS(5950),
    [anon_sym_macromodule] = ACTIONS(5950),
    [anon_sym_endinterface] = ACTIONS(5950),
    [anon_sym_interface] = ACTIONS(5950),
    [anon_sym_endprogram] = ACTIONS(5950),
    [anon_sym_program] = ACTIONS(5950),
    [anon_sym_checker] = ACTIONS(5950),
    [anon_sym_virtual] = ACTIONS(5950),
    [anon_sym_class] = ACTIONS(5950),
    [anon_sym_timeunit] = ACTIONS(5950),
    [anon_sym_timeprecision] = ACTIONS(5950),
    [anon_sym_type] = ACTIONS(5950),
    [anon_sym_input] = ACTIONS(5950),
    [anon_sym_output] = ACTIONS(5950),
    [anon_sym_inout] = ACTIONS(5950),
    [anon_sym_ref] = ACTIONS(5950),
    [anon_sym_DOLLARfatal] = ACTIONS(5952),
    [anon_sym_DOLLARerror] = ACTIONS(5952),
    [anon_sym_DOLLARwarning] = ACTIONS(5952),
    [anon_sym_DOLLARinfo] = ACTIONS(5952),
    [anon_sym_default] = ACTIONS(5950),
    [anon_sym_clocking] = ACTIONS(5950),
    [anon_sym_defparam] = ACTIONS(5950),
    [anon_sym_bind] = ACTIONS(5950),
    [anon_sym_const] = ACTIONS(5950),
    [anon_sym_function] = ACTIONS(5950),
    [anon_sym_static] = ACTIONS(5950),
    [anon_sym_constraint] = ACTIONS(5950),
    [anon_sym_if] = ACTIONS(5950),
    [anon_sym_else] = ACTIONS(5950),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_localparam] = ACTIONS(5950),
    [anon_sym_parameter] = ACTIONS(5950),
    [anon_sym_specparam] = ACTIONS(5950),
    [anon_sym_var] = ACTIONS(5950),
    [anon_sym_import] = ACTIONS(5950),
    [anon_sym_export] = ACTIONS(5950),
    [anon_sym_genvar] = ACTIONS(5950),
    [anon_sym_interconnect] = ACTIONS(5950),
    [anon_sym_typedef] = ACTIONS(5950),
    [anon_sym_enum] = ACTIONS(5950),
    [anon_sym_struct] = ACTIONS(5950),
    [anon_sym_union] = ACTIONS(5950),
    [anon_sym_nettype] = ACTIONS(5950),
    [anon_sym_automatic] = ACTIONS(5950),
    [anon_sym_string] = ACTIONS(5950),
    [anon_sym_chandle] = ACTIONS(5950),
    [anon_sym_event] = ACTIONS(5950),
    [anon_sym_byte] = ACTIONS(5950),
    [anon_sym_shortint] = ACTIONS(5950),
    [anon_sym_int] = ACTIONS(5950),
    [anon_sym_longint] = ACTIONS(5950),
    [anon_sym_integer] = ACTIONS(5950),
    [anon_sym_time] = ACTIONS(5950),
    [anon_sym_bit] = ACTIONS(5950),
    [anon_sym_logic] = ACTIONS(5950),
    [anon_sym_reg] = ACTIONS(5950),
    [anon_sym_shortreal] = ACTIONS(5950),
    [anon_sym_real] = ACTIONS(5950),
    [anon_sym_realtime] = ACTIONS(5950),
    [anon_sym_supply0] = ACTIONS(5950),
    [anon_sym_supply1] = ACTIONS(5950),
    [anon_sym_signed] = ACTIONS(5950),
    [anon_sym_unsigned] = ACTIONS(5950),
    [anon_sym_task] = ACTIONS(5950),
    [anon_sym_modport] = ACTIONS(5950),
    [anon_sym_assert] = ACTIONS(5950),
    [anon_sym_property] = ACTIONS(5950),
    [anon_sym_assume] = ACTIONS(5950),
    [anon_sym_cover] = ACTIONS(5950),
    [anon_sym_sequence] = ACTIONS(5950),
    [anon_sym_restrict] = ACTIONS(5950),
    [anon_sym_not] = ACTIONS(5950),
    [anon_sym_or] = ACTIONS(5950),
    [anon_sym_and] = ACTIONS(5950),
    [anon_sym_case] = ACTIONS(5950),
    [anon_sym_always] = ACTIONS(5950),
    [anon_sym_covergroup] = ACTIONS(5950),
    [anon_sym_let] = ACTIONS(5950),
    [anon_sym_pulldown] = ACTIONS(5950),
    [anon_sym_pullup] = ACTIONS(5950),
    [anon_sym_cmos] = ACTIONS(5950),
    [anon_sym_rcmos] = ACTIONS(5950),
    [anon_sym_bufif0] = ACTIONS(5950),
    [anon_sym_bufif1] = ACTIONS(5950),
    [anon_sym_notif0] = ACTIONS(5950),
    [anon_sym_notif1] = ACTIONS(5950),
    [anon_sym_nmos] = ACTIONS(5950),
    [anon_sym_pmos] = ACTIONS(5950),
    [anon_sym_rnmos] = ACTIONS(5950),
    [anon_sym_rpmos] = ACTIONS(5950),
    [anon_sym_nand] = ACTIONS(5950),
    [anon_sym_nor] = ACTIONS(5950),
    [anon_sym_xor] = ACTIONS(5950),
    [anon_sym_xnor] = ACTIONS(5950),
    [anon_sym_buf] = ACTIONS(5950),
    [anon_sym_tranif0] = ACTIONS(5950),
    [anon_sym_tranif1] = ACTIONS(5950),
    [anon_sym_rtranif1] = ACTIONS(5950),
    [anon_sym_rtranif0] = ACTIONS(5950),
    [anon_sym_tran] = ACTIONS(5950),
    [anon_sym_rtran] = ACTIONS(5950),
    [anon_sym_generate] = ACTIONS(5950),
    [anon_sym_for] = ACTIONS(5950),
    [anon_sym_initial] = ACTIONS(5950),
    [anon_sym_assign] = ACTIONS(5950),
    [anon_sym_alias] = ACTIONS(5950),
    [anon_sym_always_comb] = ACTIONS(5950),
    [anon_sym_always_latch] = ACTIONS(5950),
    [anon_sym_always_ff] = ACTIONS(5950),
    [anon_sym_final] = ACTIONS(5950),
    [anon_sym_while] = ACTIONS(5950),
    [anon_sym_global] = ACTIONS(5950),
    [anon_sym_specify] = ACTIONS(5950),
    [anon_sym_LPAREN_STAR] = ACTIONS(5952),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5952),
    [anon_sym_DOLLARunit] = ACTIONS(5952),
  },
  [1063] = {
    [ts_builtin_sym_end] = ACTIONS(5954),
    [sym_simple_identifier] = ACTIONS(5956),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5954),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5954),
    [anon_sym_BQUOTE] = ACTIONS(5956),
    [aux_sym_id_directive_token1] = ACTIONS(5954),
    [aux_sym_id_directive_token2] = ACTIONS(5954),
    [aux_sym_id_directive_token3] = ACTIONS(5954),
    [aux_sym_id_directive_token4] = ACTIONS(5956),
    [aux_sym_zero_directive_token1] = ACTIONS(5954),
    [aux_sym_zero_directive_token2] = ACTIONS(5954),
    [aux_sym_zero_directive_token3] = ACTIONS(5954),
    [aux_sym_zero_directive_token4] = ACTIONS(5954),
    [aux_sym_zero_directive_token5] = ACTIONS(5954),
    [aux_sym_zero_directive_token6] = ACTIONS(5954),
    [aux_sym_zero_directive_token7] = ACTIONS(5954),
    [aux_sym_zero_directive_token8] = ACTIONS(5954),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5954),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5954),
    [anon_sym_wire] = ACTIONS(5956),
    [anon_sym_tri] = ACTIONS(5956),
    [anon_sym_tri0] = ACTIONS(5956),
    [anon_sym_tri1] = ACTIONS(5956),
    [anon_sym_wand] = ACTIONS(5956),
    [anon_sym_triand] = ACTIONS(5956),
    [anon_sym_wor] = ACTIONS(5956),
    [anon_sym_trior] = ACTIONS(5956),
    [anon_sym_trireg] = ACTIONS(5956),
    [anon_sym_uwire] = ACTIONS(5956),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5954),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5954),
    [aux_sym_begin_keywords_token1] = ACTIONS(5954),
    [anon_sym_SEMI] = ACTIONS(5954),
    [anon_sym_endmodule] = ACTIONS(5956),
    [anon_sym_extern] = ACTIONS(5956),
    [anon_sym_module] = ACTIONS(5956),
    [anon_sym_macromodule] = ACTIONS(5956),
    [anon_sym_endinterface] = ACTIONS(5956),
    [anon_sym_interface] = ACTIONS(5956),
    [anon_sym_program] = ACTIONS(5956),
    [anon_sym_checker] = ACTIONS(5956),
    [anon_sym_virtual] = ACTIONS(5956),
    [anon_sym_class] = ACTIONS(5956),
    [anon_sym_package] = ACTIONS(5956),
    [anon_sym_timeunit] = ACTIONS(5956),
    [anon_sym_timeprecision] = ACTIONS(5956),
    [anon_sym_type] = ACTIONS(5956),
    [anon_sym_input] = ACTIONS(5956),
    [anon_sym_output] = ACTIONS(5956),
    [anon_sym_inout] = ACTIONS(5956),
    [anon_sym_ref] = ACTIONS(5956),
    [anon_sym_DOLLARfatal] = ACTIONS(5954),
    [anon_sym_DOLLARerror] = ACTIONS(5954),
    [anon_sym_DOLLARwarning] = ACTIONS(5954),
    [anon_sym_DOLLARinfo] = ACTIONS(5954),
    [anon_sym_default] = ACTIONS(5956),
    [anon_sym_clocking] = ACTIONS(5956),
    [anon_sym_defparam] = ACTIONS(5956),
    [anon_sym_bind] = ACTIONS(5956),
    [anon_sym_const] = ACTIONS(5956),
    [anon_sym_function] = ACTIONS(5956),
    [anon_sym_static] = ACTIONS(5956),
    [anon_sym_constraint] = ACTIONS(5956),
    [anon_sym_if] = ACTIONS(5956),
    [anon_sym_LBRACK] = ACTIONS(5954),
    [anon_sym_localparam] = ACTIONS(5956),
    [anon_sym_parameter] = ACTIONS(5956),
    [anon_sym_specparam] = ACTIONS(5956),
    [anon_sym_var] = ACTIONS(5956),
    [anon_sym_import] = ACTIONS(5956),
    [anon_sym_export] = ACTIONS(5956),
    [anon_sym_genvar] = ACTIONS(5956),
    [anon_sym_interconnect] = ACTIONS(5956),
    [anon_sym_typedef] = ACTIONS(5956),
    [anon_sym_enum] = ACTIONS(5956),
    [anon_sym_struct] = ACTIONS(5956),
    [anon_sym_union] = ACTIONS(5956),
    [anon_sym_nettype] = ACTIONS(5956),
    [anon_sym_automatic] = ACTIONS(5956),
    [anon_sym_string] = ACTIONS(5956),
    [anon_sym_chandle] = ACTIONS(5956),
    [anon_sym_event] = ACTIONS(5956),
    [anon_sym_byte] = ACTIONS(5956),
    [anon_sym_shortint] = ACTIONS(5956),
    [anon_sym_int] = ACTIONS(5956),
    [anon_sym_longint] = ACTIONS(5956),
    [anon_sym_integer] = ACTIONS(5956),
    [anon_sym_time] = ACTIONS(5956),
    [anon_sym_bit] = ACTIONS(5956),
    [anon_sym_logic] = ACTIONS(5956),
    [anon_sym_reg] = ACTIONS(5956),
    [anon_sym_shortreal] = ACTIONS(5956),
    [anon_sym_real] = ACTIONS(5956),
    [anon_sym_realtime] = ACTIONS(5956),
    [anon_sym_supply0] = ACTIONS(5956),
    [anon_sym_supply1] = ACTIONS(5956),
    [anon_sym_signed] = ACTIONS(5956),
    [anon_sym_unsigned] = ACTIONS(5956),
    [anon_sym_task] = ACTIONS(5956),
    [anon_sym_modport] = ACTIONS(5956),
    [anon_sym_assert] = ACTIONS(5956),
    [anon_sym_property] = ACTIONS(5956),
    [anon_sym_assume] = ACTIONS(5956),
    [anon_sym_cover] = ACTIONS(5956),
    [anon_sym_sequence] = ACTIONS(5956),
    [anon_sym_restrict] = ACTIONS(5956),
    [anon_sym_not] = ACTIONS(5956),
    [anon_sym_or] = ACTIONS(5956),
    [anon_sym_and] = ACTIONS(5956),
    [anon_sym_case] = ACTIONS(5956),
    [anon_sym_always] = ACTIONS(5956),
    [anon_sym_covergroup] = ACTIONS(5956),
    [anon_sym_let] = ACTIONS(5956),
    [anon_sym_pulldown] = ACTIONS(5956),
    [anon_sym_pullup] = ACTIONS(5956),
    [anon_sym_cmos] = ACTIONS(5956),
    [anon_sym_rcmos] = ACTIONS(5956),
    [anon_sym_bufif0] = ACTIONS(5956),
    [anon_sym_bufif1] = ACTIONS(5956),
    [anon_sym_notif0] = ACTIONS(5956),
    [anon_sym_notif1] = ACTIONS(5956),
    [anon_sym_nmos] = ACTIONS(5956),
    [anon_sym_pmos] = ACTIONS(5956),
    [anon_sym_rnmos] = ACTIONS(5956),
    [anon_sym_rpmos] = ACTIONS(5956),
    [anon_sym_nand] = ACTIONS(5956),
    [anon_sym_nor] = ACTIONS(5956),
    [anon_sym_xor] = ACTIONS(5956),
    [anon_sym_xnor] = ACTIONS(5956),
    [anon_sym_buf] = ACTIONS(5956),
    [anon_sym_tranif0] = ACTIONS(5956),
    [anon_sym_tranif1] = ACTIONS(5956),
    [anon_sym_rtranif1] = ACTIONS(5956),
    [anon_sym_rtranif0] = ACTIONS(5956),
    [anon_sym_tran] = ACTIONS(5956),
    [anon_sym_rtran] = ACTIONS(5956),
    [anon_sym_generate] = ACTIONS(5956),
    [anon_sym_for] = ACTIONS(5956),
    [anon_sym_primitive] = ACTIONS(5956),
    [anon_sym_initial] = ACTIONS(5956),
    [anon_sym_assign] = ACTIONS(5956),
    [anon_sym_alias] = ACTIONS(5956),
    [anon_sym_always_comb] = ACTIONS(5956),
    [anon_sym_always_latch] = ACTIONS(5956),
    [anon_sym_always_ff] = ACTIONS(5956),
    [anon_sym_final] = ACTIONS(5956),
    [anon_sym_global] = ACTIONS(5956),
    [anon_sym_specify] = ACTIONS(5956),
    [anon_sym_LPAREN_STAR] = ACTIONS(5954),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5954),
    [anon_sym_DOLLARunit] = ACTIONS(5954),
  },
  [1064] = {
    [sym_simple_identifier] = ACTIONS(5958),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5960),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5960),
    [anon_sym_BQUOTE] = ACTIONS(5958),
    [aux_sym_id_directive_token1] = ACTIONS(5960),
    [aux_sym_id_directive_token2] = ACTIONS(5960),
    [aux_sym_id_directive_token3] = ACTIONS(5960),
    [aux_sym_id_directive_token4] = ACTIONS(5958),
    [aux_sym_zero_directive_token1] = ACTIONS(5960),
    [aux_sym_zero_directive_token2] = ACTIONS(5960),
    [aux_sym_zero_directive_token3] = ACTIONS(5960),
    [aux_sym_zero_directive_token4] = ACTIONS(5960),
    [aux_sym_zero_directive_token5] = ACTIONS(5960),
    [aux_sym_zero_directive_token6] = ACTIONS(5960),
    [aux_sym_zero_directive_token7] = ACTIONS(5960),
    [aux_sym_zero_directive_token8] = ACTIONS(5960),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5960),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5960),
    [anon_sym_wire] = ACTIONS(5958),
    [anon_sym_tri] = ACTIONS(5958),
    [anon_sym_tri0] = ACTIONS(5958),
    [anon_sym_tri1] = ACTIONS(5958),
    [anon_sym_wand] = ACTIONS(5958),
    [anon_sym_triand] = ACTIONS(5958),
    [anon_sym_wor] = ACTIONS(5958),
    [anon_sym_trior] = ACTIONS(5958),
    [anon_sym_trireg] = ACTIONS(5958),
    [anon_sym_uwire] = ACTIONS(5958),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5960),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5960),
    [aux_sym_begin_keywords_token1] = ACTIONS(5960),
    [anon_sym_SEMI] = ACTIONS(5960),
    [anon_sym_endmodule] = ACTIONS(5958),
    [anon_sym_extern] = ACTIONS(5958),
    [anon_sym_module] = ACTIONS(5958),
    [anon_sym_macromodule] = ACTIONS(5958),
    [anon_sym_endinterface] = ACTIONS(5958),
    [anon_sym_interface] = ACTIONS(5958),
    [anon_sym_endprogram] = ACTIONS(5958),
    [anon_sym_program] = ACTIONS(5958),
    [anon_sym_checker] = ACTIONS(5958),
    [anon_sym_virtual] = ACTIONS(5958),
    [anon_sym_class] = ACTIONS(5958),
    [anon_sym_timeunit] = ACTIONS(5958),
    [anon_sym_timeprecision] = ACTIONS(5958),
    [anon_sym_type] = ACTIONS(5958),
    [anon_sym_input] = ACTIONS(5958),
    [anon_sym_output] = ACTIONS(5958),
    [anon_sym_inout] = ACTIONS(5958),
    [anon_sym_ref] = ACTIONS(5958),
    [anon_sym_DOLLARfatal] = ACTIONS(5960),
    [anon_sym_DOLLARerror] = ACTIONS(5960),
    [anon_sym_DOLLARwarning] = ACTIONS(5960),
    [anon_sym_DOLLARinfo] = ACTIONS(5960),
    [anon_sym_default] = ACTIONS(5958),
    [anon_sym_clocking] = ACTIONS(5958),
    [anon_sym_defparam] = ACTIONS(5958),
    [anon_sym_bind] = ACTIONS(5958),
    [anon_sym_const] = ACTIONS(5958),
    [anon_sym_function] = ACTIONS(5958),
    [anon_sym_static] = ACTIONS(5958),
    [anon_sym_constraint] = ACTIONS(5958),
    [anon_sym_if] = ACTIONS(5958),
    [anon_sym_else] = ACTIONS(5958),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_localparam] = ACTIONS(5958),
    [anon_sym_parameter] = ACTIONS(5958),
    [anon_sym_specparam] = ACTIONS(5958),
    [anon_sym_var] = ACTIONS(5958),
    [anon_sym_import] = ACTIONS(5958),
    [anon_sym_export] = ACTIONS(5958),
    [anon_sym_genvar] = ACTIONS(5958),
    [anon_sym_interconnect] = ACTIONS(5958),
    [anon_sym_typedef] = ACTIONS(5958),
    [anon_sym_enum] = ACTIONS(5958),
    [anon_sym_struct] = ACTIONS(5958),
    [anon_sym_union] = ACTIONS(5958),
    [anon_sym_nettype] = ACTIONS(5958),
    [anon_sym_automatic] = ACTIONS(5958),
    [anon_sym_string] = ACTIONS(5958),
    [anon_sym_chandle] = ACTIONS(5958),
    [anon_sym_event] = ACTIONS(5958),
    [anon_sym_byte] = ACTIONS(5958),
    [anon_sym_shortint] = ACTIONS(5958),
    [anon_sym_int] = ACTIONS(5958),
    [anon_sym_longint] = ACTIONS(5958),
    [anon_sym_integer] = ACTIONS(5958),
    [anon_sym_time] = ACTIONS(5958),
    [anon_sym_bit] = ACTIONS(5958),
    [anon_sym_logic] = ACTIONS(5958),
    [anon_sym_reg] = ACTIONS(5958),
    [anon_sym_shortreal] = ACTIONS(5958),
    [anon_sym_real] = ACTIONS(5958),
    [anon_sym_realtime] = ACTIONS(5958),
    [anon_sym_supply0] = ACTIONS(5958),
    [anon_sym_supply1] = ACTIONS(5958),
    [anon_sym_signed] = ACTIONS(5958),
    [anon_sym_unsigned] = ACTIONS(5958),
    [anon_sym_task] = ACTIONS(5958),
    [anon_sym_modport] = ACTIONS(5958),
    [anon_sym_assert] = ACTIONS(5958),
    [anon_sym_property] = ACTIONS(5958),
    [anon_sym_assume] = ACTIONS(5958),
    [anon_sym_cover] = ACTIONS(5958),
    [anon_sym_sequence] = ACTIONS(5958),
    [anon_sym_restrict] = ACTIONS(5958),
    [anon_sym_not] = ACTIONS(5958),
    [anon_sym_or] = ACTIONS(5958),
    [anon_sym_and] = ACTIONS(5958),
    [anon_sym_case] = ACTIONS(5958),
    [anon_sym_always] = ACTIONS(5958),
    [anon_sym_covergroup] = ACTIONS(5958),
    [anon_sym_let] = ACTIONS(5958),
    [anon_sym_pulldown] = ACTIONS(5958),
    [anon_sym_pullup] = ACTIONS(5958),
    [anon_sym_cmos] = ACTIONS(5958),
    [anon_sym_rcmos] = ACTIONS(5958),
    [anon_sym_bufif0] = ACTIONS(5958),
    [anon_sym_bufif1] = ACTIONS(5958),
    [anon_sym_notif0] = ACTIONS(5958),
    [anon_sym_notif1] = ACTIONS(5958),
    [anon_sym_nmos] = ACTIONS(5958),
    [anon_sym_pmos] = ACTIONS(5958),
    [anon_sym_rnmos] = ACTIONS(5958),
    [anon_sym_rpmos] = ACTIONS(5958),
    [anon_sym_nand] = ACTIONS(5958),
    [anon_sym_nor] = ACTIONS(5958),
    [anon_sym_xor] = ACTIONS(5958),
    [anon_sym_xnor] = ACTIONS(5958),
    [anon_sym_buf] = ACTIONS(5958),
    [anon_sym_tranif0] = ACTIONS(5958),
    [anon_sym_tranif1] = ACTIONS(5958),
    [anon_sym_rtranif1] = ACTIONS(5958),
    [anon_sym_rtranif0] = ACTIONS(5958),
    [anon_sym_tran] = ACTIONS(5958),
    [anon_sym_rtran] = ACTIONS(5958),
    [anon_sym_generate] = ACTIONS(5958),
    [anon_sym_for] = ACTIONS(5958),
    [anon_sym_initial] = ACTIONS(5958),
    [anon_sym_assign] = ACTIONS(5958),
    [anon_sym_alias] = ACTIONS(5958),
    [anon_sym_always_comb] = ACTIONS(5958),
    [anon_sym_always_latch] = ACTIONS(5958),
    [anon_sym_always_ff] = ACTIONS(5958),
    [anon_sym_final] = ACTIONS(5958),
    [anon_sym_while] = ACTIONS(5958),
    [anon_sym_global] = ACTIONS(5958),
    [anon_sym_specify] = ACTIONS(5958),
    [anon_sym_LPAREN_STAR] = ACTIONS(5960),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5960),
    [anon_sym_DOLLARunit] = ACTIONS(5960),
  },
  [1065] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5812),
    [anon_sym_BQUOTE] = ACTIONS(5810),
    [aux_sym_id_directive_token1] = ACTIONS(5812),
    [aux_sym_id_directive_token2] = ACTIONS(5812),
    [aux_sym_id_directive_token3] = ACTIONS(5812),
    [aux_sym_id_directive_token4] = ACTIONS(5810),
    [aux_sym_zero_directive_token1] = ACTIONS(5812),
    [aux_sym_zero_directive_token2] = ACTIONS(5812),
    [aux_sym_zero_directive_token3] = ACTIONS(5812),
    [aux_sym_zero_directive_token4] = ACTIONS(5812),
    [aux_sym_zero_directive_token5] = ACTIONS(5812),
    [aux_sym_zero_directive_token6] = ACTIONS(5812),
    [aux_sym_zero_directive_token7] = ACTIONS(5812),
    [aux_sym_zero_directive_token8] = ACTIONS(5812),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5812),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5812),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_begin_keywords_token1] = ACTIONS(5812),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_endmodule] = ACTIONS(5810),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_module] = ACTIONS(5810),
    [anon_sym_macromodule] = ACTIONS(5810),
    [anon_sym_endinterface] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_endprogram] = ACTIONS(5810),
    [anon_sym_program] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_timeunit] = ACTIONS(5810),
    [anon_sym_timeprecision] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_input] = ACTIONS(5810),
    [anon_sym_output] = ACTIONS(5810),
    [anon_sym_inout] = ACTIONS(5810),
    [anon_sym_ref] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(5962),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_specparam] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_modport] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_while] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_specify] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [1066] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5850),
    [anon_sym_BQUOTE] = ACTIONS(5848),
    [aux_sym_id_directive_token1] = ACTIONS(5850),
    [aux_sym_id_directive_token2] = ACTIONS(5850),
    [aux_sym_id_directive_token3] = ACTIONS(5850),
    [aux_sym_id_directive_token4] = ACTIONS(5848),
    [aux_sym_zero_directive_token1] = ACTIONS(5850),
    [aux_sym_zero_directive_token2] = ACTIONS(5850),
    [aux_sym_zero_directive_token3] = ACTIONS(5850),
    [aux_sym_zero_directive_token4] = ACTIONS(5850),
    [aux_sym_zero_directive_token5] = ACTIONS(5850),
    [aux_sym_zero_directive_token6] = ACTIONS(5850),
    [aux_sym_zero_directive_token7] = ACTIONS(5850),
    [aux_sym_zero_directive_token8] = ACTIONS(5850),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5850),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5850),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5850),
    [aux_sym_begin_keywords_token1] = ACTIONS(5850),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_endmodule] = ACTIONS(5848),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_module] = ACTIONS(5848),
    [anon_sym_macromodule] = ACTIONS(5848),
    [anon_sym_endinterface] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_endprogram] = ACTIONS(5848),
    [anon_sym_program] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_timeunit] = ACTIONS(5848),
    [anon_sym_timeprecision] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_input] = ACTIONS(5848),
    [anon_sym_output] = ACTIONS(5848),
    [anon_sym_inout] = ACTIONS(5848),
    [anon_sym_ref] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(5848),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_specparam] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_modport] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_while] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_specify] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [1067] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5967),
    [anon_sym_BQUOTE] = ACTIONS(5965),
    [aux_sym_id_directive_token1] = ACTIONS(5967),
    [aux_sym_id_directive_token2] = ACTIONS(5967),
    [aux_sym_id_directive_token3] = ACTIONS(5967),
    [aux_sym_id_directive_token4] = ACTIONS(5965),
    [aux_sym_zero_directive_token1] = ACTIONS(5967),
    [aux_sym_zero_directive_token2] = ACTIONS(5967),
    [aux_sym_zero_directive_token3] = ACTIONS(5967),
    [aux_sym_zero_directive_token4] = ACTIONS(5967),
    [aux_sym_zero_directive_token5] = ACTIONS(5967),
    [aux_sym_zero_directive_token6] = ACTIONS(5967),
    [aux_sym_zero_directive_token7] = ACTIONS(5967),
    [aux_sym_zero_directive_token8] = ACTIONS(5967),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5967),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5967),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_begin_keywords_token1] = ACTIONS(5967),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_endmodule] = ACTIONS(5965),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_module] = ACTIONS(5965),
    [anon_sym_macromodule] = ACTIONS(5965),
    [anon_sym_endinterface] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_endprogram] = ACTIONS(5965),
    [anon_sym_program] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_timeunit] = ACTIONS(5965),
    [anon_sym_timeprecision] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_input] = ACTIONS(5965),
    [anon_sym_output] = ACTIONS(5965),
    [anon_sym_inout] = ACTIONS(5965),
    [anon_sym_ref] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_specparam] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_modport] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_while] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_specify] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [1068] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9164),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_RBRACE] = ACTIONS(2648),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_COLON_EQ] = ACTIONS(2648),
    [anon_sym_COLON_SLASH] = ACTIONS(2648),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [1069] = {
    [sym_simple_identifier] = ACTIONS(6011),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6013),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6013),
    [anon_sym_BQUOTE] = ACTIONS(6011),
    [aux_sym_id_directive_token1] = ACTIONS(6013),
    [aux_sym_id_directive_token2] = ACTIONS(6013),
    [aux_sym_id_directive_token3] = ACTIONS(6013),
    [aux_sym_id_directive_token4] = ACTIONS(6011),
    [aux_sym_zero_directive_token1] = ACTIONS(6013),
    [aux_sym_zero_directive_token2] = ACTIONS(6013),
    [aux_sym_zero_directive_token3] = ACTIONS(6013),
    [aux_sym_zero_directive_token4] = ACTIONS(6013),
    [aux_sym_zero_directive_token5] = ACTIONS(6013),
    [aux_sym_zero_directive_token6] = ACTIONS(6013),
    [aux_sym_zero_directive_token7] = ACTIONS(6013),
    [aux_sym_zero_directive_token8] = ACTIONS(6013),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6013),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6013),
    [anon_sym_wire] = ACTIONS(6011),
    [anon_sym_tri] = ACTIONS(6011),
    [anon_sym_tri0] = ACTIONS(6011),
    [anon_sym_tri1] = ACTIONS(6011),
    [anon_sym_wand] = ACTIONS(6011),
    [anon_sym_triand] = ACTIONS(6011),
    [anon_sym_wor] = ACTIONS(6011),
    [anon_sym_trior] = ACTIONS(6011),
    [anon_sym_trireg] = ACTIONS(6011),
    [anon_sym_uwire] = ACTIONS(6011),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6013),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6013),
    [aux_sym_begin_keywords_token1] = ACTIONS(6013),
    [anon_sym_SEMI] = ACTIONS(6013),
    [anon_sym_endmodule] = ACTIONS(6011),
    [anon_sym_extern] = ACTIONS(6011),
    [anon_sym_module] = ACTIONS(6011),
    [anon_sym_macromodule] = ACTIONS(6011),
    [anon_sym_endinterface] = ACTIONS(6011),
    [anon_sym_interface] = ACTIONS(6011),
    [anon_sym_endprogram] = ACTIONS(6011),
    [anon_sym_program] = ACTIONS(6011),
    [anon_sym_checker] = ACTIONS(6011),
    [anon_sym_virtual] = ACTIONS(6011),
    [anon_sym_class] = ACTIONS(6011),
    [anon_sym_timeunit] = ACTIONS(6011),
    [anon_sym_timeprecision] = ACTIONS(6011),
    [anon_sym_type] = ACTIONS(6011),
    [anon_sym_input] = ACTIONS(6011),
    [anon_sym_output] = ACTIONS(6011),
    [anon_sym_inout] = ACTIONS(6011),
    [anon_sym_ref] = ACTIONS(6011),
    [anon_sym_DOLLARfatal] = ACTIONS(6013),
    [anon_sym_DOLLARerror] = ACTIONS(6013),
    [anon_sym_DOLLARwarning] = ACTIONS(6013),
    [anon_sym_DOLLARinfo] = ACTIONS(6013),
    [anon_sym_default] = ACTIONS(6011),
    [anon_sym_clocking] = ACTIONS(6011),
    [anon_sym_defparam] = ACTIONS(6011),
    [anon_sym_bind] = ACTIONS(6011),
    [anon_sym_const] = ACTIONS(6011),
    [anon_sym_function] = ACTIONS(6011),
    [anon_sym_static] = ACTIONS(6011),
    [anon_sym_constraint] = ACTIONS(6011),
    [anon_sym_if] = ACTIONS(6011),
    [anon_sym_else] = ACTIONS(6011),
    [anon_sym_LBRACK] = ACTIONS(6013),
    [anon_sym_localparam] = ACTIONS(6011),
    [anon_sym_parameter] = ACTIONS(6011),
    [anon_sym_specparam] = ACTIONS(6011),
    [anon_sym_var] = ACTIONS(6011),
    [anon_sym_import] = ACTIONS(6011),
    [anon_sym_export] = ACTIONS(6011),
    [anon_sym_genvar] = ACTIONS(6011),
    [anon_sym_interconnect] = ACTIONS(6011),
    [anon_sym_typedef] = ACTIONS(6011),
    [anon_sym_enum] = ACTIONS(6011),
    [anon_sym_struct] = ACTIONS(6011),
    [anon_sym_union] = ACTIONS(6011),
    [anon_sym_nettype] = ACTIONS(6011),
    [anon_sym_automatic] = ACTIONS(6011),
    [anon_sym_string] = ACTIONS(6011),
    [anon_sym_chandle] = ACTIONS(6011),
    [anon_sym_event] = ACTIONS(6011),
    [anon_sym_byte] = ACTIONS(6011),
    [anon_sym_shortint] = ACTIONS(6011),
    [anon_sym_int] = ACTIONS(6011),
    [anon_sym_longint] = ACTIONS(6011),
    [anon_sym_integer] = ACTIONS(6011),
    [anon_sym_time] = ACTIONS(6011),
    [anon_sym_bit] = ACTIONS(6011),
    [anon_sym_logic] = ACTIONS(6011),
    [anon_sym_reg] = ACTIONS(6011),
    [anon_sym_shortreal] = ACTIONS(6011),
    [anon_sym_real] = ACTIONS(6011),
    [anon_sym_realtime] = ACTIONS(6011),
    [anon_sym_supply0] = ACTIONS(6011),
    [anon_sym_supply1] = ACTIONS(6011),
    [anon_sym_signed] = ACTIONS(6011),
    [anon_sym_unsigned] = ACTIONS(6011),
    [anon_sym_task] = ACTIONS(6011),
    [anon_sym_modport] = ACTIONS(6011),
    [anon_sym_assert] = ACTIONS(6011),
    [anon_sym_property] = ACTIONS(6011),
    [anon_sym_assume] = ACTIONS(6011),
    [anon_sym_cover] = ACTIONS(6011),
    [anon_sym_sequence] = ACTIONS(6011),
    [anon_sym_restrict] = ACTIONS(6011),
    [anon_sym_not] = ACTIONS(6011),
    [anon_sym_or] = ACTIONS(6011),
    [anon_sym_and] = ACTIONS(6011),
    [anon_sym_case] = ACTIONS(6011),
    [anon_sym_always] = ACTIONS(6011),
    [anon_sym_covergroup] = ACTIONS(6011),
    [anon_sym_let] = ACTIONS(6011),
    [anon_sym_pulldown] = ACTIONS(6011),
    [anon_sym_pullup] = ACTIONS(6011),
    [anon_sym_cmos] = ACTIONS(6011),
    [anon_sym_rcmos] = ACTIONS(6011),
    [anon_sym_bufif0] = ACTIONS(6011),
    [anon_sym_bufif1] = ACTIONS(6011),
    [anon_sym_notif0] = ACTIONS(6011),
    [anon_sym_notif1] = ACTIONS(6011),
    [anon_sym_nmos] = ACTIONS(6011),
    [anon_sym_pmos] = ACTIONS(6011),
    [anon_sym_rnmos] = ACTIONS(6011),
    [anon_sym_rpmos] = ACTIONS(6011),
    [anon_sym_nand] = ACTIONS(6011),
    [anon_sym_nor] = ACTIONS(6011),
    [anon_sym_xor] = ACTIONS(6011),
    [anon_sym_xnor] = ACTIONS(6011),
    [anon_sym_buf] = ACTIONS(6011),
    [anon_sym_tranif0] = ACTIONS(6011),
    [anon_sym_tranif1] = ACTIONS(6011),
    [anon_sym_rtranif1] = ACTIONS(6011),
    [anon_sym_rtranif0] = ACTIONS(6011),
    [anon_sym_tran] = ACTIONS(6011),
    [anon_sym_rtran] = ACTIONS(6011),
    [anon_sym_generate] = ACTIONS(6011),
    [anon_sym_for] = ACTIONS(6011),
    [anon_sym_initial] = ACTIONS(6011),
    [anon_sym_assign] = ACTIONS(6011),
    [anon_sym_alias] = ACTIONS(6011),
    [anon_sym_always_comb] = ACTIONS(6011),
    [anon_sym_always_latch] = ACTIONS(6011),
    [anon_sym_always_ff] = ACTIONS(6011),
    [anon_sym_final] = ACTIONS(6011),
    [anon_sym_while] = ACTIONS(6011),
    [anon_sym_global] = ACTIONS(6011),
    [anon_sym_specify] = ACTIONS(6011),
    [anon_sym_LPAREN_STAR] = ACTIONS(6013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6013),
    [anon_sym_DOLLARunit] = ACTIONS(6013),
  },
  [1070] = {
    [sym_simple_identifier] = ACTIONS(6015),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6017),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6017),
    [anon_sym_BQUOTE] = ACTIONS(6015),
    [aux_sym_id_directive_token1] = ACTIONS(6017),
    [aux_sym_id_directive_token2] = ACTIONS(6017),
    [aux_sym_id_directive_token3] = ACTIONS(6017),
    [aux_sym_id_directive_token4] = ACTIONS(6015),
    [aux_sym_zero_directive_token1] = ACTIONS(6017),
    [aux_sym_zero_directive_token2] = ACTIONS(6017),
    [aux_sym_zero_directive_token3] = ACTIONS(6017),
    [aux_sym_zero_directive_token4] = ACTIONS(6017),
    [aux_sym_zero_directive_token5] = ACTIONS(6017),
    [aux_sym_zero_directive_token6] = ACTIONS(6017),
    [aux_sym_zero_directive_token7] = ACTIONS(6017),
    [aux_sym_zero_directive_token8] = ACTIONS(6017),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6017),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6017),
    [anon_sym_wire] = ACTIONS(6015),
    [anon_sym_tri] = ACTIONS(6015),
    [anon_sym_tri0] = ACTIONS(6015),
    [anon_sym_tri1] = ACTIONS(6015),
    [anon_sym_wand] = ACTIONS(6015),
    [anon_sym_triand] = ACTIONS(6015),
    [anon_sym_wor] = ACTIONS(6015),
    [anon_sym_trior] = ACTIONS(6015),
    [anon_sym_trireg] = ACTIONS(6015),
    [anon_sym_uwire] = ACTIONS(6015),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6017),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6017),
    [aux_sym_begin_keywords_token1] = ACTIONS(6017),
    [anon_sym_SEMI] = ACTIONS(6017),
    [anon_sym_endmodule] = ACTIONS(6015),
    [anon_sym_extern] = ACTIONS(6015),
    [anon_sym_module] = ACTIONS(6015),
    [anon_sym_macromodule] = ACTIONS(6015),
    [anon_sym_endinterface] = ACTIONS(6015),
    [anon_sym_interface] = ACTIONS(6015),
    [anon_sym_endprogram] = ACTIONS(6015),
    [anon_sym_program] = ACTIONS(6015),
    [anon_sym_checker] = ACTIONS(6015),
    [anon_sym_virtual] = ACTIONS(6015),
    [anon_sym_class] = ACTIONS(6015),
    [anon_sym_timeunit] = ACTIONS(6015),
    [anon_sym_timeprecision] = ACTIONS(6015),
    [anon_sym_type] = ACTIONS(6015),
    [anon_sym_input] = ACTIONS(6015),
    [anon_sym_output] = ACTIONS(6015),
    [anon_sym_inout] = ACTIONS(6015),
    [anon_sym_ref] = ACTIONS(6015),
    [anon_sym_DOLLARfatal] = ACTIONS(6017),
    [anon_sym_DOLLARerror] = ACTIONS(6017),
    [anon_sym_DOLLARwarning] = ACTIONS(6017),
    [anon_sym_DOLLARinfo] = ACTIONS(6017),
    [anon_sym_default] = ACTIONS(6015),
    [anon_sym_clocking] = ACTIONS(6015),
    [anon_sym_defparam] = ACTIONS(6015),
    [anon_sym_bind] = ACTIONS(6015),
    [anon_sym_const] = ACTIONS(6015),
    [anon_sym_function] = ACTIONS(6015),
    [anon_sym_static] = ACTIONS(6015),
    [anon_sym_constraint] = ACTIONS(6015),
    [anon_sym_if] = ACTIONS(6015),
    [anon_sym_else] = ACTIONS(6015),
    [anon_sym_LBRACK] = ACTIONS(6017),
    [anon_sym_localparam] = ACTIONS(6015),
    [anon_sym_parameter] = ACTIONS(6015),
    [anon_sym_specparam] = ACTIONS(6015),
    [anon_sym_var] = ACTIONS(6015),
    [anon_sym_import] = ACTIONS(6015),
    [anon_sym_export] = ACTIONS(6015),
    [anon_sym_genvar] = ACTIONS(6015),
    [anon_sym_interconnect] = ACTIONS(6015),
    [anon_sym_typedef] = ACTIONS(6015),
    [anon_sym_enum] = ACTIONS(6015),
    [anon_sym_struct] = ACTIONS(6015),
    [anon_sym_union] = ACTIONS(6015),
    [anon_sym_nettype] = ACTIONS(6015),
    [anon_sym_automatic] = ACTIONS(6015),
    [anon_sym_string] = ACTIONS(6015),
    [anon_sym_chandle] = ACTIONS(6015),
    [anon_sym_event] = ACTIONS(6015),
    [anon_sym_byte] = ACTIONS(6015),
    [anon_sym_shortint] = ACTIONS(6015),
    [anon_sym_int] = ACTIONS(6015),
    [anon_sym_longint] = ACTIONS(6015),
    [anon_sym_integer] = ACTIONS(6015),
    [anon_sym_time] = ACTIONS(6015),
    [anon_sym_bit] = ACTIONS(6015),
    [anon_sym_logic] = ACTIONS(6015),
    [anon_sym_reg] = ACTIONS(6015),
    [anon_sym_shortreal] = ACTIONS(6015),
    [anon_sym_real] = ACTIONS(6015),
    [anon_sym_realtime] = ACTIONS(6015),
    [anon_sym_supply0] = ACTIONS(6015),
    [anon_sym_supply1] = ACTIONS(6015),
    [anon_sym_signed] = ACTIONS(6015),
    [anon_sym_unsigned] = ACTIONS(6015),
    [anon_sym_task] = ACTIONS(6015),
    [anon_sym_modport] = ACTIONS(6015),
    [anon_sym_assert] = ACTIONS(6015),
    [anon_sym_property] = ACTIONS(6015),
    [anon_sym_assume] = ACTIONS(6015),
    [anon_sym_cover] = ACTIONS(6015),
    [anon_sym_sequence] = ACTIONS(6015),
    [anon_sym_restrict] = ACTIONS(6015),
    [anon_sym_not] = ACTIONS(6015),
    [anon_sym_or] = ACTIONS(6015),
    [anon_sym_and] = ACTIONS(6015),
    [anon_sym_case] = ACTIONS(6015),
    [anon_sym_always] = ACTIONS(6015),
    [anon_sym_covergroup] = ACTIONS(6015),
    [anon_sym_let] = ACTIONS(6015),
    [anon_sym_pulldown] = ACTIONS(6015),
    [anon_sym_pullup] = ACTIONS(6015),
    [anon_sym_cmos] = ACTIONS(6015),
    [anon_sym_rcmos] = ACTIONS(6015),
    [anon_sym_bufif0] = ACTIONS(6015),
    [anon_sym_bufif1] = ACTIONS(6015),
    [anon_sym_notif0] = ACTIONS(6015),
    [anon_sym_notif1] = ACTIONS(6015),
    [anon_sym_nmos] = ACTIONS(6015),
    [anon_sym_pmos] = ACTIONS(6015),
    [anon_sym_rnmos] = ACTIONS(6015),
    [anon_sym_rpmos] = ACTIONS(6015),
    [anon_sym_nand] = ACTIONS(6015),
    [anon_sym_nor] = ACTIONS(6015),
    [anon_sym_xor] = ACTIONS(6015),
    [anon_sym_xnor] = ACTIONS(6015),
    [anon_sym_buf] = ACTIONS(6015),
    [anon_sym_tranif0] = ACTIONS(6015),
    [anon_sym_tranif1] = ACTIONS(6015),
    [anon_sym_rtranif1] = ACTIONS(6015),
    [anon_sym_rtranif0] = ACTIONS(6015),
    [anon_sym_tran] = ACTIONS(6015),
    [anon_sym_rtran] = ACTIONS(6015),
    [anon_sym_generate] = ACTIONS(6015),
    [anon_sym_for] = ACTIONS(6015),
    [anon_sym_initial] = ACTIONS(6015),
    [anon_sym_assign] = ACTIONS(6015),
    [anon_sym_alias] = ACTIONS(6015),
    [anon_sym_always_comb] = ACTIONS(6015),
    [anon_sym_always_latch] = ACTIONS(6015),
    [anon_sym_always_ff] = ACTIONS(6015),
    [anon_sym_final] = ACTIONS(6015),
    [anon_sym_while] = ACTIONS(6015),
    [anon_sym_global] = ACTIONS(6015),
    [anon_sym_specify] = ACTIONS(6015),
    [anon_sym_LPAREN_STAR] = ACTIONS(6017),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6017),
    [anon_sym_DOLLARunit] = ACTIONS(6017),
  },
  [1071] = {
    [sym_simple_identifier] = ACTIONS(6019),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6021),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6021),
    [anon_sym_BQUOTE] = ACTIONS(6019),
    [aux_sym_id_directive_token1] = ACTIONS(6021),
    [aux_sym_id_directive_token2] = ACTIONS(6021),
    [aux_sym_id_directive_token3] = ACTIONS(6021),
    [aux_sym_id_directive_token4] = ACTIONS(6019),
    [aux_sym_zero_directive_token1] = ACTIONS(6021),
    [aux_sym_zero_directive_token2] = ACTIONS(6021),
    [aux_sym_zero_directive_token3] = ACTIONS(6021),
    [aux_sym_zero_directive_token4] = ACTIONS(6021),
    [aux_sym_zero_directive_token5] = ACTIONS(6021),
    [aux_sym_zero_directive_token6] = ACTIONS(6021),
    [aux_sym_zero_directive_token7] = ACTIONS(6021),
    [aux_sym_zero_directive_token8] = ACTIONS(6021),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6021),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6021),
    [anon_sym_wire] = ACTIONS(6019),
    [anon_sym_tri] = ACTIONS(6019),
    [anon_sym_tri0] = ACTIONS(6019),
    [anon_sym_tri1] = ACTIONS(6019),
    [anon_sym_wand] = ACTIONS(6019),
    [anon_sym_triand] = ACTIONS(6019),
    [anon_sym_wor] = ACTIONS(6019),
    [anon_sym_trior] = ACTIONS(6019),
    [anon_sym_trireg] = ACTIONS(6019),
    [anon_sym_uwire] = ACTIONS(6019),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6021),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6021),
    [aux_sym_begin_keywords_token1] = ACTIONS(6021),
    [anon_sym_SEMI] = ACTIONS(6021),
    [anon_sym_endmodule] = ACTIONS(6019),
    [anon_sym_extern] = ACTIONS(6019),
    [anon_sym_module] = ACTIONS(6019),
    [anon_sym_macromodule] = ACTIONS(6019),
    [anon_sym_endinterface] = ACTIONS(6019),
    [anon_sym_interface] = ACTIONS(6019),
    [anon_sym_endprogram] = ACTIONS(6019),
    [anon_sym_program] = ACTIONS(6019),
    [anon_sym_checker] = ACTIONS(6019),
    [anon_sym_virtual] = ACTIONS(6019),
    [anon_sym_class] = ACTIONS(6019),
    [anon_sym_timeunit] = ACTIONS(6019),
    [anon_sym_timeprecision] = ACTIONS(6019),
    [anon_sym_type] = ACTIONS(6019),
    [anon_sym_input] = ACTIONS(6019),
    [anon_sym_output] = ACTIONS(6019),
    [anon_sym_inout] = ACTIONS(6019),
    [anon_sym_ref] = ACTIONS(6019),
    [anon_sym_DOLLARfatal] = ACTIONS(6021),
    [anon_sym_DOLLARerror] = ACTIONS(6021),
    [anon_sym_DOLLARwarning] = ACTIONS(6021),
    [anon_sym_DOLLARinfo] = ACTIONS(6021),
    [anon_sym_default] = ACTIONS(6019),
    [anon_sym_clocking] = ACTIONS(6019),
    [anon_sym_defparam] = ACTIONS(6019),
    [anon_sym_bind] = ACTIONS(6019),
    [anon_sym_const] = ACTIONS(6019),
    [anon_sym_function] = ACTIONS(6019),
    [anon_sym_static] = ACTIONS(6019),
    [anon_sym_constraint] = ACTIONS(6019),
    [anon_sym_if] = ACTIONS(6019),
    [anon_sym_else] = ACTIONS(6019),
    [anon_sym_LBRACK] = ACTIONS(6021),
    [anon_sym_localparam] = ACTIONS(6019),
    [anon_sym_parameter] = ACTIONS(6019),
    [anon_sym_specparam] = ACTIONS(6019),
    [anon_sym_var] = ACTIONS(6019),
    [anon_sym_import] = ACTIONS(6019),
    [anon_sym_export] = ACTIONS(6019),
    [anon_sym_genvar] = ACTIONS(6019),
    [anon_sym_interconnect] = ACTIONS(6019),
    [anon_sym_typedef] = ACTIONS(6019),
    [anon_sym_enum] = ACTIONS(6019),
    [anon_sym_struct] = ACTIONS(6019),
    [anon_sym_union] = ACTIONS(6019),
    [anon_sym_nettype] = ACTIONS(6019),
    [anon_sym_automatic] = ACTIONS(6019),
    [anon_sym_string] = ACTIONS(6019),
    [anon_sym_chandle] = ACTIONS(6019),
    [anon_sym_event] = ACTIONS(6019),
    [anon_sym_byte] = ACTIONS(6019),
    [anon_sym_shortint] = ACTIONS(6019),
    [anon_sym_int] = ACTIONS(6019),
    [anon_sym_longint] = ACTIONS(6019),
    [anon_sym_integer] = ACTIONS(6019),
    [anon_sym_time] = ACTIONS(6019),
    [anon_sym_bit] = ACTIONS(6019),
    [anon_sym_logic] = ACTIONS(6019),
    [anon_sym_reg] = ACTIONS(6019),
    [anon_sym_shortreal] = ACTIONS(6019),
    [anon_sym_real] = ACTIONS(6019),
    [anon_sym_realtime] = ACTIONS(6019),
    [anon_sym_supply0] = ACTIONS(6019),
    [anon_sym_supply1] = ACTIONS(6019),
    [anon_sym_signed] = ACTIONS(6019),
    [anon_sym_unsigned] = ACTIONS(6019),
    [anon_sym_task] = ACTIONS(6019),
    [anon_sym_modport] = ACTIONS(6019),
    [anon_sym_assert] = ACTIONS(6019),
    [anon_sym_property] = ACTIONS(6019),
    [anon_sym_assume] = ACTIONS(6019),
    [anon_sym_cover] = ACTIONS(6019),
    [anon_sym_sequence] = ACTIONS(6019),
    [anon_sym_restrict] = ACTIONS(6019),
    [anon_sym_not] = ACTIONS(6019),
    [anon_sym_or] = ACTIONS(6019),
    [anon_sym_and] = ACTIONS(6019),
    [anon_sym_case] = ACTIONS(6019),
    [anon_sym_always] = ACTIONS(6019),
    [anon_sym_covergroup] = ACTIONS(6019),
    [anon_sym_let] = ACTIONS(6019),
    [anon_sym_pulldown] = ACTIONS(6019),
    [anon_sym_pullup] = ACTIONS(6019),
    [anon_sym_cmos] = ACTIONS(6019),
    [anon_sym_rcmos] = ACTIONS(6019),
    [anon_sym_bufif0] = ACTIONS(6019),
    [anon_sym_bufif1] = ACTIONS(6019),
    [anon_sym_notif0] = ACTIONS(6019),
    [anon_sym_notif1] = ACTIONS(6019),
    [anon_sym_nmos] = ACTIONS(6019),
    [anon_sym_pmos] = ACTIONS(6019),
    [anon_sym_rnmos] = ACTIONS(6019),
    [anon_sym_rpmos] = ACTIONS(6019),
    [anon_sym_nand] = ACTIONS(6019),
    [anon_sym_nor] = ACTIONS(6019),
    [anon_sym_xor] = ACTIONS(6019),
    [anon_sym_xnor] = ACTIONS(6019),
    [anon_sym_buf] = ACTIONS(6019),
    [anon_sym_tranif0] = ACTIONS(6019),
    [anon_sym_tranif1] = ACTIONS(6019),
    [anon_sym_rtranif1] = ACTIONS(6019),
    [anon_sym_rtranif0] = ACTIONS(6019),
    [anon_sym_tran] = ACTIONS(6019),
    [anon_sym_rtran] = ACTIONS(6019),
    [anon_sym_generate] = ACTIONS(6019),
    [anon_sym_for] = ACTIONS(6019),
    [anon_sym_initial] = ACTIONS(6019),
    [anon_sym_assign] = ACTIONS(6019),
    [anon_sym_alias] = ACTIONS(6019),
    [anon_sym_always_comb] = ACTIONS(6019),
    [anon_sym_always_latch] = ACTIONS(6019),
    [anon_sym_always_ff] = ACTIONS(6019),
    [anon_sym_final] = ACTIONS(6019),
    [anon_sym_while] = ACTIONS(6019),
    [anon_sym_global] = ACTIONS(6019),
    [anon_sym_specify] = ACTIONS(6019),
    [anon_sym_LPAREN_STAR] = ACTIONS(6021),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6021),
    [anon_sym_DOLLARunit] = ACTIONS(6021),
  },
  [1072] = {
    [ts_builtin_sym_end] = ACTIONS(6023),
    [sym_simple_identifier] = ACTIONS(6025),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6023),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6023),
    [anon_sym_BQUOTE] = ACTIONS(6025),
    [aux_sym_id_directive_token1] = ACTIONS(6023),
    [aux_sym_id_directive_token2] = ACTIONS(6023),
    [aux_sym_id_directive_token3] = ACTIONS(6023),
    [aux_sym_id_directive_token4] = ACTIONS(6025),
    [aux_sym_zero_directive_token1] = ACTIONS(6023),
    [aux_sym_zero_directive_token2] = ACTIONS(6023),
    [aux_sym_zero_directive_token3] = ACTIONS(6023),
    [aux_sym_zero_directive_token4] = ACTIONS(6023),
    [aux_sym_zero_directive_token5] = ACTIONS(6023),
    [aux_sym_zero_directive_token6] = ACTIONS(6023),
    [aux_sym_zero_directive_token7] = ACTIONS(6023),
    [aux_sym_zero_directive_token8] = ACTIONS(6023),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6023),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6023),
    [anon_sym_wire] = ACTIONS(6025),
    [anon_sym_tri] = ACTIONS(6025),
    [anon_sym_tri0] = ACTIONS(6025),
    [anon_sym_tri1] = ACTIONS(6025),
    [anon_sym_wand] = ACTIONS(6025),
    [anon_sym_triand] = ACTIONS(6025),
    [anon_sym_wor] = ACTIONS(6025),
    [anon_sym_trior] = ACTIONS(6025),
    [anon_sym_trireg] = ACTIONS(6025),
    [anon_sym_uwire] = ACTIONS(6025),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6023),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6023),
    [aux_sym_begin_keywords_token1] = ACTIONS(6023),
    [anon_sym_SEMI] = ACTIONS(6023),
    [anon_sym_endmodule] = ACTIONS(6025),
    [anon_sym_extern] = ACTIONS(6025),
    [anon_sym_module] = ACTIONS(6025),
    [anon_sym_macromodule] = ACTIONS(6025),
    [anon_sym_endinterface] = ACTIONS(6025),
    [anon_sym_interface] = ACTIONS(6025),
    [anon_sym_program] = ACTIONS(6025),
    [anon_sym_checker] = ACTIONS(6025),
    [anon_sym_virtual] = ACTIONS(6025),
    [anon_sym_class] = ACTIONS(6025),
    [anon_sym_package] = ACTIONS(6025),
    [anon_sym_timeunit] = ACTIONS(6025),
    [anon_sym_timeprecision] = ACTIONS(6025),
    [anon_sym_type] = ACTIONS(6025),
    [anon_sym_input] = ACTIONS(6025),
    [anon_sym_output] = ACTIONS(6025),
    [anon_sym_inout] = ACTIONS(6025),
    [anon_sym_ref] = ACTIONS(6025),
    [anon_sym_DOLLARfatal] = ACTIONS(6023),
    [anon_sym_DOLLARerror] = ACTIONS(6023),
    [anon_sym_DOLLARwarning] = ACTIONS(6023),
    [anon_sym_DOLLARinfo] = ACTIONS(6023),
    [anon_sym_default] = ACTIONS(6025),
    [anon_sym_clocking] = ACTIONS(6025),
    [anon_sym_defparam] = ACTIONS(6025),
    [anon_sym_bind] = ACTIONS(6025),
    [anon_sym_const] = ACTIONS(6025),
    [anon_sym_function] = ACTIONS(6025),
    [anon_sym_static] = ACTIONS(6025),
    [anon_sym_constraint] = ACTIONS(6025),
    [anon_sym_if] = ACTIONS(6025),
    [anon_sym_LBRACK] = ACTIONS(6023),
    [anon_sym_localparam] = ACTIONS(6025),
    [anon_sym_parameter] = ACTIONS(6025),
    [anon_sym_specparam] = ACTIONS(6025),
    [anon_sym_var] = ACTIONS(6025),
    [anon_sym_import] = ACTIONS(6025),
    [anon_sym_export] = ACTIONS(6025),
    [anon_sym_genvar] = ACTIONS(6025),
    [anon_sym_interconnect] = ACTIONS(6025),
    [anon_sym_typedef] = ACTIONS(6025),
    [anon_sym_enum] = ACTIONS(6025),
    [anon_sym_struct] = ACTIONS(6025),
    [anon_sym_union] = ACTIONS(6025),
    [anon_sym_nettype] = ACTIONS(6025),
    [anon_sym_automatic] = ACTIONS(6025),
    [anon_sym_string] = ACTIONS(6025),
    [anon_sym_chandle] = ACTIONS(6025),
    [anon_sym_event] = ACTIONS(6025),
    [anon_sym_byte] = ACTIONS(6025),
    [anon_sym_shortint] = ACTIONS(6025),
    [anon_sym_int] = ACTIONS(6025),
    [anon_sym_longint] = ACTIONS(6025),
    [anon_sym_integer] = ACTIONS(6025),
    [anon_sym_time] = ACTIONS(6025),
    [anon_sym_bit] = ACTIONS(6025),
    [anon_sym_logic] = ACTIONS(6025),
    [anon_sym_reg] = ACTIONS(6025),
    [anon_sym_shortreal] = ACTIONS(6025),
    [anon_sym_real] = ACTIONS(6025),
    [anon_sym_realtime] = ACTIONS(6025),
    [anon_sym_supply0] = ACTIONS(6025),
    [anon_sym_supply1] = ACTIONS(6025),
    [anon_sym_signed] = ACTIONS(6025),
    [anon_sym_unsigned] = ACTIONS(6025),
    [anon_sym_task] = ACTIONS(6025),
    [anon_sym_modport] = ACTIONS(6025),
    [anon_sym_assert] = ACTIONS(6025),
    [anon_sym_property] = ACTIONS(6025),
    [anon_sym_assume] = ACTIONS(6025),
    [anon_sym_cover] = ACTIONS(6025),
    [anon_sym_sequence] = ACTIONS(6025),
    [anon_sym_restrict] = ACTIONS(6025),
    [anon_sym_not] = ACTIONS(6025),
    [anon_sym_or] = ACTIONS(6025),
    [anon_sym_and] = ACTIONS(6025),
    [anon_sym_case] = ACTIONS(6025),
    [anon_sym_always] = ACTIONS(6025),
    [anon_sym_covergroup] = ACTIONS(6025),
    [anon_sym_let] = ACTIONS(6025),
    [anon_sym_pulldown] = ACTIONS(6025),
    [anon_sym_pullup] = ACTIONS(6025),
    [anon_sym_cmos] = ACTIONS(6025),
    [anon_sym_rcmos] = ACTIONS(6025),
    [anon_sym_bufif0] = ACTIONS(6025),
    [anon_sym_bufif1] = ACTIONS(6025),
    [anon_sym_notif0] = ACTIONS(6025),
    [anon_sym_notif1] = ACTIONS(6025),
    [anon_sym_nmos] = ACTIONS(6025),
    [anon_sym_pmos] = ACTIONS(6025),
    [anon_sym_rnmos] = ACTIONS(6025),
    [anon_sym_rpmos] = ACTIONS(6025),
    [anon_sym_nand] = ACTIONS(6025),
    [anon_sym_nor] = ACTIONS(6025),
    [anon_sym_xor] = ACTIONS(6025),
    [anon_sym_xnor] = ACTIONS(6025),
    [anon_sym_buf] = ACTIONS(6025),
    [anon_sym_tranif0] = ACTIONS(6025),
    [anon_sym_tranif1] = ACTIONS(6025),
    [anon_sym_rtranif1] = ACTIONS(6025),
    [anon_sym_rtranif0] = ACTIONS(6025),
    [anon_sym_tran] = ACTIONS(6025),
    [anon_sym_rtran] = ACTIONS(6025),
    [anon_sym_generate] = ACTIONS(6025),
    [anon_sym_for] = ACTIONS(6025),
    [anon_sym_primitive] = ACTIONS(6025),
    [anon_sym_initial] = ACTIONS(6025),
    [anon_sym_assign] = ACTIONS(6025),
    [anon_sym_alias] = ACTIONS(6025),
    [anon_sym_always_comb] = ACTIONS(6025),
    [anon_sym_always_latch] = ACTIONS(6025),
    [anon_sym_always_ff] = ACTIONS(6025),
    [anon_sym_final] = ACTIONS(6025),
    [anon_sym_global] = ACTIONS(6025),
    [anon_sym_specify] = ACTIONS(6025),
    [anon_sym_LPAREN_STAR] = ACTIONS(6023),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6023),
    [anon_sym_DOLLARunit] = ACTIONS(6023),
  },
  [1073] = {
    [sym_simple_identifier] = ACTIONS(6027),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6029),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6029),
    [anon_sym_BQUOTE] = ACTIONS(6027),
    [aux_sym_id_directive_token1] = ACTIONS(6029),
    [aux_sym_id_directive_token2] = ACTIONS(6029),
    [aux_sym_id_directive_token3] = ACTIONS(6029),
    [aux_sym_id_directive_token4] = ACTIONS(6027),
    [aux_sym_zero_directive_token1] = ACTIONS(6029),
    [aux_sym_zero_directive_token2] = ACTIONS(6029),
    [aux_sym_zero_directive_token3] = ACTIONS(6029),
    [aux_sym_zero_directive_token4] = ACTIONS(6029),
    [aux_sym_zero_directive_token5] = ACTIONS(6029),
    [aux_sym_zero_directive_token6] = ACTIONS(6029),
    [aux_sym_zero_directive_token7] = ACTIONS(6029),
    [aux_sym_zero_directive_token8] = ACTIONS(6029),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6029),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6029),
    [anon_sym_wire] = ACTIONS(6027),
    [anon_sym_tri] = ACTIONS(6027),
    [anon_sym_tri0] = ACTIONS(6027),
    [anon_sym_tri1] = ACTIONS(6027),
    [anon_sym_wand] = ACTIONS(6027),
    [anon_sym_triand] = ACTIONS(6027),
    [anon_sym_wor] = ACTIONS(6027),
    [anon_sym_trior] = ACTIONS(6027),
    [anon_sym_trireg] = ACTIONS(6027),
    [anon_sym_uwire] = ACTIONS(6027),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6029),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6029),
    [aux_sym_begin_keywords_token1] = ACTIONS(6029),
    [anon_sym_SEMI] = ACTIONS(6029),
    [anon_sym_endmodule] = ACTIONS(6027),
    [anon_sym_extern] = ACTIONS(6027),
    [anon_sym_module] = ACTIONS(6027),
    [anon_sym_macromodule] = ACTIONS(6027),
    [anon_sym_endinterface] = ACTIONS(6027),
    [anon_sym_interface] = ACTIONS(6027),
    [anon_sym_endprogram] = ACTIONS(6027),
    [anon_sym_program] = ACTIONS(6027),
    [anon_sym_checker] = ACTIONS(6027),
    [anon_sym_virtual] = ACTIONS(6027),
    [anon_sym_class] = ACTIONS(6027),
    [anon_sym_timeunit] = ACTIONS(6027),
    [anon_sym_timeprecision] = ACTIONS(6027),
    [anon_sym_type] = ACTIONS(6027),
    [anon_sym_input] = ACTIONS(6027),
    [anon_sym_output] = ACTIONS(6027),
    [anon_sym_inout] = ACTIONS(6027),
    [anon_sym_ref] = ACTIONS(6027),
    [anon_sym_DOLLARfatal] = ACTIONS(6029),
    [anon_sym_DOLLARerror] = ACTIONS(6029),
    [anon_sym_DOLLARwarning] = ACTIONS(6029),
    [anon_sym_DOLLARinfo] = ACTIONS(6029),
    [anon_sym_default] = ACTIONS(6027),
    [anon_sym_clocking] = ACTIONS(6027),
    [anon_sym_defparam] = ACTIONS(6027),
    [anon_sym_bind] = ACTIONS(6027),
    [anon_sym_const] = ACTIONS(6027),
    [anon_sym_function] = ACTIONS(6027),
    [anon_sym_static] = ACTIONS(6027),
    [anon_sym_constraint] = ACTIONS(6027),
    [anon_sym_if] = ACTIONS(6027),
    [anon_sym_else] = ACTIONS(6027),
    [anon_sym_LBRACK] = ACTIONS(6029),
    [anon_sym_localparam] = ACTIONS(6027),
    [anon_sym_parameter] = ACTIONS(6027),
    [anon_sym_specparam] = ACTIONS(6027),
    [anon_sym_var] = ACTIONS(6027),
    [anon_sym_import] = ACTIONS(6027),
    [anon_sym_export] = ACTIONS(6027),
    [anon_sym_genvar] = ACTIONS(6027),
    [anon_sym_interconnect] = ACTIONS(6027),
    [anon_sym_typedef] = ACTIONS(6027),
    [anon_sym_enum] = ACTIONS(6027),
    [anon_sym_struct] = ACTIONS(6027),
    [anon_sym_union] = ACTIONS(6027),
    [anon_sym_nettype] = ACTIONS(6027),
    [anon_sym_automatic] = ACTIONS(6027),
    [anon_sym_string] = ACTIONS(6027),
    [anon_sym_chandle] = ACTIONS(6027),
    [anon_sym_event] = ACTIONS(6027),
    [anon_sym_byte] = ACTIONS(6027),
    [anon_sym_shortint] = ACTIONS(6027),
    [anon_sym_int] = ACTIONS(6027),
    [anon_sym_longint] = ACTIONS(6027),
    [anon_sym_integer] = ACTIONS(6027),
    [anon_sym_time] = ACTIONS(6027),
    [anon_sym_bit] = ACTIONS(6027),
    [anon_sym_logic] = ACTIONS(6027),
    [anon_sym_reg] = ACTIONS(6027),
    [anon_sym_shortreal] = ACTIONS(6027),
    [anon_sym_real] = ACTIONS(6027),
    [anon_sym_realtime] = ACTIONS(6027),
    [anon_sym_supply0] = ACTIONS(6027),
    [anon_sym_supply1] = ACTIONS(6027),
    [anon_sym_signed] = ACTIONS(6027),
    [anon_sym_unsigned] = ACTIONS(6027),
    [anon_sym_task] = ACTIONS(6027),
    [anon_sym_modport] = ACTIONS(6027),
    [anon_sym_assert] = ACTIONS(6027),
    [anon_sym_property] = ACTIONS(6027),
    [anon_sym_assume] = ACTIONS(6027),
    [anon_sym_cover] = ACTIONS(6027),
    [anon_sym_sequence] = ACTIONS(6027),
    [anon_sym_restrict] = ACTIONS(6027),
    [anon_sym_not] = ACTIONS(6027),
    [anon_sym_or] = ACTIONS(6027),
    [anon_sym_and] = ACTIONS(6027),
    [anon_sym_case] = ACTIONS(6027),
    [anon_sym_always] = ACTIONS(6027),
    [anon_sym_covergroup] = ACTIONS(6027),
    [anon_sym_let] = ACTIONS(6027),
    [anon_sym_pulldown] = ACTIONS(6027),
    [anon_sym_pullup] = ACTIONS(6027),
    [anon_sym_cmos] = ACTIONS(6027),
    [anon_sym_rcmos] = ACTIONS(6027),
    [anon_sym_bufif0] = ACTIONS(6027),
    [anon_sym_bufif1] = ACTIONS(6027),
    [anon_sym_notif0] = ACTIONS(6027),
    [anon_sym_notif1] = ACTIONS(6027),
    [anon_sym_nmos] = ACTIONS(6027),
    [anon_sym_pmos] = ACTIONS(6027),
    [anon_sym_rnmos] = ACTIONS(6027),
    [anon_sym_rpmos] = ACTIONS(6027),
    [anon_sym_nand] = ACTIONS(6027),
    [anon_sym_nor] = ACTIONS(6027),
    [anon_sym_xor] = ACTIONS(6027),
    [anon_sym_xnor] = ACTIONS(6027),
    [anon_sym_buf] = ACTIONS(6027),
    [anon_sym_tranif0] = ACTIONS(6027),
    [anon_sym_tranif1] = ACTIONS(6027),
    [anon_sym_rtranif1] = ACTIONS(6027),
    [anon_sym_rtranif0] = ACTIONS(6027),
    [anon_sym_tran] = ACTIONS(6027),
    [anon_sym_rtran] = ACTIONS(6027),
    [anon_sym_generate] = ACTIONS(6027),
    [anon_sym_for] = ACTIONS(6027),
    [anon_sym_initial] = ACTIONS(6027),
    [anon_sym_assign] = ACTIONS(6027),
    [anon_sym_alias] = ACTIONS(6027),
    [anon_sym_always_comb] = ACTIONS(6027),
    [anon_sym_always_latch] = ACTIONS(6027),
    [anon_sym_always_ff] = ACTIONS(6027),
    [anon_sym_final] = ACTIONS(6027),
    [anon_sym_while] = ACTIONS(6027),
    [anon_sym_global] = ACTIONS(6027),
    [anon_sym_specify] = ACTIONS(6027),
    [anon_sym_LPAREN_STAR] = ACTIONS(6029),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6029),
    [anon_sym_DOLLARunit] = ACTIONS(6029),
  },
  [1074] = {
    [ts_builtin_sym_end] = ACTIONS(6031),
    [sym_simple_identifier] = ACTIONS(6033),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6031),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6031),
    [anon_sym_BQUOTE] = ACTIONS(6033),
    [aux_sym_id_directive_token1] = ACTIONS(6031),
    [aux_sym_id_directive_token2] = ACTIONS(6031),
    [aux_sym_id_directive_token3] = ACTIONS(6031),
    [aux_sym_id_directive_token4] = ACTIONS(6033),
    [aux_sym_zero_directive_token1] = ACTIONS(6031),
    [aux_sym_zero_directive_token2] = ACTIONS(6031),
    [aux_sym_zero_directive_token3] = ACTIONS(6031),
    [aux_sym_zero_directive_token4] = ACTIONS(6031),
    [aux_sym_zero_directive_token5] = ACTIONS(6031),
    [aux_sym_zero_directive_token6] = ACTIONS(6031),
    [aux_sym_zero_directive_token7] = ACTIONS(6031),
    [aux_sym_zero_directive_token8] = ACTIONS(6031),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6031),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6031),
    [anon_sym_wire] = ACTIONS(6033),
    [anon_sym_tri] = ACTIONS(6033),
    [anon_sym_tri0] = ACTIONS(6033),
    [anon_sym_tri1] = ACTIONS(6033),
    [anon_sym_wand] = ACTIONS(6033),
    [anon_sym_triand] = ACTIONS(6033),
    [anon_sym_wor] = ACTIONS(6033),
    [anon_sym_trior] = ACTIONS(6033),
    [anon_sym_trireg] = ACTIONS(6033),
    [anon_sym_uwire] = ACTIONS(6033),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6031),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6031),
    [aux_sym_begin_keywords_token1] = ACTIONS(6031),
    [anon_sym_SEMI] = ACTIONS(6031),
    [anon_sym_endmodule] = ACTIONS(6033),
    [anon_sym_extern] = ACTIONS(6033),
    [anon_sym_module] = ACTIONS(6033),
    [anon_sym_macromodule] = ACTIONS(6033),
    [anon_sym_endinterface] = ACTIONS(6033),
    [anon_sym_interface] = ACTIONS(6033),
    [anon_sym_program] = ACTIONS(6033),
    [anon_sym_checker] = ACTIONS(6033),
    [anon_sym_virtual] = ACTIONS(6033),
    [anon_sym_class] = ACTIONS(6033),
    [anon_sym_package] = ACTIONS(6033),
    [anon_sym_timeunit] = ACTIONS(6033),
    [anon_sym_timeprecision] = ACTIONS(6033),
    [anon_sym_type] = ACTIONS(6033),
    [anon_sym_input] = ACTIONS(6033),
    [anon_sym_output] = ACTIONS(6033),
    [anon_sym_inout] = ACTIONS(6033),
    [anon_sym_ref] = ACTIONS(6033),
    [anon_sym_DOLLARfatal] = ACTIONS(6031),
    [anon_sym_DOLLARerror] = ACTIONS(6031),
    [anon_sym_DOLLARwarning] = ACTIONS(6031),
    [anon_sym_DOLLARinfo] = ACTIONS(6031),
    [anon_sym_default] = ACTIONS(6033),
    [anon_sym_clocking] = ACTIONS(6033),
    [anon_sym_defparam] = ACTIONS(6033),
    [anon_sym_bind] = ACTIONS(6033),
    [anon_sym_const] = ACTIONS(6033),
    [anon_sym_function] = ACTIONS(6033),
    [anon_sym_static] = ACTIONS(6033),
    [anon_sym_constraint] = ACTIONS(6033),
    [anon_sym_if] = ACTIONS(6033),
    [anon_sym_LBRACK] = ACTIONS(6031),
    [anon_sym_localparam] = ACTIONS(6033),
    [anon_sym_parameter] = ACTIONS(6033),
    [anon_sym_specparam] = ACTIONS(6033),
    [anon_sym_var] = ACTIONS(6033),
    [anon_sym_import] = ACTIONS(6033),
    [anon_sym_export] = ACTIONS(6033),
    [anon_sym_genvar] = ACTIONS(6033),
    [anon_sym_interconnect] = ACTIONS(6033),
    [anon_sym_typedef] = ACTIONS(6033),
    [anon_sym_enum] = ACTIONS(6033),
    [anon_sym_struct] = ACTIONS(6033),
    [anon_sym_union] = ACTIONS(6033),
    [anon_sym_nettype] = ACTIONS(6033),
    [anon_sym_automatic] = ACTIONS(6033),
    [anon_sym_string] = ACTIONS(6033),
    [anon_sym_chandle] = ACTIONS(6033),
    [anon_sym_event] = ACTIONS(6033),
    [anon_sym_byte] = ACTIONS(6033),
    [anon_sym_shortint] = ACTIONS(6033),
    [anon_sym_int] = ACTIONS(6033),
    [anon_sym_longint] = ACTIONS(6033),
    [anon_sym_integer] = ACTIONS(6033),
    [anon_sym_time] = ACTIONS(6033),
    [anon_sym_bit] = ACTIONS(6033),
    [anon_sym_logic] = ACTIONS(6033),
    [anon_sym_reg] = ACTIONS(6033),
    [anon_sym_shortreal] = ACTIONS(6033),
    [anon_sym_real] = ACTIONS(6033),
    [anon_sym_realtime] = ACTIONS(6033),
    [anon_sym_supply0] = ACTIONS(6033),
    [anon_sym_supply1] = ACTIONS(6033),
    [anon_sym_signed] = ACTIONS(6033),
    [anon_sym_unsigned] = ACTIONS(6033),
    [anon_sym_task] = ACTIONS(6033),
    [anon_sym_modport] = ACTIONS(6033),
    [anon_sym_assert] = ACTIONS(6033),
    [anon_sym_property] = ACTIONS(6033),
    [anon_sym_assume] = ACTIONS(6033),
    [anon_sym_cover] = ACTIONS(6033),
    [anon_sym_sequence] = ACTIONS(6033),
    [anon_sym_restrict] = ACTIONS(6033),
    [anon_sym_not] = ACTIONS(6033),
    [anon_sym_or] = ACTIONS(6033),
    [anon_sym_and] = ACTIONS(6033),
    [anon_sym_case] = ACTIONS(6033),
    [anon_sym_always] = ACTIONS(6033),
    [anon_sym_covergroup] = ACTIONS(6033),
    [anon_sym_let] = ACTIONS(6033),
    [anon_sym_pulldown] = ACTIONS(6033),
    [anon_sym_pullup] = ACTIONS(6033),
    [anon_sym_cmos] = ACTIONS(6033),
    [anon_sym_rcmos] = ACTIONS(6033),
    [anon_sym_bufif0] = ACTIONS(6033),
    [anon_sym_bufif1] = ACTIONS(6033),
    [anon_sym_notif0] = ACTIONS(6033),
    [anon_sym_notif1] = ACTIONS(6033),
    [anon_sym_nmos] = ACTIONS(6033),
    [anon_sym_pmos] = ACTIONS(6033),
    [anon_sym_rnmos] = ACTIONS(6033),
    [anon_sym_rpmos] = ACTIONS(6033),
    [anon_sym_nand] = ACTIONS(6033),
    [anon_sym_nor] = ACTIONS(6033),
    [anon_sym_xor] = ACTIONS(6033),
    [anon_sym_xnor] = ACTIONS(6033),
    [anon_sym_buf] = ACTIONS(6033),
    [anon_sym_tranif0] = ACTIONS(6033),
    [anon_sym_tranif1] = ACTIONS(6033),
    [anon_sym_rtranif1] = ACTIONS(6033),
    [anon_sym_rtranif0] = ACTIONS(6033),
    [anon_sym_tran] = ACTIONS(6033),
    [anon_sym_rtran] = ACTIONS(6033),
    [anon_sym_generate] = ACTIONS(6033),
    [anon_sym_for] = ACTIONS(6033),
    [anon_sym_primitive] = ACTIONS(6033),
    [anon_sym_initial] = ACTIONS(6033),
    [anon_sym_assign] = ACTIONS(6033),
    [anon_sym_alias] = ACTIONS(6033),
    [anon_sym_always_comb] = ACTIONS(6033),
    [anon_sym_always_latch] = ACTIONS(6033),
    [anon_sym_always_ff] = ACTIONS(6033),
    [anon_sym_final] = ACTIONS(6033),
    [anon_sym_global] = ACTIONS(6033),
    [anon_sym_specify] = ACTIONS(6033),
    [anon_sym_LPAREN_STAR] = ACTIONS(6031),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6031),
    [anon_sym_DOLLARunit] = ACTIONS(6031),
  },
  [1075] = {
    [sym_simple_identifier] = ACTIONS(6035),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6037),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6037),
    [anon_sym_BQUOTE] = ACTIONS(6035),
    [aux_sym_id_directive_token1] = ACTIONS(6037),
    [aux_sym_id_directive_token2] = ACTIONS(6037),
    [aux_sym_id_directive_token3] = ACTIONS(6037),
    [aux_sym_id_directive_token4] = ACTIONS(6035),
    [aux_sym_zero_directive_token1] = ACTIONS(6037),
    [aux_sym_zero_directive_token2] = ACTIONS(6037),
    [aux_sym_zero_directive_token3] = ACTIONS(6037),
    [aux_sym_zero_directive_token4] = ACTIONS(6037),
    [aux_sym_zero_directive_token5] = ACTIONS(6037),
    [aux_sym_zero_directive_token6] = ACTIONS(6037),
    [aux_sym_zero_directive_token7] = ACTIONS(6037),
    [aux_sym_zero_directive_token8] = ACTIONS(6037),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6037),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6037),
    [anon_sym_wire] = ACTIONS(6035),
    [anon_sym_tri] = ACTIONS(6035),
    [anon_sym_tri0] = ACTIONS(6035),
    [anon_sym_tri1] = ACTIONS(6035),
    [anon_sym_wand] = ACTIONS(6035),
    [anon_sym_triand] = ACTIONS(6035),
    [anon_sym_wor] = ACTIONS(6035),
    [anon_sym_trior] = ACTIONS(6035),
    [anon_sym_trireg] = ACTIONS(6035),
    [anon_sym_uwire] = ACTIONS(6035),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6037),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6037),
    [aux_sym_begin_keywords_token1] = ACTIONS(6037),
    [anon_sym_SEMI] = ACTIONS(6037),
    [anon_sym_endmodule] = ACTIONS(6035),
    [anon_sym_extern] = ACTIONS(6035),
    [anon_sym_module] = ACTIONS(6035),
    [anon_sym_macromodule] = ACTIONS(6035),
    [anon_sym_endinterface] = ACTIONS(6035),
    [anon_sym_interface] = ACTIONS(6035),
    [anon_sym_endprogram] = ACTIONS(6035),
    [anon_sym_program] = ACTIONS(6035),
    [anon_sym_checker] = ACTIONS(6035),
    [anon_sym_virtual] = ACTIONS(6035),
    [anon_sym_class] = ACTIONS(6035),
    [anon_sym_timeunit] = ACTIONS(6035),
    [anon_sym_timeprecision] = ACTIONS(6035),
    [anon_sym_type] = ACTIONS(6035),
    [anon_sym_input] = ACTIONS(6035),
    [anon_sym_output] = ACTIONS(6035),
    [anon_sym_inout] = ACTIONS(6035),
    [anon_sym_ref] = ACTIONS(6035),
    [anon_sym_DOLLARfatal] = ACTIONS(6037),
    [anon_sym_DOLLARerror] = ACTIONS(6037),
    [anon_sym_DOLLARwarning] = ACTIONS(6037),
    [anon_sym_DOLLARinfo] = ACTIONS(6037),
    [anon_sym_default] = ACTIONS(6035),
    [anon_sym_clocking] = ACTIONS(6035),
    [anon_sym_defparam] = ACTIONS(6035),
    [anon_sym_bind] = ACTIONS(6035),
    [anon_sym_const] = ACTIONS(6035),
    [anon_sym_function] = ACTIONS(6035),
    [anon_sym_static] = ACTIONS(6035),
    [anon_sym_constraint] = ACTIONS(6035),
    [anon_sym_if] = ACTIONS(6035),
    [anon_sym_else] = ACTIONS(6035),
    [anon_sym_LBRACK] = ACTIONS(6037),
    [anon_sym_localparam] = ACTIONS(6035),
    [anon_sym_parameter] = ACTIONS(6035),
    [anon_sym_specparam] = ACTIONS(6035),
    [anon_sym_var] = ACTIONS(6035),
    [anon_sym_import] = ACTIONS(6035),
    [anon_sym_export] = ACTIONS(6035),
    [anon_sym_genvar] = ACTIONS(6035),
    [anon_sym_interconnect] = ACTIONS(6035),
    [anon_sym_typedef] = ACTIONS(6035),
    [anon_sym_enum] = ACTIONS(6035),
    [anon_sym_struct] = ACTIONS(6035),
    [anon_sym_union] = ACTIONS(6035),
    [anon_sym_nettype] = ACTIONS(6035),
    [anon_sym_automatic] = ACTIONS(6035),
    [anon_sym_string] = ACTIONS(6035),
    [anon_sym_chandle] = ACTIONS(6035),
    [anon_sym_event] = ACTIONS(6035),
    [anon_sym_byte] = ACTIONS(6035),
    [anon_sym_shortint] = ACTIONS(6035),
    [anon_sym_int] = ACTIONS(6035),
    [anon_sym_longint] = ACTIONS(6035),
    [anon_sym_integer] = ACTIONS(6035),
    [anon_sym_time] = ACTIONS(6035),
    [anon_sym_bit] = ACTIONS(6035),
    [anon_sym_logic] = ACTIONS(6035),
    [anon_sym_reg] = ACTIONS(6035),
    [anon_sym_shortreal] = ACTIONS(6035),
    [anon_sym_real] = ACTIONS(6035),
    [anon_sym_realtime] = ACTIONS(6035),
    [anon_sym_supply0] = ACTIONS(6035),
    [anon_sym_supply1] = ACTIONS(6035),
    [anon_sym_signed] = ACTIONS(6035),
    [anon_sym_unsigned] = ACTIONS(6035),
    [anon_sym_task] = ACTIONS(6035),
    [anon_sym_modport] = ACTIONS(6035),
    [anon_sym_assert] = ACTIONS(6035),
    [anon_sym_property] = ACTIONS(6035),
    [anon_sym_assume] = ACTIONS(6035),
    [anon_sym_cover] = ACTIONS(6035),
    [anon_sym_sequence] = ACTIONS(6035),
    [anon_sym_restrict] = ACTIONS(6035),
    [anon_sym_not] = ACTIONS(6035),
    [anon_sym_or] = ACTIONS(6035),
    [anon_sym_and] = ACTIONS(6035),
    [anon_sym_case] = ACTIONS(6035),
    [anon_sym_always] = ACTIONS(6035),
    [anon_sym_covergroup] = ACTIONS(6035),
    [anon_sym_let] = ACTIONS(6035),
    [anon_sym_pulldown] = ACTIONS(6035),
    [anon_sym_pullup] = ACTIONS(6035),
    [anon_sym_cmos] = ACTIONS(6035),
    [anon_sym_rcmos] = ACTIONS(6035),
    [anon_sym_bufif0] = ACTIONS(6035),
    [anon_sym_bufif1] = ACTIONS(6035),
    [anon_sym_notif0] = ACTIONS(6035),
    [anon_sym_notif1] = ACTIONS(6035),
    [anon_sym_nmos] = ACTIONS(6035),
    [anon_sym_pmos] = ACTIONS(6035),
    [anon_sym_rnmos] = ACTIONS(6035),
    [anon_sym_rpmos] = ACTIONS(6035),
    [anon_sym_nand] = ACTIONS(6035),
    [anon_sym_nor] = ACTIONS(6035),
    [anon_sym_xor] = ACTIONS(6035),
    [anon_sym_xnor] = ACTIONS(6035),
    [anon_sym_buf] = ACTIONS(6035),
    [anon_sym_tranif0] = ACTIONS(6035),
    [anon_sym_tranif1] = ACTIONS(6035),
    [anon_sym_rtranif1] = ACTIONS(6035),
    [anon_sym_rtranif0] = ACTIONS(6035),
    [anon_sym_tran] = ACTIONS(6035),
    [anon_sym_rtran] = ACTIONS(6035),
    [anon_sym_generate] = ACTIONS(6035),
    [anon_sym_for] = ACTIONS(6035),
    [anon_sym_initial] = ACTIONS(6035),
    [anon_sym_assign] = ACTIONS(6035),
    [anon_sym_alias] = ACTIONS(6035),
    [anon_sym_always_comb] = ACTIONS(6035),
    [anon_sym_always_latch] = ACTIONS(6035),
    [anon_sym_always_ff] = ACTIONS(6035),
    [anon_sym_final] = ACTIONS(6035),
    [anon_sym_while] = ACTIONS(6035),
    [anon_sym_global] = ACTIONS(6035),
    [anon_sym_specify] = ACTIONS(6035),
    [anon_sym_LPAREN_STAR] = ACTIONS(6037),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6037),
    [anon_sym_DOLLARunit] = ACTIONS(6037),
  },
  [1076] = {
    [sym_simple_identifier] = ACTIONS(6039),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6041),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6041),
    [anon_sym_BQUOTE] = ACTIONS(6039),
    [aux_sym_id_directive_token1] = ACTIONS(6041),
    [aux_sym_id_directive_token2] = ACTIONS(6041),
    [aux_sym_id_directive_token3] = ACTIONS(6041),
    [aux_sym_id_directive_token4] = ACTIONS(6039),
    [aux_sym_zero_directive_token1] = ACTIONS(6041),
    [aux_sym_zero_directive_token2] = ACTIONS(6041),
    [aux_sym_zero_directive_token3] = ACTIONS(6041),
    [aux_sym_zero_directive_token4] = ACTIONS(6041),
    [aux_sym_zero_directive_token5] = ACTIONS(6041),
    [aux_sym_zero_directive_token6] = ACTIONS(6041),
    [aux_sym_zero_directive_token7] = ACTIONS(6041),
    [aux_sym_zero_directive_token8] = ACTIONS(6041),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6041),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6041),
    [anon_sym_wire] = ACTIONS(6039),
    [anon_sym_tri] = ACTIONS(6039),
    [anon_sym_tri0] = ACTIONS(6039),
    [anon_sym_tri1] = ACTIONS(6039),
    [anon_sym_wand] = ACTIONS(6039),
    [anon_sym_triand] = ACTIONS(6039),
    [anon_sym_wor] = ACTIONS(6039),
    [anon_sym_trior] = ACTIONS(6039),
    [anon_sym_trireg] = ACTIONS(6039),
    [anon_sym_uwire] = ACTIONS(6039),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6041),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6041),
    [aux_sym_begin_keywords_token1] = ACTIONS(6041),
    [anon_sym_SEMI] = ACTIONS(6041),
    [anon_sym_endmodule] = ACTIONS(6039),
    [anon_sym_extern] = ACTIONS(6039),
    [anon_sym_module] = ACTIONS(6039),
    [anon_sym_macromodule] = ACTIONS(6039),
    [anon_sym_endinterface] = ACTIONS(6039),
    [anon_sym_interface] = ACTIONS(6039),
    [anon_sym_endprogram] = ACTIONS(6039),
    [anon_sym_program] = ACTIONS(6039),
    [anon_sym_checker] = ACTIONS(6039),
    [anon_sym_virtual] = ACTIONS(6039),
    [anon_sym_class] = ACTIONS(6039),
    [anon_sym_timeunit] = ACTIONS(6039),
    [anon_sym_timeprecision] = ACTIONS(6039),
    [anon_sym_type] = ACTIONS(6039),
    [anon_sym_input] = ACTIONS(6039),
    [anon_sym_output] = ACTIONS(6039),
    [anon_sym_inout] = ACTIONS(6039),
    [anon_sym_ref] = ACTIONS(6039),
    [anon_sym_DOLLARfatal] = ACTIONS(6041),
    [anon_sym_DOLLARerror] = ACTIONS(6041),
    [anon_sym_DOLLARwarning] = ACTIONS(6041),
    [anon_sym_DOLLARinfo] = ACTIONS(6041),
    [anon_sym_default] = ACTIONS(6039),
    [anon_sym_clocking] = ACTIONS(6039),
    [anon_sym_defparam] = ACTIONS(6039),
    [anon_sym_bind] = ACTIONS(6039),
    [anon_sym_const] = ACTIONS(6039),
    [anon_sym_function] = ACTIONS(6039),
    [anon_sym_static] = ACTIONS(6039),
    [anon_sym_constraint] = ACTIONS(6039),
    [anon_sym_if] = ACTIONS(6039),
    [anon_sym_else] = ACTIONS(6039),
    [anon_sym_LBRACK] = ACTIONS(6041),
    [anon_sym_localparam] = ACTIONS(6039),
    [anon_sym_parameter] = ACTIONS(6039),
    [anon_sym_specparam] = ACTIONS(6039),
    [anon_sym_var] = ACTIONS(6039),
    [anon_sym_import] = ACTIONS(6039),
    [anon_sym_export] = ACTIONS(6039),
    [anon_sym_genvar] = ACTIONS(6039),
    [anon_sym_interconnect] = ACTIONS(6039),
    [anon_sym_typedef] = ACTIONS(6039),
    [anon_sym_enum] = ACTIONS(6039),
    [anon_sym_struct] = ACTIONS(6039),
    [anon_sym_union] = ACTIONS(6039),
    [anon_sym_nettype] = ACTIONS(6039),
    [anon_sym_automatic] = ACTIONS(6039),
    [anon_sym_string] = ACTIONS(6039),
    [anon_sym_chandle] = ACTIONS(6039),
    [anon_sym_event] = ACTIONS(6039),
    [anon_sym_byte] = ACTIONS(6039),
    [anon_sym_shortint] = ACTIONS(6039),
    [anon_sym_int] = ACTIONS(6039),
    [anon_sym_longint] = ACTIONS(6039),
    [anon_sym_integer] = ACTIONS(6039),
    [anon_sym_time] = ACTIONS(6039),
    [anon_sym_bit] = ACTIONS(6039),
    [anon_sym_logic] = ACTIONS(6039),
    [anon_sym_reg] = ACTIONS(6039),
    [anon_sym_shortreal] = ACTIONS(6039),
    [anon_sym_real] = ACTIONS(6039),
    [anon_sym_realtime] = ACTIONS(6039),
    [anon_sym_supply0] = ACTIONS(6039),
    [anon_sym_supply1] = ACTIONS(6039),
    [anon_sym_signed] = ACTIONS(6039),
    [anon_sym_unsigned] = ACTIONS(6039),
    [anon_sym_task] = ACTIONS(6039),
    [anon_sym_modport] = ACTIONS(6039),
    [anon_sym_assert] = ACTIONS(6039),
    [anon_sym_property] = ACTIONS(6039),
    [anon_sym_assume] = ACTIONS(6039),
    [anon_sym_cover] = ACTIONS(6039),
    [anon_sym_sequence] = ACTIONS(6039),
    [anon_sym_restrict] = ACTIONS(6039),
    [anon_sym_not] = ACTIONS(6039),
    [anon_sym_or] = ACTIONS(6039),
    [anon_sym_and] = ACTIONS(6039),
    [anon_sym_case] = ACTIONS(6039),
    [anon_sym_always] = ACTIONS(6039),
    [anon_sym_covergroup] = ACTIONS(6039),
    [anon_sym_let] = ACTIONS(6039),
    [anon_sym_pulldown] = ACTIONS(6039),
    [anon_sym_pullup] = ACTIONS(6039),
    [anon_sym_cmos] = ACTIONS(6039),
    [anon_sym_rcmos] = ACTIONS(6039),
    [anon_sym_bufif0] = ACTIONS(6039),
    [anon_sym_bufif1] = ACTIONS(6039),
    [anon_sym_notif0] = ACTIONS(6039),
    [anon_sym_notif1] = ACTIONS(6039),
    [anon_sym_nmos] = ACTIONS(6039),
    [anon_sym_pmos] = ACTIONS(6039),
    [anon_sym_rnmos] = ACTIONS(6039),
    [anon_sym_rpmos] = ACTIONS(6039),
    [anon_sym_nand] = ACTIONS(6039),
    [anon_sym_nor] = ACTIONS(6039),
    [anon_sym_xor] = ACTIONS(6039),
    [anon_sym_xnor] = ACTIONS(6039),
    [anon_sym_buf] = ACTIONS(6039),
    [anon_sym_tranif0] = ACTIONS(6039),
    [anon_sym_tranif1] = ACTIONS(6039),
    [anon_sym_rtranif1] = ACTIONS(6039),
    [anon_sym_rtranif0] = ACTIONS(6039),
    [anon_sym_tran] = ACTIONS(6039),
    [anon_sym_rtran] = ACTIONS(6039),
    [anon_sym_generate] = ACTIONS(6039),
    [anon_sym_for] = ACTIONS(6039),
    [anon_sym_initial] = ACTIONS(6039),
    [anon_sym_assign] = ACTIONS(6039),
    [anon_sym_alias] = ACTIONS(6039),
    [anon_sym_always_comb] = ACTIONS(6039),
    [anon_sym_always_latch] = ACTIONS(6039),
    [anon_sym_always_ff] = ACTIONS(6039),
    [anon_sym_final] = ACTIONS(6039),
    [anon_sym_while] = ACTIONS(6039),
    [anon_sym_global] = ACTIONS(6039),
    [anon_sym_specify] = ACTIONS(6039),
    [anon_sym_LPAREN_STAR] = ACTIONS(6041),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6041),
    [anon_sym_DOLLARunit] = ACTIONS(6041),
  },
  [1077] = {
    [sym_simple_identifier] = ACTIONS(6043),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6045),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6045),
    [anon_sym_BQUOTE] = ACTIONS(6043),
    [aux_sym_id_directive_token1] = ACTIONS(6045),
    [aux_sym_id_directive_token2] = ACTIONS(6045),
    [aux_sym_id_directive_token3] = ACTIONS(6045),
    [aux_sym_id_directive_token4] = ACTIONS(6043),
    [aux_sym_zero_directive_token1] = ACTIONS(6045),
    [aux_sym_zero_directive_token2] = ACTIONS(6045),
    [aux_sym_zero_directive_token3] = ACTIONS(6045),
    [aux_sym_zero_directive_token4] = ACTIONS(6045),
    [aux_sym_zero_directive_token5] = ACTIONS(6045),
    [aux_sym_zero_directive_token6] = ACTIONS(6045),
    [aux_sym_zero_directive_token7] = ACTIONS(6045),
    [aux_sym_zero_directive_token8] = ACTIONS(6045),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6045),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6045),
    [anon_sym_wire] = ACTIONS(6043),
    [anon_sym_tri] = ACTIONS(6043),
    [anon_sym_tri0] = ACTIONS(6043),
    [anon_sym_tri1] = ACTIONS(6043),
    [anon_sym_wand] = ACTIONS(6043),
    [anon_sym_triand] = ACTIONS(6043),
    [anon_sym_wor] = ACTIONS(6043),
    [anon_sym_trior] = ACTIONS(6043),
    [anon_sym_trireg] = ACTIONS(6043),
    [anon_sym_uwire] = ACTIONS(6043),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6045),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6045),
    [aux_sym_begin_keywords_token1] = ACTIONS(6045),
    [anon_sym_SEMI] = ACTIONS(6045),
    [anon_sym_endmodule] = ACTIONS(6043),
    [anon_sym_extern] = ACTIONS(6043),
    [anon_sym_module] = ACTIONS(6043),
    [anon_sym_macromodule] = ACTIONS(6043),
    [anon_sym_endinterface] = ACTIONS(6043),
    [anon_sym_interface] = ACTIONS(6043),
    [anon_sym_endprogram] = ACTIONS(6043),
    [anon_sym_program] = ACTIONS(6043),
    [anon_sym_checker] = ACTIONS(6043),
    [anon_sym_virtual] = ACTIONS(6043),
    [anon_sym_class] = ACTIONS(6043),
    [anon_sym_timeunit] = ACTIONS(6043),
    [anon_sym_timeprecision] = ACTIONS(6043),
    [anon_sym_type] = ACTIONS(6043),
    [anon_sym_input] = ACTIONS(6043),
    [anon_sym_output] = ACTIONS(6043),
    [anon_sym_inout] = ACTIONS(6043),
    [anon_sym_ref] = ACTIONS(6043),
    [anon_sym_DOLLARfatal] = ACTIONS(6045),
    [anon_sym_DOLLARerror] = ACTIONS(6045),
    [anon_sym_DOLLARwarning] = ACTIONS(6045),
    [anon_sym_DOLLARinfo] = ACTIONS(6045),
    [anon_sym_default] = ACTIONS(6043),
    [anon_sym_clocking] = ACTIONS(6043),
    [anon_sym_defparam] = ACTIONS(6043),
    [anon_sym_bind] = ACTIONS(6043),
    [anon_sym_const] = ACTIONS(6043),
    [anon_sym_function] = ACTIONS(6043),
    [anon_sym_static] = ACTIONS(6043),
    [anon_sym_constraint] = ACTIONS(6043),
    [anon_sym_if] = ACTIONS(6043),
    [anon_sym_else] = ACTIONS(6043),
    [anon_sym_LBRACK] = ACTIONS(6045),
    [anon_sym_localparam] = ACTIONS(6043),
    [anon_sym_parameter] = ACTIONS(6043),
    [anon_sym_specparam] = ACTIONS(6043),
    [anon_sym_var] = ACTIONS(6043),
    [anon_sym_import] = ACTIONS(6043),
    [anon_sym_export] = ACTIONS(6043),
    [anon_sym_genvar] = ACTIONS(6043),
    [anon_sym_interconnect] = ACTIONS(6043),
    [anon_sym_typedef] = ACTIONS(6043),
    [anon_sym_enum] = ACTIONS(6043),
    [anon_sym_struct] = ACTIONS(6043),
    [anon_sym_union] = ACTIONS(6043),
    [anon_sym_nettype] = ACTIONS(6043),
    [anon_sym_automatic] = ACTIONS(6043),
    [anon_sym_string] = ACTIONS(6043),
    [anon_sym_chandle] = ACTIONS(6043),
    [anon_sym_event] = ACTIONS(6043),
    [anon_sym_byte] = ACTIONS(6043),
    [anon_sym_shortint] = ACTIONS(6043),
    [anon_sym_int] = ACTIONS(6043),
    [anon_sym_longint] = ACTIONS(6043),
    [anon_sym_integer] = ACTIONS(6043),
    [anon_sym_time] = ACTIONS(6043),
    [anon_sym_bit] = ACTIONS(6043),
    [anon_sym_logic] = ACTIONS(6043),
    [anon_sym_reg] = ACTIONS(6043),
    [anon_sym_shortreal] = ACTIONS(6043),
    [anon_sym_real] = ACTIONS(6043),
    [anon_sym_realtime] = ACTIONS(6043),
    [anon_sym_supply0] = ACTIONS(6043),
    [anon_sym_supply1] = ACTIONS(6043),
    [anon_sym_signed] = ACTIONS(6043),
    [anon_sym_unsigned] = ACTIONS(6043),
    [anon_sym_task] = ACTIONS(6043),
    [anon_sym_modport] = ACTIONS(6043),
    [anon_sym_assert] = ACTIONS(6043),
    [anon_sym_property] = ACTIONS(6043),
    [anon_sym_assume] = ACTIONS(6043),
    [anon_sym_cover] = ACTIONS(6043),
    [anon_sym_sequence] = ACTIONS(6043),
    [anon_sym_restrict] = ACTIONS(6043),
    [anon_sym_not] = ACTIONS(6043),
    [anon_sym_or] = ACTIONS(6043),
    [anon_sym_and] = ACTIONS(6043),
    [anon_sym_case] = ACTIONS(6043),
    [anon_sym_always] = ACTIONS(6043),
    [anon_sym_covergroup] = ACTIONS(6043),
    [anon_sym_let] = ACTIONS(6043),
    [anon_sym_pulldown] = ACTIONS(6043),
    [anon_sym_pullup] = ACTIONS(6043),
    [anon_sym_cmos] = ACTIONS(6043),
    [anon_sym_rcmos] = ACTIONS(6043),
    [anon_sym_bufif0] = ACTIONS(6043),
    [anon_sym_bufif1] = ACTIONS(6043),
    [anon_sym_notif0] = ACTIONS(6043),
    [anon_sym_notif1] = ACTIONS(6043),
    [anon_sym_nmos] = ACTIONS(6043),
    [anon_sym_pmos] = ACTIONS(6043),
    [anon_sym_rnmos] = ACTIONS(6043),
    [anon_sym_rpmos] = ACTIONS(6043),
    [anon_sym_nand] = ACTIONS(6043),
    [anon_sym_nor] = ACTIONS(6043),
    [anon_sym_xor] = ACTIONS(6043),
    [anon_sym_xnor] = ACTIONS(6043),
    [anon_sym_buf] = ACTIONS(6043),
    [anon_sym_tranif0] = ACTIONS(6043),
    [anon_sym_tranif1] = ACTIONS(6043),
    [anon_sym_rtranif1] = ACTIONS(6043),
    [anon_sym_rtranif0] = ACTIONS(6043),
    [anon_sym_tran] = ACTIONS(6043),
    [anon_sym_rtran] = ACTIONS(6043),
    [anon_sym_generate] = ACTIONS(6043),
    [anon_sym_for] = ACTIONS(6043),
    [anon_sym_initial] = ACTIONS(6043),
    [anon_sym_assign] = ACTIONS(6043),
    [anon_sym_alias] = ACTIONS(6043),
    [anon_sym_always_comb] = ACTIONS(6043),
    [anon_sym_always_latch] = ACTIONS(6043),
    [anon_sym_always_ff] = ACTIONS(6043),
    [anon_sym_final] = ACTIONS(6043),
    [anon_sym_while] = ACTIONS(6043),
    [anon_sym_global] = ACTIONS(6043),
    [anon_sym_specify] = ACTIONS(6043),
    [anon_sym_LPAREN_STAR] = ACTIONS(6045),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6045),
    [anon_sym_DOLLARunit] = ACTIONS(6045),
  },
  [1078] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6049),
    [anon_sym_BQUOTE] = ACTIONS(6047),
    [aux_sym_id_directive_token1] = ACTIONS(6049),
    [aux_sym_id_directive_token2] = ACTIONS(6049),
    [aux_sym_id_directive_token3] = ACTIONS(6049),
    [aux_sym_id_directive_token4] = ACTIONS(6047),
    [aux_sym_zero_directive_token1] = ACTIONS(6049),
    [aux_sym_zero_directive_token2] = ACTIONS(6049),
    [aux_sym_zero_directive_token3] = ACTIONS(6049),
    [aux_sym_zero_directive_token4] = ACTIONS(6049),
    [aux_sym_zero_directive_token5] = ACTIONS(6049),
    [aux_sym_zero_directive_token6] = ACTIONS(6049),
    [aux_sym_zero_directive_token7] = ACTIONS(6049),
    [aux_sym_zero_directive_token8] = ACTIONS(6049),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6049),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6049),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_begin_keywords_token1] = ACTIONS(6049),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_endmodule] = ACTIONS(6047),
    [anon_sym_COLON] = ACTIONS(6051),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_module] = ACTIONS(6047),
    [anon_sym_macromodule] = ACTIONS(6047),
    [anon_sym_endinterface] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_endprogram] = ACTIONS(6047),
    [anon_sym_program] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_timeunit] = ACTIONS(6047),
    [anon_sym_timeprecision] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_input] = ACTIONS(6047),
    [anon_sym_output] = ACTIONS(6047),
    [anon_sym_inout] = ACTIONS(6047),
    [anon_sym_ref] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_specparam] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_modport] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_specify] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [1079] = {
    [sym_simple_identifier] = ACTIONS(6053),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6055),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6055),
    [anon_sym_BQUOTE] = ACTIONS(6053),
    [aux_sym_id_directive_token1] = ACTIONS(6055),
    [aux_sym_id_directive_token2] = ACTIONS(6055),
    [aux_sym_id_directive_token3] = ACTIONS(6055),
    [aux_sym_id_directive_token4] = ACTIONS(6053),
    [aux_sym_zero_directive_token1] = ACTIONS(6055),
    [aux_sym_zero_directive_token2] = ACTIONS(6055),
    [aux_sym_zero_directive_token3] = ACTIONS(6055),
    [aux_sym_zero_directive_token4] = ACTIONS(6055),
    [aux_sym_zero_directive_token5] = ACTIONS(6055),
    [aux_sym_zero_directive_token6] = ACTIONS(6055),
    [aux_sym_zero_directive_token7] = ACTIONS(6055),
    [aux_sym_zero_directive_token8] = ACTIONS(6055),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6055),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6055),
    [anon_sym_wire] = ACTIONS(6053),
    [anon_sym_tri] = ACTIONS(6053),
    [anon_sym_tri0] = ACTIONS(6053),
    [anon_sym_tri1] = ACTIONS(6053),
    [anon_sym_wand] = ACTIONS(6053),
    [anon_sym_triand] = ACTIONS(6053),
    [anon_sym_wor] = ACTIONS(6053),
    [anon_sym_trior] = ACTIONS(6053),
    [anon_sym_trireg] = ACTIONS(6053),
    [anon_sym_uwire] = ACTIONS(6053),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6055),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6055),
    [aux_sym_begin_keywords_token1] = ACTIONS(6055),
    [anon_sym_SEMI] = ACTIONS(6055),
    [anon_sym_endmodule] = ACTIONS(6053),
    [anon_sym_extern] = ACTIONS(6053),
    [anon_sym_module] = ACTIONS(6053),
    [anon_sym_macromodule] = ACTIONS(6053),
    [anon_sym_endinterface] = ACTIONS(6053),
    [anon_sym_interface] = ACTIONS(6053),
    [anon_sym_endprogram] = ACTIONS(6053),
    [anon_sym_program] = ACTIONS(6053),
    [anon_sym_checker] = ACTIONS(6053),
    [anon_sym_virtual] = ACTIONS(6053),
    [anon_sym_class] = ACTIONS(6053),
    [anon_sym_timeunit] = ACTIONS(6053),
    [anon_sym_timeprecision] = ACTIONS(6053),
    [anon_sym_type] = ACTIONS(6053),
    [anon_sym_input] = ACTIONS(6053),
    [anon_sym_output] = ACTIONS(6053),
    [anon_sym_inout] = ACTIONS(6053),
    [anon_sym_ref] = ACTIONS(6053),
    [anon_sym_DOLLARfatal] = ACTIONS(6055),
    [anon_sym_DOLLARerror] = ACTIONS(6055),
    [anon_sym_DOLLARwarning] = ACTIONS(6055),
    [anon_sym_DOLLARinfo] = ACTIONS(6055),
    [anon_sym_default] = ACTIONS(6053),
    [anon_sym_clocking] = ACTIONS(6053),
    [anon_sym_defparam] = ACTIONS(6053),
    [anon_sym_bind] = ACTIONS(6053),
    [anon_sym_const] = ACTIONS(6053),
    [anon_sym_function] = ACTIONS(6053),
    [anon_sym_static] = ACTIONS(6053),
    [anon_sym_constraint] = ACTIONS(6053),
    [anon_sym_if] = ACTIONS(6053),
    [anon_sym_else] = ACTIONS(6053),
    [anon_sym_LBRACK] = ACTIONS(6055),
    [anon_sym_localparam] = ACTIONS(6053),
    [anon_sym_parameter] = ACTIONS(6053),
    [anon_sym_specparam] = ACTIONS(6053),
    [anon_sym_var] = ACTIONS(6053),
    [anon_sym_import] = ACTIONS(6053),
    [anon_sym_export] = ACTIONS(6053),
    [anon_sym_genvar] = ACTIONS(6053),
    [anon_sym_interconnect] = ACTIONS(6053),
    [anon_sym_typedef] = ACTIONS(6053),
    [anon_sym_enum] = ACTIONS(6053),
    [anon_sym_struct] = ACTIONS(6053),
    [anon_sym_union] = ACTIONS(6053),
    [anon_sym_nettype] = ACTIONS(6053),
    [anon_sym_automatic] = ACTIONS(6053),
    [anon_sym_string] = ACTIONS(6053),
    [anon_sym_chandle] = ACTIONS(6053),
    [anon_sym_event] = ACTIONS(6053),
    [anon_sym_byte] = ACTIONS(6053),
    [anon_sym_shortint] = ACTIONS(6053),
    [anon_sym_int] = ACTIONS(6053),
    [anon_sym_longint] = ACTIONS(6053),
    [anon_sym_integer] = ACTIONS(6053),
    [anon_sym_time] = ACTIONS(6053),
    [anon_sym_bit] = ACTIONS(6053),
    [anon_sym_logic] = ACTIONS(6053),
    [anon_sym_reg] = ACTIONS(6053),
    [anon_sym_shortreal] = ACTIONS(6053),
    [anon_sym_real] = ACTIONS(6053),
    [anon_sym_realtime] = ACTIONS(6053),
    [anon_sym_supply0] = ACTIONS(6053),
    [anon_sym_supply1] = ACTIONS(6053),
    [anon_sym_signed] = ACTIONS(6053),
    [anon_sym_unsigned] = ACTIONS(6053),
    [anon_sym_task] = ACTIONS(6053),
    [anon_sym_modport] = ACTIONS(6053),
    [anon_sym_assert] = ACTIONS(6053),
    [anon_sym_property] = ACTIONS(6053),
    [anon_sym_assume] = ACTIONS(6053),
    [anon_sym_cover] = ACTIONS(6053),
    [anon_sym_sequence] = ACTIONS(6053),
    [anon_sym_restrict] = ACTIONS(6053),
    [anon_sym_not] = ACTIONS(6053),
    [anon_sym_or] = ACTIONS(6053),
    [anon_sym_and] = ACTIONS(6053),
    [anon_sym_case] = ACTIONS(6053),
    [anon_sym_always] = ACTIONS(6053),
    [anon_sym_covergroup] = ACTIONS(6053),
    [anon_sym_let] = ACTIONS(6053),
    [anon_sym_pulldown] = ACTIONS(6053),
    [anon_sym_pullup] = ACTIONS(6053),
    [anon_sym_cmos] = ACTIONS(6053),
    [anon_sym_rcmos] = ACTIONS(6053),
    [anon_sym_bufif0] = ACTIONS(6053),
    [anon_sym_bufif1] = ACTIONS(6053),
    [anon_sym_notif0] = ACTIONS(6053),
    [anon_sym_notif1] = ACTIONS(6053),
    [anon_sym_nmos] = ACTIONS(6053),
    [anon_sym_pmos] = ACTIONS(6053),
    [anon_sym_rnmos] = ACTIONS(6053),
    [anon_sym_rpmos] = ACTIONS(6053),
    [anon_sym_nand] = ACTIONS(6053),
    [anon_sym_nor] = ACTIONS(6053),
    [anon_sym_xor] = ACTIONS(6053),
    [anon_sym_xnor] = ACTIONS(6053),
    [anon_sym_buf] = ACTIONS(6053),
    [anon_sym_tranif0] = ACTIONS(6053),
    [anon_sym_tranif1] = ACTIONS(6053),
    [anon_sym_rtranif1] = ACTIONS(6053),
    [anon_sym_rtranif0] = ACTIONS(6053),
    [anon_sym_tran] = ACTIONS(6053),
    [anon_sym_rtran] = ACTIONS(6053),
    [anon_sym_generate] = ACTIONS(6053),
    [anon_sym_for] = ACTIONS(6053),
    [anon_sym_initial] = ACTIONS(6053),
    [anon_sym_assign] = ACTIONS(6053),
    [anon_sym_alias] = ACTIONS(6053),
    [anon_sym_always_comb] = ACTIONS(6053),
    [anon_sym_always_latch] = ACTIONS(6053),
    [anon_sym_always_ff] = ACTIONS(6053),
    [anon_sym_final] = ACTIONS(6053),
    [anon_sym_while] = ACTIONS(6053),
    [anon_sym_global] = ACTIONS(6053),
    [anon_sym_specify] = ACTIONS(6053),
    [anon_sym_LPAREN_STAR] = ACTIONS(6055),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6055),
    [anon_sym_DOLLARunit] = ACTIONS(6055),
  },
  [1080] = {
    [ts_builtin_sym_end] = ACTIONS(6057),
    [sym_simple_identifier] = ACTIONS(6059),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6057),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6057),
    [anon_sym_BQUOTE] = ACTIONS(6059),
    [aux_sym_id_directive_token1] = ACTIONS(6057),
    [aux_sym_id_directive_token2] = ACTIONS(6057),
    [aux_sym_id_directive_token3] = ACTIONS(6057),
    [aux_sym_id_directive_token4] = ACTIONS(6059),
    [aux_sym_zero_directive_token1] = ACTIONS(6057),
    [aux_sym_zero_directive_token2] = ACTIONS(6057),
    [aux_sym_zero_directive_token3] = ACTIONS(6057),
    [aux_sym_zero_directive_token4] = ACTIONS(6057),
    [aux_sym_zero_directive_token5] = ACTIONS(6057),
    [aux_sym_zero_directive_token6] = ACTIONS(6057),
    [aux_sym_zero_directive_token7] = ACTIONS(6057),
    [aux_sym_zero_directive_token8] = ACTIONS(6057),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6057),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6057),
    [anon_sym_wire] = ACTIONS(6059),
    [anon_sym_tri] = ACTIONS(6059),
    [anon_sym_tri0] = ACTIONS(6059),
    [anon_sym_tri1] = ACTIONS(6059),
    [anon_sym_wand] = ACTIONS(6059),
    [anon_sym_triand] = ACTIONS(6059),
    [anon_sym_wor] = ACTIONS(6059),
    [anon_sym_trior] = ACTIONS(6059),
    [anon_sym_trireg] = ACTIONS(6059),
    [anon_sym_uwire] = ACTIONS(6059),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6057),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6057),
    [aux_sym_begin_keywords_token1] = ACTIONS(6057),
    [anon_sym_SEMI] = ACTIONS(6057),
    [anon_sym_endmodule] = ACTIONS(6059),
    [anon_sym_extern] = ACTIONS(6059),
    [anon_sym_module] = ACTIONS(6059),
    [anon_sym_macromodule] = ACTIONS(6059),
    [anon_sym_endinterface] = ACTIONS(6059),
    [anon_sym_interface] = ACTIONS(6059),
    [anon_sym_program] = ACTIONS(6059),
    [anon_sym_checker] = ACTIONS(6059),
    [anon_sym_virtual] = ACTIONS(6059),
    [anon_sym_class] = ACTIONS(6059),
    [anon_sym_package] = ACTIONS(6059),
    [anon_sym_timeunit] = ACTIONS(6059),
    [anon_sym_timeprecision] = ACTIONS(6059),
    [anon_sym_type] = ACTIONS(6059),
    [anon_sym_input] = ACTIONS(6059),
    [anon_sym_output] = ACTIONS(6059),
    [anon_sym_inout] = ACTIONS(6059),
    [anon_sym_ref] = ACTIONS(6059),
    [anon_sym_DOLLARfatal] = ACTIONS(6057),
    [anon_sym_DOLLARerror] = ACTIONS(6057),
    [anon_sym_DOLLARwarning] = ACTIONS(6057),
    [anon_sym_DOLLARinfo] = ACTIONS(6057),
    [anon_sym_default] = ACTIONS(6059),
    [anon_sym_clocking] = ACTIONS(6059),
    [anon_sym_defparam] = ACTIONS(6059),
    [anon_sym_bind] = ACTIONS(6059),
    [anon_sym_const] = ACTIONS(6059),
    [anon_sym_function] = ACTIONS(6059),
    [anon_sym_static] = ACTIONS(6059),
    [anon_sym_constraint] = ACTIONS(6059),
    [anon_sym_if] = ACTIONS(6059),
    [anon_sym_LBRACK] = ACTIONS(6057),
    [anon_sym_localparam] = ACTIONS(6059),
    [anon_sym_parameter] = ACTIONS(6059),
    [anon_sym_specparam] = ACTIONS(6059),
    [anon_sym_var] = ACTIONS(6059),
    [anon_sym_import] = ACTIONS(6059),
    [anon_sym_export] = ACTIONS(6059),
    [anon_sym_genvar] = ACTIONS(6059),
    [anon_sym_interconnect] = ACTIONS(6059),
    [anon_sym_typedef] = ACTIONS(6059),
    [anon_sym_enum] = ACTIONS(6059),
    [anon_sym_struct] = ACTIONS(6059),
    [anon_sym_union] = ACTIONS(6059),
    [anon_sym_nettype] = ACTIONS(6059),
    [anon_sym_automatic] = ACTIONS(6059),
    [anon_sym_string] = ACTIONS(6059),
    [anon_sym_chandle] = ACTIONS(6059),
    [anon_sym_event] = ACTIONS(6059),
    [anon_sym_byte] = ACTIONS(6059),
    [anon_sym_shortint] = ACTIONS(6059),
    [anon_sym_int] = ACTIONS(6059),
    [anon_sym_longint] = ACTIONS(6059),
    [anon_sym_integer] = ACTIONS(6059),
    [anon_sym_time] = ACTIONS(6059),
    [anon_sym_bit] = ACTIONS(6059),
    [anon_sym_logic] = ACTIONS(6059),
    [anon_sym_reg] = ACTIONS(6059),
    [anon_sym_shortreal] = ACTIONS(6059),
    [anon_sym_real] = ACTIONS(6059),
    [anon_sym_realtime] = ACTIONS(6059),
    [anon_sym_supply0] = ACTIONS(6059),
    [anon_sym_supply1] = ACTIONS(6059),
    [anon_sym_signed] = ACTIONS(6059),
    [anon_sym_unsigned] = ACTIONS(6059),
    [anon_sym_task] = ACTIONS(6059),
    [anon_sym_modport] = ACTIONS(6059),
    [anon_sym_assert] = ACTIONS(6059),
    [anon_sym_property] = ACTIONS(6059),
    [anon_sym_assume] = ACTIONS(6059),
    [anon_sym_cover] = ACTIONS(6059),
    [anon_sym_sequence] = ACTIONS(6059),
    [anon_sym_restrict] = ACTIONS(6059),
    [anon_sym_not] = ACTIONS(6059),
    [anon_sym_or] = ACTIONS(6059),
    [anon_sym_and] = ACTIONS(6059),
    [anon_sym_case] = ACTIONS(6059),
    [anon_sym_always] = ACTIONS(6059),
    [anon_sym_covergroup] = ACTIONS(6059),
    [anon_sym_let] = ACTIONS(6059),
    [anon_sym_pulldown] = ACTIONS(6059),
    [anon_sym_pullup] = ACTIONS(6059),
    [anon_sym_cmos] = ACTIONS(6059),
    [anon_sym_rcmos] = ACTIONS(6059),
    [anon_sym_bufif0] = ACTIONS(6059),
    [anon_sym_bufif1] = ACTIONS(6059),
    [anon_sym_notif0] = ACTIONS(6059),
    [anon_sym_notif1] = ACTIONS(6059),
    [anon_sym_nmos] = ACTIONS(6059),
    [anon_sym_pmos] = ACTIONS(6059),
    [anon_sym_rnmos] = ACTIONS(6059),
    [anon_sym_rpmos] = ACTIONS(6059),
    [anon_sym_nand] = ACTIONS(6059),
    [anon_sym_nor] = ACTIONS(6059),
    [anon_sym_xor] = ACTIONS(6059),
    [anon_sym_xnor] = ACTIONS(6059),
    [anon_sym_buf] = ACTIONS(6059),
    [anon_sym_tranif0] = ACTIONS(6059),
    [anon_sym_tranif1] = ACTIONS(6059),
    [anon_sym_rtranif1] = ACTIONS(6059),
    [anon_sym_rtranif0] = ACTIONS(6059),
    [anon_sym_tran] = ACTIONS(6059),
    [anon_sym_rtran] = ACTIONS(6059),
    [anon_sym_generate] = ACTIONS(6059),
    [anon_sym_for] = ACTIONS(6059),
    [anon_sym_primitive] = ACTIONS(6059),
    [anon_sym_initial] = ACTIONS(6059),
    [anon_sym_assign] = ACTIONS(6059),
    [anon_sym_alias] = ACTIONS(6059),
    [anon_sym_always_comb] = ACTIONS(6059),
    [anon_sym_always_latch] = ACTIONS(6059),
    [anon_sym_always_ff] = ACTIONS(6059),
    [anon_sym_final] = ACTIONS(6059),
    [anon_sym_global] = ACTIONS(6059),
    [anon_sym_specify] = ACTIONS(6059),
    [anon_sym_LPAREN_STAR] = ACTIONS(6057),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6057),
    [anon_sym_DOLLARunit] = ACTIONS(6057),
  },
  [1081] = {
    [sym_simple_identifier] = ACTIONS(6061),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6063),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6063),
    [anon_sym_BQUOTE] = ACTIONS(6061),
    [aux_sym_id_directive_token1] = ACTIONS(6063),
    [aux_sym_id_directive_token2] = ACTIONS(6063),
    [aux_sym_id_directive_token3] = ACTIONS(6063),
    [aux_sym_id_directive_token4] = ACTIONS(6061),
    [aux_sym_zero_directive_token1] = ACTIONS(6063),
    [aux_sym_zero_directive_token2] = ACTIONS(6063),
    [aux_sym_zero_directive_token3] = ACTIONS(6063),
    [aux_sym_zero_directive_token4] = ACTIONS(6063),
    [aux_sym_zero_directive_token5] = ACTIONS(6063),
    [aux_sym_zero_directive_token6] = ACTIONS(6063),
    [aux_sym_zero_directive_token7] = ACTIONS(6063),
    [aux_sym_zero_directive_token8] = ACTIONS(6063),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6063),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6063),
    [anon_sym_wire] = ACTIONS(6061),
    [anon_sym_tri] = ACTIONS(6061),
    [anon_sym_tri0] = ACTIONS(6061),
    [anon_sym_tri1] = ACTIONS(6061),
    [anon_sym_wand] = ACTIONS(6061),
    [anon_sym_triand] = ACTIONS(6061),
    [anon_sym_wor] = ACTIONS(6061),
    [anon_sym_trior] = ACTIONS(6061),
    [anon_sym_trireg] = ACTIONS(6061),
    [anon_sym_uwire] = ACTIONS(6061),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6063),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6063),
    [aux_sym_begin_keywords_token1] = ACTIONS(6063),
    [anon_sym_SEMI] = ACTIONS(6063),
    [anon_sym_endmodule] = ACTIONS(6061),
    [anon_sym_extern] = ACTIONS(6061),
    [anon_sym_module] = ACTIONS(6061),
    [anon_sym_macromodule] = ACTIONS(6061),
    [anon_sym_endinterface] = ACTIONS(6061),
    [anon_sym_interface] = ACTIONS(6061),
    [anon_sym_endprogram] = ACTIONS(6061),
    [anon_sym_program] = ACTIONS(6061),
    [anon_sym_checker] = ACTIONS(6061),
    [anon_sym_virtual] = ACTIONS(6061),
    [anon_sym_class] = ACTIONS(6061),
    [anon_sym_timeunit] = ACTIONS(6061),
    [anon_sym_timeprecision] = ACTIONS(6061),
    [anon_sym_type] = ACTIONS(6061),
    [anon_sym_input] = ACTIONS(6061),
    [anon_sym_output] = ACTIONS(6061),
    [anon_sym_inout] = ACTIONS(6061),
    [anon_sym_ref] = ACTIONS(6061),
    [anon_sym_DOLLARfatal] = ACTIONS(6063),
    [anon_sym_DOLLARerror] = ACTIONS(6063),
    [anon_sym_DOLLARwarning] = ACTIONS(6063),
    [anon_sym_DOLLARinfo] = ACTIONS(6063),
    [anon_sym_default] = ACTIONS(6061),
    [anon_sym_clocking] = ACTIONS(6061),
    [anon_sym_defparam] = ACTIONS(6061),
    [anon_sym_bind] = ACTIONS(6061),
    [anon_sym_const] = ACTIONS(6061),
    [anon_sym_function] = ACTIONS(6061),
    [anon_sym_static] = ACTIONS(6061),
    [anon_sym_constraint] = ACTIONS(6061),
    [anon_sym_if] = ACTIONS(6061),
    [anon_sym_else] = ACTIONS(6061),
    [anon_sym_LBRACK] = ACTIONS(6063),
    [anon_sym_localparam] = ACTIONS(6061),
    [anon_sym_parameter] = ACTIONS(6061),
    [anon_sym_specparam] = ACTIONS(6061),
    [anon_sym_var] = ACTIONS(6061),
    [anon_sym_import] = ACTIONS(6061),
    [anon_sym_export] = ACTIONS(6061),
    [anon_sym_genvar] = ACTIONS(6061),
    [anon_sym_interconnect] = ACTIONS(6061),
    [anon_sym_typedef] = ACTIONS(6061),
    [anon_sym_enum] = ACTIONS(6061),
    [anon_sym_struct] = ACTIONS(6061),
    [anon_sym_union] = ACTIONS(6061),
    [anon_sym_nettype] = ACTIONS(6061),
    [anon_sym_automatic] = ACTIONS(6061),
    [anon_sym_string] = ACTIONS(6061),
    [anon_sym_chandle] = ACTIONS(6061),
    [anon_sym_event] = ACTIONS(6061),
    [anon_sym_byte] = ACTIONS(6061),
    [anon_sym_shortint] = ACTIONS(6061),
    [anon_sym_int] = ACTIONS(6061),
    [anon_sym_longint] = ACTIONS(6061),
    [anon_sym_integer] = ACTIONS(6061),
    [anon_sym_time] = ACTIONS(6061),
    [anon_sym_bit] = ACTIONS(6061),
    [anon_sym_logic] = ACTIONS(6061),
    [anon_sym_reg] = ACTIONS(6061),
    [anon_sym_shortreal] = ACTIONS(6061),
    [anon_sym_real] = ACTIONS(6061),
    [anon_sym_realtime] = ACTIONS(6061),
    [anon_sym_supply0] = ACTIONS(6061),
    [anon_sym_supply1] = ACTIONS(6061),
    [anon_sym_signed] = ACTIONS(6061),
    [anon_sym_unsigned] = ACTIONS(6061),
    [anon_sym_task] = ACTIONS(6061),
    [anon_sym_modport] = ACTIONS(6061),
    [anon_sym_assert] = ACTIONS(6061),
    [anon_sym_property] = ACTIONS(6061),
    [anon_sym_assume] = ACTIONS(6061),
    [anon_sym_cover] = ACTIONS(6061),
    [anon_sym_sequence] = ACTIONS(6061),
    [anon_sym_restrict] = ACTIONS(6061),
    [anon_sym_not] = ACTIONS(6061),
    [anon_sym_or] = ACTIONS(6061),
    [anon_sym_and] = ACTIONS(6061),
    [anon_sym_case] = ACTIONS(6061),
    [anon_sym_always] = ACTIONS(6061),
    [anon_sym_covergroup] = ACTIONS(6061),
    [anon_sym_let] = ACTIONS(6061),
    [anon_sym_pulldown] = ACTIONS(6061),
    [anon_sym_pullup] = ACTIONS(6061),
    [anon_sym_cmos] = ACTIONS(6061),
    [anon_sym_rcmos] = ACTIONS(6061),
    [anon_sym_bufif0] = ACTIONS(6061),
    [anon_sym_bufif1] = ACTIONS(6061),
    [anon_sym_notif0] = ACTIONS(6061),
    [anon_sym_notif1] = ACTIONS(6061),
    [anon_sym_nmos] = ACTIONS(6061),
    [anon_sym_pmos] = ACTIONS(6061),
    [anon_sym_rnmos] = ACTIONS(6061),
    [anon_sym_rpmos] = ACTIONS(6061),
    [anon_sym_nand] = ACTIONS(6061),
    [anon_sym_nor] = ACTIONS(6061),
    [anon_sym_xor] = ACTIONS(6061),
    [anon_sym_xnor] = ACTIONS(6061),
    [anon_sym_buf] = ACTIONS(6061),
    [anon_sym_tranif0] = ACTIONS(6061),
    [anon_sym_tranif1] = ACTIONS(6061),
    [anon_sym_rtranif1] = ACTIONS(6061),
    [anon_sym_rtranif0] = ACTIONS(6061),
    [anon_sym_tran] = ACTIONS(6061),
    [anon_sym_rtran] = ACTIONS(6061),
    [anon_sym_generate] = ACTIONS(6061),
    [anon_sym_for] = ACTIONS(6061),
    [anon_sym_initial] = ACTIONS(6061),
    [anon_sym_assign] = ACTIONS(6061),
    [anon_sym_alias] = ACTIONS(6061),
    [anon_sym_always_comb] = ACTIONS(6061),
    [anon_sym_always_latch] = ACTIONS(6061),
    [anon_sym_always_ff] = ACTIONS(6061),
    [anon_sym_final] = ACTIONS(6061),
    [anon_sym_while] = ACTIONS(6061),
    [anon_sym_global] = ACTIONS(6061),
    [anon_sym_specify] = ACTIONS(6061),
    [anon_sym_LPAREN_STAR] = ACTIONS(6063),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6063),
    [anon_sym_DOLLARunit] = ACTIONS(6063),
  },
  [1082] = {
    [sym_simple_identifier] = ACTIONS(6065),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6067),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6067),
    [anon_sym_BQUOTE] = ACTIONS(6065),
    [aux_sym_id_directive_token1] = ACTIONS(6067),
    [aux_sym_id_directive_token2] = ACTIONS(6067),
    [aux_sym_id_directive_token3] = ACTIONS(6067),
    [aux_sym_id_directive_token4] = ACTIONS(6065),
    [aux_sym_zero_directive_token1] = ACTIONS(6067),
    [aux_sym_zero_directive_token2] = ACTIONS(6067),
    [aux_sym_zero_directive_token3] = ACTIONS(6067),
    [aux_sym_zero_directive_token4] = ACTIONS(6067),
    [aux_sym_zero_directive_token5] = ACTIONS(6067),
    [aux_sym_zero_directive_token6] = ACTIONS(6067),
    [aux_sym_zero_directive_token7] = ACTIONS(6067),
    [aux_sym_zero_directive_token8] = ACTIONS(6067),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6067),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6067),
    [anon_sym_wire] = ACTIONS(6065),
    [anon_sym_tri] = ACTIONS(6065),
    [anon_sym_tri0] = ACTIONS(6065),
    [anon_sym_tri1] = ACTIONS(6065),
    [anon_sym_wand] = ACTIONS(6065),
    [anon_sym_triand] = ACTIONS(6065),
    [anon_sym_wor] = ACTIONS(6065),
    [anon_sym_trior] = ACTIONS(6065),
    [anon_sym_trireg] = ACTIONS(6065),
    [anon_sym_uwire] = ACTIONS(6065),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6067),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6067),
    [aux_sym_begin_keywords_token1] = ACTIONS(6067),
    [anon_sym_SEMI] = ACTIONS(6067),
    [anon_sym_endmodule] = ACTIONS(6065),
    [anon_sym_extern] = ACTIONS(6065),
    [anon_sym_module] = ACTIONS(6065),
    [anon_sym_macromodule] = ACTIONS(6065),
    [anon_sym_endinterface] = ACTIONS(6065),
    [anon_sym_interface] = ACTIONS(6065),
    [anon_sym_endprogram] = ACTIONS(6065),
    [anon_sym_program] = ACTIONS(6065),
    [anon_sym_checker] = ACTIONS(6065),
    [anon_sym_virtual] = ACTIONS(6065),
    [anon_sym_class] = ACTIONS(6065),
    [anon_sym_timeunit] = ACTIONS(6065),
    [anon_sym_timeprecision] = ACTIONS(6065),
    [anon_sym_type] = ACTIONS(6065),
    [anon_sym_input] = ACTIONS(6065),
    [anon_sym_output] = ACTIONS(6065),
    [anon_sym_inout] = ACTIONS(6065),
    [anon_sym_ref] = ACTIONS(6065),
    [anon_sym_DOLLARfatal] = ACTIONS(6067),
    [anon_sym_DOLLARerror] = ACTIONS(6067),
    [anon_sym_DOLLARwarning] = ACTIONS(6067),
    [anon_sym_DOLLARinfo] = ACTIONS(6067),
    [anon_sym_default] = ACTIONS(6065),
    [anon_sym_clocking] = ACTIONS(6065),
    [anon_sym_defparam] = ACTIONS(6065),
    [anon_sym_bind] = ACTIONS(6065),
    [anon_sym_const] = ACTIONS(6065),
    [anon_sym_function] = ACTIONS(6065),
    [anon_sym_static] = ACTIONS(6065),
    [anon_sym_constraint] = ACTIONS(6065),
    [anon_sym_if] = ACTIONS(6065),
    [anon_sym_else] = ACTIONS(6065),
    [anon_sym_LBRACK] = ACTIONS(6067),
    [anon_sym_localparam] = ACTIONS(6065),
    [anon_sym_parameter] = ACTIONS(6065),
    [anon_sym_specparam] = ACTIONS(6065),
    [anon_sym_var] = ACTIONS(6065),
    [anon_sym_import] = ACTIONS(6065),
    [anon_sym_export] = ACTIONS(6065),
    [anon_sym_genvar] = ACTIONS(6065),
    [anon_sym_interconnect] = ACTIONS(6065),
    [anon_sym_typedef] = ACTIONS(6065),
    [anon_sym_enum] = ACTIONS(6065),
    [anon_sym_struct] = ACTIONS(6065),
    [anon_sym_union] = ACTIONS(6065),
    [anon_sym_nettype] = ACTIONS(6065),
    [anon_sym_automatic] = ACTIONS(6065),
    [anon_sym_string] = ACTIONS(6065),
    [anon_sym_chandle] = ACTIONS(6065),
    [anon_sym_event] = ACTIONS(6065),
    [anon_sym_byte] = ACTIONS(6065),
    [anon_sym_shortint] = ACTIONS(6065),
    [anon_sym_int] = ACTIONS(6065),
    [anon_sym_longint] = ACTIONS(6065),
    [anon_sym_integer] = ACTIONS(6065),
    [anon_sym_time] = ACTIONS(6065),
    [anon_sym_bit] = ACTIONS(6065),
    [anon_sym_logic] = ACTIONS(6065),
    [anon_sym_reg] = ACTIONS(6065),
    [anon_sym_shortreal] = ACTIONS(6065),
    [anon_sym_real] = ACTIONS(6065),
    [anon_sym_realtime] = ACTIONS(6065),
    [anon_sym_supply0] = ACTIONS(6065),
    [anon_sym_supply1] = ACTIONS(6065),
    [anon_sym_signed] = ACTIONS(6065),
    [anon_sym_unsigned] = ACTIONS(6065),
    [anon_sym_task] = ACTIONS(6065),
    [anon_sym_modport] = ACTIONS(6065),
    [anon_sym_assert] = ACTIONS(6065),
    [anon_sym_property] = ACTIONS(6065),
    [anon_sym_assume] = ACTIONS(6065),
    [anon_sym_cover] = ACTIONS(6065),
    [anon_sym_sequence] = ACTIONS(6065),
    [anon_sym_restrict] = ACTIONS(6065),
    [anon_sym_not] = ACTIONS(6065),
    [anon_sym_or] = ACTIONS(6065),
    [anon_sym_and] = ACTIONS(6065),
    [anon_sym_case] = ACTIONS(6065),
    [anon_sym_always] = ACTIONS(6065),
    [anon_sym_covergroup] = ACTIONS(6065),
    [anon_sym_let] = ACTIONS(6065),
    [anon_sym_pulldown] = ACTIONS(6065),
    [anon_sym_pullup] = ACTIONS(6065),
    [anon_sym_cmos] = ACTIONS(6065),
    [anon_sym_rcmos] = ACTIONS(6065),
    [anon_sym_bufif0] = ACTIONS(6065),
    [anon_sym_bufif1] = ACTIONS(6065),
    [anon_sym_notif0] = ACTIONS(6065),
    [anon_sym_notif1] = ACTIONS(6065),
    [anon_sym_nmos] = ACTIONS(6065),
    [anon_sym_pmos] = ACTIONS(6065),
    [anon_sym_rnmos] = ACTIONS(6065),
    [anon_sym_rpmos] = ACTIONS(6065),
    [anon_sym_nand] = ACTIONS(6065),
    [anon_sym_nor] = ACTIONS(6065),
    [anon_sym_xor] = ACTIONS(6065),
    [anon_sym_xnor] = ACTIONS(6065),
    [anon_sym_buf] = ACTIONS(6065),
    [anon_sym_tranif0] = ACTIONS(6065),
    [anon_sym_tranif1] = ACTIONS(6065),
    [anon_sym_rtranif1] = ACTIONS(6065),
    [anon_sym_rtranif0] = ACTIONS(6065),
    [anon_sym_tran] = ACTIONS(6065),
    [anon_sym_rtran] = ACTIONS(6065),
    [anon_sym_generate] = ACTIONS(6065),
    [anon_sym_for] = ACTIONS(6065),
    [anon_sym_initial] = ACTIONS(6065),
    [anon_sym_assign] = ACTIONS(6065),
    [anon_sym_alias] = ACTIONS(6065),
    [anon_sym_always_comb] = ACTIONS(6065),
    [anon_sym_always_latch] = ACTIONS(6065),
    [anon_sym_always_ff] = ACTIONS(6065),
    [anon_sym_final] = ACTIONS(6065),
    [anon_sym_while] = ACTIONS(6065),
    [anon_sym_global] = ACTIONS(6065),
    [anon_sym_specify] = ACTIONS(6065),
    [anon_sym_LPAREN_STAR] = ACTIONS(6067),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6067),
    [anon_sym_DOLLARunit] = ACTIONS(6067),
  },
  [1083] = {
    [ts_builtin_sym_end] = ACTIONS(6069),
    [sym_simple_identifier] = ACTIONS(6071),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6069),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6069),
    [anon_sym_BQUOTE] = ACTIONS(6071),
    [aux_sym_id_directive_token1] = ACTIONS(6069),
    [aux_sym_id_directive_token2] = ACTIONS(6069),
    [aux_sym_id_directive_token3] = ACTIONS(6069),
    [aux_sym_id_directive_token4] = ACTIONS(6071),
    [aux_sym_zero_directive_token1] = ACTIONS(6069),
    [aux_sym_zero_directive_token2] = ACTIONS(6069),
    [aux_sym_zero_directive_token3] = ACTIONS(6069),
    [aux_sym_zero_directive_token4] = ACTIONS(6069),
    [aux_sym_zero_directive_token5] = ACTIONS(6069),
    [aux_sym_zero_directive_token6] = ACTIONS(6069),
    [aux_sym_zero_directive_token7] = ACTIONS(6069),
    [aux_sym_zero_directive_token8] = ACTIONS(6069),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6069),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6069),
    [anon_sym_wire] = ACTIONS(6071),
    [anon_sym_tri] = ACTIONS(6071),
    [anon_sym_tri0] = ACTIONS(6071),
    [anon_sym_tri1] = ACTIONS(6071),
    [anon_sym_wand] = ACTIONS(6071),
    [anon_sym_triand] = ACTIONS(6071),
    [anon_sym_wor] = ACTIONS(6071),
    [anon_sym_trior] = ACTIONS(6071),
    [anon_sym_trireg] = ACTIONS(6071),
    [anon_sym_uwire] = ACTIONS(6071),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6069),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6069),
    [aux_sym_begin_keywords_token1] = ACTIONS(6069),
    [anon_sym_SEMI] = ACTIONS(6069),
    [anon_sym_endmodule] = ACTIONS(6071),
    [anon_sym_extern] = ACTIONS(6071),
    [anon_sym_module] = ACTIONS(6071),
    [anon_sym_macromodule] = ACTIONS(6071),
    [anon_sym_endinterface] = ACTIONS(6071),
    [anon_sym_interface] = ACTIONS(6071),
    [anon_sym_program] = ACTIONS(6071),
    [anon_sym_checker] = ACTIONS(6071),
    [anon_sym_virtual] = ACTIONS(6071),
    [anon_sym_class] = ACTIONS(6071),
    [anon_sym_package] = ACTIONS(6071),
    [anon_sym_timeunit] = ACTIONS(6071),
    [anon_sym_timeprecision] = ACTIONS(6071),
    [anon_sym_type] = ACTIONS(6071),
    [anon_sym_input] = ACTIONS(6071),
    [anon_sym_output] = ACTIONS(6071),
    [anon_sym_inout] = ACTIONS(6071),
    [anon_sym_ref] = ACTIONS(6071),
    [anon_sym_DOLLARfatal] = ACTIONS(6069),
    [anon_sym_DOLLARerror] = ACTIONS(6069),
    [anon_sym_DOLLARwarning] = ACTIONS(6069),
    [anon_sym_DOLLARinfo] = ACTIONS(6069),
    [anon_sym_default] = ACTIONS(6071),
    [anon_sym_clocking] = ACTIONS(6071),
    [anon_sym_defparam] = ACTIONS(6071),
    [anon_sym_bind] = ACTIONS(6071),
    [anon_sym_const] = ACTIONS(6071),
    [anon_sym_function] = ACTIONS(6071),
    [anon_sym_static] = ACTIONS(6071),
    [anon_sym_constraint] = ACTIONS(6071),
    [anon_sym_if] = ACTIONS(6071),
    [anon_sym_LBRACK] = ACTIONS(6069),
    [anon_sym_localparam] = ACTIONS(6071),
    [anon_sym_parameter] = ACTIONS(6071),
    [anon_sym_specparam] = ACTIONS(6071),
    [anon_sym_var] = ACTIONS(6071),
    [anon_sym_import] = ACTIONS(6071),
    [anon_sym_export] = ACTIONS(6071),
    [anon_sym_genvar] = ACTIONS(6071),
    [anon_sym_interconnect] = ACTIONS(6071),
    [anon_sym_typedef] = ACTIONS(6071),
    [anon_sym_enum] = ACTIONS(6071),
    [anon_sym_struct] = ACTIONS(6071),
    [anon_sym_union] = ACTIONS(6071),
    [anon_sym_nettype] = ACTIONS(6071),
    [anon_sym_automatic] = ACTIONS(6071),
    [anon_sym_string] = ACTIONS(6071),
    [anon_sym_chandle] = ACTIONS(6071),
    [anon_sym_event] = ACTIONS(6071),
    [anon_sym_byte] = ACTIONS(6071),
    [anon_sym_shortint] = ACTIONS(6071),
    [anon_sym_int] = ACTIONS(6071),
    [anon_sym_longint] = ACTIONS(6071),
    [anon_sym_integer] = ACTIONS(6071),
    [anon_sym_time] = ACTIONS(6071),
    [anon_sym_bit] = ACTIONS(6071),
    [anon_sym_logic] = ACTIONS(6071),
    [anon_sym_reg] = ACTIONS(6071),
    [anon_sym_shortreal] = ACTIONS(6071),
    [anon_sym_real] = ACTIONS(6071),
    [anon_sym_realtime] = ACTIONS(6071),
    [anon_sym_supply0] = ACTIONS(6071),
    [anon_sym_supply1] = ACTIONS(6071),
    [anon_sym_signed] = ACTIONS(6071),
    [anon_sym_unsigned] = ACTIONS(6071),
    [anon_sym_task] = ACTIONS(6071),
    [anon_sym_modport] = ACTIONS(6071),
    [anon_sym_assert] = ACTIONS(6071),
    [anon_sym_property] = ACTIONS(6071),
    [anon_sym_assume] = ACTIONS(6071),
    [anon_sym_cover] = ACTIONS(6071),
    [anon_sym_sequence] = ACTIONS(6071),
    [anon_sym_restrict] = ACTIONS(6071),
    [anon_sym_not] = ACTIONS(6071),
    [anon_sym_or] = ACTIONS(6071),
    [anon_sym_and] = ACTIONS(6071),
    [anon_sym_case] = ACTIONS(6071),
    [anon_sym_always] = ACTIONS(6071),
    [anon_sym_covergroup] = ACTIONS(6071),
    [anon_sym_let] = ACTIONS(6071),
    [anon_sym_pulldown] = ACTIONS(6071),
    [anon_sym_pullup] = ACTIONS(6071),
    [anon_sym_cmos] = ACTIONS(6071),
    [anon_sym_rcmos] = ACTIONS(6071),
    [anon_sym_bufif0] = ACTIONS(6071),
    [anon_sym_bufif1] = ACTIONS(6071),
    [anon_sym_notif0] = ACTIONS(6071),
    [anon_sym_notif1] = ACTIONS(6071),
    [anon_sym_nmos] = ACTIONS(6071),
    [anon_sym_pmos] = ACTIONS(6071),
    [anon_sym_rnmos] = ACTIONS(6071),
    [anon_sym_rpmos] = ACTIONS(6071),
    [anon_sym_nand] = ACTIONS(6071),
    [anon_sym_nor] = ACTIONS(6071),
    [anon_sym_xor] = ACTIONS(6071),
    [anon_sym_xnor] = ACTIONS(6071),
    [anon_sym_buf] = ACTIONS(6071),
    [anon_sym_tranif0] = ACTIONS(6071),
    [anon_sym_tranif1] = ACTIONS(6071),
    [anon_sym_rtranif1] = ACTIONS(6071),
    [anon_sym_rtranif0] = ACTIONS(6071),
    [anon_sym_tran] = ACTIONS(6071),
    [anon_sym_rtran] = ACTIONS(6071),
    [anon_sym_generate] = ACTIONS(6071),
    [anon_sym_for] = ACTIONS(6071),
    [anon_sym_primitive] = ACTIONS(6071),
    [anon_sym_initial] = ACTIONS(6071),
    [anon_sym_assign] = ACTIONS(6071),
    [anon_sym_alias] = ACTIONS(6071),
    [anon_sym_always_comb] = ACTIONS(6071),
    [anon_sym_always_latch] = ACTIONS(6071),
    [anon_sym_always_ff] = ACTIONS(6071),
    [anon_sym_final] = ACTIONS(6071),
    [anon_sym_global] = ACTIONS(6071),
    [anon_sym_specify] = ACTIONS(6071),
    [anon_sym_LPAREN_STAR] = ACTIONS(6069),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6069),
    [anon_sym_DOLLARunit] = ACTIONS(6069),
  },
  [1084] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6075),
    [anon_sym_BQUOTE] = ACTIONS(6073),
    [aux_sym_id_directive_token1] = ACTIONS(6075),
    [aux_sym_id_directive_token2] = ACTIONS(6075),
    [aux_sym_id_directive_token3] = ACTIONS(6075),
    [aux_sym_id_directive_token4] = ACTIONS(6073),
    [aux_sym_zero_directive_token1] = ACTIONS(6075),
    [aux_sym_zero_directive_token2] = ACTIONS(6075),
    [aux_sym_zero_directive_token3] = ACTIONS(6075),
    [aux_sym_zero_directive_token4] = ACTIONS(6075),
    [aux_sym_zero_directive_token5] = ACTIONS(6075),
    [aux_sym_zero_directive_token6] = ACTIONS(6075),
    [aux_sym_zero_directive_token7] = ACTIONS(6075),
    [aux_sym_zero_directive_token8] = ACTIONS(6075),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6075),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6075),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_begin_keywords_token1] = ACTIONS(6075),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_endmodule] = ACTIONS(6073),
    [anon_sym_COLON] = ACTIONS(6077),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_module] = ACTIONS(6073),
    [anon_sym_macromodule] = ACTIONS(6073),
    [anon_sym_endinterface] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_endprogram] = ACTIONS(6073),
    [anon_sym_program] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_timeunit] = ACTIONS(6073),
    [anon_sym_timeprecision] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_input] = ACTIONS(6073),
    [anon_sym_output] = ACTIONS(6073),
    [anon_sym_inout] = ACTIONS(6073),
    [anon_sym_ref] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_specparam] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_modport] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_specify] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [1085] = {
    [ts_builtin_sym_end] = ACTIONS(6079),
    [sym_simple_identifier] = ACTIONS(6081),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6079),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6079),
    [anon_sym_BQUOTE] = ACTIONS(6081),
    [aux_sym_id_directive_token1] = ACTIONS(6079),
    [aux_sym_id_directive_token2] = ACTIONS(6079),
    [aux_sym_id_directive_token3] = ACTIONS(6079),
    [aux_sym_id_directive_token4] = ACTIONS(6081),
    [aux_sym_zero_directive_token1] = ACTIONS(6079),
    [aux_sym_zero_directive_token2] = ACTIONS(6079),
    [aux_sym_zero_directive_token3] = ACTIONS(6079),
    [aux_sym_zero_directive_token4] = ACTIONS(6079),
    [aux_sym_zero_directive_token5] = ACTIONS(6079),
    [aux_sym_zero_directive_token6] = ACTIONS(6079),
    [aux_sym_zero_directive_token7] = ACTIONS(6079),
    [aux_sym_zero_directive_token8] = ACTIONS(6079),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6079),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6079),
    [anon_sym_wire] = ACTIONS(6081),
    [anon_sym_tri] = ACTIONS(6081),
    [anon_sym_tri0] = ACTIONS(6081),
    [anon_sym_tri1] = ACTIONS(6081),
    [anon_sym_wand] = ACTIONS(6081),
    [anon_sym_triand] = ACTIONS(6081),
    [anon_sym_wor] = ACTIONS(6081),
    [anon_sym_trior] = ACTIONS(6081),
    [anon_sym_trireg] = ACTIONS(6081),
    [anon_sym_uwire] = ACTIONS(6081),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6079),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6079),
    [aux_sym_begin_keywords_token1] = ACTIONS(6079),
    [anon_sym_SEMI] = ACTIONS(6079),
    [anon_sym_endmodule] = ACTIONS(6081),
    [anon_sym_extern] = ACTIONS(6081),
    [anon_sym_module] = ACTIONS(6081),
    [anon_sym_macromodule] = ACTIONS(6081),
    [anon_sym_endinterface] = ACTIONS(6081),
    [anon_sym_interface] = ACTIONS(6081),
    [anon_sym_program] = ACTIONS(6081),
    [anon_sym_checker] = ACTIONS(6081),
    [anon_sym_virtual] = ACTIONS(6081),
    [anon_sym_class] = ACTIONS(6081),
    [anon_sym_package] = ACTIONS(6081),
    [anon_sym_timeunit] = ACTIONS(6081),
    [anon_sym_timeprecision] = ACTIONS(6081),
    [anon_sym_type] = ACTIONS(6081),
    [anon_sym_input] = ACTIONS(6081),
    [anon_sym_output] = ACTIONS(6081),
    [anon_sym_inout] = ACTIONS(6081),
    [anon_sym_ref] = ACTIONS(6081),
    [anon_sym_DOLLARfatal] = ACTIONS(6079),
    [anon_sym_DOLLARerror] = ACTIONS(6079),
    [anon_sym_DOLLARwarning] = ACTIONS(6079),
    [anon_sym_DOLLARinfo] = ACTIONS(6079),
    [anon_sym_default] = ACTIONS(6081),
    [anon_sym_clocking] = ACTIONS(6081),
    [anon_sym_defparam] = ACTIONS(6081),
    [anon_sym_bind] = ACTIONS(6081),
    [anon_sym_const] = ACTIONS(6081),
    [anon_sym_function] = ACTIONS(6081),
    [anon_sym_static] = ACTIONS(6081),
    [anon_sym_constraint] = ACTIONS(6081),
    [anon_sym_if] = ACTIONS(6081),
    [anon_sym_LBRACK] = ACTIONS(6079),
    [anon_sym_localparam] = ACTIONS(6081),
    [anon_sym_parameter] = ACTIONS(6081),
    [anon_sym_specparam] = ACTIONS(6081),
    [anon_sym_var] = ACTIONS(6081),
    [anon_sym_import] = ACTIONS(6081),
    [anon_sym_export] = ACTIONS(6081),
    [anon_sym_genvar] = ACTIONS(6081),
    [anon_sym_interconnect] = ACTIONS(6081),
    [anon_sym_typedef] = ACTIONS(6081),
    [anon_sym_enum] = ACTIONS(6081),
    [anon_sym_struct] = ACTIONS(6081),
    [anon_sym_union] = ACTIONS(6081),
    [anon_sym_nettype] = ACTIONS(6081),
    [anon_sym_automatic] = ACTIONS(6081),
    [anon_sym_string] = ACTIONS(6081),
    [anon_sym_chandle] = ACTIONS(6081),
    [anon_sym_event] = ACTIONS(6081),
    [anon_sym_byte] = ACTIONS(6081),
    [anon_sym_shortint] = ACTIONS(6081),
    [anon_sym_int] = ACTIONS(6081),
    [anon_sym_longint] = ACTIONS(6081),
    [anon_sym_integer] = ACTIONS(6081),
    [anon_sym_time] = ACTIONS(6081),
    [anon_sym_bit] = ACTIONS(6081),
    [anon_sym_logic] = ACTIONS(6081),
    [anon_sym_reg] = ACTIONS(6081),
    [anon_sym_shortreal] = ACTIONS(6081),
    [anon_sym_real] = ACTIONS(6081),
    [anon_sym_realtime] = ACTIONS(6081),
    [anon_sym_supply0] = ACTIONS(6081),
    [anon_sym_supply1] = ACTIONS(6081),
    [anon_sym_signed] = ACTIONS(6081),
    [anon_sym_unsigned] = ACTIONS(6081),
    [anon_sym_task] = ACTIONS(6081),
    [anon_sym_modport] = ACTIONS(6081),
    [anon_sym_assert] = ACTIONS(6081),
    [anon_sym_property] = ACTIONS(6081),
    [anon_sym_assume] = ACTIONS(6081),
    [anon_sym_cover] = ACTIONS(6081),
    [anon_sym_sequence] = ACTIONS(6081),
    [anon_sym_restrict] = ACTIONS(6081),
    [anon_sym_not] = ACTIONS(6081),
    [anon_sym_or] = ACTIONS(6081),
    [anon_sym_and] = ACTIONS(6081),
    [anon_sym_case] = ACTIONS(6081),
    [anon_sym_always] = ACTIONS(6081),
    [anon_sym_covergroup] = ACTIONS(6081),
    [anon_sym_let] = ACTIONS(6081),
    [anon_sym_pulldown] = ACTIONS(6081),
    [anon_sym_pullup] = ACTIONS(6081),
    [anon_sym_cmos] = ACTIONS(6081),
    [anon_sym_rcmos] = ACTIONS(6081),
    [anon_sym_bufif0] = ACTIONS(6081),
    [anon_sym_bufif1] = ACTIONS(6081),
    [anon_sym_notif0] = ACTIONS(6081),
    [anon_sym_notif1] = ACTIONS(6081),
    [anon_sym_nmos] = ACTIONS(6081),
    [anon_sym_pmos] = ACTIONS(6081),
    [anon_sym_rnmos] = ACTIONS(6081),
    [anon_sym_rpmos] = ACTIONS(6081),
    [anon_sym_nand] = ACTIONS(6081),
    [anon_sym_nor] = ACTIONS(6081),
    [anon_sym_xor] = ACTIONS(6081),
    [anon_sym_xnor] = ACTIONS(6081),
    [anon_sym_buf] = ACTIONS(6081),
    [anon_sym_tranif0] = ACTIONS(6081),
    [anon_sym_tranif1] = ACTIONS(6081),
    [anon_sym_rtranif1] = ACTIONS(6081),
    [anon_sym_rtranif0] = ACTIONS(6081),
    [anon_sym_tran] = ACTIONS(6081),
    [anon_sym_rtran] = ACTIONS(6081),
    [anon_sym_generate] = ACTIONS(6081),
    [anon_sym_for] = ACTIONS(6081),
    [anon_sym_primitive] = ACTIONS(6081),
    [anon_sym_initial] = ACTIONS(6081),
    [anon_sym_assign] = ACTIONS(6081),
    [anon_sym_alias] = ACTIONS(6081),
    [anon_sym_always_comb] = ACTIONS(6081),
    [anon_sym_always_latch] = ACTIONS(6081),
    [anon_sym_always_ff] = ACTIONS(6081),
    [anon_sym_final] = ACTIONS(6081),
    [anon_sym_global] = ACTIONS(6081),
    [anon_sym_specify] = ACTIONS(6081),
    [anon_sym_LPAREN_STAR] = ACTIONS(6079),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6079),
    [anon_sym_DOLLARunit] = ACTIONS(6079),
  },
  [1086] = {
    [sym_simple_identifier] = ACTIONS(6083),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6085),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6085),
    [anon_sym_BQUOTE] = ACTIONS(6083),
    [aux_sym_id_directive_token1] = ACTIONS(6085),
    [aux_sym_id_directive_token2] = ACTIONS(6085),
    [aux_sym_id_directive_token3] = ACTIONS(6085),
    [aux_sym_id_directive_token4] = ACTIONS(6083),
    [aux_sym_zero_directive_token1] = ACTIONS(6085),
    [aux_sym_zero_directive_token2] = ACTIONS(6085),
    [aux_sym_zero_directive_token3] = ACTIONS(6085),
    [aux_sym_zero_directive_token4] = ACTIONS(6085),
    [aux_sym_zero_directive_token5] = ACTIONS(6085),
    [aux_sym_zero_directive_token6] = ACTIONS(6085),
    [aux_sym_zero_directive_token7] = ACTIONS(6085),
    [aux_sym_zero_directive_token8] = ACTIONS(6085),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6085),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6085),
    [anon_sym_wire] = ACTIONS(6083),
    [anon_sym_tri] = ACTIONS(6083),
    [anon_sym_tri0] = ACTIONS(6083),
    [anon_sym_tri1] = ACTIONS(6083),
    [anon_sym_wand] = ACTIONS(6083),
    [anon_sym_triand] = ACTIONS(6083),
    [anon_sym_wor] = ACTIONS(6083),
    [anon_sym_trior] = ACTIONS(6083),
    [anon_sym_trireg] = ACTIONS(6083),
    [anon_sym_uwire] = ACTIONS(6083),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6085),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6085),
    [aux_sym_begin_keywords_token1] = ACTIONS(6085),
    [anon_sym_SEMI] = ACTIONS(6085),
    [anon_sym_endmodule] = ACTIONS(6083),
    [anon_sym_extern] = ACTIONS(6083),
    [anon_sym_module] = ACTIONS(6083),
    [anon_sym_macromodule] = ACTIONS(6083),
    [anon_sym_endinterface] = ACTIONS(6083),
    [anon_sym_interface] = ACTIONS(6083),
    [anon_sym_endprogram] = ACTIONS(6083),
    [anon_sym_program] = ACTIONS(6083),
    [anon_sym_checker] = ACTIONS(6083),
    [anon_sym_virtual] = ACTIONS(6083),
    [anon_sym_class] = ACTIONS(6083),
    [anon_sym_timeunit] = ACTIONS(6083),
    [anon_sym_timeprecision] = ACTIONS(6083),
    [anon_sym_type] = ACTIONS(6083),
    [anon_sym_input] = ACTIONS(6083),
    [anon_sym_output] = ACTIONS(6083),
    [anon_sym_inout] = ACTIONS(6083),
    [anon_sym_ref] = ACTIONS(6083),
    [anon_sym_DOLLARfatal] = ACTIONS(6085),
    [anon_sym_DOLLARerror] = ACTIONS(6085),
    [anon_sym_DOLLARwarning] = ACTIONS(6085),
    [anon_sym_DOLLARinfo] = ACTIONS(6085),
    [anon_sym_default] = ACTIONS(6083),
    [anon_sym_clocking] = ACTIONS(6083),
    [anon_sym_defparam] = ACTIONS(6083),
    [anon_sym_bind] = ACTIONS(6083),
    [anon_sym_const] = ACTIONS(6083),
    [anon_sym_function] = ACTIONS(6083),
    [anon_sym_static] = ACTIONS(6083),
    [anon_sym_constraint] = ACTIONS(6083),
    [anon_sym_if] = ACTIONS(6083),
    [anon_sym_else] = ACTIONS(6083),
    [anon_sym_LBRACK] = ACTIONS(6085),
    [anon_sym_localparam] = ACTIONS(6083),
    [anon_sym_parameter] = ACTIONS(6083),
    [anon_sym_specparam] = ACTIONS(6083),
    [anon_sym_var] = ACTIONS(6083),
    [anon_sym_import] = ACTIONS(6083),
    [anon_sym_export] = ACTIONS(6083),
    [anon_sym_genvar] = ACTIONS(6083),
    [anon_sym_interconnect] = ACTIONS(6083),
    [anon_sym_typedef] = ACTIONS(6083),
    [anon_sym_enum] = ACTIONS(6083),
    [anon_sym_struct] = ACTIONS(6083),
    [anon_sym_union] = ACTIONS(6083),
    [anon_sym_nettype] = ACTIONS(6083),
    [anon_sym_automatic] = ACTIONS(6083),
    [anon_sym_string] = ACTIONS(6083),
    [anon_sym_chandle] = ACTIONS(6083),
    [anon_sym_event] = ACTIONS(6083),
    [anon_sym_byte] = ACTIONS(6083),
    [anon_sym_shortint] = ACTIONS(6083),
    [anon_sym_int] = ACTIONS(6083),
    [anon_sym_longint] = ACTIONS(6083),
    [anon_sym_integer] = ACTIONS(6083),
    [anon_sym_time] = ACTIONS(6083),
    [anon_sym_bit] = ACTIONS(6083),
    [anon_sym_logic] = ACTIONS(6083),
    [anon_sym_reg] = ACTIONS(6083),
    [anon_sym_shortreal] = ACTIONS(6083),
    [anon_sym_real] = ACTIONS(6083),
    [anon_sym_realtime] = ACTIONS(6083),
    [anon_sym_supply0] = ACTIONS(6083),
    [anon_sym_supply1] = ACTIONS(6083),
    [anon_sym_signed] = ACTIONS(6083),
    [anon_sym_unsigned] = ACTIONS(6083),
    [anon_sym_task] = ACTIONS(6083),
    [anon_sym_modport] = ACTIONS(6083),
    [anon_sym_assert] = ACTIONS(6083),
    [anon_sym_property] = ACTIONS(6083),
    [anon_sym_assume] = ACTIONS(6083),
    [anon_sym_cover] = ACTIONS(6083),
    [anon_sym_sequence] = ACTIONS(6083),
    [anon_sym_restrict] = ACTIONS(6083),
    [anon_sym_not] = ACTIONS(6083),
    [anon_sym_or] = ACTIONS(6083),
    [anon_sym_and] = ACTIONS(6083),
    [anon_sym_case] = ACTIONS(6083),
    [anon_sym_always] = ACTIONS(6083),
    [anon_sym_covergroup] = ACTIONS(6083),
    [anon_sym_let] = ACTIONS(6083),
    [anon_sym_pulldown] = ACTIONS(6083),
    [anon_sym_pullup] = ACTIONS(6083),
    [anon_sym_cmos] = ACTIONS(6083),
    [anon_sym_rcmos] = ACTIONS(6083),
    [anon_sym_bufif0] = ACTIONS(6083),
    [anon_sym_bufif1] = ACTIONS(6083),
    [anon_sym_notif0] = ACTIONS(6083),
    [anon_sym_notif1] = ACTIONS(6083),
    [anon_sym_nmos] = ACTIONS(6083),
    [anon_sym_pmos] = ACTIONS(6083),
    [anon_sym_rnmos] = ACTIONS(6083),
    [anon_sym_rpmos] = ACTIONS(6083),
    [anon_sym_nand] = ACTIONS(6083),
    [anon_sym_nor] = ACTIONS(6083),
    [anon_sym_xor] = ACTIONS(6083),
    [anon_sym_xnor] = ACTIONS(6083),
    [anon_sym_buf] = ACTIONS(6083),
    [anon_sym_tranif0] = ACTIONS(6083),
    [anon_sym_tranif1] = ACTIONS(6083),
    [anon_sym_rtranif1] = ACTIONS(6083),
    [anon_sym_rtranif0] = ACTIONS(6083),
    [anon_sym_tran] = ACTIONS(6083),
    [anon_sym_rtran] = ACTIONS(6083),
    [anon_sym_generate] = ACTIONS(6083),
    [anon_sym_for] = ACTIONS(6083),
    [anon_sym_initial] = ACTIONS(6083),
    [anon_sym_assign] = ACTIONS(6083),
    [anon_sym_alias] = ACTIONS(6083),
    [anon_sym_always_comb] = ACTIONS(6083),
    [anon_sym_always_latch] = ACTIONS(6083),
    [anon_sym_always_ff] = ACTIONS(6083),
    [anon_sym_final] = ACTIONS(6083),
    [anon_sym_while] = ACTIONS(6083),
    [anon_sym_global] = ACTIONS(6083),
    [anon_sym_specify] = ACTIONS(6083),
    [anon_sym_LPAREN_STAR] = ACTIONS(6085),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6085),
    [anon_sym_DOLLARunit] = ACTIONS(6085),
  },
  [1087] = {
    [ts_builtin_sym_end] = ACTIONS(6087),
    [sym_simple_identifier] = ACTIONS(6089),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6087),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6087),
    [anon_sym_BQUOTE] = ACTIONS(6089),
    [aux_sym_id_directive_token1] = ACTIONS(6087),
    [aux_sym_id_directive_token2] = ACTIONS(6087),
    [aux_sym_id_directive_token3] = ACTIONS(6087),
    [aux_sym_id_directive_token4] = ACTIONS(6089),
    [aux_sym_zero_directive_token1] = ACTIONS(6087),
    [aux_sym_zero_directive_token2] = ACTIONS(6087),
    [aux_sym_zero_directive_token3] = ACTIONS(6087),
    [aux_sym_zero_directive_token4] = ACTIONS(6087),
    [aux_sym_zero_directive_token5] = ACTIONS(6087),
    [aux_sym_zero_directive_token6] = ACTIONS(6087),
    [aux_sym_zero_directive_token7] = ACTIONS(6087),
    [aux_sym_zero_directive_token8] = ACTIONS(6087),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6087),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6087),
    [anon_sym_wire] = ACTIONS(6089),
    [anon_sym_tri] = ACTIONS(6089),
    [anon_sym_tri0] = ACTIONS(6089),
    [anon_sym_tri1] = ACTIONS(6089),
    [anon_sym_wand] = ACTIONS(6089),
    [anon_sym_triand] = ACTIONS(6089),
    [anon_sym_wor] = ACTIONS(6089),
    [anon_sym_trior] = ACTIONS(6089),
    [anon_sym_trireg] = ACTIONS(6089),
    [anon_sym_uwire] = ACTIONS(6089),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6087),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6087),
    [aux_sym_begin_keywords_token1] = ACTIONS(6087),
    [anon_sym_SEMI] = ACTIONS(6087),
    [anon_sym_endmodule] = ACTIONS(6089),
    [anon_sym_extern] = ACTIONS(6089),
    [anon_sym_module] = ACTIONS(6089),
    [anon_sym_macromodule] = ACTIONS(6089),
    [anon_sym_endinterface] = ACTIONS(6089),
    [anon_sym_interface] = ACTIONS(6089),
    [anon_sym_program] = ACTIONS(6089),
    [anon_sym_checker] = ACTIONS(6089),
    [anon_sym_virtual] = ACTIONS(6089),
    [anon_sym_class] = ACTIONS(6089),
    [anon_sym_package] = ACTIONS(6089),
    [anon_sym_timeunit] = ACTIONS(6089),
    [anon_sym_timeprecision] = ACTIONS(6089),
    [anon_sym_type] = ACTIONS(6089),
    [anon_sym_input] = ACTIONS(6089),
    [anon_sym_output] = ACTIONS(6089),
    [anon_sym_inout] = ACTIONS(6089),
    [anon_sym_ref] = ACTIONS(6089),
    [anon_sym_DOLLARfatal] = ACTIONS(6087),
    [anon_sym_DOLLARerror] = ACTIONS(6087),
    [anon_sym_DOLLARwarning] = ACTIONS(6087),
    [anon_sym_DOLLARinfo] = ACTIONS(6087),
    [anon_sym_default] = ACTIONS(6089),
    [anon_sym_clocking] = ACTIONS(6089),
    [anon_sym_defparam] = ACTIONS(6089),
    [anon_sym_bind] = ACTIONS(6089),
    [anon_sym_const] = ACTIONS(6089),
    [anon_sym_function] = ACTIONS(6089),
    [anon_sym_static] = ACTIONS(6089),
    [anon_sym_constraint] = ACTIONS(6089),
    [anon_sym_if] = ACTIONS(6089),
    [anon_sym_LBRACK] = ACTIONS(6087),
    [anon_sym_localparam] = ACTIONS(6089),
    [anon_sym_parameter] = ACTIONS(6089),
    [anon_sym_specparam] = ACTIONS(6089),
    [anon_sym_var] = ACTIONS(6089),
    [anon_sym_import] = ACTIONS(6089),
    [anon_sym_export] = ACTIONS(6089),
    [anon_sym_genvar] = ACTIONS(6089),
    [anon_sym_interconnect] = ACTIONS(6089),
    [anon_sym_typedef] = ACTIONS(6089),
    [anon_sym_enum] = ACTIONS(6089),
    [anon_sym_struct] = ACTIONS(6089),
    [anon_sym_union] = ACTIONS(6089),
    [anon_sym_nettype] = ACTIONS(6089),
    [anon_sym_automatic] = ACTIONS(6089),
    [anon_sym_string] = ACTIONS(6089),
    [anon_sym_chandle] = ACTIONS(6089),
    [anon_sym_event] = ACTIONS(6089),
    [anon_sym_byte] = ACTIONS(6089),
    [anon_sym_shortint] = ACTIONS(6089),
    [anon_sym_int] = ACTIONS(6089),
    [anon_sym_longint] = ACTIONS(6089),
    [anon_sym_integer] = ACTIONS(6089),
    [anon_sym_time] = ACTIONS(6089),
    [anon_sym_bit] = ACTIONS(6089),
    [anon_sym_logic] = ACTIONS(6089),
    [anon_sym_reg] = ACTIONS(6089),
    [anon_sym_shortreal] = ACTIONS(6089),
    [anon_sym_real] = ACTIONS(6089),
    [anon_sym_realtime] = ACTIONS(6089),
    [anon_sym_supply0] = ACTIONS(6089),
    [anon_sym_supply1] = ACTIONS(6089),
    [anon_sym_signed] = ACTIONS(6089),
    [anon_sym_unsigned] = ACTIONS(6089),
    [anon_sym_task] = ACTIONS(6089),
    [anon_sym_modport] = ACTIONS(6089),
    [anon_sym_assert] = ACTIONS(6089),
    [anon_sym_property] = ACTIONS(6089),
    [anon_sym_assume] = ACTIONS(6089),
    [anon_sym_cover] = ACTIONS(6089),
    [anon_sym_sequence] = ACTIONS(6089),
    [anon_sym_restrict] = ACTIONS(6089),
    [anon_sym_not] = ACTIONS(6089),
    [anon_sym_or] = ACTIONS(6089),
    [anon_sym_and] = ACTIONS(6089),
    [anon_sym_case] = ACTIONS(6089),
    [anon_sym_always] = ACTIONS(6089),
    [anon_sym_covergroup] = ACTIONS(6089),
    [anon_sym_let] = ACTIONS(6089),
    [anon_sym_pulldown] = ACTIONS(6089),
    [anon_sym_pullup] = ACTIONS(6089),
    [anon_sym_cmos] = ACTIONS(6089),
    [anon_sym_rcmos] = ACTIONS(6089),
    [anon_sym_bufif0] = ACTIONS(6089),
    [anon_sym_bufif1] = ACTIONS(6089),
    [anon_sym_notif0] = ACTIONS(6089),
    [anon_sym_notif1] = ACTIONS(6089),
    [anon_sym_nmos] = ACTIONS(6089),
    [anon_sym_pmos] = ACTIONS(6089),
    [anon_sym_rnmos] = ACTIONS(6089),
    [anon_sym_rpmos] = ACTIONS(6089),
    [anon_sym_nand] = ACTIONS(6089),
    [anon_sym_nor] = ACTIONS(6089),
    [anon_sym_xor] = ACTIONS(6089),
    [anon_sym_xnor] = ACTIONS(6089),
    [anon_sym_buf] = ACTIONS(6089),
    [anon_sym_tranif0] = ACTIONS(6089),
    [anon_sym_tranif1] = ACTIONS(6089),
    [anon_sym_rtranif1] = ACTIONS(6089),
    [anon_sym_rtranif0] = ACTIONS(6089),
    [anon_sym_tran] = ACTIONS(6089),
    [anon_sym_rtran] = ACTIONS(6089),
    [anon_sym_generate] = ACTIONS(6089),
    [anon_sym_for] = ACTIONS(6089),
    [anon_sym_primitive] = ACTIONS(6089),
    [anon_sym_initial] = ACTIONS(6089),
    [anon_sym_assign] = ACTIONS(6089),
    [anon_sym_alias] = ACTIONS(6089),
    [anon_sym_always_comb] = ACTIONS(6089),
    [anon_sym_always_latch] = ACTIONS(6089),
    [anon_sym_always_ff] = ACTIONS(6089),
    [anon_sym_final] = ACTIONS(6089),
    [anon_sym_global] = ACTIONS(6089),
    [anon_sym_specify] = ACTIONS(6089),
    [anon_sym_LPAREN_STAR] = ACTIONS(6087),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6087),
    [anon_sym_DOLLARunit] = ACTIONS(6087),
  },
  [1088] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6093),
    [anon_sym_BQUOTE] = ACTIONS(6091),
    [aux_sym_id_directive_token1] = ACTIONS(6093),
    [aux_sym_id_directive_token2] = ACTIONS(6093),
    [aux_sym_id_directive_token3] = ACTIONS(6093),
    [aux_sym_id_directive_token4] = ACTIONS(6091),
    [aux_sym_zero_directive_token1] = ACTIONS(6093),
    [aux_sym_zero_directive_token2] = ACTIONS(6093),
    [aux_sym_zero_directive_token3] = ACTIONS(6093),
    [aux_sym_zero_directive_token4] = ACTIONS(6093),
    [aux_sym_zero_directive_token5] = ACTIONS(6093),
    [aux_sym_zero_directive_token6] = ACTIONS(6093),
    [aux_sym_zero_directive_token7] = ACTIONS(6093),
    [aux_sym_zero_directive_token8] = ACTIONS(6093),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6093),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6093),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_begin_keywords_token1] = ACTIONS(6093),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_endmodule] = ACTIONS(6091),
    [anon_sym_COLON] = ACTIONS(6095),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_module] = ACTIONS(6091),
    [anon_sym_macromodule] = ACTIONS(6091),
    [anon_sym_endinterface] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_endprogram] = ACTIONS(6091),
    [anon_sym_program] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_timeunit] = ACTIONS(6091),
    [anon_sym_timeprecision] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_input] = ACTIONS(6091),
    [anon_sym_output] = ACTIONS(6091),
    [anon_sym_inout] = ACTIONS(6091),
    [anon_sym_ref] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_specparam] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_modport] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_specify] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [1089] = {
    [sym_simple_identifier] = ACTIONS(6097),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6099),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6099),
    [anon_sym_BQUOTE] = ACTIONS(6097),
    [aux_sym_id_directive_token1] = ACTIONS(6099),
    [aux_sym_id_directive_token2] = ACTIONS(6099),
    [aux_sym_id_directive_token3] = ACTIONS(6099),
    [aux_sym_id_directive_token4] = ACTIONS(6097),
    [aux_sym_zero_directive_token1] = ACTIONS(6099),
    [aux_sym_zero_directive_token2] = ACTIONS(6099),
    [aux_sym_zero_directive_token3] = ACTIONS(6099),
    [aux_sym_zero_directive_token4] = ACTIONS(6099),
    [aux_sym_zero_directive_token5] = ACTIONS(6099),
    [aux_sym_zero_directive_token6] = ACTIONS(6099),
    [aux_sym_zero_directive_token7] = ACTIONS(6099),
    [aux_sym_zero_directive_token8] = ACTIONS(6099),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6099),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6099),
    [anon_sym_wire] = ACTIONS(6097),
    [anon_sym_tri] = ACTIONS(6097),
    [anon_sym_tri0] = ACTIONS(6097),
    [anon_sym_tri1] = ACTIONS(6097),
    [anon_sym_wand] = ACTIONS(6097),
    [anon_sym_triand] = ACTIONS(6097),
    [anon_sym_wor] = ACTIONS(6097),
    [anon_sym_trior] = ACTIONS(6097),
    [anon_sym_trireg] = ACTIONS(6097),
    [anon_sym_uwire] = ACTIONS(6097),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6099),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6099),
    [aux_sym_begin_keywords_token1] = ACTIONS(6099),
    [anon_sym_SEMI] = ACTIONS(6099),
    [anon_sym_endmodule] = ACTIONS(6097),
    [anon_sym_extern] = ACTIONS(6097),
    [anon_sym_module] = ACTIONS(6097),
    [anon_sym_macromodule] = ACTIONS(6097),
    [anon_sym_endinterface] = ACTIONS(6097),
    [anon_sym_interface] = ACTIONS(6097),
    [anon_sym_endprogram] = ACTIONS(6097),
    [anon_sym_program] = ACTIONS(6097),
    [anon_sym_checker] = ACTIONS(6097),
    [anon_sym_virtual] = ACTIONS(6097),
    [anon_sym_class] = ACTIONS(6097),
    [anon_sym_timeunit] = ACTIONS(6097),
    [anon_sym_timeprecision] = ACTIONS(6097),
    [anon_sym_type] = ACTIONS(6097),
    [anon_sym_input] = ACTIONS(6097),
    [anon_sym_output] = ACTIONS(6097),
    [anon_sym_inout] = ACTIONS(6097),
    [anon_sym_ref] = ACTIONS(6097),
    [anon_sym_DOLLARfatal] = ACTIONS(6099),
    [anon_sym_DOLLARerror] = ACTIONS(6099),
    [anon_sym_DOLLARwarning] = ACTIONS(6099),
    [anon_sym_DOLLARinfo] = ACTIONS(6099),
    [anon_sym_default] = ACTIONS(6097),
    [anon_sym_clocking] = ACTIONS(6097),
    [anon_sym_defparam] = ACTIONS(6097),
    [anon_sym_bind] = ACTIONS(6097),
    [anon_sym_const] = ACTIONS(6097),
    [anon_sym_function] = ACTIONS(6097),
    [anon_sym_static] = ACTIONS(6097),
    [anon_sym_constraint] = ACTIONS(6097),
    [anon_sym_if] = ACTIONS(6097),
    [anon_sym_else] = ACTIONS(6097),
    [anon_sym_LBRACK] = ACTIONS(6099),
    [anon_sym_localparam] = ACTIONS(6097),
    [anon_sym_parameter] = ACTIONS(6097),
    [anon_sym_specparam] = ACTIONS(6097),
    [anon_sym_var] = ACTIONS(6097),
    [anon_sym_import] = ACTIONS(6097),
    [anon_sym_export] = ACTIONS(6097),
    [anon_sym_genvar] = ACTIONS(6097),
    [anon_sym_interconnect] = ACTIONS(6097),
    [anon_sym_typedef] = ACTIONS(6097),
    [anon_sym_enum] = ACTIONS(6097),
    [anon_sym_struct] = ACTIONS(6097),
    [anon_sym_union] = ACTIONS(6097),
    [anon_sym_nettype] = ACTIONS(6097),
    [anon_sym_automatic] = ACTIONS(6097),
    [anon_sym_string] = ACTIONS(6097),
    [anon_sym_chandle] = ACTIONS(6097),
    [anon_sym_event] = ACTIONS(6097),
    [anon_sym_byte] = ACTIONS(6097),
    [anon_sym_shortint] = ACTIONS(6097),
    [anon_sym_int] = ACTIONS(6097),
    [anon_sym_longint] = ACTIONS(6097),
    [anon_sym_integer] = ACTIONS(6097),
    [anon_sym_time] = ACTIONS(6097),
    [anon_sym_bit] = ACTIONS(6097),
    [anon_sym_logic] = ACTIONS(6097),
    [anon_sym_reg] = ACTIONS(6097),
    [anon_sym_shortreal] = ACTIONS(6097),
    [anon_sym_real] = ACTIONS(6097),
    [anon_sym_realtime] = ACTIONS(6097),
    [anon_sym_supply0] = ACTIONS(6097),
    [anon_sym_supply1] = ACTIONS(6097),
    [anon_sym_signed] = ACTIONS(6097),
    [anon_sym_unsigned] = ACTIONS(6097),
    [anon_sym_task] = ACTIONS(6097),
    [anon_sym_modport] = ACTIONS(6097),
    [anon_sym_assert] = ACTIONS(6097),
    [anon_sym_property] = ACTIONS(6097),
    [anon_sym_assume] = ACTIONS(6097),
    [anon_sym_cover] = ACTIONS(6097),
    [anon_sym_sequence] = ACTIONS(6097),
    [anon_sym_restrict] = ACTIONS(6097),
    [anon_sym_not] = ACTIONS(6097),
    [anon_sym_or] = ACTIONS(6097),
    [anon_sym_and] = ACTIONS(6097),
    [anon_sym_case] = ACTIONS(6097),
    [anon_sym_always] = ACTIONS(6097),
    [anon_sym_covergroup] = ACTIONS(6097),
    [anon_sym_let] = ACTIONS(6097),
    [anon_sym_pulldown] = ACTIONS(6097),
    [anon_sym_pullup] = ACTIONS(6097),
    [anon_sym_cmos] = ACTIONS(6097),
    [anon_sym_rcmos] = ACTIONS(6097),
    [anon_sym_bufif0] = ACTIONS(6097),
    [anon_sym_bufif1] = ACTIONS(6097),
    [anon_sym_notif0] = ACTIONS(6097),
    [anon_sym_notif1] = ACTIONS(6097),
    [anon_sym_nmos] = ACTIONS(6097),
    [anon_sym_pmos] = ACTIONS(6097),
    [anon_sym_rnmos] = ACTIONS(6097),
    [anon_sym_rpmos] = ACTIONS(6097),
    [anon_sym_nand] = ACTIONS(6097),
    [anon_sym_nor] = ACTIONS(6097),
    [anon_sym_xor] = ACTIONS(6097),
    [anon_sym_xnor] = ACTIONS(6097),
    [anon_sym_buf] = ACTIONS(6097),
    [anon_sym_tranif0] = ACTIONS(6097),
    [anon_sym_tranif1] = ACTIONS(6097),
    [anon_sym_rtranif1] = ACTIONS(6097),
    [anon_sym_rtranif0] = ACTIONS(6097),
    [anon_sym_tran] = ACTIONS(6097),
    [anon_sym_rtran] = ACTIONS(6097),
    [anon_sym_generate] = ACTIONS(6097),
    [anon_sym_for] = ACTIONS(6097),
    [anon_sym_initial] = ACTIONS(6097),
    [anon_sym_assign] = ACTIONS(6097),
    [anon_sym_alias] = ACTIONS(6097),
    [anon_sym_always_comb] = ACTIONS(6097),
    [anon_sym_always_latch] = ACTIONS(6097),
    [anon_sym_always_ff] = ACTIONS(6097),
    [anon_sym_final] = ACTIONS(6097),
    [anon_sym_while] = ACTIONS(6097),
    [anon_sym_global] = ACTIONS(6097),
    [anon_sym_specify] = ACTIONS(6097),
    [anon_sym_LPAREN_STAR] = ACTIONS(6099),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6099),
    [anon_sym_DOLLARunit] = ACTIONS(6099),
  },
  [1090] = {
    [sym_simple_identifier] = ACTIONS(6101),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6103),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6103),
    [anon_sym_BQUOTE] = ACTIONS(6101),
    [aux_sym_id_directive_token1] = ACTIONS(6103),
    [aux_sym_id_directive_token2] = ACTIONS(6103),
    [aux_sym_id_directive_token3] = ACTIONS(6103),
    [aux_sym_id_directive_token4] = ACTIONS(6101),
    [aux_sym_zero_directive_token1] = ACTIONS(6103),
    [aux_sym_zero_directive_token2] = ACTIONS(6103),
    [aux_sym_zero_directive_token3] = ACTIONS(6103),
    [aux_sym_zero_directive_token4] = ACTIONS(6103),
    [aux_sym_zero_directive_token5] = ACTIONS(6103),
    [aux_sym_zero_directive_token6] = ACTIONS(6103),
    [aux_sym_zero_directive_token7] = ACTIONS(6103),
    [aux_sym_zero_directive_token8] = ACTIONS(6103),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6103),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6103),
    [anon_sym_wire] = ACTIONS(6101),
    [anon_sym_tri] = ACTIONS(6101),
    [anon_sym_tri0] = ACTIONS(6101),
    [anon_sym_tri1] = ACTIONS(6101),
    [anon_sym_wand] = ACTIONS(6101),
    [anon_sym_triand] = ACTIONS(6101),
    [anon_sym_wor] = ACTIONS(6101),
    [anon_sym_trior] = ACTIONS(6101),
    [anon_sym_trireg] = ACTIONS(6101),
    [anon_sym_uwire] = ACTIONS(6101),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6103),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6103),
    [aux_sym_begin_keywords_token1] = ACTIONS(6103),
    [anon_sym_SEMI] = ACTIONS(6103),
    [anon_sym_endmodule] = ACTIONS(6101),
    [anon_sym_COLON] = ACTIONS(6105),
    [anon_sym_extern] = ACTIONS(6101),
    [anon_sym_module] = ACTIONS(6101),
    [anon_sym_macromodule] = ACTIONS(6101),
    [anon_sym_endinterface] = ACTIONS(6101),
    [anon_sym_interface] = ACTIONS(6101),
    [anon_sym_endprogram] = ACTIONS(6101),
    [anon_sym_program] = ACTIONS(6101),
    [anon_sym_checker] = ACTIONS(6101),
    [anon_sym_virtual] = ACTIONS(6101),
    [anon_sym_class] = ACTIONS(6101),
    [anon_sym_timeunit] = ACTIONS(6101),
    [anon_sym_timeprecision] = ACTIONS(6101),
    [anon_sym_type] = ACTIONS(6101),
    [anon_sym_input] = ACTIONS(6101),
    [anon_sym_output] = ACTIONS(6101),
    [anon_sym_inout] = ACTIONS(6101),
    [anon_sym_ref] = ACTIONS(6101),
    [anon_sym_DOLLARfatal] = ACTIONS(6103),
    [anon_sym_DOLLARerror] = ACTIONS(6103),
    [anon_sym_DOLLARwarning] = ACTIONS(6103),
    [anon_sym_DOLLARinfo] = ACTIONS(6103),
    [anon_sym_default] = ACTIONS(6101),
    [anon_sym_clocking] = ACTIONS(6101),
    [anon_sym_defparam] = ACTIONS(6101),
    [anon_sym_bind] = ACTIONS(6101),
    [anon_sym_const] = ACTIONS(6101),
    [anon_sym_function] = ACTIONS(6101),
    [anon_sym_static] = ACTIONS(6101),
    [anon_sym_constraint] = ACTIONS(6101),
    [anon_sym_if] = ACTIONS(6101),
    [anon_sym_else] = ACTIONS(6101),
    [anon_sym_LBRACK] = ACTIONS(6103),
    [anon_sym_localparam] = ACTIONS(6101),
    [anon_sym_parameter] = ACTIONS(6101),
    [anon_sym_specparam] = ACTIONS(6101),
    [anon_sym_var] = ACTIONS(6101),
    [anon_sym_import] = ACTIONS(6101),
    [anon_sym_export] = ACTIONS(6101),
    [anon_sym_genvar] = ACTIONS(6101),
    [anon_sym_interconnect] = ACTIONS(6101),
    [anon_sym_typedef] = ACTIONS(6101),
    [anon_sym_enum] = ACTIONS(6101),
    [anon_sym_struct] = ACTIONS(6101),
    [anon_sym_union] = ACTIONS(6101),
    [anon_sym_nettype] = ACTIONS(6101),
    [anon_sym_automatic] = ACTIONS(6101),
    [anon_sym_string] = ACTIONS(6101),
    [anon_sym_chandle] = ACTIONS(6101),
    [anon_sym_event] = ACTIONS(6101),
    [anon_sym_byte] = ACTIONS(6101),
    [anon_sym_shortint] = ACTIONS(6101),
    [anon_sym_int] = ACTIONS(6101),
    [anon_sym_longint] = ACTIONS(6101),
    [anon_sym_integer] = ACTIONS(6101),
    [anon_sym_time] = ACTIONS(6101),
    [anon_sym_bit] = ACTIONS(6101),
    [anon_sym_logic] = ACTIONS(6101),
    [anon_sym_reg] = ACTIONS(6101),
    [anon_sym_shortreal] = ACTIONS(6101),
    [anon_sym_real] = ACTIONS(6101),
    [anon_sym_realtime] = ACTIONS(6101),
    [anon_sym_supply0] = ACTIONS(6101),
    [anon_sym_supply1] = ACTIONS(6101),
    [anon_sym_signed] = ACTIONS(6101),
    [anon_sym_unsigned] = ACTIONS(6101),
    [anon_sym_task] = ACTIONS(6101),
    [anon_sym_modport] = ACTIONS(6101),
    [anon_sym_assert] = ACTIONS(6101),
    [anon_sym_property] = ACTIONS(6101),
    [anon_sym_assume] = ACTIONS(6101),
    [anon_sym_cover] = ACTIONS(6101),
    [anon_sym_sequence] = ACTIONS(6101),
    [anon_sym_restrict] = ACTIONS(6101),
    [anon_sym_not] = ACTIONS(6101),
    [anon_sym_or] = ACTIONS(6101),
    [anon_sym_and] = ACTIONS(6101),
    [anon_sym_case] = ACTIONS(6101),
    [anon_sym_always] = ACTIONS(6101),
    [anon_sym_covergroup] = ACTIONS(6101),
    [anon_sym_let] = ACTIONS(6101),
    [anon_sym_pulldown] = ACTIONS(6101),
    [anon_sym_pullup] = ACTIONS(6101),
    [anon_sym_cmos] = ACTIONS(6101),
    [anon_sym_rcmos] = ACTIONS(6101),
    [anon_sym_bufif0] = ACTIONS(6101),
    [anon_sym_bufif1] = ACTIONS(6101),
    [anon_sym_notif0] = ACTIONS(6101),
    [anon_sym_notif1] = ACTIONS(6101),
    [anon_sym_nmos] = ACTIONS(6101),
    [anon_sym_pmos] = ACTIONS(6101),
    [anon_sym_rnmos] = ACTIONS(6101),
    [anon_sym_rpmos] = ACTIONS(6101),
    [anon_sym_nand] = ACTIONS(6101),
    [anon_sym_nor] = ACTIONS(6101),
    [anon_sym_xor] = ACTIONS(6101),
    [anon_sym_xnor] = ACTIONS(6101),
    [anon_sym_buf] = ACTIONS(6101),
    [anon_sym_tranif0] = ACTIONS(6101),
    [anon_sym_tranif1] = ACTIONS(6101),
    [anon_sym_rtranif1] = ACTIONS(6101),
    [anon_sym_rtranif0] = ACTIONS(6101),
    [anon_sym_tran] = ACTIONS(6101),
    [anon_sym_rtran] = ACTIONS(6101),
    [anon_sym_generate] = ACTIONS(6101),
    [anon_sym_for] = ACTIONS(6101),
    [anon_sym_initial] = ACTIONS(6101),
    [anon_sym_assign] = ACTIONS(6101),
    [anon_sym_alias] = ACTIONS(6101),
    [anon_sym_always_comb] = ACTIONS(6101),
    [anon_sym_always_latch] = ACTIONS(6101),
    [anon_sym_always_ff] = ACTIONS(6101),
    [anon_sym_final] = ACTIONS(6101),
    [anon_sym_global] = ACTIONS(6101),
    [anon_sym_specify] = ACTIONS(6101),
    [anon_sym_LPAREN_STAR] = ACTIONS(6103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6103),
    [anon_sym_DOLLARunit] = ACTIONS(6103),
  },
  [1091] = {
    [sym_simple_identifier] = ACTIONS(6107),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6109),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6109),
    [anon_sym_BQUOTE] = ACTIONS(6107),
    [aux_sym_id_directive_token1] = ACTIONS(6109),
    [aux_sym_id_directive_token2] = ACTIONS(6109),
    [aux_sym_id_directive_token3] = ACTIONS(6109),
    [aux_sym_id_directive_token4] = ACTIONS(6107),
    [aux_sym_zero_directive_token1] = ACTIONS(6109),
    [aux_sym_zero_directive_token2] = ACTIONS(6109),
    [aux_sym_zero_directive_token3] = ACTIONS(6109),
    [aux_sym_zero_directive_token4] = ACTIONS(6109),
    [aux_sym_zero_directive_token5] = ACTIONS(6109),
    [aux_sym_zero_directive_token6] = ACTIONS(6109),
    [aux_sym_zero_directive_token7] = ACTIONS(6109),
    [aux_sym_zero_directive_token8] = ACTIONS(6109),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6109),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6109),
    [anon_sym_wire] = ACTIONS(6107),
    [anon_sym_tri] = ACTIONS(6107),
    [anon_sym_tri0] = ACTIONS(6107),
    [anon_sym_tri1] = ACTIONS(6107),
    [anon_sym_wand] = ACTIONS(6107),
    [anon_sym_triand] = ACTIONS(6107),
    [anon_sym_wor] = ACTIONS(6107),
    [anon_sym_trior] = ACTIONS(6107),
    [anon_sym_trireg] = ACTIONS(6107),
    [anon_sym_uwire] = ACTIONS(6107),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6109),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6109),
    [aux_sym_begin_keywords_token1] = ACTIONS(6109),
    [anon_sym_SEMI] = ACTIONS(6109),
    [anon_sym_endmodule] = ACTIONS(6107),
    [anon_sym_extern] = ACTIONS(6107),
    [anon_sym_module] = ACTIONS(6107),
    [anon_sym_macromodule] = ACTIONS(6107),
    [anon_sym_endinterface] = ACTIONS(6107),
    [anon_sym_interface] = ACTIONS(6107),
    [anon_sym_endprogram] = ACTIONS(6107),
    [anon_sym_program] = ACTIONS(6107),
    [anon_sym_checker] = ACTIONS(6107),
    [anon_sym_virtual] = ACTIONS(6107),
    [anon_sym_class] = ACTIONS(6107),
    [anon_sym_timeunit] = ACTIONS(6107),
    [anon_sym_timeprecision] = ACTIONS(6107),
    [anon_sym_type] = ACTIONS(6107),
    [anon_sym_input] = ACTIONS(6107),
    [anon_sym_output] = ACTIONS(6107),
    [anon_sym_inout] = ACTIONS(6107),
    [anon_sym_ref] = ACTIONS(6107),
    [anon_sym_DOLLARfatal] = ACTIONS(6109),
    [anon_sym_DOLLARerror] = ACTIONS(6109),
    [anon_sym_DOLLARwarning] = ACTIONS(6109),
    [anon_sym_DOLLARinfo] = ACTIONS(6109),
    [anon_sym_default] = ACTIONS(6107),
    [anon_sym_clocking] = ACTIONS(6107),
    [anon_sym_defparam] = ACTIONS(6107),
    [anon_sym_bind] = ACTIONS(6107),
    [anon_sym_const] = ACTIONS(6107),
    [anon_sym_function] = ACTIONS(6107),
    [anon_sym_static] = ACTIONS(6107),
    [anon_sym_constraint] = ACTIONS(6107),
    [anon_sym_if] = ACTIONS(6107),
    [anon_sym_else] = ACTIONS(6107),
    [anon_sym_LBRACK] = ACTIONS(6109),
    [anon_sym_localparam] = ACTIONS(6107),
    [anon_sym_parameter] = ACTIONS(6107),
    [anon_sym_specparam] = ACTIONS(6107),
    [anon_sym_var] = ACTIONS(6107),
    [anon_sym_import] = ACTIONS(6107),
    [anon_sym_export] = ACTIONS(6107),
    [anon_sym_genvar] = ACTIONS(6107),
    [anon_sym_interconnect] = ACTIONS(6107),
    [anon_sym_typedef] = ACTIONS(6107),
    [anon_sym_enum] = ACTIONS(6107),
    [anon_sym_struct] = ACTIONS(6107),
    [anon_sym_union] = ACTIONS(6107),
    [anon_sym_nettype] = ACTIONS(6107),
    [anon_sym_automatic] = ACTIONS(6107),
    [anon_sym_string] = ACTIONS(6107),
    [anon_sym_chandle] = ACTIONS(6107),
    [anon_sym_event] = ACTIONS(6107),
    [anon_sym_byte] = ACTIONS(6107),
    [anon_sym_shortint] = ACTIONS(6107),
    [anon_sym_int] = ACTIONS(6107),
    [anon_sym_longint] = ACTIONS(6107),
    [anon_sym_integer] = ACTIONS(6107),
    [anon_sym_time] = ACTIONS(6107),
    [anon_sym_bit] = ACTIONS(6107),
    [anon_sym_logic] = ACTIONS(6107),
    [anon_sym_reg] = ACTIONS(6107),
    [anon_sym_shortreal] = ACTIONS(6107),
    [anon_sym_real] = ACTIONS(6107),
    [anon_sym_realtime] = ACTIONS(6107),
    [anon_sym_supply0] = ACTIONS(6107),
    [anon_sym_supply1] = ACTIONS(6107),
    [anon_sym_signed] = ACTIONS(6107),
    [anon_sym_unsigned] = ACTIONS(6107),
    [anon_sym_task] = ACTIONS(6107),
    [anon_sym_modport] = ACTIONS(6107),
    [anon_sym_assert] = ACTIONS(6107),
    [anon_sym_property] = ACTIONS(6107),
    [anon_sym_assume] = ACTIONS(6107),
    [anon_sym_cover] = ACTIONS(6107),
    [anon_sym_sequence] = ACTIONS(6107),
    [anon_sym_restrict] = ACTIONS(6107),
    [anon_sym_not] = ACTIONS(6107),
    [anon_sym_or] = ACTIONS(6107),
    [anon_sym_and] = ACTIONS(6107),
    [anon_sym_case] = ACTIONS(6107),
    [anon_sym_always] = ACTIONS(6107),
    [anon_sym_covergroup] = ACTIONS(6107),
    [anon_sym_let] = ACTIONS(6107),
    [anon_sym_pulldown] = ACTIONS(6107),
    [anon_sym_pullup] = ACTIONS(6107),
    [anon_sym_cmos] = ACTIONS(6107),
    [anon_sym_rcmos] = ACTIONS(6107),
    [anon_sym_bufif0] = ACTIONS(6107),
    [anon_sym_bufif1] = ACTIONS(6107),
    [anon_sym_notif0] = ACTIONS(6107),
    [anon_sym_notif1] = ACTIONS(6107),
    [anon_sym_nmos] = ACTIONS(6107),
    [anon_sym_pmos] = ACTIONS(6107),
    [anon_sym_rnmos] = ACTIONS(6107),
    [anon_sym_rpmos] = ACTIONS(6107),
    [anon_sym_nand] = ACTIONS(6107),
    [anon_sym_nor] = ACTIONS(6107),
    [anon_sym_xor] = ACTIONS(6107),
    [anon_sym_xnor] = ACTIONS(6107),
    [anon_sym_buf] = ACTIONS(6107),
    [anon_sym_tranif0] = ACTIONS(6107),
    [anon_sym_tranif1] = ACTIONS(6107),
    [anon_sym_rtranif1] = ACTIONS(6107),
    [anon_sym_rtranif0] = ACTIONS(6107),
    [anon_sym_tran] = ACTIONS(6107),
    [anon_sym_rtran] = ACTIONS(6107),
    [anon_sym_generate] = ACTIONS(6107),
    [anon_sym_for] = ACTIONS(6107),
    [anon_sym_initial] = ACTIONS(6107),
    [anon_sym_assign] = ACTIONS(6107),
    [anon_sym_alias] = ACTIONS(6107),
    [anon_sym_always_comb] = ACTIONS(6107),
    [anon_sym_always_latch] = ACTIONS(6107),
    [anon_sym_always_ff] = ACTIONS(6107),
    [anon_sym_final] = ACTIONS(6107),
    [anon_sym_while] = ACTIONS(6107),
    [anon_sym_global] = ACTIONS(6107),
    [anon_sym_specify] = ACTIONS(6107),
    [anon_sym_LPAREN_STAR] = ACTIONS(6109),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6109),
    [anon_sym_DOLLARunit] = ACTIONS(6109),
  },
  [1092] = {
    [sym_simple_identifier] = ACTIONS(6111),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6113),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6113),
    [anon_sym_BQUOTE] = ACTIONS(6111),
    [aux_sym_id_directive_token1] = ACTIONS(6113),
    [aux_sym_id_directive_token2] = ACTIONS(6113),
    [aux_sym_id_directive_token3] = ACTIONS(6113),
    [aux_sym_id_directive_token4] = ACTIONS(6111),
    [aux_sym_zero_directive_token1] = ACTIONS(6113),
    [aux_sym_zero_directive_token2] = ACTIONS(6113),
    [aux_sym_zero_directive_token3] = ACTIONS(6113),
    [aux_sym_zero_directive_token4] = ACTIONS(6113),
    [aux_sym_zero_directive_token5] = ACTIONS(6113),
    [aux_sym_zero_directive_token6] = ACTIONS(6113),
    [aux_sym_zero_directive_token7] = ACTIONS(6113),
    [aux_sym_zero_directive_token8] = ACTIONS(6113),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6113),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6113),
    [anon_sym_wire] = ACTIONS(6111),
    [anon_sym_tri] = ACTIONS(6111),
    [anon_sym_tri0] = ACTIONS(6111),
    [anon_sym_tri1] = ACTIONS(6111),
    [anon_sym_wand] = ACTIONS(6111),
    [anon_sym_triand] = ACTIONS(6111),
    [anon_sym_wor] = ACTIONS(6111),
    [anon_sym_trior] = ACTIONS(6111),
    [anon_sym_trireg] = ACTIONS(6111),
    [anon_sym_uwire] = ACTIONS(6111),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6113),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6113),
    [aux_sym_begin_keywords_token1] = ACTIONS(6113),
    [anon_sym_SEMI] = ACTIONS(6113),
    [anon_sym_endmodule] = ACTIONS(6111),
    [anon_sym_extern] = ACTIONS(6111),
    [anon_sym_module] = ACTIONS(6111),
    [anon_sym_macromodule] = ACTIONS(6111),
    [anon_sym_endinterface] = ACTIONS(6111),
    [anon_sym_interface] = ACTIONS(6111),
    [anon_sym_endprogram] = ACTIONS(6111),
    [anon_sym_program] = ACTIONS(6111),
    [anon_sym_checker] = ACTIONS(6111),
    [anon_sym_virtual] = ACTIONS(6111),
    [anon_sym_class] = ACTIONS(6111),
    [anon_sym_timeunit] = ACTIONS(6111),
    [anon_sym_timeprecision] = ACTIONS(6111),
    [anon_sym_type] = ACTIONS(6111),
    [anon_sym_input] = ACTIONS(6111),
    [anon_sym_output] = ACTIONS(6111),
    [anon_sym_inout] = ACTIONS(6111),
    [anon_sym_ref] = ACTIONS(6111),
    [anon_sym_DOLLARfatal] = ACTIONS(6113),
    [anon_sym_DOLLARerror] = ACTIONS(6113),
    [anon_sym_DOLLARwarning] = ACTIONS(6113),
    [anon_sym_DOLLARinfo] = ACTIONS(6113),
    [anon_sym_default] = ACTIONS(6111),
    [anon_sym_clocking] = ACTIONS(6111),
    [anon_sym_defparam] = ACTIONS(6111),
    [anon_sym_bind] = ACTIONS(6111),
    [anon_sym_const] = ACTIONS(6111),
    [anon_sym_function] = ACTIONS(6111),
    [anon_sym_static] = ACTIONS(6111),
    [anon_sym_constraint] = ACTIONS(6111),
    [anon_sym_if] = ACTIONS(6111),
    [anon_sym_else] = ACTIONS(6111),
    [anon_sym_LBRACK] = ACTIONS(6113),
    [anon_sym_localparam] = ACTIONS(6111),
    [anon_sym_parameter] = ACTIONS(6111),
    [anon_sym_specparam] = ACTIONS(6111),
    [anon_sym_var] = ACTIONS(6111),
    [anon_sym_import] = ACTIONS(6111),
    [anon_sym_export] = ACTIONS(6111),
    [anon_sym_genvar] = ACTIONS(6111),
    [anon_sym_interconnect] = ACTIONS(6111),
    [anon_sym_typedef] = ACTIONS(6111),
    [anon_sym_enum] = ACTIONS(6111),
    [anon_sym_struct] = ACTIONS(6111),
    [anon_sym_union] = ACTIONS(6111),
    [anon_sym_nettype] = ACTIONS(6111),
    [anon_sym_automatic] = ACTIONS(6111),
    [anon_sym_string] = ACTIONS(6111),
    [anon_sym_chandle] = ACTIONS(6111),
    [anon_sym_event] = ACTIONS(6111),
    [anon_sym_byte] = ACTIONS(6111),
    [anon_sym_shortint] = ACTIONS(6111),
    [anon_sym_int] = ACTIONS(6111),
    [anon_sym_longint] = ACTIONS(6111),
    [anon_sym_integer] = ACTIONS(6111),
    [anon_sym_time] = ACTIONS(6111),
    [anon_sym_bit] = ACTIONS(6111),
    [anon_sym_logic] = ACTIONS(6111),
    [anon_sym_reg] = ACTIONS(6111),
    [anon_sym_shortreal] = ACTIONS(6111),
    [anon_sym_real] = ACTIONS(6111),
    [anon_sym_realtime] = ACTIONS(6111),
    [anon_sym_supply0] = ACTIONS(6111),
    [anon_sym_supply1] = ACTIONS(6111),
    [anon_sym_signed] = ACTIONS(6111),
    [anon_sym_unsigned] = ACTIONS(6111),
    [anon_sym_task] = ACTIONS(6111),
    [anon_sym_modport] = ACTIONS(6111),
    [anon_sym_assert] = ACTIONS(6111),
    [anon_sym_property] = ACTIONS(6111),
    [anon_sym_assume] = ACTIONS(6111),
    [anon_sym_cover] = ACTIONS(6111),
    [anon_sym_sequence] = ACTIONS(6111),
    [anon_sym_restrict] = ACTIONS(6111),
    [anon_sym_not] = ACTIONS(6111),
    [anon_sym_or] = ACTIONS(6111),
    [anon_sym_and] = ACTIONS(6111),
    [anon_sym_case] = ACTIONS(6111),
    [anon_sym_always] = ACTIONS(6111),
    [anon_sym_covergroup] = ACTIONS(6111),
    [anon_sym_let] = ACTIONS(6111),
    [anon_sym_pulldown] = ACTIONS(6111),
    [anon_sym_pullup] = ACTIONS(6111),
    [anon_sym_cmos] = ACTIONS(6111),
    [anon_sym_rcmos] = ACTIONS(6111),
    [anon_sym_bufif0] = ACTIONS(6111),
    [anon_sym_bufif1] = ACTIONS(6111),
    [anon_sym_notif0] = ACTIONS(6111),
    [anon_sym_notif1] = ACTIONS(6111),
    [anon_sym_nmos] = ACTIONS(6111),
    [anon_sym_pmos] = ACTIONS(6111),
    [anon_sym_rnmos] = ACTIONS(6111),
    [anon_sym_rpmos] = ACTIONS(6111),
    [anon_sym_nand] = ACTIONS(6111),
    [anon_sym_nor] = ACTIONS(6111),
    [anon_sym_xor] = ACTIONS(6111),
    [anon_sym_xnor] = ACTIONS(6111),
    [anon_sym_buf] = ACTIONS(6111),
    [anon_sym_tranif0] = ACTIONS(6111),
    [anon_sym_tranif1] = ACTIONS(6111),
    [anon_sym_rtranif1] = ACTIONS(6111),
    [anon_sym_rtranif0] = ACTIONS(6111),
    [anon_sym_tran] = ACTIONS(6111),
    [anon_sym_rtran] = ACTIONS(6111),
    [anon_sym_generate] = ACTIONS(6111),
    [anon_sym_for] = ACTIONS(6111),
    [anon_sym_initial] = ACTIONS(6111),
    [anon_sym_assign] = ACTIONS(6111),
    [anon_sym_alias] = ACTIONS(6111),
    [anon_sym_always_comb] = ACTIONS(6111),
    [anon_sym_always_latch] = ACTIONS(6111),
    [anon_sym_always_ff] = ACTIONS(6111),
    [anon_sym_final] = ACTIONS(6111),
    [anon_sym_while] = ACTIONS(6111),
    [anon_sym_global] = ACTIONS(6111),
    [anon_sym_specify] = ACTIONS(6111),
    [anon_sym_LPAREN_STAR] = ACTIONS(6113),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6113),
    [anon_sym_DOLLARunit] = ACTIONS(6113),
  },
  [1093] = {
    [sym_simple_identifier] = ACTIONS(6115),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6117),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6117),
    [anon_sym_BQUOTE] = ACTIONS(6115),
    [aux_sym_id_directive_token1] = ACTIONS(6117),
    [aux_sym_id_directive_token2] = ACTIONS(6117),
    [aux_sym_id_directive_token3] = ACTIONS(6117),
    [aux_sym_id_directive_token4] = ACTIONS(6115),
    [aux_sym_zero_directive_token1] = ACTIONS(6117),
    [aux_sym_zero_directive_token2] = ACTIONS(6117),
    [aux_sym_zero_directive_token3] = ACTIONS(6117),
    [aux_sym_zero_directive_token4] = ACTIONS(6117),
    [aux_sym_zero_directive_token5] = ACTIONS(6117),
    [aux_sym_zero_directive_token6] = ACTIONS(6117),
    [aux_sym_zero_directive_token7] = ACTIONS(6117),
    [aux_sym_zero_directive_token8] = ACTIONS(6117),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6117),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6117),
    [anon_sym_wire] = ACTIONS(6115),
    [anon_sym_tri] = ACTIONS(6115),
    [anon_sym_tri0] = ACTIONS(6115),
    [anon_sym_tri1] = ACTIONS(6115),
    [anon_sym_wand] = ACTIONS(6115),
    [anon_sym_triand] = ACTIONS(6115),
    [anon_sym_wor] = ACTIONS(6115),
    [anon_sym_trior] = ACTIONS(6115),
    [anon_sym_trireg] = ACTIONS(6115),
    [anon_sym_uwire] = ACTIONS(6115),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6117),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6117),
    [aux_sym_begin_keywords_token1] = ACTIONS(6117),
    [anon_sym_SEMI] = ACTIONS(6117),
    [anon_sym_endmodule] = ACTIONS(6115),
    [anon_sym_extern] = ACTIONS(6115),
    [anon_sym_module] = ACTIONS(6115),
    [anon_sym_macromodule] = ACTIONS(6115),
    [anon_sym_endinterface] = ACTIONS(6115),
    [anon_sym_interface] = ACTIONS(6115),
    [anon_sym_endprogram] = ACTIONS(6115),
    [anon_sym_program] = ACTIONS(6115),
    [anon_sym_checker] = ACTIONS(6115),
    [anon_sym_virtual] = ACTIONS(6115),
    [anon_sym_class] = ACTIONS(6115),
    [anon_sym_timeunit] = ACTIONS(6115),
    [anon_sym_timeprecision] = ACTIONS(6115),
    [anon_sym_type] = ACTIONS(6115),
    [anon_sym_input] = ACTIONS(6115),
    [anon_sym_output] = ACTIONS(6115),
    [anon_sym_inout] = ACTIONS(6115),
    [anon_sym_ref] = ACTIONS(6115),
    [anon_sym_DOLLARfatal] = ACTIONS(6117),
    [anon_sym_DOLLARerror] = ACTIONS(6117),
    [anon_sym_DOLLARwarning] = ACTIONS(6117),
    [anon_sym_DOLLARinfo] = ACTIONS(6117),
    [anon_sym_default] = ACTIONS(6115),
    [anon_sym_clocking] = ACTIONS(6115),
    [anon_sym_defparam] = ACTIONS(6115),
    [anon_sym_bind] = ACTIONS(6115),
    [anon_sym_const] = ACTIONS(6115),
    [anon_sym_function] = ACTIONS(6115),
    [anon_sym_static] = ACTIONS(6115),
    [anon_sym_constraint] = ACTIONS(6115),
    [anon_sym_if] = ACTIONS(6115),
    [anon_sym_else] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(6117),
    [anon_sym_localparam] = ACTIONS(6115),
    [anon_sym_parameter] = ACTIONS(6115),
    [anon_sym_specparam] = ACTIONS(6115),
    [anon_sym_var] = ACTIONS(6115),
    [anon_sym_import] = ACTIONS(6115),
    [anon_sym_export] = ACTIONS(6115),
    [anon_sym_genvar] = ACTIONS(6115),
    [anon_sym_interconnect] = ACTIONS(6115),
    [anon_sym_typedef] = ACTIONS(6115),
    [anon_sym_enum] = ACTIONS(6115),
    [anon_sym_struct] = ACTIONS(6115),
    [anon_sym_union] = ACTIONS(6115),
    [anon_sym_nettype] = ACTIONS(6115),
    [anon_sym_automatic] = ACTIONS(6115),
    [anon_sym_string] = ACTIONS(6115),
    [anon_sym_chandle] = ACTIONS(6115),
    [anon_sym_event] = ACTIONS(6115),
    [anon_sym_byte] = ACTIONS(6115),
    [anon_sym_shortint] = ACTIONS(6115),
    [anon_sym_int] = ACTIONS(6115),
    [anon_sym_longint] = ACTIONS(6115),
    [anon_sym_integer] = ACTIONS(6115),
    [anon_sym_time] = ACTIONS(6115),
    [anon_sym_bit] = ACTIONS(6115),
    [anon_sym_logic] = ACTIONS(6115),
    [anon_sym_reg] = ACTIONS(6115),
    [anon_sym_shortreal] = ACTIONS(6115),
    [anon_sym_real] = ACTIONS(6115),
    [anon_sym_realtime] = ACTIONS(6115),
    [anon_sym_supply0] = ACTIONS(6115),
    [anon_sym_supply1] = ACTIONS(6115),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_task] = ACTIONS(6115),
    [anon_sym_modport] = ACTIONS(6115),
    [anon_sym_assert] = ACTIONS(6115),
    [anon_sym_property] = ACTIONS(6115),
    [anon_sym_assume] = ACTIONS(6115),
    [anon_sym_cover] = ACTIONS(6115),
    [anon_sym_sequence] = ACTIONS(6115),
    [anon_sym_restrict] = ACTIONS(6115),
    [anon_sym_not] = ACTIONS(6115),
    [anon_sym_or] = ACTIONS(6115),
    [anon_sym_and] = ACTIONS(6115),
    [anon_sym_case] = ACTIONS(6115),
    [anon_sym_always] = ACTIONS(6115),
    [anon_sym_covergroup] = ACTIONS(6115),
    [anon_sym_let] = ACTIONS(6115),
    [anon_sym_pulldown] = ACTIONS(6115),
    [anon_sym_pullup] = ACTIONS(6115),
    [anon_sym_cmos] = ACTIONS(6115),
    [anon_sym_rcmos] = ACTIONS(6115),
    [anon_sym_bufif0] = ACTIONS(6115),
    [anon_sym_bufif1] = ACTIONS(6115),
    [anon_sym_notif0] = ACTIONS(6115),
    [anon_sym_notif1] = ACTIONS(6115),
    [anon_sym_nmos] = ACTIONS(6115),
    [anon_sym_pmos] = ACTIONS(6115),
    [anon_sym_rnmos] = ACTIONS(6115),
    [anon_sym_rpmos] = ACTIONS(6115),
    [anon_sym_nand] = ACTIONS(6115),
    [anon_sym_nor] = ACTIONS(6115),
    [anon_sym_xor] = ACTIONS(6115),
    [anon_sym_xnor] = ACTIONS(6115),
    [anon_sym_buf] = ACTIONS(6115),
    [anon_sym_tranif0] = ACTIONS(6115),
    [anon_sym_tranif1] = ACTIONS(6115),
    [anon_sym_rtranif1] = ACTIONS(6115),
    [anon_sym_rtranif0] = ACTIONS(6115),
    [anon_sym_tran] = ACTIONS(6115),
    [anon_sym_rtran] = ACTIONS(6115),
    [anon_sym_generate] = ACTIONS(6115),
    [anon_sym_for] = ACTIONS(6115),
    [anon_sym_initial] = ACTIONS(6115),
    [anon_sym_assign] = ACTIONS(6115),
    [anon_sym_alias] = ACTIONS(6115),
    [anon_sym_always_comb] = ACTIONS(6115),
    [anon_sym_always_latch] = ACTIONS(6115),
    [anon_sym_always_ff] = ACTIONS(6115),
    [anon_sym_final] = ACTIONS(6115),
    [anon_sym_while] = ACTIONS(6115),
    [anon_sym_global] = ACTIONS(6115),
    [anon_sym_specify] = ACTIONS(6115),
    [anon_sym_LPAREN_STAR] = ACTIONS(6117),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6117),
    [anon_sym_DOLLARunit] = ACTIONS(6117),
  },
  [1094] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5758),
    [anon_sym_BQUOTE] = ACTIONS(5756),
    [aux_sym_id_directive_token1] = ACTIONS(5758),
    [aux_sym_id_directive_token2] = ACTIONS(5758),
    [aux_sym_id_directive_token3] = ACTIONS(5758),
    [aux_sym_id_directive_token4] = ACTIONS(5756),
    [aux_sym_zero_directive_token1] = ACTIONS(5758),
    [aux_sym_zero_directive_token2] = ACTIONS(5758),
    [aux_sym_zero_directive_token3] = ACTIONS(5758),
    [aux_sym_zero_directive_token4] = ACTIONS(5758),
    [aux_sym_zero_directive_token5] = ACTIONS(5758),
    [aux_sym_zero_directive_token6] = ACTIONS(5758),
    [aux_sym_zero_directive_token7] = ACTIONS(5758),
    [aux_sym_zero_directive_token8] = ACTIONS(5758),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5758),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5758),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5758),
    [aux_sym_begin_keywords_token1] = ACTIONS(5758),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_endmodule] = ACTIONS(5756),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_module] = ACTIONS(5756),
    [anon_sym_macromodule] = ACTIONS(5756),
    [anon_sym_endinterface] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_endprogram] = ACTIONS(5756),
    [anon_sym_program] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_timeunit] = ACTIONS(5756),
    [anon_sym_timeprecision] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_input] = ACTIONS(5756),
    [anon_sym_output] = ACTIONS(5756),
    [anon_sym_inout] = ACTIONS(5756),
    [anon_sym_ref] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_specparam] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_modport] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_while] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_specify] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [1095] = {
    [ts_builtin_sym_end] = ACTIONS(6119),
    [sym_simple_identifier] = ACTIONS(6121),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6119),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6119),
    [anon_sym_BQUOTE] = ACTIONS(6121),
    [aux_sym_id_directive_token1] = ACTIONS(6119),
    [aux_sym_id_directive_token2] = ACTIONS(6119),
    [aux_sym_id_directive_token3] = ACTIONS(6119),
    [aux_sym_id_directive_token4] = ACTIONS(6121),
    [aux_sym_zero_directive_token1] = ACTIONS(6119),
    [aux_sym_zero_directive_token2] = ACTIONS(6119),
    [aux_sym_zero_directive_token3] = ACTIONS(6119),
    [aux_sym_zero_directive_token4] = ACTIONS(6119),
    [aux_sym_zero_directive_token5] = ACTIONS(6119),
    [aux_sym_zero_directive_token6] = ACTIONS(6119),
    [aux_sym_zero_directive_token7] = ACTIONS(6119),
    [aux_sym_zero_directive_token8] = ACTIONS(6119),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6119),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6119),
    [anon_sym_wire] = ACTIONS(6121),
    [anon_sym_tri] = ACTIONS(6121),
    [anon_sym_tri0] = ACTIONS(6121),
    [anon_sym_tri1] = ACTIONS(6121),
    [anon_sym_wand] = ACTIONS(6121),
    [anon_sym_triand] = ACTIONS(6121),
    [anon_sym_wor] = ACTIONS(6121),
    [anon_sym_trior] = ACTIONS(6121),
    [anon_sym_trireg] = ACTIONS(6121),
    [anon_sym_uwire] = ACTIONS(6121),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6119),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6119),
    [aux_sym_begin_keywords_token1] = ACTIONS(6119),
    [anon_sym_SEMI] = ACTIONS(6119),
    [anon_sym_endmodule] = ACTIONS(6121),
    [anon_sym_extern] = ACTIONS(6121),
    [anon_sym_module] = ACTIONS(6121),
    [anon_sym_macromodule] = ACTIONS(6121),
    [anon_sym_endinterface] = ACTIONS(6121),
    [anon_sym_interface] = ACTIONS(6121),
    [anon_sym_program] = ACTIONS(6121),
    [anon_sym_checker] = ACTIONS(6121),
    [anon_sym_virtual] = ACTIONS(6121),
    [anon_sym_class] = ACTIONS(6121),
    [anon_sym_package] = ACTIONS(6121),
    [anon_sym_timeunit] = ACTIONS(6121),
    [anon_sym_timeprecision] = ACTIONS(6121),
    [anon_sym_type] = ACTIONS(6121),
    [anon_sym_input] = ACTIONS(6121),
    [anon_sym_output] = ACTIONS(6121),
    [anon_sym_inout] = ACTIONS(6121),
    [anon_sym_ref] = ACTIONS(6121),
    [anon_sym_DOLLARfatal] = ACTIONS(6119),
    [anon_sym_DOLLARerror] = ACTIONS(6119),
    [anon_sym_DOLLARwarning] = ACTIONS(6119),
    [anon_sym_DOLLARinfo] = ACTIONS(6119),
    [anon_sym_default] = ACTIONS(6121),
    [anon_sym_clocking] = ACTIONS(6121),
    [anon_sym_defparam] = ACTIONS(6121),
    [anon_sym_bind] = ACTIONS(6121),
    [anon_sym_const] = ACTIONS(6121),
    [anon_sym_function] = ACTIONS(6121),
    [anon_sym_static] = ACTIONS(6121),
    [anon_sym_constraint] = ACTIONS(6121),
    [anon_sym_if] = ACTIONS(6121),
    [anon_sym_LBRACK] = ACTIONS(6119),
    [anon_sym_localparam] = ACTIONS(6121),
    [anon_sym_parameter] = ACTIONS(6121),
    [anon_sym_specparam] = ACTIONS(6121),
    [anon_sym_var] = ACTIONS(6121),
    [anon_sym_import] = ACTIONS(6121),
    [anon_sym_export] = ACTIONS(6121),
    [anon_sym_genvar] = ACTIONS(6121),
    [anon_sym_interconnect] = ACTIONS(6121),
    [anon_sym_typedef] = ACTIONS(6121),
    [anon_sym_enum] = ACTIONS(6121),
    [anon_sym_struct] = ACTIONS(6121),
    [anon_sym_union] = ACTIONS(6121),
    [anon_sym_nettype] = ACTIONS(6121),
    [anon_sym_automatic] = ACTIONS(6121),
    [anon_sym_string] = ACTIONS(6121),
    [anon_sym_chandle] = ACTIONS(6121),
    [anon_sym_event] = ACTIONS(6121),
    [anon_sym_byte] = ACTIONS(6121),
    [anon_sym_shortint] = ACTIONS(6121),
    [anon_sym_int] = ACTIONS(6121),
    [anon_sym_longint] = ACTIONS(6121),
    [anon_sym_integer] = ACTIONS(6121),
    [anon_sym_time] = ACTIONS(6121),
    [anon_sym_bit] = ACTIONS(6121),
    [anon_sym_logic] = ACTIONS(6121),
    [anon_sym_reg] = ACTIONS(6121),
    [anon_sym_shortreal] = ACTIONS(6121),
    [anon_sym_real] = ACTIONS(6121),
    [anon_sym_realtime] = ACTIONS(6121),
    [anon_sym_supply0] = ACTIONS(6121),
    [anon_sym_supply1] = ACTIONS(6121),
    [anon_sym_signed] = ACTIONS(6121),
    [anon_sym_unsigned] = ACTIONS(6121),
    [anon_sym_task] = ACTIONS(6121),
    [anon_sym_modport] = ACTIONS(6121),
    [anon_sym_assert] = ACTIONS(6121),
    [anon_sym_property] = ACTIONS(6121),
    [anon_sym_assume] = ACTIONS(6121),
    [anon_sym_cover] = ACTIONS(6121),
    [anon_sym_sequence] = ACTIONS(6121),
    [anon_sym_restrict] = ACTIONS(6121),
    [anon_sym_not] = ACTIONS(6121),
    [anon_sym_or] = ACTIONS(6121),
    [anon_sym_and] = ACTIONS(6121),
    [anon_sym_case] = ACTIONS(6121),
    [anon_sym_always] = ACTIONS(6121),
    [anon_sym_covergroup] = ACTIONS(6121),
    [anon_sym_let] = ACTIONS(6121),
    [anon_sym_pulldown] = ACTIONS(6121),
    [anon_sym_pullup] = ACTIONS(6121),
    [anon_sym_cmos] = ACTIONS(6121),
    [anon_sym_rcmos] = ACTIONS(6121),
    [anon_sym_bufif0] = ACTIONS(6121),
    [anon_sym_bufif1] = ACTIONS(6121),
    [anon_sym_notif0] = ACTIONS(6121),
    [anon_sym_notif1] = ACTIONS(6121),
    [anon_sym_nmos] = ACTIONS(6121),
    [anon_sym_pmos] = ACTIONS(6121),
    [anon_sym_rnmos] = ACTIONS(6121),
    [anon_sym_rpmos] = ACTIONS(6121),
    [anon_sym_nand] = ACTIONS(6121),
    [anon_sym_nor] = ACTIONS(6121),
    [anon_sym_xor] = ACTIONS(6121),
    [anon_sym_xnor] = ACTIONS(6121),
    [anon_sym_buf] = ACTIONS(6121),
    [anon_sym_tranif0] = ACTIONS(6121),
    [anon_sym_tranif1] = ACTIONS(6121),
    [anon_sym_rtranif1] = ACTIONS(6121),
    [anon_sym_rtranif0] = ACTIONS(6121),
    [anon_sym_tran] = ACTIONS(6121),
    [anon_sym_rtran] = ACTIONS(6121),
    [anon_sym_generate] = ACTIONS(6121),
    [anon_sym_for] = ACTIONS(6121),
    [anon_sym_primitive] = ACTIONS(6121),
    [anon_sym_initial] = ACTIONS(6121),
    [anon_sym_assign] = ACTIONS(6121),
    [anon_sym_alias] = ACTIONS(6121),
    [anon_sym_always_comb] = ACTIONS(6121),
    [anon_sym_always_latch] = ACTIONS(6121),
    [anon_sym_always_ff] = ACTIONS(6121),
    [anon_sym_final] = ACTIONS(6121),
    [anon_sym_global] = ACTIONS(6121),
    [anon_sym_specify] = ACTIONS(6121),
    [anon_sym_LPAREN_STAR] = ACTIONS(6119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6119),
    [anon_sym_DOLLARunit] = ACTIONS(6119),
  },
  [1096] = {
    [sym_simple_identifier] = ACTIONS(6123),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6125),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6125),
    [anon_sym_BQUOTE] = ACTIONS(6123),
    [aux_sym_id_directive_token1] = ACTIONS(6125),
    [aux_sym_id_directive_token2] = ACTIONS(6125),
    [aux_sym_id_directive_token3] = ACTIONS(6125),
    [aux_sym_id_directive_token4] = ACTIONS(6123),
    [aux_sym_zero_directive_token1] = ACTIONS(6125),
    [aux_sym_zero_directive_token2] = ACTIONS(6125),
    [aux_sym_zero_directive_token3] = ACTIONS(6125),
    [aux_sym_zero_directive_token4] = ACTIONS(6125),
    [aux_sym_zero_directive_token5] = ACTIONS(6125),
    [aux_sym_zero_directive_token6] = ACTIONS(6125),
    [aux_sym_zero_directive_token7] = ACTIONS(6125),
    [aux_sym_zero_directive_token8] = ACTIONS(6125),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6125),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6125),
    [anon_sym_wire] = ACTIONS(6123),
    [anon_sym_tri] = ACTIONS(6123),
    [anon_sym_tri0] = ACTIONS(6123),
    [anon_sym_tri1] = ACTIONS(6123),
    [anon_sym_wand] = ACTIONS(6123),
    [anon_sym_triand] = ACTIONS(6123),
    [anon_sym_wor] = ACTIONS(6123),
    [anon_sym_trior] = ACTIONS(6123),
    [anon_sym_trireg] = ACTIONS(6123),
    [anon_sym_uwire] = ACTIONS(6123),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6125),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6125),
    [aux_sym_begin_keywords_token1] = ACTIONS(6125),
    [anon_sym_SEMI] = ACTIONS(6125),
    [anon_sym_endmodule] = ACTIONS(6123),
    [anon_sym_extern] = ACTIONS(6123),
    [anon_sym_module] = ACTIONS(6123),
    [anon_sym_macromodule] = ACTIONS(6123),
    [anon_sym_endinterface] = ACTIONS(6123),
    [anon_sym_interface] = ACTIONS(6123),
    [anon_sym_endprogram] = ACTIONS(6123),
    [anon_sym_program] = ACTIONS(6123),
    [anon_sym_checker] = ACTIONS(6123),
    [anon_sym_virtual] = ACTIONS(6123),
    [anon_sym_class] = ACTIONS(6123),
    [anon_sym_timeunit] = ACTIONS(6123),
    [anon_sym_timeprecision] = ACTIONS(6123),
    [anon_sym_type] = ACTIONS(6123),
    [anon_sym_input] = ACTIONS(6123),
    [anon_sym_output] = ACTIONS(6123),
    [anon_sym_inout] = ACTIONS(6123),
    [anon_sym_ref] = ACTIONS(6123),
    [anon_sym_DOLLARfatal] = ACTIONS(6125),
    [anon_sym_DOLLARerror] = ACTIONS(6125),
    [anon_sym_DOLLARwarning] = ACTIONS(6125),
    [anon_sym_DOLLARinfo] = ACTIONS(6125),
    [anon_sym_default] = ACTIONS(6123),
    [anon_sym_clocking] = ACTIONS(6123),
    [anon_sym_defparam] = ACTIONS(6123),
    [anon_sym_bind] = ACTIONS(6123),
    [anon_sym_const] = ACTIONS(6123),
    [anon_sym_function] = ACTIONS(6123),
    [anon_sym_static] = ACTIONS(6123),
    [anon_sym_constraint] = ACTIONS(6123),
    [anon_sym_if] = ACTIONS(6123),
    [anon_sym_else] = ACTIONS(6123),
    [anon_sym_LBRACK] = ACTIONS(6125),
    [anon_sym_localparam] = ACTIONS(6123),
    [anon_sym_parameter] = ACTIONS(6123),
    [anon_sym_specparam] = ACTIONS(6123),
    [anon_sym_var] = ACTIONS(6123),
    [anon_sym_import] = ACTIONS(6123),
    [anon_sym_export] = ACTIONS(6123),
    [anon_sym_genvar] = ACTIONS(6123),
    [anon_sym_interconnect] = ACTIONS(6123),
    [anon_sym_typedef] = ACTIONS(6123),
    [anon_sym_enum] = ACTIONS(6123),
    [anon_sym_struct] = ACTIONS(6123),
    [anon_sym_union] = ACTIONS(6123),
    [anon_sym_nettype] = ACTIONS(6123),
    [anon_sym_automatic] = ACTIONS(6123),
    [anon_sym_string] = ACTIONS(6123),
    [anon_sym_chandle] = ACTIONS(6123),
    [anon_sym_event] = ACTIONS(6123),
    [anon_sym_byte] = ACTIONS(6123),
    [anon_sym_shortint] = ACTIONS(6123),
    [anon_sym_int] = ACTIONS(6123),
    [anon_sym_longint] = ACTIONS(6123),
    [anon_sym_integer] = ACTIONS(6123),
    [anon_sym_time] = ACTIONS(6123),
    [anon_sym_bit] = ACTIONS(6123),
    [anon_sym_logic] = ACTIONS(6123),
    [anon_sym_reg] = ACTIONS(6123),
    [anon_sym_shortreal] = ACTIONS(6123),
    [anon_sym_real] = ACTIONS(6123),
    [anon_sym_realtime] = ACTIONS(6123),
    [anon_sym_supply0] = ACTIONS(6123),
    [anon_sym_supply1] = ACTIONS(6123),
    [anon_sym_signed] = ACTIONS(6123),
    [anon_sym_unsigned] = ACTIONS(6123),
    [anon_sym_task] = ACTIONS(6123),
    [anon_sym_modport] = ACTIONS(6123),
    [anon_sym_assert] = ACTIONS(6123),
    [anon_sym_property] = ACTIONS(6123),
    [anon_sym_assume] = ACTIONS(6123),
    [anon_sym_cover] = ACTIONS(6123),
    [anon_sym_sequence] = ACTIONS(6123),
    [anon_sym_restrict] = ACTIONS(6123),
    [anon_sym_not] = ACTIONS(6123),
    [anon_sym_or] = ACTIONS(6123),
    [anon_sym_and] = ACTIONS(6123),
    [anon_sym_case] = ACTIONS(6123),
    [anon_sym_always] = ACTIONS(6123),
    [anon_sym_covergroup] = ACTIONS(6123),
    [anon_sym_let] = ACTIONS(6123),
    [anon_sym_pulldown] = ACTIONS(6123),
    [anon_sym_pullup] = ACTIONS(6123),
    [anon_sym_cmos] = ACTIONS(6123),
    [anon_sym_rcmos] = ACTIONS(6123),
    [anon_sym_bufif0] = ACTIONS(6123),
    [anon_sym_bufif1] = ACTIONS(6123),
    [anon_sym_notif0] = ACTIONS(6123),
    [anon_sym_notif1] = ACTIONS(6123),
    [anon_sym_nmos] = ACTIONS(6123),
    [anon_sym_pmos] = ACTIONS(6123),
    [anon_sym_rnmos] = ACTIONS(6123),
    [anon_sym_rpmos] = ACTIONS(6123),
    [anon_sym_nand] = ACTIONS(6123),
    [anon_sym_nor] = ACTIONS(6123),
    [anon_sym_xor] = ACTIONS(6123),
    [anon_sym_xnor] = ACTIONS(6123),
    [anon_sym_buf] = ACTIONS(6123),
    [anon_sym_tranif0] = ACTIONS(6123),
    [anon_sym_tranif1] = ACTIONS(6123),
    [anon_sym_rtranif1] = ACTIONS(6123),
    [anon_sym_rtranif0] = ACTIONS(6123),
    [anon_sym_tran] = ACTIONS(6123),
    [anon_sym_rtran] = ACTIONS(6123),
    [anon_sym_generate] = ACTIONS(6123),
    [anon_sym_for] = ACTIONS(6123),
    [anon_sym_initial] = ACTIONS(6123),
    [anon_sym_assign] = ACTIONS(6123),
    [anon_sym_alias] = ACTIONS(6123),
    [anon_sym_always_comb] = ACTIONS(6123),
    [anon_sym_always_latch] = ACTIONS(6123),
    [anon_sym_always_ff] = ACTIONS(6123),
    [anon_sym_final] = ACTIONS(6123),
    [anon_sym_while] = ACTIONS(6123),
    [anon_sym_global] = ACTIONS(6123),
    [anon_sym_specify] = ACTIONS(6123),
    [anon_sym_LPAREN_STAR] = ACTIONS(6125),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6125),
    [anon_sym_DOLLARunit] = ACTIONS(6125),
  },
  [1097] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5696),
    [anon_sym_BQUOTE] = ACTIONS(5694),
    [aux_sym_id_directive_token1] = ACTIONS(5696),
    [aux_sym_id_directive_token2] = ACTIONS(5696),
    [aux_sym_id_directive_token3] = ACTIONS(5696),
    [aux_sym_id_directive_token4] = ACTIONS(5694),
    [aux_sym_zero_directive_token1] = ACTIONS(5696),
    [aux_sym_zero_directive_token2] = ACTIONS(5696),
    [aux_sym_zero_directive_token3] = ACTIONS(5696),
    [aux_sym_zero_directive_token4] = ACTIONS(5696),
    [aux_sym_zero_directive_token5] = ACTIONS(5696),
    [aux_sym_zero_directive_token6] = ACTIONS(5696),
    [aux_sym_zero_directive_token7] = ACTIONS(5696),
    [aux_sym_zero_directive_token8] = ACTIONS(5696),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5696),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5696),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5696),
    [aux_sym_begin_keywords_token1] = ACTIONS(5696),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_endmodule] = ACTIONS(5694),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_module] = ACTIONS(5694),
    [anon_sym_macromodule] = ACTIONS(5694),
    [anon_sym_endinterface] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_endprogram] = ACTIONS(5694),
    [anon_sym_program] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_timeunit] = ACTIONS(5694),
    [anon_sym_timeprecision] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_input] = ACTIONS(5694),
    [anon_sym_output] = ACTIONS(5694),
    [anon_sym_inout] = ACTIONS(5694),
    [anon_sym_ref] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_specparam] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_modport] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_while] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_specify] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [1098] = {
    [ts_builtin_sym_end] = ACTIONS(6127),
    [sym_simple_identifier] = ACTIONS(6129),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6127),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6127),
    [anon_sym_BQUOTE] = ACTIONS(6129),
    [aux_sym_id_directive_token1] = ACTIONS(6127),
    [aux_sym_id_directive_token2] = ACTIONS(6127),
    [aux_sym_id_directive_token3] = ACTIONS(6127),
    [aux_sym_id_directive_token4] = ACTIONS(6129),
    [aux_sym_zero_directive_token1] = ACTIONS(6127),
    [aux_sym_zero_directive_token2] = ACTIONS(6127),
    [aux_sym_zero_directive_token3] = ACTIONS(6127),
    [aux_sym_zero_directive_token4] = ACTIONS(6127),
    [aux_sym_zero_directive_token5] = ACTIONS(6127),
    [aux_sym_zero_directive_token6] = ACTIONS(6127),
    [aux_sym_zero_directive_token7] = ACTIONS(6127),
    [aux_sym_zero_directive_token8] = ACTIONS(6127),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6127),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6127),
    [anon_sym_wire] = ACTIONS(6129),
    [anon_sym_tri] = ACTIONS(6129),
    [anon_sym_tri0] = ACTIONS(6129),
    [anon_sym_tri1] = ACTIONS(6129),
    [anon_sym_wand] = ACTIONS(6129),
    [anon_sym_triand] = ACTIONS(6129),
    [anon_sym_wor] = ACTIONS(6129),
    [anon_sym_trior] = ACTIONS(6129),
    [anon_sym_trireg] = ACTIONS(6129),
    [anon_sym_uwire] = ACTIONS(6129),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6127),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6127),
    [aux_sym_begin_keywords_token1] = ACTIONS(6127),
    [anon_sym_SEMI] = ACTIONS(6127),
    [anon_sym_endmodule] = ACTIONS(6129),
    [anon_sym_extern] = ACTIONS(6129),
    [anon_sym_module] = ACTIONS(6129),
    [anon_sym_macromodule] = ACTIONS(6129),
    [anon_sym_endinterface] = ACTIONS(6129),
    [anon_sym_interface] = ACTIONS(6129),
    [anon_sym_program] = ACTIONS(6129),
    [anon_sym_checker] = ACTIONS(6129),
    [anon_sym_virtual] = ACTIONS(6129),
    [anon_sym_class] = ACTIONS(6129),
    [anon_sym_package] = ACTIONS(6129),
    [anon_sym_timeunit] = ACTIONS(6129),
    [anon_sym_timeprecision] = ACTIONS(6129),
    [anon_sym_type] = ACTIONS(6129),
    [anon_sym_input] = ACTIONS(6129),
    [anon_sym_output] = ACTIONS(6129),
    [anon_sym_inout] = ACTIONS(6129),
    [anon_sym_ref] = ACTIONS(6129),
    [anon_sym_DOLLARfatal] = ACTIONS(6127),
    [anon_sym_DOLLARerror] = ACTIONS(6127),
    [anon_sym_DOLLARwarning] = ACTIONS(6127),
    [anon_sym_DOLLARinfo] = ACTIONS(6127),
    [anon_sym_default] = ACTIONS(6129),
    [anon_sym_clocking] = ACTIONS(6129),
    [anon_sym_defparam] = ACTIONS(6129),
    [anon_sym_bind] = ACTIONS(6129),
    [anon_sym_const] = ACTIONS(6129),
    [anon_sym_function] = ACTIONS(6129),
    [anon_sym_static] = ACTIONS(6129),
    [anon_sym_constraint] = ACTIONS(6129),
    [anon_sym_if] = ACTIONS(6129),
    [anon_sym_LBRACK] = ACTIONS(6127),
    [anon_sym_localparam] = ACTIONS(6129),
    [anon_sym_parameter] = ACTIONS(6129),
    [anon_sym_specparam] = ACTIONS(6129),
    [anon_sym_var] = ACTIONS(6129),
    [anon_sym_import] = ACTIONS(6129),
    [anon_sym_export] = ACTIONS(6129),
    [anon_sym_genvar] = ACTIONS(6129),
    [anon_sym_interconnect] = ACTIONS(6129),
    [anon_sym_typedef] = ACTIONS(6129),
    [anon_sym_enum] = ACTIONS(6129),
    [anon_sym_struct] = ACTIONS(6129),
    [anon_sym_union] = ACTIONS(6129),
    [anon_sym_nettype] = ACTIONS(6129),
    [anon_sym_automatic] = ACTIONS(6129),
    [anon_sym_string] = ACTIONS(6129),
    [anon_sym_chandle] = ACTIONS(6129),
    [anon_sym_event] = ACTIONS(6129),
    [anon_sym_byte] = ACTIONS(6129),
    [anon_sym_shortint] = ACTIONS(6129),
    [anon_sym_int] = ACTIONS(6129),
    [anon_sym_longint] = ACTIONS(6129),
    [anon_sym_integer] = ACTIONS(6129),
    [anon_sym_time] = ACTIONS(6129),
    [anon_sym_bit] = ACTIONS(6129),
    [anon_sym_logic] = ACTIONS(6129),
    [anon_sym_reg] = ACTIONS(6129),
    [anon_sym_shortreal] = ACTIONS(6129),
    [anon_sym_real] = ACTIONS(6129),
    [anon_sym_realtime] = ACTIONS(6129),
    [anon_sym_supply0] = ACTIONS(6129),
    [anon_sym_supply1] = ACTIONS(6129),
    [anon_sym_signed] = ACTIONS(6129),
    [anon_sym_unsigned] = ACTIONS(6129),
    [anon_sym_task] = ACTIONS(6129),
    [anon_sym_modport] = ACTIONS(6129),
    [anon_sym_assert] = ACTIONS(6129),
    [anon_sym_property] = ACTIONS(6129),
    [anon_sym_assume] = ACTIONS(6129),
    [anon_sym_cover] = ACTIONS(6129),
    [anon_sym_sequence] = ACTIONS(6129),
    [anon_sym_restrict] = ACTIONS(6129),
    [anon_sym_not] = ACTIONS(6129),
    [anon_sym_or] = ACTIONS(6129),
    [anon_sym_and] = ACTIONS(6129),
    [anon_sym_case] = ACTIONS(6129),
    [anon_sym_always] = ACTIONS(6129),
    [anon_sym_covergroup] = ACTIONS(6129),
    [anon_sym_let] = ACTIONS(6129),
    [anon_sym_pulldown] = ACTIONS(6129),
    [anon_sym_pullup] = ACTIONS(6129),
    [anon_sym_cmos] = ACTIONS(6129),
    [anon_sym_rcmos] = ACTIONS(6129),
    [anon_sym_bufif0] = ACTIONS(6129),
    [anon_sym_bufif1] = ACTIONS(6129),
    [anon_sym_notif0] = ACTIONS(6129),
    [anon_sym_notif1] = ACTIONS(6129),
    [anon_sym_nmos] = ACTIONS(6129),
    [anon_sym_pmos] = ACTIONS(6129),
    [anon_sym_rnmos] = ACTIONS(6129),
    [anon_sym_rpmos] = ACTIONS(6129),
    [anon_sym_nand] = ACTIONS(6129),
    [anon_sym_nor] = ACTIONS(6129),
    [anon_sym_xor] = ACTIONS(6129),
    [anon_sym_xnor] = ACTIONS(6129),
    [anon_sym_buf] = ACTIONS(6129),
    [anon_sym_tranif0] = ACTIONS(6129),
    [anon_sym_tranif1] = ACTIONS(6129),
    [anon_sym_rtranif1] = ACTIONS(6129),
    [anon_sym_rtranif0] = ACTIONS(6129),
    [anon_sym_tran] = ACTIONS(6129),
    [anon_sym_rtran] = ACTIONS(6129),
    [anon_sym_generate] = ACTIONS(6129),
    [anon_sym_for] = ACTIONS(6129),
    [anon_sym_primitive] = ACTIONS(6129),
    [anon_sym_initial] = ACTIONS(6129),
    [anon_sym_assign] = ACTIONS(6129),
    [anon_sym_alias] = ACTIONS(6129),
    [anon_sym_always_comb] = ACTIONS(6129),
    [anon_sym_always_latch] = ACTIONS(6129),
    [anon_sym_always_ff] = ACTIONS(6129),
    [anon_sym_final] = ACTIONS(6129),
    [anon_sym_global] = ACTIONS(6129),
    [anon_sym_specify] = ACTIONS(6129),
    [anon_sym_LPAREN_STAR] = ACTIONS(6127),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6127),
    [anon_sym_DOLLARunit] = ACTIONS(6127),
  },
  [1099] = {
    [sym_simple_identifier] = ACTIONS(6131),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6133),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6133),
    [anon_sym_BQUOTE] = ACTIONS(6131),
    [aux_sym_id_directive_token1] = ACTIONS(6133),
    [aux_sym_id_directive_token2] = ACTIONS(6133),
    [aux_sym_id_directive_token3] = ACTIONS(6133),
    [aux_sym_id_directive_token4] = ACTIONS(6131),
    [aux_sym_zero_directive_token1] = ACTIONS(6133),
    [aux_sym_zero_directive_token2] = ACTIONS(6133),
    [aux_sym_zero_directive_token3] = ACTIONS(6133),
    [aux_sym_zero_directive_token4] = ACTIONS(6133),
    [aux_sym_zero_directive_token5] = ACTIONS(6133),
    [aux_sym_zero_directive_token6] = ACTIONS(6133),
    [aux_sym_zero_directive_token7] = ACTIONS(6133),
    [aux_sym_zero_directive_token8] = ACTIONS(6133),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6133),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6133),
    [anon_sym_wire] = ACTIONS(6131),
    [anon_sym_tri] = ACTIONS(6131),
    [anon_sym_tri0] = ACTIONS(6131),
    [anon_sym_tri1] = ACTIONS(6131),
    [anon_sym_wand] = ACTIONS(6131),
    [anon_sym_triand] = ACTIONS(6131),
    [anon_sym_wor] = ACTIONS(6131),
    [anon_sym_trior] = ACTIONS(6131),
    [anon_sym_trireg] = ACTIONS(6131),
    [anon_sym_uwire] = ACTIONS(6131),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6133),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6133),
    [aux_sym_begin_keywords_token1] = ACTIONS(6133),
    [anon_sym_SEMI] = ACTIONS(6133),
    [anon_sym_endmodule] = ACTIONS(6131),
    [anon_sym_extern] = ACTIONS(6131),
    [anon_sym_module] = ACTIONS(6131),
    [anon_sym_macromodule] = ACTIONS(6131),
    [anon_sym_endinterface] = ACTIONS(6131),
    [anon_sym_interface] = ACTIONS(6131),
    [anon_sym_endprogram] = ACTIONS(6131),
    [anon_sym_program] = ACTIONS(6131),
    [anon_sym_checker] = ACTIONS(6131),
    [anon_sym_virtual] = ACTIONS(6131),
    [anon_sym_class] = ACTIONS(6131),
    [anon_sym_timeunit] = ACTIONS(6131),
    [anon_sym_timeprecision] = ACTIONS(6131),
    [anon_sym_type] = ACTIONS(6131),
    [anon_sym_input] = ACTIONS(6131),
    [anon_sym_output] = ACTIONS(6131),
    [anon_sym_inout] = ACTIONS(6131),
    [anon_sym_ref] = ACTIONS(6131),
    [anon_sym_DOLLARfatal] = ACTIONS(6133),
    [anon_sym_DOLLARerror] = ACTIONS(6133),
    [anon_sym_DOLLARwarning] = ACTIONS(6133),
    [anon_sym_DOLLARinfo] = ACTIONS(6133),
    [anon_sym_default] = ACTIONS(6131),
    [anon_sym_clocking] = ACTIONS(6131),
    [anon_sym_defparam] = ACTIONS(6131),
    [anon_sym_bind] = ACTIONS(6131),
    [anon_sym_const] = ACTIONS(6131),
    [anon_sym_function] = ACTIONS(6131),
    [anon_sym_static] = ACTIONS(6131),
    [anon_sym_constraint] = ACTIONS(6131),
    [anon_sym_if] = ACTIONS(6131),
    [anon_sym_else] = ACTIONS(6131),
    [anon_sym_LBRACK] = ACTIONS(6133),
    [anon_sym_localparam] = ACTIONS(6131),
    [anon_sym_parameter] = ACTIONS(6131),
    [anon_sym_specparam] = ACTIONS(6131),
    [anon_sym_var] = ACTIONS(6131),
    [anon_sym_import] = ACTIONS(6131),
    [anon_sym_export] = ACTIONS(6131),
    [anon_sym_genvar] = ACTIONS(6131),
    [anon_sym_interconnect] = ACTIONS(6131),
    [anon_sym_typedef] = ACTIONS(6131),
    [anon_sym_enum] = ACTIONS(6131),
    [anon_sym_struct] = ACTIONS(6131),
    [anon_sym_union] = ACTIONS(6131),
    [anon_sym_nettype] = ACTIONS(6131),
    [anon_sym_automatic] = ACTIONS(6131),
    [anon_sym_string] = ACTIONS(6131),
    [anon_sym_chandle] = ACTIONS(6131),
    [anon_sym_event] = ACTIONS(6131),
    [anon_sym_byte] = ACTIONS(6131),
    [anon_sym_shortint] = ACTIONS(6131),
    [anon_sym_int] = ACTIONS(6131),
    [anon_sym_longint] = ACTIONS(6131),
    [anon_sym_integer] = ACTIONS(6131),
    [anon_sym_time] = ACTIONS(6131),
    [anon_sym_bit] = ACTIONS(6131),
    [anon_sym_logic] = ACTIONS(6131),
    [anon_sym_reg] = ACTIONS(6131),
    [anon_sym_shortreal] = ACTIONS(6131),
    [anon_sym_real] = ACTIONS(6131),
    [anon_sym_realtime] = ACTIONS(6131),
    [anon_sym_supply0] = ACTIONS(6131),
    [anon_sym_supply1] = ACTIONS(6131),
    [anon_sym_signed] = ACTIONS(6131),
    [anon_sym_unsigned] = ACTIONS(6131),
    [anon_sym_task] = ACTIONS(6131),
    [anon_sym_modport] = ACTIONS(6131),
    [anon_sym_assert] = ACTIONS(6131),
    [anon_sym_property] = ACTIONS(6131),
    [anon_sym_assume] = ACTIONS(6131),
    [anon_sym_cover] = ACTIONS(6131),
    [anon_sym_sequence] = ACTIONS(6131),
    [anon_sym_restrict] = ACTIONS(6131),
    [anon_sym_not] = ACTIONS(6131),
    [anon_sym_or] = ACTIONS(6131),
    [anon_sym_and] = ACTIONS(6131),
    [anon_sym_case] = ACTIONS(6131),
    [anon_sym_always] = ACTIONS(6131),
    [anon_sym_covergroup] = ACTIONS(6131),
    [anon_sym_let] = ACTIONS(6131),
    [anon_sym_pulldown] = ACTIONS(6131),
    [anon_sym_pullup] = ACTIONS(6131),
    [anon_sym_cmos] = ACTIONS(6131),
    [anon_sym_rcmos] = ACTIONS(6131),
    [anon_sym_bufif0] = ACTIONS(6131),
    [anon_sym_bufif1] = ACTIONS(6131),
    [anon_sym_notif0] = ACTIONS(6131),
    [anon_sym_notif1] = ACTIONS(6131),
    [anon_sym_nmos] = ACTIONS(6131),
    [anon_sym_pmos] = ACTIONS(6131),
    [anon_sym_rnmos] = ACTIONS(6131),
    [anon_sym_rpmos] = ACTIONS(6131),
    [anon_sym_nand] = ACTIONS(6131),
    [anon_sym_nor] = ACTIONS(6131),
    [anon_sym_xor] = ACTIONS(6131),
    [anon_sym_xnor] = ACTIONS(6131),
    [anon_sym_buf] = ACTIONS(6131),
    [anon_sym_tranif0] = ACTIONS(6131),
    [anon_sym_tranif1] = ACTIONS(6131),
    [anon_sym_rtranif1] = ACTIONS(6131),
    [anon_sym_rtranif0] = ACTIONS(6131),
    [anon_sym_tran] = ACTIONS(6131),
    [anon_sym_rtran] = ACTIONS(6131),
    [anon_sym_generate] = ACTIONS(6131),
    [anon_sym_for] = ACTIONS(6131),
    [anon_sym_initial] = ACTIONS(6131),
    [anon_sym_assign] = ACTIONS(6131),
    [anon_sym_alias] = ACTIONS(6131),
    [anon_sym_always_comb] = ACTIONS(6131),
    [anon_sym_always_latch] = ACTIONS(6131),
    [anon_sym_always_ff] = ACTIONS(6131),
    [anon_sym_final] = ACTIONS(6131),
    [anon_sym_while] = ACTIONS(6131),
    [anon_sym_global] = ACTIONS(6131),
    [anon_sym_specify] = ACTIONS(6131),
    [anon_sym_LPAREN_STAR] = ACTIONS(6133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6133),
    [anon_sym_DOLLARunit] = ACTIONS(6133),
  },
  [1100] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5967),
    [anon_sym_BQUOTE] = ACTIONS(5965),
    [aux_sym_id_directive_token1] = ACTIONS(5967),
    [aux_sym_id_directive_token2] = ACTIONS(5967),
    [aux_sym_id_directive_token3] = ACTIONS(5967),
    [aux_sym_id_directive_token4] = ACTIONS(5965),
    [aux_sym_zero_directive_token1] = ACTIONS(5967),
    [aux_sym_zero_directive_token2] = ACTIONS(5967),
    [aux_sym_zero_directive_token3] = ACTIONS(5967),
    [aux_sym_zero_directive_token4] = ACTIONS(5967),
    [aux_sym_zero_directive_token5] = ACTIONS(5967),
    [aux_sym_zero_directive_token6] = ACTIONS(5967),
    [aux_sym_zero_directive_token7] = ACTIONS(5967),
    [aux_sym_zero_directive_token8] = ACTIONS(5967),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5967),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5967),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5967),
    [aux_sym_begin_keywords_token1] = ACTIONS(5967),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_endmodule] = ACTIONS(5965),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_module] = ACTIONS(5965),
    [anon_sym_macromodule] = ACTIONS(5965),
    [anon_sym_endinterface] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_endprogram] = ACTIONS(5965),
    [anon_sym_program] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_timeunit] = ACTIONS(5965),
    [anon_sym_timeprecision] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_input] = ACTIONS(5965),
    [anon_sym_output] = ACTIONS(5965),
    [anon_sym_inout] = ACTIONS(5965),
    [anon_sym_ref] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(6135),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_specparam] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_modport] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_while] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_specify] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [1101] = {
    [sym_simple_identifier] = ACTIONS(6137),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6139),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6139),
    [anon_sym_BQUOTE] = ACTIONS(6137),
    [aux_sym_id_directive_token1] = ACTIONS(6139),
    [aux_sym_id_directive_token2] = ACTIONS(6139),
    [aux_sym_id_directive_token3] = ACTIONS(6139),
    [aux_sym_id_directive_token4] = ACTIONS(6137),
    [aux_sym_zero_directive_token1] = ACTIONS(6139),
    [aux_sym_zero_directive_token2] = ACTIONS(6139),
    [aux_sym_zero_directive_token3] = ACTIONS(6139),
    [aux_sym_zero_directive_token4] = ACTIONS(6139),
    [aux_sym_zero_directive_token5] = ACTIONS(6139),
    [aux_sym_zero_directive_token6] = ACTIONS(6139),
    [aux_sym_zero_directive_token7] = ACTIONS(6139),
    [aux_sym_zero_directive_token8] = ACTIONS(6139),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6139),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6139),
    [anon_sym_wire] = ACTIONS(6137),
    [anon_sym_tri] = ACTIONS(6137),
    [anon_sym_tri0] = ACTIONS(6137),
    [anon_sym_tri1] = ACTIONS(6137),
    [anon_sym_wand] = ACTIONS(6137),
    [anon_sym_triand] = ACTIONS(6137),
    [anon_sym_wor] = ACTIONS(6137),
    [anon_sym_trior] = ACTIONS(6137),
    [anon_sym_trireg] = ACTIONS(6137),
    [anon_sym_uwire] = ACTIONS(6137),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6139),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6139),
    [aux_sym_begin_keywords_token1] = ACTIONS(6139),
    [anon_sym_SEMI] = ACTIONS(6139),
    [anon_sym_endmodule] = ACTIONS(6137),
    [anon_sym_extern] = ACTIONS(6137),
    [anon_sym_module] = ACTIONS(6137),
    [anon_sym_macromodule] = ACTIONS(6137),
    [anon_sym_endinterface] = ACTIONS(6137),
    [anon_sym_interface] = ACTIONS(6137),
    [anon_sym_endprogram] = ACTIONS(6137),
    [anon_sym_program] = ACTIONS(6137),
    [anon_sym_checker] = ACTIONS(6137),
    [anon_sym_virtual] = ACTIONS(6137),
    [anon_sym_class] = ACTIONS(6137),
    [anon_sym_timeunit] = ACTIONS(6137),
    [anon_sym_timeprecision] = ACTIONS(6137),
    [anon_sym_type] = ACTIONS(6137),
    [anon_sym_input] = ACTIONS(6137),
    [anon_sym_output] = ACTIONS(6137),
    [anon_sym_inout] = ACTIONS(6137),
    [anon_sym_ref] = ACTIONS(6137),
    [anon_sym_DOLLARfatal] = ACTIONS(6139),
    [anon_sym_DOLLARerror] = ACTIONS(6139),
    [anon_sym_DOLLARwarning] = ACTIONS(6139),
    [anon_sym_DOLLARinfo] = ACTIONS(6139),
    [anon_sym_default] = ACTIONS(6137),
    [anon_sym_clocking] = ACTIONS(6137),
    [anon_sym_defparam] = ACTIONS(6137),
    [anon_sym_bind] = ACTIONS(6137),
    [anon_sym_const] = ACTIONS(6137),
    [anon_sym_function] = ACTIONS(6137),
    [anon_sym_static] = ACTIONS(6137),
    [anon_sym_constraint] = ACTIONS(6137),
    [anon_sym_if] = ACTIONS(6137),
    [anon_sym_else] = ACTIONS(6137),
    [anon_sym_LBRACK] = ACTIONS(6139),
    [anon_sym_localparam] = ACTIONS(6137),
    [anon_sym_parameter] = ACTIONS(6137),
    [anon_sym_specparam] = ACTIONS(6137),
    [anon_sym_var] = ACTIONS(6137),
    [anon_sym_import] = ACTIONS(6137),
    [anon_sym_export] = ACTIONS(6137),
    [anon_sym_genvar] = ACTIONS(6137),
    [anon_sym_interconnect] = ACTIONS(6137),
    [anon_sym_typedef] = ACTIONS(6137),
    [anon_sym_enum] = ACTIONS(6137),
    [anon_sym_struct] = ACTIONS(6137),
    [anon_sym_union] = ACTIONS(6137),
    [anon_sym_nettype] = ACTIONS(6137),
    [anon_sym_automatic] = ACTIONS(6137),
    [anon_sym_string] = ACTIONS(6137),
    [anon_sym_chandle] = ACTIONS(6137),
    [anon_sym_event] = ACTIONS(6137),
    [anon_sym_byte] = ACTIONS(6137),
    [anon_sym_shortint] = ACTIONS(6137),
    [anon_sym_int] = ACTIONS(6137),
    [anon_sym_longint] = ACTIONS(6137),
    [anon_sym_integer] = ACTIONS(6137),
    [anon_sym_time] = ACTIONS(6137),
    [anon_sym_bit] = ACTIONS(6137),
    [anon_sym_logic] = ACTIONS(6137),
    [anon_sym_reg] = ACTIONS(6137),
    [anon_sym_shortreal] = ACTIONS(6137),
    [anon_sym_real] = ACTIONS(6137),
    [anon_sym_realtime] = ACTIONS(6137),
    [anon_sym_supply0] = ACTIONS(6137),
    [anon_sym_supply1] = ACTIONS(6137),
    [anon_sym_signed] = ACTIONS(6137),
    [anon_sym_unsigned] = ACTIONS(6137),
    [anon_sym_task] = ACTIONS(6137),
    [anon_sym_modport] = ACTIONS(6137),
    [anon_sym_assert] = ACTIONS(6137),
    [anon_sym_property] = ACTIONS(6137),
    [anon_sym_assume] = ACTIONS(6137),
    [anon_sym_cover] = ACTIONS(6137),
    [anon_sym_sequence] = ACTIONS(6137),
    [anon_sym_restrict] = ACTIONS(6137),
    [anon_sym_not] = ACTIONS(6137),
    [anon_sym_or] = ACTIONS(6137),
    [anon_sym_and] = ACTIONS(6137),
    [anon_sym_case] = ACTIONS(6137),
    [anon_sym_always] = ACTIONS(6137),
    [anon_sym_covergroup] = ACTIONS(6137),
    [anon_sym_let] = ACTIONS(6137),
    [anon_sym_pulldown] = ACTIONS(6137),
    [anon_sym_pullup] = ACTIONS(6137),
    [anon_sym_cmos] = ACTIONS(6137),
    [anon_sym_rcmos] = ACTIONS(6137),
    [anon_sym_bufif0] = ACTIONS(6137),
    [anon_sym_bufif1] = ACTIONS(6137),
    [anon_sym_notif0] = ACTIONS(6137),
    [anon_sym_notif1] = ACTIONS(6137),
    [anon_sym_nmos] = ACTIONS(6137),
    [anon_sym_pmos] = ACTIONS(6137),
    [anon_sym_rnmos] = ACTIONS(6137),
    [anon_sym_rpmos] = ACTIONS(6137),
    [anon_sym_nand] = ACTIONS(6137),
    [anon_sym_nor] = ACTIONS(6137),
    [anon_sym_xor] = ACTIONS(6137),
    [anon_sym_xnor] = ACTIONS(6137),
    [anon_sym_buf] = ACTIONS(6137),
    [anon_sym_tranif0] = ACTIONS(6137),
    [anon_sym_tranif1] = ACTIONS(6137),
    [anon_sym_rtranif1] = ACTIONS(6137),
    [anon_sym_rtranif0] = ACTIONS(6137),
    [anon_sym_tran] = ACTIONS(6137),
    [anon_sym_rtran] = ACTIONS(6137),
    [anon_sym_generate] = ACTIONS(6137),
    [anon_sym_for] = ACTIONS(6137),
    [anon_sym_initial] = ACTIONS(6137),
    [anon_sym_assign] = ACTIONS(6137),
    [anon_sym_alias] = ACTIONS(6137),
    [anon_sym_always_comb] = ACTIONS(6137),
    [anon_sym_always_latch] = ACTIONS(6137),
    [anon_sym_always_ff] = ACTIONS(6137),
    [anon_sym_final] = ACTIONS(6137),
    [anon_sym_while] = ACTIONS(6137),
    [anon_sym_global] = ACTIONS(6137),
    [anon_sym_specify] = ACTIONS(6137),
    [anon_sym_LPAREN_STAR] = ACTIONS(6139),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6139),
    [anon_sym_DOLLARunit] = ACTIONS(6139),
  },
  [1102] = {
    [sym_simple_identifier] = ACTIONS(6141),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6143),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6143),
    [anon_sym_BQUOTE] = ACTIONS(6141),
    [aux_sym_id_directive_token1] = ACTIONS(6143),
    [aux_sym_id_directive_token2] = ACTIONS(6143),
    [aux_sym_id_directive_token3] = ACTIONS(6143),
    [aux_sym_id_directive_token4] = ACTIONS(6141),
    [aux_sym_zero_directive_token1] = ACTIONS(6143),
    [aux_sym_zero_directive_token2] = ACTIONS(6143),
    [aux_sym_zero_directive_token3] = ACTIONS(6143),
    [aux_sym_zero_directive_token4] = ACTIONS(6143),
    [aux_sym_zero_directive_token5] = ACTIONS(6143),
    [aux_sym_zero_directive_token6] = ACTIONS(6143),
    [aux_sym_zero_directive_token7] = ACTIONS(6143),
    [aux_sym_zero_directive_token8] = ACTIONS(6143),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6143),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6143),
    [anon_sym_wire] = ACTIONS(6141),
    [anon_sym_tri] = ACTIONS(6141),
    [anon_sym_tri0] = ACTIONS(6141),
    [anon_sym_tri1] = ACTIONS(6141),
    [anon_sym_wand] = ACTIONS(6141),
    [anon_sym_triand] = ACTIONS(6141),
    [anon_sym_wor] = ACTIONS(6141),
    [anon_sym_trior] = ACTIONS(6141),
    [anon_sym_trireg] = ACTIONS(6141),
    [anon_sym_uwire] = ACTIONS(6141),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6143),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6143),
    [aux_sym_begin_keywords_token1] = ACTIONS(6143),
    [anon_sym_SEMI] = ACTIONS(6143),
    [anon_sym_endmodule] = ACTIONS(6141),
    [anon_sym_extern] = ACTIONS(6141),
    [anon_sym_module] = ACTIONS(6141),
    [anon_sym_macromodule] = ACTIONS(6141),
    [anon_sym_endinterface] = ACTIONS(6141),
    [anon_sym_interface] = ACTIONS(6141),
    [anon_sym_endprogram] = ACTIONS(6141),
    [anon_sym_program] = ACTIONS(6141),
    [anon_sym_checker] = ACTIONS(6141),
    [anon_sym_virtual] = ACTIONS(6141),
    [anon_sym_class] = ACTIONS(6141),
    [anon_sym_timeunit] = ACTIONS(6141),
    [anon_sym_timeprecision] = ACTIONS(6141),
    [anon_sym_type] = ACTIONS(6141),
    [anon_sym_input] = ACTIONS(6141),
    [anon_sym_output] = ACTIONS(6141),
    [anon_sym_inout] = ACTIONS(6141),
    [anon_sym_ref] = ACTIONS(6141),
    [anon_sym_DOLLARfatal] = ACTIONS(6143),
    [anon_sym_DOLLARerror] = ACTIONS(6143),
    [anon_sym_DOLLARwarning] = ACTIONS(6143),
    [anon_sym_DOLLARinfo] = ACTIONS(6143),
    [anon_sym_default] = ACTIONS(6141),
    [anon_sym_clocking] = ACTIONS(6141),
    [anon_sym_defparam] = ACTIONS(6141),
    [anon_sym_bind] = ACTIONS(6141),
    [anon_sym_const] = ACTIONS(6141),
    [anon_sym_function] = ACTIONS(6141),
    [anon_sym_static] = ACTIONS(6141),
    [anon_sym_constraint] = ACTIONS(6141),
    [anon_sym_if] = ACTIONS(6141),
    [anon_sym_else] = ACTIONS(6141),
    [anon_sym_LBRACK] = ACTIONS(6143),
    [anon_sym_localparam] = ACTIONS(6141),
    [anon_sym_parameter] = ACTIONS(6141),
    [anon_sym_specparam] = ACTIONS(6141),
    [anon_sym_var] = ACTIONS(6141),
    [anon_sym_import] = ACTIONS(6141),
    [anon_sym_export] = ACTIONS(6141),
    [anon_sym_genvar] = ACTIONS(6141),
    [anon_sym_interconnect] = ACTIONS(6141),
    [anon_sym_typedef] = ACTIONS(6141),
    [anon_sym_enum] = ACTIONS(6141),
    [anon_sym_struct] = ACTIONS(6141),
    [anon_sym_union] = ACTIONS(6141),
    [anon_sym_nettype] = ACTIONS(6141),
    [anon_sym_automatic] = ACTIONS(6141),
    [anon_sym_string] = ACTIONS(6141),
    [anon_sym_chandle] = ACTIONS(6141),
    [anon_sym_event] = ACTIONS(6141),
    [anon_sym_byte] = ACTIONS(6141),
    [anon_sym_shortint] = ACTIONS(6141),
    [anon_sym_int] = ACTIONS(6141),
    [anon_sym_longint] = ACTIONS(6141),
    [anon_sym_integer] = ACTIONS(6141),
    [anon_sym_time] = ACTIONS(6141),
    [anon_sym_bit] = ACTIONS(6141),
    [anon_sym_logic] = ACTIONS(6141),
    [anon_sym_reg] = ACTIONS(6141),
    [anon_sym_shortreal] = ACTIONS(6141),
    [anon_sym_real] = ACTIONS(6141),
    [anon_sym_realtime] = ACTIONS(6141),
    [anon_sym_supply0] = ACTIONS(6141),
    [anon_sym_supply1] = ACTIONS(6141),
    [anon_sym_signed] = ACTIONS(6141),
    [anon_sym_unsigned] = ACTIONS(6141),
    [anon_sym_task] = ACTIONS(6141),
    [anon_sym_modport] = ACTIONS(6141),
    [anon_sym_assert] = ACTIONS(6141),
    [anon_sym_property] = ACTIONS(6141),
    [anon_sym_assume] = ACTIONS(6141),
    [anon_sym_cover] = ACTIONS(6141),
    [anon_sym_sequence] = ACTIONS(6141),
    [anon_sym_restrict] = ACTIONS(6141),
    [anon_sym_not] = ACTIONS(6141),
    [anon_sym_or] = ACTIONS(6141),
    [anon_sym_and] = ACTIONS(6141),
    [anon_sym_case] = ACTIONS(6141),
    [anon_sym_always] = ACTIONS(6141),
    [anon_sym_covergroup] = ACTIONS(6141),
    [anon_sym_let] = ACTIONS(6141),
    [anon_sym_pulldown] = ACTIONS(6141),
    [anon_sym_pullup] = ACTIONS(6141),
    [anon_sym_cmos] = ACTIONS(6141),
    [anon_sym_rcmos] = ACTIONS(6141),
    [anon_sym_bufif0] = ACTIONS(6141),
    [anon_sym_bufif1] = ACTIONS(6141),
    [anon_sym_notif0] = ACTIONS(6141),
    [anon_sym_notif1] = ACTIONS(6141),
    [anon_sym_nmos] = ACTIONS(6141),
    [anon_sym_pmos] = ACTIONS(6141),
    [anon_sym_rnmos] = ACTIONS(6141),
    [anon_sym_rpmos] = ACTIONS(6141),
    [anon_sym_nand] = ACTIONS(6141),
    [anon_sym_nor] = ACTIONS(6141),
    [anon_sym_xor] = ACTIONS(6141),
    [anon_sym_xnor] = ACTIONS(6141),
    [anon_sym_buf] = ACTIONS(6141),
    [anon_sym_tranif0] = ACTIONS(6141),
    [anon_sym_tranif1] = ACTIONS(6141),
    [anon_sym_rtranif1] = ACTIONS(6141),
    [anon_sym_rtranif0] = ACTIONS(6141),
    [anon_sym_tran] = ACTIONS(6141),
    [anon_sym_rtran] = ACTIONS(6141),
    [anon_sym_generate] = ACTIONS(6141),
    [anon_sym_for] = ACTIONS(6141),
    [anon_sym_initial] = ACTIONS(6141),
    [anon_sym_assign] = ACTIONS(6141),
    [anon_sym_alias] = ACTIONS(6141),
    [anon_sym_always_comb] = ACTIONS(6141),
    [anon_sym_always_latch] = ACTIONS(6141),
    [anon_sym_always_ff] = ACTIONS(6141),
    [anon_sym_final] = ACTIONS(6141),
    [anon_sym_while] = ACTIONS(6141),
    [anon_sym_global] = ACTIONS(6141),
    [anon_sym_specify] = ACTIONS(6141),
    [anon_sym_LPAREN_STAR] = ACTIONS(6143),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6143),
    [anon_sym_DOLLARunit] = ACTIONS(6143),
  },
  [1103] = {
    [sym_simple_identifier] = ACTIONS(6145),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6147),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6147),
    [anon_sym_BQUOTE] = ACTIONS(6145),
    [aux_sym_id_directive_token1] = ACTIONS(6147),
    [aux_sym_id_directive_token2] = ACTIONS(6147),
    [aux_sym_id_directive_token3] = ACTIONS(6147),
    [aux_sym_id_directive_token4] = ACTIONS(6145),
    [aux_sym_zero_directive_token1] = ACTIONS(6147),
    [aux_sym_zero_directive_token2] = ACTIONS(6147),
    [aux_sym_zero_directive_token3] = ACTIONS(6147),
    [aux_sym_zero_directive_token4] = ACTIONS(6147),
    [aux_sym_zero_directive_token5] = ACTIONS(6147),
    [aux_sym_zero_directive_token6] = ACTIONS(6147),
    [aux_sym_zero_directive_token7] = ACTIONS(6147),
    [aux_sym_zero_directive_token8] = ACTIONS(6147),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6147),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6147),
    [anon_sym_wire] = ACTIONS(6145),
    [anon_sym_tri] = ACTIONS(6145),
    [anon_sym_tri0] = ACTIONS(6145),
    [anon_sym_tri1] = ACTIONS(6145),
    [anon_sym_wand] = ACTIONS(6145),
    [anon_sym_triand] = ACTIONS(6145),
    [anon_sym_wor] = ACTIONS(6145),
    [anon_sym_trior] = ACTIONS(6145),
    [anon_sym_trireg] = ACTIONS(6145),
    [anon_sym_uwire] = ACTIONS(6145),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6147),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6147),
    [aux_sym_begin_keywords_token1] = ACTIONS(6147),
    [anon_sym_SEMI] = ACTIONS(6147),
    [anon_sym_endmodule] = ACTIONS(6145),
    [anon_sym_extern] = ACTIONS(6145),
    [anon_sym_module] = ACTIONS(6145),
    [anon_sym_macromodule] = ACTIONS(6145),
    [anon_sym_endinterface] = ACTIONS(6145),
    [anon_sym_interface] = ACTIONS(6145),
    [anon_sym_endprogram] = ACTIONS(6145),
    [anon_sym_program] = ACTIONS(6145),
    [anon_sym_checker] = ACTIONS(6145),
    [anon_sym_virtual] = ACTIONS(6145),
    [anon_sym_class] = ACTIONS(6145),
    [anon_sym_timeunit] = ACTIONS(6145),
    [anon_sym_timeprecision] = ACTIONS(6145),
    [anon_sym_type] = ACTIONS(6145),
    [anon_sym_input] = ACTIONS(6145),
    [anon_sym_output] = ACTIONS(6145),
    [anon_sym_inout] = ACTIONS(6145),
    [anon_sym_ref] = ACTIONS(6145),
    [anon_sym_DOLLARfatal] = ACTIONS(6147),
    [anon_sym_DOLLARerror] = ACTIONS(6147),
    [anon_sym_DOLLARwarning] = ACTIONS(6147),
    [anon_sym_DOLLARinfo] = ACTIONS(6147),
    [anon_sym_default] = ACTIONS(6145),
    [anon_sym_clocking] = ACTIONS(6145),
    [anon_sym_defparam] = ACTIONS(6145),
    [anon_sym_bind] = ACTIONS(6145),
    [anon_sym_const] = ACTIONS(6145),
    [anon_sym_function] = ACTIONS(6145),
    [anon_sym_static] = ACTIONS(6145),
    [anon_sym_constraint] = ACTIONS(6145),
    [anon_sym_if] = ACTIONS(6145),
    [anon_sym_else] = ACTIONS(6145),
    [anon_sym_LBRACK] = ACTIONS(6147),
    [anon_sym_localparam] = ACTIONS(6145),
    [anon_sym_parameter] = ACTIONS(6145),
    [anon_sym_specparam] = ACTIONS(6145),
    [anon_sym_var] = ACTIONS(6145),
    [anon_sym_import] = ACTIONS(6145),
    [anon_sym_export] = ACTIONS(6145),
    [anon_sym_genvar] = ACTIONS(6145),
    [anon_sym_interconnect] = ACTIONS(6145),
    [anon_sym_typedef] = ACTIONS(6145),
    [anon_sym_enum] = ACTIONS(6145),
    [anon_sym_struct] = ACTIONS(6145),
    [anon_sym_union] = ACTIONS(6145),
    [anon_sym_nettype] = ACTIONS(6145),
    [anon_sym_automatic] = ACTIONS(6145),
    [anon_sym_string] = ACTIONS(6145),
    [anon_sym_chandle] = ACTIONS(6145),
    [anon_sym_event] = ACTIONS(6145),
    [anon_sym_byte] = ACTIONS(6145),
    [anon_sym_shortint] = ACTIONS(6145),
    [anon_sym_int] = ACTIONS(6145),
    [anon_sym_longint] = ACTIONS(6145),
    [anon_sym_integer] = ACTIONS(6145),
    [anon_sym_time] = ACTIONS(6145),
    [anon_sym_bit] = ACTIONS(6145),
    [anon_sym_logic] = ACTIONS(6145),
    [anon_sym_reg] = ACTIONS(6145),
    [anon_sym_shortreal] = ACTIONS(6145),
    [anon_sym_real] = ACTIONS(6145),
    [anon_sym_realtime] = ACTIONS(6145),
    [anon_sym_supply0] = ACTIONS(6145),
    [anon_sym_supply1] = ACTIONS(6145),
    [anon_sym_signed] = ACTIONS(6145),
    [anon_sym_unsigned] = ACTIONS(6145),
    [anon_sym_task] = ACTIONS(6145),
    [anon_sym_modport] = ACTIONS(6145),
    [anon_sym_assert] = ACTIONS(6145),
    [anon_sym_property] = ACTIONS(6145),
    [anon_sym_assume] = ACTIONS(6145),
    [anon_sym_cover] = ACTIONS(6145),
    [anon_sym_sequence] = ACTIONS(6145),
    [anon_sym_restrict] = ACTIONS(6145),
    [anon_sym_not] = ACTIONS(6145),
    [anon_sym_or] = ACTIONS(6145),
    [anon_sym_and] = ACTIONS(6145),
    [anon_sym_case] = ACTIONS(6145),
    [anon_sym_always] = ACTIONS(6145),
    [anon_sym_covergroup] = ACTIONS(6145),
    [anon_sym_let] = ACTIONS(6145),
    [anon_sym_pulldown] = ACTIONS(6145),
    [anon_sym_pullup] = ACTIONS(6145),
    [anon_sym_cmos] = ACTIONS(6145),
    [anon_sym_rcmos] = ACTIONS(6145),
    [anon_sym_bufif0] = ACTIONS(6145),
    [anon_sym_bufif1] = ACTIONS(6145),
    [anon_sym_notif0] = ACTIONS(6145),
    [anon_sym_notif1] = ACTIONS(6145),
    [anon_sym_nmos] = ACTIONS(6145),
    [anon_sym_pmos] = ACTIONS(6145),
    [anon_sym_rnmos] = ACTIONS(6145),
    [anon_sym_rpmos] = ACTIONS(6145),
    [anon_sym_nand] = ACTIONS(6145),
    [anon_sym_nor] = ACTIONS(6145),
    [anon_sym_xor] = ACTIONS(6145),
    [anon_sym_xnor] = ACTIONS(6145),
    [anon_sym_buf] = ACTIONS(6145),
    [anon_sym_tranif0] = ACTIONS(6145),
    [anon_sym_tranif1] = ACTIONS(6145),
    [anon_sym_rtranif1] = ACTIONS(6145),
    [anon_sym_rtranif0] = ACTIONS(6145),
    [anon_sym_tran] = ACTIONS(6145),
    [anon_sym_rtran] = ACTIONS(6145),
    [anon_sym_generate] = ACTIONS(6145),
    [anon_sym_for] = ACTIONS(6145),
    [anon_sym_initial] = ACTIONS(6145),
    [anon_sym_assign] = ACTIONS(6145),
    [anon_sym_alias] = ACTIONS(6145),
    [anon_sym_always_comb] = ACTIONS(6145),
    [anon_sym_always_latch] = ACTIONS(6145),
    [anon_sym_always_ff] = ACTIONS(6145),
    [anon_sym_final] = ACTIONS(6145),
    [anon_sym_while] = ACTIONS(6145),
    [anon_sym_global] = ACTIONS(6145),
    [anon_sym_specify] = ACTIONS(6145),
    [anon_sym_LPAREN_STAR] = ACTIONS(6147),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6147),
    [anon_sym_DOLLARunit] = ACTIONS(6147),
  },
  [1104] = {
    [sym_simple_identifier] = ACTIONS(6149),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6151),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6151),
    [anon_sym_BQUOTE] = ACTIONS(6149),
    [aux_sym_id_directive_token1] = ACTIONS(6151),
    [aux_sym_id_directive_token2] = ACTIONS(6151),
    [aux_sym_id_directive_token3] = ACTIONS(6151),
    [aux_sym_id_directive_token4] = ACTIONS(6149),
    [aux_sym_zero_directive_token1] = ACTIONS(6151),
    [aux_sym_zero_directive_token2] = ACTIONS(6151),
    [aux_sym_zero_directive_token3] = ACTIONS(6151),
    [aux_sym_zero_directive_token4] = ACTIONS(6151),
    [aux_sym_zero_directive_token5] = ACTIONS(6151),
    [aux_sym_zero_directive_token6] = ACTIONS(6151),
    [aux_sym_zero_directive_token7] = ACTIONS(6151),
    [aux_sym_zero_directive_token8] = ACTIONS(6151),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6151),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6151),
    [anon_sym_wire] = ACTIONS(6149),
    [anon_sym_tri] = ACTIONS(6149),
    [anon_sym_tri0] = ACTIONS(6149),
    [anon_sym_tri1] = ACTIONS(6149),
    [anon_sym_wand] = ACTIONS(6149),
    [anon_sym_triand] = ACTIONS(6149),
    [anon_sym_wor] = ACTIONS(6149),
    [anon_sym_trior] = ACTIONS(6149),
    [anon_sym_trireg] = ACTIONS(6149),
    [anon_sym_uwire] = ACTIONS(6149),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6151),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6151),
    [aux_sym_begin_keywords_token1] = ACTIONS(6151),
    [anon_sym_SEMI] = ACTIONS(6151),
    [anon_sym_endmodule] = ACTIONS(6149),
    [anon_sym_extern] = ACTIONS(6149),
    [anon_sym_module] = ACTIONS(6149),
    [anon_sym_macromodule] = ACTIONS(6149),
    [anon_sym_endinterface] = ACTIONS(6149),
    [anon_sym_interface] = ACTIONS(6149),
    [anon_sym_endprogram] = ACTIONS(6149),
    [anon_sym_program] = ACTIONS(6149),
    [anon_sym_checker] = ACTIONS(6149),
    [anon_sym_virtual] = ACTIONS(6149),
    [anon_sym_class] = ACTIONS(6149),
    [anon_sym_timeunit] = ACTIONS(6149),
    [anon_sym_timeprecision] = ACTIONS(6149),
    [anon_sym_type] = ACTIONS(6149),
    [anon_sym_input] = ACTIONS(6149),
    [anon_sym_output] = ACTIONS(6149),
    [anon_sym_inout] = ACTIONS(6149),
    [anon_sym_ref] = ACTIONS(6149),
    [anon_sym_DOLLARfatal] = ACTIONS(6151),
    [anon_sym_DOLLARerror] = ACTIONS(6151),
    [anon_sym_DOLLARwarning] = ACTIONS(6151),
    [anon_sym_DOLLARinfo] = ACTIONS(6151),
    [anon_sym_default] = ACTIONS(6149),
    [anon_sym_clocking] = ACTIONS(6149),
    [anon_sym_defparam] = ACTIONS(6149),
    [anon_sym_bind] = ACTIONS(6149),
    [anon_sym_const] = ACTIONS(6149),
    [anon_sym_function] = ACTIONS(6149),
    [anon_sym_static] = ACTIONS(6149),
    [anon_sym_constraint] = ACTIONS(6149),
    [anon_sym_if] = ACTIONS(6149),
    [anon_sym_else] = ACTIONS(6149),
    [anon_sym_LBRACK] = ACTIONS(6151),
    [anon_sym_localparam] = ACTIONS(6149),
    [anon_sym_parameter] = ACTIONS(6149),
    [anon_sym_specparam] = ACTIONS(6149),
    [anon_sym_var] = ACTIONS(6149),
    [anon_sym_import] = ACTIONS(6149),
    [anon_sym_export] = ACTIONS(6149),
    [anon_sym_genvar] = ACTIONS(6149),
    [anon_sym_interconnect] = ACTIONS(6149),
    [anon_sym_typedef] = ACTIONS(6149),
    [anon_sym_enum] = ACTIONS(6149),
    [anon_sym_struct] = ACTIONS(6149),
    [anon_sym_union] = ACTIONS(6149),
    [anon_sym_nettype] = ACTIONS(6149),
    [anon_sym_automatic] = ACTIONS(6149),
    [anon_sym_string] = ACTIONS(6149),
    [anon_sym_chandle] = ACTIONS(6149),
    [anon_sym_event] = ACTIONS(6149),
    [anon_sym_byte] = ACTIONS(6149),
    [anon_sym_shortint] = ACTIONS(6149),
    [anon_sym_int] = ACTIONS(6149),
    [anon_sym_longint] = ACTIONS(6149),
    [anon_sym_integer] = ACTIONS(6149),
    [anon_sym_time] = ACTIONS(6149),
    [anon_sym_bit] = ACTIONS(6149),
    [anon_sym_logic] = ACTIONS(6149),
    [anon_sym_reg] = ACTIONS(6149),
    [anon_sym_shortreal] = ACTIONS(6149),
    [anon_sym_real] = ACTIONS(6149),
    [anon_sym_realtime] = ACTIONS(6149),
    [anon_sym_supply0] = ACTIONS(6149),
    [anon_sym_supply1] = ACTIONS(6149),
    [anon_sym_signed] = ACTIONS(6149),
    [anon_sym_unsigned] = ACTIONS(6149),
    [anon_sym_task] = ACTIONS(6149),
    [anon_sym_modport] = ACTIONS(6149),
    [anon_sym_assert] = ACTIONS(6149),
    [anon_sym_property] = ACTIONS(6149),
    [anon_sym_assume] = ACTIONS(6149),
    [anon_sym_cover] = ACTIONS(6149),
    [anon_sym_sequence] = ACTIONS(6149),
    [anon_sym_restrict] = ACTIONS(6149),
    [anon_sym_not] = ACTIONS(6149),
    [anon_sym_or] = ACTIONS(6149),
    [anon_sym_and] = ACTIONS(6149),
    [anon_sym_case] = ACTIONS(6149),
    [anon_sym_always] = ACTIONS(6149),
    [anon_sym_covergroup] = ACTIONS(6149),
    [anon_sym_let] = ACTIONS(6149),
    [anon_sym_pulldown] = ACTIONS(6149),
    [anon_sym_pullup] = ACTIONS(6149),
    [anon_sym_cmos] = ACTIONS(6149),
    [anon_sym_rcmos] = ACTIONS(6149),
    [anon_sym_bufif0] = ACTIONS(6149),
    [anon_sym_bufif1] = ACTIONS(6149),
    [anon_sym_notif0] = ACTIONS(6149),
    [anon_sym_notif1] = ACTIONS(6149),
    [anon_sym_nmos] = ACTIONS(6149),
    [anon_sym_pmos] = ACTIONS(6149),
    [anon_sym_rnmos] = ACTIONS(6149),
    [anon_sym_rpmos] = ACTIONS(6149),
    [anon_sym_nand] = ACTIONS(6149),
    [anon_sym_nor] = ACTIONS(6149),
    [anon_sym_xor] = ACTIONS(6149),
    [anon_sym_xnor] = ACTIONS(6149),
    [anon_sym_buf] = ACTIONS(6149),
    [anon_sym_tranif0] = ACTIONS(6149),
    [anon_sym_tranif1] = ACTIONS(6149),
    [anon_sym_rtranif1] = ACTIONS(6149),
    [anon_sym_rtranif0] = ACTIONS(6149),
    [anon_sym_tran] = ACTIONS(6149),
    [anon_sym_rtran] = ACTIONS(6149),
    [anon_sym_generate] = ACTIONS(6149),
    [anon_sym_for] = ACTIONS(6149),
    [anon_sym_initial] = ACTIONS(6149),
    [anon_sym_assign] = ACTIONS(6149),
    [anon_sym_alias] = ACTIONS(6149),
    [anon_sym_always_comb] = ACTIONS(6149),
    [anon_sym_always_latch] = ACTIONS(6149),
    [anon_sym_always_ff] = ACTIONS(6149),
    [anon_sym_final] = ACTIONS(6149),
    [anon_sym_while] = ACTIONS(6149),
    [anon_sym_global] = ACTIONS(6149),
    [anon_sym_specify] = ACTIONS(6149),
    [anon_sym_LPAREN_STAR] = ACTIONS(6151),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6151),
    [anon_sym_DOLLARunit] = ACTIONS(6151),
  },
  [1105] = {
    [ts_builtin_sym_end] = ACTIONS(6153),
    [sym_simple_identifier] = ACTIONS(6155),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6153),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6153),
    [anon_sym_BQUOTE] = ACTIONS(6155),
    [aux_sym_id_directive_token1] = ACTIONS(6153),
    [aux_sym_id_directive_token2] = ACTIONS(6153),
    [aux_sym_id_directive_token3] = ACTIONS(6153),
    [aux_sym_id_directive_token4] = ACTIONS(6155),
    [aux_sym_zero_directive_token1] = ACTIONS(6153),
    [aux_sym_zero_directive_token2] = ACTIONS(6153),
    [aux_sym_zero_directive_token3] = ACTIONS(6153),
    [aux_sym_zero_directive_token4] = ACTIONS(6153),
    [aux_sym_zero_directive_token5] = ACTIONS(6153),
    [aux_sym_zero_directive_token6] = ACTIONS(6153),
    [aux_sym_zero_directive_token7] = ACTIONS(6153),
    [aux_sym_zero_directive_token8] = ACTIONS(6153),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6153),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6153),
    [anon_sym_wire] = ACTIONS(6155),
    [anon_sym_tri] = ACTIONS(6155),
    [anon_sym_tri0] = ACTIONS(6155),
    [anon_sym_tri1] = ACTIONS(6155),
    [anon_sym_wand] = ACTIONS(6155),
    [anon_sym_triand] = ACTIONS(6155),
    [anon_sym_wor] = ACTIONS(6155),
    [anon_sym_trior] = ACTIONS(6155),
    [anon_sym_trireg] = ACTIONS(6155),
    [anon_sym_uwire] = ACTIONS(6155),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6153),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6153),
    [aux_sym_begin_keywords_token1] = ACTIONS(6153),
    [anon_sym_SEMI] = ACTIONS(6153),
    [anon_sym_endmodule] = ACTIONS(6155),
    [anon_sym_extern] = ACTIONS(6155),
    [anon_sym_module] = ACTIONS(6155),
    [anon_sym_macromodule] = ACTIONS(6155),
    [anon_sym_endinterface] = ACTIONS(6155),
    [anon_sym_interface] = ACTIONS(6155),
    [anon_sym_program] = ACTIONS(6155),
    [anon_sym_checker] = ACTIONS(6155),
    [anon_sym_virtual] = ACTIONS(6155),
    [anon_sym_class] = ACTIONS(6155),
    [anon_sym_package] = ACTIONS(6155),
    [anon_sym_timeunit] = ACTIONS(6155),
    [anon_sym_timeprecision] = ACTIONS(6155),
    [anon_sym_type] = ACTIONS(6155),
    [anon_sym_input] = ACTIONS(6155),
    [anon_sym_output] = ACTIONS(6155),
    [anon_sym_inout] = ACTIONS(6155),
    [anon_sym_ref] = ACTIONS(6155),
    [anon_sym_DOLLARfatal] = ACTIONS(6153),
    [anon_sym_DOLLARerror] = ACTIONS(6153),
    [anon_sym_DOLLARwarning] = ACTIONS(6153),
    [anon_sym_DOLLARinfo] = ACTIONS(6153),
    [anon_sym_default] = ACTIONS(6155),
    [anon_sym_clocking] = ACTIONS(6155),
    [anon_sym_defparam] = ACTIONS(6155),
    [anon_sym_bind] = ACTIONS(6155),
    [anon_sym_const] = ACTIONS(6155),
    [anon_sym_function] = ACTIONS(6155),
    [anon_sym_static] = ACTIONS(6155),
    [anon_sym_constraint] = ACTIONS(6155),
    [anon_sym_if] = ACTIONS(6155),
    [anon_sym_LBRACK] = ACTIONS(6153),
    [anon_sym_localparam] = ACTIONS(6155),
    [anon_sym_parameter] = ACTIONS(6155),
    [anon_sym_specparam] = ACTIONS(6155),
    [anon_sym_var] = ACTIONS(6155),
    [anon_sym_import] = ACTIONS(6155),
    [anon_sym_export] = ACTIONS(6155),
    [anon_sym_genvar] = ACTIONS(6155),
    [anon_sym_interconnect] = ACTIONS(6155),
    [anon_sym_typedef] = ACTIONS(6155),
    [anon_sym_enum] = ACTIONS(6155),
    [anon_sym_struct] = ACTIONS(6155),
    [anon_sym_union] = ACTIONS(6155),
    [anon_sym_nettype] = ACTIONS(6155),
    [anon_sym_automatic] = ACTIONS(6155),
    [anon_sym_string] = ACTIONS(6155),
    [anon_sym_chandle] = ACTIONS(6155),
    [anon_sym_event] = ACTIONS(6155),
    [anon_sym_byte] = ACTIONS(6155),
    [anon_sym_shortint] = ACTIONS(6155),
    [anon_sym_int] = ACTIONS(6155),
    [anon_sym_longint] = ACTIONS(6155),
    [anon_sym_integer] = ACTIONS(6155),
    [anon_sym_time] = ACTIONS(6155),
    [anon_sym_bit] = ACTIONS(6155),
    [anon_sym_logic] = ACTIONS(6155),
    [anon_sym_reg] = ACTIONS(6155),
    [anon_sym_shortreal] = ACTIONS(6155),
    [anon_sym_real] = ACTIONS(6155),
    [anon_sym_realtime] = ACTIONS(6155),
    [anon_sym_supply0] = ACTIONS(6155),
    [anon_sym_supply1] = ACTIONS(6155),
    [anon_sym_signed] = ACTIONS(6155),
    [anon_sym_unsigned] = ACTIONS(6155),
    [anon_sym_task] = ACTIONS(6155),
    [anon_sym_modport] = ACTIONS(6155),
    [anon_sym_assert] = ACTIONS(6155),
    [anon_sym_property] = ACTIONS(6155),
    [anon_sym_assume] = ACTIONS(6155),
    [anon_sym_cover] = ACTIONS(6155),
    [anon_sym_sequence] = ACTIONS(6155),
    [anon_sym_restrict] = ACTIONS(6155),
    [anon_sym_not] = ACTIONS(6155),
    [anon_sym_or] = ACTIONS(6155),
    [anon_sym_and] = ACTIONS(6155),
    [anon_sym_case] = ACTIONS(6155),
    [anon_sym_always] = ACTIONS(6155),
    [anon_sym_covergroup] = ACTIONS(6155),
    [anon_sym_let] = ACTIONS(6155),
    [anon_sym_pulldown] = ACTIONS(6155),
    [anon_sym_pullup] = ACTIONS(6155),
    [anon_sym_cmos] = ACTIONS(6155),
    [anon_sym_rcmos] = ACTIONS(6155),
    [anon_sym_bufif0] = ACTIONS(6155),
    [anon_sym_bufif1] = ACTIONS(6155),
    [anon_sym_notif0] = ACTIONS(6155),
    [anon_sym_notif1] = ACTIONS(6155),
    [anon_sym_nmos] = ACTIONS(6155),
    [anon_sym_pmos] = ACTIONS(6155),
    [anon_sym_rnmos] = ACTIONS(6155),
    [anon_sym_rpmos] = ACTIONS(6155),
    [anon_sym_nand] = ACTIONS(6155),
    [anon_sym_nor] = ACTIONS(6155),
    [anon_sym_xor] = ACTIONS(6155),
    [anon_sym_xnor] = ACTIONS(6155),
    [anon_sym_buf] = ACTIONS(6155),
    [anon_sym_tranif0] = ACTIONS(6155),
    [anon_sym_tranif1] = ACTIONS(6155),
    [anon_sym_rtranif1] = ACTIONS(6155),
    [anon_sym_rtranif0] = ACTIONS(6155),
    [anon_sym_tran] = ACTIONS(6155),
    [anon_sym_rtran] = ACTIONS(6155),
    [anon_sym_generate] = ACTIONS(6155),
    [anon_sym_for] = ACTIONS(6155),
    [anon_sym_primitive] = ACTIONS(6155),
    [anon_sym_initial] = ACTIONS(6155),
    [anon_sym_assign] = ACTIONS(6155),
    [anon_sym_alias] = ACTIONS(6155),
    [anon_sym_always_comb] = ACTIONS(6155),
    [anon_sym_always_latch] = ACTIONS(6155),
    [anon_sym_always_ff] = ACTIONS(6155),
    [anon_sym_final] = ACTIONS(6155),
    [anon_sym_global] = ACTIONS(6155),
    [anon_sym_specify] = ACTIONS(6155),
    [anon_sym_LPAREN_STAR] = ACTIONS(6153),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6153),
    [anon_sym_DOLLARunit] = ACTIONS(6153),
  },
  [1106] = {
    [sym_simple_identifier] = ACTIONS(6157),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6159),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6159),
    [anon_sym_BQUOTE] = ACTIONS(6157),
    [aux_sym_id_directive_token1] = ACTIONS(6159),
    [aux_sym_id_directive_token2] = ACTIONS(6159),
    [aux_sym_id_directive_token3] = ACTIONS(6159),
    [aux_sym_id_directive_token4] = ACTIONS(6157),
    [aux_sym_zero_directive_token1] = ACTIONS(6159),
    [aux_sym_zero_directive_token2] = ACTIONS(6159),
    [aux_sym_zero_directive_token3] = ACTIONS(6159),
    [aux_sym_zero_directive_token4] = ACTIONS(6159),
    [aux_sym_zero_directive_token5] = ACTIONS(6159),
    [aux_sym_zero_directive_token6] = ACTIONS(6159),
    [aux_sym_zero_directive_token7] = ACTIONS(6159),
    [aux_sym_zero_directive_token8] = ACTIONS(6159),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6159),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6159),
    [anon_sym_wire] = ACTIONS(6157),
    [anon_sym_tri] = ACTIONS(6157),
    [anon_sym_tri0] = ACTIONS(6157),
    [anon_sym_tri1] = ACTIONS(6157),
    [anon_sym_wand] = ACTIONS(6157),
    [anon_sym_triand] = ACTIONS(6157),
    [anon_sym_wor] = ACTIONS(6157),
    [anon_sym_trior] = ACTIONS(6157),
    [anon_sym_trireg] = ACTIONS(6157),
    [anon_sym_uwire] = ACTIONS(6157),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6159),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6159),
    [aux_sym_begin_keywords_token1] = ACTIONS(6159),
    [anon_sym_SEMI] = ACTIONS(6159),
    [anon_sym_endmodule] = ACTIONS(6157),
    [anon_sym_extern] = ACTIONS(6157),
    [anon_sym_module] = ACTIONS(6157),
    [anon_sym_macromodule] = ACTIONS(6157),
    [anon_sym_endinterface] = ACTIONS(6157),
    [anon_sym_interface] = ACTIONS(6157),
    [anon_sym_endprogram] = ACTIONS(6157),
    [anon_sym_program] = ACTIONS(6157),
    [anon_sym_checker] = ACTIONS(6157),
    [anon_sym_virtual] = ACTIONS(6157),
    [anon_sym_class] = ACTIONS(6157),
    [anon_sym_timeunit] = ACTIONS(6157),
    [anon_sym_timeprecision] = ACTIONS(6157),
    [anon_sym_type] = ACTIONS(6157),
    [anon_sym_input] = ACTIONS(6157),
    [anon_sym_output] = ACTIONS(6157),
    [anon_sym_inout] = ACTIONS(6157),
    [anon_sym_ref] = ACTIONS(6157),
    [anon_sym_DOLLARfatal] = ACTIONS(6159),
    [anon_sym_DOLLARerror] = ACTIONS(6159),
    [anon_sym_DOLLARwarning] = ACTIONS(6159),
    [anon_sym_DOLLARinfo] = ACTIONS(6159),
    [anon_sym_default] = ACTIONS(6157),
    [anon_sym_clocking] = ACTIONS(6157),
    [anon_sym_defparam] = ACTIONS(6157),
    [anon_sym_bind] = ACTIONS(6157),
    [anon_sym_const] = ACTIONS(6157),
    [anon_sym_function] = ACTIONS(6157),
    [anon_sym_static] = ACTIONS(6157),
    [anon_sym_constraint] = ACTIONS(6157),
    [anon_sym_if] = ACTIONS(6157),
    [anon_sym_else] = ACTIONS(6157),
    [anon_sym_LBRACK] = ACTIONS(6159),
    [anon_sym_localparam] = ACTIONS(6157),
    [anon_sym_parameter] = ACTIONS(6157),
    [anon_sym_specparam] = ACTIONS(6157),
    [anon_sym_var] = ACTIONS(6157),
    [anon_sym_import] = ACTIONS(6157),
    [anon_sym_export] = ACTIONS(6157),
    [anon_sym_genvar] = ACTIONS(6157),
    [anon_sym_interconnect] = ACTIONS(6157),
    [anon_sym_typedef] = ACTIONS(6157),
    [anon_sym_enum] = ACTIONS(6157),
    [anon_sym_struct] = ACTIONS(6157),
    [anon_sym_union] = ACTIONS(6157),
    [anon_sym_nettype] = ACTIONS(6157),
    [anon_sym_automatic] = ACTIONS(6157),
    [anon_sym_string] = ACTIONS(6157),
    [anon_sym_chandle] = ACTIONS(6157),
    [anon_sym_event] = ACTIONS(6157),
    [anon_sym_byte] = ACTIONS(6157),
    [anon_sym_shortint] = ACTIONS(6157),
    [anon_sym_int] = ACTIONS(6157),
    [anon_sym_longint] = ACTIONS(6157),
    [anon_sym_integer] = ACTIONS(6157),
    [anon_sym_time] = ACTIONS(6157),
    [anon_sym_bit] = ACTIONS(6157),
    [anon_sym_logic] = ACTIONS(6157),
    [anon_sym_reg] = ACTIONS(6157),
    [anon_sym_shortreal] = ACTIONS(6157),
    [anon_sym_real] = ACTIONS(6157),
    [anon_sym_realtime] = ACTIONS(6157),
    [anon_sym_supply0] = ACTIONS(6157),
    [anon_sym_supply1] = ACTIONS(6157),
    [anon_sym_signed] = ACTIONS(6157),
    [anon_sym_unsigned] = ACTIONS(6157),
    [anon_sym_task] = ACTIONS(6157),
    [anon_sym_modport] = ACTIONS(6157),
    [anon_sym_assert] = ACTIONS(6157),
    [anon_sym_property] = ACTIONS(6157),
    [anon_sym_assume] = ACTIONS(6157),
    [anon_sym_cover] = ACTIONS(6157),
    [anon_sym_sequence] = ACTIONS(6157),
    [anon_sym_restrict] = ACTIONS(6157),
    [anon_sym_not] = ACTIONS(6157),
    [anon_sym_or] = ACTIONS(6157),
    [anon_sym_and] = ACTIONS(6157),
    [anon_sym_case] = ACTIONS(6157),
    [anon_sym_always] = ACTIONS(6157),
    [anon_sym_covergroup] = ACTIONS(6157),
    [anon_sym_let] = ACTIONS(6157),
    [anon_sym_pulldown] = ACTIONS(6157),
    [anon_sym_pullup] = ACTIONS(6157),
    [anon_sym_cmos] = ACTIONS(6157),
    [anon_sym_rcmos] = ACTIONS(6157),
    [anon_sym_bufif0] = ACTIONS(6157),
    [anon_sym_bufif1] = ACTIONS(6157),
    [anon_sym_notif0] = ACTIONS(6157),
    [anon_sym_notif1] = ACTIONS(6157),
    [anon_sym_nmos] = ACTIONS(6157),
    [anon_sym_pmos] = ACTIONS(6157),
    [anon_sym_rnmos] = ACTIONS(6157),
    [anon_sym_rpmos] = ACTIONS(6157),
    [anon_sym_nand] = ACTIONS(6157),
    [anon_sym_nor] = ACTIONS(6157),
    [anon_sym_xor] = ACTIONS(6157),
    [anon_sym_xnor] = ACTIONS(6157),
    [anon_sym_buf] = ACTIONS(6157),
    [anon_sym_tranif0] = ACTIONS(6157),
    [anon_sym_tranif1] = ACTIONS(6157),
    [anon_sym_rtranif1] = ACTIONS(6157),
    [anon_sym_rtranif0] = ACTIONS(6157),
    [anon_sym_tran] = ACTIONS(6157),
    [anon_sym_rtran] = ACTIONS(6157),
    [anon_sym_generate] = ACTIONS(6157),
    [anon_sym_for] = ACTIONS(6157),
    [anon_sym_initial] = ACTIONS(6157),
    [anon_sym_assign] = ACTIONS(6157),
    [anon_sym_alias] = ACTIONS(6157),
    [anon_sym_always_comb] = ACTIONS(6157),
    [anon_sym_always_latch] = ACTIONS(6157),
    [anon_sym_always_ff] = ACTIONS(6157),
    [anon_sym_final] = ACTIONS(6157),
    [anon_sym_while] = ACTIONS(6157),
    [anon_sym_global] = ACTIONS(6157),
    [anon_sym_specify] = ACTIONS(6157),
    [anon_sym_LPAREN_STAR] = ACTIONS(6159),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6159),
    [anon_sym_DOLLARunit] = ACTIONS(6159),
  },
  [1107] = {
    [ts_builtin_sym_end] = ACTIONS(6161),
    [sym_simple_identifier] = ACTIONS(6163),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6161),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6161),
    [anon_sym_BQUOTE] = ACTIONS(6163),
    [aux_sym_id_directive_token1] = ACTIONS(6161),
    [aux_sym_id_directive_token2] = ACTIONS(6161),
    [aux_sym_id_directive_token3] = ACTIONS(6161),
    [aux_sym_id_directive_token4] = ACTIONS(6163),
    [aux_sym_zero_directive_token1] = ACTIONS(6161),
    [aux_sym_zero_directive_token2] = ACTIONS(6161),
    [aux_sym_zero_directive_token3] = ACTIONS(6161),
    [aux_sym_zero_directive_token4] = ACTIONS(6161),
    [aux_sym_zero_directive_token5] = ACTIONS(6161),
    [aux_sym_zero_directive_token6] = ACTIONS(6161),
    [aux_sym_zero_directive_token7] = ACTIONS(6161),
    [aux_sym_zero_directive_token8] = ACTIONS(6161),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6161),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6161),
    [anon_sym_wire] = ACTIONS(6163),
    [anon_sym_tri] = ACTIONS(6163),
    [anon_sym_tri0] = ACTIONS(6163),
    [anon_sym_tri1] = ACTIONS(6163),
    [anon_sym_wand] = ACTIONS(6163),
    [anon_sym_triand] = ACTIONS(6163),
    [anon_sym_wor] = ACTIONS(6163),
    [anon_sym_trior] = ACTIONS(6163),
    [anon_sym_trireg] = ACTIONS(6163),
    [anon_sym_uwire] = ACTIONS(6163),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6161),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6161),
    [aux_sym_begin_keywords_token1] = ACTIONS(6161),
    [anon_sym_SEMI] = ACTIONS(6161),
    [anon_sym_endmodule] = ACTIONS(6163),
    [anon_sym_extern] = ACTIONS(6163),
    [anon_sym_module] = ACTIONS(6163),
    [anon_sym_macromodule] = ACTIONS(6163),
    [anon_sym_endinterface] = ACTIONS(6163),
    [anon_sym_interface] = ACTIONS(6163),
    [anon_sym_program] = ACTIONS(6163),
    [anon_sym_checker] = ACTIONS(6163),
    [anon_sym_virtual] = ACTIONS(6163),
    [anon_sym_class] = ACTIONS(6163),
    [anon_sym_package] = ACTIONS(6163),
    [anon_sym_timeunit] = ACTIONS(6163),
    [anon_sym_timeprecision] = ACTIONS(6163),
    [anon_sym_type] = ACTIONS(6163),
    [anon_sym_input] = ACTIONS(6163),
    [anon_sym_output] = ACTIONS(6163),
    [anon_sym_inout] = ACTIONS(6163),
    [anon_sym_ref] = ACTIONS(6163),
    [anon_sym_DOLLARfatal] = ACTIONS(6161),
    [anon_sym_DOLLARerror] = ACTIONS(6161),
    [anon_sym_DOLLARwarning] = ACTIONS(6161),
    [anon_sym_DOLLARinfo] = ACTIONS(6161),
    [anon_sym_default] = ACTIONS(6163),
    [anon_sym_clocking] = ACTIONS(6163),
    [anon_sym_defparam] = ACTIONS(6163),
    [anon_sym_bind] = ACTIONS(6163),
    [anon_sym_const] = ACTIONS(6163),
    [anon_sym_function] = ACTIONS(6163),
    [anon_sym_static] = ACTIONS(6163),
    [anon_sym_constraint] = ACTIONS(6163),
    [anon_sym_if] = ACTIONS(6163),
    [anon_sym_LBRACK] = ACTIONS(6161),
    [anon_sym_localparam] = ACTIONS(6163),
    [anon_sym_parameter] = ACTIONS(6163),
    [anon_sym_specparam] = ACTIONS(6163),
    [anon_sym_var] = ACTIONS(6163),
    [anon_sym_import] = ACTIONS(6163),
    [anon_sym_export] = ACTIONS(6163),
    [anon_sym_genvar] = ACTIONS(6163),
    [anon_sym_interconnect] = ACTIONS(6163),
    [anon_sym_typedef] = ACTIONS(6163),
    [anon_sym_enum] = ACTIONS(6163),
    [anon_sym_struct] = ACTIONS(6163),
    [anon_sym_union] = ACTIONS(6163),
    [anon_sym_nettype] = ACTIONS(6163),
    [anon_sym_automatic] = ACTIONS(6163),
    [anon_sym_string] = ACTIONS(6163),
    [anon_sym_chandle] = ACTIONS(6163),
    [anon_sym_event] = ACTIONS(6163),
    [anon_sym_byte] = ACTIONS(6163),
    [anon_sym_shortint] = ACTIONS(6163),
    [anon_sym_int] = ACTIONS(6163),
    [anon_sym_longint] = ACTIONS(6163),
    [anon_sym_integer] = ACTIONS(6163),
    [anon_sym_time] = ACTIONS(6163),
    [anon_sym_bit] = ACTIONS(6163),
    [anon_sym_logic] = ACTIONS(6163),
    [anon_sym_reg] = ACTIONS(6163),
    [anon_sym_shortreal] = ACTIONS(6163),
    [anon_sym_real] = ACTIONS(6163),
    [anon_sym_realtime] = ACTIONS(6163),
    [anon_sym_supply0] = ACTIONS(6163),
    [anon_sym_supply1] = ACTIONS(6163),
    [anon_sym_signed] = ACTIONS(6163),
    [anon_sym_unsigned] = ACTIONS(6163),
    [anon_sym_task] = ACTIONS(6163),
    [anon_sym_modport] = ACTIONS(6163),
    [anon_sym_assert] = ACTIONS(6163),
    [anon_sym_property] = ACTIONS(6163),
    [anon_sym_assume] = ACTIONS(6163),
    [anon_sym_cover] = ACTIONS(6163),
    [anon_sym_sequence] = ACTIONS(6163),
    [anon_sym_restrict] = ACTIONS(6163),
    [anon_sym_not] = ACTIONS(6163),
    [anon_sym_or] = ACTIONS(6163),
    [anon_sym_and] = ACTIONS(6163),
    [anon_sym_case] = ACTIONS(6163),
    [anon_sym_always] = ACTIONS(6163),
    [anon_sym_covergroup] = ACTIONS(6163),
    [anon_sym_let] = ACTIONS(6163),
    [anon_sym_pulldown] = ACTIONS(6163),
    [anon_sym_pullup] = ACTIONS(6163),
    [anon_sym_cmos] = ACTIONS(6163),
    [anon_sym_rcmos] = ACTIONS(6163),
    [anon_sym_bufif0] = ACTIONS(6163),
    [anon_sym_bufif1] = ACTIONS(6163),
    [anon_sym_notif0] = ACTIONS(6163),
    [anon_sym_notif1] = ACTIONS(6163),
    [anon_sym_nmos] = ACTIONS(6163),
    [anon_sym_pmos] = ACTIONS(6163),
    [anon_sym_rnmos] = ACTIONS(6163),
    [anon_sym_rpmos] = ACTIONS(6163),
    [anon_sym_nand] = ACTIONS(6163),
    [anon_sym_nor] = ACTIONS(6163),
    [anon_sym_xor] = ACTIONS(6163),
    [anon_sym_xnor] = ACTIONS(6163),
    [anon_sym_buf] = ACTIONS(6163),
    [anon_sym_tranif0] = ACTIONS(6163),
    [anon_sym_tranif1] = ACTIONS(6163),
    [anon_sym_rtranif1] = ACTIONS(6163),
    [anon_sym_rtranif0] = ACTIONS(6163),
    [anon_sym_tran] = ACTIONS(6163),
    [anon_sym_rtran] = ACTIONS(6163),
    [anon_sym_generate] = ACTIONS(6163),
    [anon_sym_for] = ACTIONS(6163),
    [anon_sym_primitive] = ACTIONS(6163),
    [anon_sym_initial] = ACTIONS(6163),
    [anon_sym_assign] = ACTIONS(6163),
    [anon_sym_alias] = ACTIONS(6163),
    [anon_sym_always_comb] = ACTIONS(6163),
    [anon_sym_always_latch] = ACTIONS(6163),
    [anon_sym_always_ff] = ACTIONS(6163),
    [anon_sym_final] = ACTIONS(6163),
    [anon_sym_global] = ACTIONS(6163),
    [anon_sym_specify] = ACTIONS(6163),
    [anon_sym_LPAREN_STAR] = ACTIONS(6161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6161),
    [anon_sym_DOLLARunit] = ACTIONS(6161),
  },
  [1108] = {
    [ts_builtin_sym_end] = ACTIONS(6165),
    [sym_simple_identifier] = ACTIONS(6167),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6165),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6165),
    [anon_sym_BQUOTE] = ACTIONS(6167),
    [aux_sym_id_directive_token1] = ACTIONS(6165),
    [aux_sym_id_directive_token2] = ACTIONS(6165),
    [aux_sym_id_directive_token3] = ACTIONS(6165),
    [aux_sym_id_directive_token4] = ACTIONS(6167),
    [aux_sym_zero_directive_token1] = ACTIONS(6165),
    [aux_sym_zero_directive_token2] = ACTIONS(6165),
    [aux_sym_zero_directive_token3] = ACTIONS(6165),
    [aux_sym_zero_directive_token4] = ACTIONS(6165),
    [aux_sym_zero_directive_token5] = ACTIONS(6165),
    [aux_sym_zero_directive_token6] = ACTIONS(6165),
    [aux_sym_zero_directive_token7] = ACTIONS(6165),
    [aux_sym_zero_directive_token8] = ACTIONS(6165),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6165),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6165),
    [anon_sym_wire] = ACTIONS(6167),
    [anon_sym_tri] = ACTIONS(6167),
    [anon_sym_tri0] = ACTIONS(6167),
    [anon_sym_tri1] = ACTIONS(6167),
    [anon_sym_wand] = ACTIONS(6167),
    [anon_sym_triand] = ACTIONS(6167),
    [anon_sym_wor] = ACTIONS(6167),
    [anon_sym_trior] = ACTIONS(6167),
    [anon_sym_trireg] = ACTIONS(6167),
    [anon_sym_uwire] = ACTIONS(6167),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6165),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6165),
    [aux_sym_begin_keywords_token1] = ACTIONS(6165),
    [anon_sym_SEMI] = ACTIONS(6165),
    [anon_sym_endmodule] = ACTIONS(6167),
    [anon_sym_extern] = ACTIONS(6167),
    [anon_sym_module] = ACTIONS(6167),
    [anon_sym_macromodule] = ACTIONS(6167),
    [anon_sym_endinterface] = ACTIONS(6167),
    [anon_sym_interface] = ACTIONS(6167),
    [anon_sym_program] = ACTIONS(6167),
    [anon_sym_checker] = ACTIONS(6167),
    [anon_sym_virtual] = ACTIONS(6167),
    [anon_sym_class] = ACTIONS(6167),
    [anon_sym_package] = ACTIONS(6167),
    [anon_sym_timeunit] = ACTIONS(6167),
    [anon_sym_timeprecision] = ACTIONS(6167),
    [anon_sym_type] = ACTIONS(6167),
    [anon_sym_input] = ACTIONS(6167),
    [anon_sym_output] = ACTIONS(6167),
    [anon_sym_inout] = ACTIONS(6167),
    [anon_sym_ref] = ACTIONS(6167),
    [anon_sym_DOLLARfatal] = ACTIONS(6165),
    [anon_sym_DOLLARerror] = ACTIONS(6165),
    [anon_sym_DOLLARwarning] = ACTIONS(6165),
    [anon_sym_DOLLARinfo] = ACTIONS(6165),
    [anon_sym_default] = ACTIONS(6167),
    [anon_sym_clocking] = ACTIONS(6167),
    [anon_sym_defparam] = ACTIONS(6167),
    [anon_sym_bind] = ACTIONS(6167),
    [anon_sym_const] = ACTIONS(6167),
    [anon_sym_function] = ACTIONS(6167),
    [anon_sym_static] = ACTIONS(6167),
    [anon_sym_constraint] = ACTIONS(6167),
    [anon_sym_if] = ACTIONS(6167),
    [anon_sym_LBRACK] = ACTIONS(6165),
    [anon_sym_localparam] = ACTIONS(6167),
    [anon_sym_parameter] = ACTIONS(6167),
    [anon_sym_specparam] = ACTIONS(6167),
    [anon_sym_var] = ACTIONS(6167),
    [anon_sym_import] = ACTIONS(6167),
    [anon_sym_export] = ACTIONS(6167),
    [anon_sym_genvar] = ACTIONS(6167),
    [anon_sym_interconnect] = ACTIONS(6167),
    [anon_sym_typedef] = ACTIONS(6167),
    [anon_sym_enum] = ACTIONS(6167),
    [anon_sym_struct] = ACTIONS(6167),
    [anon_sym_union] = ACTIONS(6167),
    [anon_sym_nettype] = ACTIONS(6167),
    [anon_sym_automatic] = ACTIONS(6167),
    [anon_sym_string] = ACTIONS(6167),
    [anon_sym_chandle] = ACTIONS(6167),
    [anon_sym_event] = ACTIONS(6167),
    [anon_sym_byte] = ACTIONS(6167),
    [anon_sym_shortint] = ACTIONS(6167),
    [anon_sym_int] = ACTIONS(6167),
    [anon_sym_longint] = ACTIONS(6167),
    [anon_sym_integer] = ACTIONS(6167),
    [anon_sym_time] = ACTIONS(6167),
    [anon_sym_bit] = ACTIONS(6167),
    [anon_sym_logic] = ACTIONS(6167),
    [anon_sym_reg] = ACTIONS(6167),
    [anon_sym_shortreal] = ACTIONS(6167),
    [anon_sym_real] = ACTIONS(6167),
    [anon_sym_realtime] = ACTIONS(6167),
    [anon_sym_supply0] = ACTIONS(6167),
    [anon_sym_supply1] = ACTIONS(6167),
    [anon_sym_signed] = ACTIONS(6167),
    [anon_sym_unsigned] = ACTIONS(6167),
    [anon_sym_task] = ACTIONS(6167),
    [anon_sym_modport] = ACTIONS(6167),
    [anon_sym_assert] = ACTIONS(6167),
    [anon_sym_property] = ACTIONS(6167),
    [anon_sym_assume] = ACTIONS(6167),
    [anon_sym_cover] = ACTIONS(6167),
    [anon_sym_sequence] = ACTIONS(6167),
    [anon_sym_restrict] = ACTIONS(6167),
    [anon_sym_not] = ACTIONS(6167),
    [anon_sym_or] = ACTIONS(6167),
    [anon_sym_and] = ACTIONS(6167),
    [anon_sym_case] = ACTIONS(6167),
    [anon_sym_always] = ACTIONS(6167),
    [anon_sym_covergroup] = ACTIONS(6167),
    [anon_sym_let] = ACTIONS(6167),
    [anon_sym_pulldown] = ACTIONS(6167),
    [anon_sym_pullup] = ACTIONS(6167),
    [anon_sym_cmos] = ACTIONS(6167),
    [anon_sym_rcmos] = ACTIONS(6167),
    [anon_sym_bufif0] = ACTIONS(6167),
    [anon_sym_bufif1] = ACTIONS(6167),
    [anon_sym_notif0] = ACTIONS(6167),
    [anon_sym_notif1] = ACTIONS(6167),
    [anon_sym_nmos] = ACTIONS(6167),
    [anon_sym_pmos] = ACTIONS(6167),
    [anon_sym_rnmos] = ACTIONS(6167),
    [anon_sym_rpmos] = ACTIONS(6167),
    [anon_sym_nand] = ACTIONS(6167),
    [anon_sym_nor] = ACTIONS(6167),
    [anon_sym_xor] = ACTIONS(6167),
    [anon_sym_xnor] = ACTIONS(6167),
    [anon_sym_buf] = ACTIONS(6167),
    [anon_sym_tranif0] = ACTIONS(6167),
    [anon_sym_tranif1] = ACTIONS(6167),
    [anon_sym_rtranif1] = ACTIONS(6167),
    [anon_sym_rtranif0] = ACTIONS(6167),
    [anon_sym_tran] = ACTIONS(6167),
    [anon_sym_rtran] = ACTIONS(6167),
    [anon_sym_generate] = ACTIONS(6167),
    [anon_sym_for] = ACTIONS(6167),
    [anon_sym_primitive] = ACTIONS(6167),
    [anon_sym_initial] = ACTIONS(6167),
    [anon_sym_assign] = ACTIONS(6167),
    [anon_sym_alias] = ACTIONS(6167),
    [anon_sym_always_comb] = ACTIONS(6167),
    [anon_sym_always_latch] = ACTIONS(6167),
    [anon_sym_always_ff] = ACTIONS(6167),
    [anon_sym_final] = ACTIONS(6167),
    [anon_sym_global] = ACTIONS(6167),
    [anon_sym_specify] = ACTIONS(6167),
    [anon_sym_LPAREN_STAR] = ACTIONS(6165),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6165),
    [anon_sym_DOLLARunit] = ACTIONS(6165),
  },
  [1109] = {
    [sym_simple_identifier] = ACTIONS(6169),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6171),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6171),
    [anon_sym_BQUOTE] = ACTIONS(6169),
    [aux_sym_id_directive_token1] = ACTIONS(6171),
    [aux_sym_id_directive_token2] = ACTIONS(6171),
    [aux_sym_id_directive_token3] = ACTIONS(6171),
    [aux_sym_id_directive_token4] = ACTIONS(6169),
    [aux_sym_zero_directive_token1] = ACTIONS(6171),
    [aux_sym_zero_directive_token2] = ACTIONS(6171),
    [aux_sym_zero_directive_token3] = ACTIONS(6171),
    [aux_sym_zero_directive_token4] = ACTIONS(6171),
    [aux_sym_zero_directive_token5] = ACTIONS(6171),
    [aux_sym_zero_directive_token6] = ACTIONS(6171),
    [aux_sym_zero_directive_token7] = ACTIONS(6171),
    [aux_sym_zero_directive_token8] = ACTIONS(6171),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6171),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6171),
    [anon_sym_wire] = ACTIONS(6169),
    [anon_sym_tri] = ACTIONS(6169),
    [anon_sym_tri0] = ACTIONS(6169),
    [anon_sym_tri1] = ACTIONS(6169),
    [anon_sym_wand] = ACTIONS(6169),
    [anon_sym_triand] = ACTIONS(6169),
    [anon_sym_wor] = ACTIONS(6169),
    [anon_sym_trior] = ACTIONS(6169),
    [anon_sym_trireg] = ACTIONS(6169),
    [anon_sym_uwire] = ACTIONS(6169),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6171),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6171),
    [aux_sym_begin_keywords_token1] = ACTIONS(6171),
    [anon_sym_SEMI] = ACTIONS(6171),
    [anon_sym_endmodule] = ACTIONS(6169),
    [anon_sym_extern] = ACTIONS(6169),
    [anon_sym_module] = ACTIONS(6169),
    [anon_sym_macromodule] = ACTIONS(6169),
    [anon_sym_endinterface] = ACTIONS(6169),
    [anon_sym_interface] = ACTIONS(6169),
    [anon_sym_endprogram] = ACTIONS(6169),
    [anon_sym_program] = ACTIONS(6169),
    [anon_sym_checker] = ACTIONS(6169),
    [anon_sym_virtual] = ACTIONS(6169),
    [anon_sym_class] = ACTIONS(6169),
    [anon_sym_timeunit] = ACTIONS(6169),
    [anon_sym_timeprecision] = ACTIONS(6169),
    [anon_sym_type] = ACTIONS(6169),
    [anon_sym_input] = ACTIONS(6169),
    [anon_sym_output] = ACTIONS(6169),
    [anon_sym_inout] = ACTIONS(6169),
    [anon_sym_ref] = ACTIONS(6169),
    [anon_sym_DOLLARfatal] = ACTIONS(6171),
    [anon_sym_DOLLARerror] = ACTIONS(6171),
    [anon_sym_DOLLARwarning] = ACTIONS(6171),
    [anon_sym_DOLLARinfo] = ACTIONS(6171),
    [anon_sym_default] = ACTIONS(6169),
    [anon_sym_clocking] = ACTIONS(6169),
    [anon_sym_defparam] = ACTIONS(6169),
    [anon_sym_bind] = ACTIONS(6169),
    [anon_sym_const] = ACTIONS(6169),
    [anon_sym_function] = ACTIONS(6169),
    [anon_sym_static] = ACTIONS(6169),
    [anon_sym_constraint] = ACTIONS(6169),
    [anon_sym_if] = ACTIONS(6169),
    [anon_sym_else] = ACTIONS(6169),
    [anon_sym_LBRACK] = ACTIONS(6171),
    [anon_sym_localparam] = ACTIONS(6169),
    [anon_sym_parameter] = ACTIONS(6169),
    [anon_sym_specparam] = ACTIONS(6169),
    [anon_sym_var] = ACTIONS(6169),
    [anon_sym_import] = ACTIONS(6169),
    [anon_sym_export] = ACTIONS(6169),
    [anon_sym_genvar] = ACTIONS(6169),
    [anon_sym_interconnect] = ACTIONS(6169),
    [anon_sym_typedef] = ACTIONS(6169),
    [anon_sym_enum] = ACTIONS(6169),
    [anon_sym_struct] = ACTIONS(6169),
    [anon_sym_union] = ACTIONS(6169),
    [anon_sym_nettype] = ACTIONS(6169),
    [anon_sym_automatic] = ACTIONS(6169),
    [anon_sym_string] = ACTIONS(6169),
    [anon_sym_chandle] = ACTIONS(6169),
    [anon_sym_event] = ACTIONS(6169),
    [anon_sym_byte] = ACTIONS(6169),
    [anon_sym_shortint] = ACTIONS(6169),
    [anon_sym_int] = ACTIONS(6169),
    [anon_sym_longint] = ACTIONS(6169),
    [anon_sym_integer] = ACTIONS(6169),
    [anon_sym_time] = ACTIONS(6169),
    [anon_sym_bit] = ACTIONS(6169),
    [anon_sym_logic] = ACTIONS(6169),
    [anon_sym_reg] = ACTIONS(6169),
    [anon_sym_shortreal] = ACTIONS(6169),
    [anon_sym_real] = ACTIONS(6169),
    [anon_sym_realtime] = ACTIONS(6169),
    [anon_sym_supply0] = ACTIONS(6169),
    [anon_sym_supply1] = ACTIONS(6169),
    [anon_sym_signed] = ACTIONS(6169),
    [anon_sym_unsigned] = ACTIONS(6169),
    [anon_sym_task] = ACTIONS(6169),
    [anon_sym_modport] = ACTIONS(6169),
    [anon_sym_assert] = ACTIONS(6169),
    [anon_sym_property] = ACTIONS(6169),
    [anon_sym_assume] = ACTIONS(6169),
    [anon_sym_cover] = ACTIONS(6169),
    [anon_sym_sequence] = ACTIONS(6169),
    [anon_sym_restrict] = ACTIONS(6169),
    [anon_sym_not] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6169),
    [anon_sym_and] = ACTIONS(6169),
    [anon_sym_case] = ACTIONS(6169),
    [anon_sym_always] = ACTIONS(6169),
    [anon_sym_covergroup] = ACTIONS(6169),
    [anon_sym_let] = ACTIONS(6169),
    [anon_sym_pulldown] = ACTIONS(6169),
    [anon_sym_pullup] = ACTIONS(6169),
    [anon_sym_cmos] = ACTIONS(6169),
    [anon_sym_rcmos] = ACTIONS(6169),
    [anon_sym_bufif0] = ACTIONS(6169),
    [anon_sym_bufif1] = ACTIONS(6169),
    [anon_sym_notif0] = ACTIONS(6169),
    [anon_sym_notif1] = ACTIONS(6169),
    [anon_sym_nmos] = ACTIONS(6169),
    [anon_sym_pmos] = ACTIONS(6169),
    [anon_sym_rnmos] = ACTIONS(6169),
    [anon_sym_rpmos] = ACTIONS(6169),
    [anon_sym_nand] = ACTIONS(6169),
    [anon_sym_nor] = ACTIONS(6169),
    [anon_sym_xor] = ACTIONS(6169),
    [anon_sym_xnor] = ACTIONS(6169),
    [anon_sym_buf] = ACTIONS(6169),
    [anon_sym_tranif0] = ACTIONS(6169),
    [anon_sym_tranif1] = ACTIONS(6169),
    [anon_sym_rtranif1] = ACTIONS(6169),
    [anon_sym_rtranif0] = ACTIONS(6169),
    [anon_sym_tran] = ACTIONS(6169),
    [anon_sym_rtran] = ACTIONS(6169),
    [anon_sym_generate] = ACTIONS(6169),
    [anon_sym_for] = ACTIONS(6169),
    [anon_sym_initial] = ACTIONS(6169),
    [anon_sym_assign] = ACTIONS(6169),
    [anon_sym_alias] = ACTIONS(6169),
    [anon_sym_always_comb] = ACTIONS(6169),
    [anon_sym_always_latch] = ACTIONS(6169),
    [anon_sym_always_ff] = ACTIONS(6169),
    [anon_sym_final] = ACTIONS(6169),
    [anon_sym_while] = ACTIONS(6169),
    [anon_sym_global] = ACTIONS(6169),
    [anon_sym_specify] = ACTIONS(6169),
    [anon_sym_LPAREN_STAR] = ACTIONS(6171),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6171),
    [anon_sym_DOLLARunit] = ACTIONS(6171),
  },
  [1110] = {
    [sym_simple_identifier] = ACTIONS(6173),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6175),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6175),
    [anon_sym_BQUOTE] = ACTIONS(6173),
    [aux_sym_id_directive_token1] = ACTIONS(6175),
    [aux_sym_id_directive_token2] = ACTIONS(6175),
    [aux_sym_id_directive_token3] = ACTIONS(6175),
    [aux_sym_id_directive_token4] = ACTIONS(6173),
    [aux_sym_zero_directive_token1] = ACTIONS(6175),
    [aux_sym_zero_directive_token2] = ACTIONS(6175),
    [aux_sym_zero_directive_token3] = ACTIONS(6175),
    [aux_sym_zero_directive_token4] = ACTIONS(6175),
    [aux_sym_zero_directive_token5] = ACTIONS(6175),
    [aux_sym_zero_directive_token6] = ACTIONS(6175),
    [aux_sym_zero_directive_token7] = ACTIONS(6175),
    [aux_sym_zero_directive_token8] = ACTIONS(6175),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6175),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6175),
    [anon_sym_wire] = ACTIONS(6173),
    [anon_sym_tri] = ACTIONS(6173),
    [anon_sym_tri0] = ACTIONS(6173),
    [anon_sym_tri1] = ACTIONS(6173),
    [anon_sym_wand] = ACTIONS(6173),
    [anon_sym_triand] = ACTIONS(6173),
    [anon_sym_wor] = ACTIONS(6173),
    [anon_sym_trior] = ACTIONS(6173),
    [anon_sym_trireg] = ACTIONS(6173),
    [anon_sym_uwire] = ACTIONS(6173),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6175),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6175),
    [aux_sym_begin_keywords_token1] = ACTIONS(6175),
    [anon_sym_SEMI] = ACTIONS(6175),
    [anon_sym_endmodule] = ACTIONS(6173),
    [anon_sym_extern] = ACTIONS(6173),
    [anon_sym_module] = ACTIONS(6173),
    [anon_sym_macromodule] = ACTIONS(6173),
    [anon_sym_endinterface] = ACTIONS(6173),
    [anon_sym_interface] = ACTIONS(6173),
    [anon_sym_endprogram] = ACTIONS(6173),
    [anon_sym_program] = ACTIONS(6173),
    [anon_sym_checker] = ACTIONS(6173),
    [anon_sym_virtual] = ACTIONS(6173),
    [anon_sym_class] = ACTIONS(6173),
    [anon_sym_timeunit] = ACTIONS(6173),
    [anon_sym_timeprecision] = ACTIONS(6173),
    [anon_sym_type] = ACTIONS(6173),
    [anon_sym_input] = ACTIONS(6173),
    [anon_sym_output] = ACTIONS(6173),
    [anon_sym_inout] = ACTIONS(6173),
    [anon_sym_ref] = ACTIONS(6173),
    [anon_sym_DOLLARfatal] = ACTIONS(6175),
    [anon_sym_DOLLARerror] = ACTIONS(6175),
    [anon_sym_DOLLARwarning] = ACTIONS(6175),
    [anon_sym_DOLLARinfo] = ACTIONS(6175),
    [anon_sym_default] = ACTIONS(6173),
    [anon_sym_clocking] = ACTIONS(6173),
    [anon_sym_defparam] = ACTIONS(6173),
    [anon_sym_bind] = ACTIONS(6173),
    [anon_sym_const] = ACTIONS(6173),
    [anon_sym_function] = ACTIONS(6173),
    [anon_sym_static] = ACTIONS(6173),
    [anon_sym_constraint] = ACTIONS(6173),
    [anon_sym_if] = ACTIONS(6173),
    [anon_sym_else] = ACTIONS(6173),
    [anon_sym_LBRACK] = ACTIONS(6175),
    [anon_sym_localparam] = ACTIONS(6173),
    [anon_sym_parameter] = ACTIONS(6173),
    [anon_sym_specparam] = ACTIONS(6173),
    [anon_sym_var] = ACTIONS(6173),
    [anon_sym_import] = ACTIONS(6173),
    [anon_sym_export] = ACTIONS(6173),
    [anon_sym_genvar] = ACTIONS(6173),
    [anon_sym_interconnect] = ACTIONS(6173),
    [anon_sym_typedef] = ACTIONS(6173),
    [anon_sym_enum] = ACTIONS(6173),
    [anon_sym_struct] = ACTIONS(6173),
    [anon_sym_union] = ACTIONS(6173),
    [anon_sym_nettype] = ACTIONS(6173),
    [anon_sym_automatic] = ACTIONS(6173),
    [anon_sym_string] = ACTIONS(6173),
    [anon_sym_chandle] = ACTIONS(6173),
    [anon_sym_event] = ACTIONS(6173),
    [anon_sym_byte] = ACTIONS(6173),
    [anon_sym_shortint] = ACTIONS(6173),
    [anon_sym_int] = ACTIONS(6173),
    [anon_sym_longint] = ACTIONS(6173),
    [anon_sym_integer] = ACTIONS(6173),
    [anon_sym_time] = ACTIONS(6173),
    [anon_sym_bit] = ACTIONS(6173),
    [anon_sym_logic] = ACTIONS(6173),
    [anon_sym_reg] = ACTIONS(6173),
    [anon_sym_shortreal] = ACTIONS(6173),
    [anon_sym_real] = ACTIONS(6173),
    [anon_sym_realtime] = ACTIONS(6173),
    [anon_sym_supply0] = ACTIONS(6173),
    [anon_sym_supply1] = ACTIONS(6173),
    [anon_sym_signed] = ACTIONS(6173),
    [anon_sym_unsigned] = ACTIONS(6173),
    [anon_sym_task] = ACTIONS(6173),
    [anon_sym_modport] = ACTIONS(6173),
    [anon_sym_assert] = ACTIONS(6173),
    [anon_sym_property] = ACTIONS(6173),
    [anon_sym_assume] = ACTIONS(6173),
    [anon_sym_cover] = ACTIONS(6173),
    [anon_sym_sequence] = ACTIONS(6173),
    [anon_sym_restrict] = ACTIONS(6173),
    [anon_sym_not] = ACTIONS(6173),
    [anon_sym_or] = ACTIONS(6173),
    [anon_sym_and] = ACTIONS(6173),
    [anon_sym_case] = ACTIONS(6173),
    [anon_sym_always] = ACTIONS(6173),
    [anon_sym_covergroup] = ACTIONS(6173),
    [anon_sym_let] = ACTIONS(6173),
    [anon_sym_pulldown] = ACTIONS(6173),
    [anon_sym_pullup] = ACTIONS(6173),
    [anon_sym_cmos] = ACTIONS(6173),
    [anon_sym_rcmos] = ACTIONS(6173),
    [anon_sym_bufif0] = ACTIONS(6173),
    [anon_sym_bufif1] = ACTIONS(6173),
    [anon_sym_notif0] = ACTIONS(6173),
    [anon_sym_notif1] = ACTIONS(6173),
    [anon_sym_nmos] = ACTIONS(6173),
    [anon_sym_pmos] = ACTIONS(6173),
    [anon_sym_rnmos] = ACTIONS(6173),
    [anon_sym_rpmos] = ACTIONS(6173),
    [anon_sym_nand] = ACTIONS(6173),
    [anon_sym_nor] = ACTIONS(6173),
    [anon_sym_xor] = ACTIONS(6173),
    [anon_sym_xnor] = ACTIONS(6173),
    [anon_sym_buf] = ACTIONS(6173),
    [anon_sym_tranif0] = ACTIONS(6173),
    [anon_sym_tranif1] = ACTIONS(6173),
    [anon_sym_rtranif1] = ACTIONS(6173),
    [anon_sym_rtranif0] = ACTIONS(6173),
    [anon_sym_tran] = ACTIONS(6173),
    [anon_sym_rtran] = ACTIONS(6173),
    [anon_sym_generate] = ACTIONS(6173),
    [anon_sym_for] = ACTIONS(6173),
    [anon_sym_initial] = ACTIONS(6173),
    [anon_sym_assign] = ACTIONS(6173),
    [anon_sym_alias] = ACTIONS(6173),
    [anon_sym_always_comb] = ACTIONS(6173),
    [anon_sym_always_latch] = ACTIONS(6173),
    [anon_sym_always_ff] = ACTIONS(6173),
    [anon_sym_final] = ACTIONS(6173),
    [anon_sym_while] = ACTIONS(6173),
    [anon_sym_global] = ACTIONS(6173),
    [anon_sym_specify] = ACTIONS(6173),
    [anon_sym_LPAREN_STAR] = ACTIONS(6175),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6175),
    [anon_sym_DOLLARunit] = ACTIONS(6175),
  },
  [1111] = {
    [sym_simple_identifier] = ACTIONS(6177),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6179),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6179),
    [anon_sym_BQUOTE] = ACTIONS(6177),
    [aux_sym_id_directive_token1] = ACTIONS(6179),
    [aux_sym_id_directive_token2] = ACTIONS(6179),
    [aux_sym_id_directive_token3] = ACTIONS(6179),
    [aux_sym_id_directive_token4] = ACTIONS(6177),
    [aux_sym_zero_directive_token1] = ACTIONS(6179),
    [aux_sym_zero_directive_token2] = ACTIONS(6179),
    [aux_sym_zero_directive_token3] = ACTIONS(6179),
    [aux_sym_zero_directive_token4] = ACTIONS(6179),
    [aux_sym_zero_directive_token5] = ACTIONS(6179),
    [aux_sym_zero_directive_token6] = ACTIONS(6179),
    [aux_sym_zero_directive_token7] = ACTIONS(6179),
    [aux_sym_zero_directive_token8] = ACTIONS(6179),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6179),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6179),
    [anon_sym_wire] = ACTIONS(6177),
    [anon_sym_tri] = ACTIONS(6177),
    [anon_sym_tri0] = ACTIONS(6177),
    [anon_sym_tri1] = ACTIONS(6177),
    [anon_sym_wand] = ACTIONS(6177),
    [anon_sym_triand] = ACTIONS(6177),
    [anon_sym_wor] = ACTIONS(6177),
    [anon_sym_trior] = ACTIONS(6177),
    [anon_sym_trireg] = ACTIONS(6177),
    [anon_sym_uwire] = ACTIONS(6177),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6179),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6179),
    [aux_sym_begin_keywords_token1] = ACTIONS(6179),
    [anon_sym_SEMI] = ACTIONS(6179),
    [anon_sym_endmodule] = ACTIONS(6177),
    [anon_sym_extern] = ACTIONS(6177),
    [anon_sym_module] = ACTIONS(6177),
    [anon_sym_macromodule] = ACTIONS(6177),
    [anon_sym_endinterface] = ACTIONS(6177),
    [anon_sym_interface] = ACTIONS(6177),
    [anon_sym_endprogram] = ACTIONS(6177),
    [anon_sym_program] = ACTIONS(6177),
    [anon_sym_checker] = ACTIONS(6177),
    [anon_sym_virtual] = ACTIONS(6177),
    [anon_sym_class] = ACTIONS(6177),
    [anon_sym_timeunit] = ACTIONS(6177),
    [anon_sym_timeprecision] = ACTIONS(6177),
    [anon_sym_type] = ACTIONS(6177),
    [anon_sym_input] = ACTIONS(6177),
    [anon_sym_output] = ACTIONS(6177),
    [anon_sym_inout] = ACTIONS(6177),
    [anon_sym_ref] = ACTIONS(6177),
    [anon_sym_DOLLARfatal] = ACTIONS(6179),
    [anon_sym_DOLLARerror] = ACTIONS(6179),
    [anon_sym_DOLLARwarning] = ACTIONS(6179),
    [anon_sym_DOLLARinfo] = ACTIONS(6179),
    [anon_sym_default] = ACTIONS(6177),
    [anon_sym_clocking] = ACTIONS(6177),
    [anon_sym_defparam] = ACTIONS(6177),
    [anon_sym_bind] = ACTIONS(6177),
    [anon_sym_const] = ACTIONS(6177),
    [anon_sym_function] = ACTIONS(6177),
    [anon_sym_static] = ACTIONS(6177),
    [anon_sym_constraint] = ACTIONS(6177),
    [anon_sym_if] = ACTIONS(6177),
    [anon_sym_else] = ACTIONS(6177),
    [anon_sym_LBRACK] = ACTIONS(6179),
    [anon_sym_localparam] = ACTIONS(6177),
    [anon_sym_parameter] = ACTIONS(6177),
    [anon_sym_specparam] = ACTIONS(6177),
    [anon_sym_var] = ACTIONS(6177),
    [anon_sym_import] = ACTIONS(6177),
    [anon_sym_export] = ACTIONS(6177),
    [anon_sym_genvar] = ACTIONS(6177),
    [anon_sym_interconnect] = ACTIONS(6177),
    [anon_sym_typedef] = ACTIONS(6177),
    [anon_sym_enum] = ACTIONS(6177),
    [anon_sym_struct] = ACTIONS(6177),
    [anon_sym_union] = ACTIONS(6177),
    [anon_sym_nettype] = ACTIONS(6177),
    [anon_sym_automatic] = ACTIONS(6177),
    [anon_sym_string] = ACTIONS(6177),
    [anon_sym_chandle] = ACTIONS(6177),
    [anon_sym_event] = ACTIONS(6177),
    [anon_sym_byte] = ACTIONS(6177),
    [anon_sym_shortint] = ACTIONS(6177),
    [anon_sym_int] = ACTIONS(6177),
    [anon_sym_longint] = ACTIONS(6177),
    [anon_sym_integer] = ACTIONS(6177),
    [anon_sym_time] = ACTIONS(6177),
    [anon_sym_bit] = ACTIONS(6177),
    [anon_sym_logic] = ACTIONS(6177),
    [anon_sym_reg] = ACTIONS(6177),
    [anon_sym_shortreal] = ACTIONS(6177),
    [anon_sym_real] = ACTIONS(6177),
    [anon_sym_realtime] = ACTIONS(6177),
    [anon_sym_supply0] = ACTIONS(6177),
    [anon_sym_supply1] = ACTIONS(6177),
    [anon_sym_signed] = ACTIONS(6177),
    [anon_sym_unsigned] = ACTIONS(6177),
    [anon_sym_task] = ACTIONS(6177),
    [anon_sym_modport] = ACTIONS(6177),
    [anon_sym_assert] = ACTIONS(6177),
    [anon_sym_property] = ACTIONS(6177),
    [anon_sym_assume] = ACTIONS(6177),
    [anon_sym_cover] = ACTIONS(6177),
    [anon_sym_sequence] = ACTIONS(6177),
    [anon_sym_restrict] = ACTIONS(6177),
    [anon_sym_not] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6177),
    [anon_sym_and] = ACTIONS(6177),
    [anon_sym_case] = ACTIONS(6177),
    [anon_sym_always] = ACTIONS(6177),
    [anon_sym_covergroup] = ACTIONS(6177),
    [anon_sym_let] = ACTIONS(6177),
    [anon_sym_pulldown] = ACTIONS(6177),
    [anon_sym_pullup] = ACTIONS(6177),
    [anon_sym_cmos] = ACTIONS(6177),
    [anon_sym_rcmos] = ACTIONS(6177),
    [anon_sym_bufif0] = ACTIONS(6177),
    [anon_sym_bufif1] = ACTIONS(6177),
    [anon_sym_notif0] = ACTIONS(6177),
    [anon_sym_notif1] = ACTIONS(6177),
    [anon_sym_nmos] = ACTIONS(6177),
    [anon_sym_pmos] = ACTIONS(6177),
    [anon_sym_rnmos] = ACTIONS(6177),
    [anon_sym_rpmos] = ACTIONS(6177),
    [anon_sym_nand] = ACTIONS(6177),
    [anon_sym_nor] = ACTIONS(6177),
    [anon_sym_xor] = ACTIONS(6177),
    [anon_sym_xnor] = ACTIONS(6177),
    [anon_sym_buf] = ACTIONS(6177),
    [anon_sym_tranif0] = ACTIONS(6177),
    [anon_sym_tranif1] = ACTIONS(6177),
    [anon_sym_rtranif1] = ACTIONS(6177),
    [anon_sym_rtranif0] = ACTIONS(6177),
    [anon_sym_tran] = ACTIONS(6177),
    [anon_sym_rtran] = ACTIONS(6177),
    [anon_sym_generate] = ACTIONS(6177),
    [anon_sym_for] = ACTIONS(6177),
    [anon_sym_initial] = ACTIONS(6177),
    [anon_sym_assign] = ACTIONS(6177),
    [anon_sym_alias] = ACTIONS(6177),
    [anon_sym_always_comb] = ACTIONS(6177),
    [anon_sym_always_latch] = ACTIONS(6177),
    [anon_sym_always_ff] = ACTIONS(6177),
    [anon_sym_final] = ACTIONS(6177),
    [anon_sym_while] = ACTIONS(6177),
    [anon_sym_global] = ACTIONS(6177),
    [anon_sym_specify] = ACTIONS(6177),
    [anon_sym_LPAREN_STAR] = ACTIONS(6179),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6179),
    [anon_sym_DOLLARunit] = ACTIONS(6179),
  },
  [1112] = {
    [ts_builtin_sym_end] = ACTIONS(6181),
    [sym_simple_identifier] = ACTIONS(6183),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6181),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6181),
    [anon_sym_BQUOTE] = ACTIONS(6183),
    [aux_sym_id_directive_token1] = ACTIONS(6181),
    [aux_sym_id_directive_token2] = ACTIONS(6181),
    [aux_sym_id_directive_token3] = ACTIONS(6181),
    [aux_sym_id_directive_token4] = ACTIONS(6183),
    [aux_sym_zero_directive_token1] = ACTIONS(6181),
    [aux_sym_zero_directive_token2] = ACTIONS(6181),
    [aux_sym_zero_directive_token3] = ACTIONS(6181),
    [aux_sym_zero_directive_token4] = ACTIONS(6181),
    [aux_sym_zero_directive_token5] = ACTIONS(6181),
    [aux_sym_zero_directive_token6] = ACTIONS(6181),
    [aux_sym_zero_directive_token7] = ACTIONS(6181),
    [aux_sym_zero_directive_token8] = ACTIONS(6181),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6181),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6181),
    [anon_sym_wire] = ACTIONS(6183),
    [anon_sym_tri] = ACTIONS(6183),
    [anon_sym_tri0] = ACTIONS(6183),
    [anon_sym_tri1] = ACTIONS(6183),
    [anon_sym_wand] = ACTIONS(6183),
    [anon_sym_triand] = ACTIONS(6183),
    [anon_sym_wor] = ACTIONS(6183),
    [anon_sym_trior] = ACTIONS(6183),
    [anon_sym_trireg] = ACTIONS(6183),
    [anon_sym_uwire] = ACTIONS(6183),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6181),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6181),
    [aux_sym_begin_keywords_token1] = ACTIONS(6181),
    [anon_sym_SEMI] = ACTIONS(6181),
    [anon_sym_endmodule] = ACTIONS(6183),
    [anon_sym_extern] = ACTIONS(6183),
    [anon_sym_module] = ACTIONS(6183),
    [anon_sym_macromodule] = ACTIONS(6183),
    [anon_sym_endinterface] = ACTIONS(6183),
    [anon_sym_interface] = ACTIONS(6183),
    [anon_sym_program] = ACTIONS(6183),
    [anon_sym_checker] = ACTIONS(6183),
    [anon_sym_virtual] = ACTIONS(6183),
    [anon_sym_class] = ACTIONS(6183),
    [anon_sym_package] = ACTIONS(6183),
    [anon_sym_timeunit] = ACTIONS(6183),
    [anon_sym_timeprecision] = ACTIONS(6183),
    [anon_sym_type] = ACTIONS(6183),
    [anon_sym_input] = ACTIONS(6183),
    [anon_sym_output] = ACTIONS(6183),
    [anon_sym_inout] = ACTIONS(6183),
    [anon_sym_ref] = ACTIONS(6183),
    [anon_sym_DOLLARfatal] = ACTIONS(6181),
    [anon_sym_DOLLARerror] = ACTIONS(6181),
    [anon_sym_DOLLARwarning] = ACTIONS(6181),
    [anon_sym_DOLLARinfo] = ACTIONS(6181),
    [anon_sym_default] = ACTIONS(6183),
    [anon_sym_clocking] = ACTIONS(6183),
    [anon_sym_defparam] = ACTIONS(6183),
    [anon_sym_bind] = ACTIONS(6183),
    [anon_sym_const] = ACTIONS(6183),
    [anon_sym_function] = ACTIONS(6183),
    [anon_sym_static] = ACTIONS(6183),
    [anon_sym_constraint] = ACTIONS(6183),
    [anon_sym_if] = ACTIONS(6183),
    [anon_sym_LBRACK] = ACTIONS(6181),
    [anon_sym_localparam] = ACTIONS(6183),
    [anon_sym_parameter] = ACTIONS(6183),
    [anon_sym_specparam] = ACTIONS(6183),
    [anon_sym_var] = ACTIONS(6183),
    [anon_sym_import] = ACTIONS(6183),
    [anon_sym_export] = ACTIONS(6183),
    [anon_sym_genvar] = ACTIONS(6183),
    [anon_sym_interconnect] = ACTIONS(6183),
    [anon_sym_typedef] = ACTIONS(6183),
    [anon_sym_enum] = ACTIONS(6183),
    [anon_sym_struct] = ACTIONS(6183),
    [anon_sym_union] = ACTIONS(6183),
    [anon_sym_nettype] = ACTIONS(6183),
    [anon_sym_automatic] = ACTIONS(6183),
    [anon_sym_string] = ACTIONS(6183),
    [anon_sym_chandle] = ACTIONS(6183),
    [anon_sym_event] = ACTIONS(6183),
    [anon_sym_byte] = ACTIONS(6183),
    [anon_sym_shortint] = ACTIONS(6183),
    [anon_sym_int] = ACTIONS(6183),
    [anon_sym_longint] = ACTIONS(6183),
    [anon_sym_integer] = ACTIONS(6183),
    [anon_sym_time] = ACTIONS(6183),
    [anon_sym_bit] = ACTIONS(6183),
    [anon_sym_logic] = ACTIONS(6183),
    [anon_sym_reg] = ACTIONS(6183),
    [anon_sym_shortreal] = ACTIONS(6183),
    [anon_sym_real] = ACTIONS(6183),
    [anon_sym_realtime] = ACTIONS(6183),
    [anon_sym_supply0] = ACTIONS(6183),
    [anon_sym_supply1] = ACTIONS(6183),
    [anon_sym_signed] = ACTIONS(6183),
    [anon_sym_unsigned] = ACTIONS(6183),
    [anon_sym_task] = ACTIONS(6183),
    [anon_sym_modport] = ACTIONS(6183),
    [anon_sym_assert] = ACTIONS(6183),
    [anon_sym_property] = ACTIONS(6183),
    [anon_sym_assume] = ACTIONS(6183),
    [anon_sym_cover] = ACTIONS(6183),
    [anon_sym_sequence] = ACTIONS(6183),
    [anon_sym_restrict] = ACTIONS(6183),
    [anon_sym_not] = ACTIONS(6183),
    [anon_sym_or] = ACTIONS(6183),
    [anon_sym_and] = ACTIONS(6183),
    [anon_sym_case] = ACTIONS(6183),
    [anon_sym_always] = ACTIONS(6183),
    [anon_sym_covergroup] = ACTIONS(6183),
    [anon_sym_let] = ACTIONS(6183),
    [anon_sym_pulldown] = ACTIONS(6183),
    [anon_sym_pullup] = ACTIONS(6183),
    [anon_sym_cmos] = ACTIONS(6183),
    [anon_sym_rcmos] = ACTIONS(6183),
    [anon_sym_bufif0] = ACTIONS(6183),
    [anon_sym_bufif1] = ACTIONS(6183),
    [anon_sym_notif0] = ACTIONS(6183),
    [anon_sym_notif1] = ACTIONS(6183),
    [anon_sym_nmos] = ACTIONS(6183),
    [anon_sym_pmos] = ACTIONS(6183),
    [anon_sym_rnmos] = ACTIONS(6183),
    [anon_sym_rpmos] = ACTIONS(6183),
    [anon_sym_nand] = ACTIONS(6183),
    [anon_sym_nor] = ACTIONS(6183),
    [anon_sym_xor] = ACTIONS(6183),
    [anon_sym_xnor] = ACTIONS(6183),
    [anon_sym_buf] = ACTIONS(6183),
    [anon_sym_tranif0] = ACTIONS(6183),
    [anon_sym_tranif1] = ACTIONS(6183),
    [anon_sym_rtranif1] = ACTIONS(6183),
    [anon_sym_rtranif0] = ACTIONS(6183),
    [anon_sym_tran] = ACTIONS(6183),
    [anon_sym_rtran] = ACTIONS(6183),
    [anon_sym_generate] = ACTIONS(6183),
    [anon_sym_for] = ACTIONS(6183),
    [anon_sym_primitive] = ACTIONS(6183),
    [anon_sym_initial] = ACTIONS(6183),
    [anon_sym_assign] = ACTIONS(6183),
    [anon_sym_alias] = ACTIONS(6183),
    [anon_sym_always_comb] = ACTIONS(6183),
    [anon_sym_always_latch] = ACTIONS(6183),
    [anon_sym_always_ff] = ACTIONS(6183),
    [anon_sym_final] = ACTIONS(6183),
    [anon_sym_global] = ACTIONS(6183),
    [anon_sym_specify] = ACTIONS(6183),
    [anon_sym_LPAREN_STAR] = ACTIONS(6181),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6181),
    [anon_sym_DOLLARunit] = ACTIONS(6181),
  },
  [1113] = {
    [ts_builtin_sym_end] = ACTIONS(6185),
    [sym_simple_identifier] = ACTIONS(6187),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6185),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6185),
    [anon_sym_BQUOTE] = ACTIONS(6187),
    [aux_sym_id_directive_token1] = ACTIONS(6185),
    [aux_sym_id_directive_token2] = ACTIONS(6185),
    [aux_sym_id_directive_token3] = ACTIONS(6185),
    [aux_sym_id_directive_token4] = ACTIONS(6187),
    [aux_sym_zero_directive_token1] = ACTIONS(6185),
    [aux_sym_zero_directive_token2] = ACTIONS(6185),
    [aux_sym_zero_directive_token3] = ACTIONS(6185),
    [aux_sym_zero_directive_token4] = ACTIONS(6185),
    [aux_sym_zero_directive_token5] = ACTIONS(6185),
    [aux_sym_zero_directive_token6] = ACTIONS(6185),
    [aux_sym_zero_directive_token7] = ACTIONS(6185),
    [aux_sym_zero_directive_token8] = ACTIONS(6185),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6185),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6185),
    [anon_sym_wire] = ACTIONS(6187),
    [anon_sym_tri] = ACTIONS(6187),
    [anon_sym_tri0] = ACTIONS(6187),
    [anon_sym_tri1] = ACTIONS(6187),
    [anon_sym_wand] = ACTIONS(6187),
    [anon_sym_triand] = ACTIONS(6187),
    [anon_sym_wor] = ACTIONS(6187),
    [anon_sym_trior] = ACTIONS(6187),
    [anon_sym_trireg] = ACTIONS(6187),
    [anon_sym_uwire] = ACTIONS(6187),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6185),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6185),
    [aux_sym_begin_keywords_token1] = ACTIONS(6185),
    [anon_sym_SEMI] = ACTIONS(6185),
    [anon_sym_endmodule] = ACTIONS(6187),
    [anon_sym_extern] = ACTIONS(6187),
    [anon_sym_module] = ACTIONS(6187),
    [anon_sym_macromodule] = ACTIONS(6187),
    [anon_sym_endinterface] = ACTIONS(6187),
    [anon_sym_interface] = ACTIONS(6187),
    [anon_sym_program] = ACTIONS(6187),
    [anon_sym_checker] = ACTIONS(6187),
    [anon_sym_virtual] = ACTIONS(6187),
    [anon_sym_class] = ACTIONS(6187),
    [anon_sym_package] = ACTIONS(6187),
    [anon_sym_timeunit] = ACTIONS(6187),
    [anon_sym_timeprecision] = ACTIONS(6187),
    [anon_sym_type] = ACTIONS(6187),
    [anon_sym_input] = ACTIONS(6187),
    [anon_sym_output] = ACTIONS(6187),
    [anon_sym_inout] = ACTIONS(6187),
    [anon_sym_ref] = ACTIONS(6187),
    [anon_sym_DOLLARfatal] = ACTIONS(6185),
    [anon_sym_DOLLARerror] = ACTIONS(6185),
    [anon_sym_DOLLARwarning] = ACTIONS(6185),
    [anon_sym_DOLLARinfo] = ACTIONS(6185),
    [anon_sym_default] = ACTIONS(6187),
    [anon_sym_clocking] = ACTIONS(6187),
    [anon_sym_defparam] = ACTIONS(6187),
    [anon_sym_bind] = ACTIONS(6187),
    [anon_sym_const] = ACTIONS(6187),
    [anon_sym_function] = ACTIONS(6187),
    [anon_sym_static] = ACTIONS(6187),
    [anon_sym_constraint] = ACTIONS(6187),
    [anon_sym_if] = ACTIONS(6187),
    [anon_sym_LBRACK] = ACTIONS(6185),
    [anon_sym_localparam] = ACTIONS(6187),
    [anon_sym_parameter] = ACTIONS(6187),
    [anon_sym_specparam] = ACTIONS(6187),
    [anon_sym_var] = ACTIONS(6187),
    [anon_sym_import] = ACTIONS(6187),
    [anon_sym_export] = ACTIONS(6187),
    [anon_sym_genvar] = ACTIONS(6187),
    [anon_sym_interconnect] = ACTIONS(6187),
    [anon_sym_typedef] = ACTIONS(6187),
    [anon_sym_enum] = ACTIONS(6187),
    [anon_sym_struct] = ACTIONS(6187),
    [anon_sym_union] = ACTIONS(6187),
    [anon_sym_nettype] = ACTIONS(6187),
    [anon_sym_automatic] = ACTIONS(6187),
    [anon_sym_string] = ACTIONS(6187),
    [anon_sym_chandle] = ACTIONS(6187),
    [anon_sym_event] = ACTIONS(6187),
    [anon_sym_byte] = ACTIONS(6187),
    [anon_sym_shortint] = ACTIONS(6187),
    [anon_sym_int] = ACTIONS(6187),
    [anon_sym_longint] = ACTIONS(6187),
    [anon_sym_integer] = ACTIONS(6187),
    [anon_sym_time] = ACTIONS(6187),
    [anon_sym_bit] = ACTIONS(6187),
    [anon_sym_logic] = ACTIONS(6187),
    [anon_sym_reg] = ACTIONS(6187),
    [anon_sym_shortreal] = ACTIONS(6187),
    [anon_sym_real] = ACTIONS(6187),
    [anon_sym_realtime] = ACTIONS(6187),
    [anon_sym_supply0] = ACTIONS(6187),
    [anon_sym_supply1] = ACTIONS(6187),
    [anon_sym_signed] = ACTIONS(6187),
    [anon_sym_unsigned] = ACTIONS(6187),
    [anon_sym_task] = ACTIONS(6187),
    [anon_sym_modport] = ACTIONS(6187),
    [anon_sym_assert] = ACTIONS(6187),
    [anon_sym_property] = ACTIONS(6187),
    [anon_sym_assume] = ACTIONS(6187),
    [anon_sym_cover] = ACTIONS(6187),
    [anon_sym_sequence] = ACTIONS(6187),
    [anon_sym_restrict] = ACTIONS(6187),
    [anon_sym_not] = ACTIONS(6187),
    [anon_sym_or] = ACTIONS(6187),
    [anon_sym_and] = ACTIONS(6187),
    [anon_sym_case] = ACTIONS(6187),
    [anon_sym_always] = ACTIONS(6187),
    [anon_sym_covergroup] = ACTIONS(6187),
    [anon_sym_let] = ACTIONS(6187),
    [anon_sym_pulldown] = ACTIONS(6187),
    [anon_sym_pullup] = ACTIONS(6187),
    [anon_sym_cmos] = ACTIONS(6187),
    [anon_sym_rcmos] = ACTIONS(6187),
    [anon_sym_bufif0] = ACTIONS(6187),
    [anon_sym_bufif1] = ACTIONS(6187),
    [anon_sym_notif0] = ACTIONS(6187),
    [anon_sym_notif1] = ACTIONS(6187),
    [anon_sym_nmos] = ACTIONS(6187),
    [anon_sym_pmos] = ACTIONS(6187),
    [anon_sym_rnmos] = ACTIONS(6187),
    [anon_sym_rpmos] = ACTIONS(6187),
    [anon_sym_nand] = ACTIONS(6187),
    [anon_sym_nor] = ACTIONS(6187),
    [anon_sym_xor] = ACTIONS(6187),
    [anon_sym_xnor] = ACTIONS(6187),
    [anon_sym_buf] = ACTIONS(6187),
    [anon_sym_tranif0] = ACTIONS(6187),
    [anon_sym_tranif1] = ACTIONS(6187),
    [anon_sym_rtranif1] = ACTIONS(6187),
    [anon_sym_rtranif0] = ACTIONS(6187),
    [anon_sym_tran] = ACTIONS(6187),
    [anon_sym_rtran] = ACTIONS(6187),
    [anon_sym_generate] = ACTIONS(6187),
    [anon_sym_for] = ACTIONS(6187),
    [anon_sym_primitive] = ACTIONS(6187),
    [anon_sym_initial] = ACTIONS(6187),
    [anon_sym_assign] = ACTIONS(6187),
    [anon_sym_alias] = ACTIONS(6187),
    [anon_sym_always_comb] = ACTIONS(6187),
    [anon_sym_always_latch] = ACTIONS(6187),
    [anon_sym_always_ff] = ACTIONS(6187),
    [anon_sym_final] = ACTIONS(6187),
    [anon_sym_global] = ACTIONS(6187),
    [anon_sym_specify] = ACTIONS(6187),
    [anon_sym_LPAREN_STAR] = ACTIONS(6185),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6185),
    [anon_sym_DOLLARunit] = ACTIONS(6185),
  },
  [1114] = {
    [ts_builtin_sym_end] = ACTIONS(6189),
    [sym_simple_identifier] = ACTIONS(6191),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6189),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6189),
    [anon_sym_BQUOTE] = ACTIONS(6191),
    [aux_sym_id_directive_token1] = ACTIONS(6189),
    [aux_sym_id_directive_token2] = ACTIONS(6189),
    [aux_sym_id_directive_token3] = ACTIONS(6189),
    [aux_sym_id_directive_token4] = ACTIONS(6191),
    [aux_sym_zero_directive_token1] = ACTIONS(6189),
    [aux_sym_zero_directive_token2] = ACTIONS(6189),
    [aux_sym_zero_directive_token3] = ACTIONS(6189),
    [aux_sym_zero_directive_token4] = ACTIONS(6189),
    [aux_sym_zero_directive_token5] = ACTIONS(6189),
    [aux_sym_zero_directive_token6] = ACTIONS(6189),
    [aux_sym_zero_directive_token7] = ACTIONS(6189),
    [aux_sym_zero_directive_token8] = ACTIONS(6189),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6189),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6189),
    [anon_sym_wire] = ACTIONS(6191),
    [anon_sym_tri] = ACTIONS(6191),
    [anon_sym_tri0] = ACTIONS(6191),
    [anon_sym_tri1] = ACTIONS(6191),
    [anon_sym_wand] = ACTIONS(6191),
    [anon_sym_triand] = ACTIONS(6191),
    [anon_sym_wor] = ACTIONS(6191),
    [anon_sym_trior] = ACTIONS(6191),
    [anon_sym_trireg] = ACTIONS(6191),
    [anon_sym_uwire] = ACTIONS(6191),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6189),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6189),
    [aux_sym_begin_keywords_token1] = ACTIONS(6189),
    [anon_sym_SEMI] = ACTIONS(6189),
    [anon_sym_endmodule] = ACTIONS(6191),
    [anon_sym_extern] = ACTIONS(6191),
    [anon_sym_module] = ACTIONS(6191),
    [anon_sym_macromodule] = ACTIONS(6191),
    [anon_sym_endinterface] = ACTIONS(6191),
    [anon_sym_interface] = ACTIONS(6191),
    [anon_sym_program] = ACTIONS(6191),
    [anon_sym_checker] = ACTIONS(6191),
    [anon_sym_virtual] = ACTIONS(6191),
    [anon_sym_class] = ACTIONS(6191),
    [anon_sym_package] = ACTIONS(6191),
    [anon_sym_timeunit] = ACTIONS(6191),
    [anon_sym_timeprecision] = ACTIONS(6191),
    [anon_sym_type] = ACTIONS(6191),
    [anon_sym_input] = ACTIONS(6191),
    [anon_sym_output] = ACTIONS(6191),
    [anon_sym_inout] = ACTIONS(6191),
    [anon_sym_ref] = ACTIONS(6191),
    [anon_sym_DOLLARfatal] = ACTIONS(6189),
    [anon_sym_DOLLARerror] = ACTIONS(6189),
    [anon_sym_DOLLARwarning] = ACTIONS(6189),
    [anon_sym_DOLLARinfo] = ACTIONS(6189),
    [anon_sym_default] = ACTIONS(6191),
    [anon_sym_clocking] = ACTIONS(6191),
    [anon_sym_defparam] = ACTIONS(6191),
    [anon_sym_bind] = ACTIONS(6191),
    [anon_sym_const] = ACTIONS(6191),
    [anon_sym_function] = ACTIONS(6191),
    [anon_sym_static] = ACTIONS(6191),
    [anon_sym_constraint] = ACTIONS(6191),
    [anon_sym_if] = ACTIONS(6191),
    [anon_sym_LBRACK] = ACTIONS(6189),
    [anon_sym_localparam] = ACTIONS(6191),
    [anon_sym_parameter] = ACTIONS(6191),
    [anon_sym_specparam] = ACTIONS(6191),
    [anon_sym_var] = ACTIONS(6191),
    [anon_sym_import] = ACTIONS(6191),
    [anon_sym_export] = ACTIONS(6191),
    [anon_sym_genvar] = ACTIONS(6191),
    [anon_sym_interconnect] = ACTIONS(6191),
    [anon_sym_typedef] = ACTIONS(6191),
    [anon_sym_enum] = ACTIONS(6191),
    [anon_sym_struct] = ACTIONS(6191),
    [anon_sym_union] = ACTIONS(6191),
    [anon_sym_nettype] = ACTIONS(6191),
    [anon_sym_automatic] = ACTIONS(6191),
    [anon_sym_string] = ACTIONS(6191),
    [anon_sym_chandle] = ACTIONS(6191),
    [anon_sym_event] = ACTIONS(6191),
    [anon_sym_byte] = ACTIONS(6191),
    [anon_sym_shortint] = ACTIONS(6191),
    [anon_sym_int] = ACTIONS(6191),
    [anon_sym_longint] = ACTIONS(6191),
    [anon_sym_integer] = ACTIONS(6191),
    [anon_sym_time] = ACTIONS(6191),
    [anon_sym_bit] = ACTIONS(6191),
    [anon_sym_logic] = ACTIONS(6191),
    [anon_sym_reg] = ACTIONS(6191),
    [anon_sym_shortreal] = ACTIONS(6191),
    [anon_sym_real] = ACTIONS(6191),
    [anon_sym_realtime] = ACTIONS(6191),
    [anon_sym_supply0] = ACTIONS(6191),
    [anon_sym_supply1] = ACTIONS(6191),
    [anon_sym_signed] = ACTIONS(6191),
    [anon_sym_unsigned] = ACTIONS(6191),
    [anon_sym_task] = ACTIONS(6191),
    [anon_sym_modport] = ACTIONS(6191),
    [anon_sym_assert] = ACTIONS(6191),
    [anon_sym_property] = ACTIONS(6191),
    [anon_sym_assume] = ACTIONS(6191),
    [anon_sym_cover] = ACTIONS(6191),
    [anon_sym_sequence] = ACTIONS(6191),
    [anon_sym_restrict] = ACTIONS(6191),
    [anon_sym_not] = ACTIONS(6191),
    [anon_sym_or] = ACTIONS(6191),
    [anon_sym_and] = ACTIONS(6191),
    [anon_sym_case] = ACTIONS(6191),
    [anon_sym_always] = ACTIONS(6191),
    [anon_sym_covergroup] = ACTIONS(6191),
    [anon_sym_let] = ACTIONS(6191),
    [anon_sym_pulldown] = ACTIONS(6191),
    [anon_sym_pullup] = ACTIONS(6191),
    [anon_sym_cmos] = ACTIONS(6191),
    [anon_sym_rcmos] = ACTIONS(6191),
    [anon_sym_bufif0] = ACTIONS(6191),
    [anon_sym_bufif1] = ACTIONS(6191),
    [anon_sym_notif0] = ACTIONS(6191),
    [anon_sym_notif1] = ACTIONS(6191),
    [anon_sym_nmos] = ACTIONS(6191),
    [anon_sym_pmos] = ACTIONS(6191),
    [anon_sym_rnmos] = ACTIONS(6191),
    [anon_sym_rpmos] = ACTIONS(6191),
    [anon_sym_nand] = ACTIONS(6191),
    [anon_sym_nor] = ACTIONS(6191),
    [anon_sym_xor] = ACTIONS(6191),
    [anon_sym_xnor] = ACTIONS(6191),
    [anon_sym_buf] = ACTIONS(6191),
    [anon_sym_tranif0] = ACTIONS(6191),
    [anon_sym_tranif1] = ACTIONS(6191),
    [anon_sym_rtranif1] = ACTIONS(6191),
    [anon_sym_rtranif0] = ACTIONS(6191),
    [anon_sym_tran] = ACTIONS(6191),
    [anon_sym_rtran] = ACTIONS(6191),
    [anon_sym_generate] = ACTIONS(6191),
    [anon_sym_for] = ACTIONS(6191),
    [anon_sym_primitive] = ACTIONS(6191),
    [anon_sym_initial] = ACTIONS(6191),
    [anon_sym_assign] = ACTIONS(6191),
    [anon_sym_alias] = ACTIONS(6191),
    [anon_sym_always_comb] = ACTIONS(6191),
    [anon_sym_always_latch] = ACTIONS(6191),
    [anon_sym_always_ff] = ACTIONS(6191),
    [anon_sym_final] = ACTIONS(6191),
    [anon_sym_global] = ACTIONS(6191),
    [anon_sym_specify] = ACTIONS(6191),
    [anon_sym_LPAREN_STAR] = ACTIONS(6189),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6189),
    [anon_sym_DOLLARunit] = ACTIONS(6189),
  },
  [1115] = {
    [ts_builtin_sym_end] = ACTIONS(6193),
    [sym_simple_identifier] = ACTIONS(6195),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6193),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6193),
    [anon_sym_BQUOTE] = ACTIONS(6195),
    [aux_sym_id_directive_token1] = ACTIONS(6193),
    [aux_sym_id_directive_token2] = ACTIONS(6193),
    [aux_sym_id_directive_token3] = ACTIONS(6193),
    [aux_sym_id_directive_token4] = ACTIONS(6195),
    [aux_sym_zero_directive_token1] = ACTIONS(6193),
    [aux_sym_zero_directive_token2] = ACTIONS(6193),
    [aux_sym_zero_directive_token3] = ACTIONS(6193),
    [aux_sym_zero_directive_token4] = ACTIONS(6193),
    [aux_sym_zero_directive_token5] = ACTIONS(6193),
    [aux_sym_zero_directive_token6] = ACTIONS(6193),
    [aux_sym_zero_directive_token7] = ACTIONS(6193),
    [aux_sym_zero_directive_token8] = ACTIONS(6193),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6193),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6193),
    [anon_sym_wire] = ACTIONS(6195),
    [anon_sym_tri] = ACTIONS(6195),
    [anon_sym_tri0] = ACTIONS(6195),
    [anon_sym_tri1] = ACTIONS(6195),
    [anon_sym_wand] = ACTIONS(6195),
    [anon_sym_triand] = ACTIONS(6195),
    [anon_sym_wor] = ACTIONS(6195),
    [anon_sym_trior] = ACTIONS(6195),
    [anon_sym_trireg] = ACTIONS(6195),
    [anon_sym_uwire] = ACTIONS(6195),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6193),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6193),
    [aux_sym_begin_keywords_token1] = ACTIONS(6193),
    [anon_sym_SEMI] = ACTIONS(6193),
    [anon_sym_endmodule] = ACTIONS(6195),
    [anon_sym_extern] = ACTIONS(6195),
    [anon_sym_module] = ACTIONS(6195),
    [anon_sym_macromodule] = ACTIONS(6195),
    [anon_sym_endinterface] = ACTIONS(6195),
    [anon_sym_interface] = ACTIONS(6195),
    [anon_sym_program] = ACTIONS(6195),
    [anon_sym_checker] = ACTIONS(6195),
    [anon_sym_virtual] = ACTIONS(6195),
    [anon_sym_class] = ACTIONS(6195),
    [anon_sym_package] = ACTIONS(6195),
    [anon_sym_timeunit] = ACTIONS(6195),
    [anon_sym_timeprecision] = ACTIONS(6195),
    [anon_sym_type] = ACTIONS(6195),
    [anon_sym_input] = ACTIONS(6195),
    [anon_sym_output] = ACTIONS(6195),
    [anon_sym_inout] = ACTIONS(6195),
    [anon_sym_ref] = ACTIONS(6195),
    [anon_sym_DOLLARfatal] = ACTIONS(6193),
    [anon_sym_DOLLARerror] = ACTIONS(6193),
    [anon_sym_DOLLARwarning] = ACTIONS(6193),
    [anon_sym_DOLLARinfo] = ACTIONS(6193),
    [anon_sym_default] = ACTIONS(6195),
    [anon_sym_clocking] = ACTIONS(6195),
    [anon_sym_defparam] = ACTIONS(6195),
    [anon_sym_bind] = ACTIONS(6195),
    [anon_sym_const] = ACTIONS(6195),
    [anon_sym_function] = ACTIONS(6195),
    [anon_sym_static] = ACTIONS(6195),
    [anon_sym_constraint] = ACTIONS(6195),
    [anon_sym_if] = ACTIONS(6195),
    [anon_sym_LBRACK] = ACTIONS(6193),
    [anon_sym_localparam] = ACTIONS(6195),
    [anon_sym_parameter] = ACTIONS(6195),
    [anon_sym_specparam] = ACTIONS(6195),
    [anon_sym_var] = ACTIONS(6195),
    [anon_sym_import] = ACTIONS(6195),
    [anon_sym_export] = ACTIONS(6195),
    [anon_sym_genvar] = ACTIONS(6195),
    [anon_sym_interconnect] = ACTIONS(6195),
    [anon_sym_typedef] = ACTIONS(6195),
    [anon_sym_enum] = ACTIONS(6195),
    [anon_sym_struct] = ACTIONS(6195),
    [anon_sym_union] = ACTIONS(6195),
    [anon_sym_nettype] = ACTIONS(6195),
    [anon_sym_automatic] = ACTIONS(6195),
    [anon_sym_string] = ACTIONS(6195),
    [anon_sym_chandle] = ACTIONS(6195),
    [anon_sym_event] = ACTIONS(6195),
    [anon_sym_byte] = ACTIONS(6195),
    [anon_sym_shortint] = ACTIONS(6195),
    [anon_sym_int] = ACTIONS(6195),
    [anon_sym_longint] = ACTIONS(6195),
    [anon_sym_integer] = ACTIONS(6195),
    [anon_sym_time] = ACTIONS(6195),
    [anon_sym_bit] = ACTIONS(6195),
    [anon_sym_logic] = ACTIONS(6195),
    [anon_sym_reg] = ACTIONS(6195),
    [anon_sym_shortreal] = ACTIONS(6195),
    [anon_sym_real] = ACTIONS(6195),
    [anon_sym_realtime] = ACTIONS(6195),
    [anon_sym_supply0] = ACTIONS(6195),
    [anon_sym_supply1] = ACTIONS(6195),
    [anon_sym_signed] = ACTIONS(6195),
    [anon_sym_unsigned] = ACTIONS(6195),
    [anon_sym_task] = ACTIONS(6195),
    [anon_sym_modport] = ACTIONS(6195),
    [anon_sym_assert] = ACTIONS(6195),
    [anon_sym_property] = ACTIONS(6195),
    [anon_sym_assume] = ACTIONS(6195),
    [anon_sym_cover] = ACTIONS(6195),
    [anon_sym_sequence] = ACTIONS(6195),
    [anon_sym_restrict] = ACTIONS(6195),
    [anon_sym_not] = ACTIONS(6195),
    [anon_sym_or] = ACTIONS(6195),
    [anon_sym_and] = ACTIONS(6195),
    [anon_sym_case] = ACTIONS(6195),
    [anon_sym_always] = ACTIONS(6195),
    [anon_sym_covergroup] = ACTIONS(6195),
    [anon_sym_let] = ACTIONS(6195),
    [anon_sym_pulldown] = ACTIONS(6195),
    [anon_sym_pullup] = ACTIONS(6195),
    [anon_sym_cmos] = ACTIONS(6195),
    [anon_sym_rcmos] = ACTIONS(6195),
    [anon_sym_bufif0] = ACTIONS(6195),
    [anon_sym_bufif1] = ACTIONS(6195),
    [anon_sym_notif0] = ACTIONS(6195),
    [anon_sym_notif1] = ACTIONS(6195),
    [anon_sym_nmos] = ACTIONS(6195),
    [anon_sym_pmos] = ACTIONS(6195),
    [anon_sym_rnmos] = ACTIONS(6195),
    [anon_sym_rpmos] = ACTIONS(6195),
    [anon_sym_nand] = ACTIONS(6195),
    [anon_sym_nor] = ACTIONS(6195),
    [anon_sym_xor] = ACTIONS(6195),
    [anon_sym_xnor] = ACTIONS(6195),
    [anon_sym_buf] = ACTIONS(6195),
    [anon_sym_tranif0] = ACTIONS(6195),
    [anon_sym_tranif1] = ACTIONS(6195),
    [anon_sym_rtranif1] = ACTIONS(6195),
    [anon_sym_rtranif0] = ACTIONS(6195),
    [anon_sym_tran] = ACTIONS(6195),
    [anon_sym_rtran] = ACTIONS(6195),
    [anon_sym_generate] = ACTIONS(6195),
    [anon_sym_for] = ACTIONS(6195),
    [anon_sym_primitive] = ACTIONS(6195),
    [anon_sym_initial] = ACTIONS(6195),
    [anon_sym_assign] = ACTIONS(6195),
    [anon_sym_alias] = ACTIONS(6195),
    [anon_sym_always_comb] = ACTIONS(6195),
    [anon_sym_always_latch] = ACTIONS(6195),
    [anon_sym_always_ff] = ACTIONS(6195),
    [anon_sym_final] = ACTIONS(6195),
    [anon_sym_global] = ACTIONS(6195),
    [anon_sym_specify] = ACTIONS(6195),
    [anon_sym_LPAREN_STAR] = ACTIONS(6193),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6193),
    [anon_sym_DOLLARunit] = ACTIONS(6193),
  },
  [1116] = {
    [ts_builtin_sym_end] = ACTIONS(6197),
    [sym_simple_identifier] = ACTIONS(6199),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6197),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6197),
    [anon_sym_BQUOTE] = ACTIONS(6199),
    [aux_sym_id_directive_token1] = ACTIONS(6197),
    [aux_sym_id_directive_token2] = ACTIONS(6197),
    [aux_sym_id_directive_token3] = ACTIONS(6197),
    [aux_sym_id_directive_token4] = ACTIONS(6199),
    [aux_sym_zero_directive_token1] = ACTIONS(6197),
    [aux_sym_zero_directive_token2] = ACTIONS(6197),
    [aux_sym_zero_directive_token3] = ACTIONS(6197),
    [aux_sym_zero_directive_token4] = ACTIONS(6197),
    [aux_sym_zero_directive_token5] = ACTIONS(6197),
    [aux_sym_zero_directive_token6] = ACTIONS(6197),
    [aux_sym_zero_directive_token7] = ACTIONS(6197),
    [aux_sym_zero_directive_token8] = ACTIONS(6197),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6197),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6197),
    [anon_sym_wire] = ACTIONS(6199),
    [anon_sym_tri] = ACTIONS(6199),
    [anon_sym_tri0] = ACTIONS(6199),
    [anon_sym_tri1] = ACTIONS(6199),
    [anon_sym_wand] = ACTIONS(6199),
    [anon_sym_triand] = ACTIONS(6199),
    [anon_sym_wor] = ACTIONS(6199),
    [anon_sym_trior] = ACTIONS(6199),
    [anon_sym_trireg] = ACTIONS(6199),
    [anon_sym_uwire] = ACTIONS(6199),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6197),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6197),
    [aux_sym_begin_keywords_token1] = ACTIONS(6197),
    [anon_sym_SEMI] = ACTIONS(6197),
    [anon_sym_endmodule] = ACTIONS(6199),
    [anon_sym_extern] = ACTIONS(6199),
    [anon_sym_module] = ACTIONS(6199),
    [anon_sym_macromodule] = ACTIONS(6199),
    [anon_sym_endinterface] = ACTIONS(6199),
    [anon_sym_interface] = ACTIONS(6199),
    [anon_sym_program] = ACTIONS(6199),
    [anon_sym_checker] = ACTIONS(6199),
    [anon_sym_virtual] = ACTIONS(6199),
    [anon_sym_class] = ACTIONS(6199),
    [anon_sym_package] = ACTIONS(6199),
    [anon_sym_timeunit] = ACTIONS(6199),
    [anon_sym_timeprecision] = ACTIONS(6199),
    [anon_sym_type] = ACTIONS(6199),
    [anon_sym_input] = ACTIONS(6199),
    [anon_sym_output] = ACTIONS(6199),
    [anon_sym_inout] = ACTIONS(6199),
    [anon_sym_ref] = ACTIONS(6199),
    [anon_sym_DOLLARfatal] = ACTIONS(6197),
    [anon_sym_DOLLARerror] = ACTIONS(6197),
    [anon_sym_DOLLARwarning] = ACTIONS(6197),
    [anon_sym_DOLLARinfo] = ACTIONS(6197),
    [anon_sym_default] = ACTIONS(6199),
    [anon_sym_clocking] = ACTIONS(6199),
    [anon_sym_defparam] = ACTIONS(6199),
    [anon_sym_bind] = ACTIONS(6199),
    [anon_sym_const] = ACTIONS(6199),
    [anon_sym_function] = ACTIONS(6199),
    [anon_sym_static] = ACTIONS(6199),
    [anon_sym_constraint] = ACTIONS(6199),
    [anon_sym_if] = ACTIONS(6199),
    [anon_sym_LBRACK] = ACTIONS(6197),
    [anon_sym_localparam] = ACTIONS(6199),
    [anon_sym_parameter] = ACTIONS(6199),
    [anon_sym_specparam] = ACTIONS(6199),
    [anon_sym_var] = ACTIONS(6199),
    [anon_sym_import] = ACTIONS(6199),
    [anon_sym_export] = ACTIONS(6199),
    [anon_sym_genvar] = ACTIONS(6199),
    [anon_sym_interconnect] = ACTIONS(6199),
    [anon_sym_typedef] = ACTIONS(6199),
    [anon_sym_enum] = ACTIONS(6199),
    [anon_sym_struct] = ACTIONS(6199),
    [anon_sym_union] = ACTIONS(6199),
    [anon_sym_nettype] = ACTIONS(6199),
    [anon_sym_automatic] = ACTIONS(6199),
    [anon_sym_string] = ACTIONS(6199),
    [anon_sym_chandle] = ACTIONS(6199),
    [anon_sym_event] = ACTIONS(6199),
    [anon_sym_byte] = ACTIONS(6199),
    [anon_sym_shortint] = ACTIONS(6199),
    [anon_sym_int] = ACTIONS(6199),
    [anon_sym_longint] = ACTIONS(6199),
    [anon_sym_integer] = ACTIONS(6199),
    [anon_sym_time] = ACTIONS(6199),
    [anon_sym_bit] = ACTIONS(6199),
    [anon_sym_logic] = ACTIONS(6199),
    [anon_sym_reg] = ACTIONS(6199),
    [anon_sym_shortreal] = ACTIONS(6199),
    [anon_sym_real] = ACTIONS(6199),
    [anon_sym_realtime] = ACTIONS(6199),
    [anon_sym_supply0] = ACTIONS(6199),
    [anon_sym_supply1] = ACTIONS(6199),
    [anon_sym_signed] = ACTIONS(6199),
    [anon_sym_unsigned] = ACTIONS(6199),
    [anon_sym_task] = ACTIONS(6199),
    [anon_sym_modport] = ACTIONS(6199),
    [anon_sym_assert] = ACTIONS(6199),
    [anon_sym_property] = ACTIONS(6199),
    [anon_sym_assume] = ACTIONS(6199),
    [anon_sym_cover] = ACTIONS(6199),
    [anon_sym_sequence] = ACTIONS(6199),
    [anon_sym_restrict] = ACTIONS(6199),
    [anon_sym_not] = ACTIONS(6199),
    [anon_sym_or] = ACTIONS(6199),
    [anon_sym_and] = ACTIONS(6199),
    [anon_sym_case] = ACTIONS(6199),
    [anon_sym_always] = ACTIONS(6199),
    [anon_sym_covergroup] = ACTIONS(6199),
    [anon_sym_let] = ACTIONS(6199),
    [anon_sym_pulldown] = ACTIONS(6199),
    [anon_sym_pullup] = ACTIONS(6199),
    [anon_sym_cmos] = ACTIONS(6199),
    [anon_sym_rcmos] = ACTIONS(6199),
    [anon_sym_bufif0] = ACTIONS(6199),
    [anon_sym_bufif1] = ACTIONS(6199),
    [anon_sym_notif0] = ACTIONS(6199),
    [anon_sym_notif1] = ACTIONS(6199),
    [anon_sym_nmos] = ACTIONS(6199),
    [anon_sym_pmos] = ACTIONS(6199),
    [anon_sym_rnmos] = ACTIONS(6199),
    [anon_sym_rpmos] = ACTIONS(6199),
    [anon_sym_nand] = ACTIONS(6199),
    [anon_sym_nor] = ACTIONS(6199),
    [anon_sym_xor] = ACTIONS(6199),
    [anon_sym_xnor] = ACTIONS(6199),
    [anon_sym_buf] = ACTIONS(6199),
    [anon_sym_tranif0] = ACTIONS(6199),
    [anon_sym_tranif1] = ACTIONS(6199),
    [anon_sym_rtranif1] = ACTIONS(6199),
    [anon_sym_rtranif0] = ACTIONS(6199),
    [anon_sym_tran] = ACTIONS(6199),
    [anon_sym_rtran] = ACTIONS(6199),
    [anon_sym_generate] = ACTIONS(6199),
    [anon_sym_for] = ACTIONS(6199),
    [anon_sym_primitive] = ACTIONS(6199),
    [anon_sym_initial] = ACTIONS(6199),
    [anon_sym_assign] = ACTIONS(6199),
    [anon_sym_alias] = ACTIONS(6199),
    [anon_sym_always_comb] = ACTIONS(6199),
    [anon_sym_always_latch] = ACTIONS(6199),
    [anon_sym_always_ff] = ACTIONS(6199),
    [anon_sym_final] = ACTIONS(6199),
    [anon_sym_global] = ACTIONS(6199),
    [anon_sym_specify] = ACTIONS(6199),
    [anon_sym_LPAREN_STAR] = ACTIONS(6197),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6197),
    [anon_sym_DOLLARunit] = ACTIONS(6197),
  },
  [1117] = {
    [ts_builtin_sym_end] = ACTIONS(6201),
    [sym_simple_identifier] = ACTIONS(6203),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6201),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6201),
    [anon_sym_BQUOTE] = ACTIONS(6203),
    [aux_sym_id_directive_token1] = ACTIONS(6201),
    [aux_sym_id_directive_token2] = ACTIONS(6201),
    [aux_sym_id_directive_token3] = ACTIONS(6201),
    [aux_sym_id_directive_token4] = ACTIONS(6203),
    [aux_sym_zero_directive_token1] = ACTIONS(6201),
    [aux_sym_zero_directive_token2] = ACTIONS(6201),
    [aux_sym_zero_directive_token3] = ACTIONS(6201),
    [aux_sym_zero_directive_token4] = ACTIONS(6201),
    [aux_sym_zero_directive_token5] = ACTIONS(6201),
    [aux_sym_zero_directive_token6] = ACTIONS(6201),
    [aux_sym_zero_directive_token7] = ACTIONS(6201),
    [aux_sym_zero_directive_token8] = ACTIONS(6201),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6201),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6201),
    [anon_sym_wire] = ACTIONS(6203),
    [anon_sym_tri] = ACTIONS(6203),
    [anon_sym_tri0] = ACTIONS(6203),
    [anon_sym_tri1] = ACTIONS(6203),
    [anon_sym_wand] = ACTIONS(6203),
    [anon_sym_triand] = ACTIONS(6203),
    [anon_sym_wor] = ACTIONS(6203),
    [anon_sym_trior] = ACTIONS(6203),
    [anon_sym_trireg] = ACTIONS(6203),
    [anon_sym_uwire] = ACTIONS(6203),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6201),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6201),
    [aux_sym_begin_keywords_token1] = ACTIONS(6201),
    [anon_sym_SEMI] = ACTIONS(6201),
    [anon_sym_endmodule] = ACTIONS(6203),
    [anon_sym_extern] = ACTIONS(6203),
    [anon_sym_module] = ACTIONS(6203),
    [anon_sym_macromodule] = ACTIONS(6203),
    [anon_sym_endinterface] = ACTIONS(6203),
    [anon_sym_interface] = ACTIONS(6203),
    [anon_sym_program] = ACTIONS(6203),
    [anon_sym_checker] = ACTIONS(6203),
    [anon_sym_virtual] = ACTIONS(6203),
    [anon_sym_class] = ACTIONS(6203),
    [anon_sym_package] = ACTIONS(6203),
    [anon_sym_timeunit] = ACTIONS(6203),
    [anon_sym_timeprecision] = ACTIONS(6203),
    [anon_sym_type] = ACTIONS(6203),
    [anon_sym_input] = ACTIONS(6203),
    [anon_sym_output] = ACTIONS(6203),
    [anon_sym_inout] = ACTIONS(6203),
    [anon_sym_ref] = ACTIONS(6203),
    [anon_sym_DOLLARfatal] = ACTIONS(6201),
    [anon_sym_DOLLARerror] = ACTIONS(6201),
    [anon_sym_DOLLARwarning] = ACTIONS(6201),
    [anon_sym_DOLLARinfo] = ACTIONS(6201),
    [anon_sym_default] = ACTIONS(6203),
    [anon_sym_clocking] = ACTIONS(6203),
    [anon_sym_defparam] = ACTIONS(6203),
    [anon_sym_bind] = ACTIONS(6203),
    [anon_sym_const] = ACTIONS(6203),
    [anon_sym_function] = ACTIONS(6203),
    [anon_sym_static] = ACTIONS(6203),
    [anon_sym_constraint] = ACTIONS(6203),
    [anon_sym_if] = ACTIONS(6203),
    [anon_sym_LBRACK] = ACTIONS(6201),
    [anon_sym_localparam] = ACTIONS(6203),
    [anon_sym_parameter] = ACTIONS(6203),
    [anon_sym_specparam] = ACTIONS(6203),
    [anon_sym_var] = ACTIONS(6203),
    [anon_sym_import] = ACTIONS(6203),
    [anon_sym_export] = ACTIONS(6203),
    [anon_sym_genvar] = ACTIONS(6203),
    [anon_sym_interconnect] = ACTIONS(6203),
    [anon_sym_typedef] = ACTIONS(6203),
    [anon_sym_enum] = ACTIONS(6203),
    [anon_sym_struct] = ACTIONS(6203),
    [anon_sym_union] = ACTIONS(6203),
    [anon_sym_nettype] = ACTIONS(6203),
    [anon_sym_automatic] = ACTIONS(6203),
    [anon_sym_string] = ACTIONS(6203),
    [anon_sym_chandle] = ACTIONS(6203),
    [anon_sym_event] = ACTIONS(6203),
    [anon_sym_byte] = ACTIONS(6203),
    [anon_sym_shortint] = ACTIONS(6203),
    [anon_sym_int] = ACTIONS(6203),
    [anon_sym_longint] = ACTIONS(6203),
    [anon_sym_integer] = ACTIONS(6203),
    [anon_sym_time] = ACTIONS(6203),
    [anon_sym_bit] = ACTIONS(6203),
    [anon_sym_logic] = ACTIONS(6203),
    [anon_sym_reg] = ACTIONS(6203),
    [anon_sym_shortreal] = ACTIONS(6203),
    [anon_sym_real] = ACTIONS(6203),
    [anon_sym_realtime] = ACTIONS(6203),
    [anon_sym_supply0] = ACTIONS(6203),
    [anon_sym_supply1] = ACTIONS(6203),
    [anon_sym_signed] = ACTIONS(6203),
    [anon_sym_unsigned] = ACTIONS(6203),
    [anon_sym_task] = ACTIONS(6203),
    [anon_sym_modport] = ACTIONS(6203),
    [anon_sym_assert] = ACTIONS(6203),
    [anon_sym_property] = ACTIONS(6203),
    [anon_sym_assume] = ACTIONS(6203),
    [anon_sym_cover] = ACTIONS(6203),
    [anon_sym_sequence] = ACTIONS(6203),
    [anon_sym_restrict] = ACTIONS(6203),
    [anon_sym_not] = ACTIONS(6203),
    [anon_sym_or] = ACTIONS(6203),
    [anon_sym_and] = ACTIONS(6203),
    [anon_sym_case] = ACTIONS(6203),
    [anon_sym_always] = ACTIONS(6203),
    [anon_sym_covergroup] = ACTIONS(6203),
    [anon_sym_let] = ACTIONS(6203),
    [anon_sym_pulldown] = ACTIONS(6203),
    [anon_sym_pullup] = ACTIONS(6203),
    [anon_sym_cmos] = ACTIONS(6203),
    [anon_sym_rcmos] = ACTIONS(6203),
    [anon_sym_bufif0] = ACTIONS(6203),
    [anon_sym_bufif1] = ACTIONS(6203),
    [anon_sym_notif0] = ACTIONS(6203),
    [anon_sym_notif1] = ACTIONS(6203),
    [anon_sym_nmos] = ACTIONS(6203),
    [anon_sym_pmos] = ACTIONS(6203),
    [anon_sym_rnmos] = ACTIONS(6203),
    [anon_sym_rpmos] = ACTIONS(6203),
    [anon_sym_nand] = ACTIONS(6203),
    [anon_sym_nor] = ACTIONS(6203),
    [anon_sym_xor] = ACTIONS(6203),
    [anon_sym_xnor] = ACTIONS(6203),
    [anon_sym_buf] = ACTIONS(6203),
    [anon_sym_tranif0] = ACTIONS(6203),
    [anon_sym_tranif1] = ACTIONS(6203),
    [anon_sym_rtranif1] = ACTIONS(6203),
    [anon_sym_rtranif0] = ACTIONS(6203),
    [anon_sym_tran] = ACTIONS(6203),
    [anon_sym_rtran] = ACTIONS(6203),
    [anon_sym_generate] = ACTIONS(6203),
    [anon_sym_for] = ACTIONS(6203),
    [anon_sym_primitive] = ACTIONS(6203),
    [anon_sym_initial] = ACTIONS(6203),
    [anon_sym_assign] = ACTIONS(6203),
    [anon_sym_alias] = ACTIONS(6203),
    [anon_sym_always_comb] = ACTIONS(6203),
    [anon_sym_always_latch] = ACTIONS(6203),
    [anon_sym_always_ff] = ACTIONS(6203),
    [anon_sym_final] = ACTIONS(6203),
    [anon_sym_global] = ACTIONS(6203),
    [anon_sym_specify] = ACTIONS(6203),
    [anon_sym_LPAREN_STAR] = ACTIONS(6201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6201),
    [anon_sym_DOLLARunit] = ACTIONS(6201),
  },
  [1118] = {
    [ts_builtin_sym_end] = ACTIONS(6205),
    [sym_simple_identifier] = ACTIONS(6207),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6205),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6205),
    [anon_sym_BQUOTE] = ACTIONS(6207),
    [aux_sym_id_directive_token1] = ACTIONS(6205),
    [aux_sym_id_directive_token2] = ACTIONS(6205),
    [aux_sym_id_directive_token3] = ACTIONS(6205),
    [aux_sym_id_directive_token4] = ACTIONS(6207),
    [aux_sym_zero_directive_token1] = ACTIONS(6205),
    [aux_sym_zero_directive_token2] = ACTIONS(6205),
    [aux_sym_zero_directive_token3] = ACTIONS(6205),
    [aux_sym_zero_directive_token4] = ACTIONS(6205),
    [aux_sym_zero_directive_token5] = ACTIONS(6205),
    [aux_sym_zero_directive_token6] = ACTIONS(6205),
    [aux_sym_zero_directive_token7] = ACTIONS(6205),
    [aux_sym_zero_directive_token8] = ACTIONS(6205),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6205),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6205),
    [anon_sym_wire] = ACTIONS(6207),
    [anon_sym_tri] = ACTIONS(6207),
    [anon_sym_tri0] = ACTIONS(6207),
    [anon_sym_tri1] = ACTIONS(6207),
    [anon_sym_wand] = ACTIONS(6207),
    [anon_sym_triand] = ACTIONS(6207),
    [anon_sym_wor] = ACTIONS(6207),
    [anon_sym_trior] = ACTIONS(6207),
    [anon_sym_trireg] = ACTIONS(6207),
    [anon_sym_uwire] = ACTIONS(6207),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6205),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6205),
    [aux_sym_begin_keywords_token1] = ACTIONS(6205),
    [anon_sym_SEMI] = ACTIONS(6205),
    [anon_sym_endmodule] = ACTIONS(6207),
    [anon_sym_extern] = ACTIONS(6207),
    [anon_sym_module] = ACTIONS(6207),
    [anon_sym_macromodule] = ACTIONS(6207),
    [anon_sym_endinterface] = ACTIONS(6207),
    [anon_sym_interface] = ACTIONS(6207),
    [anon_sym_program] = ACTIONS(6207),
    [anon_sym_checker] = ACTIONS(6207),
    [anon_sym_virtual] = ACTIONS(6207),
    [anon_sym_class] = ACTIONS(6207),
    [anon_sym_package] = ACTIONS(6207),
    [anon_sym_timeunit] = ACTIONS(6207),
    [anon_sym_timeprecision] = ACTIONS(6207),
    [anon_sym_type] = ACTIONS(6207),
    [anon_sym_input] = ACTIONS(6207),
    [anon_sym_output] = ACTIONS(6207),
    [anon_sym_inout] = ACTIONS(6207),
    [anon_sym_ref] = ACTIONS(6207),
    [anon_sym_DOLLARfatal] = ACTIONS(6205),
    [anon_sym_DOLLARerror] = ACTIONS(6205),
    [anon_sym_DOLLARwarning] = ACTIONS(6205),
    [anon_sym_DOLLARinfo] = ACTIONS(6205),
    [anon_sym_default] = ACTIONS(6207),
    [anon_sym_clocking] = ACTIONS(6207),
    [anon_sym_defparam] = ACTIONS(6207),
    [anon_sym_bind] = ACTIONS(6207),
    [anon_sym_const] = ACTIONS(6207),
    [anon_sym_function] = ACTIONS(6207),
    [anon_sym_static] = ACTIONS(6207),
    [anon_sym_constraint] = ACTIONS(6207),
    [anon_sym_if] = ACTIONS(6207),
    [anon_sym_LBRACK] = ACTIONS(6205),
    [anon_sym_localparam] = ACTIONS(6207),
    [anon_sym_parameter] = ACTIONS(6207),
    [anon_sym_specparam] = ACTIONS(6207),
    [anon_sym_var] = ACTIONS(6207),
    [anon_sym_import] = ACTIONS(6207),
    [anon_sym_export] = ACTIONS(6207),
    [anon_sym_genvar] = ACTIONS(6207),
    [anon_sym_interconnect] = ACTIONS(6207),
    [anon_sym_typedef] = ACTIONS(6207),
    [anon_sym_enum] = ACTIONS(6207),
    [anon_sym_struct] = ACTIONS(6207),
    [anon_sym_union] = ACTIONS(6207),
    [anon_sym_nettype] = ACTIONS(6207),
    [anon_sym_automatic] = ACTIONS(6207),
    [anon_sym_string] = ACTIONS(6207),
    [anon_sym_chandle] = ACTIONS(6207),
    [anon_sym_event] = ACTIONS(6207),
    [anon_sym_byte] = ACTIONS(6207),
    [anon_sym_shortint] = ACTIONS(6207),
    [anon_sym_int] = ACTIONS(6207),
    [anon_sym_longint] = ACTIONS(6207),
    [anon_sym_integer] = ACTIONS(6207),
    [anon_sym_time] = ACTIONS(6207),
    [anon_sym_bit] = ACTIONS(6207),
    [anon_sym_logic] = ACTIONS(6207),
    [anon_sym_reg] = ACTIONS(6207),
    [anon_sym_shortreal] = ACTIONS(6207),
    [anon_sym_real] = ACTIONS(6207),
    [anon_sym_realtime] = ACTIONS(6207),
    [anon_sym_supply0] = ACTIONS(6207),
    [anon_sym_supply1] = ACTIONS(6207),
    [anon_sym_signed] = ACTIONS(6207),
    [anon_sym_unsigned] = ACTIONS(6207),
    [anon_sym_task] = ACTIONS(6207),
    [anon_sym_modport] = ACTIONS(6207),
    [anon_sym_assert] = ACTIONS(6207),
    [anon_sym_property] = ACTIONS(6207),
    [anon_sym_assume] = ACTIONS(6207),
    [anon_sym_cover] = ACTIONS(6207),
    [anon_sym_sequence] = ACTIONS(6207),
    [anon_sym_restrict] = ACTIONS(6207),
    [anon_sym_not] = ACTIONS(6207),
    [anon_sym_or] = ACTIONS(6207),
    [anon_sym_and] = ACTIONS(6207),
    [anon_sym_case] = ACTIONS(6207),
    [anon_sym_always] = ACTIONS(6207),
    [anon_sym_covergroup] = ACTIONS(6207),
    [anon_sym_let] = ACTIONS(6207),
    [anon_sym_pulldown] = ACTIONS(6207),
    [anon_sym_pullup] = ACTIONS(6207),
    [anon_sym_cmos] = ACTIONS(6207),
    [anon_sym_rcmos] = ACTIONS(6207),
    [anon_sym_bufif0] = ACTIONS(6207),
    [anon_sym_bufif1] = ACTIONS(6207),
    [anon_sym_notif0] = ACTIONS(6207),
    [anon_sym_notif1] = ACTIONS(6207),
    [anon_sym_nmos] = ACTIONS(6207),
    [anon_sym_pmos] = ACTIONS(6207),
    [anon_sym_rnmos] = ACTIONS(6207),
    [anon_sym_rpmos] = ACTIONS(6207),
    [anon_sym_nand] = ACTIONS(6207),
    [anon_sym_nor] = ACTIONS(6207),
    [anon_sym_xor] = ACTIONS(6207),
    [anon_sym_xnor] = ACTIONS(6207),
    [anon_sym_buf] = ACTIONS(6207),
    [anon_sym_tranif0] = ACTIONS(6207),
    [anon_sym_tranif1] = ACTIONS(6207),
    [anon_sym_rtranif1] = ACTIONS(6207),
    [anon_sym_rtranif0] = ACTIONS(6207),
    [anon_sym_tran] = ACTIONS(6207),
    [anon_sym_rtran] = ACTIONS(6207),
    [anon_sym_generate] = ACTIONS(6207),
    [anon_sym_for] = ACTIONS(6207),
    [anon_sym_primitive] = ACTIONS(6207),
    [anon_sym_initial] = ACTIONS(6207),
    [anon_sym_assign] = ACTIONS(6207),
    [anon_sym_alias] = ACTIONS(6207),
    [anon_sym_always_comb] = ACTIONS(6207),
    [anon_sym_always_latch] = ACTIONS(6207),
    [anon_sym_always_ff] = ACTIONS(6207),
    [anon_sym_final] = ACTIONS(6207),
    [anon_sym_global] = ACTIONS(6207),
    [anon_sym_specify] = ACTIONS(6207),
    [anon_sym_LPAREN_STAR] = ACTIONS(6205),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6205),
    [anon_sym_DOLLARunit] = ACTIONS(6205),
  },
  [1119] = {
    [ts_builtin_sym_end] = ACTIONS(6209),
    [sym_simple_identifier] = ACTIONS(6211),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6209),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6209),
    [anon_sym_BQUOTE] = ACTIONS(6211),
    [aux_sym_id_directive_token1] = ACTIONS(6209),
    [aux_sym_id_directive_token2] = ACTIONS(6209),
    [aux_sym_id_directive_token3] = ACTIONS(6209),
    [aux_sym_id_directive_token4] = ACTIONS(6211),
    [aux_sym_zero_directive_token1] = ACTIONS(6209),
    [aux_sym_zero_directive_token2] = ACTIONS(6209),
    [aux_sym_zero_directive_token3] = ACTIONS(6209),
    [aux_sym_zero_directive_token4] = ACTIONS(6209),
    [aux_sym_zero_directive_token5] = ACTIONS(6209),
    [aux_sym_zero_directive_token6] = ACTIONS(6209),
    [aux_sym_zero_directive_token7] = ACTIONS(6209),
    [aux_sym_zero_directive_token8] = ACTIONS(6209),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6209),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6209),
    [anon_sym_wire] = ACTIONS(6211),
    [anon_sym_tri] = ACTIONS(6211),
    [anon_sym_tri0] = ACTIONS(6211),
    [anon_sym_tri1] = ACTIONS(6211),
    [anon_sym_wand] = ACTIONS(6211),
    [anon_sym_triand] = ACTIONS(6211),
    [anon_sym_wor] = ACTIONS(6211),
    [anon_sym_trior] = ACTIONS(6211),
    [anon_sym_trireg] = ACTIONS(6211),
    [anon_sym_uwire] = ACTIONS(6211),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6209),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6209),
    [aux_sym_begin_keywords_token1] = ACTIONS(6209),
    [anon_sym_SEMI] = ACTIONS(6209),
    [anon_sym_endmodule] = ACTIONS(6211),
    [anon_sym_extern] = ACTIONS(6211),
    [anon_sym_module] = ACTIONS(6211),
    [anon_sym_macromodule] = ACTIONS(6211),
    [anon_sym_endinterface] = ACTIONS(6211),
    [anon_sym_interface] = ACTIONS(6211),
    [anon_sym_program] = ACTIONS(6211),
    [anon_sym_checker] = ACTIONS(6211),
    [anon_sym_virtual] = ACTIONS(6211),
    [anon_sym_class] = ACTIONS(6211),
    [anon_sym_package] = ACTIONS(6211),
    [anon_sym_timeunit] = ACTIONS(6211),
    [anon_sym_timeprecision] = ACTIONS(6211),
    [anon_sym_type] = ACTIONS(6211),
    [anon_sym_input] = ACTIONS(6211),
    [anon_sym_output] = ACTIONS(6211),
    [anon_sym_inout] = ACTIONS(6211),
    [anon_sym_ref] = ACTIONS(6211),
    [anon_sym_DOLLARfatal] = ACTIONS(6209),
    [anon_sym_DOLLARerror] = ACTIONS(6209),
    [anon_sym_DOLLARwarning] = ACTIONS(6209),
    [anon_sym_DOLLARinfo] = ACTIONS(6209),
    [anon_sym_default] = ACTIONS(6211),
    [anon_sym_clocking] = ACTIONS(6211),
    [anon_sym_defparam] = ACTIONS(6211),
    [anon_sym_bind] = ACTIONS(6211),
    [anon_sym_const] = ACTIONS(6211),
    [anon_sym_function] = ACTIONS(6211),
    [anon_sym_static] = ACTIONS(6211),
    [anon_sym_constraint] = ACTIONS(6211),
    [anon_sym_if] = ACTIONS(6211),
    [anon_sym_LBRACK] = ACTIONS(6209),
    [anon_sym_localparam] = ACTIONS(6211),
    [anon_sym_parameter] = ACTIONS(6211),
    [anon_sym_specparam] = ACTIONS(6211),
    [anon_sym_var] = ACTIONS(6211),
    [anon_sym_import] = ACTIONS(6211),
    [anon_sym_export] = ACTIONS(6211),
    [anon_sym_genvar] = ACTIONS(6211),
    [anon_sym_interconnect] = ACTIONS(6211),
    [anon_sym_typedef] = ACTIONS(6211),
    [anon_sym_enum] = ACTIONS(6211),
    [anon_sym_struct] = ACTIONS(6211),
    [anon_sym_union] = ACTIONS(6211),
    [anon_sym_nettype] = ACTIONS(6211),
    [anon_sym_automatic] = ACTIONS(6211),
    [anon_sym_string] = ACTIONS(6211),
    [anon_sym_chandle] = ACTIONS(6211),
    [anon_sym_event] = ACTIONS(6211),
    [anon_sym_byte] = ACTIONS(6211),
    [anon_sym_shortint] = ACTIONS(6211),
    [anon_sym_int] = ACTIONS(6211),
    [anon_sym_longint] = ACTIONS(6211),
    [anon_sym_integer] = ACTIONS(6211),
    [anon_sym_time] = ACTIONS(6211),
    [anon_sym_bit] = ACTIONS(6211),
    [anon_sym_logic] = ACTIONS(6211),
    [anon_sym_reg] = ACTIONS(6211),
    [anon_sym_shortreal] = ACTIONS(6211),
    [anon_sym_real] = ACTIONS(6211),
    [anon_sym_realtime] = ACTIONS(6211),
    [anon_sym_supply0] = ACTIONS(6211),
    [anon_sym_supply1] = ACTIONS(6211),
    [anon_sym_signed] = ACTIONS(6211),
    [anon_sym_unsigned] = ACTIONS(6211),
    [anon_sym_task] = ACTIONS(6211),
    [anon_sym_modport] = ACTIONS(6211),
    [anon_sym_assert] = ACTIONS(6211),
    [anon_sym_property] = ACTIONS(6211),
    [anon_sym_assume] = ACTIONS(6211),
    [anon_sym_cover] = ACTIONS(6211),
    [anon_sym_sequence] = ACTIONS(6211),
    [anon_sym_restrict] = ACTIONS(6211),
    [anon_sym_not] = ACTIONS(6211),
    [anon_sym_or] = ACTIONS(6211),
    [anon_sym_and] = ACTIONS(6211),
    [anon_sym_case] = ACTIONS(6211),
    [anon_sym_always] = ACTIONS(6211),
    [anon_sym_covergroup] = ACTIONS(6211),
    [anon_sym_let] = ACTIONS(6211),
    [anon_sym_pulldown] = ACTIONS(6211),
    [anon_sym_pullup] = ACTIONS(6211),
    [anon_sym_cmos] = ACTIONS(6211),
    [anon_sym_rcmos] = ACTIONS(6211),
    [anon_sym_bufif0] = ACTIONS(6211),
    [anon_sym_bufif1] = ACTIONS(6211),
    [anon_sym_notif0] = ACTIONS(6211),
    [anon_sym_notif1] = ACTIONS(6211),
    [anon_sym_nmos] = ACTIONS(6211),
    [anon_sym_pmos] = ACTIONS(6211),
    [anon_sym_rnmos] = ACTIONS(6211),
    [anon_sym_rpmos] = ACTIONS(6211),
    [anon_sym_nand] = ACTIONS(6211),
    [anon_sym_nor] = ACTIONS(6211),
    [anon_sym_xor] = ACTIONS(6211),
    [anon_sym_xnor] = ACTIONS(6211),
    [anon_sym_buf] = ACTIONS(6211),
    [anon_sym_tranif0] = ACTIONS(6211),
    [anon_sym_tranif1] = ACTIONS(6211),
    [anon_sym_rtranif1] = ACTIONS(6211),
    [anon_sym_rtranif0] = ACTIONS(6211),
    [anon_sym_tran] = ACTIONS(6211),
    [anon_sym_rtran] = ACTIONS(6211),
    [anon_sym_generate] = ACTIONS(6211),
    [anon_sym_for] = ACTIONS(6211),
    [anon_sym_primitive] = ACTIONS(6211),
    [anon_sym_initial] = ACTIONS(6211),
    [anon_sym_assign] = ACTIONS(6211),
    [anon_sym_alias] = ACTIONS(6211),
    [anon_sym_always_comb] = ACTIONS(6211),
    [anon_sym_always_latch] = ACTIONS(6211),
    [anon_sym_always_ff] = ACTIONS(6211),
    [anon_sym_final] = ACTIONS(6211),
    [anon_sym_global] = ACTIONS(6211),
    [anon_sym_specify] = ACTIONS(6211),
    [anon_sym_LPAREN_STAR] = ACTIONS(6209),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6209),
    [anon_sym_DOLLARunit] = ACTIONS(6209),
  },
  [1120] = {
    [ts_builtin_sym_end] = ACTIONS(5676),
    [sym_simple_identifier] = ACTIONS(5678),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5676),
    [anon_sym_BQUOTE] = ACTIONS(5678),
    [aux_sym_id_directive_token1] = ACTIONS(5676),
    [aux_sym_id_directive_token2] = ACTIONS(5676),
    [aux_sym_id_directive_token3] = ACTIONS(5676),
    [aux_sym_id_directive_token4] = ACTIONS(5678),
    [aux_sym_zero_directive_token1] = ACTIONS(5676),
    [aux_sym_zero_directive_token2] = ACTIONS(5676),
    [aux_sym_zero_directive_token3] = ACTIONS(5676),
    [aux_sym_zero_directive_token4] = ACTIONS(5676),
    [aux_sym_zero_directive_token5] = ACTIONS(5676),
    [aux_sym_zero_directive_token6] = ACTIONS(5676),
    [aux_sym_zero_directive_token7] = ACTIONS(5676),
    [aux_sym_zero_directive_token8] = ACTIONS(5676),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5676),
    [anon_sym_wire] = ACTIONS(5678),
    [anon_sym_tri] = ACTIONS(5678),
    [anon_sym_tri0] = ACTIONS(5678),
    [anon_sym_tri1] = ACTIONS(5678),
    [anon_sym_wand] = ACTIONS(5678),
    [anon_sym_triand] = ACTIONS(5678),
    [anon_sym_wor] = ACTIONS(5678),
    [anon_sym_trior] = ACTIONS(5678),
    [anon_sym_trireg] = ACTIONS(5678),
    [anon_sym_uwire] = ACTIONS(5678),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5676),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5676),
    [aux_sym_begin_keywords_token1] = ACTIONS(5676),
    [anon_sym_SEMI] = ACTIONS(5676),
    [anon_sym_endmodule] = ACTIONS(5678),
    [anon_sym_extern] = ACTIONS(5678),
    [anon_sym_module] = ACTIONS(5678),
    [anon_sym_macromodule] = ACTIONS(5678),
    [anon_sym_endinterface] = ACTIONS(5678),
    [anon_sym_interface] = ACTIONS(5678),
    [anon_sym_program] = ACTIONS(5678),
    [anon_sym_checker] = ACTIONS(5678),
    [anon_sym_virtual] = ACTIONS(5678),
    [anon_sym_class] = ACTIONS(5678),
    [anon_sym_package] = ACTIONS(5678),
    [anon_sym_timeunit] = ACTIONS(5678),
    [anon_sym_timeprecision] = ACTIONS(5678),
    [anon_sym_type] = ACTIONS(5678),
    [anon_sym_input] = ACTIONS(5678),
    [anon_sym_output] = ACTIONS(5678),
    [anon_sym_inout] = ACTIONS(5678),
    [anon_sym_ref] = ACTIONS(5678),
    [anon_sym_DOLLARfatal] = ACTIONS(5676),
    [anon_sym_DOLLARerror] = ACTIONS(5676),
    [anon_sym_DOLLARwarning] = ACTIONS(5676),
    [anon_sym_DOLLARinfo] = ACTIONS(5676),
    [anon_sym_default] = ACTIONS(5678),
    [anon_sym_clocking] = ACTIONS(5678),
    [anon_sym_defparam] = ACTIONS(5678),
    [anon_sym_bind] = ACTIONS(5678),
    [anon_sym_const] = ACTIONS(5678),
    [anon_sym_function] = ACTIONS(5678),
    [anon_sym_static] = ACTIONS(5678),
    [anon_sym_constraint] = ACTIONS(5678),
    [anon_sym_if] = ACTIONS(5678),
    [anon_sym_LBRACK] = ACTIONS(5676),
    [anon_sym_localparam] = ACTIONS(5678),
    [anon_sym_parameter] = ACTIONS(5678),
    [anon_sym_specparam] = ACTIONS(5678),
    [anon_sym_var] = ACTIONS(5678),
    [anon_sym_import] = ACTIONS(5678),
    [anon_sym_export] = ACTIONS(5678),
    [anon_sym_genvar] = ACTIONS(5678),
    [anon_sym_interconnect] = ACTIONS(5678),
    [anon_sym_typedef] = ACTIONS(5678),
    [anon_sym_enum] = ACTIONS(5678),
    [anon_sym_struct] = ACTIONS(5678),
    [anon_sym_union] = ACTIONS(5678),
    [anon_sym_nettype] = ACTIONS(5678),
    [anon_sym_automatic] = ACTIONS(5678),
    [anon_sym_string] = ACTIONS(5678),
    [anon_sym_chandle] = ACTIONS(5678),
    [anon_sym_event] = ACTIONS(5678),
    [anon_sym_byte] = ACTIONS(5678),
    [anon_sym_shortint] = ACTIONS(5678),
    [anon_sym_int] = ACTIONS(5678),
    [anon_sym_longint] = ACTIONS(5678),
    [anon_sym_integer] = ACTIONS(5678),
    [anon_sym_time] = ACTIONS(5678),
    [anon_sym_bit] = ACTIONS(5678),
    [anon_sym_logic] = ACTIONS(5678),
    [anon_sym_reg] = ACTIONS(5678),
    [anon_sym_shortreal] = ACTIONS(5678),
    [anon_sym_real] = ACTIONS(5678),
    [anon_sym_realtime] = ACTIONS(5678),
    [anon_sym_supply0] = ACTIONS(5678),
    [anon_sym_supply1] = ACTIONS(5678),
    [anon_sym_signed] = ACTIONS(5678),
    [anon_sym_unsigned] = ACTIONS(5678),
    [anon_sym_task] = ACTIONS(5678),
    [anon_sym_modport] = ACTIONS(5678),
    [anon_sym_assert] = ACTIONS(5678),
    [anon_sym_property] = ACTIONS(5678),
    [anon_sym_assume] = ACTIONS(5678),
    [anon_sym_cover] = ACTIONS(5678),
    [anon_sym_sequence] = ACTIONS(5678),
    [anon_sym_restrict] = ACTIONS(5678),
    [anon_sym_not] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_case] = ACTIONS(5678),
    [anon_sym_always] = ACTIONS(5678),
    [anon_sym_covergroup] = ACTIONS(5678),
    [anon_sym_let] = ACTIONS(5678),
    [anon_sym_pulldown] = ACTIONS(5678),
    [anon_sym_pullup] = ACTIONS(5678),
    [anon_sym_cmos] = ACTIONS(5678),
    [anon_sym_rcmos] = ACTIONS(5678),
    [anon_sym_bufif0] = ACTIONS(5678),
    [anon_sym_bufif1] = ACTIONS(5678),
    [anon_sym_notif0] = ACTIONS(5678),
    [anon_sym_notif1] = ACTIONS(5678),
    [anon_sym_nmos] = ACTIONS(5678),
    [anon_sym_pmos] = ACTIONS(5678),
    [anon_sym_rnmos] = ACTIONS(5678),
    [anon_sym_rpmos] = ACTIONS(5678),
    [anon_sym_nand] = ACTIONS(5678),
    [anon_sym_nor] = ACTIONS(5678),
    [anon_sym_xor] = ACTIONS(5678),
    [anon_sym_xnor] = ACTIONS(5678),
    [anon_sym_buf] = ACTIONS(5678),
    [anon_sym_tranif0] = ACTIONS(5678),
    [anon_sym_tranif1] = ACTIONS(5678),
    [anon_sym_rtranif1] = ACTIONS(5678),
    [anon_sym_rtranif0] = ACTIONS(5678),
    [anon_sym_tran] = ACTIONS(5678),
    [anon_sym_rtran] = ACTIONS(5678),
    [anon_sym_generate] = ACTIONS(5678),
    [anon_sym_for] = ACTIONS(5678),
    [anon_sym_primitive] = ACTIONS(5678),
    [anon_sym_initial] = ACTIONS(5678),
    [anon_sym_assign] = ACTIONS(5678),
    [anon_sym_alias] = ACTIONS(5678),
    [anon_sym_always_comb] = ACTIONS(5678),
    [anon_sym_always_latch] = ACTIONS(5678),
    [anon_sym_always_ff] = ACTIONS(5678),
    [anon_sym_final] = ACTIONS(5678),
    [anon_sym_global] = ACTIONS(5678),
    [anon_sym_specify] = ACTIONS(5678),
    [anon_sym_LPAREN_STAR] = ACTIONS(5676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5676),
    [anon_sym_DOLLARunit] = ACTIONS(5676),
  },
  [1121] = {
    [ts_builtin_sym_end] = ACTIONS(6213),
    [sym_simple_identifier] = ACTIONS(6215),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6213),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6213),
    [anon_sym_BQUOTE] = ACTIONS(6215),
    [aux_sym_id_directive_token1] = ACTIONS(6213),
    [aux_sym_id_directive_token2] = ACTIONS(6213),
    [aux_sym_id_directive_token3] = ACTIONS(6213),
    [aux_sym_id_directive_token4] = ACTIONS(6215),
    [aux_sym_zero_directive_token1] = ACTIONS(6213),
    [aux_sym_zero_directive_token2] = ACTIONS(6213),
    [aux_sym_zero_directive_token3] = ACTIONS(6213),
    [aux_sym_zero_directive_token4] = ACTIONS(6213),
    [aux_sym_zero_directive_token5] = ACTIONS(6213),
    [aux_sym_zero_directive_token6] = ACTIONS(6213),
    [aux_sym_zero_directive_token7] = ACTIONS(6213),
    [aux_sym_zero_directive_token8] = ACTIONS(6213),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6213),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6213),
    [anon_sym_wire] = ACTIONS(6215),
    [anon_sym_tri] = ACTIONS(6215),
    [anon_sym_tri0] = ACTIONS(6215),
    [anon_sym_tri1] = ACTIONS(6215),
    [anon_sym_wand] = ACTIONS(6215),
    [anon_sym_triand] = ACTIONS(6215),
    [anon_sym_wor] = ACTIONS(6215),
    [anon_sym_trior] = ACTIONS(6215),
    [anon_sym_trireg] = ACTIONS(6215),
    [anon_sym_uwire] = ACTIONS(6215),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6213),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6213),
    [aux_sym_begin_keywords_token1] = ACTIONS(6213),
    [anon_sym_SEMI] = ACTIONS(6213),
    [anon_sym_endmodule] = ACTIONS(6215),
    [anon_sym_extern] = ACTIONS(6215),
    [anon_sym_module] = ACTIONS(6215),
    [anon_sym_macromodule] = ACTIONS(6215),
    [anon_sym_endinterface] = ACTIONS(6215),
    [anon_sym_interface] = ACTIONS(6215),
    [anon_sym_program] = ACTIONS(6215),
    [anon_sym_checker] = ACTIONS(6215),
    [anon_sym_virtual] = ACTIONS(6215),
    [anon_sym_class] = ACTIONS(6215),
    [anon_sym_package] = ACTIONS(6215),
    [anon_sym_timeunit] = ACTIONS(6215),
    [anon_sym_timeprecision] = ACTIONS(6215),
    [anon_sym_type] = ACTIONS(6215),
    [anon_sym_input] = ACTIONS(6215),
    [anon_sym_output] = ACTIONS(6215),
    [anon_sym_inout] = ACTIONS(6215),
    [anon_sym_ref] = ACTIONS(6215),
    [anon_sym_DOLLARfatal] = ACTIONS(6213),
    [anon_sym_DOLLARerror] = ACTIONS(6213),
    [anon_sym_DOLLARwarning] = ACTIONS(6213),
    [anon_sym_DOLLARinfo] = ACTIONS(6213),
    [anon_sym_default] = ACTIONS(6215),
    [anon_sym_clocking] = ACTIONS(6215),
    [anon_sym_defparam] = ACTIONS(6215),
    [anon_sym_bind] = ACTIONS(6215),
    [anon_sym_const] = ACTIONS(6215),
    [anon_sym_function] = ACTIONS(6215),
    [anon_sym_static] = ACTIONS(6215),
    [anon_sym_constraint] = ACTIONS(6215),
    [anon_sym_if] = ACTIONS(6215),
    [anon_sym_LBRACK] = ACTIONS(6213),
    [anon_sym_localparam] = ACTIONS(6215),
    [anon_sym_parameter] = ACTIONS(6215),
    [anon_sym_specparam] = ACTIONS(6215),
    [anon_sym_var] = ACTIONS(6215),
    [anon_sym_import] = ACTIONS(6215),
    [anon_sym_export] = ACTIONS(6215),
    [anon_sym_genvar] = ACTIONS(6215),
    [anon_sym_interconnect] = ACTIONS(6215),
    [anon_sym_typedef] = ACTIONS(6215),
    [anon_sym_enum] = ACTIONS(6215),
    [anon_sym_struct] = ACTIONS(6215),
    [anon_sym_union] = ACTIONS(6215),
    [anon_sym_nettype] = ACTIONS(6215),
    [anon_sym_automatic] = ACTIONS(6215),
    [anon_sym_string] = ACTIONS(6215),
    [anon_sym_chandle] = ACTIONS(6215),
    [anon_sym_event] = ACTIONS(6215),
    [anon_sym_byte] = ACTIONS(6215),
    [anon_sym_shortint] = ACTIONS(6215),
    [anon_sym_int] = ACTIONS(6215),
    [anon_sym_longint] = ACTIONS(6215),
    [anon_sym_integer] = ACTIONS(6215),
    [anon_sym_time] = ACTIONS(6215),
    [anon_sym_bit] = ACTIONS(6215),
    [anon_sym_logic] = ACTIONS(6215),
    [anon_sym_reg] = ACTIONS(6215),
    [anon_sym_shortreal] = ACTIONS(6215),
    [anon_sym_real] = ACTIONS(6215),
    [anon_sym_realtime] = ACTIONS(6215),
    [anon_sym_supply0] = ACTIONS(6215),
    [anon_sym_supply1] = ACTIONS(6215),
    [anon_sym_signed] = ACTIONS(6215),
    [anon_sym_unsigned] = ACTIONS(6215),
    [anon_sym_task] = ACTIONS(6215),
    [anon_sym_modport] = ACTIONS(6215),
    [anon_sym_assert] = ACTIONS(6215),
    [anon_sym_property] = ACTIONS(6215),
    [anon_sym_assume] = ACTIONS(6215),
    [anon_sym_cover] = ACTIONS(6215),
    [anon_sym_sequence] = ACTIONS(6215),
    [anon_sym_restrict] = ACTIONS(6215),
    [anon_sym_not] = ACTIONS(6215),
    [anon_sym_or] = ACTIONS(6215),
    [anon_sym_and] = ACTIONS(6215),
    [anon_sym_case] = ACTIONS(6215),
    [anon_sym_always] = ACTIONS(6215),
    [anon_sym_covergroup] = ACTIONS(6215),
    [anon_sym_let] = ACTIONS(6215),
    [anon_sym_pulldown] = ACTIONS(6215),
    [anon_sym_pullup] = ACTIONS(6215),
    [anon_sym_cmos] = ACTIONS(6215),
    [anon_sym_rcmos] = ACTIONS(6215),
    [anon_sym_bufif0] = ACTIONS(6215),
    [anon_sym_bufif1] = ACTIONS(6215),
    [anon_sym_notif0] = ACTIONS(6215),
    [anon_sym_notif1] = ACTIONS(6215),
    [anon_sym_nmos] = ACTIONS(6215),
    [anon_sym_pmos] = ACTIONS(6215),
    [anon_sym_rnmos] = ACTIONS(6215),
    [anon_sym_rpmos] = ACTIONS(6215),
    [anon_sym_nand] = ACTIONS(6215),
    [anon_sym_nor] = ACTIONS(6215),
    [anon_sym_xor] = ACTIONS(6215),
    [anon_sym_xnor] = ACTIONS(6215),
    [anon_sym_buf] = ACTIONS(6215),
    [anon_sym_tranif0] = ACTIONS(6215),
    [anon_sym_tranif1] = ACTIONS(6215),
    [anon_sym_rtranif1] = ACTIONS(6215),
    [anon_sym_rtranif0] = ACTIONS(6215),
    [anon_sym_tran] = ACTIONS(6215),
    [anon_sym_rtran] = ACTIONS(6215),
    [anon_sym_generate] = ACTIONS(6215),
    [anon_sym_for] = ACTIONS(6215),
    [anon_sym_primitive] = ACTIONS(6215),
    [anon_sym_initial] = ACTIONS(6215),
    [anon_sym_assign] = ACTIONS(6215),
    [anon_sym_alias] = ACTIONS(6215),
    [anon_sym_always_comb] = ACTIONS(6215),
    [anon_sym_always_latch] = ACTIONS(6215),
    [anon_sym_always_ff] = ACTIONS(6215),
    [anon_sym_final] = ACTIONS(6215),
    [anon_sym_global] = ACTIONS(6215),
    [anon_sym_specify] = ACTIONS(6215),
    [anon_sym_LPAREN_STAR] = ACTIONS(6213),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6213),
    [anon_sym_DOLLARunit] = ACTIONS(6213),
  },
  [1122] = {
    [ts_builtin_sym_end] = ACTIONS(6217),
    [sym_simple_identifier] = ACTIONS(6219),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6217),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6217),
    [anon_sym_BQUOTE] = ACTIONS(6219),
    [aux_sym_id_directive_token1] = ACTIONS(6217),
    [aux_sym_id_directive_token2] = ACTIONS(6217),
    [aux_sym_id_directive_token3] = ACTIONS(6217),
    [aux_sym_id_directive_token4] = ACTIONS(6219),
    [aux_sym_zero_directive_token1] = ACTIONS(6217),
    [aux_sym_zero_directive_token2] = ACTIONS(6217),
    [aux_sym_zero_directive_token3] = ACTIONS(6217),
    [aux_sym_zero_directive_token4] = ACTIONS(6217),
    [aux_sym_zero_directive_token5] = ACTIONS(6217),
    [aux_sym_zero_directive_token6] = ACTIONS(6217),
    [aux_sym_zero_directive_token7] = ACTIONS(6217),
    [aux_sym_zero_directive_token8] = ACTIONS(6217),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6217),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6217),
    [anon_sym_wire] = ACTIONS(6219),
    [anon_sym_tri] = ACTIONS(6219),
    [anon_sym_tri0] = ACTIONS(6219),
    [anon_sym_tri1] = ACTIONS(6219),
    [anon_sym_wand] = ACTIONS(6219),
    [anon_sym_triand] = ACTIONS(6219),
    [anon_sym_wor] = ACTIONS(6219),
    [anon_sym_trior] = ACTIONS(6219),
    [anon_sym_trireg] = ACTIONS(6219),
    [anon_sym_uwire] = ACTIONS(6219),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6217),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6217),
    [aux_sym_begin_keywords_token1] = ACTIONS(6217),
    [anon_sym_SEMI] = ACTIONS(6217),
    [anon_sym_endmodule] = ACTIONS(6219),
    [anon_sym_extern] = ACTIONS(6219),
    [anon_sym_module] = ACTIONS(6219),
    [anon_sym_macromodule] = ACTIONS(6219),
    [anon_sym_endinterface] = ACTIONS(6219),
    [anon_sym_interface] = ACTIONS(6219),
    [anon_sym_program] = ACTIONS(6219),
    [anon_sym_checker] = ACTIONS(6219),
    [anon_sym_virtual] = ACTIONS(6219),
    [anon_sym_class] = ACTIONS(6219),
    [anon_sym_package] = ACTIONS(6219),
    [anon_sym_timeunit] = ACTIONS(6219),
    [anon_sym_timeprecision] = ACTIONS(6219),
    [anon_sym_type] = ACTIONS(6219),
    [anon_sym_input] = ACTIONS(6219),
    [anon_sym_output] = ACTIONS(6219),
    [anon_sym_inout] = ACTIONS(6219),
    [anon_sym_ref] = ACTIONS(6219),
    [anon_sym_DOLLARfatal] = ACTIONS(6217),
    [anon_sym_DOLLARerror] = ACTIONS(6217),
    [anon_sym_DOLLARwarning] = ACTIONS(6217),
    [anon_sym_DOLLARinfo] = ACTIONS(6217),
    [anon_sym_default] = ACTIONS(6219),
    [anon_sym_clocking] = ACTIONS(6219),
    [anon_sym_defparam] = ACTIONS(6219),
    [anon_sym_bind] = ACTIONS(6219),
    [anon_sym_const] = ACTIONS(6219),
    [anon_sym_function] = ACTIONS(6219),
    [anon_sym_static] = ACTIONS(6219),
    [anon_sym_constraint] = ACTIONS(6219),
    [anon_sym_if] = ACTIONS(6219),
    [anon_sym_LBRACK] = ACTIONS(6217),
    [anon_sym_localparam] = ACTIONS(6219),
    [anon_sym_parameter] = ACTIONS(6219),
    [anon_sym_specparam] = ACTIONS(6219),
    [anon_sym_var] = ACTIONS(6219),
    [anon_sym_import] = ACTIONS(6219),
    [anon_sym_export] = ACTIONS(6219),
    [anon_sym_genvar] = ACTIONS(6219),
    [anon_sym_interconnect] = ACTIONS(6219),
    [anon_sym_typedef] = ACTIONS(6219),
    [anon_sym_enum] = ACTIONS(6219),
    [anon_sym_struct] = ACTIONS(6219),
    [anon_sym_union] = ACTIONS(6219),
    [anon_sym_nettype] = ACTIONS(6219),
    [anon_sym_automatic] = ACTIONS(6219),
    [anon_sym_string] = ACTIONS(6219),
    [anon_sym_chandle] = ACTIONS(6219),
    [anon_sym_event] = ACTIONS(6219),
    [anon_sym_byte] = ACTIONS(6219),
    [anon_sym_shortint] = ACTIONS(6219),
    [anon_sym_int] = ACTIONS(6219),
    [anon_sym_longint] = ACTIONS(6219),
    [anon_sym_integer] = ACTIONS(6219),
    [anon_sym_time] = ACTIONS(6219),
    [anon_sym_bit] = ACTIONS(6219),
    [anon_sym_logic] = ACTIONS(6219),
    [anon_sym_reg] = ACTIONS(6219),
    [anon_sym_shortreal] = ACTIONS(6219),
    [anon_sym_real] = ACTIONS(6219),
    [anon_sym_realtime] = ACTIONS(6219),
    [anon_sym_supply0] = ACTIONS(6219),
    [anon_sym_supply1] = ACTIONS(6219),
    [anon_sym_signed] = ACTIONS(6219),
    [anon_sym_unsigned] = ACTIONS(6219),
    [anon_sym_task] = ACTIONS(6219),
    [anon_sym_modport] = ACTIONS(6219),
    [anon_sym_assert] = ACTIONS(6219),
    [anon_sym_property] = ACTIONS(6219),
    [anon_sym_assume] = ACTIONS(6219),
    [anon_sym_cover] = ACTIONS(6219),
    [anon_sym_sequence] = ACTIONS(6219),
    [anon_sym_restrict] = ACTIONS(6219),
    [anon_sym_not] = ACTIONS(6219),
    [anon_sym_or] = ACTIONS(6219),
    [anon_sym_and] = ACTIONS(6219),
    [anon_sym_case] = ACTIONS(6219),
    [anon_sym_always] = ACTIONS(6219),
    [anon_sym_covergroup] = ACTIONS(6219),
    [anon_sym_let] = ACTIONS(6219),
    [anon_sym_pulldown] = ACTIONS(6219),
    [anon_sym_pullup] = ACTIONS(6219),
    [anon_sym_cmos] = ACTIONS(6219),
    [anon_sym_rcmos] = ACTIONS(6219),
    [anon_sym_bufif0] = ACTIONS(6219),
    [anon_sym_bufif1] = ACTIONS(6219),
    [anon_sym_notif0] = ACTIONS(6219),
    [anon_sym_notif1] = ACTIONS(6219),
    [anon_sym_nmos] = ACTIONS(6219),
    [anon_sym_pmos] = ACTIONS(6219),
    [anon_sym_rnmos] = ACTIONS(6219),
    [anon_sym_rpmos] = ACTIONS(6219),
    [anon_sym_nand] = ACTIONS(6219),
    [anon_sym_nor] = ACTIONS(6219),
    [anon_sym_xor] = ACTIONS(6219),
    [anon_sym_xnor] = ACTIONS(6219),
    [anon_sym_buf] = ACTIONS(6219),
    [anon_sym_tranif0] = ACTIONS(6219),
    [anon_sym_tranif1] = ACTIONS(6219),
    [anon_sym_rtranif1] = ACTIONS(6219),
    [anon_sym_rtranif0] = ACTIONS(6219),
    [anon_sym_tran] = ACTIONS(6219),
    [anon_sym_rtran] = ACTIONS(6219),
    [anon_sym_generate] = ACTIONS(6219),
    [anon_sym_for] = ACTIONS(6219),
    [anon_sym_primitive] = ACTIONS(6219),
    [anon_sym_initial] = ACTIONS(6219),
    [anon_sym_assign] = ACTIONS(6219),
    [anon_sym_alias] = ACTIONS(6219),
    [anon_sym_always_comb] = ACTIONS(6219),
    [anon_sym_always_latch] = ACTIONS(6219),
    [anon_sym_always_ff] = ACTIONS(6219),
    [anon_sym_final] = ACTIONS(6219),
    [anon_sym_global] = ACTIONS(6219),
    [anon_sym_specify] = ACTIONS(6219),
    [anon_sym_LPAREN_STAR] = ACTIONS(6217),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6217),
    [anon_sym_DOLLARunit] = ACTIONS(6217),
  },
  [1123] = {
    [ts_builtin_sym_end] = ACTIONS(6221),
    [sym_simple_identifier] = ACTIONS(6223),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6221),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6221),
    [anon_sym_BQUOTE] = ACTIONS(6223),
    [aux_sym_id_directive_token1] = ACTIONS(6221),
    [aux_sym_id_directive_token2] = ACTIONS(6221),
    [aux_sym_id_directive_token3] = ACTIONS(6221),
    [aux_sym_id_directive_token4] = ACTIONS(6223),
    [aux_sym_zero_directive_token1] = ACTIONS(6221),
    [aux_sym_zero_directive_token2] = ACTIONS(6221),
    [aux_sym_zero_directive_token3] = ACTIONS(6221),
    [aux_sym_zero_directive_token4] = ACTIONS(6221),
    [aux_sym_zero_directive_token5] = ACTIONS(6221),
    [aux_sym_zero_directive_token6] = ACTIONS(6221),
    [aux_sym_zero_directive_token7] = ACTIONS(6221),
    [aux_sym_zero_directive_token8] = ACTIONS(6221),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6221),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6221),
    [anon_sym_wire] = ACTIONS(6223),
    [anon_sym_tri] = ACTIONS(6223),
    [anon_sym_tri0] = ACTIONS(6223),
    [anon_sym_tri1] = ACTIONS(6223),
    [anon_sym_wand] = ACTIONS(6223),
    [anon_sym_triand] = ACTIONS(6223),
    [anon_sym_wor] = ACTIONS(6223),
    [anon_sym_trior] = ACTIONS(6223),
    [anon_sym_trireg] = ACTIONS(6223),
    [anon_sym_uwire] = ACTIONS(6223),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6221),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6221),
    [aux_sym_begin_keywords_token1] = ACTIONS(6221),
    [anon_sym_SEMI] = ACTIONS(6221),
    [anon_sym_endmodule] = ACTIONS(6223),
    [anon_sym_extern] = ACTIONS(6223),
    [anon_sym_module] = ACTIONS(6223),
    [anon_sym_macromodule] = ACTIONS(6223),
    [anon_sym_endinterface] = ACTIONS(6223),
    [anon_sym_interface] = ACTIONS(6223),
    [anon_sym_program] = ACTIONS(6223),
    [anon_sym_checker] = ACTIONS(6223),
    [anon_sym_virtual] = ACTIONS(6223),
    [anon_sym_class] = ACTIONS(6223),
    [anon_sym_package] = ACTIONS(6223),
    [anon_sym_timeunit] = ACTIONS(6223),
    [anon_sym_timeprecision] = ACTIONS(6223),
    [anon_sym_type] = ACTIONS(6223),
    [anon_sym_input] = ACTIONS(6223),
    [anon_sym_output] = ACTIONS(6223),
    [anon_sym_inout] = ACTIONS(6223),
    [anon_sym_ref] = ACTIONS(6223),
    [anon_sym_DOLLARfatal] = ACTIONS(6221),
    [anon_sym_DOLLARerror] = ACTIONS(6221),
    [anon_sym_DOLLARwarning] = ACTIONS(6221),
    [anon_sym_DOLLARinfo] = ACTIONS(6221),
    [anon_sym_default] = ACTIONS(6223),
    [anon_sym_clocking] = ACTIONS(6223),
    [anon_sym_defparam] = ACTIONS(6223),
    [anon_sym_bind] = ACTIONS(6223),
    [anon_sym_const] = ACTIONS(6223),
    [anon_sym_function] = ACTIONS(6223),
    [anon_sym_static] = ACTIONS(6223),
    [anon_sym_constraint] = ACTIONS(6223),
    [anon_sym_if] = ACTIONS(6223),
    [anon_sym_LBRACK] = ACTIONS(6221),
    [anon_sym_localparam] = ACTIONS(6223),
    [anon_sym_parameter] = ACTIONS(6223),
    [anon_sym_specparam] = ACTIONS(6223),
    [anon_sym_var] = ACTIONS(6223),
    [anon_sym_import] = ACTIONS(6223),
    [anon_sym_export] = ACTIONS(6223),
    [anon_sym_genvar] = ACTIONS(6223),
    [anon_sym_interconnect] = ACTIONS(6223),
    [anon_sym_typedef] = ACTIONS(6223),
    [anon_sym_enum] = ACTIONS(6223),
    [anon_sym_struct] = ACTIONS(6223),
    [anon_sym_union] = ACTIONS(6223),
    [anon_sym_nettype] = ACTIONS(6223),
    [anon_sym_automatic] = ACTIONS(6223),
    [anon_sym_string] = ACTIONS(6223),
    [anon_sym_chandle] = ACTIONS(6223),
    [anon_sym_event] = ACTIONS(6223),
    [anon_sym_byte] = ACTIONS(6223),
    [anon_sym_shortint] = ACTIONS(6223),
    [anon_sym_int] = ACTIONS(6223),
    [anon_sym_longint] = ACTIONS(6223),
    [anon_sym_integer] = ACTIONS(6223),
    [anon_sym_time] = ACTIONS(6223),
    [anon_sym_bit] = ACTIONS(6223),
    [anon_sym_logic] = ACTIONS(6223),
    [anon_sym_reg] = ACTIONS(6223),
    [anon_sym_shortreal] = ACTIONS(6223),
    [anon_sym_real] = ACTIONS(6223),
    [anon_sym_realtime] = ACTIONS(6223),
    [anon_sym_supply0] = ACTIONS(6223),
    [anon_sym_supply1] = ACTIONS(6223),
    [anon_sym_signed] = ACTIONS(6223),
    [anon_sym_unsigned] = ACTIONS(6223),
    [anon_sym_task] = ACTIONS(6223),
    [anon_sym_modport] = ACTIONS(6223),
    [anon_sym_assert] = ACTIONS(6223),
    [anon_sym_property] = ACTIONS(6223),
    [anon_sym_assume] = ACTIONS(6223),
    [anon_sym_cover] = ACTIONS(6223),
    [anon_sym_sequence] = ACTIONS(6223),
    [anon_sym_restrict] = ACTIONS(6223),
    [anon_sym_not] = ACTIONS(6223),
    [anon_sym_or] = ACTIONS(6223),
    [anon_sym_and] = ACTIONS(6223),
    [anon_sym_case] = ACTIONS(6223),
    [anon_sym_always] = ACTIONS(6223),
    [anon_sym_covergroup] = ACTIONS(6223),
    [anon_sym_let] = ACTIONS(6223),
    [anon_sym_pulldown] = ACTIONS(6223),
    [anon_sym_pullup] = ACTIONS(6223),
    [anon_sym_cmos] = ACTIONS(6223),
    [anon_sym_rcmos] = ACTIONS(6223),
    [anon_sym_bufif0] = ACTIONS(6223),
    [anon_sym_bufif1] = ACTIONS(6223),
    [anon_sym_notif0] = ACTIONS(6223),
    [anon_sym_notif1] = ACTIONS(6223),
    [anon_sym_nmos] = ACTIONS(6223),
    [anon_sym_pmos] = ACTIONS(6223),
    [anon_sym_rnmos] = ACTIONS(6223),
    [anon_sym_rpmos] = ACTIONS(6223),
    [anon_sym_nand] = ACTIONS(6223),
    [anon_sym_nor] = ACTIONS(6223),
    [anon_sym_xor] = ACTIONS(6223),
    [anon_sym_xnor] = ACTIONS(6223),
    [anon_sym_buf] = ACTIONS(6223),
    [anon_sym_tranif0] = ACTIONS(6223),
    [anon_sym_tranif1] = ACTIONS(6223),
    [anon_sym_rtranif1] = ACTIONS(6223),
    [anon_sym_rtranif0] = ACTIONS(6223),
    [anon_sym_tran] = ACTIONS(6223),
    [anon_sym_rtran] = ACTIONS(6223),
    [anon_sym_generate] = ACTIONS(6223),
    [anon_sym_for] = ACTIONS(6223),
    [anon_sym_primitive] = ACTIONS(6223),
    [anon_sym_initial] = ACTIONS(6223),
    [anon_sym_assign] = ACTIONS(6223),
    [anon_sym_alias] = ACTIONS(6223),
    [anon_sym_always_comb] = ACTIONS(6223),
    [anon_sym_always_latch] = ACTIONS(6223),
    [anon_sym_always_ff] = ACTIONS(6223),
    [anon_sym_final] = ACTIONS(6223),
    [anon_sym_global] = ACTIONS(6223),
    [anon_sym_specify] = ACTIONS(6223),
    [anon_sym_LPAREN_STAR] = ACTIONS(6221),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6221),
    [anon_sym_DOLLARunit] = ACTIONS(6221),
  },
  [1124] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5812),
    [anon_sym_BQUOTE] = ACTIONS(5810),
    [aux_sym_id_directive_token1] = ACTIONS(5812),
    [aux_sym_id_directive_token2] = ACTIONS(5812),
    [aux_sym_id_directive_token3] = ACTIONS(5812),
    [aux_sym_id_directive_token4] = ACTIONS(5810),
    [aux_sym_zero_directive_token1] = ACTIONS(5812),
    [aux_sym_zero_directive_token2] = ACTIONS(5812),
    [aux_sym_zero_directive_token3] = ACTIONS(5812),
    [aux_sym_zero_directive_token4] = ACTIONS(5812),
    [aux_sym_zero_directive_token5] = ACTIONS(5812),
    [aux_sym_zero_directive_token6] = ACTIONS(5812),
    [aux_sym_zero_directive_token7] = ACTIONS(5812),
    [aux_sym_zero_directive_token8] = ACTIONS(5812),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5812),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5812),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5812),
    [aux_sym_begin_keywords_token1] = ACTIONS(5812),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_endmodule] = ACTIONS(5810),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_module] = ACTIONS(5810),
    [anon_sym_macromodule] = ACTIONS(5810),
    [anon_sym_endinterface] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_endprogram] = ACTIONS(5810),
    [anon_sym_program] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_timeunit] = ACTIONS(5810),
    [anon_sym_timeprecision] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_input] = ACTIONS(5810),
    [anon_sym_output] = ACTIONS(5810),
    [anon_sym_inout] = ACTIONS(5810),
    [anon_sym_ref] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(5810),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_specparam] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_modport] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_while] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_specify] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [1125] = {
    [ts_builtin_sym_end] = ACTIONS(5576),
    [sym_simple_identifier] = ACTIONS(5578),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5576),
    [anon_sym_BQUOTE] = ACTIONS(5578),
    [aux_sym_id_directive_token1] = ACTIONS(5576),
    [aux_sym_id_directive_token2] = ACTIONS(5576),
    [aux_sym_id_directive_token3] = ACTIONS(5576),
    [aux_sym_id_directive_token4] = ACTIONS(5578),
    [aux_sym_zero_directive_token1] = ACTIONS(5576),
    [aux_sym_zero_directive_token2] = ACTIONS(5576),
    [aux_sym_zero_directive_token3] = ACTIONS(5576),
    [aux_sym_zero_directive_token4] = ACTIONS(5576),
    [aux_sym_zero_directive_token5] = ACTIONS(5576),
    [aux_sym_zero_directive_token6] = ACTIONS(5576),
    [aux_sym_zero_directive_token7] = ACTIONS(5576),
    [aux_sym_zero_directive_token8] = ACTIONS(5576),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5576),
    [anon_sym_wire] = ACTIONS(5578),
    [anon_sym_tri] = ACTIONS(5578),
    [anon_sym_tri0] = ACTIONS(5578),
    [anon_sym_tri1] = ACTIONS(5578),
    [anon_sym_wand] = ACTIONS(5578),
    [anon_sym_triand] = ACTIONS(5578),
    [anon_sym_wor] = ACTIONS(5578),
    [anon_sym_trior] = ACTIONS(5578),
    [anon_sym_trireg] = ACTIONS(5578),
    [anon_sym_uwire] = ACTIONS(5578),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5576),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5576),
    [aux_sym_begin_keywords_token1] = ACTIONS(5576),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_endmodule] = ACTIONS(5578),
    [anon_sym_extern] = ACTIONS(5578),
    [anon_sym_module] = ACTIONS(5578),
    [anon_sym_macromodule] = ACTIONS(5578),
    [anon_sym_endinterface] = ACTIONS(5578),
    [anon_sym_interface] = ACTIONS(5578),
    [anon_sym_program] = ACTIONS(5578),
    [anon_sym_checker] = ACTIONS(5578),
    [anon_sym_virtual] = ACTIONS(5578),
    [anon_sym_class] = ACTIONS(5578),
    [anon_sym_package] = ACTIONS(5578),
    [anon_sym_timeunit] = ACTIONS(5578),
    [anon_sym_timeprecision] = ACTIONS(5578),
    [anon_sym_type] = ACTIONS(5578),
    [anon_sym_input] = ACTIONS(5578),
    [anon_sym_output] = ACTIONS(5578),
    [anon_sym_inout] = ACTIONS(5578),
    [anon_sym_ref] = ACTIONS(5578),
    [anon_sym_DOLLARfatal] = ACTIONS(5576),
    [anon_sym_DOLLARerror] = ACTIONS(5576),
    [anon_sym_DOLLARwarning] = ACTIONS(5576),
    [anon_sym_DOLLARinfo] = ACTIONS(5576),
    [anon_sym_default] = ACTIONS(5578),
    [anon_sym_clocking] = ACTIONS(5578),
    [anon_sym_defparam] = ACTIONS(5578),
    [anon_sym_bind] = ACTIONS(5578),
    [anon_sym_const] = ACTIONS(5578),
    [anon_sym_function] = ACTIONS(5578),
    [anon_sym_static] = ACTIONS(5578),
    [anon_sym_constraint] = ACTIONS(5578),
    [anon_sym_if] = ACTIONS(5578),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_localparam] = ACTIONS(5578),
    [anon_sym_parameter] = ACTIONS(5578),
    [anon_sym_specparam] = ACTIONS(5578),
    [anon_sym_var] = ACTIONS(5578),
    [anon_sym_import] = ACTIONS(5578),
    [anon_sym_export] = ACTIONS(5578),
    [anon_sym_genvar] = ACTIONS(5578),
    [anon_sym_interconnect] = ACTIONS(5578),
    [anon_sym_typedef] = ACTIONS(5578),
    [anon_sym_enum] = ACTIONS(5578),
    [anon_sym_struct] = ACTIONS(5578),
    [anon_sym_union] = ACTIONS(5578),
    [anon_sym_nettype] = ACTIONS(5578),
    [anon_sym_automatic] = ACTIONS(5578),
    [anon_sym_string] = ACTIONS(5578),
    [anon_sym_chandle] = ACTIONS(5578),
    [anon_sym_event] = ACTIONS(5578),
    [anon_sym_byte] = ACTIONS(5578),
    [anon_sym_shortint] = ACTIONS(5578),
    [anon_sym_int] = ACTIONS(5578),
    [anon_sym_longint] = ACTIONS(5578),
    [anon_sym_integer] = ACTIONS(5578),
    [anon_sym_time] = ACTIONS(5578),
    [anon_sym_bit] = ACTIONS(5578),
    [anon_sym_logic] = ACTIONS(5578),
    [anon_sym_reg] = ACTIONS(5578),
    [anon_sym_shortreal] = ACTIONS(5578),
    [anon_sym_real] = ACTIONS(5578),
    [anon_sym_realtime] = ACTIONS(5578),
    [anon_sym_supply0] = ACTIONS(5578),
    [anon_sym_supply1] = ACTIONS(5578),
    [anon_sym_signed] = ACTIONS(5578),
    [anon_sym_unsigned] = ACTIONS(5578),
    [anon_sym_task] = ACTIONS(5578),
    [anon_sym_modport] = ACTIONS(5578),
    [anon_sym_assert] = ACTIONS(5578),
    [anon_sym_property] = ACTIONS(5578),
    [anon_sym_assume] = ACTIONS(5578),
    [anon_sym_cover] = ACTIONS(5578),
    [anon_sym_sequence] = ACTIONS(5578),
    [anon_sym_restrict] = ACTIONS(5578),
    [anon_sym_not] = ACTIONS(5578),
    [anon_sym_or] = ACTIONS(5578),
    [anon_sym_and] = ACTIONS(5578),
    [anon_sym_case] = ACTIONS(5578),
    [anon_sym_always] = ACTIONS(5578),
    [anon_sym_covergroup] = ACTIONS(5578),
    [anon_sym_let] = ACTIONS(5578),
    [anon_sym_pulldown] = ACTIONS(5578),
    [anon_sym_pullup] = ACTIONS(5578),
    [anon_sym_cmos] = ACTIONS(5578),
    [anon_sym_rcmos] = ACTIONS(5578),
    [anon_sym_bufif0] = ACTIONS(5578),
    [anon_sym_bufif1] = ACTIONS(5578),
    [anon_sym_notif0] = ACTIONS(5578),
    [anon_sym_notif1] = ACTIONS(5578),
    [anon_sym_nmos] = ACTIONS(5578),
    [anon_sym_pmos] = ACTIONS(5578),
    [anon_sym_rnmos] = ACTIONS(5578),
    [anon_sym_rpmos] = ACTIONS(5578),
    [anon_sym_nand] = ACTIONS(5578),
    [anon_sym_nor] = ACTIONS(5578),
    [anon_sym_xor] = ACTIONS(5578),
    [anon_sym_xnor] = ACTIONS(5578),
    [anon_sym_buf] = ACTIONS(5578),
    [anon_sym_tranif0] = ACTIONS(5578),
    [anon_sym_tranif1] = ACTIONS(5578),
    [anon_sym_rtranif1] = ACTIONS(5578),
    [anon_sym_rtranif0] = ACTIONS(5578),
    [anon_sym_tran] = ACTIONS(5578),
    [anon_sym_rtran] = ACTIONS(5578),
    [anon_sym_generate] = ACTIONS(5578),
    [anon_sym_for] = ACTIONS(5578),
    [anon_sym_primitive] = ACTIONS(5578),
    [anon_sym_initial] = ACTIONS(5578),
    [anon_sym_assign] = ACTIONS(5578),
    [anon_sym_alias] = ACTIONS(5578),
    [anon_sym_always_comb] = ACTIONS(5578),
    [anon_sym_always_latch] = ACTIONS(5578),
    [anon_sym_always_ff] = ACTIONS(5578),
    [anon_sym_final] = ACTIONS(5578),
    [anon_sym_global] = ACTIONS(5578),
    [anon_sym_specify] = ACTIONS(5578),
    [anon_sym_LPAREN_STAR] = ACTIONS(5576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5576),
    [anon_sym_DOLLARunit] = ACTIONS(5576),
  },
  [1126] = {
    [sym_simple_identifier] = ACTIONS(6225),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6227),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6227),
    [anon_sym_BQUOTE] = ACTIONS(6225),
    [aux_sym_id_directive_token1] = ACTIONS(6227),
    [aux_sym_id_directive_token2] = ACTIONS(6227),
    [aux_sym_id_directive_token3] = ACTIONS(6227),
    [aux_sym_id_directive_token4] = ACTIONS(6225),
    [aux_sym_zero_directive_token1] = ACTIONS(6227),
    [aux_sym_zero_directive_token2] = ACTIONS(6227),
    [aux_sym_zero_directive_token3] = ACTIONS(6227),
    [aux_sym_zero_directive_token4] = ACTIONS(6227),
    [aux_sym_zero_directive_token5] = ACTIONS(6227),
    [aux_sym_zero_directive_token6] = ACTIONS(6227),
    [aux_sym_zero_directive_token7] = ACTIONS(6227),
    [aux_sym_zero_directive_token8] = ACTIONS(6227),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6227),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6227),
    [anon_sym_wire] = ACTIONS(6225),
    [anon_sym_tri] = ACTIONS(6225),
    [anon_sym_tri0] = ACTIONS(6225),
    [anon_sym_tri1] = ACTIONS(6225),
    [anon_sym_wand] = ACTIONS(6225),
    [anon_sym_triand] = ACTIONS(6225),
    [anon_sym_wor] = ACTIONS(6225),
    [anon_sym_trior] = ACTIONS(6225),
    [anon_sym_trireg] = ACTIONS(6225),
    [anon_sym_uwire] = ACTIONS(6225),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6227),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6227),
    [aux_sym_begin_keywords_token1] = ACTIONS(6227),
    [anon_sym_SEMI] = ACTIONS(6227),
    [anon_sym_endmodule] = ACTIONS(6225),
    [anon_sym_extern] = ACTIONS(6225),
    [anon_sym_module] = ACTIONS(6225),
    [anon_sym_macromodule] = ACTIONS(6225),
    [anon_sym_endinterface] = ACTIONS(6225),
    [anon_sym_interface] = ACTIONS(6225),
    [anon_sym_endprogram] = ACTIONS(6225),
    [anon_sym_program] = ACTIONS(6225),
    [anon_sym_checker] = ACTIONS(6225),
    [anon_sym_virtual] = ACTIONS(6225),
    [anon_sym_class] = ACTIONS(6225),
    [anon_sym_timeunit] = ACTIONS(6225),
    [anon_sym_timeprecision] = ACTIONS(6225),
    [anon_sym_type] = ACTIONS(6225),
    [anon_sym_input] = ACTIONS(6225),
    [anon_sym_output] = ACTIONS(6225),
    [anon_sym_inout] = ACTIONS(6225),
    [anon_sym_ref] = ACTIONS(6225),
    [anon_sym_DOLLARfatal] = ACTIONS(6227),
    [anon_sym_DOLLARerror] = ACTIONS(6227),
    [anon_sym_DOLLARwarning] = ACTIONS(6227),
    [anon_sym_DOLLARinfo] = ACTIONS(6227),
    [anon_sym_default] = ACTIONS(6225),
    [anon_sym_clocking] = ACTIONS(6225),
    [anon_sym_defparam] = ACTIONS(6225),
    [anon_sym_bind] = ACTIONS(6225),
    [anon_sym_const] = ACTIONS(6225),
    [anon_sym_function] = ACTIONS(6225),
    [anon_sym_static] = ACTIONS(6225),
    [anon_sym_constraint] = ACTIONS(6225),
    [anon_sym_if] = ACTIONS(6225),
    [anon_sym_else] = ACTIONS(6225),
    [anon_sym_LBRACK] = ACTIONS(6227),
    [anon_sym_localparam] = ACTIONS(6225),
    [anon_sym_parameter] = ACTIONS(6225),
    [anon_sym_specparam] = ACTIONS(6225),
    [anon_sym_var] = ACTIONS(6225),
    [anon_sym_import] = ACTIONS(6225),
    [anon_sym_export] = ACTIONS(6225),
    [anon_sym_genvar] = ACTIONS(6225),
    [anon_sym_interconnect] = ACTIONS(6225),
    [anon_sym_typedef] = ACTIONS(6225),
    [anon_sym_enum] = ACTIONS(6225),
    [anon_sym_struct] = ACTIONS(6225),
    [anon_sym_union] = ACTIONS(6225),
    [anon_sym_nettype] = ACTIONS(6225),
    [anon_sym_automatic] = ACTIONS(6225),
    [anon_sym_string] = ACTIONS(6225),
    [anon_sym_chandle] = ACTIONS(6225),
    [anon_sym_event] = ACTIONS(6225),
    [anon_sym_byte] = ACTIONS(6225),
    [anon_sym_shortint] = ACTIONS(6225),
    [anon_sym_int] = ACTIONS(6225),
    [anon_sym_longint] = ACTIONS(6225),
    [anon_sym_integer] = ACTIONS(6225),
    [anon_sym_time] = ACTIONS(6225),
    [anon_sym_bit] = ACTIONS(6225),
    [anon_sym_logic] = ACTIONS(6225),
    [anon_sym_reg] = ACTIONS(6225),
    [anon_sym_shortreal] = ACTIONS(6225),
    [anon_sym_real] = ACTIONS(6225),
    [anon_sym_realtime] = ACTIONS(6225),
    [anon_sym_supply0] = ACTIONS(6225),
    [anon_sym_supply1] = ACTIONS(6225),
    [anon_sym_signed] = ACTIONS(6225),
    [anon_sym_unsigned] = ACTIONS(6225),
    [anon_sym_task] = ACTIONS(6225),
    [anon_sym_modport] = ACTIONS(6225),
    [anon_sym_assert] = ACTIONS(6225),
    [anon_sym_property] = ACTIONS(6225),
    [anon_sym_assume] = ACTIONS(6225),
    [anon_sym_cover] = ACTIONS(6225),
    [anon_sym_sequence] = ACTIONS(6225),
    [anon_sym_restrict] = ACTIONS(6225),
    [anon_sym_not] = ACTIONS(6225),
    [anon_sym_or] = ACTIONS(6225),
    [anon_sym_and] = ACTIONS(6225),
    [anon_sym_case] = ACTIONS(6225),
    [anon_sym_always] = ACTIONS(6225),
    [anon_sym_covergroup] = ACTIONS(6225),
    [anon_sym_let] = ACTIONS(6225),
    [anon_sym_pulldown] = ACTIONS(6225),
    [anon_sym_pullup] = ACTIONS(6225),
    [anon_sym_cmos] = ACTIONS(6225),
    [anon_sym_rcmos] = ACTIONS(6225),
    [anon_sym_bufif0] = ACTIONS(6225),
    [anon_sym_bufif1] = ACTIONS(6225),
    [anon_sym_notif0] = ACTIONS(6225),
    [anon_sym_notif1] = ACTIONS(6225),
    [anon_sym_nmos] = ACTIONS(6225),
    [anon_sym_pmos] = ACTIONS(6225),
    [anon_sym_rnmos] = ACTIONS(6225),
    [anon_sym_rpmos] = ACTIONS(6225),
    [anon_sym_nand] = ACTIONS(6225),
    [anon_sym_nor] = ACTIONS(6225),
    [anon_sym_xor] = ACTIONS(6225),
    [anon_sym_xnor] = ACTIONS(6225),
    [anon_sym_buf] = ACTIONS(6225),
    [anon_sym_tranif0] = ACTIONS(6225),
    [anon_sym_tranif1] = ACTIONS(6225),
    [anon_sym_rtranif1] = ACTIONS(6225),
    [anon_sym_rtranif0] = ACTIONS(6225),
    [anon_sym_tran] = ACTIONS(6225),
    [anon_sym_rtran] = ACTIONS(6225),
    [anon_sym_generate] = ACTIONS(6225),
    [anon_sym_for] = ACTIONS(6225),
    [anon_sym_initial] = ACTIONS(6225),
    [anon_sym_assign] = ACTIONS(6225),
    [anon_sym_alias] = ACTIONS(6225),
    [anon_sym_always_comb] = ACTIONS(6225),
    [anon_sym_always_latch] = ACTIONS(6225),
    [anon_sym_always_ff] = ACTIONS(6225),
    [anon_sym_final] = ACTIONS(6225),
    [anon_sym_while] = ACTIONS(6225),
    [anon_sym_global] = ACTIONS(6225),
    [anon_sym_specify] = ACTIONS(6225),
    [anon_sym_LPAREN_STAR] = ACTIONS(6227),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6227),
    [anon_sym_DOLLARunit] = ACTIONS(6227),
  },
  [1127] = {
    [ts_builtin_sym_end] = ACTIONS(6229),
    [sym_simple_identifier] = ACTIONS(6231),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6229),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6229),
    [anon_sym_BQUOTE] = ACTIONS(6231),
    [aux_sym_id_directive_token1] = ACTIONS(6229),
    [aux_sym_id_directive_token2] = ACTIONS(6229),
    [aux_sym_id_directive_token3] = ACTIONS(6229),
    [aux_sym_id_directive_token4] = ACTIONS(6231),
    [aux_sym_zero_directive_token1] = ACTIONS(6229),
    [aux_sym_zero_directive_token2] = ACTIONS(6229),
    [aux_sym_zero_directive_token3] = ACTIONS(6229),
    [aux_sym_zero_directive_token4] = ACTIONS(6229),
    [aux_sym_zero_directive_token5] = ACTIONS(6229),
    [aux_sym_zero_directive_token6] = ACTIONS(6229),
    [aux_sym_zero_directive_token7] = ACTIONS(6229),
    [aux_sym_zero_directive_token8] = ACTIONS(6229),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6229),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6229),
    [anon_sym_wire] = ACTIONS(6231),
    [anon_sym_tri] = ACTIONS(6231),
    [anon_sym_tri0] = ACTIONS(6231),
    [anon_sym_tri1] = ACTIONS(6231),
    [anon_sym_wand] = ACTIONS(6231),
    [anon_sym_triand] = ACTIONS(6231),
    [anon_sym_wor] = ACTIONS(6231),
    [anon_sym_trior] = ACTIONS(6231),
    [anon_sym_trireg] = ACTIONS(6231),
    [anon_sym_uwire] = ACTIONS(6231),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6229),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6229),
    [aux_sym_begin_keywords_token1] = ACTIONS(6229),
    [anon_sym_SEMI] = ACTIONS(6229),
    [anon_sym_endmodule] = ACTIONS(6231),
    [anon_sym_extern] = ACTIONS(6231),
    [anon_sym_module] = ACTIONS(6231),
    [anon_sym_macromodule] = ACTIONS(6231),
    [anon_sym_endinterface] = ACTIONS(6231),
    [anon_sym_interface] = ACTIONS(6231),
    [anon_sym_program] = ACTIONS(6231),
    [anon_sym_checker] = ACTIONS(6231),
    [anon_sym_virtual] = ACTIONS(6231),
    [anon_sym_class] = ACTIONS(6231),
    [anon_sym_package] = ACTIONS(6231),
    [anon_sym_timeunit] = ACTIONS(6231),
    [anon_sym_timeprecision] = ACTIONS(6231),
    [anon_sym_type] = ACTIONS(6231),
    [anon_sym_input] = ACTIONS(6231),
    [anon_sym_output] = ACTIONS(6231),
    [anon_sym_inout] = ACTIONS(6231),
    [anon_sym_ref] = ACTIONS(6231),
    [anon_sym_DOLLARfatal] = ACTIONS(6229),
    [anon_sym_DOLLARerror] = ACTIONS(6229),
    [anon_sym_DOLLARwarning] = ACTIONS(6229),
    [anon_sym_DOLLARinfo] = ACTIONS(6229),
    [anon_sym_default] = ACTIONS(6231),
    [anon_sym_clocking] = ACTIONS(6231),
    [anon_sym_defparam] = ACTIONS(6231),
    [anon_sym_bind] = ACTIONS(6231),
    [anon_sym_const] = ACTIONS(6231),
    [anon_sym_function] = ACTIONS(6231),
    [anon_sym_static] = ACTIONS(6231),
    [anon_sym_constraint] = ACTIONS(6231),
    [anon_sym_if] = ACTIONS(6231),
    [anon_sym_LBRACK] = ACTIONS(6229),
    [anon_sym_localparam] = ACTIONS(6231),
    [anon_sym_parameter] = ACTIONS(6231),
    [anon_sym_specparam] = ACTIONS(6231),
    [anon_sym_var] = ACTIONS(6231),
    [anon_sym_import] = ACTIONS(6231),
    [anon_sym_export] = ACTIONS(6231),
    [anon_sym_genvar] = ACTIONS(6231),
    [anon_sym_interconnect] = ACTIONS(6231),
    [anon_sym_typedef] = ACTIONS(6231),
    [anon_sym_enum] = ACTIONS(6231),
    [anon_sym_struct] = ACTIONS(6231),
    [anon_sym_union] = ACTIONS(6231),
    [anon_sym_nettype] = ACTIONS(6231),
    [anon_sym_automatic] = ACTIONS(6231),
    [anon_sym_string] = ACTIONS(6231),
    [anon_sym_chandle] = ACTIONS(6231),
    [anon_sym_event] = ACTIONS(6231),
    [anon_sym_byte] = ACTIONS(6231),
    [anon_sym_shortint] = ACTIONS(6231),
    [anon_sym_int] = ACTIONS(6231),
    [anon_sym_longint] = ACTIONS(6231),
    [anon_sym_integer] = ACTIONS(6231),
    [anon_sym_time] = ACTIONS(6231),
    [anon_sym_bit] = ACTIONS(6231),
    [anon_sym_logic] = ACTIONS(6231),
    [anon_sym_reg] = ACTIONS(6231),
    [anon_sym_shortreal] = ACTIONS(6231),
    [anon_sym_real] = ACTIONS(6231),
    [anon_sym_realtime] = ACTIONS(6231),
    [anon_sym_supply0] = ACTIONS(6231),
    [anon_sym_supply1] = ACTIONS(6231),
    [anon_sym_signed] = ACTIONS(6231),
    [anon_sym_unsigned] = ACTIONS(6231),
    [anon_sym_task] = ACTIONS(6231),
    [anon_sym_modport] = ACTIONS(6231),
    [anon_sym_assert] = ACTIONS(6231),
    [anon_sym_property] = ACTIONS(6231),
    [anon_sym_assume] = ACTIONS(6231),
    [anon_sym_cover] = ACTIONS(6231),
    [anon_sym_sequence] = ACTIONS(6231),
    [anon_sym_restrict] = ACTIONS(6231),
    [anon_sym_not] = ACTIONS(6231),
    [anon_sym_or] = ACTIONS(6231),
    [anon_sym_and] = ACTIONS(6231),
    [anon_sym_case] = ACTIONS(6231),
    [anon_sym_always] = ACTIONS(6231),
    [anon_sym_covergroup] = ACTIONS(6231),
    [anon_sym_let] = ACTIONS(6231),
    [anon_sym_pulldown] = ACTIONS(6231),
    [anon_sym_pullup] = ACTIONS(6231),
    [anon_sym_cmos] = ACTIONS(6231),
    [anon_sym_rcmos] = ACTIONS(6231),
    [anon_sym_bufif0] = ACTIONS(6231),
    [anon_sym_bufif1] = ACTIONS(6231),
    [anon_sym_notif0] = ACTIONS(6231),
    [anon_sym_notif1] = ACTIONS(6231),
    [anon_sym_nmos] = ACTIONS(6231),
    [anon_sym_pmos] = ACTIONS(6231),
    [anon_sym_rnmos] = ACTIONS(6231),
    [anon_sym_rpmos] = ACTIONS(6231),
    [anon_sym_nand] = ACTIONS(6231),
    [anon_sym_nor] = ACTIONS(6231),
    [anon_sym_xor] = ACTIONS(6231),
    [anon_sym_xnor] = ACTIONS(6231),
    [anon_sym_buf] = ACTIONS(6231),
    [anon_sym_tranif0] = ACTIONS(6231),
    [anon_sym_tranif1] = ACTIONS(6231),
    [anon_sym_rtranif1] = ACTIONS(6231),
    [anon_sym_rtranif0] = ACTIONS(6231),
    [anon_sym_tran] = ACTIONS(6231),
    [anon_sym_rtran] = ACTIONS(6231),
    [anon_sym_generate] = ACTIONS(6231),
    [anon_sym_for] = ACTIONS(6231),
    [anon_sym_primitive] = ACTIONS(6231),
    [anon_sym_initial] = ACTIONS(6231),
    [anon_sym_assign] = ACTIONS(6231),
    [anon_sym_alias] = ACTIONS(6231),
    [anon_sym_always_comb] = ACTIONS(6231),
    [anon_sym_always_latch] = ACTIONS(6231),
    [anon_sym_always_ff] = ACTIONS(6231),
    [anon_sym_final] = ACTIONS(6231),
    [anon_sym_global] = ACTIONS(6231),
    [anon_sym_specify] = ACTIONS(6231),
    [anon_sym_LPAREN_STAR] = ACTIONS(6229),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6229),
    [anon_sym_DOLLARunit] = ACTIONS(6229),
  },
  [1128] = {
    [sym_simple_identifier] = ACTIONS(6233),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6235),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6235),
    [anon_sym_BQUOTE] = ACTIONS(6233),
    [aux_sym_id_directive_token1] = ACTIONS(6235),
    [aux_sym_id_directive_token2] = ACTIONS(6235),
    [aux_sym_id_directive_token3] = ACTIONS(6235),
    [aux_sym_id_directive_token4] = ACTIONS(6233),
    [aux_sym_zero_directive_token1] = ACTIONS(6235),
    [aux_sym_zero_directive_token2] = ACTIONS(6235),
    [aux_sym_zero_directive_token3] = ACTIONS(6235),
    [aux_sym_zero_directive_token4] = ACTIONS(6235),
    [aux_sym_zero_directive_token5] = ACTIONS(6235),
    [aux_sym_zero_directive_token6] = ACTIONS(6235),
    [aux_sym_zero_directive_token7] = ACTIONS(6235),
    [aux_sym_zero_directive_token8] = ACTIONS(6235),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6235),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6235),
    [anon_sym_wire] = ACTIONS(6233),
    [anon_sym_tri] = ACTIONS(6233),
    [anon_sym_tri0] = ACTIONS(6233),
    [anon_sym_tri1] = ACTIONS(6233),
    [anon_sym_wand] = ACTIONS(6233),
    [anon_sym_triand] = ACTIONS(6233),
    [anon_sym_wor] = ACTIONS(6233),
    [anon_sym_trior] = ACTIONS(6233),
    [anon_sym_trireg] = ACTIONS(6233),
    [anon_sym_uwire] = ACTIONS(6233),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6235),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6235),
    [aux_sym_begin_keywords_token1] = ACTIONS(6235),
    [anon_sym_SEMI] = ACTIONS(6235),
    [anon_sym_endmodule] = ACTIONS(6233),
    [anon_sym_extern] = ACTIONS(6233),
    [anon_sym_module] = ACTIONS(6233),
    [anon_sym_macromodule] = ACTIONS(6233),
    [anon_sym_endinterface] = ACTIONS(6233),
    [anon_sym_interface] = ACTIONS(6233),
    [anon_sym_endprogram] = ACTIONS(6233),
    [anon_sym_program] = ACTIONS(6233),
    [anon_sym_checker] = ACTIONS(6233),
    [anon_sym_virtual] = ACTIONS(6233),
    [anon_sym_class] = ACTIONS(6233),
    [anon_sym_timeunit] = ACTIONS(6233),
    [anon_sym_timeprecision] = ACTIONS(6233),
    [anon_sym_type] = ACTIONS(6233),
    [anon_sym_input] = ACTIONS(6233),
    [anon_sym_output] = ACTIONS(6233),
    [anon_sym_inout] = ACTIONS(6233),
    [anon_sym_ref] = ACTIONS(6233),
    [anon_sym_DOLLARfatal] = ACTIONS(6235),
    [anon_sym_DOLLARerror] = ACTIONS(6235),
    [anon_sym_DOLLARwarning] = ACTIONS(6235),
    [anon_sym_DOLLARinfo] = ACTIONS(6235),
    [anon_sym_default] = ACTIONS(6233),
    [anon_sym_clocking] = ACTIONS(6233),
    [anon_sym_defparam] = ACTIONS(6233),
    [anon_sym_bind] = ACTIONS(6233),
    [anon_sym_const] = ACTIONS(6233),
    [anon_sym_function] = ACTIONS(6233),
    [anon_sym_static] = ACTIONS(6233),
    [anon_sym_constraint] = ACTIONS(6233),
    [anon_sym_if] = ACTIONS(6233),
    [anon_sym_else] = ACTIONS(6233),
    [anon_sym_LBRACK] = ACTIONS(6235),
    [anon_sym_localparam] = ACTIONS(6233),
    [anon_sym_parameter] = ACTIONS(6233),
    [anon_sym_specparam] = ACTIONS(6233),
    [anon_sym_var] = ACTIONS(6233),
    [anon_sym_import] = ACTIONS(6233),
    [anon_sym_export] = ACTIONS(6233),
    [anon_sym_genvar] = ACTIONS(6233),
    [anon_sym_interconnect] = ACTIONS(6233),
    [anon_sym_typedef] = ACTIONS(6233),
    [anon_sym_enum] = ACTIONS(6233),
    [anon_sym_struct] = ACTIONS(6233),
    [anon_sym_union] = ACTIONS(6233),
    [anon_sym_nettype] = ACTIONS(6233),
    [anon_sym_automatic] = ACTIONS(6233),
    [anon_sym_string] = ACTIONS(6233),
    [anon_sym_chandle] = ACTIONS(6233),
    [anon_sym_event] = ACTIONS(6233),
    [anon_sym_byte] = ACTIONS(6233),
    [anon_sym_shortint] = ACTIONS(6233),
    [anon_sym_int] = ACTIONS(6233),
    [anon_sym_longint] = ACTIONS(6233),
    [anon_sym_integer] = ACTIONS(6233),
    [anon_sym_time] = ACTIONS(6233),
    [anon_sym_bit] = ACTIONS(6233),
    [anon_sym_logic] = ACTIONS(6233),
    [anon_sym_reg] = ACTIONS(6233),
    [anon_sym_shortreal] = ACTIONS(6233),
    [anon_sym_real] = ACTIONS(6233),
    [anon_sym_realtime] = ACTIONS(6233),
    [anon_sym_supply0] = ACTIONS(6233),
    [anon_sym_supply1] = ACTIONS(6233),
    [anon_sym_signed] = ACTIONS(6233),
    [anon_sym_unsigned] = ACTIONS(6233),
    [anon_sym_task] = ACTIONS(6233),
    [anon_sym_modport] = ACTIONS(6233),
    [anon_sym_assert] = ACTIONS(6233),
    [anon_sym_property] = ACTIONS(6233),
    [anon_sym_assume] = ACTIONS(6233),
    [anon_sym_cover] = ACTIONS(6233),
    [anon_sym_sequence] = ACTIONS(6233),
    [anon_sym_restrict] = ACTIONS(6233),
    [anon_sym_not] = ACTIONS(6233),
    [anon_sym_or] = ACTIONS(6233),
    [anon_sym_and] = ACTIONS(6233),
    [anon_sym_case] = ACTIONS(6233),
    [anon_sym_always] = ACTIONS(6233),
    [anon_sym_covergroup] = ACTIONS(6233),
    [anon_sym_let] = ACTIONS(6233),
    [anon_sym_pulldown] = ACTIONS(6233),
    [anon_sym_pullup] = ACTIONS(6233),
    [anon_sym_cmos] = ACTIONS(6233),
    [anon_sym_rcmos] = ACTIONS(6233),
    [anon_sym_bufif0] = ACTIONS(6233),
    [anon_sym_bufif1] = ACTIONS(6233),
    [anon_sym_notif0] = ACTIONS(6233),
    [anon_sym_notif1] = ACTIONS(6233),
    [anon_sym_nmos] = ACTIONS(6233),
    [anon_sym_pmos] = ACTIONS(6233),
    [anon_sym_rnmos] = ACTIONS(6233),
    [anon_sym_rpmos] = ACTIONS(6233),
    [anon_sym_nand] = ACTIONS(6233),
    [anon_sym_nor] = ACTIONS(6233),
    [anon_sym_xor] = ACTIONS(6233),
    [anon_sym_xnor] = ACTIONS(6233),
    [anon_sym_buf] = ACTIONS(6233),
    [anon_sym_tranif0] = ACTIONS(6233),
    [anon_sym_tranif1] = ACTIONS(6233),
    [anon_sym_rtranif1] = ACTIONS(6233),
    [anon_sym_rtranif0] = ACTIONS(6233),
    [anon_sym_tran] = ACTIONS(6233),
    [anon_sym_rtran] = ACTIONS(6233),
    [anon_sym_generate] = ACTIONS(6233),
    [anon_sym_for] = ACTIONS(6233),
    [anon_sym_initial] = ACTIONS(6233),
    [anon_sym_assign] = ACTIONS(6233),
    [anon_sym_alias] = ACTIONS(6233),
    [anon_sym_always_comb] = ACTIONS(6233),
    [anon_sym_always_latch] = ACTIONS(6233),
    [anon_sym_always_ff] = ACTIONS(6233),
    [anon_sym_final] = ACTIONS(6233),
    [anon_sym_while] = ACTIONS(6233),
    [anon_sym_global] = ACTIONS(6233),
    [anon_sym_specify] = ACTIONS(6233),
    [anon_sym_LPAREN_STAR] = ACTIONS(6235),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6235),
    [anon_sym_DOLLARunit] = ACTIONS(6235),
  },
  [1129] = {
    [sym_simple_identifier] = ACTIONS(6237),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6239),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6239),
    [anon_sym_BQUOTE] = ACTIONS(6237),
    [aux_sym_id_directive_token1] = ACTIONS(6239),
    [aux_sym_id_directive_token2] = ACTIONS(6239),
    [aux_sym_id_directive_token3] = ACTIONS(6239),
    [aux_sym_id_directive_token4] = ACTIONS(6237),
    [aux_sym_zero_directive_token1] = ACTIONS(6239),
    [aux_sym_zero_directive_token2] = ACTIONS(6239),
    [aux_sym_zero_directive_token3] = ACTIONS(6239),
    [aux_sym_zero_directive_token4] = ACTIONS(6239),
    [aux_sym_zero_directive_token5] = ACTIONS(6239),
    [aux_sym_zero_directive_token6] = ACTIONS(6239),
    [aux_sym_zero_directive_token7] = ACTIONS(6239),
    [aux_sym_zero_directive_token8] = ACTIONS(6239),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6239),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6239),
    [anon_sym_wire] = ACTIONS(6237),
    [anon_sym_tri] = ACTIONS(6237),
    [anon_sym_tri0] = ACTIONS(6237),
    [anon_sym_tri1] = ACTIONS(6237),
    [anon_sym_wand] = ACTIONS(6237),
    [anon_sym_triand] = ACTIONS(6237),
    [anon_sym_wor] = ACTIONS(6237),
    [anon_sym_trior] = ACTIONS(6237),
    [anon_sym_trireg] = ACTIONS(6237),
    [anon_sym_uwire] = ACTIONS(6237),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6239),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6239),
    [aux_sym_begin_keywords_token1] = ACTIONS(6239),
    [anon_sym_SEMI] = ACTIONS(6239),
    [anon_sym_endmodule] = ACTIONS(6237),
    [anon_sym_extern] = ACTIONS(6237),
    [anon_sym_module] = ACTIONS(6237),
    [anon_sym_macromodule] = ACTIONS(6237),
    [anon_sym_endinterface] = ACTIONS(6237),
    [anon_sym_interface] = ACTIONS(6237),
    [anon_sym_endprogram] = ACTIONS(6237),
    [anon_sym_program] = ACTIONS(6237),
    [anon_sym_checker] = ACTIONS(6237),
    [anon_sym_virtual] = ACTIONS(6237),
    [anon_sym_class] = ACTIONS(6237),
    [anon_sym_timeunit] = ACTIONS(6237),
    [anon_sym_timeprecision] = ACTIONS(6237),
    [anon_sym_type] = ACTIONS(6237),
    [anon_sym_input] = ACTIONS(6237),
    [anon_sym_output] = ACTIONS(6237),
    [anon_sym_inout] = ACTIONS(6237),
    [anon_sym_ref] = ACTIONS(6237),
    [anon_sym_DOLLARfatal] = ACTIONS(6239),
    [anon_sym_DOLLARerror] = ACTIONS(6239),
    [anon_sym_DOLLARwarning] = ACTIONS(6239),
    [anon_sym_DOLLARinfo] = ACTIONS(6239),
    [anon_sym_default] = ACTIONS(6237),
    [anon_sym_clocking] = ACTIONS(6237),
    [anon_sym_defparam] = ACTIONS(6237),
    [anon_sym_bind] = ACTIONS(6237),
    [anon_sym_const] = ACTIONS(6237),
    [anon_sym_function] = ACTIONS(6237),
    [anon_sym_static] = ACTIONS(6237),
    [anon_sym_constraint] = ACTIONS(6237),
    [anon_sym_if] = ACTIONS(6237),
    [anon_sym_else] = ACTIONS(6237),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [anon_sym_localparam] = ACTIONS(6237),
    [anon_sym_parameter] = ACTIONS(6237),
    [anon_sym_specparam] = ACTIONS(6237),
    [anon_sym_var] = ACTIONS(6237),
    [anon_sym_import] = ACTIONS(6237),
    [anon_sym_export] = ACTIONS(6237),
    [anon_sym_genvar] = ACTIONS(6237),
    [anon_sym_interconnect] = ACTIONS(6237),
    [anon_sym_typedef] = ACTIONS(6237),
    [anon_sym_enum] = ACTIONS(6237),
    [anon_sym_struct] = ACTIONS(6237),
    [anon_sym_union] = ACTIONS(6237),
    [anon_sym_nettype] = ACTIONS(6237),
    [anon_sym_automatic] = ACTIONS(6237),
    [anon_sym_string] = ACTIONS(6237),
    [anon_sym_chandle] = ACTIONS(6237),
    [anon_sym_event] = ACTIONS(6237),
    [anon_sym_byte] = ACTIONS(6237),
    [anon_sym_shortint] = ACTIONS(6237),
    [anon_sym_int] = ACTIONS(6237),
    [anon_sym_longint] = ACTIONS(6237),
    [anon_sym_integer] = ACTIONS(6237),
    [anon_sym_time] = ACTIONS(6237),
    [anon_sym_bit] = ACTIONS(6237),
    [anon_sym_logic] = ACTIONS(6237),
    [anon_sym_reg] = ACTIONS(6237),
    [anon_sym_shortreal] = ACTIONS(6237),
    [anon_sym_real] = ACTIONS(6237),
    [anon_sym_realtime] = ACTIONS(6237),
    [anon_sym_supply0] = ACTIONS(6237),
    [anon_sym_supply1] = ACTIONS(6237),
    [anon_sym_signed] = ACTIONS(6237),
    [anon_sym_unsigned] = ACTIONS(6237),
    [anon_sym_task] = ACTIONS(6237),
    [anon_sym_modport] = ACTIONS(6237),
    [anon_sym_assert] = ACTIONS(6237),
    [anon_sym_property] = ACTIONS(6237),
    [anon_sym_assume] = ACTIONS(6237),
    [anon_sym_cover] = ACTIONS(6237),
    [anon_sym_sequence] = ACTIONS(6237),
    [anon_sym_restrict] = ACTIONS(6237),
    [anon_sym_not] = ACTIONS(6237),
    [anon_sym_or] = ACTIONS(6237),
    [anon_sym_and] = ACTIONS(6237),
    [anon_sym_case] = ACTIONS(6237),
    [anon_sym_always] = ACTIONS(6237),
    [anon_sym_covergroup] = ACTIONS(6237),
    [anon_sym_let] = ACTIONS(6237),
    [anon_sym_pulldown] = ACTIONS(6237),
    [anon_sym_pullup] = ACTIONS(6237),
    [anon_sym_cmos] = ACTIONS(6237),
    [anon_sym_rcmos] = ACTIONS(6237),
    [anon_sym_bufif0] = ACTIONS(6237),
    [anon_sym_bufif1] = ACTIONS(6237),
    [anon_sym_notif0] = ACTIONS(6237),
    [anon_sym_notif1] = ACTIONS(6237),
    [anon_sym_nmos] = ACTIONS(6237),
    [anon_sym_pmos] = ACTIONS(6237),
    [anon_sym_rnmos] = ACTIONS(6237),
    [anon_sym_rpmos] = ACTIONS(6237),
    [anon_sym_nand] = ACTIONS(6237),
    [anon_sym_nor] = ACTIONS(6237),
    [anon_sym_xor] = ACTIONS(6237),
    [anon_sym_xnor] = ACTIONS(6237),
    [anon_sym_buf] = ACTIONS(6237),
    [anon_sym_tranif0] = ACTIONS(6237),
    [anon_sym_tranif1] = ACTIONS(6237),
    [anon_sym_rtranif1] = ACTIONS(6237),
    [anon_sym_rtranif0] = ACTIONS(6237),
    [anon_sym_tran] = ACTIONS(6237),
    [anon_sym_rtran] = ACTIONS(6237),
    [anon_sym_generate] = ACTIONS(6237),
    [anon_sym_for] = ACTIONS(6237),
    [anon_sym_initial] = ACTIONS(6237),
    [anon_sym_assign] = ACTIONS(6237),
    [anon_sym_alias] = ACTIONS(6237),
    [anon_sym_always_comb] = ACTIONS(6237),
    [anon_sym_always_latch] = ACTIONS(6237),
    [anon_sym_always_ff] = ACTIONS(6237),
    [anon_sym_final] = ACTIONS(6237),
    [anon_sym_while] = ACTIONS(6237),
    [anon_sym_global] = ACTIONS(6237),
    [anon_sym_specify] = ACTIONS(6237),
    [anon_sym_LPAREN_STAR] = ACTIONS(6239),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6239),
    [anon_sym_DOLLARunit] = ACTIONS(6239),
  },
  [1130] = {
    [sym_simple_identifier] = ACTIONS(6241),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6243),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6243),
    [anon_sym_BQUOTE] = ACTIONS(6241),
    [aux_sym_id_directive_token1] = ACTIONS(6243),
    [aux_sym_id_directive_token2] = ACTIONS(6243),
    [aux_sym_id_directive_token3] = ACTIONS(6243),
    [aux_sym_id_directive_token4] = ACTIONS(6241),
    [aux_sym_zero_directive_token1] = ACTIONS(6243),
    [aux_sym_zero_directive_token2] = ACTIONS(6243),
    [aux_sym_zero_directive_token3] = ACTIONS(6243),
    [aux_sym_zero_directive_token4] = ACTIONS(6243),
    [aux_sym_zero_directive_token5] = ACTIONS(6243),
    [aux_sym_zero_directive_token6] = ACTIONS(6243),
    [aux_sym_zero_directive_token7] = ACTIONS(6243),
    [aux_sym_zero_directive_token8] = ACTIONS(6243),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6243),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6243),
    [anon_sym_wire] = ACTIONS(6241),
    [anon_sym_tri] = ACTIONS(6241),
    [anon_sym_tri0] = ACTIONS(6241),
    [anon_sym_tri1] = ACTIONS(6241),
    [anon_sym_wand] = ACTIONS(6241),
    [anon_sym_triand] = ACTIONS(6241),
    [anon_sym_wor] = ACTIONS(6241),
    [anon_sym_trior] = ACTIONS(6241),
    [anon_sym_trireg] = ACTIONS(6241),
    [anon_sym_uwire] = ACTIONS(6241),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6243),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6243),
    [aux_sym_begin_keywords_token1] = ACTIONS(6243),
    [anon_sym_SEMI] = ACTIONS(6243),
    [anon_sym_endmodule] = ACTIONS(6241),
    [anon_sym_extern] = ACTIONS(6241),
    [anon_sym_module] = ACTIONS(6241),
    [anon_sym_macromodule] = ACTIONS(6241),
    [anon_sym_endinterface] = ACTIONS(6241),
    [anon_sym_interface] = ACTIONS(6241),
    [anon_sym_endprogram] = ACTIONS(6241),
    [anon_sym_program] = ACTIONS(6241),
    [anon_sym_checker] = ACTIONS(6241),
    [anon_sym_virtual] = ACTIONS(6241),
    [anon_sym_class] = ACTIONS(6241),
    [anon_sym_timeunit] = ACTIONS(6241),
    [anon_sym_timeprecision] = ACTIONS(6241),
    [anon_sym_type] = ACTIONS(6241),
    [anon_sym_input] = ACTIONS(6241),
    [anon_sym_output] = ACTIONS(6241),
    [anon_sym_inout] = ACTIONS(6241),
    [anon_sym_ref] = ACTIONS(6241),
    [anon_sym_DOLLARfatal] = ACTIONS(6243),
    [anon_sym_DOLLARerror] = ACTIONS(6243),
    [anon_sym_DOLLARwarning] = ACTIONS(6243),
    [anon_sym_DOLLARinfo] = ACTIONS(6243),
    [anon_sym_default] = ACTIONS(6241),
    [anon_sym_clocking] = ACTIONS(6241),
    [anon_sym_defparam] = ACTIONS(6241),
    [anon_sym_bind] = ACTIONS(6241),
    [anon_sym_const] = ACTIONS(6241),
    [anon_sym_function] = ACTIONS(6241),
    [anon_sym_static] = ACTIONS(6241),
    [anon_sym_constraint] = ACTIONS(6241),
    [anon_sym_if] = ACTIONS(6241),
    [anon_sym_else] = ACTIONS(6241),
    [anon_sym_LBRACK] = ACTIONS(6243),
    [anon_sym_localparam] = ACTIONS(6241),
    [anon_sym_parameter] = ACTIONS(6241),
    [anon_sym_specparam] = ACTIONS(6241),
    [anon_sym_var] = ACTIONS(6241),
    [anon_sym_import] = ACTIONS(6241),
    [anon_sym_export] = ACTIONS(6241),
    [anon_sym_genvar] = ACTIONS(6241),
    [anon_sym_interconnect] = ACTIONS(6241),
    [anon_sym_typedef] = ACTIONS(6241),
    [anon_sym_enum] = ACTIONS(6241),
    [anon_sym_struct] = ACTIONS(6241),
    [anon_sym_union] = ACTIONS(6241),
    [anon_sym_nettype] = ACTIONS(6241),
    [anon_sym_automatic] = ACTIONS(6241),
    [anon_sym_string] = ACTIONS(6241),
    [anon_sym_chandle] = ACTIONS(6241),
    [anon_sym_event] = ACTIONS(6241),
    [anon_sym_byte] = ACTIONS(6241),
    [anon_sym_shortint] = ACTIONS(6241),
    [anon_sym_int] = ACTIONS(6241),
    [anon_sym_longint] = ACTIONS(6241),
    [anon_sym_integer] = ACTIONS(6241),
    [anon_sym_time] = ACTIONS(6241),
    [anon_sym_bit] = ACTIONS(6241),
    [anon_sym_logic] = ACTIONS(6241),
    [anon_sym_reg] = ACTIONS(6241),
    [anon_sym_shortreal] = ACTIONS(6241),
    [anon_sym_real] = ACTIONS(6241),
    [anon_sym_realtime] = ACTIONS(6241),
    [anon_sym_supply0] = ACTIONS(6241),
    [anon_sym_supply1] = ACTIONS(6241),
    [anon_sym_signed] = ACTIONS(6241),
    [anon_sym_unsigned] = ACTIONS(6241),
    [anon_sym_task] = ACTIONS(6241),
    [anon_sym_modport] = ACTIONS(6241),
    [anon_sym_assert] = ACTIONS(6241),
    [anon_sym_property] = ACTIONS(6241),
    [anon_sym_assume] = ACTIONS(6241),
    [anon_sym_cover] = ACTIONS(6241),
    [anon_sym_sequence] = ACTIONS(6241),
    [anon_sym_restrict] = ACTIONS(6241),
    [anon_sym_not] = ACTIONS(6241),
    [anon_sym_or] = ACTIONS(6241),
    [anon_sym_and] = ACTIONS(6241),
    [anon_sym_case] = ACTIONS(6241),
    [anon_sym_always] = ACTIONS(6241),
    [anon_sym_covergroup] = ACTIONS(6241),
    [anon_sym_let] = ACTIONS(6241),
    [anon_sym_pulldown] = ACTIONS(6241),
    [anon_sym_pullup] = ACTIONS(6241),
    [anon_sym_cmos] = ACTIONS(6241),
    [anon_sym_rcmos] = ACTIONS(6241),
    [anon_sym_bufif0] = ACTIONS(6241),
    [anon_sym_bufif1] = ACTIONS(6241),
    [anon_sym_notif0] = ACTIONS(6241),
    [anon_sym_notif1] = ACTIONS(6241),
    [anon_sym_nmos] = ACTIONS(6241),
    [anon_sym_pmos] = ACTIONS(6241),
    [anon_sym_rnmos] = ACTIONS(6241),
    [anon_sym_rpmos] = ACTIONS(6241),
    [anon_sym_nand] = ACTIONS(6241),
    [anon_sym_nor] = ACTIONS(6241),
    [anon_sym_xor] = ACTIONS(6241),
    [anon_sym_xnor] = ACTIONS(6241),
    [anon_sym_buf] = ACTIONS(6241),
    [anon_sym_tranif0] = ACTIONS(6241),
    [anon_sym_tranif1] = ACTIONS(6241),
    [anon_sym_rtranif1] = ACTIONS(6241),
    [anon_sym_rtranif0] = ACTIONS(6241),
    [anon_sym_tran] = ACTIONS(6241),
    [anon_sym_rtran] = ACTIONS(6241),
    [anon_sym_generate] = ACTIONS(6241),
    [anon_sym_for] = ACTIONS(6241),
    [anon_sym_initial] = ACTIONS(6241),
    [anon_sym_assign] = ACTIONS(6241),
    [anon_sym_alias] = ACTIONS(6241),
    [anon_sym_always_comb] = ACTIONS(6241),
    [anon_sym_always_latch] = ACTIONS(6241),
    [anon_sym_always_ff] = ACTIONS(6241),
    [anon_sym_final] = ACTIONS(6241),
    [anon_sym_while] = ACTIONS(6241),
    [anon_sym_global] = ACTIONS(6241),
    [anon_sym_specify] = ACTIONS(6241),
    [anon_sym_LPAREN_STAR] = ACTIONS(6243),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6243),
    [anon_sym_DOLLARunit] = ACTIONS(6243),
  },
  [1131] = {
    [sym_simple_identifier] = ACTIONS(6245),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6247),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6247),
    [anon_sym_BQUOTE] = ACTIONS(6245),
    [aux_sym_id_directive_token1] = ACTIONS(6247),
    [aux_sym_id_directive_token2] = ACTIONS(6247),
    [aux_sym_id_directive_token3] = ACTIONS(6247),
    [aux_sym_id_directive_token4] = ACTIONS(6245),
    [aux_sym_zero_directive_token1] = ACTIONS(6247),
    [aux_sym_zero_directive_token2] = ACTIONS(6247),
    [aux_sym_zero_directive_token3] = ACTIONS(6247),
    [aux_sym_zero_directive_token4] = ACTIONS(6247),
    [aux_sym_zero_directive_token5] = ACTIONS(6247),
    [aux_sym_zero_directive_token6] = ACTIONS(6247),
    [aux_sym_zero_directive_token7] = ACTIONS(6247),
    [aux_sym_zero_directive_token8] = ACTIONS(6247),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6247),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6247),
    [anon_sym_wire] = ACTIONS(6245),
    [anon_sym_tri] = ACTIONS(6245),
    [anon_sym_tri0] = ACTIONS(6245),
    [anon_sym_tri1] = ACTIONS(6245),
    [anon_sym_wand] = ACTIONS(6245),
    [anon_sym_triand] = ACTIONS(6245),
    [anon_sym_wor] = ACTIONS(6245),
    [anon_sym_trior] = ACTIONS(6245),
    [anon_sym_trireg] = ACTIONS(6245),
    [anon_sym_uwire] = ACTIONS(6245),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6247),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6247),
    [aux_sym_begin_keywords_token1] = ACTIONS(6247),
    [anon_sym_SEMI] = ACTIONS(6247),
    [anon_sym_endmodule] = ACTIONS(6245),
    [anon_sym_extern] = ACTIONS(6245),
    [anon_sym_module] = ACTIONS(6245),
    [anon_sym_macromodule] = ACTIONS(6245),
    [anon_sym_endinterface] = ACTIONS(6245),
    [anon_sym_interface] = ACTIONS(6245),
    [anon_sym_endprogram] = ACTIONS(6245),
    [anon_sym_program] = ACTIONS(6245),
    [anon_sym_checker] = ACTIONS(6245),
    [anon_sym_virtual] = ACTIONS(6245),
    [anon_sym_class] = ACTIONS(6245),
    [anon_sym_timeunit] = ACTIONS(6245),
    [anon_sym_timeprecision] = ACTIONS(6245),
    [anon_sym_type] = ACTIONS(6245),
    [anon_sym_input] = ACTIONS(6245),
    [anon_sym_output] = ACTIONS(6245),
    [anon_sym_inout] = ACTIONS(6245),
    [anon_sym_ref] = ACTIONS(6245),
    [anon_sym_DOLLARfatal] = ACTIONS(6247),
    [anon_sym_DOLLARerror] = ACTIONS(6247),
    [anon_sym_DOLLARwarning] = ACTIONS(6247),
    [anon_sym_DOLLARinfo] = ACTIONS(6247),
    [anon_sym_default] = ACTIONS(6245),
    [anon_sym_clocking] = ACTIONS(6245),
    [anon_sym_defparam] = ACTIONS(6245),
    [anon_sym_bind] = ACTIONS(6245),
    [anon_sym_const] = ACTIONS(6245),
    [anon_sym_function] = ACTIONS(6245),
    [anon_sym_static] = ACTIONS(6245),
    [anon_sym_constraint] = ACTIONS(6245),
    [anon_sym_if] = ACTIONS(6245),
    [anon_sym_else] = ACTIONS(6245),
    [anon_sym_LBRACK] = ACTIONS(6247),
    [anon_sym_localparam] = ACTIONS(6245),
    [anon_sym_parameter] = ACTIONS(6245),
    [anon_sym_specparam] = ACTIONS(6245),
    [anon_sym_var] = ACTIONS(6245),
    [anon_sym_import] = ACTIONS(6245),
    [anon_sym_export] = ACTIONS(6245),
    [anon_sym_genvar] = ACTIONS(6245),
    [anon_sym_interconnect] = ACTIONS(6245),
    [anon_sym_typedef] = ACTIONS(6245),
    [anon_sym_enum] = ACTIONS(6245),
    [anon_sym_struct] = ACTIONS(6245),
    [anon_sym_union] = ACTIONS(6245),
    [anon_sym_nettype] = ACTIONS(6245),
    [anon_sym_automatic] = ACTIONS(6245),
    [anon_sym_string] = ACTIONS(6245),
    [anon_sym_chandle] = ACTIONS(6245),
    [anon_sym_event] = ACTIONS(6245),
    [anon_sym_byte] = ACTIONS(6245),
    [anon_sym_shortint] = ACTIONS(6245),
    [anon_sym_int] = ACTIONS(6245),
    [anon_sym_longint] = ACTIONS(6245),
    [anon_sym_integer] = ACTIONS(6245),
    [anon_sym_time] = ACTIONS(6245),
    [anon_sym_bit] = ACTIONS(6245),
    [anon_sym_logic] = ACTIONS(6245),
    [anon_sym_reg] = ACTIONS(6245),
    [anon_sym_shortreal] = ACTIONS(6245),
    [anon_sym_real] = ACTIONS(6245),
    [anon_sym_realtime] = ACTIONS(6245),
    [anon_sym_supply0] = ACTIONS(6245),
    [anon_sym_supply1] = ACTIONS(6245),
    [anon_sym_signed] = ACTIONS(6245),
    [anon_sym_unsigned] = ACTIONS(6245),
    [anon_sym_task] = ACTIONS(6245),
    [anon_sym_modport] = ACTIONS(6245),
    [anon_sym_assert] = ACTIONS(6245),
    [anon_sym_property] = ACTIONS(6245),
    [anon_sym_assume] = ACTIONS(6245),
    [anon_sym_cover] = ACTIONS(6245),
    [anon_sym_sequence] = ACTIONS(6245),
    [anon_sym_restrict] = ACTIONS(6245),
    [anon_sym_not] = ACTIONS(6245),
    [anon_sym_or] = ACTIONS(6245),
    [anon_sym_and] = ACTIONS(6245),
    [anon_sym_case] = ACTIONS(6245),
    [anon_sym_always] = ACTIONS(6245),
    [anon_sym_covergroup] = ACTIONS(6245),
    [anon_sym_let] = ACTIONS(6245),
    [anon_sym_pulldown] = ACTIONS(6245),
    [anon_sym_pullup] = ACTIONS(6245),
    [anon_sym_cmos] = ACTIONS(6245),
    [anon_sym_rcmos] = ACTIONS(6245),
    [anon_sym_bufif0] = ACTIONS(6245),
    [anon_sym_bufif1] = ACTIONS(6245),
    [anon_sym_notif0] = ACTIONS(6245),
    [anon_sym_notif1] = ACTIONS(6245),
    [anon_sym_nmos] = ACTIONS(6245),
    [anon_sym_pmos] = ACTIONS(6245),
    [anon_sym_rnmos] = ACTIONS(6245),
    [anon_sym_rpmos] = ACTIONS(6245),
    [anon_sym_nand] = ACTIONS(6245),
    [anon_sym_nor] = ACTIONS(6245),
    [anon_sym_xor] = ACTIONS(6245),
    [anon_sym_xnor] = ACTIONS(6245),
    [anon_sym_buf] = ACTIONS(6245),
    [anon_sym_tranif0] = ACTIONS(6245),
    [anon_sym_tranif1] = ACTIONS(6245),
    [anon_sym_rtranif1] = ACTIONS(6245),
    [anon_sym_rtranif0] = ACTIONS(6245),
    [anon_sym_tran] = ACTIONS(6245),
    [anon_sym_rtran] = ACTIONS(6245),
    [anon_sym_generate] = ACTIONS(6245),
    [anon_sym_for] = ACTIONS(6245),
    [anon_sym_initial] = ACTIONS(6245),
    [anon_sym_assign] = ACTIONS(6245),
    [anon_sym_alias] = ACTIONS(6245),
    [anon_sym_always_comb] = ACTIONS(6245),
    [anon_sym_always_latch] = ACTIONS(6245),
    [anon_sym_always_ff] = ACTIONS(6245),
    [anon_sym_final] = ACTIONS(6245),
    [anon_sym_while] = ACTIONS(6245),
    [anon_sym_global] = ACTIONS(6245),
    [anon_sym_specify] = ACTIONS(6245),
    [anon_sym_LPAREN_STAR] = ACTIONS(6247),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6247),
    [anon_sym_DOLLARunit] = ACTIONS(6247),
  },
  [1132] = {
    [sym_simple_identifier] = ACTIONS(6249),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6251),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6251),
    [anon_sym_BQUOTE] = ACTIONS(6249),
    [aux_sym_id_directive_token1] = ACTIONS(6251),
    [aux_sym_id_directive_token2] = ACTIONS(6251),
    [aux_sym_id_directive_token3] = ACTIONS(6251),
    [aux_sym_id_directive_token4] = ACTIONS(6249),
    [aux_sym_zero_directive_token1] = ACTIONS(6251),
    [aux_sym_zero_directive_token2] = ACTIONS(6251),
    [aux_sym_zero_directive_token3] = ACTIONS(6251),
    [aux_sym_zero_directive_token4] = ACTIONS(6251),
    [aux_sym_zero_directive_token5] = ACTIONS(6251),
    [aux_sym_zero_directive_token6] = ACTIONS(6251),
    [aux_sym_zero_directive_token7] = ACTIONS(6251),
    [aux_sym_zero_directive_token8] = ACTIONS(6251),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6251),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6251),
    [anon_sym_wire] = ACTIONS(6249),
    [anon_sym_tri] = ACTIONS(6249),
    [anon_sym_tri0] = ACTIONS(6249),
    [anon_sym_tri1] = ACTIONS(6249),
    [anon_sym_wand] = ACTIONS(6249),
    [anon_sym_triand] = ACTIONS(6249),
    [anon_sym_wor] = ACTIONS(6249),
    [anon_sym_trior] = ACTIONS(6249),
    [anon_sym_trireg] = ACTIONS(6249),
    [anon_sym_uwire] = ACTIONS(6249),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6251),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6251),
    [aux_sym_begin_keywords_token1] = ACTIONS(6251),
    [anon_sym_SEMI] = ACTIONS(6251),
    [anon_sym_endmodule] = ACTIONS(6249),
    [anon_sym_extern] = ACTIONS(6249),
    [anon_sym_module] = ACTIONS(6249),
    [anon_sym_macromodule] = ACTIONS(6249),
    [anon_sym_endinterface] = ACTIONS(6249),
    [anon_sym_interface] = ACTIONS(6249),
    [anon_sym_endprogram] = ACTIONS(6249),
    [anon_sym_program] = ACTIONS(6249),
    [anon_sym_checker] = ACTIONS(6249),
    [anon_sym_virtual] = ACTIONS(6249),
    [anon_sym_class] = ACTIONS(6249),
    [anon_sym_timeunit] = ACTIONS(6249),
    [anon_sym_timeprecision] = ACTIONS(6249),
    [anon_sym_type] = ACTIONS(6249),
    [anon_sym_input] = ACTIONS(6249),
    [anon_sym_output] = ACTIONS(6249),
    [anon_sym_inout] = ACTIONS(6249),
    [anon_sym_ref] = ACTIONS(6249),
    [anon_sym_DOLLARfatal] = ACTIONS(6251),
    [anon_sym_DOLLARerror] = ACTIONS(6251),
    [anon_sym_DOLLARwarning] = ACTIONS(6251),
    [anon_sym_DOLLARinfo] = ACTIONS(6251),
    [anon_sym_default] = ACTIONS(6249),
    [anon_sym_clocking] = ACTIONS(6249),
    [anon_sym_defparam] = ACTIONS(6249),
    [anon_sym_bind] = ACTIONS(6249),
    [anon_sym_const] = ACTIONS(6249),
    [anon_sym_function] = ACTIONS(6249),
    [anon_sym_static] = ACTIONS(6249),
    [anon_sym_constraint] = ACTIONS(6249),
    [anon_sym_if] = ACTIONS(6249),
    [anon_sym_else] = ACTIONS(6249),
    [anon_sym_LBRACK] = ACTIONS(6251),
    [anon_sym_localparam] = ACTIONS(6249),
    [anon_sym_parameter] = ACTIONS(6249),
    [anon_sym_specparam] = ACTIONS(6249),
    [anon_sym_var] = ACTIONS(6249),
    [anon_sym_import] = ACTIONS(6249),
    [anon_sym_export] = ACTIONS(6249),
    [anon_sym_genvar] = ACTIONS(6249),
    [anon_sym_interconnect] = ACTIONS(6249),
    [anon_sym_typedef] = ACTIONS(6249),
    [anon_sym_enum] = ACTIONS(6249),
    [anon_sym_struct] = ACTIONS(6249),
    [anon_sym_union] = ACTIONS(6249),
    [anon_sym_nettype] = ACTIONS(6249),
    [anon_sym_automatic] = ACTIONS(6249),
    [anon_sym_string] = ACTIONS(6249),
    [anon_sym_chandle] = ACTIONS(6249),
    [anon_sym_event] = ACTIONS(6249),
    [anon_sym_byte] = ACTIONS(6249),
    [anon_sym_shortint] = ACTIONS(6249),
    [anon_sym_int] = ACTIONS(6249),
    [anon_sym_longint] = ACTIONS(6249),
    [anon_sym_integer] = ACTIONS(6249),
    [anon_sym_time] = ACTIONS(6249),
    [anon_sym_bit] = ACTIONS(6249),
    [anon_sym_logic] = ACTIONS(6249),
    [anon_sym_reg] = ACTIONS(6249),
    [anon_sym_shortreal] = ACTIONS(6249),
    [anon_sym_real] = ACTIONS(6249),
    [anon_sym_realtime] = ACTIONS(6249),
    [anon_sym_supply0] = ACTIONS(6249),
    [anon_sym_supply1] = ACTIONS(6249),
    [anon_sym_signed] = ACTIONS(6249),
    [anon_sym_unsigned] = ACTIONS(6249),
    [anon_sym_task] = ACTIONS(6249),
    [anon_sym_modport] = ACTIONS(6249),
    [anon_sym_assert] = ACTIONS(6249),
    [anon_sym_property] = ACTIONS(6249),
    [anon_sym_assume] = ACTIONS(6249),
    [anon_sym_cover] = ACTIONS(6249),
    [anon_sym_sequence] = ACTIONS(6249),
    [anon_sym_restrict] = ACTIONS(6249),
    [anon_sym_not] = ACTIONS(6249),
    [anon_sym_or] = ACTIONS(6249),
    [anon_sym_and] = ACTIONS(6249),
    [anon_sym_case] = ACTIONS(6249),
    [anon_sym_always] = ACTIONS(6249),
    [anon_sym_covergroup] = ACTIONS(6249),
    [anon_sym_let] = ACTIONS(6249),
    [anon_sym_pulldown] = ACTIONS(6249),
    [anon_sym_pullup] = ACTIONS(6249),
    [anon_sym_cmos] = ACTIONS(6249),
    [anon_sym_rcmos] = ACTIONS(6249),
    [anon_sym_bufif0] = ACTIONS(6249),
    [anon_sym_bufif1] = ACTIONS(6249),
    [anon_sym_notif0] = ACTIONS(6249),
    [anon_sym_notif1] = ACTIONS(6249),
    [anon_sym_nmos] = ACTIONS(6249),
    [anon_sym_pmos] = ACTIONS(6249),
    [anon_sym_rnmos] = ACTIONS(6249),
    [anon_sym_rpmos] = ACTIONS(6249),
    [anon_sym_nand] = ACTIONS(6249),
    [anon_sym_nor] = ACTIONS(6249),
    [anon_sym_xor] = ACTIONS(6249),
    [anon_sym_xnor] = ACTIONS(6249),
    [anon_sym_buf] = ACTIONS(6249),
    [anon_sym_tranif0] = ACTIONS(6249),
    [anon_sym_tranif1] = ACTIONS(6249),
    [anon_sym_rtranif1] = ACTIONS(6249),
    [anon_sym_rtranif0] = ACTIONS(6249),
    [anon_sym_tran] = ACTIONS(6249),
    [anon_sym_rtran] = ACTIONS(6249),
    [anon_sym_generate] = ACTIONS(6249),
    [anon_sym_for] = ACTIONS(6249),
    [anon_sym_initial] = ACTIONS(6249),
    [anon_sym_assign] = ACTIONS(6249),
    [anon_sym_alias] = ACTIONS(6249),
    [anon_sym_always_comb] = ACTIONS(6249),
    [anon_sym_always_latch] = ACTIONS(6249),
    [anon_sym_always_ff] = ACTIONS(6249),
    [anon_sym_final] = ACTIONS(6249),
    [anon_sym_while] = ACTIONS(6249),
    [anon_sym_global] = ACTIONS(6249),
    [anon_sym_specify] = ACTIONS(6249),
    [anon_sym_LPAREN_STAR] = ACTIONS(6251),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6251),
    [anon_sym_DOLLARunit] = ACTIONS(6251),
  },
  [1133] = {
    [sym_simple_identifier] = ACTIONS(6253),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6255),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6255),
    [anon_sym_BQUOTE] = ACTIONS(6253),
    [aux_sym_id_directive_token1] = ACTIONS(6255),
    [aux_sym_id_directive_token2] = ACTIONS(6255),
    [aux_sym_id_directive_token3] = ACTIONS(6255),
    [aux_sym_id_directive_token4] = ACTIONS(6253),
    [aux_sym_zero_directive_token1] = ACTIONS(6255),
    [aux_sym_zero_directive_token2] = ACTIONS(6255),
    [aux_sym_zero_directive_token3] = ACTIONS(6255),
    [aux_sym_zero_directive_token4] = ACTIONS(6255),
    [aux_sym_zero_directive_token5] = ACTIONS(6255),
    [aux_sym_zero_directive_token6] = ACTIONS(6255),
    [aux_sym_zero_directive_token7] = ACTIONS(6255),
    [aux_sym_zero_directive_token8] = ACTIONS(6255),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6255),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6255),
    [anon_sym_wire] = ACTIONS(6253),
    [anon_sym_tri] = ACTIONS(6253),
    [anon_sym_tri0] = ACTIONS(6253),
    [anon_sym_tri1] = ACTIONS(6253),
    [anon_sym_wand] = ACTIONS(6253),
    [anon_sym_triand] = ACTIONS(6253),
    [anon_sym_wor] = ACTIONS(6253),
    [anon_sym_trior] = ACTIONS(6253),
    [anon_sym_trireg] = ACTIONS(6253),
    [anon_sym_uwire] = ACTIONS(6253),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6255),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6255),
    [aux_sym_begin_keywords_token1] = ACTIONS(6255),
    [anon_sym_SEMI] = ACTIONS(6255),
    [anon_sym_endmodule] = ACTIONS(6253),
    [anon_sym_extern] = ACTIONS(6253),
    [anon_sym_module] = ACTIONS(6253),
    [anon_sym_macromodule] = ACTIONS(6253),
    [anon_sym_endinterface] = ACTIONS(6253),
    [anon_sym_interface] = ACTIONS(6253),
    [anon_sym_endprogram] = ACTIONS(6253),
    [anon_sym_program] = ACTIONS(6253),
    [anon_sym_checker] = ACTIONS(6253),
    [anon_sym_virtual] = ACTIONS(6253),
    [anon_sym_class] = ACTIONS(6253),
    [anon_sym_timeunit] = ACTIONS(6253),
    [anon_sym_timeprecision] = ACTIONS(6253),
    [anon_sym_type] = ACTIONS(6253),
    [anon_sym_input] = ACTIONS(6253),
    [anon_sym_output] = ACTIONS(6253),
    [anon_sym_inout] = ACTIONS(6253),
    [anon_sym_ref] = ACTIONS(6253),
    [anon_sym_DOLLARfatal] = ACTIONS(6255),
    [anon_sym_DOLLARerror] = ACTIONS(6255),
    [anon_sym_DOLLARwarning] = ACTIONS(6255),
    [anon_sym_DOLLARinfo] = ACTIONS(6255),
    [anon_sym_default] = ACTIONS(6253),
    [anon_sym_clocking] = ACTIONS(6253),
    [anon_sym_defparam] = ACTIONS(6253),
    [anon_sym_bind] = ACTIONS(6253),
    [anon_sym_const] = ACTIONS(6253),
    [anon_sym_function] = ACTIONS(6253),
    [anon_sym_static] = ACTIONS(6253),
    [anon_sym_constraint] = ACTIONS(6253),
    [anon_sym_if] = ACTIONS(6253),
    [anon_sym_else] = ACTIONS(6253),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [anon_sym_localparam] = ACTIONS(6253),
    [anon_sym_parameter] = ACTIONS(6253),
    [anon_sym_specparam] = ACTIONS(6253),
    [anon_sym_var] = ACTIONS(6253),
    [anon_sym_import] = ACTIONS(6253),
    [anon_sym_export] = ACTIONS(6253),
    [anon_sym_genvar] = ACTIONS(6253),
    [anon_sym_interconnect] = ACTIONS(6253),
    [anon_sym_typedef] = ACTIONS(6253),
    [anon_sym_enum] = ACTIONS(6253),
    [anon_sym_struct] = ACTIONS(6253),
    [anon_sym_union] = ACTIONS(6253),
    [anon_sym_nettype] = ACTIONS(6253),
    [anon_sym_automatic] = ACTIONS(6253),
    [anon_sym_string] = ACTIONS(6253),
    [anon_sym_chandle] = ACTIONS(6253),
    [anon_sym_event] = ACTIONS(6253),
    [anon_sym_byte] = ACTIONS(6253),
    [anon_sym_shortint] = ACTIONS(6253),
    [anon_sym_int] = ACTIONS(6253),
    [anon_sym_longint] = ACTIONS(6253),
    [anon_sym_integer] = ACTIONS(6253),
    [anon_sym_time] = ACTIONS(6253),
    [anon_sym_bit] = ACTIONS(6253),
    [anon_sym_logic] = ACTIONS(6253),
    [anon_sym_reg] = ACTIONS(6253),
    [anon_sym_shortreal] = ACTIONS(6253),
    [anon_sym_real] = ACTIONS(6253),
    [anon_sym_realtime] = ACTIONS(6253),
    [anon_sym_supply0] = ACTIONS(6253),
    [anon_sym_supply1] = ACTIONS(6253),
    [anon_sym_signed] = ACTIONS(6253),
    [anon_sym_unsigned] = ACTIONS(6253),
    [anon_sym_task] = ACTIONS(6253),
    [anon_sym_modport] = ACTIONS(6253),
    [anon_sym_assert] = ACTIONS(6253),
    [anon_sym_property] = ACTIONS(6253),
    [anon_sym_assume] = ACTIONS(6253),
    [anon_sym_cover] = ACTIONS(6253),
    [anon_sym_sequence] = ACTIONS(6253),
    [anon_sym_restrict] = ACTIONS(6253),
    [anon_sym_not] = ACTIONS(6253),
    [anon_sym_or] = ACTIONS(6253),
    [anon_sym_and] = ACTIONS(6253),
    [anon_sym_case] = ACTIONS(6253),
    [anon_sym_always] = ACTIONS(6253),
    [anon_sym_covergroup] = ACTIONS(6253),
    [anon_sym_let] = ACTIONS(6253),
    [anon_sym_pulldown] = ACTIONS(6253),
    [anon_sym_pullup] = ACTIONS(6253),
    [anon_sym_cmos] = ACTIONS(6253),
    [anon_sym_rcmos] = ACTIONS(6253),
    [anon_sym_bufif0] = ACTIONS(6253),
    [anon_sym_bufif1] = ACTIONS(6253),
    [anon_sym_notif0] = ACTIONS(6253),
    [anon_sym_notif1] = ACTIONS(6253),
    [anon_sym_nmos] = ACTIONS(6253),
    [anon_sym_pmos] = ACTIONS(6253),
    [anon_sym_rnmos] = ACTIONS(6253),
    [anon_sym_rpmos] = ACTIONS(6253),
    [anon_sym_nand] = ACTIONS(6253),
    [anon_sym_nor] = ACTIONS(6253),
    [anon_sym_xor] = ACTIONS(6253),
    [anon_sym_xnor] = ACTIONS(6253),
    [anon_sym_buf] = ACTIONS(6253),
    [anon_sym_tranif0] = ACTIONS(6253),
    [anon_sym_tranif1] = ACTIONS(6253),
    [anon_sym_rtranif1] = ACTIONS(6253),
    [anon_sym_rtranif0] = ACTIONS(6253),
    [anon_sym_tran] = ACTIONS(6253),
    [anon_sym_rtran] = ACTIONS(6253),
    [anon_sym_generate] = ACTIONS(6253),
    [anon_sym_for] = ACTIONS(6253),
    [anon_sym_initial] = ACTIONS(6253),
    [anon_sym_assign] = ACTIONS(6253),
    [anon_sym_alias] = ACTIONS(6253),
    [anon_sym_always_comb] = ACTIONS(6253),
    [anon_sym_always_latch] = ACTIONS(6253),
    [anon_sym_always_ff] = ACTIONS(6253),
    [anon_sym_final] = ACTIONS(6253),
    [anon_sym_while] = ACTIONS(6253),
    [anon_sym_global] = ACTIONS(6253),
    [anon_sym_specify] = ACTIONS(6253),
    [anon_sym_LPAREN_STAR] = ACTIONS(6255),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6255),
    [anon_sym_DOLLARunit] = ACTIONS(6255),
  },
  [1134] = {
    [sym_simple_identifier] = ACTIONS(6257),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6259),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6259),
    [anon_sym_BQUOTE] = ACTIONS(6257),
    [aux_sym_id_directive_token1] = ACTIONS(6259),
    [aux_sym_id_directive_token2] = ACTIONS(6259),
    [aux_sym_id_directive_token3] = ACTIONS(6259),
    [aux_sym_id_directive_token4] = ACTIONS(6257),
    [aux_sym_zero_directive_token1] = ACTIONS(6259),
    [aux_sym_zero_directive_token2] = ACTIONS(6259),
    [aux_sym_zero_directive_token3] = ACTIONS(6259),
    [aux_sym_zero_directive_token4] = ACTIONS(6259),
    [aux_sym_zero_directive_token5] = ACTIONS(6259),
    [aux_sym_zero_directive_token6] = ACTIONS(6259),
    [aux_sym_zero_directive_token7] = ACTIONS(6259),
    [aux_sym_zero_directive_token8] = ACTIONS(6259),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6259),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6259),
    [anon_sym_wire] = ACTIONS(6257),
    [anon_sym_tri] = ACTIONS(6257),
    [anon_sym_tri0] = ACTIONS(6257),
    [anon_sym_tri1] = ACTIONS(6257),
    [anon_sym_wand] = ACTIONS(6257),
    [anon_sym_triand] = ACTIONS(6257),
    [anon_sym_wor] = ACTIONS(6257),
    [anon_sym_trior] = ACTIONS(6257),
    [anon_sym_trireg] = ACTIONS(6257),
    [anon_sym_uwire] = ACTIONS(6257),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6259),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6259),
    [aux_sym_begin_keywords_token1] = ACTIONS(6259),
    [anon_sym_SEMI] = ACTIONS(6259),
    [anon_sym_endmodule] = ACTIONS(6257),
    [anon_sym_extern] = ACTIONS(6257),
    [anon_sym_module] = ACTIONS(6257),
    [anon_sym_macromodule] = ACTIONS(6257),
    [anon_sym_endinterface] = ACTIONS(6257),
    [anon_sym_interface] = ACTIONS(6257),
    [anon_sym_endprogram] = ACTIONS(6257),
    [anon_sym_program] = ACTIONS(6257),
    [anon_sym_checker] = ACTIONS(6257),
    [anon_sym_virtual] = ACTIONS(6257),
    [anon_sym_class] = ACTIONS(6257),
    [anon_sym_timeunit] = ACTIONS(6257),
    [anon_sym_timeprecision] = ACTIONS(6257),
    [anon_sym_type] = ACTIONS(6257),
    [anon_sym_input] = ACTIONS(6257),
    [anon_sym_output] = ACTIONS(6257),
    [anon_sym_inout] = ACTIONS(6257),
    [anon_sym_ref] = ACTIONS(6257),
    [anon_sym_DOLLARfatal] = ACTIONS(6259),
    [anon_sym_DOLLARerror] = ACTIONS(6259),
    [anon_sym_DOLLARwarning] = ACTIONS(6259),
    [anon_sym_DOLLARinfo] = ACTIONS(6259),
    [anon_sym_default] = ACTIONS(6257),
    [anon_sym_clocking] = ACTIONS(6257),
    [anon_sym_defparam] = ACTIONS(6257),
    [anon_sym_bind] = ACTIONS(6257),
    [anon_sym_const] = ACTIONS(6257),
    [anon_sym_function] = ACTIONS(6257),
    [anon_sym_static] = ACTIONS(6257),
    [anon_sym_constraint] = ACTIONS(6257),
    [anon_sym_if] = ACTIONS(6257),
    [anon_sym_else] = ACTIONS(6257),
    [anon_sym_LBRACK] = ACTIONS(6259),
    [anon_sym_localparam] = ACTIONS(6257),
    [anon_sym_parameter] = ACTIONS(6257),
    [anon_sym_specparam] = ACTIONS(6257),
    [anon_sym_var] = ACTIONS(6257),
    [anon_sym_import] = ACTIONS(6257),
    [anon_sym_export] = ACTIONS(6257),
    [anon_sym_genvar] = ACTIONS(6257),
    [anon_sym_interconnect] = ACTIONS(6257),
    [anon_sym_typedef] = ACTIONS(6257),
    [anon_sym_enum] = ACTIONS(6257),
    [anon_sym_struct] = ACTIONS(6257),
    [anon_sym_union] = ACTIONS(6257),
    [anon_sym_nettype] = ACTIONS(6257),
    [anon_sym_automatic] = ACTIONS(6257),
    [anon_sym_string] = ACTIONS(6257),
    [anon_sym_chandle] = ACTIONS(6257),
    [anon_sym_event] = ACTIONS(6257),
    [anon_sym_byte] = ACTIONS(6257),
    [anon_sym_shortint] = ACTIONS(6257),
    [anon_sym_int] = ACTIONS(6257),
    [anon_sym_longint] = ACTIONS(6257),
    [anon_sym_integer] = ACTIONS(6257),
    [anon_sym_time] = ACTIONS(6257),
    [anon_sym_bit] = ACTIONS(6257),
    [anon_sym_logic] = ACTIONS(6257),
    [anon_sym_reg] = ACTIONS(6257),
    [anon_sym_shortreal] = ACTIONS(6257),
    [anon_sym_real] = ACTIONS(6257),
    [anon_sym_realtime] = ACTIONS(6257),
    [anon_sym_supply0] = ACTIONS(6257),
    [anon_sym_supply1] = ACTIONS(6257),
    [anon_sym_signed] = ACTIONS(6257),
    [anon_sym_unsigned] = ACTIONS(6257),
    [anon_sym_task] = ACTIONS(6257),
    [anon_sym_modport] = ACTIONS(6257),
    [anon_sym_assert] = ACTIONS(6257),
    [anon_sym_property] = ACTIONS(6257),
    [anon_sym_assume] = ACTIONS(6257),
    [anon_sym_cover] = ACTIONS(6257),
    [anon_sym_sequence] = ACTIONS(6257),
    [anon_sym_restrict] = ACTIONS(6257),
    [anon_sym_not] = ACTIONS(6257),
    [anon_sym_or] = ACTIONS(6257),
    [anon_sym_and] = ACTIONS(6257),
    [anon_sym_case] = ACTIONS(6257),
    [anon_sym_always] = ACTIONS(6257),
    [anon_sym_covergroup] = ACTIONS(6257),
    [anon_sym_let] = ACTIONS(6257),
    [anon_sym_pulldown] = ACTIONS(6257),
    [anon_sym_pullup] = ACTIONS(6257),
    [anon_sym_cmos] = ACTIONS(6257),
    [anon_sym_rcmos] = ACTIONS(6257),
    [anon_sym_bufif0] = ACTIONS(6257),
    [anon_sym_bufif1] = ACTIONS(6257),
    [anon_sym_notif0] = ACTIONS(6257),
    [anon_sym_notif1] = ACTIONS(6257),
    [anon_sym_nmos] = ACTIONS(6257),
    [anon_sym_pmos] = ACTIONS(6257),
    [anon_sym_rnmos] = ACTIONS(6257),
    [anon_sym_rpmos] = ACTIONS(6257),
    [anon_sym_nand] = ACTIONS(6257),
    [anon_sym_nor] = ACTIONS(6257),
    [anon_sym_xor] = ACTIONS(6257),
    [anon_sym_xnor] = ACTIONS(6257),
    [anon_sym_buf] = ACTIONS(6257),
    [anon_sym_tranif0] = ACTIONS(6257),
    [anon_sym_tranif1] = ACTIONS(6257),
    [anon_sym_rtranif1] = ACTIONS(6257),
    [anon_sym_rtranif0] = ACTIONS(6257),
    [anon_sym_tran] = ACTIONS(6257),
    [anon_sym_rtran] = ACTIONS(6257),
    [anon_sym_generate] = ACTIONS(6257),
    [anon_sym_for] = ACTIONS(6257),
    [anon_sym_initial] = ACTIONS(6257),
    [anon_sym_assign] = ACTIONS(6257),
    [anon_sym_alias] = ACTIONS(6257),
    [anon_sym_always_comb] = ACTIONS(6257),
    [anon_sym_always_latch] = ACTIONS(6257),
    [anon_sym_always_ff] = ACTIONS(6257),
    [anon_sym_final] = ACTIONS(6257),
    [anon_sym_while] = ACTIONS(6257),
    [anon_sym_global] = ACTIONS(6257),
    [anon_sym_specify] = ACTIONS(6257),
    [anon_sym_LPAREN_STAR] = ACTIONS(6259),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6259),
    [anon_sym_DOLLARunit] = ACTIONS(6259),
  },
  [1135] = {
    [sym_simple_identifier] = ACTIONS(6261),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6263),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6263),
    [anon_sym_BQUOTE] = ACTIONS(6261),
    [aux_sym_id_directive_token1] = ACTIONS(6263),
    [aux_sym_id_directive_token2] = ACTIONS(6263),
    [aux_sym_id_directive_token3] = ACTIONS(6263),
    [aux_sym_id_directive_token4] = ACTIONS(6261),
    [aux_sym_zero_directive_token1] = ACTIONS(6263),
    [aux_sym_zero_directive_token2] = ACTIONS(6263),
    [aux_sym_zero_directive_token3] = ACTIONS(6263),
    [aux_sym_zero_directive_token4] = ACTIONS(6263),
    [aux_sym_zero_directive_token5] = ACTIONS(6263),
    [aux_sym_zero_directive_token6] = ACTIONS(6263),
    [aux_sym_zero_directive_token7] = ACTIONS(6263),
    [aux_sym_zero_directive_token8] = ACTIONS(6263),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6263),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6263),
    [anon_sym_wire] = ACTIONS(6261),
    [anon_sym_tri] = ACTIONS(6261),
    [anon_sym_tri0] = ACTIONS(6261),
    [anon_sym_tri1] = ACTIONS(6261),
    [anon_sym_wand] = ACTIONS(6261),
    [anon_sym_triand] = ACTIONS(6261),
    [anon_sym_wor] = ACTIONS(6261),
    [anon_sym_trior] = ACTIONS(6261),
    [anon_sym_trireg] = ACTIONS(6261),
    [anon_sym_uwire] = ACTIONS(6261),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6263),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6263),
    [aux_sym_begin_keywords_token1] = ACTIONS(6263),
    [anon_sym_SEMI] = ACTIONS(6263),
    [anon_sym_endmodule] = ACTIONS(6261),
    [anon_sym_extern] = ACTIONS(6261),
    [anon_sym_module] = ACTIONS(6261),
    [anon_sym_macromodule] = ACTIONS(6261),
    [anon_sym_endinterface] = ACTIONS(6261),
    [anon_sym_interface] = ACTIONS(6261),
    [anon_sym_endprogram] = ACTIONS(6261),
    [anon_sym_program] = ACTIONS(6261),
    [anon_sym_checker] = ACTIONS(6261),
    [anon_sym_virtual] = ACTIONS(6261),
    [anon_sym_class] = ACTIONS(6261),
    [anon_sym_timeunit] = ACTIONS(6261),
    [anon_sym_timeprecision] = ACTIONS(6261),
    [anon_sym_type] = ACTIONS(6261),
    [anon_sym_input] = ACTIONS(6261),
    [anon_sym_output] = ACTIONS(6261),
    [anon_sym_inout] = ACTIONS(6261),
    [anon_sym_ref] = ACTIONS(6261),
    [anon_sym_DOLLARfatal] = ACTIONS(6263),
    [anon_sym_DOLLARerror] = ACTIONS(6263),
    [anon_sym_DOLLARwarning] = ACTIONS(6263),
    [anon_sym_DOLLARinfo] = ACTIONS(6263),
    [anon_sym_default] = ACTIONS(6261),
    [anon_sym_clocking] = ACTIONS(6261),
    [anon_sym_defparam] = ACTIONS(6261),
    [anon_sym_bind] = ACTIONS(6261),
    [anon_sym_const] = ACTIONS(6261),
    [anon_sym_function] = ACTIONS(6261),
    [anon_sym_static] = ACTIONS(6261),
    [anon_sym_constraint] = ACTIONS(6261),
    [anon_sym_if] = ACTIONS(6261),
    [anon_sym_else] = ACTIONS(6261),
    [anon_sym_LBRACK] = ACTIONS(6263),
    [anon_sym_localparam] = ACTIONS(6261),
    [anon_sym_parameter] = ACTIONS(6261),
    [anon_sym_specparam] = ACTIONS(6261),
    [anon_sym_var] = ACTIONS(6261),
    [anon_sym_import] = ACTIONS(6261),
    [anon_sym_export] = ACTIONS(6261),
    [anon_sym_genvar] = ACTIONS(6261),
    [anon_sym_interconnect] = ACTIONS(6261),
    [anon_sym_typedef] = ACTIONS(6261),
    [anon_sym_enum] = ACTIONS(6261),
    [anon_sym_struct] = ACTIONS(6261),
    [anon_sym_union] = ACTIONS(6261),
    [anon_sym_nettype] = ACTIONS(6261),
    [anon_sym_automatic] = ACTIONS(6261),
    [anon_sym_string] = ACTIONS(6261),
    [anon_sym_chandle] = ACTIONS(6261),
    [anon_sym_event] = ACTIONS(6261),
    [anon_sym_byte] = ACTIONS(6261),
    [anon_sym_shortint] = ACTIONS(6261),
    [anon_sym_int] = ACTIONS(6261),
    [anon_sym_longint] = ACTIONS(6261),
    [anon_sym_integer] = ACTIONS(6261),
    [anon_sym_time] = ACTIONS(6261),
    [anon_sym_bit] = ACTIONS(6261),
    [anon_sym_logic] = ACTIONS(6261),
    [anon_sym_reg] = ACTIONS(6261),
    [anon_sym_shortreal] = ACTIONS(6261),
    [anon_sym_real] = ACTIONS(6261),
    [anon_sym_realtime] = ACTIONS(6261),
    [anon_sym_supply0] = ACTIONS(6261),
    [anon_sym_supply1] = ACTIONS(6261),
    [anon_sym_signed] = ACTIONS(6261),
    [anon_sym_unsigned] = ACTIONS(6261),
    [anon_sym_task] = ACTIONS(6261),
    [anon_sym_modport] = ACTIONS(6261),
    [anon_sym_assert] = ACTIONS(6261),
    [anon_sym_property] = ACTIONS(6261),
    [anon_sym_assume] = ACTIONS(6261),
    [anon_sym_cover] = ACTIONS(6261),
    [anon_sym_sequence] = ACTIONS(6261),
    [anon_sym_restrict] = ACTIONS(6261),
    [anon_sym_not] = ACTIONS(6261),
    [anon_sym_or] = ACTIONS(6261),
    [anon_sym_and] = ACTIONS(6261),
    [anon_sym_case] = ACTIONS(6261),
    [anon_sym_always] = ACTIONS(6261),
    [anon_sym_covergroup] = ACTIONS(6261),
    [anon_sym_let] = ACTIONS(6261),
    [anon_sym_pulldown] = ACTIONS(6261),
    [anon_sym_pullup] = ACTIONS(6261),
    [anon_sym_cmos] = ACTIONS(6261),
    [anon_sym_rcmos] = ACTIONS(6261),
    [anon_sym_bufif0] = ACTIONS(6261),
    [anon_sym_bufif1] = ACTIONS(6261),
    [anon_sym_notif0] = ACTIONS(6261),
    [anon_sym_notif1] = ACTIONS(6261),
    [anon_sym_nmos] = ACTIONS(6261),
    [anon_sym_pmos] = ACTIONS(6261),
    [anon_sym_rnmos] = ACTIONS(6261),
    [anon_sym_rpmos] = ACTIONS(6261),
    [anon_sym_nand] = ACTIONS(6261),
    [anon_sym_nor] = ACTIONS(6261),
    [anon_sym_xor] = ACTIONS(6261),
    [anon_sym_xnor] = ACTIONS(6261),
    [anon_sym_buf] = ACTIONS(6261),
    [anon_sym_tranif0] = ACTIONS(6261),
    [anon_sym_tranif1] = ACTIONS(6261),
    [anon_sym_rtranif1] = ACTIONS(6261),
    [anon_sym_rtranif0] = ACTIONS(6261),
    [anon_sym_tran] = ACTIONS(6261),
    [anon_sym_rtran] = ACTIONS(6261),
    [anon_sym_generate] = ACTIONS(6261),
    [anon_sym_for] = ACTIONS(6261),
    [anon_sym_initial] = ACTIONS(6261),
    [anon_sym_assign] = ACTIONS(6261),
    [anon_sym_alias] = ACTIONS(6261),
    [anon_sym_always_comb] = ACTIONS(6261),
    [anon_sym_always_latch] = ACTIONS(6261),
    [anon_sym_always_ff] = ACTIONS(6261),
    [anon_sym_final] = ACTIONS(6261),
    [anon_sym_while] = ACTIONS(6261),
    [anon_sym_global] = ACTIONS(6261),
    [anon_sym_specify] = ACTIONS(6261),
    [anon_sym_LPAREN_STAR] = ACTIONS(6263),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6263),
    [anon_sym_DOLLARunit] = ACTIONS(6263),
  },
  [1136] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6267),
    [anon_sym_BQUOTE] = ACTIONS(6265),
    [aux_sym_id_directive_token1] = ACTIONS(6267),
    [aux_sym_id_directive_token2] = ACTIONS(6267),
    [aux_sym_id_directive_token3] = ACTIONS(6267),
    [aux_sym_id_directive_token4] = ACTIONS(6265),
    [aux_sym_zero_directive_token1] = ACTIONS(6267),
    [aux_sym_zero_directive_token2] = ACTIONS(6267),
    [aux_sym_zero_directive_token3] = ACTIONS(6267),
    [aux_sym_zero_directive_token4] = ACTIONS(6267),
    [aux_sym_zero_directive_token5] = ACTIONS(6267),
    [aux_sym_zero_directive_token6] = ACTIONS(6267),
    [aux_sym_zero_directive_token7] = ACTIONS(6267),
    [aux_sym_zero_directive_token8] = ACTIONS(6267),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6267),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6267),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_begin_keywords_token1] = ACTIONS(6267),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_endmodule] = ACTIONS(6265),
    [anon_sym_COLON] = ACTIONS(6269),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_module] = ACTIONS(6265),
    [anon_sym_macromodule] = ACTIONS(6265),
    [anon_sym_endinterface] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_endprogram] = ACTIONS(6265),
    [anon_sym_program] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_timeunit] = ACTIONS(6265),
    [anon_sym_timeprecision] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_input] = ACTIONS(6265),
    [anon_sym_output] = ACTIONS(6265),
    [anon_sym_inout] = ACTIONS(6265),
    [anon_sym_ref] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_specparam] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_modport] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_specify] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [1137] = {
    [sym_simple_identifier] = ACTIONS(6271),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6273),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6273),
    [anon_sym_BQUOTE] = ACTIONS(6271),
    [aux_sym_id_directive_token1] = ACTIONS(6273),
    [aux_sym_id_directive_token2] = ACTIONS(6273),
    [aux_sym_id_directive_token3] = ACTIONS(6273),
    [aux_sym_id_directive_token4] = ACTIONS(6271),
    [aux_sym_zero_directive_token1] = ACTIONS(6273),
    [aux_sym_zero_directive_token2] = ACTIONS(6273),
    [aux_sym_zero_directive_token3] = ACTIONS(6273),
    [aux_sym_zero_directive_token4] = ACTIONS(6273),
    [aux_sym_zero_directive_token5] = ACTIONS(6273),
    [aux_sym_zero_directive_token6] = ACTIONS(6273),
    [aux_sym_zero_directive_token7] = ACTIONS(6273),
    [aux_sym_zero_directive_token8] = ACTIONS(6273),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6273),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6273),
    [anon_sym_wire] = ACTIONS(6271),
    [anon_sym_tri] = ACTIONS(6271),
    [anon_sym_tri0] = ACTIONS(6271),
    [anon_sym_tri1] = ACTIONS(6271),
    [anon_sym_wand] = ACTIONS(6271),
    [anon_sym_triand] = ACTIONS(6271),
    [anon_sym_wor] = ACTIONS(6271),
    [anon_sym_trior] = ACTIONS(6271),
    [anon_sym_trireg] = ACTIONS(6271),
    [anon_sym_uwire] = ACTIONS(6271),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6273),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6273),
    [aux_sym_begin_keywords_token1] = ACTIONS(6273),
    [anon_sym_SEMI] = ACTIONS(6273),
    [anon_sym_endmodule] = ACTIONS(6271),
    [anon_sym_extern] = ACTIONS(6271),
    [anon_sym_module] = ACTIONS(6271),
    [anon_sym_macromodule] = ACTIONS(6271),
    [anon_sym_endinterface] = ACTIONS(6271),
    [anon_sym_interface] = ACTIONS(6271),
    [anon_sym_endprogram] = ACTIONS(6271),
    [anon_sym_program] = ACTIONS(6271),
    [anon_sym_checker] = ACTIONS(6271),
    [anon_sym_virtual] = ACTIONS(6271),
    [anon_sym_class] = ACTIONS(6271),
    [anon_sym_timeunit] = ACTIONS(6271),
    [anon_sym_timeprecision] = ACTIONS(6271),
    [anon_sym_type] = ACTIONS(6271),
    [anon_sym_input] = ACTIONS(6271),
    [anon_sym_output] = ACTIONS(6271),
    [anon_sym_inout] = ACTIONS(6271),
    [anon_sym_ref] = ACTIONS(6271),
    [anon_sym_DOLLARfatal] = ACTIONS(6273),
    [anon_sym_DOLLARerror] = ACTIONS(6273),
    [anon_sym_DOLLARwarning] = ACTIONS(6273),
    [anon_sym_DOLLARinfo] = ACTIONS(6273),
    [anon_sym_default] = ACTIONS(6271),
    [anon_sym_clocking] = ACTIONS(6271),
    [anon_sym_defparam] = ACTIONS(6271),
    [anon_sym_bind] = ACTIONS(6271),
    [anon_sym_const] = ACTIONS(6271),
    [anon_sym_function] = ACTIONS(6271),
    [anon_sym_static] = ACTIONS(6271),
    [anon_sym_constraint] = ACTIONS(6271),
    [anon_sym_if] = ACTIONS(6271),
    [anon_sym_else] = ACTIONS(6271),
    [anon_sym_LBRACK] = ACTIONS(6273),
    [anon_sym_localparam] = ACTIONS(6271),
    [anon_sym_parameter] = ACTIONS(6271),
    [anon_sym_specparam] = ACTIONS(6271),
    [anon_sym_var] = ACTIONS(6271),
    [anon_sym_import] = ACTIONS(6271),
    [anon_sym_export] = ACTIONS(6271),
    [anon_sym_genvar] = ACTIONS(6271),
    [anon_sym_interconnect] = ACTIONS(6271),
    [anon_sym_typedef] = ACTIONS(6271),
    [anon_sym_enum] = ACTIONS(6271),
    [anon_sym_struct] = ACTIONS(6271),
    [anon_sym_union] = ACTIONS(6271),
    [anon_sym_nettype] = ACTIONS(6271),
    [anon_sym_automatic] = ACTIONS(6271),
    [anon_sym_string] = ACTIONS(6271),
    [anon_sym_chandle] = ACTIONS(6271),
    [anon_sym_event] = ACTIONS(6271),
    [anon_sym_byte] = ACTIONS(6271),
    [anon_sym_shortint] = ACTIONS(6271),
    [anon_sym_int] = ACTIONS(6271),
    [anon_sym_longint] = ACTIONS(6271),
    [anon_sym_integer] = ACTIONS(6271),
    [anon_sym_time] = ACTIONS(6271),
    [anon_sym_bit] = ACTIONS(6271),
    [anon_sym_logic] = ACTIONS(6271),
    [anon_sym_reg] = ACTIONS(6271),
    [anon_sym_shortreal] = ACTIONS(6271),
    [anon_sym_real] = ACTIONS(6271),
    [anon_sym_realtime] = ACTIONS(6271),
    [anon_sym_supply0] = ACTIONS(6271),
    [anon_sym_supply1] = ACTIONS(6271),
    [anon_sym_signed] = ACTIONS(6271),
    [anon_sym_unsigned] = ACTIONS(6271),
    [anon_sym_task] = ACTIONS(6271),
    [anon_sym_modport] = ACTIONS(6271),
    [anon_sym_assert] = ACTIONS(6271),
    [anon_sym_property] = ACTIONS(6271),
    [anon_sym_assume] = ACTIONS(6271),
    [anon_sym_cover] = ACTIONS(6271),
    [anon_sym_sequence] = ACTIONS(6271),
    [anon_sym_restrict] = ACTIONS(6271),
    [anon_sym_not] = ACTIONS(6271),
    [anon_sym_or] = ACTIONS(6271),
    [anon_sym_and] = ACTIONS(6271),
    [anon_sym_case] = ACTIONS(6271),
    [anon_sym_always] = ACTIONS(6271),
    [anon_sym_covergroup] = ACTIONS(6271),
    [anon_sym_let] = ACTIONS(6271),
    [anon_sym_pulldown] = ACTIONS(6271),
    [anon_sym_pullup] = ACTIONS(6271),
    [anon_sym_cmos] = ACTIONS(6271),
    [anon_sym_rcmos] = ACTIONS(6271),
    [anon_sym_bufif0] = ACTIONS(6271),
    [anon_sym_bufif1] = ACTIONS(6271),
    [anon_sym_notif0] = ACTIONS(6271),
    [anon_sym_notif1] = ACTIONS(6271),
    [anon_sym_nmos] = ACTIONS(6271),
    [anon_sym_pmos] = ACTIONS(6271),
    [anon_sym_rnmos] = ACTIONS(6271),
    [anon_sym_rpmos] = ACTIONS(6271),
    [anon_sym_nand] = ACTIONS(6271),
    [anon_sym_nor] = ACTIONS(6271),
    [anon_sym_xor] = ACTIONS(6271),
    [anon_sym_xnor] = ACTIONS(6271),
    [anon_sym_buf] = ACTIONS(6271),
    [anon_sym_tranif0] = ACTIONS(6271),
    [anon_sym_tranif1] = ACTIONS(6271),
    [anon_sym_rtranif1] = ACTIONS(6271),
    [anon_sym_rtranif0] = ACTIONS(6271),
    [anon_sym_tran] = ACTIONS(6271),
    [anon_sym_rtran] = ACTIONS(6271),
    [anon_sym_generate] = ACTIONS(6271),
    [anon_sym_for] = ACTIONS(6271),
    [anon_sym_initial] = ACTIONS(6271),
    [anon_sym_assign] = ACTIONS(6271),
    [anon_sym_alias] = ACTIONS(6271),
    [anon_sym_always_comb] = ACTIONS(6271),
    [anon_sym_always_latch] = ACTIONS(6271),
    [anon_sym_always_ff] = ACTIONS(6271),
    [anon_sym_final] = ACTIONS(6271),
    [anon_sym_while] = ACTIONS(6271),
    [anon_sym_global] = ACTIONS(6271),
    [anon_sym_specify] = ACTIONS(6271),
    [anon_sym_LPAREN_STAR] = ACTIONS(6273),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6273),
    [anon_sym_DOLLARunit] = ACTIONS(6273),
  },
  [1138] = {
    [sym_simple_identifier] = ACTIONS(6275),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6277),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6277),
    [anon_sym_BQUOTE] = ACTIONS(6275),
    [aux_sym_id_directive_token1] = ACTIONS(6277),
    [aux_sym_id_directive_token2] = ACTIONS(6277),
    [aux_sym_id_directive_token3] = ACTIONS(6277),
    [aux_sym_id_directive_token4] = ACTIONS(6275),
    [aux_sym_zero_directive_token1] = ACTIONS(6277),
    [aux_sym_zero_directive_token2] = ACTIONS(6277),
    [aux_sym_zero_directive_token3] = ACTIONS(6277),
    [aux_sym_zero_directive_token4] = ACTIONS(6277),
    [aux_sym_zero_directive_token5] = ACTIONS(6277),
    [aux_sym_zero_directive_token6] = ACTIONS(6277),
    [aux_sym_zero_directive_token7] = ACTIONS(6277),
    [aux_sym_zero_directive_token8] = ACTIONS(6277),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6277),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6277),
    [anon_sym_wire] = ACTIONS(6275),
    [anon_sym_tri] = ACTIONS(6275),
    [anon_sym_tri0] = ACTIONS(6275),
    [anon_sym_tri1] = ACTIONS(6275),
    [anon_sym_wand] = ACTIONS(6275),
    [anon_sym_triand] = ACTIONS(6275),
    [anon_sym_wor] = ACTIONS(6275),
    [anon_sym_trior] = ACTIONS(6275),
    [anon_sym_trireg] = ACTIONS(6275),
    [anon_sym_uwire] = ACTIONS(6275),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6277),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6277),
    [aux_sym_begin_keywords_token1] = ACTIONS(6277),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym_endmodule] = ACTIONS(6275),
    [anon_sym_extern] = ACTIONS(6275),
    [anon_sym_module] = ACTIONS(6275),
    [anon_sym_macromodule] = ACTIONS(6275),
    [anon_sym_endinterface] = ACTIONS(6275),
    [anon_sym_interface] = ACTIONS(6275),
    [anon_sym_endprogram] = ACTIONS(6275),
    [anon_sym_program] = ACTIONS(6275),
    [anon_sym_checker] = ACTIONS(6275),
    [anon_sym_virtual] = ACTIONS(6275),
    [anon_sym_class] = ACTIONS(6275),
    [anon_sym_timeunit] = ACTIONS(6275),
    [anon_sym_timeprecision] = ACTIONS(6275),
    [anon_sym_type] = ACTIONS(6275),
    [anon_sym_input] = ACTIONS(6275),
    [anon_sym_output] = ACTIONS(6275),
    [anon_sym_inout] = ACTIONS(6275),
    [anon_sym_ref] = ACTIONS(6275),
    [anon_sym_DOLLARfatal] = ACTIONS(6277),
    [anon_sym_DOLLARerror] = ACTIONS(6277),
    [anon_sym_DOLLARwarning] = ACTIONS(6277),
    [anon_sym_DOLLARinfo] = ACTIONS(6277),
    [anon_sym_default] = ACTIONS(6275),
    [anon_sym_clocking] = ACTIONS(6275),
    [anon_sym_defparam] = ACTIONS(6275),
    [anon_sym_bind] = ACTIONS(6275),
    [anon_sym_const] = ACTIONS(6275),
    [anon_sym_function] = ACTIONS(6275),
    [anon_sym_static] = ACTIONS(6275),
    [anon_sym_constraint] = ACTIONS(6275),
    [anon_sym_if] = ACTIONS(6275),
    [anon_sym_else] = ACTIONS(6275),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_localparam] = ACTIONS(6275),
    [anon_sym_parameter] = ACTIONS(6275),
    [anon_sym_specparam] = ACTIONS(6275),
    [anon_sym_var] = ACTIONS(6275),
    [anon_sym_import] = ACTIONS(6275),
    [anon_sym_export] = ACTIONS(6275),
    [anon_sym_genvar] = ACTIONS(6275),
    [anon_sym_interconnect] = ACTIONS(6275),
    [anon_sym_typedef] = ACTIONS(6275),
    [anon_sym_enum] = ACTIONS(6275),
    [anon_sym_struct] = ACTIONS(6275),
    [anon_sym_union] = ACTIONS(6275),
    [anon_sym_nettype] = ACTIONS(6275),
    [anon_sym_automatic] = ACTIONS(6275),
    [anon_sym_string] = ACTIONS(6275),
    [anon_sym_chandle] = ACTIONS(6275),
    [anon_sym_event] = ACTIONS(6275),
    [anon_sym_byte] = ACTIONS(6275),
    [anon_sym_shortint] = ACTIONS(6275),
    [anon_sym_int] = ACTIONS(6275),
    [anon_sym_longint] = ACTIONS(6275),
    [anon_sym_integer] = ACTIONS(6275),
    [anon_sym_time] = ACTIONS(6275),
    [anon_sym_bit] = ACTIONS(6275),
    [anon_sym_logic] = ACTIONS(6275),
    [anon_sym_reg] = ACTIONS(6275),
    [anon_sym_shortreal] = ACTIONS(6275),
    [anon_sym_real] = ACTIONS(6275),
    [anon_sym_realtime] = ACTIONS(6275),
    [anon_sym_supply0] = ACTIONS(6275),
    [anon_sym_supply1] = ACTIONS(6275),
    [anon_sym_signed] = ACTIONS(6275),
    [anon_sym_unsigned] = ACTIONS(6275),
    [anon_sym_task] = ACTIONS(6275),
    [anon_sym_modport] = ACTIONS(6275),
    [anon_sym_assert] = ACTIONS(6275),
    [anon_sym_property] = ACTIONS(6275),
    [anon_sym_assume] = ACTIONS(6275),
    [anon_sym_cover] = ACTIONS(6275),
    [anon_sym_sequence] = ACTIONS(6275),
    [anon_sym_restrict] = ACTIONS(6275),
    [anon_sym_not] = ACTIONS(6275),
    [anon_sym_or] = ACTIONS(6275),
    [anon_sym_and] = ACTIONS(6275),
    [anon_sym_case] = ACTIONS(6275),
    [anon_sym_always] = ACTIONS(6275),
    [anon_sym_covergroup] = ACTIONS(6275),
    [anon_sym_let] = ACTIONS(6275),
    [anon_sym_pulldown] = ACTIONS(6275),
    [anon_sym_pullup] = ACTIONS(6275),
    [anon_sym_cmos] = ACTIONS(6275),
    [anon_sym_rcmos] = ACTIONS(6275),
    [anon_sym_bufif0] = ACTIONS(6275),
    [anon_sym_bufif1] = ACTIONS(6275),
    [anon_sym_notif0] = ACTIONS(6275),
    [anon_sym_notif1] = ACTIONS(6275),
    [anon_sym_nmos] = ACTIONS(6275),
    [anon_sym_pmos] = ACTIONS(6275),
    [anon_sym_rnmos] = ACTIONS(6275),
    [anon_sym_rpmos] = ACTIONS(6275),
    [anon_sym_nand] = ACTIONS(6275),
    [anon_sym_nor] = ACTIONS(6275),
    [anon_sym_xor] = ACTIONS(6275),
    [anon_sym_xnor] = ACTIONS(6275),
    [anon_sym_buf] = ACTIONS(6275),
    [anon_sym_tranif0] = ACTIONS(6275),
    [anon_sym_tranif1] = ACTIONS(6275),
    [anon_sym_rtranif1] = ACTIONS(6275),
    [anon_sym_rtranif0] = ACTIONS(6275),
    [anon_sym_tran] = ACTIONS(6275),
    [anon_sym_rtran] = ACTIONS(6275),
    [anon_sym_generate] = ACTIONS(6275),
    [anon_sym_for] = ACTIONS(6275),
    [anon_sym_initial] = ACTIONS(6275),
    [anon_sym_assign] = ACTIONS(6275),
    [anon_sym_alias] = ACTIONS(6275),
    [anon_sym_always_comb] = ACTIONS(6275),
    [anon_sym_always_latch] = ACTIONS(6275),
    [anon_sym_always_ff] = ACTIONS(6275),
    [anon_sym_final] = ACTIONS(6275),
    [anon_sym_while] = ACTIONS(6275),
    [anon_sym_global] = ACTIONS(6275),
    [anon_sym_specify] = ACTIONS(6275),
    [anon_sym_LPAREN_STAR] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6277),
    [anon_sym_DOLLARunit] = ACTIONS(6277),
  },
  [1139] = {
    [sym_simple_identifier] = ACTIONS(6279),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6281),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6281),
    [anon_sym_BQUOTE] = ACTIONS(6279),
    [aux_sym_id_directive_token1] = ACTIONS(6281),
    [aux_sym_id_directive_token2] = ACTIONS(6281),
    [aux_sym_id_directive_token3] = ACTIONS(6281),
    [aux_sym_id_directive_token4] = ACTIONS(6279),
    [aux_sym_zero_directive_token1] = ACTIONS(6281),
    [aux_sym_zero_directive_token2] = ACTIONS(6281),
    [aux_sym_zero_directive_token3] = ACTIONS(6281),
    [aux_sym_zero_directive_token4] = ACTIONS(6281),
    [aux_sym_zero_directive_token5] = ACTIONS(6281),
    [aux_sym_zero_directive_token6] = ACTIONS(6281),
    [aux_sym_zero_directive_token7] = ACTIONS(6281),
    [aux_sym_zero_directive_token8] = ACTIONS(6281),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6281),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6281),
    [anon_sym_wire] = ACTIONS(6279),
    [anon_sym_tri] = ACTIONS(6279),
    [anon_sym_tri0] = ACTIONS(6279),
    [anon_sym_tri1] = ACTIONS(6279),
    [anon_sym_wand] = ACTIONS(6279),
    [anon_sym_triand] = ACTIONS(6279),
    [anon_sym_wor] = ACTIONS(6279),
    [anon_sym_trior] = ACTIONS(6279),
    [anon_sym_trireg] = ACTIONS(6279),
    [anon_sym_uwire] = ACTIONS(6279),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6281),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6281),
    [aux_sym_begin_keywords_token1] = ACTIONS(6281),
    [anon_sym_SEMI] = ACTIONS(6281),
    [anon_sym_endmodule] = ACTIONS(6279),
    [anon_sym_extern] = ACTIONS(6279),
    [anon_sym_module] = ACTIONS(6279),
    [anon_sym_macromodule] = ACTIONS(6279),
    [anon_sym_endinterface] = ACTIONS(6279),
    [anon_sym_interface] = ACTIONS(6279),
    [anon_sym_endprogram] = ACTIONS(6279),
    [anon_sym_program] = ACTIONS(6279),
    [anon_sym_checker] = ACTIONS(6279),
    [anon_sym_virtual] = ACTIONS(6279),
    [anon_sym_class] = ACTIONS(6279),
    [anon_sym_timeunit] = ACTIONS(6279),
    [anon_sym_timeprecision] = ACTIONS(6279),
    [anon_sym_type] = ACTIONS(6279),
    [anon_sym_input] = ACTIONS(6279),
    [anon_sym_output] = ACTIONS(6279),
    [anon_sym_inout] = ACTIONS(6279),
    [anon_sym_ref] = ACTIONS(6279),
    [anon_sym_DOLLARfatal] = ACTIONS(6281),
    [anon_sym_DOLLARerror] = ACTIONS(6281),
    [anon_sym_DOLLARwarning] = ACTIONS(6281),
    [anon_sym_DOLLARinfo] = ACTIONS(6281),
    [anon_sym_default] = ACTIONS(6279),
    [anon_sym_clocking] = ACTIONS(6279),
    [anon_sym_defparam] = ACTIONS(6279),
    [anon_sym_bind] = ACTIONS(6279),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_function] = ACTIONS(6279),
    [anon_sym_static] = ACTIONS(6279),
    [anon_sym_constraint] = ACTIONS(6279),
    [anon_sym_if] = ACTIONS(6279),
    [anon_sym_else] = ACTIONS(6279),
    [anon_sym_LBRACK] = ACTIONS(6281),
    [anon_sym_localparam] = ACTIONS(6279),
    [anon_sym_parameter] = ACTIONS(6279),
    [anon_sym_specparam] = ACTIONS(6279),
    [anon_sym_var] = ACTIONS(6279),
    [anon_sym_import] = ACTIONS(6279),
    [anon_sym_export] = ACTIONS(6279),
    [anon_sym_genvar] = ACTIONS(6279),
    [anon_sym_interconnect] = ACTIONS(6279),
    [anon_sym_typedef] = ACTIONS(6279),
    [anon_sym_enum] = ACTIONS(6279),
    [anon_sym_struct] = ACTIONS(6279),
    [anon_sym_union] = ACTIONS(6279),
    [anon_sym_nettype] = ACTIONS(6279),
    [anon_sym_automatic] = ACTIONS(6279),
    [anon_sym_string] = ACTIONS(6279),
    [anon_sym_chandle] = ACTIONS(6279),
    [anon_sym_event] = ACTIONS(6279),
    [anon_sym_byte] = ACTIONS(6279),
    [anon_sym_shortint] = ACTIONS(6279),
    [anon_sym_int] = ACTIONS(6279),
    [anon_sym_longint] = ACTIONS(6279),
    [anon_sym_integer] = ACTIONS(6279),
    [anon_sym_time] = ACTIONS(6279),
    [anon_sym_bit] = ACTIONS(6279),
    [anon_sym_logic] = ACTIONS(6279),
    [anon_sym_reg] = ACTIONS(6279),
    [anon_sym_shortreal] = ACTIONS(6279),
    [anon_sym_real] = ACTIONS(6279),
    [anon_sym_realtime] = ACTIONS(6279),
    [anon_sym_supply0] = ACTIONS(6279),
    [anon_sym_supply1] = ACTIONS(6279),
    [anon_sym_signed] = ACTIONS(6279),
    [anon_sym_unsigned] = ACTIONS(6279),
    [anon_sym_task] = ACTIONS(6279),
    [anon_sym_modport] = ACTIONS(6279),
    [anon_sym_assert] = ACTIONS(6279),
    [anon_sym_property] = ACTIONS(6279),
    [anon_sym_assume] = ACTIONS(6279),
    [anon_sym_cover] = ACTIONS(6279),
    [anon_sym_sequence] = ACTIONS(6279),
    [anon_sym_restrict] = ACTIONS(6279),
    [anon_sym_not] = ACTIONS(6279),
    [anon_sym_or] = ACTIONS(6279),
    [anon_sym_and] = ACTIONS(6279),
    [anon_sym_case] = ACTIONS(6279),
    [anon_sym_always] = ACTIONS(6279),
    [anon_sym_covergroup] = ACTIONS(6279),
    [anon_sym_let] = ACTIONS(6279),
    [anon_sym_pulldown] = ACTIONS(6279),
    [anon_sym_pullup] = ACTIONS(6279),
    [anon_sym_cmos] = ACTIONS(6279),
    [anon_sym_rcmos] = ACTIONS(6279),
    [anon_sym_bufif0] = ACTIONS(6279),
    [anon_sym_bufif1] = ACTIONS(6279),
    [anon_sym_notif0] = ACTIONS(6279),
    [anon_sym_notif1] = ACTIONS(6279),
    [anon_sym_nmos] = ACTIONS(6279),
    [anon_sym_pmos] = ACTIONS(6279),
    [anon_sym_rnmos] = ACTIONS(6279),
    [anon_sym_rpmos] = ACTIONS(6279),
    [anon_sym_nand] = ACTIONS(6279),
    [anon_sym_nor] = ACTIONS(6279),
    [anon_sym_xor] = ACTIONS(6279),
    [anon_sym_xnor] = ACTIONS(6279),
    [anon_sym_buf] = ACTIONS(6279),
    [anon_sym_tranif0] = ACTIONS(6279),
    [anon_sym_tranif1] = ACTIONS(6279),
    [anon_sym_rtranif1] = ACTIONS(6279),
    [anon_sym_rtranif0] = ACTIONS(6279),
    [anon_sym_tran] = ACTIONS(6279),
    [anon_sym_rtran] = ACTIONS(6279),
    [anon_sym_generate] = ACTIONS(6279),
    [anon_sym_for] = ACTIONS(6279),
    [anon_sym_initial] = ACTIONS(6279),
    [anon_sym_assign] = ACTIONS(6279),
    [anon_sym_alias] = ACTIONS(6279),
    [anon_sym_always_comb] = ACTIONS(6279),
    [anon_sym_always_latch] = ACTIONS(6279),
    [anon_sym_always_ff] = ACTIONS(6279),
    [anon_sym_final] = ACTIONS(6279),
    [anon_sym_while] = ACTIONS(6279),
    [anon_sym_global] = ACTIONS(6279),
    [anon_sym_specify] = ACTIONS(6279),
    [anon_sym_LPAREN_STAR] = ACTIONS(6281),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6281),
    [anon_sym_DOLLARunit] = ACTIONS(6281),
  },
  [1140] = {
    [sym_simple_identifier] = ACTIONS(6283),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6285),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6285),
    [anon_sym_BQUOTE] = ACTIONS(6283),
    [aux_sym_id_directive_token1] = ACTIONS(6285),
    [aux_sym_id_directive_token2] = ACTIONS(6285),
    [aux_sym_id_directive_token3] = ACTIONS(6285),
    [aux_sym_id_directive_token4] = ACTIONS(6283),
    [aux_sym_zero_directive_token1] = ACTIONS(6285),
    [aux_sym_zero_directive_token2] = ACTIONS(6285),
    [aux_sym_zero_directive_token3] = ACTIONS(6285),
    [aux_sym_zero_directive_token4] = ACTIONS(6285),
    [aux_sym_zero_directive_token5] = ACTIONS(6285),
    [aux_sym_zero_directive_token6] = ACTIONS(6285),
    [aux_sym_zero_directive_token7] = ACTIONS(6285),
    [aux_sym_zero_directive_token8] = ACTIONS(6285),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6285),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6285),
    [anon_sym_wire] = ACTIONS(6283),
    [anon_sym_tri] = ACTIONS(6283),
    [anon_sym_tri0] = ACTIONS(6283),
    [anon_sym_tri1] = ACTIONS(6283),
    [anon_sym_wand] = ACTIONS(6283),
    [anon_sym_triand] = ACTIONS(6283),
    [anon_sym_wor] = ACTIONS(6283),
    [anon_sym_trior] = ACTIONS(6283),
    [anon_sym_trireg] = ACTIONS(6283),
    [anon_sym_uwire] = ACTIONS(6283),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6285),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6285),
    [aux_sym_begin_keywords_token1] = ACTIONS(6285),
    [anon_sym_SEMI] = ACTIONS(6285),
    [anon_sym_endmodule] = ACTIONS(6283),
    [anon_sym_extern] = ACTIONS(6283),
    [anon_sym_module] = ACTIONS(6283),
    [anon_sym_macromodule] = ACTIONS(6283),
    [anon_sym_endinterface] = ACTIONS(6283),
    [anon_sym_interface] = ACTIONS(6283),
    [anon_sym_endprogram] = ACTIONS(6283),
    [anon_sym_program] = ACTIONS(6283),
    [anon_sym_checker] = ACTIONS(6283),
    [anon_sym_virtual] = ACTIONS(6283),
    [anon_sym_class] = ACTIONS(6283),
    [anon_sym_timeunit] = ACTIONS(6283),
    [anon_sym_timeprecision] = ACTIONS(6283),
    [anon_sym_type] = ACTIONS(6283),
    [anon_sym_input] = ACTIONS(6283),
    [anon_sym_output] = ACTIONS(6283),
    [anon_sym_inout] = ACTIONS(6283),
    [anon_sym_ref] = ACTIONS(6283),
    [anon_sym_DOLLARfatal] = ACTIONS(6285),
    [anon_sym_DOLLARerror] = ACTIONS(6285),
    [anon_sym_DOLLARwarning] = ACTIONS(6285),
    [anon_sym_DOLLARinfo] = ACTIONS(6285),
    [anon_sym_default] = ACTIONS(6283),
    [anon_sym_clocking] = ACTIONS(6283),
    [anon_sym_defparam] = ACTIONS(6283),
    [anon_sym_bind] = ACTIONS(6283),
    [anon_sym_const] = ACTIONS(6283),
    [anon_sym_function] = ACTIONS(6283),
    [anon_sym_static] = ACTIONS(6283),
    [anon_sym_constraint] = ACTIONS(6283),
    [anon_sym_if] = ACTIONS(6283),
    [anon_sym_else] = ACTIONS(6283),
    [anon_sym_LBRACK] = ACTIONS(6285),
    [anon_sym_localparam] = ACTIONS(6283),
    [anon_sym_parameter] = ACTIONS(6283),
    [anon_sym_specparam] = ACTIONS(6283),
    [anon_sym_var] = ACTIONS(6283),
    [anon_sym_import] = ACTIONS(6283),
    [anon_sym_export] = ACTIONS(6283),
    [anon_sym_genvar] = ACTIONS(6283),
    [anon_sym_interconnect] = ACTIONS(6283),
    [anon_sym_typedef] = ACTIONS(6283),
    [anon_sym_enum] = ACTIONS(6283),
    [anon_sym_struct] = ACTIONS(6283),
    [anon_sym_union] = ACTIONS(6283),
    [anon_sym_nettype] = ACTIONS(6283),
    [anon_sym_automatic] = ACTIONS(6283),
    [anon_sym_string] = ACTIONS(6283),
    [anon_sym_chandle] = ACTIONS(6283),
    [anon_sym_event] = ACTIONS(6283),
    [anon_sym_byte] = ACTIONS(6283),
    [anon_sym_shortint] = ACTIONS(6283),
    [anon_sym_int] = ACTIONS(6283),
    [anon_sym_longint] = ACTIONS(6283),
    [anon_sym_integer] = ACTIONS(6283),
    [anon_sym_time] = ACTIONS(6283),
    [anon_sym_bit] = ACTIONS(6283),
    [anon_sym_logic] = ACTIONS(6283),
    [anon_sym_reg] = ACTIONS(6283),
    [anon_sym_shortreal] = ACTIONS(6283),
    [anon_sym_real] = ACTIONS(6283),
    [anon_sym_realtime] = ACTIONS(6283),
    [anon_sym_supply0] = ACTIONS(6283),
    [anon_sym_supply1] = ACTIONS(6283),
    [anon_sym_signed] = ACTIONS(6283),
    [anon_sym_unsigned] = ACTIONS(6283),
    [anon_sym_task] = ACTIONS(6283),
    [anon_sym_modport] = ACTIONS(6283),
    [anon_sym_assert] = ACTIONS(6283),
    [anon_sym_property] = ACTIONS(6283),
    [anon_sym_assume] = ACTIONS(6283),
    [anon_sym_cover] = ACTIONS(6283),
    [anon_sym_sequence] = ACTIONS(6283),
    [anon_sym_restrict] = ACTIONS(6283),
    [anon_sym_not] = ACTIONS(6283),
    [anon_sym_or] = ACTIONS(6283),
    [anon_sym_and] = ACTIONS(6283),
    [anon_sym_case] = ACTIONS(6283),
    [anon_sym_always] = ACTIONS(6283),
    [anon_sym_covergroup] = ACTIONS(6283),
    [anon_sym_let] = ACTIONS(6283),
    [anon_sym_pulldown] = ACTIONS(6283),
    [anon_sym_pullup] = ACTIONS(6283),
    [anon_sym_cmos] = ACTIONS(6283),
    [anon_sym_rcmos] = ACTIONS(6283),
    [anon_sym_bufif0] = ACTIONS(6283),
    [anon_sym_bufif1] = ACTIONS(6283),
    [anon_sym_notif0] = ACTIONS(6283),
    [anon_sym_notif1] = ACTIONS(6283),
    [anon_sym_nmos] = ACTIONS(6283),
    [anon_sym_pmos] = ACTIONS(6283),
    [anon_sym_rnmos] = ACTIONS(6283),
    [anon_sym_rpmos] = ACTIONS(6283),
    [anon_sym_nand] = ACTIONS(6283),
    [anon_sym_nor] = ACTIONS(6283),
    [anon_sym_xor] = ACTIONS(6283),
    [anon_sym_xnor] = ACTIONS(6283),
    [anon_sym_buf] = ACTIONS(6283),
    [anon_sym_tranif0] = ACTIONS(6283),
    [anon_sym_tranif1] = ACTIONS(6283),
    [anon_sym_rtranif1] = ACTIONS(6283),
    [anon_sym_rtranif0] = ACTIONS(6283),
    [anon_sym_tran] = ACTIONS(6283),
    [anon_sym_rtran] = ACTIONS(6283),
    [anon_sym_generate] = ACTIONS(6283),
    [anon_sym_for] = ACTIONS(6283),
    [anon_sym_initial] = ACTIONS(6283),
    [anon_sym_assign] = ACTIONS(6283),
    [anon_sym_alias] = ACTIONS(6283),
    [anon_sym_always_comb] = ACTIONS(6283),
    [anon_sym_always_latch] = ACTIONS(6283),
    [anon_sym_always_ff] = ACTIONS(6283),
    [anon_sym_final] = ACTIONS(6283),
    [anon_sym_while] = ACTIONS(6283),
    [anon_sym_global] = ACTIONS(6283),
    [anon_sym_specify] = ACTIONS(6283),
    [anon_sym_LPAREN_STAR] = ACTIONS(6285),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6285),
    [anon_sym_DOLLARunit] = ACTIONS(6285),
  },
  [1141] = {
    [sym_simple_identifier] = ACTIONS(6287),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6289),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6289),
    [anon_sym_BQUOTE] = ACTIONS(6287),
    [aux_sym_id_directive_token1] = ACTIONS(6289),
    [aux_sym_id_directive_token2] = ACTIONS(6289),
    [aux_sym_id_directive_token3] = ACTIONS(6289),
    [aux_sym_id_directive_token4] = ACTIONS(6287),
    [aux_sym_zero_directive_token1] = ACTIONS(6289),
    [aux_sym_zero_directive_token2] = ACTIONS(6289),
    [aux_sym_zero_directive_token3] = ACTIONS(6289),
    [aux_sym_zero_directive_token4] = ACTIONS(6289),
    [aux_sym_zero_directive_token5] = ACTIONS(6289),
    [aux_sym_zero_directive_token6] = ACTIONS(6289),
    [aux_sym_zero_directive_token7] = ACTIONS(6289),
    [aux_sym_zero_directive_token8] = ACTIONS(6289),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6289),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6289),
    [anon_sym_wire] = ACTIONS(6287),
    [anon_sym_tri] = ACTIONS(6287),
    [anon_sym_tri0] = ACTIONS(6287),
    [anon_sym_tri1] = ACTIONS(6287),
    [anon_sym_wand] = ACTIONS(6287),
    [anon_sym_triand] = ACTIONS(6287),
    [anon_sym_wor] = ACTIONS(6287),
    [anon_sym_trior] = ACTIONS(6287),
    [anon_sym_trireg] = ACTIONS(6287),
    [anon_sym_uwire] = ACTIONS(6287),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6289),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6289),
    [aux_sym_begin_keywords_token1] = ACTIONS(6289),
    [anon_sym_SEMI] = ACTIONS(6289),
    [anon_sym_endmodule] = ACTIONS(6287),
    [anon_sym_extern] = ACTIONS(6287),
    [anon_sym_module] = ACTIONS(6287),
    [anon_sym_macromodule] = ACTIONS(6287),
    [anon_sym_endinterface] = ACTIONS(6287),
    [anon_sym_interface] = ACTIONS(6287),
    [anon_sym_endprogram] = ACTIONS(6287),
    [anon_sym_program] = ACTIONS(6287),
    [anon_sym_checker] = ACTIONS(6287),
    [anon_sym_virtual] = ACTIONS(6287),
    [anon_sym_class] = ACTIONS(6287),
    [anon_sym_timeunit] = ACTIONS(6287),
    [anon_sym_timeprecision] = ACTIONS(6287),
    [anon_sym_type] = ACTIONS(6287),
    [anon_sym_input] = ACTIONS(6287),
    [anon_sym_output] = ACTIONS(6287),
    [anon_sym_inout] = ACTIONS(6287),
    [anon_sym_ref] = ACTIONS(6287),
    [anon_sym_DOLLARfatal] = ACTIONS(6289),
    [anon_sym_DOLLARerror] = ACTIONS(6289),
    [anon_sym_DOLLARwarning] = ACTIONS(6289),
    [anon_sym_DOLLARinfo] = ACTIONS(6289),
    [anon_sym_default] = ACTIONS(6287),
    [anon_sym_clocking] = ACTIONS(6287),
    [anon_sym_defparam] = ACTIONS(6287),
    [anon_sym_bind] = ACTIONS(6287),
    [anon_sym_const] = ACTIONS(6287),
    [anon_sym_function] = ACTIONS(6287),
    [anon_sym_static] = ACTIONS(6287),
    [anon_sym_constraint] = ACTIONS(6287),
    [anon_sym_if] = ACTIONS(6287),
    [anon_sym_else] = ACTIONS(6287),
    [anon_sym_LBRACK] = ACTIONS(6289),
    [anon_sym_localparam] = ACTIONS(6287),
    [anon_sym_parameter] = ACTIONS(6287),
    [anon_sym_specparam] = ACTIONS(6287),
    [anon_sym_var] = ACTIONS(6287),
    [anon_sym_import] = ACTIONS(6287),
    [anon_sym_export] = ACTIONS(6287),
    [anon_sym_genvar] = ACTIONS(6287),
    [anon_sym_interconnect] = ACTIONS(6287),
    [anon_sym_typedef] = ACTIONS(6287),
    [anon_sym_enum] = ACTIONS(6287),
    [anon_sym_struct] = ACTIONS(6287),
    [anon_sym_union] = ACTIONS(6287),
    [anon_sym_nettype] = ACTIONS(6287),
    [anon_sym_automatic] = ACTIONS(6287),
    [anon_sym_string] = ACTIONS(6287),
    [anon_sym_chandle] = ACTIONS(6287),
    [anon_sym_event] = ACTIONS(6287),
    [anon_sym_byte] = ACTIONS(6287),
    [anon_sym_shortint] = ACTIONS(6287),
    [anon_sym_int] = ACTIONS(6287),
    [anon_sym_longint] = ACTIONS(6287),
    [anon_sym_integer] = ACTIONS(6287),
    [anon_sym_time] = ACTIONS(6287),
    [anon_sym_bit] = ACTIONS(6287),
    [anon_sym_logic] = ACTIONS(6287),
    [anon_sym_reg] = ACTIONS(6287),
    [anon_sym_shortreal] = ACTIONS(6287),
    [anon_sym_real] = ACTIONS(6287),
    [anon_sym_realtime] = ACTIONS(6287),
    [anon_sym_supply0] = ACTIONS(6287),
    [anon_sym_supply1] = ACTIONS(6287),
    [anon_sym_signed] = ACTIONS(6287),
    [anon_sym_unsigned] = ACTIONS(6287),
    [anon_sym_task] = ACTIONS(6287),
    [anon_sym_modport] = ACTIONS(6287),
    [anon_sym_assert] = ACTIONS(6287),
    [anon_sym_property] = ACTIONS(6287),
    [anon_sym_assume] = ACTIONS(6287),
    [anon_sym_cover] = ACTIONS(6287),
    [anon_sym_sequence] = ACTIONS(6287),
    [anon_sym_restrict] = ACTIONS(6287),
    [anon_sym_not] = ACTIONS(6287),
    [anon_sym_or] = ACTIONS(6287),
    [anon_sym_and] = ACTIONS(6287),
    [anon_sym_case] = ACTIONS(6287),
    [anon_sym_always] = ACTIONS(6287),
    [anon_sym_covergroup] = ACTIONS(6287),
    [anon_sym_let] = ACTIONS(6287),
    [anon_sym_pulldown] = ACTIONS(6287),
    [anon_sym_pullup] = ACTIONS(6287),
    [anon_sym_cmos] = ACTIONS(6287),
    [anon_sym_rcmos] = ACTIONS(6287),
    [anon_sym_bufif0] = ACTIONS(6287),
    [anon_sym_bufif1] = ACTIONS(6287),
    [anon_sym_notif0] = ACTIONS(6287),
    [anon_sym_notif1] = ACTIONS(6287),
    [anon_sym_nmos] = ACTIONS(6287),
    [anon_sym_pmos] = ACTIONS(6287),
    [anon_sym_rnmos] = ACTIONS(6287),
    [anon_sym_rpmos] = ACTIONS(6287),
    [anon_sym_nand] = ACTIONS(6287),
    [anon_sym_nor] = ACTIONS(6287),
    [anon_sym_xor] = ACTIONS(6287),
    [anon_sym_xnor] = ACTIONS(6287),
    [anon_sym_buf] = ACTIONS(6287),
    [anon_sym_tranif0] = ACTIONS(6287),
    [anon_sym_tranif1] = ACTIONS(6287),
    [anon_sym_rtranif1] = ACTIONS(6287),
    [anon_sym_rtranif0] = ACTIONS(6287),
    [anon_sym_tran] = ACTIONS(6287),
    [anon_sym_rtran] = ACTIONS(6287),
    [anon_sym_generate] = ACTIONS(6287),
    [anon_sym_for] = ACTIONS(6287),
    [anon_sym_initial] = ACTIONS(6287),
    [anon_sym_assign] = ACTIONS(6287),
    [anon_sym_alias] = ACTIONS(6287),
    [anon_sym_always_comb] = ACTIONS(6287),
    [anon_sym_always_latch] = ACTIONS(6287),
    [anon_sym_always_ff] = ACTIONS(6287),
    [anon_sym_final] = ACTIONS(6287),
    [anon_sym_while] = ACTIONS(6287),
    [anon_sym_global] = ACTIONS(6287),
    [anon_sym_specify] = ACTIONS(6287),
    [anon_sym_LPAREN_STAR] = ACTIONS(6289),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6289),
    [anon_sym_DOLLARunit] = ACTIONS(6289),
  },
  [1142] = {
    [sym_simple_identifier] = ACTIONS(6291),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6293),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6293),
    [anon_sym_BQUOTE] = ACTIONS(6291),
    [aux_sym_id_directive_token1] = ACTIONS(6293),
    [aux_sym_id_directive_token2] = ACTIONS(6293),
    [aux_sym_id_directive_token3] = ACTIONS(6293),
    [aux_sym_id_directive_token4] = ACTIONS(6291),
    [aux_sym_zero_directive_token1] = ACTIONS(6293),
    [aux_sym_zero_directive_token2] = ACTIONS(6293),
    [aux_sym_zero_directive_token3] = ACTIONS(6293),
    [aux_sym_zero_directive_token4] = ACTIONS(6293),
    [aux_sym_zero_directive_token5] = ACTIONS(6293),
    [aux_sym_zero_directive_token6] = ACTIONS(6293),
    [aux_sym_zero_directive_token7] = ACTIONS(6293),
    [aux_sym_zero_directive_token8] = ACTIONS(6293),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6293),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6293),
    [anon_sym_wire] = ACTIONS(6291),
    [anon_sym_tri] = ACTIONS(6291),
    [anon_sym_tri0] = ACTIONS(6291),
    [anon_sym_tri1] = ACTIONS(6291),
    [anon_sym_wand] = ACTIONS(6291),
    [anon_sym_triand] = ACTIONS(6291),
    [anon_sym_wor] = ACTIONS(6291),
    [anon_sym_trior] = ACTIONS(6291),
    [anon_sym_trireg] = ACTIONS(6291),
    [anon_sym_uwire] = ACTIONS(6291),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6293),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6293),
    [aux_sym_begin_keywords_token1] = ACTIONS(6293),
    [anon_sym_SEMI] = ACTIONS(6293),
    [anon_sym_endmodule] = ACTIONS(6291),
    [anon_sym_extern] = ACTIONS(6291),
    [anon_sym_module] = ACTIONS(6291),
    [anon_sym_macromodule] = ACTIONS(6291),
    [anon_sym_endinterface] = ACTIONS(6291),
    [anon_sym_interface] = ACTIONS(6291),
    [anon_sym_endprogram] = ACTIONS(6291),
    [anon_sym_program] = ACTIONS(6291),
    [anon_sym_checker] = ACTIONS(6291),
    [anon_sym_virtual] = ACTIONS(6291),
    [anon_sym_class] = ACTIONS(6291),
    [anon_sym_timeunit] = ACTIONS(6291),
    [anon_sym_timeprecision] = ACTIONS(6291),
    [anon_sym_type] = ACTIONS(6291),
    [anon_sym_input] = ACTIONS(6291),
    [anon_sym_output] = ACTIONS(6291),
    [anon_sym_inout] = ACTIONS(6291),
    [anon_sym_ref] = ACTIONS(6291),
    [anon_sym_DOLLARfatal] = ACTIONS(6293),
    [anon_sym_DOLLARerror] = ACTIONS(6293),
    [anon_sym_DOLLARwarning] = ACTIONS(6293),
    [anon_sym_DOLLARinfo] = ACTIONS(6293),
    [anon_sym_default] = ACTIONS(6291),
    [anon_sym_clocking] = ACTIONS(6291),
    [anon_sym_defparam] = ACTIONS(6291),
    [anon_sym_bind] = ACTIONS(6291),
    [anon_sym_const] = ACTIONS(6291),
    [anon_sym_function] = ACTIONS(6291),
    [anon_sym_static] = ACTIONS(6291),
    [anon_sym_constraint] = ACTIONS(6291),
    [anon_sym_if] = ACTIONS(6291),
    [anon_sym_else] = ACTIONS(6291),
    [anon_sym_LBRACK] = ACTIONS(6293),
    [anon_sym_localparam] = ACTIONS(6291),
    [anon_sym_parameter] = ACTIONS(6291),
    [anon_sym_specparam] = ACTIONS(6291),
    [anon_sym_var] = ACTIONS(6291),
    [anon_sym_import] = ACTIONS(6291),
    [anon_sym_export] = ACTIONS(6291),
    [anon_sym_genvar] = ACTIONS(6291),
    [anon_sym_interconnect] = ACTIONS(6291),
    [anon_sym_typedef] = ACTIONS(6291),
    [anon_sym_enum] = ACTIONS(6291),
    [anon_sym_struct] = ACTIONS(6291),
    [anon_sym_union] = ACTIONS(6291),
    [anon_sym_nettype] = ACTIONS(6291),
    [anon_sym_automatic] = ACTIONS(6291),
    [anon_sym_string] = ACTIONS(6291),
    [anon_sym_chandle] = ACTIONS(6291),
    [anon_sym_event] = ACTIONS(6291),
    [anon_sym_byte] = ACTIONS(6291),
    [anon_sym_shortint] = ACTIONS(6291),
    [anon_sym_int] = ACTIONS(6291),
    [anon_sym_longint] = ACTIONS(6291),
    [anon_sym_integer] = ACTIONS(6291),
    [anon_sym_time] = ACTIONS(6291),
    [anon_sym_bit] = ACTIONS(6291),
    [anon_sym_logic] = ACTIONS(6291),
    [anon_sym_reg] = ACTIONS(6291),
    [anon_sym_shortreal] = ACTIONS(6291),
    [anon_sym_real] = ACTIONS(6291),
    [anon_sym_realtime] = ACTIONS(6291),
    [anon_sym_supply0] = ACTIONS(6291),
    [anon_sym_supply1] = ACTIONS(6291),
    [anon_sym_signed] = ACTIONS(6291),
    [anon_sym_unsigned] = ACTIONS(6291),
    [anon_sym_task] = ACTIONS(6291),
    [anon_sym_modport] = ACTIONS(6291),
    [anon_sym_assert] = ACTIONS(6291),
    [anon_sym_property] = ACTIONS(6291),
    [anon_sym_assume] = ACTIONS(6291),
    [anon_sym_cover] = ACTIONS(6291),
    [anon_sym_sequence] = ACTIONS(6291),
    [anon_sym_restrict] = ACTIONS(6291),
    [anon_sym_not] = ACTIONS(6291),
    [anon_sym_or] = ACTIONS(6291),
    [anon_sym_and] = ACTIONS(6291),
    [anon_sym_case] = ACTIONS(6291),
    [anon_sym_always] = ACTIONS(6291),
    [anon_sym_covergroup] = ACTIONS(6291),
    [anon_sym_let] = ACTIONS(6291),
    [anon_sym_pulldown] = ACTIONS(6291),
    [anon_sym_pullup] = ACTIONS(6291),
    [anon_sym_cmos] = ACTIONS(6291),
    [anon_sym_rcmos] = ACTIONS(6291),
    [anon_sym_bufif0] = ACTIONS(6291),
    [anon_sym_bufif1] = ACTIONS(6291),
    [anon_sym_notif0] = ACTIONS(6291),
    [anon_sym_notif1] = ACTIONS(6291),
    [anon_sym_nmos] = ACTIONS(6291),
    [anon_sym_pmos] = ACTIONS(6291),
    [anon_sym_rnmos] = ACTIONS(6291),
    [anon_sym_rpmos] = ACTIONS(6291),
    [anon_sym_nand] = ACTIONS(6291),
    [anon_sym_nor] = ACTIONS(6291),
    [anon_sym_xor] = ACTIONS(6291),
    [anon_sym_xnor] = ACTIONS(6291),
    [anon_sym_buf] = ACTIONS(6291),
    [anon_sym_tranif0] = ACTIONS(6291),
    [anon_sym_tranif1] = ACTIONS(6291),
    [anon_sym_rtranif1] = ACTIONS(6291),
    [anon_sym_rtranif0] = ACTIONS(6291),
    [anon_sym_tran] = ACTIONS(6291),
    [anon_sym_rtran] = ACTIONS(6291),
    [anon_sym_generate] = ACTIONS(6291),
    [anon_sym_for] = ACTIONS(6291),
    [anon_sym_initial] = ACTIONS(6291),
    [anon_sym_assign] = ACTIONS(6291),
    [anon_sym_alias] = ACTIONS(6291),
    [anon_sym_always_comb] = ACTIONS(6291),
    [anon_sym_always_latch] = ACTIONS(6291),
    [anon_sym_always_ff] = ACTIONS(6291),
    [anon_sym_final] = ACTIONS(6291),
    [anon_sym_while] = ACTIONS(6291),
    [anon_sym_global] = ACTIONS(6291),
    [anon_sym_specify] = ACTIONS(6291),
    [anon_sym_LPAREN_STAR] = ACTIONS(6293),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6293),
    [anon_sym_DOLLARunit] = ACTIONS(6293),
  },
  [1143] = {
    [sym_simple_identifier] = ACTIONS(6295),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6297),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6297),
    [anon_sym_BQUOTE] = ACTIONS(6295),
    [aux_sym_id_directive_token1] = ACTIONS(6297),
    [aux_sym_id_directive_token2] = ACTIONS(6297),
    [aux_sym_id_directive_token3] = ACTIONS(6297),
    [aux_sym_id_directive_token4] = ACTIONS(6295),
    [aux_sym_zero_directive_token1] = ACTIONS(6297),
    [aux_sym_zero_directive_token2] = ACTIONS(6297),
    [aux_sym_zero_directive_token3] = ACTIONS(6297),
    [aux_sym_zero_directive_token4] = ACTIONS(6297),
    [aux_sym_zero_directive_token5] = ACTIONS(6297),
    [aux_sym_zero_directive_token6] = ACTIONS(6297),
    [aux_sym_zero_directive_token7] = ACTIONS(6297),
    [aux_sym_zero_directive_token8] = ACTIONS(6297),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6297),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6297),
    [anon_sym_wire] = ACTIONS(6295),
    [anon_sym_tri] = ACTIONS(6295),
    [anon_sym_tri0] = ACTIONS(6295),
    [anon_sym_tri1] = ACTIONS(6295),
    [anon_sym_wand] = ACTIONS(6295),
    [anon_sym_triand] = ACTIONS(6295),
    [anon_sym_wor] = ACTIONS(6295),
    [anon_sym_trior] = ACTIONS(6295),
    [anon_sym_trireg] = ACTIONS(6295),
    [anon_sym_uwire] = ACTIONS(6295),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6297),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6297),
    [aux_sym_begin_keywords_token1] = ACTIONS(6297),
    [anon_sym_SEMI] = ACTIONS(6297),
    [anon_sym_endmodule] = ACTIONS(6295),
    [anon_sym_extern] = ACTIONS(6295),
    [anon_sym_module] = ACTIONS(6295),
    [anon_sym_macromodule] = ACTIONS(6295),
    [anon_sym_endinterface] = ACTIONS(6295),
    [anon_sym_interface] = ACTIONS(6295),
    [anon_sym_endprogram] = ACTIONS(6295),
    [anon_sym_program] = ACTIONS(6295),
    [anon_sym_checker] = ACTIONS(6295),
    [anon_sym_virtual] = ACTIONS(6295),
    [anon_sym_class] = ACTIONS(6295),
    [anon_sym_timeunit] = ACTIONS(6295),
    [anon_sym_timeprecision] = ACTIONS(6295),
    [anon_sym_type] = ACTIONS(6295),
    [anon_sym_input] = ACTIONS(6295),
    [anon_sym_output] = ACTIONS(6295),
    [anon_sym_inout] = ACTIONS(6295),
    [anon_sym_ref] = ACTIONS(6295),
    [anon_sym_DOLLARfatal] = ACTIONS(6297),
    [anon_sym_DOLLARerror] = ACTIONS(6297),
    [anon_sym_DOLLARwarning] = ACTIONS(6297),
    [anon_sym_DOLLARinfo] = ACTIONS(6297),
    [anon_sym_default] = ACTIONS(6295),
    [anon_sym_clocking] = ACTIONS(6295),
    [anon_sym_defparam] = ACTIONS(6295),
    [anon_sym_bind] = ACTIONS(6295),
    [anon_sym_const] = ACTIONS(6295),
    [anon_sym_function] = ACTIONS(6295),
    [anon_sym_static] = ACTIONS(6295),
    [anon_sym_constraint] = ACTIONS(6295),
    [anon_sym_if] = ACTIONS(6295),
    [anon_sym_else] = ACTIONS(6295),
    [anon_sym_LBRACK] = ACTIONS(6297),
    [anon_sym_localparam] = ACTIONS(6295),
    [anon_sym_parameter] = ACTIONS(6295),
    [anon_sym_specparam] = ACTIONS(6295),
    [anon_sym_var] = ACTIONS(6295),
    [anon_sym_import] = ACTIONS(6295),
    [anon_sym_export] = ACTIONS(6295),
    [anon_sym_genvar] = ACTIONS(6295),
    [anon_sym_interconnect] = ACTIONS(6295),
    [anon_sym_typedef] = ACTIONS(6295),
    [anon_sym_enum] = ACTIONS(6295),
    [anon_sym_struct] = ACTIONS(6295),
    [anon_sym_union] = ACTIONS(6295),
    [anon_sym_nettype] = ACTIONS(6295),
    [anon_sym_automatic] = ACTIONS(6295),
    [anon_sym_string] = ACTIONS(6295),
    [anon_sym_chandle] = ACTIONS(6295),
    [anon_sym_event] = ACTIONS(6295),
    [anon_sym_byte] = ACTIONS(6295),
    [anon_sym_shortint] = ACTIONS(6295),
    [anon_sym_int] = ACTIONS(6295),
    [anon_sym_longint] = ACTIONS(6295),
    [anon_sym_integer] = ACTIONS(6295),
    [anon_sym_time] = ACTIONS(6295),
    [anon_sym_bit] = ACTIONS(6295),
    [anon_sym_logic] = ACTIONS(6295),
    [anon_sym_reg] = ACTIONS(6295),
    [anon_sym_shortreal] = ACTIONS(6295),
    [anon_sym_real] = ACTIONS(6295),
    [anon_sym_realtime] = ACTIONS(6295),
    [anon_sym_supply0] = ACTIONS(6295),
    [anon_sym_supply1] = ACTIONS(6295),
    [anon_sym_signed] = ACTIONS(6295),
    [anon_sym_unsigned] = ACTIONS(6295),
    [anon_sym_task] = ACTIONS(6295),
    [anon_sym_modport] = ACTIONS(6295),
    [anon_sym_assert] = ACTIONS(6295),
    [anon_sym_property] = ACTIONS(6295),
    [anon_sym_assume] = ACTIONS(6295),
    [anon_sym_cover] = ACTIONS(6295),
    [anon_sym_sequence] = ACTIONS(6295),
    [anon_sym_restrict] = ACTIONS(6295),
    [anon_sym_not] = ACTIONS(6295),
    [anon_sym_or] = ACTIONS(6295),
    [anon_sym_and] = ACTIONS(6295),
    [anon_sym_case] = ACTIONS(6295),
    [anon_sym_always] = ACTIONS(6295),
    [anon_sym_covergroup] = ACTIONS(6295),
    [anon_sym_let] = ACTIONS(6295),
    [anon_sym_pulldown] = ACTIONS(6295),
    [anon_sym_pullup] = ACTIONS(6295),
    [anon_sym_cmos] = ACTIONS(6295),
    [anon_sym_rcmos] = ACTIONS(6295),
    [anon_sym_bufif0] = ACTIONS(6295),
    [anon_sym_bufif1] = ACTIONS(6295),
    [anon_sym_notif0] = ACTIONS(6295),
    [anon_sym_notif1] = ACTIONS(6295),
    [anon_sym_nmos] = ACTIONS(6295),
    [anon_sym_pmos] = ACTIONS(6295),
    [anon_sym_rnmos] = ACTIONS(6295),
    [anon_sym_rpmos] = ACTIONS(6295),
    [anon_sym_nand] = ACTIONS(6295),
    [anon_sym_nor] = ACTIONS(6295),
    [anon_sym_xor] = ACTIONS(6295),
    [anon_sym_xnor] = ACTIONS(6295),
    [anon_sym_buf] = ACTIONS(6295),
    [anon_sym_tranif0] = ACTIONS(6295),
    [anon_sym_tranif1] = ACTIONS(6295),
    [anon_sym_rtranif1] = ACTIONS(6295),
    [anon_sym_rtranif0] = ACTIONS(6295),
    [anon_sym_tran] = ACTIONS(6295),
    [anon_sym_rtran] = ACTIONS(6295),
    [anon_sym_generate] = ACTIONS(6295),
    [anon_sym_for] = ACTIONS(6295),
    [anon_sym_initial] = ACTIONS(6295),
    [anon_sym_assign] = ACTIONS(6295),
    [anon_sym_alias] = ACTIONS(6295),
    [anon_sym_always_comb] = ACTIONS(6295),
    [anon_sym_always_latch] = ACTIONS(6295),
    [anon_sym_always_ff] = ACTIONS(6295),
    [anon_sym_final] = ACTIONS(6295),
    [anon_sym_while] = ACTIONS(6295),
    [anon_sym_global] = ACTIONS(6295),
    [anon_sym_specify] = ACTIONS(6295),
    [anon_sym_LPAREN_STAR] = ACTIONS(6297),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6297),
    [anon_sym_DOLLARunit] = ACTIONS(6297),
  },
  [1144] = {
    [sym_simple_identifier] = ACTIONS(6299),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6301),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6301),
    [anon_sym_BQUOTE] = ACTIONS(6299),
    [aux_sym_id_directive_token1] = ACTIONS(6301),
    [aux_sym_id_directive_token2] = ACTIONS(6301),
    [aux_sym_id_directive_token3] = ACTIONS(6301),
    [aux_sym_id_directive_token4] = ACTIONS(6299),
    [aux_sym_zero_directive_token1] = ACTIONS(6301),
    [aux_sym_zero_directive_token2] = ACTIONS(6301),
    [aux_sym_zero_directive_token3] = ACTIONS(6301),
    [aux_sym_zero_directive_token4] = ACTIONS(6301),
    [aux_sym_zero_directive_token5] = ACTIONS(6301),
    [aux_sym_zero_directive_token6] = ACTIONS(6301),
    [aux_sym_zero_directive_token7] = ACTIONS(6301),
    [aux_sym_zero_directive_token8] = ACTIONS(6301),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6301),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6301),
    [anon_sym_wire] = ACTIONS(6299),
    [anon_sym_tri] = ACTIONS(6299),
    [anon_sym_tri0] = ACTIONS(6299),
    [anon_sym_tri1] = ACTIONS(6299),
    [anon_sym_wand] = ACTIONS(6299),
    [anon_sym_triand] = ACTIONS(6299),
    [anon_sym_wor] = ACTIONS(6299),
    [anon_sym_trior] = ACTIONS(6299),
    [anon_sym_trireg] = ACTIONS(6299),
    [anon_sym_uwire] = ACTIONS(6299),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6301),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6301),
    [aux_sym_begin_keywords_token1] = ACTIONS(6301),
    [anon_sym_SEMI] = ACTIONS(6301),
    [anon_sym_endmodule] = ACTIONS(6299),
    [anon_sym_extern] = ACTIONS(6299),
    [anon_sym_module] = ACTIONS(6299),
    [anon_sym_macromodule] = ACTIONS(6299),
    [anon_sym_endinterface] = ACTIONS(6299),
    [anon_sym_interface] = ACTIONS(6299),
    [anon_sym_endprogram] = ACTIONS(6299),
    [anon_sym_program] = ACTIONS(6299),
    [anon_sym_checker] = ACTIONS(6299),
    [anon_sym_virtual] = ACTIONS(6299),
    [anon_sym_class] = ACTIONS(6299),
    [anon_sym_timeunit] = ACTIONS(6299),
    [anon_sym_timeprecision] = ACTIONS(6299),
    [anon_sym_type] = ACTIONS(6299),
    [anon_sym_input] = ACTIONS(6299),
    [anon_sym_output] = ACTIONS(6299),
    [anon_sym_inout] = ACTIONS(6299),
    [anon_sym_ref] = ACTIONS(6299),
    [anon_sym_DOLLARfatal] = ACTIONS(6301),
    [anon_sym_DOLLARerror] = ACTIONS(6301),
    [anon_sym_DOLLARwarning] = ACTIONS(6301),
    [anon_sym_DOLLARinfo] = ACTIONS(6301),
    [anon_sym_default] = ACTIONS(6299),
    [anon_sym_clocking] = ACTIONS(6299),
    [anon_sym_defparam] = ACTIONS(6299),
    [anon_sym_bind] = ACTIONS(6299),
    [anon_sym_const] = ACTIONS(6299),
    [anon_sym_function] = ACTIONS(6299),
    [anon_sym_static] = ACTIONS(6299),
    [anon_sym_constraint] = ACTIONS(6299),
    [anon_sym_if] = ACTIONS(6299),
    [anon_sym_else] = ACTIONS(6299),
    [anon_sym_LBRACK] = ACTIONS(6301),
    [anon_sym_localparam] = ACTIONS(6299),
    [anon_sym_parameter] = ACTIONS(6299),
    [anon_sym_specparam] = ACTIONS(6299),
    [anon_sym_var] = ACTIONS(6299),
    [anon_sym_import] = ACTIONS(6299),
    [anon_sym_export] = ACTIONS(6299),
    [anon_sym_genvar] = ACTIONS(6299),
    [anon_sym_interconnect] = ACTIONS(6299),
    [anon_sym_typedef] = ACTIONS(6299),
    [anon_sym_enum] = ACTIONS(6299),
    [anon_sym_struct] = ACTIONS(6299),
    [anon_sym_union] = ACTIONS(6299),
    [anon_sym_nettype] = ACTIONS(6299),
    [anon_sym_automatic] = ACTIONS(6299),
    [anon_sym_string] = ACTIONS(6299),
    [anon_sym_chandle] = ACTIONS(6299),
    [anon_sym_event] = ACTIONS(6299),
    [anon_sym_byte] = ACTIONS(6299),
    [anon_sym_shortint] = ACTIONS(6299),
    [anon_sym_int] = ACTIONS(6299),
    [anon_sym_longint] = ACTIONS(6299),
    [anon_sym_integer] = ACTIONS(6299),
    [anon_sym_time] = ACTIONS(6299),
    [anon_sym_bit] = ACTIONS(6299),
    [anon_sym_logic] = ACTIONS(6299),
    [anon_sym_reg] = ACTIONS(6299),
    [anon_sym_shortreal] = ACTIONS(6299),
    [anon_sym_real] = ACTIONS(6299),
    [anon_sym_realtime] = ACTIONS(6299),
    [anon_sym_supply0] = ACTIONS(6299),
    [anon_sym_supply1] = ACTIONS(6299),
    [anon_sym_signed] = ACTIONS(6299),
    [anon_sym_unsigned] = ACTIONS(6299),
    [anon_sym_task] = ACTIONS(6299),
    [anon_sym_modport] = ACTIONS(6299),
    [anon_sym_assert] = ACTIONS(6299),
    [anon_sym_property] = ACTIONS(6299),
    [anon_sym_assume] = ACTIONS(6299),
    [anon_sym_cover] = ACTIONS(6299),
    [anon_sym_sequence] = ACTIONS(6299),
    [anon_sym_restrict] = ACTIONS(6299),
    [anon_sym_not] = ACTIONS(6299),
    [anon_sym_or] = ACTIONS(6299),
    [anon_sym_and] = ACTIONS(6299),
    [anon_sym_case] = ACTIONS(6299),
    [anon_sym_always] = ACTIONS(6299),
    [anon_sym_covergroup] = ACTIONS(6299),
    [anon_sym_let] = ACTIONS(6299),
    [anon_sym_pulldown] = ACTIONS(6299),
    [anon_sym_pullup] = ACTIONS(6299),
    [anon_sym_cmos] = ACTIONS(6299),
    [anon_sym_rcmos] = ACTIONS(6299),
    [anon_sym_bufif0] = ACTIONS(6299),
    [anon_sym_bufif1] = ACTIONS(6299),
    [anon_sym_notif0] = ACTIONS(6299),
    [anon_sym_notif1] = ACTIONS(6299),
    [anon_sym_nmos] = ACTIONS(6299),
    [anon_sym_pmos] = ACTIONS(6299),
    [anon_sym_rnmos] = ACTIONS(6299),
    [anon_sym_rpmos] = ACTIONS(6299),
    [anon_sym_nand] = ACTIONS(6299),
    [anon_sym_nor] = ACTIONS(6299),
    [anon_sym_xor] = ACTIONS(6299),
    [anon_sym_xnor] = ACTIONS(6299),
    [anon_sym_buf] = ACTIONS(6299),
    [anon_sym_tranif0] = ACTIONS(6299),
    [anon_sym_tranif1] = ACTIONS(6299),
    [anon_sym_rtranif1] = ACTIONS(6299),
    [anon_sym_rtranif0] = ACTIONS(6299),
    [anon_sym_tran] = ACTIONS(6299),
    [anon_sym_rtran] = ACTIONS(6299),
    [anon_sym_generate] = ACTIONS(6299),
    [anon_sym_for] = ACTIONS(6299),
    [anon_sym_initial] = ACTIONS(6299),
    [anon_sym_assign] = ACTIONS(6299),
    [anon_sym_alias] = ACTIONS(6299),
    [anon_sym_always_comb] = ACTIONS(6299),
    [anon_sym_always_latch] = ACTIONS(6299),
    [anon_sym_always_ff] = ACTIONS(6299),
    [anon_sym_final] = ACTIONS(6299),
    [anon_sym_while] = ACTIONS(6299),
    [anon_sym_global] = ACTIONS(6299),
    [anon_sym_specify] = ACTIONS(6299),
    [anon_sym_LPAREN_STAR] = ACTIONS(6301),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6301),
    [anon_sym_DOLLARunit] = ACTIONS(6301),
  },
  [1145] = {
    [sym_simple_identifier] = ACTIONS(6303),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6305),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6305),
    [anon_sym_BQUOTE] = ACTIONS(6303),
    [aux_sym_id_directive_token1] = ACTIONS(6305),
    [aux_sym_id_directive_token2] = ACTIONS(6305),
    [aux_sym_id_directive_token3] = ACTIONS(6305),
    [aux_sym_id_directive_token4] = ACTIONS(6303),
    [aux_sym_zero_directive_token1] = ACTIONS(6305),
    [aux_sym_zero_directive_token2] = ACTIONS(6305),
    [aux_sym_zero_directive_token3] = ACTIONS(6305),
    [aux_sym_zero_directive_token4] = ACTIONS(6305),
    [aux_sym_zero_directive_token5] = ACTIONS(6305),
    [aux_sym_zero_directive_token6] = ACTIONS(6305),
    [aux_sym_zero_directive_token7] = ACTIONS(6305),
    [aux_sym_zero_directive_token8] = ACTIONS(6305),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6305),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6305),
    [anon_sym_wire] = ACTIONS(6303),
    [anon_sym_tri] = ACTIONS(6303),
    [anon_sym_tri0] = ACTIONS(6303),
    [anon_sym_tri1] = ACTIONS(6303),
    [anon_sym_wand] = ACTIONS(6303),
    [anon_sym_triand] = ACTIONS(6303),
    [anon_sym_wor] = ACTIONS(6303),
    [anon_sym_trior] = ACTIONS(6303),
    [anon_sym_trireg] = ACTIONS(6303),
    [anon_sym_uwire] = ACTIONS(6303),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6305),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6305),
    [aux_sym_begin_keywords_token1] = ACTIONS(6305),
    [anon_sym_SEMI] = ACTIONS(6305),
    [anon_sym_endmodule] = ACTIONS(6303),
    [anon_sym_extern] = ACTIONS(6303),
    [anon_sym_module] = ACTIONS(6303),
    [anon_sym_macromodule] = ACTIONS(6303),
    [anon_sym_endinterface] = ACTIONS(6303),
    [anon_sym_interface] = ACTIONS(6303),
    [anon_sym_endprogram] = ACTIONS(6303),
    [anon_sym_program] = ACTIONS(6303),
    [anon_sym_checker] = ACTIONS(6303),
    [anon_sym_virtual] = ACTIONS(6303),
    [anon_sym_class] = ACTIONS(6303),
    [anon_sym_timeunit] = ACTIONS(6303),
    [anon_sym_timeprecision] = ACTIONS(6303),
    [anon_sym_type] = ACTIONS(6303),
    [anon_sym_input] = ACTIONS(6303),
    [anon_sym_output] = ACTIONS(6303),
    [anon_sym_inout] = ACTIONS(6303),
    [anon_sym_ref] = ACTIONS(6303),
    [anon_sym_DOLLARfatal] = ACTIONS(6305),
    [anon_sym_DOLLARerror] = ACTIONS(6305),
    [anon_sym_DOLLARwarning] = ACTIONS(6305),
    [anon_sym_DOLLARinfo] = ACTIONS(6305),
    [anon_sym_default] = ACTIONS(6303),
    [anon_sym_clocking] = ACTIONS(6303),
    [anon_sym_defparam] = ACTIONS(6303),
    [anon_sym_bind] = ACTIONS(6303),
    [anon_sym_const] = ACTIONS(6303),
    [anon_sym_function] = ACTIONS(6303),
    [anon_sym_static] = ACTIONS(6303),
    [anon_sym_constraint] = ACTIONS(6303),
    [anon_sym_if] = ACTIONS(6303),
    [anon_sym_else] = ACTIONS(6303),
    [anon_sym_LBRACK] = ACTIONS(6305),
    [anon_sym_localparam] = ACTIONS(6303),
    [anon_sym_parameter] = ACTIONS(6303),
    [anon_sym_specparam] = ACTIONS(6303),
    [anon_sym_var] = ACTIONS(6303),
    [anon_sym_import] = ACTIONS(6303),
    [anon_sym_export] = ACTIONS(6303),
    [anon_sym_genvar] = ACTIONS(6303),
    [anon_sym_interconnect] = ACTIONS(6303),
    [anon_sym_typedef] = ACTIONS(6303),
    [anon_sym_enum] = ACTIONS(6303),
    [anon_sym_struct] = ACTIONS(6303),
    [anon_sym_union] = ACTIONS(6303),
    [anon_sym_nettype] = ACTIONS(6303),
    [anon_sym_automatic] = ACTIONS(6303),
    [anon_sym_string] = ACTIONS(6303),
    [anon_sym_chandle] = ACTIONS(6303),
    [anon_sym_event] = ACTIONS(6303),
    [anon_sym_byte] = ACTIONS(6303),
    [anon_sym_shortint] = ACTIONS(6303),
    [anon_sym_int] = ACTIONS(6303),
    [anon_sym_longint] = ACTIONS(6303),
    [anon_sym_integer] = ACTIONS(6303),
    [anon_sym_time] = ACTIONS(6303),
    [anon_sym_bit] = ACTIONS(6303),
    [anon_sym_logic] = ACTIONS(6303),
    [anon_sym_reg] = ACTIONS(6303),
    [anon_sym_shortreal] = ACTIONS(6303),
    [anon_sym_real] = ACTIONS(6303),
    [anon_sym_realtime] = ACTIONS(6303),
    [anon_sym_supply0] = ACTIONS(6303),
    [anon_sym_supply1] = ACTIONS(6303),
    [anon_sym_signed] = ACTIONS(6303),
    [anon_sym_unsigned] = ACTIONS(6303),
    [anon_sym_task] = ACTIONS(6303),
    [anon_sym_modport] = ACTIONS(6303),
    [anon_sym_assert] = ACTIONS(6303),
    [anon_sym_property] = ACTIONS(6303),
    [anon_sym_assume] = ACTIONS(6303),
    [anon_sym_cover] = ACTIONS(6303),
    [anon_sym_sequence] = ACTIONS(6303),
    [anon_sym_restrict] = ACTIONS(6303),
    [anon_sym_not] = ACTIONS(6303),
    [anon_sym_or] = ACTIONS(6303),
    [anon_sym_and] = ACTIONS(6303),
    [anon_sym_case] = ACTIONS(6303),
    [anon_sym_always] = ACTIONS(6303),
    [anon_sym_covergroup] = ACTIONS(6303),
    [anon_sym_let] = ACTIONS(6303),
    [anon_sym_pulldown] = ACTIONS(6303),
    [anon_sym_pullup] = ACTIONS(6303),
    [anon_sym_cmos] = ACTIONS(6303),
    [anon_sym_rcmos] = ACTIONS(6303),
    [anon_sym_bufif0] = ACTIONS(6303),
    [anon_sym_bufif1] = ACTIONS(6303),
    [anon_sym_notif0] = ACTIONS(6303),
    [anon_sym_notif1] = ACTIONS(6303),
    [anon_sym_nmos] = ACTIONS(6303),
    [anon_sym_pmos] = ACTIONS(6303),
    [anon_sym_rnmos] = ACTIONS(6303),
    [anon_sym_rpmos] = ACTIONS(6303),
    [anon_sym_nand] = ACTIONS(6303),
    [anon_sym_nor] = ACTIONS(6303),
    [anon_sym_xor] = ACTIONS(6303),
    [anon_sym_xnor] = ACTIONS(6303),
    [anon_sym_buf] = ACTIONS(6303),
    [anon_sym_tranif0] = ACTIONS(6303),
    [anon_sym_tranif1] = ACTIONS(6303),
    [anon_sym_rtranif1] = ACTIONS(6303),
    [anon_sym_rtranif0] = ACTIONS(6303),
    [anon_sym_tran] = ACTIONS(6303),
    [anon_sym_rtran] = ACTIONS(6303),
    [anon_sym_generate] = ACTIONS(6303),
    [anon_sym_for] = ACTIONS(6303),
    [anon_sym_initial] = ACTIONS(6303),
    [anon_sym_assign] = ACTIONS(6303),
    [anon_sym_alias] = ACTIONS(6303),
    [anon_sym_always_comb] = ACTIONS(6303),
    [anon_sym_always_latch] = ACTIONS(6303),
    [anon_sym_always_ff] = ACTIONS(6303),
    [anon_sym_final] = ACTIONS(6303),
    [anon_sym_while] = ACTIONS(6303),
    [anon_sym_global] = ACTIONS(6303),
    [anon_sym_specify] = ACTIONS(6303),
    [anon_sym_LPAREN_STAR] = ACTIONS(6305),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6305),
    [anon_sym_DOLLARunit] = ACTIONS(6305),
  },
  [1146] = {
    [sym_simple_identifier] = ACTIONS(6307),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6309),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6309),
    [anon_sym_BQUOTE] = ACTIONS(6307),
    [aux_sym_id_directive_token1] = ACTIONS(6309),
    [aux_sym_id_directive_token2] = ACTIONS(6309),
    [aux_sym_id_directive_token3] = ACTIONS(6309),
    [aux_sym_id_directive_token4] = ACTIONS(6307),
    [aux_sym_zero_directive_token1] = ACTIONS(6309),
    [aux_sym_zero_directive_token2] = ACTIONS(6309),
    [aux_sym_zero_directive_token3] = ACTIONS(6309),
    [aux_sym_zero_directive_token4] = ACTIONS(6309),
    [aux_sym_zero_directive_token5] = ACTIONS(6309),
    [aux_sym_zero_directive_token6] = ACTIONS(6309),
    [aux_sym_zero_directive_token7] = ACTIONS(6309),
    [aux_sym_zero_directive_token8] = ACTIONS(6309),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6309),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6309),
    [anon_sym_wire] = ACTIONS(6307),
    [anon_sym_tri] = ACTIONS(6307),
    [anon_sym_tri0] = ACTIONS(6307),
    [anon_sym_tri1] = ACTIONS(6307),
    [anon_sym_wand] = ACTIONS(6307),
    [anon_sym_triand] = ACTIONS(6307),
    [anon_sym_wor] = ACTIONS(6307),
    [anon_sym_trior] = ACTIONS(6307),
    [anon_sym_trireg] = ACTIONS(6307),
    [anon_sym_uwire] = ACTIONS(6307),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6309),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6309),
    [aux_sym_begin_keywords_token1] = ACTIONS(6309),
    [anon_sym_SEMI] = ACTIONS(6309),
    [anon_sym_endmodule] = ACTIONS(6307),
    [anon_sym_extern] = ACTIONS(6307),
    [anon_sym_module] = ACTIONS(6307),
    [anon_sym_macromodule] = ACTIONS(6307),
    [anon_sym_endinterface] = ACTIONS(6307),
    [anon_sym_interface] = ACTIONS(6307),
    [anon_sym_endprogram] = ACTIONS(6307),
    [anon_sym_program] = ACTIONS(6307),
    [anon_sym_checker] = ACTIONS(6307),
    [anon_sym_virtual] = ACTIONS(6307),
    [anon_sym_class] = ACTIONS(6307),
    [anon_sym_timeunit] = ACTIONS(6307),
    [anon_sym_timeprecision] = ACTIONS(6307),
    [anon_sym_type] = ACTIONS(6307),
    [anon_sym_input] = ACTIONS(6307),
    [anon_sym_output] = ACTIONS(6307),
    [anon_sym_inout] = ACTIONS(6307),
    [anon_sym_ref] = ACTIONS(6307),
    [anon_sym_DOLLARfatal] = ACTIONS(6309),
    [anon_sym_DOLLARerror] = ACTIONS(6309),
    [anon_sym_DOLLARwarning] = ACTIONS(6309),
    [anon_sym_DOLLARinfo] = ACTIONS(6309),
    [anon_sym_default] = ACTIONS(6307),
    [anon_sym_clocking] = ACTIONS(6307),
    [anon_sym_defparam] = ACTIONS(6307),
    [anon_sym_bind] = ACTIONS(6307),
    [anon_sym_const] = ACTIONS(6307),
    [anon_sym_function] = ACTIONS(6307),
    [anon_sym_static] = ACTIONS(6307),
    [anon_sym_constraint] = ACTIONS(6307),
    [anon_sym_if] = ACTIONS(6307),
    [anon_sym_else] = ACTIONS(6307),
    [anon_sym_LBRACK] = ACTIONS(6309),
    [anon_sym_localparam] = ACTIONS(6307),
    [anon_sym_parameter] = ACTIONS(6307),
    [anon_sym_specparam] = ACTIONS(6307),
    [anon_sym_var] = ACTIONS(6307),
    [anon_sym_import] = ACTIONS(6307),
    [anon_sym_export] = ACTIONS(6307),
    [anon_sym_genvar] = ACTIONS(6307),
    [anon_sym_interconnect] = ACTIONS(6307),
    [anon_sym_typedef] = ACTIONS(6307),
    [anon_sym_enum] = ACTIONS(6307),
    [anon_sym_struct] = ACTIONS(6307),
    [anon_sym_union] = ACTIONS(6307),
    [anon_sym_nettype] = ACTIONS(6307),
    [anon_sym_automatic] = ACTIONS(6307),
    [anon_sym_string] = ACTIONS(6307),
    [anon_sym_chandle] = ACTIONS(6307),
    [anon_sym_event] = ACTIONS(6307),
    [anon_sym_byte] = ACTIONS(6307),
    [anon_sym_shortint] = ACTIONS(6307),
    [anon_sym_int] = ACTIONS(6307),
    [anon_sym_longint] = ACTIONS(6307),
    [anon_sym_integer] = ACTIONS(6307),
    [anon_sym_time] = ACTIONS(6307),
    [anon_sym_bit] = ACTIONS(6307),
    [anon_sym_logic] = ACTIONS(6307),
    [anon_sym_reg] = ACTIONS(6307),
    [anon_sym_shortreal] = ACTIONS(6307),
    [anon_sym_real] = ACTIONS(6307),
    [anon_sym_realtime] = ACTIONS(6307),
    [anon_sym_supply0] = ACTIONS(6307),
    [anon_sym_supply1] = ACTIONS(6307),
    [anon_sym_signed] = ACTIONS(6307),
    [anon_sym_unsigned] = ACTIONS(6307),
    [anon_sym_task] = ACTIONS(6307),
    [anon_sym_modport] = ACTIONS(6307),
    [anon_sym_assert] = ACTIONS(6307),
    [anon_sym_property] = ACTIONS(6307),
    [anon_sym_assume] = ACTIONS(6307),
    [anon_sym_cover] = ACTIONS(6307),
    [anon_sym_sequence] = ACTIONS(6307),
    [anon_sym_restrict] = ACTIONS(6307),
    [anon_sym_not] = ACTIONS(6307),
    [anon_sym_or] = ACTIONS(6307),
    [anon_sym_and] = ACTIONS(6307),
    [anon_sym_case] = ACTIONS(6307),
    [anon_sym_always] = ACTIONS(6307),
    [anon_sym_covergroup] = ACTIONS(6307),
    [anon_sym_let] = ACTIONS(6307),
    [anon_sym_pulldown] = ACTIONS(6307),
    [anon_sym_pullup] = ACTIONS(6307),
    [anon_sym_cmos] = ACTIONS(6307),
    [anon_sym_rcmos] = ACTIONS(6307),
    [anon_sym_bufif0] = ACTIONS(6307),
    [anon_sym_bufif1] = ACTIONS(6307),
    [anon_sym_notif0] = ACTIONS(6307),
    [anon_sym_notif1] = ACTIONS(6307),
    [anon_sym_nmos] = ACTIONS(6307),
    [anon_sym_pmos] = ACTIONS(6307),
    [anon_sym_rnmos] = ACTIONS(6307),
    [anon_sym_rpmos] = ACTIONS(6307),
    [anon_sym_nand] = ACTIONS(6307),
    [anon_sym_nor] = ACTIONS(6307),
    [anon_sym_xor] = ACTIONS(6307),
    [anon_sym_xnor] = ACTIONS(6307),
    [anon_sym_buf] = ACTIONS(6307),
    [anon_sym_tranif0] = ACTIONS(6307),
    [anon_sym_tranif1] = ACTIONS(6307),
    [anon_sym_rtranif1] = ACTIONS(6307),
    [anon_sym_rtranif0] = ACTIONS(6307),
    [anon_sym_tran] = ACTIONS(6307),
    [anon_sym_rtran] = ACTIONS(6307),
    [anon_sym_generate] = ACTIONS(6307),
    [anon_sym_for] = ACTIONS(6307),
    [anon_sym_initial] = ACTIONS(6307),
    [anon_sym_assign] = ACTIONS(6307),
    [anon_sym_alias] = ACTIONS(6307),
    [anon_sym_always_comb] = ACTIONS(6307),
    [anon_sym_always_latch] = ACTIONS(6307),
    [anon_sym_always_ff] = ACTIONS(6307),
    [anon_sym_final] = ACTIONS(6307),
    [anon_sym_while] = ACTIONS(6307),
    [anon_sym_global] = ACTIONS(6307),
    [anon_sym_specify] = ACTIONS(6307),
    [anon_sym_LPAREN_STAR] = ACTIONS(6309),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6309),
    [anon_sym_DOLLARunit] = ACTIONS(6309),
  },
  [1147] = {
    [sym_simple_identifier] = ACTIONS(6311),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6313),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6313),
    [anon_sym_BQUOTE] = ACTIONS(6311),
    [aux_sym_id_directive_token1] = ACTIONS(6313),
    [aux_sym_id_directive_token2] = ACTIONS(6313),
    [aux_sym_id_directive_token3] = ACTIONS(6313),
    [aux_sym_id_directive_token4] = ACTIONS(6311),
    [aux_sym_zero_directive_token1] = ACTIONS(6313),
    [aux_sym_zero_directive_token2] = ACTIONS(6313),
    [aux_sym_zero_directive_token3] = ACTIONS(6313),
    [aux_sym_zero_directive_token4] = ACTIONS(6313),
    [aux_sym_zero_directive_token5] = ACTIONS(6313),
    [aux_sym_zero_directive_token6] = ACTIONS(6313),
    [aux_sym_zero_directive_token7] = ACTIONS(6313),
    [aux_sym_zero_directive_token8] = ACTIONS(6313),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6313),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6313),
    [anon_sym_wire] = ACTIONS(6311),
    [anon_sym_tri] = ACTIONS(6311),
    [anon_sym_tri0] = ACTIONS(6311),
    [anon_sym_tri1] = ACTIONS(6311),
    [anon_sym_wand] = ACTIONS(6311),
    [anon_sym_triand] = ACTIONS(6311),
    [anon_sym_wor] = ACTIONS(6311),
    [anon_sym_trior] = ACTIONS(6311),
    [anon_sym_trireg] = ACTIONS(6311),
    [anon_sym_uwire] = ACTIONS(6311),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6313),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6313),
    [aux_sym_begin_keywords_token1] = ACTIONS(6313),
    [anon_sym_SEMI] = ACTIONS(6313),
    [anon_sym_endmodule] = ACTIONS(6311),
    [anon_sym_extern] = ACTIONS(6311),
    [anon_sym_module] = ACTIONS(6311),
    [anon_sym_macromodule] = ACTIONS(6311),
    [anon_sym_endinterface] = ACTIONS(6311),
    [anon_sym_interface] = ACTIONS(6311),
    [anon_sym_endprogram] = ACTIONS(6311),
    [anon_sym_program] = ACTIONS(6311),
    [anon_sym_checker] = ACTIONS(6311),
    [anon_sym_virtual] = ACTIONS(6311),
    [anon_sym_class] = ACTIONS(6311),
    [anon_sym_timeunit] = ACTIONS(6311),
    [anon_sym_timeprecision] = ACTIONS(6311),
    [anon_sym_type] = ACTIONS(6311),
    [anon_sym_input] = ACTIONS(6311),
    [anon_sym_output] = ACTIONS(6311),
    [anon_sym_inout] = ACTIONS(6311),
    [anon_sym_ref] = ACTIONS(6311),
    [anon_sym_DOLLARfatal] = ACTIONS(6313),
    [anon_sym_DOLLARerror] = ACTIONS(6313),
    [anon_sym_DOLLARwarning] = ACTIONS(6313),
    [anon_sym_DOLLARinfo] = ACTIONS(6313),
    [anon_sym_default] = ACTIONS(6311),
    [anon_sym_clocking] = ACTIONS(6311),
    [anon_sym_defparam] = ACTIONS(6311),
    [anon_sym_bind] = ACTIONS(6311),
    [anon_sym_const] = ACTIONS(6311),
    [anon_sym_function] = ACTIONS(6311),
    [anon_sym_static] = ACTIONS(6311),
    [anon_sym_constraint] = ACTIONS(6311),
    [anon_sym_if] = ACTIONS(6311),
    [anon_sym_else] = ACTIONS(6311),
    [anon_sym_LBRACK] = ACTIONS(6313),
    [anon_sym_localparam] = ACTIONS(6311),
    [anon_sym_parameter] = ACTIONS(6311),
    [anon_sym_specparam] = ACTIONS(6311),
    [anon_sym_var] = ACTIONS(6311),
    [anon_sym_import] = ACTIONS(6311),
    [anon_sym_export] = ACTIONS(6311),
    [anon_sym_genvar] = ACTIONS(6311),
    [anon_sym_interconnect] = ACTIONS(6311),
    [anon_sym_typedef] = ACTIONS(6311),
    [anon_sym_enum] = ACTIONS(6311),
    [anon_sym_struct] = ACTIONS(6311),
    [anon_sym_union] = ACTIONS(6311),
    [anon_sym_nettype] = ACTIONS(6311),
    [anon_sym_automatic] = ACTIONS(6311),
    [anon_sym_string] = ACTIONS(6311),
    [anon_sym_chandle] = ACTIONS(6311),
    [anon_sym_event] = ACTIONS(6311),
    [anon_sym_byte] = ACTIONS(6311),
    [anon_sym_shortint] = ACTIONS(6311),
    [anon_sym_int] = ACTIONS(6311),
    [anon_sym_longint] = ACTIONS(6311),
    [anon_sym_integer] = ACTIONS(6311),
    [anon_sym_time] = ACTIONS(6311),
    [anon_sym_bit] = ACTIONS(6311),
    [anon_sym_logic] = ACTIONS(6311),
    [anon_sym_reg] = ACTIONS(6311),
    [anon_sym_shortreal] = ACTIONS(6311),
    [anon_sym_real] = ACTIONS(6311),
    [anon_sym_realtime] = ACTIONS(6311),
    [anon_sym_supply0] = ACTIONS(6311),
    [anon_sym_supply1] = ACTIONS(6311),
    [anon_sym_signed] = ACTIONS(6311),
    [anon_sym_unsigned] = ACTIONS(6311),
    [anon_sym_task] = ACTIONS(6311),
    [anon_sym_modport] = ACTIONS(6311),
    [anon_sym_assert] = ACTIONS(6311),
    [anon_sym_property] = ACTIONS(6311),
    [anon_sym_assume] = ACTIONS(6311),
    [anon_sym_cover] = ACTIONS(6311),
    [anon_sym_sequence] = ACTIONS(6311),
    [anon_sym_restrict] = ACTIONS(6311),
    [anon_sym_not] = ACTIONS(6311),
    [anon_sym_or] = ACTIONS(6311),
    [anon_sym_and] = ACTIONS(6311),
    [anon_sym_case] = ACTIONS(6311),
    [anon_sym_always] = ACTIONS(6311),
    [anon_sym_covergroup] = ACTIONS(6311),
    [anon_sym_let] = ACTIONS(6311),
    [anon_sym_pulldown] = ACTIONS(6311),
    [anon_sym_pullup] = ACTIONS(6311),
    [anon_sym_cmos] = ACTIONS(6311),
    [anon_sym_rcmos] = ACTIONS(6311),
    [anon_sym_bufif0] = ACTIONS(6311),
    [anon_sym_bufif1] = ACTIONS(6311),
    [anon_sym_notif0] = ACTIONS(6311),
    [anon_sym_notif1] = ACTIONS(6311),
    [anon_sym_nmos] = ACTIONS(6311),
    [anon_sym_pmos] = ACTIONS(6311),
    [anon_sym_rnmos] = ACTIONS(6311),
    [anon_sym_rpmos] = ACTIONS(6311),
    [anon_sym_nand] = ACTIONS(6311),
    [anon_sym_nor] = ACTIONS(6311),
    [anon_sym_xor] = ACTIONS(6311),
    [anon_sym_xnor] = ACTIONS(6311),
    [anon_sym_buf] = ACTIONS(6311),
    [anon_sym_tranif0] = ACTIONS(6311),
    [anon_sym_tranif1] = ACTIONS(6311),
    [anon_sym_rtranif1] = ACTIONS(6311),
    [anon_sym_rtranif0] = ACTIONS(6311),
    [anon_sym_tran] = ACTIONS(6311),
    [anon_sym_rtran] = ACTIONS(6311),
    [anon_sym_generate] = ACTIONS(6311),
    [anon_sym_for] = ACTIONS(6311),
    [anon_sym_initial] = ACTIONS(6311),
    [anon_sym_assign] = ACTIONS(6311),
    [anon_sym_alias] = ACTIONS(6311),
    [anon_sym_always_comb] = ACTIONS(6311),
    [anon_sym_always_latch] = ACTIONS(6311),
    [anon_sym_always_ff] = ACTIONS(6311),
    [anon_sym_final] = ACTIONS(6311),
    [anon_sym_while] = ACTIONS(6311),
    [anon_sym_global] = ACTIONS(6311),
    [anon_sym_specify] = ACTIONS(6311),
    [anon_sym_LPAREN_STAR] = ACTIONS(6313),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6313),
    [anon_sym_DOLLARunit] = ACTIONS(6313),
  },
  [1148] = {
    [sym_simple_identifier] = ACTIONS(6315),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6317),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6317),
    [anon_sym_BQUOTE] = ACTIONS(6315),
    [aux_sym_id_directive_token1] = ACTIONS(6317),
    [aux_sym_id_directive_token2] = ACTIONS(6317),
    [aux_sym_id_directive_token3] = ACTIONS(6317),
    [aux_sym_id_directive_token4] = ACTIONS(6315),
    [aux_sym_zero_directive_token1] = ACTIONS(6317),
    [aux_sym_zero_directive_token2] = ACTIONS(6317),
    [aux_sym_zero_directive_token3] = ACTIONS(6317),
    [aux_sym_zero_directive_token4] = ACTIONS(6317),
    [aux_sym_zero_directive_token5] = ACTIONS(6317),
    [aux_sym_zero_directive_token6] = ACTIONS(6317),
    [aux_sym_zero_directive_token7] = ACTIONS(6317),
    [aux_sym_zero_directive_token8] = ACTIONS(6317),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6317),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6317),
    [anon_sym_wire] = ACTIONS(6315),
    [anon_sym_tri] = ACTIONS(6315),
    [anon_sym_tri0] = ACTIONS(6315),
    [anon_sym_tri1] = ACTIONS(6315),
    [anon_sym_wand] = ACTIONS(6315),
    [anon_sym_triand] = ACTIONS(6315),
    [anon_sym_wor] = ACTIONS(6315),
    [anon_sym_trior] = ACTIONS(6315),
    [anon_sym_trireg] = ACTIONS(6315),
    [anon_sym_uwire] = ACTIONS(6315),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6317),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6317),
    [aux_sym_begin_keywords_token1] = ACTIONS(6317),
    [anon_sym_SEMI] = ACTIONS(6317),
    [anon_sym_endmodule] = ACTIONS(6315),
    [anon_sym_extern] = ACTIONS(6315),
    [anon_sym_module] = ACTIONS(6315),
    [anon_sym_macromodule] = ACTIONS(6315),
    [anon_sym_endinterface] = ACTIONS(6315),
    [anon_sym_interface] = ACTIONS(6315),
    [anon_sym_endprogram] = ACTIONS(6315),
    [anon_sym_program] = ACTIONS(6315),
    [anon_sym_checker] = ACTIONS(6315),
    [anon_sym_virtual] = ACTIONS(6315),
    [anon_sym_class] = ACTIONS(6315),
    [anon_sym_timeunit] = ACTIONS(6315),
    [anon_sym_timeprecision] = ACTIONS(6315),
    [anon_sym_type] = ACTIONS(6315),
    [anon_sym_input] = ACTIONS(6315),
    [anon_sym_output] = ACTIONS(6315),
    [anon_sym_inout] = ACTIONS(6315),
    [anon_sym_ref] = ACTIONS(6315),
    [anon_sym_DOLLARfatal] = ACTIONS(6317),
    [anon_sym_DOLLARerror] = ACTIONS(6317),
    [anon_sym_DOLLARwarning] = ACTIONS(6317),
    [anon_sym_DOLLARinfo] = ACTIONS(6317),
    [anon_sym_default] = ACTIONS(6315),
    [anon_sym_clocking] = ACTIONS(6315),
    [anon_sym_defparam] = ACTIONS(6315),
    [anon_sym_bind] = ACTIONS(6315),
    [anon_sym_const] = ACTIONS(6315),
    [anon_sym_function] = ACTIONS(6315),
    [anon_sym_static] = ACTIONS(6315),
    [anon_sym_constraint] = ACTIONS(6315),
    [anon_sym_if] = ACTIONS(6315),
    [anon_sym_else] = ACTIONS(6315),
    [anon_sym_LBRACK] = ACTIONS(6317),
    [anon_sym_localparam] = ACTIONS(6315),
    [anon_sym_parameter] = ACTIONS(6315),
    [anon_sym_specparam] = ACTIONS(6315),
    [anon_sym_var] = ACTIONS(6315),
    [anon_sym_import] = ACTIONS(6315),
    [anon_sym_export] = ACTIONS(6315),
    [anon_sym_genvar] = ACTIONS(6315),
    [anon_sym_interconnect] = ACTIONS(6315),
    [anon_sym_typedef] = ACTIONS(6315),
    [anon_sym_enum] = ACTIONS(6315),
    [anon_sym_struct] = ACTIONS(6315),
    [anon_sym_union] = ACTIONS(6315),
    [anon_sym_nettype] = ACTIONS(6315),
    [anon_sym_automatic] = ACTIONS(6315),
    [anon_sym_string] = ACTIONS(6315),
    [anon_sym_chandle] = ACTIONS(6315),
    [anon_sym_event] = ACTIONS(6315),
    [anon_sym_byte] = ACTIONS(6315),
    [anon_sym_shortint] = ACTIONS(6315),
    [anon_sym_int] = ACTIONS(6315),
    [anon_sym_longint] = ACTIONS(6315),
    [anon_sym_integer] = ACTIONS(6315),
    [anon_sym_time] = ACTIONS(6315),
    [anon_sym_bit] = ACTIONS(6315),
    [anon_sym_logic] = ACTIONS(6315),
    [anon_sym_reg] = ACTIONS(6315),
    [anon_sym_shortreal] = ACTIONS(6315),
    [anon_sym_real] = ACTIONS(6315),
    [anon_sym_realtime] = ACTIONS(6315),
    [anon_sym_supply0] = ACTIONS(6315),
    [anon_sym_supply1] = ACTIONS(6315),
    [anon_sym_signed] = ACTIONS(6315),
    [anon_sym_unsigned] = ACTIONS(6315),
    [anon_sym_task] = ACTIONS(6315),
    [anon_sym_modport] = ACTIONS(6315),
    [anon_sym_assert] = ACTIONS(6315),
    [anon_sym_property] = ACTIONS(6315),
    [anon_sym_assume] = ACTIONS(6315),
    [anon_sym_cover] = ACTIONS(6315),
    [anon_sym_sequence] = ACTIONS(6315),
    [anon_sym_restrict] = ACTIONS(6315),
    [anon_sym_not] = ACTIONS(6315),
    [anon_sym_or] = ACTIONS(6315),
    [anon_sym_and] = ACTIONS(6315),
    [anon_sym_case] = ACTIONS(6315),
    [anon_sym_always] = ACTIONS(6315),
    [anon_sym_covergroup] = ACTIONS(6315),
    [anon_sym_let] = ACTIONS(6315),
    [anon_sym_pulldown] = ACTIONS(6315),
    [anon_sym_pullup] = ACTIONS(6315),
    [anon_sym_cmos] = ACTIONS(6315),
    [anon_sym_rcmos] = ACTIONS(6315),
    [anon_sym_bufif0] = ACTIONS(6315),
    [anon_sym_bufif1] = ACTIONS(6315),
    [anon_sym_notif0] = ACTIONS(6315),
    [anon_sym_notif1] = ACTIONS(6315),
    [anon_sym_nmos] = ACTIONS(6315),
    [anon_sym_pmos] = ACTIONS(6315),
    [anon_sym_rnmos] = ACTIONS(6315),
    [anon_sym_rpmos] = ACTIONS(6315),
    [anon_sym_nand] = ACTIONS(6315),
    [anon_sym_nor] = ACTIONS(6315),
    [anon_sym_xor] = ACTIONS(6315),
    [anon_sym_xnor] = ACTIONS(6315),
    [anon_sym_buf] = ACTIONS(6315),
    [anon_sym_tranif0] = ACTIONS(6315),
    [anon_sym_tranif1] = ACTIONS(6315),
    [anon_sym_rtranif1] = ACTIONS(6315),
    [anon_sym_rtranif0] = ACTIONS(6315),
    [anon_sym_tran] = ACTIONS(6315),
    [anon_sym_rtran] = ACTIONS(6315),
    [anon_sym_generate] = ACTIONS(6315),
    [anon_sym_for] = ACTIONS(6315),
    [anon_sym_initial] = ACTIONS(6315),
    [anon_sym_assign] = ACTIONS(6315),
    [anon_sym_alias] = ACTIONS(6315),
    [anon_sym_always_comb] = ACTIONS(6315),
    [anon_sym_always_latch] = ACTIONS(6315),
    [anon_sym_always_ff] = ACTIONS(6315),
    [anon_sym_final] = ACTIONS(6315),
    [anon_sym_while] = ACTIONS(6315),
    [anon_sym_global] = ACTIONS(6315),
    [anon_sym_specify] = ACTIONS(6315),
    [anon_sym_LPAREN_STAR] = ACTIONS(6317),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6317),
    [anon_sym_DOLLARunit] = ACTIONS(6317),
  },
  [1149] = {
    [sym_simple_identifier] = ACTIONS(6319),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6321),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6321),
    [anon_sym_BQUOTE] = ACTIONS(6319),
    [aux_sym_id_directive_token1] = ACTIONS(6321),
    [aux_sym_id_directive_token2] = ACTIONS(6321),
    [aux_sym_id_directive_token3] = ACTIONS(6321),
    [aux_sym_id_directive_token4] = ACTIONS(6319),
    [aux_sym_zero_directive_token1] = ACTIONS(6321),
    [aux_sym_zero_directive_token2] = ACTIONS(6321),
    [aux_sym_zero_directive_token3] = ACTIONS(6321),
    [aux_sym_zero_directive_token4] = ACTIONS(6321),
    [aux_sym_zero_directive_token5] = ACTIONS(6321),
    [aux_sym_zero_directive_token6] = ACTIONS(6321),
    [aux_sym_zero_directive_token7] = ACTIONS(6321),
    [aux_sym_zero_directive_token8] = ACTIONS(6321),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6321),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6321),
    [anon_sym_wire] = ACTIONS(6319),
    [anon_sym_tri] = ACTIONS(6319),
    [anon_sym_tri0] = ACTIONS(6319),
    [anon_sym_tri1] = ACTIONS(6319),
    [anon_sym_wand] = ACTIONS(6319),
    [anon_sym_triand] = ACTIONS(6319),
    [anon_sym_wor] = ACTIONS(6319),
    [anon_sym_trior] = ACTIONS(6319),
    [anon_sym_trireg] = ACTIONS(6319),
    [anon_sym_uwire] = ACTIONS(6319),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6321),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6321),
    [aux_sym_begin_keywords_token1] = ACTIONS(6321),
    [anon_sym_SEMI] = ACTIONS(6321),
    [anon_sym_endmodule] = ACTIONS(6319),
    [anon_sym_extern] = ACTIONS(6319),
    [anon_sym_module] = ACTIONS(6319),
    [anon_sym_macromodule] = ACTIONS(6319),
    [anon_sym_endinterface] = ACTIONS(6319),
    [anon_sym_interface] = ACTIONS(6319),
    [anon_sym_endprogram] = ACTIONS(6319),
    [anon_sym_program] = ACTIONS(6319),
    [anon_sym_checker] = ACTIONS(6319),
    [anon_sym_virtual] = ACTIONS(6319),
    [anon_sym_class] = ACTIONS(6319),
    [anon_sym_timeunit] = ACTIONS(6319),
    [anon_sym_timeprecision] = ACTIONS(6319),
    [anon_sym_type] = ACTIONS(6319),
    [anon_sym_input] = ACTIONS(6319),
    [anon_sym_output] = ACTIONS(6319),
    [anon_sym_inout] = ACTIONS(6319),
    [anon_sym_ref] = ACTIONS(6319),
    [anon_sym_DOLLARfatal] = ACTIONS(6321),
    [anon_sym_DOLLARerror] = ACTIONS(6321),
    [anon_sym_DOLLARwarning] = ACTIONS(6321),
    [anon_sym_DOLLARinfo] = ACTIONS(6321),
    [anon_sym_default] = ACTIONS(6319),
    [anon_sym_clocking] = ACTIONS(6319),
    [anon_sym_defparam] = ACTIONS(6319),
    [anon_sym_bind] = ACTIONS(6319),
    [anon_sym_const] = ACTIONS(6319),
    [anon_sym_function] = ACTIONS(6319),
    [anon_sym_static] = ACTIONS(6319),
    [anon_sym_constraint] = ACTIONS(6319),
    [anon_sym_if] = ACTIONS(6319),
    [anon_sym_else] = ACTIONS(6319),
    [anon_sym_LBRACK] = ACTIONS(6321),
    [anon_sym_localparam] = ACTIONS(6319),
    [anon_sym_parameter] = ACTIONS(6319),
    [anon_sym_specparam] = ACTIONS(6319),
    [anon_sym_var] = ACTIONS(6319),
    [anon_sym_import] = ACTIONS(6319),
    [anon_sym_export] = ACTIONS(6319),
    [anon_sym_genvar] = ACTIONS(6319),
    [anon_sym_interconnect] = ACTIONS(6319),
    [anon_sym_typedef] = ACTIONS(6319),
    [anon_sym_enum] = ACTIONS(6319),
    [anon_sym_struct] = ACTIONS(6319),
    [anon_sym_union] = ACTIONS(6319),
    [anon_sym_nettype] = ACTIONS(6319),
    [anon_sym_automatic] = ACTIONS(6319),
    [anon_sym_string] = ACTIONS(6319),
    [anon_sym_chandle] = ACTIONS(6319),
    [anon_sym_event] = ACTIONS(6319),
    [anon_sym_byte] = ACTIONS(6319),
    [anon_sym_shortint] = ACTIONS(6319),
    [anon_sym_int] = ACTIONS(6319),
    [anon_sym_longint] = ACTIONS(6319),
    [anon_sym_integer] = ACTIONS(6319),
    [anon_sym_time] = ACTIONS(6319),
    [anon_sym_bit] = ACTIONS(6319),
    [anon_sym_logic] = ACTIONS(6319),
    [anon_sym_reg] = ACTIONS(6319),
    [anon_sym_shortreal] = ACTIONS(6319),
    [anon_sym_real] = ACTIONS(6319),
    [anon_sym_realtime] = ACTIONS(6319),
    [anon_sym_supply0] = ACTIONS(6319),
    [anon_sym_supply1] = ACTIONS(6319),
    [anon_sym_signed] = ACTIONS(6319),
    [anon_sym_unsigned] = ACTIONS(6319),
    [anon_sym_task] = ACTIONS(6319),
    [anon_sym_modport] = ACTIONS(6319),
    [anon_sym_assert] = ACTIONS(6319),
    [anon_sym_property] = ACTIONS(6319),
    [anon_sym_assume] = ACTIONS(6319),
    [anon_sym_cover] = ACTIONS(6319),
    [anon_sym_sequence] = ACTIONS(6319),
    [anon_sym_restrict] = ACTIONS(6319),
    [anon_sym_not] = ACTIONS(6319),
    [anon_sym_or] = ACTIONS(6319),
    [anon_sym_and] = ACTIONS(6319),
    [anon_sym_case] = ACTIONS(6319),
    [anon_sym_always] = ACTIONS(6319),
    [anon_sym_covergroup] = ACTIONS(6319),
    [anon_sym_let] = ACTIONS(6319),
    [anon_sym_pulldown] = ACTIONS(6319),
    [anon_sym_pullup] = ACTIONS(6319),
    [anon_sym_cmos] = ACTIONS(6319),
    [anon_sym_rcmos] = ACTIONS(6319),
    [anon_sym_bufif0] = ACTIONS(6319),
    [anon_sym_bufif1] = ACTIONS(6319),
    [anon_sym_notif0] = ACTIONS(6319),
    [anon_sym_notif1] = ACTIONS(6319),
    [anon_sym_nmos] = ACTIONS(6319),
    [anon_sym_pmos] = ACTIONS(6319),
    [anon_sym_rnmos] = ACTIONS(6319),
    [anon_sym_rpmos] = ACTIONS(6319),
    [anon_sym_nand] = ACTIONS(6319),
    [anon_sym_nor] = ACTIONS(6319),
    [anon_sym_xor] = ACTIONS(6319),
    [anon_sym_xnor] = ACTIONS(6319),
    [anon_sym_buf] = ACTIONS(6319),
    [anon_sym_tranif0] = ACTIONS(6319),
    [anon_sym_tranif1] = ACTIONS(6319),
    [anon_sym_rtranif1] = ACTIONS(6319),
    [anon_sym_rtranif0] = ACTIONS(6319),
    [anon_sym_tran] = ACTIONS(6319),
    [anon_sym_rtran] = ACTIONS(6319),
    [anon_sym_generate] = ACTIONS(6319),
    [anon_sym_for] = ACTIONS(6319),
    [anon_sym_initial] = ACTIONS(6319),
    [anon_sym_assign] = ACTIONS(6319),
    [anon_sym_alias] = ACTIONS(6319),
    [anon_sym_always_comb] = ACTIONS(6319),
    [anon_sym_always_latch] = ACTIONS(6319),
    [anon_sym_always_ff] = ACTIONS(6319),
    [anon_sym_final] = ACTIONS(6319),
    [anon_sym_while] = ACTIONS(6319),
    [anon_sym_global] = ACTIONS(6319),
    [anon_sym_specify] = ACTIONS(6319),
    [anon_sym_LPAREN_STAR] = ACTIONS(6321),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6321),
    [anon_sym_DOLLARunit] = ACTIONS(6321),
  },
  [1150] = {
    [sym_simple_identifier] = ACTIONS(6323),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6325),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6325),
    [anon_sym_BQUOTE] = ACTIONS(6323),
    [aux_sym_id_directive_token1] = ACTIONS(6325),
    [aux_sym_id_directive_token2] = ACTIONS(6325),
    [aux_sym_id_directive_token3] = ACTIONS(6325),
    [aux_sym_id_directive_token4] = ACTIONS(6323),
    [aux_sym_zero_directive_token1] = ACTIONS(6325),
    [aux_sym_zero_directive_token2] = ACTIONS(6325),
    [aux_sym_zero_directive_token3] = ACTIONS(6325),
    [aux_sym_zero_directive_token4] = ACTIONS(6325),
    [aux_sym_zero_directive_token5] = ACTIONS(6325),
    [aux_sym_zero_directive_token6] = ACTIONS(6325),
    [aux_sym_zero_directive_token7] = ACTIONS(6325),
    [aux_sym_zero_directive_token8] = ACTIONS(6325),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6325),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6325),
    [anon_sym_wire] = ACTIONS(6323),
    [anon_sym_tri] = ACTIONS(6323),
    [anon_sym_tri0] = ACTIONS(6323),
    [anon_sym_tri1] = ACTIONS(6323),
    [anon_sym_wand] = ACTIONS(6323),
    [anon_sym_triand] = ACTIONS(6323),
    [anon_sym_wor] = ACTIONS(6323),
    [anon_sym_trior] = ACTIONS(6323),
    [anon_sym_trireg] = ACTIONS(6323),
    [anon_sym_uwire] = ACTIONS(6323),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6325),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6325),
    [aux_sym_begin_keywords_token1] = ACTIONS(6325),
    [anon_sym_SEMI] = ACTIONS(6325),
    [anon_sym_endmodule] = ACTIONS(6323),
    [anon_sym_extern] = ACTIONS(6323),
    [anon_sym_module] = ACTIONS(6323),
    [anon_sym_macromodule] = ACTIONS(6323),
    [anon_sym_endinterface] = ACTIONS(6323),
    [anon_sym_interface] = ACTIONS(6323),
    [anon_sym_endprogram] = ACTIONS(6323),
    [anon_sym_program] = ACTIONS(6323),
    [anon_sym_checker] = ACTIONS(6323),
    [anon_sym_virtual] = ACTIONS(6323),
    [anon_sym_class] = ACTIONS(6323),
    [anon_sym_timeunit] = ACTIONS(6323),
    [anon_sym_timeprecision] = ACTIONS(6323),
    [anon_sym_type] = ACTIONS(6323),
    [anon_sym_input] = ACTIONS(6323),
    [anon_sym_output] = ACTIONS(6323),
    [anon_sym_inout] = ACTIONS(6323),
    [anon_sym_ref] = ACTIONS(6323),
    [anon_sym_DOLLARfatal] = ACTIONS(6325),
    [anon_sym_DOLLARerror] = ACTIONS(6325),
    [anon_sym_DOLLARwarning] = ACTIONS(6325),
    [anon_sym_DOLLARinfo] = ACTIONS(6325),
    [anon_sym_default] = ACTIONS(6323),
    [anon_sym_clocking] = ACTIONS(6323),
    [anon_sym_defparam] = ACTIONS(6323),
    [anon_sym_bind] = ACTIONS(6323),
    [anon_sym_const] = ACTIONS(6323),
    [anon_sym_function] = ACTIONS(6323),
    [anon_sym_static] = ACTIONS(6323),
    [anon_sym_constraint] = ACTIONS(6323),
    [anon_sym_if] = ACTIONS(6323),
    [anon_sym_else] = ACTIONS(6323),
    [anon_sym_LBRACK] = ACTIONS(6325),
    [anon_sym_localparam] = ACTIONS(6323),
    [anon_sym_parameter] = ACTIONS(6323),
    [anon_sym_specparam] = ACTIONS(6323),
    [anon_sym_var] = ACTIONS(6323),
    [anon_sym_import] = ACTIONS(6323),
    [anon_sym_export] = ACTIONS(6323),
    [anon_sym_genvar] = ACTIONS(6323),
    [anon_sym_interconnect] = ACTIONS(6323),
    [anon_sym_typedef] = ACTIONS(6323),
    [anon_sym_enum] = ACTIONS(6323),
    [anon_sym_struct] = ACTIONS(6323),
    [anon_sym_union] = ACTIONS(6323),
    [anon_sym_nettype] = ACTIONS(6323),
    [anon_sym_automatic] = ACTIONS(6323),
    [anon_sym_string] = ACTIONS(6323),
    [anon_sym_chandle] = ACTIONS(6323),
    [anon_sym_event] = ACTIONS(6323),
    [anon_sym_byte] = ACTIONS(6323),
    [anon_sym_shortint] = ACTIONS(6323),
    [anon_sym_int] = ACTIONS(6323),
    [anon_sym_longint] = ACTIONS(6323),
    [anon_sym_integer] = ACTIONS(6323),
    [anon_sym_time] = ACTIONS(6323),
    [anon_sym_bit] = ACTIONS(6323),
    [anon_sym_logic] = ACTIONS(6323),
    [anon_sym_reg] = ACTIONS(6323),
    [anon_sym_shortreal] = ACTIONS(6323),
    [anon_sym_real] = ACTIONS(6323),
    [anon_sym_realtime] = ACTIONS(6323),
    [anon_sym_supply0] = ACTIONS(6323),
    [anon_sym_supply1] = ACTIONS(6323),
    [anon_sym_signed] = ACTIONS(6323),
    [anon_sym_unsigned] = ACTIONS(6323),
    [anon_sym_task] = ACTIONS(6323),
    [anon_sym_modport] = ACTIONS(6323),
    [anon_sym_assert] = ACTIONS(6323),
    [anon_sym_property] = ACTIONS(6323),
    [anon_sym_assume] = ACTIONS(6323),
    [anon_sym_cover] = ACTIONS(6323),
    [anon_sym_sequence] = ACTIONS(6323),
    [anon_sym_restrict] = ACTIONS(6323),
    [anon_sym_not] = ACTIONS(6323),
    [anon_sym_or] = ACTIONS(6323),
    [anon_sym_and] = ACTIONS(6323),
    [anon_sym_case] = ACTIONS(6323),
    [anon_sym_always] = ACTIONS(6323),
    [anon_sym_covergroup] = ACTIONS(6323),
    [anon_sym_let] = ACTIONS(6323),
    [anon_sym_pulldown] = ACTIONS(6323),
    [anon_sym_pullup] = ACTIONS(6323),
    [anon_sym_cmos] = ACTIONS(6323),
    [anon_sym_rcmos] = ACTIONS(6323),
    [anon_sym_bufif0] = ACTIONS(6323),
    [anon_sym_bufif1] = ACTIONS(6323),
    [anon_sym_notif0] = ACTIONS(6323),
    [anon_sym_notif1] = ACTIONS(6323),
    [anon_sym_nmos] = ACTIONS(6323),
    [anon_sym_pmos] = ACTIONS(6323),
    [anon_sym_rnmos] = ACTIONS(6323),
    [anon_sym_rpmos] = ACTIONS(6323),
    [anon_sym_nand] = ACTIONS(6323),
    [anon_sym_nor] = ACTIONS(6323),
    [anon_sym_xor] = ACTIONS(6323),
    [anon_sym_xnor] = ACTIONS(6323),
    [anon_sym_buf] = ACTIONS(6323),
    [anon_sym_tranif0] = ACTIONS(6323),
    [anon_sym_tranif1] = ACTIONS(6323),
    [anon_sym_rtranif1] = ACTIONS(6323),
    [anon_sym_rtranif0] = ACTIONS(6323),
    [anon_sym_tran] = ACTIONS(6323),
    [anon_sym_rtran] = ACTIONS(6323),
    [anon_sym_generate] = ACTIONS(6323),
    [anon_sym_for] = ACTIONS(6323),
    [anon_sym_initial] = ACTIONS(6323),
    [anon_sym_assign] = ACTIONS(6323),
    [anon_sym_alias] = ACTIONS(6323),
    [anon_sym_always_comb] = ACTIONS(6323),
    [anon_sym_always_latch] = ACTIONS(6323),
    [anon_sym_always_ff] = ACTIONS(6323),
    [anon_sym_final] = ACTIONS(6323),
    [anon_sym_while] = ACTIONS(6323),
    [anon_sym_global] = ACTIONS(6323),
    [anon_sym_specify] = ACTIONS(6323),
    [anon_sym_LPAREN_STAR] = ACTIONS(6325),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6325),
    [anon_sym_DOLLARunit] = ACTIONS(6325),
  },
  [1151] = {
    [sym_simple_identifier] = ACTIONS(6327),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6329),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6329),
    [anon_sym_BQUOTE] = ACTIONS(6327),
    [aux_sym_id_directive_token1] = ACTIONS(6329),
    [aux_sym_id_directive_token2] = ACTIONS(6329),
    [aux_sym_id_directive_token3] = ACTIONS(6329),
    [aux_sym_id_directive_token4] = ACTIONS(6327),
    [aux_sym_zero_directive_token1] = ACTIONS(6329),
    [aux_sym_zero_directive_token2] = ACTIONS(6329),
    [aux_sym_zero_directive_token3] = ACTIONS(6329),
    [aux_sym_zero_directive_token4] = ACTIONS(6329),
    [aux_sym_zero_directive_token5] = ACTIONS(6329),
    [aux_sym_zero_directive_token6] = ACTIONS(6329),
    [aux_sym_zero_directive_token7] = ACTIONS(6329),
    [aux_sym_zero_directive_token8] = ACTIONS(6329),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6329),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6329),
    [anon_sym_wire] = ACTIONS(6327),
    [anon_sym_tri] = ACTIONS(6327),
    [anon_sym_tri0] = ACTIONS(6327),
    [anon_sym_tri1] = ACTIONS(6327),
    [anon_sym_wand] = ACTIONS(6327),
    [anon_sym_triand] = ACTIONS(6327),
    [anon_sym_wor] = ACTIONS(6327),
    [anon_sym_trior] = ACTIONS(6327),
    [anon_sym_trireg] = ACTIONS(6327),
    [anon_sym_uwire] = ACTIONS(6327),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6329),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6329),
    [aux_sym_begin_keywords_token1] = ACTIONS(6329),
    [anon_sym_SEMI] = ACTIONS(6329),
    [anon_sym_endmodule] = ACTIONS(6327),
    [anon_sym_extern] = ACTIONS(6327),
    [anon_sym_module] = ACTIONS(6327),
    [anon_sym_macromodule] = ACTIONS(6327),
    [anon_sym_endinterface] = ACTIONS(6327),
    [anon_sym_interface] = ACTIONS(6327),
    [anon_sym_endprogram] = ACTIONS(6327),
    [anon_sym_program] = ACTIONS(6327),
    [anon_sym_checker] = ACTIONS(6327),
    [anon_sym_virtual] = ACTIONS(6327),
    [anon_sym_class] = ACTIONS(6327),
    [anon_sym_timeunit] = ACTIONS(6327),
    [anon_sym_timeprecision] = ACTIONS(6327),
    [anon_sym_type] = ACTIONS(6327),
    [anon_sym_input] = ACTIONS(6327),
    [anon_sym_output] = ACTIONS(6327),
    [anon_sym_inout] = ACTIONS(6327),
    [anon_sym_ref] = ACTIONS(6327),
    [anon_sym_DOLLARfatal] = ACTIONS(6329),
    [anon_sym_DOLLARerror] = ACTIONS(6329),
    [anon_sym_DOLLARwarning] = ACTIONS(6329),
    [anon_sym_DOLLARinfo] = ACTIONS(6329),
    [anon_sym_default] = ACTIONS(6327),
    [anon_sym_clocking] = ACTIONS(6327),
    [anon_sym_defparam] = ACTIONS(6327),
    [anon_sym_bind] = ACTIONS(6327),
    [anon_sym_const] = ACTIONS(6327),
    [anon_sym_function] = ACTIONS(6327),
    [anon_sym_static] = ACTIONS(6327),
    [anon_sym_constraint] = ACTIONS(6327),
    [anon_sym_if] = ACTIONS(6327),
    [anon_sym_else] = ACTIONS(6327),
    [anon_sym_LBRACK] = ACTIONS(6329),
    [anon_sym_localparam] = ACTIONS(6327),
    [anon_sym_parameter] = ACTIONS(6327),
    [anon_sym_specparam] = ACTIONS(6327),
    [anon_sym_var] = ACTIONS(6327),
    [anon_sym_import] = ACTIONS(6327),
    [anon_sym_export] = ACTIONS(6327),
    [anon_sym_genvar] = ACTIONS(6327),
    [anon_sym_interconnect] = ACTIONS(6327),
    [anon_sym_typedef] = ACTIONS(6327),
    [anon_sym_enum] = ACTIONS(6327),
    [anon_sym_struct] = ACTIONS(6327),
    [anon_sym_union] = ACTIONS(6327),
    [anon_sym_nettype] = ACTIONS(6327),
    [anon_sym_automatic] = ACTIONS(6327),
    [anon_sym_string] = ACTIONS(6327),
    [anon_sym_chandle] = ACTIONS(6327),
    [anon_sym_event] = ACTIONS(6327),
    [anon_sym_byte] = ACTIONS(6327),
    [anon_sym_shortint] = ACTIONS(6327),
    [anon_sym_int] = ACTIONS(6327),
    [anon_sym_longint] = ACTIONS(6327),
    [anon_sym_integer] = ACTIONS(6327),
    [anon_sym_time] = ACTIONS(6327),
    [anon_sym_bit] = ACTIONS(6327),
    [anon_sym_logic] = ACTIONS(6327),
    [anon_sym_reg] = ACTIONS(6327),
    [anon_sym_shortreal] = ACTIONS(6327),
    [anon_sym_real] = ACTIONS(6327),
    [anon_sym_realtime] = ACTIONS(6327),
    [anon_sym_supply0] = ACTIONS(6327),
    [anon_sym_supply1] = ACTIONS(6327),
    [anon_sym_signed] = ACTIONS(6327),
    [anon_sym_unsigned] = ACTIONS(6327),
    [anon_sym_task] = ACTIONS(6327),
    [anon_sym_modport] = ACTIONS(6327),
    [anon_sym_assert] = ACTIONS(6327),
    [anon_sym_property] = ACTIONS(6327),
    [anon_sym_assume] = ACTIONS(6327),
    [anon_sym_cover] = ACTIONS(6327),
    [anon_sym_sequence] = ACTIONS(6327),
    [anon_sym_restrict] = ACTIONS(6327),
    [anon_sym_not] = ACTIONS(6327),
    [anon_sym_or] = ACTIONS(6327),
    [anon_sym_and] = ACTIONS(6327),
    [anon_sym_case] = ACTIONS(6327),
    [anon_sym_always] = ACTIONS(6327),
    [anon_sym_covergroup] = ACTIONS(6327),
    [anon_sym_let] = ACTIONS(6327),
    [anon_sym_pulldown] = ACTIONS(6327),
    [anon_sym_pullup] = ACTIONS(6327),
    [anon_sym_cmos] = ACTIONS(6327),
    [anon_sym_rcmos] = ACTIONS(6327),
    [anon_sym_bufif0] = ACTIONS(6327),
    [anon_sym_bufif1] = ACTIONS(6327),
    [anon_sym_notif0] = ACTIONS(6327),
    [anon_sym_notif1] = ACTIONS(6327),
    [anon_sym_nmos] = ACTIONS(6327),
    [anon_sym_pmos] = ACTIONS(6327),
    [anon_sym_rnmos] = ACTIONS(6327),
    [anon_sym_rpmos] = ACTIONS(6327),
    [anon_sym_nand] = ACTIONS(6327),
    [anon_sym_nor] = ACTIONS(6327),
    [anon_sym_xor] = ACTIONS(6327),
    [anon_sym_xnor] = ACTIONS(6327),
    [anon_sym_buf] = ACTIONS(6327),
    [anon_sym_tranif0] = ACTIONS(6327),
    [anon_sym_tranif1] = ACTIONS(6327),
    [anon_sym_rtranif1] = ACTIONS(6327),
    [anon_sym_rtranif0] = ACTIONS(6327),
    [anon_sym_tran] = ACTIONS(6327),
    [anon_sym_rtran] = ACTIONS(6327),
    [anon_sym_generate] = ACTIONS(6327),
    [anon_sym_for] = ACTIONS(6327),
    [anon_sym_initial] = ACTIONS(6327),
    [anon_sym_assign] = ACTIONS(6327),
    [anon_sym_alias] = ACTIONS(6327),
    [anon_sym_always_comb] = ACTIONS(6327),
    [anon_sym_always_latch] = ACTIONS(6327),
    [anon_sym_always_ff] = ACTIONS(6327),
    [anon_sym_final] = ACTIONS(6327),
    [anon_sym_while] = ACTIONS(6327),
    [anon_sym_global] = ACTIONS(6327),
    [anon_sym_specify] = ACTIONS(6327),
    [anon_sym_LPAREN_STAR] = ACTIONS(6329),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6329),
    [anon_sym_DOLLARunit] = ACTIONS(6329),
  },
  [1152] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9250),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_SEMI] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_iff] = ACTIONS(2644),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_with] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [1153] = {
    [sym_simple_identifier] = ACTIONS(6345),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6347),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6347),
    [anon_sym_BQUOTE] = ACTIONS(6345),
    [aux_sym_id_directive_token1] = ACTIONS(6347),
    [aux_sym_id_directive_token2] = ACTIONS(6347),
    [aux_sym_id_directive_token3] = ACTIONS(6347),
    [aux_sym_id_directive_token4] = ACTIONS(6345),
    [aux_sym_zero_directive_token1] = ACTIONS(6347),
    [aux_sym_zero_directive_token2] = ACTIONS(6347),
    [aux_sym_zero_directive_token3] = ACTIONS(6347),
    [aux_sym_zero_directive_token4] = ACTIONS(6347),
    [aux_sym_zero_directive_token5] = ACTIONS(6347),
    [aux_sym_zero_directive_token6] = ACTIONS(6347),
    [aux_sym_zero_directive_token7] = ACTIONS(6347),
    [aux_sym_zero_directive_token8] = ACTIONS(6347),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6347),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6347),
    [anon_sym_wire] = ACTIONS(6345),
    [anon_sym_tri] = ACTIONS(6345),
    [anon_sym_tri0] = ACTIONS(6345),
    [anon_sym_tri1] = ACTIONS(6345),
    [anon_sym_wand] = ACTIONS(6345),
    [anon_sym_triand] = ACTIONS(6345),
    [anon_sym_wor] = ACTIONS(6345),
    [anon_sym_trior] = ACTIONS(6345),
    [anon_sym_trireg] = ACTIONS(6345),
    [anon_sym_uwire] = ACTIONS(6345),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6347),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6347),
    [aux_sym_begin_keywords_token1] = ACTIONS(6347),
    [anon_sym_SEMI] = ACTIONS(6347),
    [anon_sym_endmodule] = ACTIONS(6345),
    [anon_sym_extern] = ACTIONS(6345),
    [anon_sym_module] = ACTIONS(6345),
    [anon_sym_macromodule] = ACTIONS(6345),
    [anon_sym_endinterface] = ACTIONS(6345),
    [anon_sym_interface] = ACTIONS(6345),
    [anon_sym_endprogram] = ACTIONS(6345),
    [anon_sym_program] = ACTIONS(6345),
    [anon_sym_checker] = ACTIONS(6345),
    [anon_sym_virtual] = ACTIONS(6345),
    [anon_sym_class] = ACTIONS(6345),
    [anon_sym_timeunit] = ACTIONS(6345),
    [anon_sym_timeprecision] = ACTIONS(6345),
    [anon_sym_type] = ACTIONS(6345),
    [anon_sym_input] = ACTIONS(6345),
    [anon_sym_output] = ACTIONS(6345),
    [anon_sym_inout] = ACTIONS(6345),
    [anon_sym_ref] = ACTIONS(6345),
    [anon_sym_DOLLARfatal] = ACTIONS(6347),
    [anon_sym_DOLLARerror] = ACTIONS(6347),
    [anon_sym_DOLLARwarning] = ACTIONS(6347),
    [anon_sym_DOLLARinfo] = ACTIONS(6347),
    [anon_sym_default] = ACTIONS(6345),
    [anon_sym_clocking] = ACTIONS(6345),
    [anon_sym_defparam] = ACTIONS(6345),
    [anon_sym_bind] = ACTIONS(6345),
    [anon_sym_const] = ACTIONS(6345),
    [anon_sym_function] = ACTIONS(6345),
    [anon_sym_static] = ACTIONS(6345),
    [anon_sym_constraint] = ACTIONS(6345),
    [anon_sym_if] = ACTIONS(6345),
    [anon_sym_else] = ACTIONS(6345),
    [anon_sym_LBRACK] = ACTIONS(6347),
    [anon_sym_localparam] = ACTIONS(6345),
    [anon_sym_parameter] = ACTIONS(6345),
    [anon_sym_specparam] = ACTIONS(6345),
    [anon_sym_var] = ACTIONS(6345),
    [anon_sym_import] = ACTIONS(6345),
    [anon_sym_export] = ACTIONS(6345),
    [anon_sym_genvar] = ACTIONS(6345),
    [anon_sym_interconnect] = ACTIONS(6345),
    [anon_sym_typedef] = ACTIONS(6345),
    [anon_sym_enum] = ACTIONS(6345),
    [anon_sym_struct] = ACTIONS(6345),
    [anon_sym_union] = ACTIONS(6345),
    [anon_sym_nettype] = ACTIONS(6345),
    [anon_sym_automatic] = ACTIONS(6345),
    [anon_sym_string] = ACTIONS(6345),
    [anon_sym_chandle] = ACTIONS(6345),
    [anon_sym_event] = ACTIONS(6345),
    [anon_sym_byte] = ACTIONS(6345),
    [anon_sym_shortint] = ACTIONS(6345),
    [anon_sym_int] = ACTIONS(6345),
    [anon_sym_longint] = ACTIONS(6345),
    [anon_sym_integer] = ACTIONS(6345),
    [anon_sym_time] = ACTIONS(6345),
    [anon_sym_bit] = ACTIONS(6345),
    [anon_sym_logic] = ACTIONS(6345),
    [anon_sym_reg] = ACTIONS(6345),
    [anon_sym_shortreal] = ACTIONS(6345),
    [anon_sym_real] = ACTIONS(6345),
    [anon_sym_realtime] = ACTIONS(6345),
    [anon_sym_supply0] = ACTIONS(6345),
    [anon_sym_supply1] = ACTIONS(6345),
    [anon_sym_signed] = ACTIONS(6345),
    [anon_sym_unsigned] = ACTIONS(6345),
    [anon_sym_task] = ACTIONS(6345),
    [anon_sym_modport] = ACTIONS(6345),
    [anon_sym_assert] = ACTIONS(6345),
    [anon_sym_property] = ACTIONS(6345),
    [anon_sym_assume] = ACTIONS(6345),
    [anon_sym_cover] = ACTIONS(6345),
    [anon_sym_sequence] = ACTIONS(6345),
    [anon_sym_restrict] = ACTIONS(6345),
    [anon_sym_not] = ACTIONS(6345),
    [anon_sym_or] = ACTIONS(6345),
    [anon_sym_and] = ACTIONS(6345),
    [anon_sym_case] = ACTIONS(6345),
    [anon_sym_always] = ACTIONS(6345),
    [anon_sym_covergroup] = ACTIONS(6345),
    [anon_sym_let] = ACTIONS(6345),
    [anon_sym_pulldown] = ACTIONS(6345),
    [anon_sym_pullup] = ACTIONS(6345),
    [anon_sym_cmos] = ACTIONS(6345),
    [anon_sym_rcmos] = ACTIONS(6345),
    [anon_sym_bufif0] = ACTIONS(6345),
    [anon_sym_bufif1] = ACTIONS(6345),
    [anon_sym_notif0] = ACTIONS(6345),
    [anon_sym_notif1] = ACTIONS(6345),
    [anon_sym_nmos] = ACTIONS(6345),
    [anon_sym_pmos] = ACTIONS(6345),
    [anon_sym_rnmos] = ACTIONS(6345),
    [anon_sym_rpmos] = ACTIONS(6345),
    [anon_sym_nand] = ACTIONS(6345),
    [anon_sym_nor] = ACTIONS(6345),
    [anon_sym_xor] = ACTIONS(6345),
    [anon_sym_xnor] = ACTIONS(6345),
    [anon_sym_buf] = ACTIONS(6345),
    [anon_sym_tranif0] = ACTIONS(6345),
    [anon_sym_tranif1] = ACTIONS(6345),
    [anon_sym_rtranif1] = ACTIONS(6345),
    [anon_sym_rtranif0] = ACTIONS(6345),
    [anon_sym_tran] = ACTIONS(6345),
    [anon_sym_rtran] = ACTIONS(6345),
    [anon_sym_generate] = ACTIONS(6345),
    [anon_sym_for] = ACTIONS(6345),
    [anon_sym_initial] = ACTIONS(6345),
    [anon_sym_assign] = ACTIONS(6345),
    [anon_sym_alias] = ACTIONS(6345),
    [anon_sym_always_comb] = ACTIONS(6345),
    [anon_sym_always_latch] = ACTIONS(6345),
    [anon_sym_always_ff] = ACTIONS(6345),
    [anon_sym_final] = ACTIONS(6345),
    [anon_sym_while] = ACTIONS(6345),
    [anon_sym_global] = ACTIONS(6345),
    [anon_sym_specify] = ACTIONS(6345),
    [anon_sym_LPAREN_STAR] = ACTIONS(6347),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6347),
    [anon_sym_DOLLARunit] = ACTIONS(6347),
  },
  [1154] = {
    [ts_builtin_sym_end] = ACTIONS(6349),
    [sym_simple_identifier] = ACTIONS(6351),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6349),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6349),
    [anon_sym_BQUOTE] = ACTIONS(6351),
    [aux_sym_id_directive_token1] = ACTIONS(6349),
    [aux_sym_id_directive_token2] = ACTIONS(6349),
    [aux_sym_id_directive_token3] = ACTIONS(6349),
    [aux_sym_id_directive_token4] = ACTIONS(6351),
    [aux_sym_zero_directive_token1] = ACTIONS(6349),
    [aux_sym_zero_directive_token2] = ACTIONS(6349),
    [aux_sym_zero_directive_token3] = ACTIONS(6349),
    [aux_sym_zero_directive_token4] = ACTIONS(6349),
    [aux_sym_zero_directive_token5] = ACTIONS(6349),
    [aux_sym_zero_directive_token6] = ACTIONS(6349),
    [aux_sym_zero_directive_token7] = ACTIONS(6349),
    [aux_sym_zero_directive_token8] = ACTIONS(6349),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6349),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6349),
    [anon_sym_wire] = ACTIONS(6351),
    [anon_sym_tri] = ACTIONS(6351),
    [anon_sym_tri0] = ACTIONS(6351),
    [anon_sym_tri1] = ACTIONS(6351),
    [anon_sym_wand] = ACTIONS(6351),
    [anon_sym_triand] = ACTIONS(6351),
    [anon_sym_wor] = ACTIONS(6351),
    [anon_sym_trior] = ACTIONS(6351),
    [anon_sym_trireg] = ACTIONS(6351),
    [anon_sym_uwire] = ACTIONS(6351),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6349),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6349),
    [aux_sym_begin_keywords_token1] = ACTIONS(6349),
    [anon_sym_SEMI] = ACTIONS(6349),
    [anon_sym_endmodule] = ACTIONS(6351),
    [anon_sym_extern] = ACTIONS(6351),
    [anon_sym_module] = ACTIONS(6351),
    [anon_sym_macromodule] = ACTIONS(6351),
    [anon_sym_endinterface] = ACTIONS(6351),
    [anon_sym_interface] = ACTIONS(6351),
    [anon_sym_program] = ACTIONS(6351),
    [anon_sym_checker] = ACTIONS(6351),
    [anon_sym_virtual] = ACTIONS(6351),
    [anon_sym_class] = ACTIONS(6351),
    [anon_sym_package] = ACTIONS(6351),
    [anon_sym_timeunit] = ACTIONS(6351),
    [anon_sym_timeprecision] = ACTIONS(6351),
    [anon_sym_type] = ACTIONS(6351),
    [anon_sym_input] = ACTIONS(6351),
    [anon_sym_output] = ACTIONS(6351),
    [anon_sym_inout] = ACTIONS(6351),
    [anon_sym_ref] = ACTIONS(6351),
    [anon_sym_DOLLARfatal] = ACTIONS(6349),
    [anon_sym_DOLLARerror] = ACTIONS(6349),
    [anon_sym_DOLLARwarning] = ACTIONS(6349),
    [anon_sym_DOLLARinfo] = ACTIONS(6349),
    [anon_sym_default] = ACTIONS(6351),
    [anon_sym_clocking] = ACTIONS(6351),
    [anon_sym_defparam] = ACTIONS(6351),
    [anon_sym_bind] = ACTIONS(6351),
    [anon_sym_const] = ACTIONS(6351),
    [anon_sym_function] = ACTIONS(6351),
    [anon_sym_static] = ACTIONS(6351),
    [anon_sym_constraint] = ACTIONS(6351),
    [anon_sym_if] = ACTIONS(6351),
    [anon_sym_LBRACK] = ACTIONS(6349),
    [anon_sym_localparam] = ACTIONS(6351),
    [anon_sym_parameter] = ACTIONS(6351),
    [anon_sym_specparam] = ACTIONS(6351),
    [anon_sym_var] = ACTIONS(6351),
    [anon_sym_import] = ACTIONS(6351),
    [anon_sym_export] = ACTIONS(6351),
    [anon_sym_genvar] = ACTIONS(6351),
    [anon_sym_interconnect] = ACTIONS(6351),
    [anon_sym_typedef] = ACTIONS(6351),
    [anon_sym_enum] = ACTIONS(6351),
    [anon_sym_struct] = ACTIONS(6351),
    [anon_sym_union] = ACTIONS(6351),
    [anon_sym_nettype] = ACTIONS(6351),
    [anon_sym_automatic] = ACTIONS(6351),
    [anon_sym_string] = ACTIONS(6351),
    [anon_sym_chandle] = ACTIONS(6351),
    [anon_sym_event] = ACTIONS(6351),
    [anon_sym_byte] = ACTIONS(6351),
    [anon_sym_shortint] = ACTIONS(6351),
    [anon_sym_int] = ACTIONS(6351),
    [anon_sym_longint] = ACTIONS(6351),
    [anon_sym_integer] = ACTIONS(6351),
    [anon_sym_time] = ACTIONS(6351),
    [anon_sym_bit] = ACTIONS(6351),
    [anon_sym_logic] = ACTIONS(6351),
    [anon_sym_reg] = ACTIONS(6351),
    [anon_sym_shortreal] = ACTIONS(6351),
    [anon_sym_real] = ACTIONS(6351),
    [anon_sym_realtime] = ACTIONS(6351),
    [anon_sym_supply0] = ACTIONS(6351),
    [anon_sym_supply1] = ACTIONS(6351),
    [anon_sym_signed] = ACTIONS(6351),
    [anon_sym_unsigned] = ACTIONS(6351),
    [anon_sym_task] = ACTIONS(6351),
    [anon_sym_modport] = ACTIONS(6351),
    [anon_sym_assert] = ACTIONS(6351),
    [anon_sym_property] = ACTIONS(6351),
    [anon_sym_assume] = ACTIONS(6351),
    [anon_sym_cover] = ACTIONS(6351),
    [anon_sym_sequence] = ACTIONS(6351),
    [anon_sym_restrict] = ACTIONS(6351),
    [anon_sym_not] = ACTIONS(6351),
    [anon_sym_or] = ACTIONS(6351),
    [anon_sym_and] = ACTIONS(6351),
    [anon_sym_case] = ACTIONS(6351),
    [anon_sym_always] = ACTIONS(6351),
    [anon_sym_covergroup] = ACTIONS(6351),
    [anon_sym_let] = ACTIONS(6351),
    [anon_sym_pulldown] = ACTIONS(6351),
    [anon_sym_pullup] = ACTIONS(6351),
    [anon_sym_cmos] = ACTIONS(6351),
    [anon_sym_rcmos] = ACTIONS(6351),
    [anon_sym_bufif0] = ACTIONS(6351),
    [anon_sym_bufif1] = ACTIONS(6351),
    [anon_sym_notif0] = ACTIONS(6351),
    [anon_sym_notif1] = ACTIONS(6351),
    [anon_sym_nmos] = ACTIONS(6351),
    [anon_sym_pmos] = ACTIONS(6351),
    [anon_sym_rnmos] = ACTIONS(6351),
    [anon_sym_rpmos] = ACTIONS(6351),
    [anon_sym_nand] = ACTIONS(6351),
    [anon_sym_nor] = ACTIONS(6351),
    [anon_sym_xor] = ACTIONS(6351),
    [anon_sym_xnor] = ACTIONS(6351),
    [anon_sym_buf] = ACTIONS(6351),
    [anon_sym_tranif0] = ACTIONS(6351),
    [anon_sym_tranif1] = ACTIONS(6351),
    [anon_sym_rtranif1] = ACTIONS(6351),
    [anon_sym_rtranif0] = ACTIONS(6351),
    [anon_sym_tran] = ACTIONS(6351),
    [anon_sym_rtran] = ACTIONS(6351),
    [anon_sym_generate] = ACTIONS(6351),
    [anon_sym_for] = ACTIONS(6351),
    [anon_sym_primitive] = ACTIONS(6351),
    [anon_sym_initial] = ACTIONS(6351),
    [anon_sym_assign] = ACTIONS(6351),
    [anon_sym_alias] = ACTIONS(6351),
    [anon_sym_always_comb] = ACTIONS(6351),
    [anon_sym_always_latch] = ACTIONS(6351),
    [anon_sym_always_ff] = ACTIONS(6351),
    [anon_sym_final] = ACTIONS(6351),
    [anon_sym_global] = ACTIONS(6351),
    [anon_sym_specify] = ACTIONS(6351),
    [anon_sym_LPAREN_STAR] = ACTIONS(6349),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6349),
    [anon_sym_DOLLARunit] = ACTIONS(6349),
  },
  [1155] = {
    [ts_builtin_sym_end] = ACTIONS(6353),
    [sym_simple_identifier] = ACTIONS(6355),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6353),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6353),
    [anon_sym_BQUOTE] = ACTIONS(6355),
    [aux_sym_id_directive_token1] = ACTIONS(6353),
    [aux_sym_id_directive_token2] = ACTIONS(6353),
    [aux_sym_id_directive_token3] = ACTIONS(6353),
    [aux_sym_id_directive_token4] = ACTIONS(6355),
    [aux_sym_zero_directive_token1] = ACTIONS(6353),
    [aux_sym_zero_directive_token2] = ACTIONS(6353),
    [aux_sym_zero_directive_token3] = ACTIONS(6353),
    [aux_sym_zero_directive_token4] = ACTIONS(6353),
    [aux_sym_zero_directive_token5] = ACTIONS(6353),
    [aux_sym_zero_directive_token6] = ACTIONS(6353),
    [aux_sym_zero_directive_token7] = ACTIONS(6353),
    [aux_sym_zero_directive_token8] = ACTIONS(6353),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6353),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6353),
    [anon_sym_wire] = ACTIONS(6355),
    [anon_sym_tri] = ACTIONS(6355),
    [anon_sym_tri0] = ACTIONS(6355),
    [anon_sym_tri1] = ACTIONS(6355),
    [anon_sym_wand] = ACTIONS(6355),
    [anon_sym_triand] = ACTIONS(6355),
    [anon_sym_wor] = ACTIONS(6355),
    [anon_sym_trior] = ACTIONS(6355),
    [anon_sym_trireg] = ACTIONS(6355),
    [anon_sym_uwire] = ACTIONS(6355),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6353),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6353),
    [aux_sym_begin_keywords_token1] = ACTIONS(6353),
    [anon_sym_SEMI] = ACTIONS(6353),
    [anon_sym_endmodule] = ACTIONS(6355),
    [anon_sym_extern] = ACTIONS(6355),
    [anon_sym_module] = ACTIONS(6355),
    [anon_sym_macromodule] = ACTIONS(6355),
    [anon_sym_endinterface] = ACTIONS(6355),
    [anon_sym_interface] = ACTIONS(6355),
    [anon_sym_program] = ACTIONS(6355),
    [anon_sym_checker] = ACTIONS(6355),
    [anon_sym_virtual] = ACTIONS(6355),
    [anon_sym_class] = ACTIONS(6355),
    [anon_sym_package] = ACTIONS(6355),
    [anon_sym_timeunit] = ACTIONS(6355),
    [anon_sym_timeprecision] = ACTIONS(6355),
    [anon_sym_type] = ACTIONS(6355),
    [anon_sym_input] = ACTIONS(6355),
    [anon_sym_output] = ACTIONS(6355),
    [anon_sym_inout] = ACTIONS(6355),
    [anon_sym_ref] = ACTIONS(6355),
    [anon_sym_DOLLARfatal] = ACTIONS(6353),
    [anon_sym_DOLLARerror] = ACTIONS(6353),
    [anon_sym_DOLLARwarning] = ACTIONS(6353),
    [anon_sym_DOLLARinfo] = ACTIONS(6353),
    [anon_sym_default] = ACTIONS(6355),
    [anon_sym_clocking] = ACTIONS(6355),
    [anon_sym_defparam] = ACTIONS(6355),
    [anon_sym_bind] = ACTIONS(6355),
    [anon_sym_const] = ACTIONS(6355),
    [anon_sym_function] = ACTIONS(6355),
    [anon_sym_static] = ACTIONS(6355),
    [anon_sym_constraint] = ACTIONS(6355),
    [anon_sym_if] = ACTIONS(6355),
    [anon_sym_LBRACK] = ACTIONS(6353),
    [anon_sym_localparam] = ACTIONS(6355),
    [anon_sym_parameter] = ACTIONS(6355),
    [anon_sym_specparam] = ACTIONS(6355),
    [anon_sym_var] = ACTIONS(6355),
    [anon_sym_import] = ACTIONS(6355),
    [anon_sym_export] = ACTIONS(6355),
    [anon_sym_genvar] = ACTIONS(6355),
    [anon_sym_interconnect] = ACTIONS(6355),
    [anon_sym_typedef] = ACTIONS(6355),
    [anon_sym_enum] = ACTIONS(6355),
    [anon_sym_struct] = ACTIONS(6355),
    [anon_sym_union] = ACTIONS(6355),
    [anon_sym_nettype] = ACTIONS(6355),
    [anon_sym_automatic] = ACTIONS(6355),
    [anon_sym_string] = ACTIONS(6355),
    [anon_sym_chandle] = ACTIONS(6355),
    [anon_sym_event] = ACTIONS(6355),
    [anon_sym_byte] = ACTIONS(6355),
    [anon_sym_shortint] = ACTIONS(6355),
    [anon_sym_int] = ACTIONS(6355),
    [anon_sym_longint] = ACTIONS(6355),
    [anon_sym_integer] = ACTIONS(6355),
    [anon_sym_time] = ACTIONS(6355),
    [anon_sym_bit] = ACTIONS(6355),
    [anon_sym_logic] = ACTIONS(6355),
    [anon_sym_reg] = ACTIONS(6355),
    [anon_sym_shortreal] = ACTIONS(6355),
    [anon_sym_real] = ACTIONS(6355),
    [anon_sym_realtime] = ACTIONS(6355),
    [anon_sym_supply0] = ACTIONS(6355),
    [anon_sym_supply1] = ACTIONS(6355),
    [anon_sym_signed] = ACTIONS(6355),
    [anon_sym_unsigned] = ACTIONS(6355),
    [anon_sym_task] = ACTIONS(6355),
    [anon_sym_modport] = ACTIONS(6355),
    [anon_sym_assert] = ACTIONS(6355),
    [anon_sym_property] = ACTIONS(6355),
    [anon_sym_assume] = ACTIONS(6355),
    [anon_sym_cover] = ACTIONS(6355),
    [anon_sym_sequence] = ACTIONS(6355),
    [anon_sym_restrict] = ACTIONS(6355),
    [anon_sym_not] = ACTIONS(6355),
    [anon_sym_or] = ACTIONS(6355),
    [anon_sym_and] = ACTIONS(6355),
    [anon_sym_case] = ACTIONS(6355),
    [anon_sym_always] = ACTIONS(6355),
    [anon_sym_covergroup] = ACTIONS(6355),
    [anon_sym_let] = ACTIONS(6355),
    [anon_sym_pulldown] = ACTIONS(6355),
    [anon_sym_pullup] = ACTIONS(6355),
    [anon_sym_cmos] = ACTIONS(6355),
    [anon_sym_rcmos] = ACTIONS(6355),
    [anon_sym_bufif0] = ACTIONS(6355),
    [anon_sym_bufif1] = ACTIONS(6355),
    [anon_sym_notif0] = ACTIONS(6355),
    [anon_sym_notif1] = ACTIONS(6355),
    [anon_sym_nmos] = ACTIONS(6355),
    [anon_sym_pmos] = ACTIONS(6355),
    [anon_sym_rnmos] = ACTIONS(6355),
    [anon_sym_rpmos] = ACTIONS(6355),
    [anon_sym_nand] = ACTIONS(6355),
    [anon_sym_nor] = ACTIONS(6355),
    [anon_sym_xor] = ACTIONS(6355),
    [anon_sym_xnor] = ACTIONS(6355),
    [anon_sym_buf] = ACTIONS(6355),
    [anon_sym_tranif0] = ACTIONS(6355),
    [anon_sym_tranif1] = ACTIONS(6355),
    [anon_sym_rtranif1] = ACTIONS(6355),
    [anon_sym_rtranif0] = ACTIONS(6355),
    [anon_sym_tran] = ACTIONS(6355),
    [anon_sym_rtran] = ACTIONS(6355),
    [anon_sym_generate] = ACTIONS(6355),
    [anon_sym_for] = ACTIONS(6355),
    [anon_sym_primitive] = ACTIONS(6355),
    [anon_sym_initial] = ACTIONS(6355),
    [anon_sym_assign] = ACTIONS(6355),
    [anon_sym_alias] = ACTIONS(6355),
    [anon_sym_always_comb] = ACTIONS(6355),
    [anon_sym_always_latch] = ACTIONS(6355),
    [anon_sym_always_ff] = ACTIONS(6355),
    [anon_sym_final] = ACTIONS(6355),
    [anon_sym_global] = ACTIONS(6355),
    [anon_sym_specify] = ACTIONS(6355),
    [anon_sym_LPAREN_STAR] = ACTIONS(6353),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6353),
    [anon_sym_DOLLARunit] = ACTIONS(6353),
  },
  [1156] = {
    [sym_simple_identifier] = ACTIONS(6357),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6359),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6359),
    [anon_sym_BQUOTE] = ACTIONS(6357),
    [aux_sym_id_directive_token1] = ACTIONS(6359),
    [aux_sym_id_directive_token2] = ACTIONS(6359),
    [aux_sym_id_directive_token3] = ACTIONS(6359),
    [aux_sym_id_directive_token4] = ACTIONS(6357),
    [aux_sym_zero_directive_token1] = ACTIONS(6359),
    [aux_sym_zero_directive_token2] = ACTIONS(6359),
    [aux_sym_zero_directive_token3] = ACTIONS(6359),
    [aux_sym_zero_directive_token4] = ACTIONS(6359),
    [aux_sym_zero_directive_token5] = ACTIONS(6359),
    [aux_sym_zero_directive_token6] = ACTIONS(6359),
    [aux_sym_zero_directive_token7] = ACTIONS(6359),
    [aux_sym_zero_directive_token8] = ACTIONS(6359),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6359),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6359),
    [anon_sym_wire] = ACTIONS(6357),
    [anon_sym_tri] = ACTIONS(6357),
    [anon_sym_tri0] = ACTIONS(6357),
    [anon_sym_tri1] = ACTIONS(6357),
    [anon_sym_wand] = ACTIONS(6357),
    [anon_sym_triand] = ACTIONS(6357),
    [anon_sym_wor] = ACTIONS(6357),
    [anon_sym_trior] = ACTIONS(6357),
    [anon_sym_trireg] = ACTIONS(6357),
    [anon_sym_uwire] = ACTIONS(6357),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6359),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6359),
    [aux_sym_begin_keywords_token1] = ACTIONS(6359),
    [anon_sym_SEMI] = ACTIONS(6359),
    [anon_sym_endmodule] = ACTIONS(6357),
    [anon_sym_extern] = ACTIONS(6357),
    [anon_sym_module] = ACTIONS(6357),
    [anon_sym_macromodule] = ACTIONS(6357),
    [anon_sym_endinterface] = ACTIONS(6357),
    [anon_sym_interface] = ACTIONS(6357),
    [anon_sym_endprogram] = ACTIONS(6357),
    [anon_sym_program] = ACTIONS(6357),
    [anon_sym_checker] = ACTIONS(6357),
    [anon_sym_virtual] = ACTIONS(6357),
    [anon_sym_class] = ACTIONS(6357),
    [anon_sym_timeunit] = ACTIONS(6357),
    [anon_sym_timeprecision] = ACTIONS(6357),
    [anon_sym_type] = ACTIONS(6357),
    [anon_sym_input] = ACTIONS(6357),
    [anon_sym_output] = ACTIONS(6357),
    [anon_sym_inout] = ACTIONS(6357),
    [anon_sym_ref] = ACTIONS(6357),
    [anon_sym_DOLLARfatal] = ACTIONS(6359),
    [anon_sym_DOLLARerror] = ACTIONS(6359),
    [anon_sym_DOLLARwarning] = ACTIONS(6359),
    [anon_sym_DOLLARinfo] = ACTIONS(6359),
    [anon_sym_default] = ACTIONS(6357),
    [anon_sym_clocking] = ACTIONS(6357),
    [anon_sym_defparam] = ACTIONS(6357),
    [anon_sym_bind] = ACTIONS(6357),
    [anon_sym_const] = ACTIONS(6357),
    [anon_sym_function] = ACTIONS(6357),
    [anon_sym_static] = ACTIONS(6357),
    [anon_sym_constraint] = ACTIONS(6357),
    [anon_sym_if] = ACTIONS(6357),
    [anon_sym_else] = ACTIONS(6357),
    [anon_sym_LBRACK] = ACTIONS(6359),
    [anon_sym_localparam] = ACTIONS(6357),
    [anon_sym_parameter] = ACTIONS(6357),
    [anon_sym_specparam] = ACTIONS(6357),
    [anon_sym_var] = ACTIONS(6357),
    [anon_sym_import] = ACTIONS(6357),
    [anon_sym_export] = ACTIONS(6357),
    [anon_sym_genvar] = ACTIONS(6357),
    [anon_sym_interconnect] = ACTIONS(6357),
    [anon_sym_typedef] = ACTIONS(6357),
    [anon_sym_enum] = ACTIONS(6357),
    [anon_sym_struct] = ACTIONS(6357),
    [anon_sym_union] = ACTIONS(6357),
    [anon_sym_nettype] = ACTIONS(6357),
    [anon_sym_automatic] = ACTIONS(6357),
    [anon_sym_string] = ACTIONS(6357),
    [anon_sym_chandle] = ACTIONS(6357),
    [anon_sym_event] = ACTIONS(6357),
    [anon_sym_byte] = ACTIONS(6357),
    [anon_sym_shortint] = ACTIONS(6357),
    [anon_sym_int] = ACTIONS(6357),
    [anon_sym_longint] = ACTIONS(6357),
    [anon_sym_integer] = ACTIONS(6357),
    [anon_sym_time] = ACTIONS(6357),
    [anon_sym_bit] = ACTIONS(6357),
    [anon_sym_logic] = ACTIONS(6357),
    [anon_sym_reg] = ACTIONS(6357),
    [anon_sym_shortreal] = ACTIONS(6357),
    [anon_sym_real] = ACTIONS(6357),
    [anon_sym_realtime] = ACTIONS(6357),
    [anon_sym_supply0] = ACTIONS(6357),
    [anon_sym_supply1] = ACTIONS(6357),
    [anon_sym_signed] = ACTIONS(6357),
    [anon_sym_unsigned] = ACTIONS(6357),
    [anon_sym_task] = ACTIONS(6357),
    [anon_sym_modport] = ACTIONS(6357),
    [anon_sym_assert] = ACTIONS(6357),
    [anon_sym_property] = ACTIONS(6357),
    [anon_sym_assume] = ACTIONS(6357),
    [anon_sym_cover] = ACTIONS(6357),
    [anon_sym_sequence] = ACTIONS(6357),
    [anon_sym_restrict] = ACTIONS(6357),
    [anon_sym_not] = ACTIONS(6357),
    [anon_sym_or] = ACTIONS(6357),
    [anon_sym_and] = ACTIONS(6357),
    [anon_sym_case] = ACTIONS(6357),
    [anon_sym_always] = ACTIONS(6357),
    [anon_sym_covergroup] = ACTIONS(6357),
    [anon_sym_let] = ACTIONS(6357),
    [anon_sym_pulldown] = ACTIONS(6357),
    [anon_sym_pullup] = ACTIONS(6357),
    [anon_sym_cmos] = ACTIONS(6357),
    [anon_sym_rcmos] = ACTIONS(6357),
    [anon_sym_bufif0] = ACTIONS(6357),
    [anon_sym_bufif1] = ACTIONS(6357),
    [anon_sym_notif0] = ACTIONS(6357),
    [anon_sym_notif1] = ACTIONS(6357),
    [anon_sym_nmos] = ACTIONS(6357),
    [anon_sym_pmos] = ACTIONS(6357),
    [anon_sym_rnmos] = ACTIONS(6357),
    [anon_sym_rpmos] = ACTIONS(6357),
    [anon_sym_nand] = ACTIONS(6357),
    [anon_sym_nor] = ACTIONS(6357),
    [anon_sym_xor] = ACTIONS(6357),
    [anon_sym_xnor] = ACTIONS(6357),
    [anon_sym_buf] = ACTIONS(6357),
    [anon_sym_tranif0] = ACTIONS(6357),
    [anon_sym_tranif1] = ACTIONS(6357),
    [anon_sym_rtranif1] = ACTIONS(6357),
    [anon_sym_rtranif0] = ACTIONS(6357),
    [anon_sym_tran] = ACTIONS(6357),
    [anon_sym_rtran] = ACTIONS(6357),
    [anon_sym_generate] = ACTIONS(6357),
    [anon_sym_for] = ACTIONS(6357),
    [anon_sym_initial] = ACTIONS(6357),
    [anon_sym_assign] = ACTIONS(6357),
    [anon_sym_alias] = ACTIONS(6357),
    [anon_sym_always_comb] = ACTIONS(6357),
    [anon_sym_always_latch] = ACTIONS(6357),
    [anon_sym_always_ff] = ACTIONS(6357),
    [anon_sym_final] = ACTIONS(6357),
    [anon_sym_while] = ACTIONS(6357),
    [anon_sym_global] = ACTIONS(6357),
    [anon_sym_specify] = ACTIONS(6357),
    [anon_sym_LPAREN_STAR] = ACTIONS(6359),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6359),
    [anon_sym_DOLLARunit] = ACTIONS(6359),
  },
  [1157] = {
    [sym_simple_identifier] = ACTIONS(6361),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6363),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6363),
    [anon_sym_BQUOTE] = ACTIONS(6361),
    [aux_sym_id_directive_token1] = ACTIONS(6363),
    [aux_sym_id_directive_token2] = ACTIONS(6363),
    [aux_sym_id_directive_token3] = ACTIONS(6363),
    [aux_sym_id_directive_token4] = ACTIONS(6361),
    [aux_sym_zero_directive_token1] = ACTIONS(6363),
    [aux_sym_zero_directive_token2] = ACTIONS(6363),
    [aux_sym_zero_directive_token3] = ACTIONS(6363),
    [aux_sym_zero_directive_token4] = ACTIONS(6363),
    [aux_sym_zero_directive_token5] = ACTIONS(6363),
    [aux_sym_zero_directive_token6] = ACTIONS(6363),
    [aux_sym_zero_directive_token7] = ACTIONS(6363),
    [aux_sym_zero_directive_token8] = ACTIONS(6363),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6363),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6363),
    [anon_sym_wire] = ACTIONS(6361),
    [anon_sym_tri] = ACTIONS(6361),
    [anon_sym_tri0] = ACTIONS(6361),
    [anon_sym_tri1] = ACTIONS(6361),
    [anon_sym_wand] = ACTIONS(6361),
    [anon_sym_triand] = ACTIONS(6361),
    [anon_sym_wor] = ACTIONS(6361),
    [anon_sym_trior] = ACTIONS(6361),
    [anon_sym_trireg] = ACTIONS(6361),
    [anon_sym_uwire] = ACTIONS(6361),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6363),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6363),
    [aux_sym_begin_keywords_token1] = ACTIONS(6363),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_endmodule] = ACTIONS(6361),
    [anon_sym_extern] = ACTIONS(6361),
    [anon_sym_module] = ACTIONS(6361),
    [anon_sym_macromodule] = ACTIONS(6361),
    [anon_sym_endinterface] = ACTIONS(6361),
    [anon_sym_interface] = ACTIONS(6361),
    [anon_sym_endprogram] = ACTIONS(6361),
    [anon_sym_program] = ACTIONS(6361),
    [anon_sym_checker] = ACTIONS(6361),
    [anon_sym_virtual] = ACTIONS(6361),
    [anon_sym_class] = ACTIONS(6361),
    [anon_sym_timeunit] = ACTIONS(6361),
    [anon_sym_timeprecision] = ACTIONS(6361),
    [anon_sym_type] = ACTIONS(6361),
    [anon_sym_input] = ACTIONS(6361),
    [anon_sym_output] = ACTIONS(6361),
    [anon_sym_inout] = ACTIONS(6361),
    [anon_sym_ref] = ACTIONS(6361),
    [anon_sym_DOLLARfatal] = ACTIONS(6363),
    [anon_sym_DOLLARerror] = ACTIONS(6363),
    [anon_sym_DOLLARwarning] = ACTIONS(6363),
    [anon_sym_DOLLARinfo] = ACTIONS(6363),
    [anon_sym_default] = ACTIONS(6361),
    [anon_sym_clocking] = ACTIONS(6361),
    [anon_sym_defparam] = ACTIONS(6361),
    [anon_sym_bind] = ACTIONS(6361),
    [anon_sym_const] = ACTIONS(6361),
    [anon_sym_function] = ACTIONS(6361),
    [anon_sym_static] = ACTIONS(6361),
    [anon_sym_constraint] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6361),
    [anon_sym_else] = ACTIONS(6361),
    [anon_sym_LBRACK] = ACTIONS(6363),
    [anon_sym_localparam] = ACTIONS(6361),
    [anon_sym_parameter] = ACTIONS(6361),
    [anon_sym_specparam] = ACTIONS(6361),
    [anon_sym_var] = ACTIONS(6361),
    [anon_sym_import] = ACTIONS(6361),
    [anon_sym_export] = ACTIONS(6361),
    [anon_sym_genvar] = ACTIONS(6361),
    [anon_sym_interconnect] = ACTIONS(6361),
    [anon_sym_typedef] = ACTIONS(6361),
    [anon_sym_enum] = ACTIONS(6361),
    [anon_sym_struct] = ACTIONS(6361),
    [anon_sym_union] = ACTIONS(6361),
    [anon_sym_nettype] = ACTIONS(6361),
    [anon_sym_automatic] = ACTIONS(6361),
    [anon_sym_string] = ACTIONS(6361),
    [anon_sym_chandle] = ACTIONS(6361),
    [anon_sym_event] = ACTIONS(6361),
    [anon_sym_byte] = ACTIONS(6361),
    [anon_sym_shortint] = ACTIONS(6361),
    [anon_sym_int] = ACTIONS(6361),
    [anon_sym_longint] = ACTIONS(6361),
    [anon_sym_integer] = ACTIONS(6361),
    [anon_sym_time] = ACTIONS(6361),
    [anon_sym_bit] = ACTIONS(6361),
    [anon_sym_logic] = ACTIONS(6361),
    [anon_sym_reg] = ACTIONS(6361),
    [anon_sym_shortreal] = ACTIONS(6361),
    [anon_sym_real] = ACTIONS(6361),
    [anon_sym_realtime] = ACTIONS(6361),
    [anon_sym_supply0] = ACTIONS(6361),
    [anon_sym_supply1] = ACTIONS(6361),
    [anon_sym_signed] = ACTIONS(6361),
    [anon_sym_unsigned] = ACTIONS(6361),
    [anon_sym_task] = ACTIONS(6361),
    [anon_sym_modport] = ACTIONS(6361),
    [anon_sym_assert] = ACTIONS(6361),
    [anon_sym_property] = ACTIONS(6361),
    [anon_sym_assume] = ACTIONS(6361),
    [anon_sym_cover] = ACTIONS(6361),
    [anon_sym_sequence] = ACTIONS(6361),
    [anon_sym_restrict] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6361),
    [anon_sym_or] = ACTIONS(6361),
    [anon_sym_and] = ACTIONS(6361),
    [anon_sym_case] = ACTIONS(6361),
    [anon_sym_always] = ACTIONS(6361),
    [anon_sym_covergroup] = ACTIONS(6361),
    [anon_sym_let] = ACTIONS(6361),
    [anon_sym_pulldown] = ACTIONS(6361),
    [anon_sym_pullup] = ACTIONS(6361),
    [anon_sym_cmos] = ACTIONS(6361),
    [anon_sym_rcmos] = ACTIONS(6361),
    [anon_sym_bufif0] = ACTIONS(6361),
    [anon_sym_bufif1] = ACTIONS(6361),
    [anon_sym_notif0] = ACTIONS(6361),
    [anon_sym_notif1] = ACTIONS(6361),
    [anon_sym_nmos] = ACTIONS(6361),
    [anon_sym_pmos] = ACTIONS(6361),
    [anon_sym_rnmos] = ACTIONS(6361),
    [anon_sym_rpmos] = ACTIONS(6361),
    [anon_sym_nand] = ACTIONS(6361),
    [anon_sym_nor] = ACTIONS(6361),
    [anon_sym_xor] = ACTIONS(6361),
    [anon_sym_xnor] = ACTIONS(6361),
    [anon_sym_buf] = ACTIONS(6361),
    [anon_sym_tranif0] = ACTIONS(6361),
    [anon_sym_tranif1] = ACTIONS(6361),
    [anon_sym_rtranif1] = ACTIONS(6361),
    [anon_sym_rtranif0] = ACTIONS(6361),
    [anon_sym_tran] = ACTIONS(6361),
    [anon_sym_rtran] = ACTIONS(6361),
    [anon_sym_generate] = ACTIONS(6361),
    [anon_sym_for] = ACTIONS(6361),
    [anon_sym_initial] = ACTIONS(6361),
    [anon_sym_assign] = ACTIONS(6361),
    [anon_sym_alias] = ACTIONS(6361),
    [anon_sym_always_comb] = ACTIONS(6361),
    [anon_sym_always_latch] = ACTIONS(6361),
    [anon_sym_always_ff] = ACTIONS(6361),
    [anon_sym_final] = ACTIONS(6361),
    [anon_sym_while] = ACTIONS(6361),
    [anon_sym_global] = ACTIONS(6361),
    [anon_sym_specify] = ACTIONS(6361),
    [anon_sym_LPAREN_STAR] = ACTIONS(6363),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6363),
    [anon_sym_DOLLARunit] = ACTIONS(6363),
  },
  [1158] = {
    [sym_simple_identifier] = ACTIONS(6365),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6367),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6367),
    [anon_sym_BQUOTE] = ACTIONS(6365),
    [aux_sym_id_directive_token1] = ACTIONS(6367),
    [aux_sym_id_directive_token2] = ACTIONS(6367),
    [aux_sym_id_directive_token3] = ACTIONS(6367),
    [aux_sym_id_directive_token4] = ACTIONS(6365),
    [aux_sym_zero_directive_token1] = ACTIONS(6367),
    [aux_sym_zero_directive_token2] = ACTIONS(6367),
    [aux_sym_zero_directive_token3] = ACTIONS(6367),
    [aux_sym_zero_directive_token4] = ACTIONS(6367),
    [aux_sym_zero_directive_token5] = ACTIONS(6367),
    [aux_sym_zero_directive_token6] = ACTIONS(6367),
    [aux_sym_zero_directive_token7] = ACTIONS(6367),
    [aux_sym_zero_directive_token8] = ACTIONS(6367),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6367),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6367),
    [anon_sym_wire] = ACTIONS(6365),
    [anon_sym_tri] = ACTIONS(6365),
    [anon_sym_tri0] = ACTIONS(6365),
    [anon_sym_tri1] = ACTIONS(6365),
    [anon_sym_wand] = ACTIONS(6365),
    [anon_sym_triand] = ACTIONS(6365),
    [anon_sym_wor] = ACTIONS(6365),
    [anon_sym_trior] = ACTIONS(6365),
    [anon_sym_trireg] = ACTIONS(6365),
    [anon_sym_uwire] = ACTIONS(6365),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6367),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6367),
    [aux_sym_begin_keywords_token1] = ACTIONS(6367),
    [anon_sym_SEMI] = ACTIONS(6367),
    [anon_sym_endmodule] = ACTIONS(6365),
    [anon_sym_COLON] = ACTIONS(6369),
    [anon_sym_extern] = ACTIONS(6365),
    [anon_sym_module] = ACTIONS(6365),
    [anon_sym_macromodule] = ACTIONS(6365),
    [anon_sym_endinterface] = ACTIONS(6365),
    [anon_sym_interface] = ACTIONS(6365),
    [anon_sym_endprogram] = ACTIONS(6365),
    [anon_sym_program] = ACTIONS(6365),
    [anon_sym_checker] = ACTIONS(6365),
    [anon_sym_virtual] = ACTIONS(6365),
    [anon_sym_class] = ACTIONS(6365),
    [anon_sym_timeunit] = ACTIONS(6365),
    [anon_sym_timeprecision] = ACTIONS(6365),
    [anon_sym_type] = ACTIONS(6365),
    [anon_sym_input] = ACTIONS(6365),
    [anon_sym_output] = ACTIONS(6365),
    [anon_sym_inout] = ACTIONS(6365),
    [anon_sym_ref] = ACTIONS(6365),
    [anon_sym_DOLLARfatal] = ACTIONS(6367),
    [anon_sym_DOLLARerror] = ACTIONS(6367),
    [anon_sym_DOLLARwarning] = ACTIONS(6367),
    [anon_sym_DOLLARinfo] = ACTIONS(6367),
    [anon_sym_default] = ACTIONS(6365),
    [anon_sym_clocking] = ACTIONS(6365),
    [anon_sym_defparam] = ACTIONS(6365),
    [anon_sym_bind] = ACTIONS(6365),
    [anon_sym_const] = ACTIONS(6365),
    [anon_sym_function] = ACTIONS(6365),
    [anon_sym_static] = ACTIONS(6365),
    [anon_sym_constraint] = ACTIONS(6365),
    [anon_sym_if] = ACTIONS(6365),
    [anon_sym_else] = ACTIONS(6365),
    [anon_sym_LBRACK] = ACTIONS(6367),
    [anon_sym_localparam] = ACTIONS(6365),
    [anon_sym_parameter] = ACTIONS(6365),
    [anon_sym_specparam] = ACTIONS(6365),
    [anon_sym_var] = ACTIONS(6365),
    [anon_sym_import] = ACTIONS(6365),
    [anon_sym_export] = ACTIONS(6365),
    [anon_sym_genvar] = ACTIONS(6365),
    [anon_sym_interconnect] = ACTIONS(6365),
    [anon_sym_typedef] = ACTIONS(6365),
    [anon_sym_enum] = ACTIONS(6365),
    [anon_sym_struct] = ACTIONS(6365),
    [anon_sym_union] = ACTIONS(6365),
    [anon_sym_nettype] = ACTIONS(6365),
    [anon_sym_automatic] = ACTIONS(6365),
    [anon_sym_string] = ACTIONS(6365),
    [anon_sym_chandle] = ACTIONS(6365),
    [anon_sym_event] = ACTIONS(6365),
    [anon_sym_byte] = ACTIONS(6365),
    [anon_sym_shortint] = ACTIONS(6365),
    [anon_sym_int] = ACTIONS(6365),
    [anon_sym_longint] = ACTIONS(6365),
    [anon_sym_integer] = ACTIONS(6365),
    [anon_sym_time] = ACTIONS(6365),
    [anon_sym_bit] = ACTIONS(6365),
    [anon_sym_logic] = ACTIONS(6365),
    [anon_sym_reg] = ACTIONS(6365),
    [anon_sym_shortreal] = ACTIONS(6365),
    [anon_sym_real] = ACTIONS(6365),
    [anon_sym_realtime] = ACTIONS(6365),
    [anon_sym_supply0] = ACTIONS(6365),
    [anon_sym_supply1] = ACTIONS(6365),
    [anon_sym_signed] = ACTIONS(6365),
    [anon_sym_unsigned] = ACTIONS(6365),
    [anon_sym_task] = ACTIONS(6365),
    [anon_sym_modport] = ACTIONS(6365),
    [anon_sym_assert] = ACTIONS(6365),
    [anon_sym_property] = ACTIONS(6365),
    [anon_sym_assume] = ACTIONS(6365),
    [anon_sym_cover] = ACTIONS(6365),
    [anon_sym_sequence] = ACTIONS(6365),
    [anon_sym_restrict] = ACTIONS(6365),
    [anon_sym_not] = ACTIONS(6365),
    [anon_sym_or] = ACTIONS(6365),
    [anon_sym_and] = ACTIONS(6365),
    [anon_sym_case] = ACTIONS(6365),
    [anon_sym_always] = ACTIONS(6365),
    [anon_sym_covergroup] = ACTIONS(6365),
    [anon_sym_let] = ACTIONS(6365),
    [anon_sym_pulldown] = ACTIONS(6365),
    [anon_sym_pullup] = ACTIONS(6365),
    [anon_sym_cmos] = ACTIONS(6365),
    [anon_sym_rcmos] = ACTIONS(6365),
    [anon_sym_bufif0] = ACTIONS(6365),
    [anon_sym_bufif1] = ACTIONS(6365),
    [anon_sym_notif0] = ACTIONS(6365),
    [anon_sym_notif1] = ACTIONS(6365),
    [anon_sym_nmos] = ACTIONS(6365),
    [anon_sym_pmos] = ACTIONS(6365),
    [anon_sym_rnmos] = ACTIONS(6365),
    [anon_sym_rpmos] = ACTIONS(6365),
    [anon_sym_nand] = ACTIONS(6365),
    [anon_sym_nor] = ACTIONS(6365),
    [anon_sym_xor] = ACTIONS(6365),
    [anon_sym_xnor] = ACTIONS(6365),
    [anon_sym_buf] = ACTIONS(6365),
    [anon_sym_tranif0] = ACTIONS(6365),
    [anon_sym_tranif1] = ACTIONS(6365),
    [anon_sym_rtranif1] = ACTIONS(6365),
    [anon_sym_rtranif0] = ACTIONS(6365),
    [anon_sym_tran] = ACTIONS(6365),
    [anon_sym_rtran] = ACTIONS(6365),
    [anon_sym_generate] = ACTIONS(6365),
    [anon_sym_for] = ACTIONS(6365),
    [anon_sym_initial] = ACTIONS(6365),
    [anon_sym_assign] = ACTIONS(6365),
    [anon_sym_alias] = ACTIONS(6365),
    [anon_sym_always_comb] = ACTIONS(6365),
    [anon_sym_always_latch] = ACTIONS(6365),
    [anon_sym_always_ff] = ACTIONS(6365),
    [anon_sym_final] = ACTIONS(6365),
    [anon_sym_global] = ACTIONS(6365),
    [anon_sym_specify] = ACTIONS(6365),
    [anon_sym_LPAREN_STAR] = ACTIONS(6367),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6367),
    [anon_sym_DOLLARunit] = ACTIONS(6367),
  },
  [1159] = {
    [ts_builtin_sym_end] = ACTIONS(6371),
    [sym_simple_identifier] = ACTIONS(6373),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6371),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6371),
    [anon_sym_BQUOTE] = ACTIONS(6373),
    [aux_sym_id_directive_token1] = ACTIONS(6371),
    [aux_sym_id_directive_token2] = ACTIONS(6371),
    [aux_sym_id_directive_token3] = ACTIONS(6371),
    [aux_sym_id_directive_token4] = ACTIONS(6373),
    [aux_sym_zero_directive_token1] = ACTIONS(6371),
    [aux_sym_zero_directive_token2] = ACTIONS(6371),
    [aux_sym_zero_directive_token3] = ACTIONS(6371),
    [aux_sym_zero_directive_token4] = ACTIONS(6371),
    [aux_sym_zero_directive_token5] = ACTIONS(6371),
    [aux_sym_zero_directive_token6] = ACTIONS(6371),
    [aux_sym_zero_directive_token7] = ACTIONS(6371),
    [aux_sym_zero_directive_token8] = ACTIONS(6371),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6371),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6371),
    [anon_sym_wire] = ACTIONS(6373),
    [anon_sym_tri] = ACTIONS(6373),
    [anon_sym_tri0] = ACTIONS(6373),
    [anon_sym_tri1] = ACTIONS(6373),
    [anon_sym_wand] = ACTIONS(6373),
    [anon_sym_triand] = ACTIONS(6373),
    [anon_sym_wor] = ACTIONS(6373),
    [anon_sym_trior] = ACTIONS(6373),
    [anon_sym_trireg] = ACTIONS(6373),
    [anon_sym_uwire] = ACTIONS(6373),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6371),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6371),
    [aux_sym_begin_keywords_token1] = ACTIONS(6371),
    [anon_sym_SEMI] = ACTIONS(6371),
    [anon_sym_endmodule] = ACTIONS(6373),
    [anon_sym_extern] = ACTIONS(6373),
    [anon_sym_module] = ACTIONS(6373),
    [anon_sym_macromodule] = ACTIONS(6373),
    [anon_sym_endinterface] = ACTIONS(6373),
    [anon_sym_interface] = ACTIONS(6373),
    [anon_sym_program] = ACTIONS(6373),
    [anon_sym_checker] = ACTIONS(6373),
    [anon_sym_virtual] = ACTIONS(6373),
    [anon_sym_class] = ACTIONS(6373),
    [anon_sym_package] = ACTIONS(6373),
    [anon_sym_timeunit] = ACTIONS(6373),
    [anon_sym_timeprecision] = ACTIONS(6373),
    [anon_sym_type] = ACTIONS(6373),
    [anon_sym_input] = ACTIONS(6373),
    [anon_sym_output] = ACTIONS(6373),
    [anon_sym_inout] = ACTIONS(6373),
    [anon_sym_ref] = ACTIONS(6373),
    [anon_sym_DOLLARfatal] = ACTIONS(6371),
    [anon_sym_DOLLARerror] = ACTIONS(6371),
    [anon_sym_DOLLARwarning] = ACTIONS(6371),
    [anon_sym_DOLLARinfo] = ACTIONS(6371),
    [anon_sym_default] = ACTIONS(6373),
    [anon_sym_clocking] = ACTIONS(6373),
    [anon_sym_defparam] = ACTIONS(6373),
    [anon_sym_bind] = ACTIONS(6373),
    [anon_sym_const] = ACTIONS(6373),
    [anon_sym_function] = ACTIONS(6373),
    [anon_sym_static] = ACTIONS(6373),
    [anon_sym_constraint] = ACTIONS(6373),
    [anon_sym_if] = ACTIONS(6373),
    [anon_sym_LBRACK] = ACTIONS(6371),
    [anon_sym_localparam] = ACTIONS(6373),
    [anon_sym_parameter] = ACTIONS(6373),
    [anon_sym_specparam] = ACTIONS(6373),
    [anon_sym_var] = ACTIONS(6373),
    [anon_sym_import] = ACTIONS(6373),
    [anon_sym_export] = ACTIONS(6373),
    [anon_sym_genvar] = ACTIONS(6373),
    [anon_sym_interconnect] = ACTIONS(6373),
    [anon_sym_typedef] = ACTIONS(6373),
    [anon_sym_enum] = ACTIONS(6373),
    [anon_sym_struct] = ACTIONS(6373),
    [anon_sym_union] = ACTIONS(6373),
    [anon_sym_nettype] = ACTIONS(6373),
    [anon_sym_automatic] = ACTIONS(6373),
    [anon_sym_string] = ACTIONS(6373),
    [anon_sym_chandle] = ACTIONS(6373),
    [anon_sym_event] = ACTIONS(6373),
    [anon_sym_byte] = ACTIONS(6373),
    [anon_sym_shortint] = ACTIONS(6373),
    [anon_sym_int] = ACTIONS(6373),
    [anon_sym_longint] = ACTIONS(6373),
    [anon_sym_integer] = ACTIONS(6373),
    [anon_sym_time] = ACTIONS(6373),
    [anon_sym_bit] = ACTIONS(6373),
    [anon_sym_logic] = ACTIONS(6373),
    [anon_sym_reg] = ACTIONS(6373),
    [anon_sym_shortreal] = ACTIONS(6373),
    [anon_sym_real] = ACTIONS(6373),
    [anon_sym_realtime] = ACTIONS(6373),
    [anon_sym_supply0] = ACTIONS(6373),
    [anon_sym_supply1] = ACTIONS(6373),
    [anon_sym_signed] = ACTIONS(6373),
    [anon_sym_unsigned] = ACTIONS(6373),
    [anon_sym_task] = ACTIONS(6373),
    [anon_sym_modport] = ACTIONS(6373),
    [anon_sym_assert] = ACTIONS(6373),
    [anon_sym_property] = ACTIONS(6373),
    [anon_sym_assume] = ACTIONS(6373),
    [anon_sym_cover] = ACTIONS(6373),
    [anon_sym_sequence] = ACTIONS(6373),
    [anon_sym_restrict] = ACTIONS(6373),
    [anon_sym_not] = ACTIONS(6373),
    [anon_sym_or] = ACTIONS(6373),
    [anon_sym_and] = ACTIONS(6373),
    [anon_sym_case] = ACTIONS(6373),
    [anon_sym_always] = ACTIONS(6373),
    [anon_sym_covergroup] = ACTIONS(6373),
    [anon_sym_let] = ACTIONS(6373),
    [anon_sym_pulldown] = ACTIONS(6373),
    [anon_sym_pullup] = ACTIONS(6373),
    [anon_sym_cmos] = ACTIONS(6373),
    [anon_sym_rcmos] = ACTIONS(6373),
    [anon_sym_bufif0] = ACTIONS(6373),
    [anon_sym_bufif1] = ACTIONS(6373),
    [anon_sym_notif0] = ACTIONS(6373),
    [anon_sym_notif1] = ACTIONS(6373),
    [anon_sym_nmos] = ACTIONS(6373),
    [anon_sym_pmos] = ACTIONS(6373),
    [anon_sym_rnmos] = ACTIONS(6373),
    [anon_sym_rpmos] = ACTIONS(6373),
    [anon_sym_nand] = ACTIONS(6373),
    [anon_sym_nor] = ACTIONS(6373),
    [anon_sym_xor] = ACTIONS(6373),
    [anon_sym_xnor] = ACTIONS(6373),
    [anon_sym_buf] = ACTIONS(6373),
    [anon_sym_tranif0] = ACTIONS(6373),
    [anon_sym_tranif1] = ACTIONS(6373),
    [anon_sym_rtranif1] = ACTIONS(6373),
    [anon_sym_rtranif0] = ACTIONS(6373),
    [anon_sym_tran] = ACTIONS(6373),
    [anon_sym_rtran] = ACTIONS(6373),
    [anon_sym_generate] = ACTIONS(6373),
    [anon_sym_for] = ACTIONS(6373),
    [anon_sym_primitive] = ACTIONS(6373),
    [anon_sym_initial] = ACTIONS(6373),
    [anon_sym_assign] = ACTIONS(6373),
    [anon_sym_alias] = ACTIONS(6373),
    [anon_sym_always_comb] = ACTIONS(6373),
    [anon_sym_always_latch] = ACTIONS(6373),
    [anon_sym_always_ff] = ACTIONS(6373),
    [anon_sym_final] = ACTIONS(6373),
    [anon_sym_global] = ACTIONS(6373),
    [anon_sym_specify] = ACTIONS(6373),
    [anon_sym_LPAREN_STAR] = ACTIONS(6371),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6371),
    [anon_sym_DOLLARunit] = ACTIONS(6371),
  },
  [1160] = {
    [sym_simple_identifier] = ACTIONS(6375),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6377),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6377),
    [anon_sym_BQUOTE] = ACTIONS(6375),
    [aux_sym_id_directive_token1] = ACTIONS(6377),
    [aux_sym_id_directive_token2] = ACTIONS(6377),
    [aux_sym_id_directive_token3] = ACTIONS(6377),
    [aux_sym_id_directive_token4] = ACTIONS(6375),
    [aux_sym_zero_directive_token1] = ACTIONS(6377),
    [aux_sym_zero_directive_token2] = ACTIONS(6377),
    [aux_sym_zero_directive_token3] = ACTIONS(6377),
    [aux_sym_zero_directive_token4] = ACTIONS(6377),
    [aux_sym_zero_directive_token5] = ACTIONS(6377),
    [aux_sym_zero_directive_token6] = ACTIONS(6377),
    [aux_sym_zero_directive_token7] = ACTIONS(6377),
    [aux_sym_zero_directive_token8] = ACTIONS(6377),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6377),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6377),
    [anon_sym_wire] = ACTIONS(6375),
    [anon_sym_tri] = ACTIONS(6375),
    [anon_sym_tri0] = ACTIONS(6375),
    [anon_sym_tri1] = ACTIONS(6375),
    [anon_sym_wand] = ACTIONS(6375),
    [anon_sym_triand] = ACTIONS(6375),
    [anon_sym_wor] = ACTIONS(6375),
    [anon_sym_trior] = ACTIONS(6375),
    [anon_sym_trireg] = ACTIONS(6375),
    [anon_sym_uwire] = ACTIONS(6375),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6377),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6377),
    [aux_sym_begin_keywords_token1] = ACTIONS(6377),
    [anon_sym_SEMI] = ACTIONS(6377),
    [anon_sym_endmodule] = ACTIONS(6375),
    [anon_sym_extern] = ACTIONS(6375),
    [anon_sym_module] = ACTIONS(6375),
    [anon_sym_macromodule] = ACTIONS(6375),
    [anon_sym_endinterface] = ACTIONS(6375),
    [anon_sym_interface] = ACTIONS(6375),
    [anon_sym_endprogram] = ACTIONS(6375),
    [anon_sym_program] = ACTIONS(6375),
    [anon_sym_checker] = ACTIONS(6375),
    [anon_sym_virtual] = ACTIONS(6375),
    [anon_sym_class] = ACTIONS(6375),
    [anon_sym_timeunit] = ACTIONS(6375),
    [anon_sym_timeprecision] = ACTIONS(6375),
    [anon_sym_type] = ACTIONS(6375),
    [anon_sym_input] = ACTIONS(6375),
    [anon_sym_output] = ACTIONS(6375),
    [anon_sym_inout] = ACTIONS(6375),
    [anon_sym_ref] = ACTIONS(6375),
    [anon_sym_DOLLARfatal] = ACTIONS(6377),
    [anon_sym_DOLLARerror] = ACTIONS(6377),
    [anon_sym_DOLLARwarning] = ACTIONS(6377),
    [anon_sym_DOLLARinfo] = ACTIONS(6377),
    [anon_sym_default] = ACTIONS(6375),
    [anon_sym_clocking] = ACTIONS(6375),
    [anon_sym_defparam] = ACTIONS(6375),
    [anon_sym_bind] = ACTIONS(6375),
    [anon_sym_const] = ACTIONS(6375),
    [anon_sym_function] = ACTIONS(6375),
    [anon_sym_static] = ACTIONS(6375),
    [anon_sym_constraint] = ACTIONS(6375),
    [anon_sym_if] = ACTIONS(6375),
    [anon_sym_else] = ACTIONS(6375),
    [anon_sym_LBRACK] = ACTIONS(6377),
    [anon_sym_localparam] = ACTIONS(6375),
    [anon_sym_parameter] = ACTIONS(6375),
    [anon_sym_specparam] = ACTIONS(6375),
    [anon_sym_var] = ACTIONS(6375),
    [anon_sym_import] = ACTIONS(6375),
    [anon_sym_export] = ACTIONS(6375),
    [anon_sym_genvar] = ACTIONS(6375),
    [anon_sym_interconnect] = ACTIONS(6375),
    [anon_sym_typedef] = ACTIONS(6375),
    [anon_sym_enum] = ACTIONS(6375),
    [anon_sym_struct] = ACTIONS(6375),
    [anon_sym_union] = ACTIONS(6375),
    [anon_sym_nettype] = ACTIONS(6375),
    [anon_sym_automatic] = ACTIONS(6375),
    [anon_sym_string] = ACTIONS(6375),
    [anon_sym_chandle] = ACTIONS(6375),
    [anon_sym_event] = ACTIONS(6375),
    [anon_sym_byte] = ACTIONS(6375),
    [anon_sym_shortint] = ACTIONS(6375),
    [anon_sym_int] = ACTIONS(6375),
    [anon_sym_longint] = ACTIONS(6375),
    [anon_sym_integer] = ACTIONS(6375),
    [anon_sym_time] = ACTIONS(6375),
    [anon_sym_bit] = ACTIONS(6375),
    [anon_sym_logic] = ACTIONS(6375),
    [anon_sym_reg] = ACTIONS(6375),
    [anon_sym_shortreal] = ACTIONS(6375),
    [anon_sym_real] = ACTIONS(6375),
    [anon_sym_realtime] = ACTIONS(6375),
    [anon_sym_supply0] = ACTIONS(6375),
    [anon_sym_supply1] = ACTIONS(6375),
    [anon_sym_signed] = ACTIONS(6375),
    [anon_sym_unsigned] = ACTIONS(6375),
    [anon_sym_task] = ACTIONS(6375),
    [anon_sym_modport] = ACTIONS(6375),
    [anon_sym_assert] = ACTIONS(6375),
    [anon_sym_property] = ACTIONS(6375),
    [anon_sym_assume] = ACTIONS(6375),
    [anon_sym_cover] = ACTIONS(6375),
    [anon_sym_sequence] = ACTIONS(6375),
    [anon_sym_restrict] = ACTIONS(6375),
    [anon_sym_not] = ACTIONS(6375),
    [anon_sym_or] = ACTIONS(6375),
    [anon_sym_and] = ACTIONS(6375),
    [anon_sym_case] = ACTIONS(6375),
    [anon_sym_always] = ACTIONS(6375),
    [anon_sym_covergroup] = ACTIONS(6375),
    [anon_sym_let] = ACTIONS(6375),
    [anon_sym_pulldown] = ACTIONS(6375),
    [anon_sym_pullup] = ACTIONS(6375),
    [anon_sym_cmos] = ACTIONS(6375),
    [anon_sym_rcmos] = ACTIONS(6375),
    [anon_sym_bufif0] = ACTIONS(6375),
    [anon_sym_bufif1] = ACTIONS(6375),
    [anon_sym_notif0] = ACTIONS(6375),
    [anon_sym_notif1] = ACTIONS(6375),
    [anon_sym_nmos] = ACTIONS(6375),
    [anon_sym_pmos] = ACTIONS(6375),
    [anon_sym_rnmos] = ACTIONS(6375),
    [anon_sym_rpmos] = ACTIONS(6375),
    [anon_sym_nand] = ACTIONS(6375),
    [anon_sym_nor] = ACTIONS(6375),
    [anon_sym_xor] = ACTIONS(6375),
    [anon_sym_xnor] = ACTIONS(6375),
    [anon_sym_buf] = ACTIONS(6375),
    [anon_sym_tranif0] = ACTIONS(6375),
    [anon_sym_tranif1] = ACTIONS(6375),
    [anon_sym_rtranif1] = ACTIONS(6375),
    [anon_sym_rtranif0] = ACTIONS(6375),
    [anon_sym_tran] = ACTIONS(6375),
    [anon_sym_rtran] = ACTIONS(6375),
    [anon_sym_generate] = ACTIONS(6375),
    [anon_sym_for] = ACTIONS(6375),
    [anon_sym_initial] = ACTIONS(6375),
    [anon_sym_assign] = ACTIONS(6375),
    [anon_sym_alias] = ACTIONS(6375),
    [anon_sym_always_comb] = ACTIONS(6375),
    [anon_sym_always_latch] = ACTIONS(6375),
    [anon_sym_always_ff] = ACTIONS(6375),
    [anon_sym_final] = ACTIONS(6375),
    [anon_sym_while] = ACTIONS(6375),
    [anon_sym_global] = ACTIONS(6375),
    [anon_sym_specify] = ACTIONS(6375),
    [anon_sym_LPAREN_STAR] = ACTIONS(6377),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6377),
    [anon_sym_DOLLARunit] = ACTIONS(6377),
  },
  [1161] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6381),
    [anon_sym_BQUOTE] = ACTIONS(6379),
    [aux_sym_id_directive_token1] = ACTIONS(6381),
    [aux_sym_id_directive_token2] = ACTIONS(6381),
    [aux_sym_id_directive_token3] = ACTIONS(6381),
    [aux_sym_id_directive_token4] = ACTIONS(6379),
    [aux_sym_zero_directive_token1] = ACTIONS(6381),
    [aux_sym_zero_directive_token2] = ACTIONS(6381),
    [aux_sym_zero_directive_token3] = ACTIONS(6381),
    [aux_sym_zero_directive_token4] = ACTIONS(6381),
    [aux_sym_zero_directive_token5] = ACTIONS(6381),
    [aux_sym_zero_directive_token6] = ACTIONS(6381),
    [aux_sym_zero_directive_token7] = ACTIONS(6381),
    [aux_sym_zero_directive_token8] = ACTIONS(6381),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6381),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6381),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_begin_keywords_token1] = ACTIONS(6381),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_endmodule] = ACTIONS(6379),
    [anon_sym_COLON] = ACTIONS(6383),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_module] = ACTIONS(6379),
    [anon_sym_macromodule] = ACTIONS(6379),
    [anon_sym_endinterface] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_endprogram] = ACTIONS(6379),
    [anon_sym_program] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_timeunit] = ACTIONS(6379),
    [anon_sym_timeprecision] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_input] = ACTIONS(6379),
    [anon_sym_output] = ACTIONS(6379),
    [anon_sym_inout] = ACTIONS(6379),
    [anon_sym_ref] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_specparam] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_modport] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_specify] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [1162] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5706),
    [anon_sym_BQUOTE] = ACTIONS(5704),
    [aux_sym_id_directive_token1] = ACTIONS(5706),
    [aux_sym_id_directive_token2] = ACTIONS(5706),
    [aux_sym_id_directive_token3] = ACTIONS(5706),
    [aux_sym_id_directive_token4] = ACTIONS(5704),
    [aux_sym_zero_directive_token1] = ACTIONS(5706),
    [aux_sym_zero_directive_token2] = ACTIONS(5706),
    [aux_sym_zero_directive_token3] = ACTIONS(5706),
    [aux_sym_zero_directive_token4] = ACTIONS(5706),
    [aux_sym_zero_directive_token5] = ACTIONS(5706),
    [aux_sym_zero_directive_token6] = ACTIONS(5706),
    [aux_sym_zero_directive_token7] = ACTIONS(5706),
    [aux_sym_zero_directive_token8] = ACTIONS(5706),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5706),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5706),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5706),
    [aux_sym_begin_keywords_token1] = ACTIONS(5706),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_endmodule] = ACTIONS(5704),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_module] = ACTIONS(5704),
    [anon_sym_macromodule] = ACTIONS(5704),
    [anon_sym_endinterface] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_endprogram] = ACTIONS(5704),
    [anon_sym_program] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_timeunit] = ACTIONS(5704),
    [anon_sym_timeprecision] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_input] = ACTIONS(5704),
    [anon_sym_output] = ACTIONS(5704),
    [anon_sym_inout] = ACTIONS(5704),
    [anon_sym_ref] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_specparam] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_modport] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_while] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_specify] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [1163] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5716),
    [anon_sym_BQUOTE] = ACTIONS(5714),
    [aux_sym_id_directive_token1] = ACTIONS(5716),
    [aux_sym_id_directive_token2] = ACTIONS(5716),
    [aux_sym_id_directive_token3] = ACTIONS(5716),
    [aux_sym_id_directive_token4] = ACTIONS(5714),
    [aux_sym_zero_directive_token1] = ACTIONS(5716),
    [aux_sym_zero_directive_token2] = ACTIONS(5716),
    [aux_sym_zero_directive_token3] = ACTIONS(5716),
    [aux_sym_zero_directive_token4] = ACTIONS(5716),
    [aux_sym_zero_directive_token5] = ACTIONS(5716),
    [aux_sym_zero_directive_token6] = ACTIONS(5716),
    [aux_sym_zero_directive_token7] = ACTIONS(5716),
    [aux_sym_zero_directive_token8] = ACTIONS(5716),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5716),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5716),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5716),
    [aux_sym_begin_keywords_token1] = ACTIONS(5716),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_endmodule] = ACTIONS(5714),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_module] = ACTIONS(5714),
    [anon_sym_macromodule] = ACTIONS(5714),
    [anon_sym_endinterface] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_endprogram] = ACTIONS(5714),
    [anon_sym_program] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_timeunit] = ACTIONS(5714),
    [anon_sym_timeprecision] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_input] = ACTIONS(5714),
    [anon_sym_output] = ACTIONS(5714),
    [anon_sym_inout] = ACTIONS(5714),
    [anon_sym_ref] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_specparam] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_modport] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_while] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_specify] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [1164] = {
    [sym_simple_identifier] = ACTIONS(6385),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6387),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6387),
    [anon_sym_BQUOTE] = ACTIONS(6385),
    [aux_sym_id_directive_token1] = ACTIONS(6387),
    [aux_sym_id_directive_token2] = ACTIONS(6387),
    [aux_sym_id_directive_token3] = ACTIONS(6387),
    [aux_sym_id_directive_token4] = ACTIONS(6385),
    [aux_sym_zero_directive_token1] = ACTIONS(6387),
    [aux_sym_zero_directive_token2] = ACTIONS(6387),
    [aux_sym_zero_directive_token3] = ACTIONS(6387),
    [aux_sym_zero_directive_token4] = ACTIONS(6387),
    [aux_sym_zero_directive_token5] = ACTIONS(6387),
    [aux_sym_zero_directive_token6] = ACTIONS(6387),
    [aux_sym_zero_directive_token7] = ACTIONS(6387),
    [aux_sym_zero_directive_token8] = ACTIONS(6387),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6387),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6387),
    [anon_sym_wire] = ACTIONS(6385),
    [anon_sym_tri] = ACTIONS(6385),
    [anon_sym_tri0] = ACTIONS(6385),
    [anon_sym_tri1] = ACTIONS(6385),
    [anon_sym_wand] = ACTIONS(6385),
    [anon_sym_triand] = ACTIONS(6385),
    [anon_sym_wor] = ACTIONS(6385),
    [anon_sym_trior] = ACTIONS(6385),
    [anon_sym_trireg] = ACTIONS(6385),
    [anon_sym_uwire] = ACTIONS(6385),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6387),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6387),
    [aux_sym_begin_keywords_token1] = ACTIONS(6387),
    [anon_sym_SEMI] = ACTIONS(6387),
    [anon_sym_endmodule] = ACTIONS(6385),
    [anon_sym_extern] = ACTIONS(6385),
    [anon_sym_module] = ACTIONS(6385),
    [anon_sym_macromodule] = ACTIONS(6385),
    [anon_sym_endinterface] = ACTIONS(6385),
    [anon_sym_interface] = ACTIONS(6385),
    [anon_sym_endprogram] = ACTIONS(6385),
    [anon_sym_program] = ACTIONS(6385),
    [anon_sym_checker] = ACTIONS(6385),
    [anon_sym_virtual] = ACTIONS(6385),
    [anon_sym_class] = ACTIONS(6385),
    [anon_sym_timeunit] = ACTIONS(6385),
    [anon_sym_timeprecision] = ACTIONS(6385),
    [anon_sym_type] = ACTIONS(6385),
    [anon_sym_input] = ACTIONS(6385),
    [anon_sym_output] = ACTIONS(6385),
    [anon_sym_inout] = ACTIONS(6385),
    [anon_sym_ref] = ACTIONS(6385),
    [anon_sym_DOLLARfatal] = ACTIONS(6387),
    [anon_sym_DOLLARerror] = ACTIONS(6387),
    [anon_sym_DOLLARwarning] = ACTIONS(6387),
    [anon_sym_DOLLARinfo] = ACTIONS(6387),
    [anon_sym_default] = ACTIONS(6385),
    [anon_sym_clocking] = ACTIONS(6385),
    [anon_sym_defparam] = ACTIONS(6385),
    [anon_sym_bind] = ACTIONS(6385),
    [anon_sym_const] = ACTIONS(6385),
    [anon_sym_function] = ACTIONS(6385),
    [anon_sym_static] = ACTIONS(6385),
    [anon_sym_constraint] = ACTIONS(6385),
    [anon_sym_if] = ACTIONS(6385),
    [anon_sym_else] = ACTIONS(6385),
    [anon_sym_LBRACK] = ACTIONS(6387),
    [anon_sym_localparam] = ACTIONS(6385),
    [anon_sym_parameter] = ACTIONS(6385),
    [anon_sym_specparam] = ACTIONS(6385),
    [anon_sym_var] = ACTIONS(6385),
    [anon_sym_import] = ACTIONS(6385),
    [anon_sym_export] = ACTIONS(6385),
    [anon_sym_genvar] = ACTIONS(6385),
    [anon_sym_interconnect] = ACTIONS(6385),
    [anon_sym_typedef] = ACTIONS(6385),
    [anon_sym_enum] = ACTIONS(6385),
    [anon_sym_struct] = ACTIONS(6385),
    [anon_sym_union] = ACTIONS(6385),
    [anon_sym_nettype] = ACTIONS(6385),
    [anon_sym_automatic] = ACTIONS(6385),
    [anon_sym_string] = ACTIONS(6385),
    [anon_sym_chandle] = ACTIONS(6385),
    [anon_sym_event] = ACTIONS(6385),
    [anon_sym_byte] = ACTIONS(6385),
    [anon_sym_shortint] = ACTIONS(6385),
    [anon_sym_int] = ACTIONS(6385),
    [anon_sym_longint] = ACTIONS(6385),
    [anon_sym_integer] = ACTIONS(6385),
    [anon_sym_time] = ACTIONS(6385),
    [anon_sym_bit] = ACTIONS(6385),
    [anon_sym_logic] = ACTIONS(6385),
    [anon_sym_reg] = ACTIONS(6385),
    [anon_sym_shortreal] = ACTIONS(6385),
    [anon_sym_real] = ACTIONS(6385),
    [anon_sym_realtime] = ACTIONS(6385),
    [anon_sym_supply0] = ACTIONS(6385),
    [anon_sym_supply1] = ACTIONS(6385),
    [anon_sym_signed] = ACTIONS(6385),
    [anon_sym_unsigned] = ACTIONS(6385),
    [anon_sym_task] = ACTIONS(6385),
    [anon_sym_modport] = ACTIONS(6385),
    [anon_sym_assert] = ACTIONS(6385),
    [anon_sym_property] = ACTIONS(6385),
    [anon_sym_assume] = ACTIONS(6385),
    [anon_sym_cover] = ACTIONS(6385),
    [anon_sym_sequence] = ACTIONS(6385),
    [anon_sym_restrict] = ACTIONS(6385),
    [anon_sym_not] = ACTIONS(6385),
    [anon_sym_or] = ACTIONS(6385),
    [anon_sym_and] = ACTIONS(6385),
    [anon_sym_case] = ACTIONS(6385),
    [anon_sym_always] = ACTIONS(6385),
    [anon_sym_covergroup] = ACTIONS(6385),
    [anon_sym_let] = ACTIONS(6385),
    [anon_sym_pulldown] = ACTIONS(6385),
    [anon_sym_pullup] = ACTIONS(6385),
    [anon_sym_cmos] = ACTIONS(6385),
    [anon_sym_rcmos] = ACTIONS(6385),
    [anon_sym_bufif0] = ACTIONS(6385),
    [anon_sym_bufif1] = ACTIONS(6385),
    [anon_sym_notif0] = ACTIONS(6385),
    [anon_sym_notif1] = ACTIONS(6385),
    [anon_sym_nmos] = ACTIONS(6385),
    [anon_sym_pmos] = ACTIONS(6385),
    [anon_sym_rnmos] = ACTIONS(6385),
    [anon_sym_rpmos] = ACTIONS(6385),
    [anon_sym_nand] = ACTIONS(6385),
    [anon_sym_nor] = ACTIONS(6385),
    [anon_sym_xor] = ACTIONS(6385),
    [anon_sym_xnor] = ACTIONS(6385),
    [anon_sym_buf] = ACTIONS(6385),
    [anon_sym_tranif0] = ACTIONS(6385),
    [anon_sym_tranif1] = ACTIONS(6385),
    [anon_sym_rtranif1] = ACTIONS(6385),
    [anon_sym_rtranif0] = ACTIONS(6385),
    [anon_sym_tran] = ACTIONS(6385),
    [anon_sym_rtran] = ACTIONS(6385),
    [anon_sym_generate] = ACTIONS(6385),
    [anon_sym_for] = ACTIONS(6385),
    [anon_sym_initial] = ACTIONS(6385),
    [anon_sym_assign] = ACTIONS(6385),
    [anon_sym_alias] = ACTIONS(6385),
    [anon_sym_always_comb] = ACTIONS(6385),
    [anon_sym_always_latch] = ACTIONS(6385),
    [anon_sym_always_ff] = ACTIONS(6385),
    [anon_sym_final] = ACTIONS(6385),
    [anon_sym_while] = ACTIONS(6385),
    [anon_sym_global] = ACTIONS(6385),
    [anon_sym_specify] = ACTIONS(6385),
    [anon_sym_LPAREN_STAR] = ACTIONS(6387),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6387),
    [anon_sym_DOLLARunit] = ACTIONS(6387),
  },
  [1165] = {
    [sym_simple_identifier] = ACTIONS(6389),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6391),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6391),
    [anon_sym_BQUOTE] = ACTIONS(6389),
    [aux_sym_id_directive_token1] = ACTIONS(6391),
    [aux_sym_id_directive_token2] = ACTIONS(6391),
    [aux_sym_id_directive_token3] = ACTIONS(6391),
    [aux_sym_id_directive_token4] = ACTIONS(6389),
    [aux_sym_zero_directive_token1] = ACTIONS(6391),
    [aux_sym_zero_directive_token2] = ACTIONS(6391),
    [aux_sym_zero_directive_token3] = ACTIONS(6391),
    [aux_sym_zero_directive_token4] = ACTIONS(6391),
    [aux_sym_zero_directive_token5] = ACTIONS(6391),
    [aux_sym_zero_directive_token6] = ACTIONS(6391),
    [aux_sym_zero_directive_token7] = ACTIONS(6391),
    [aux_sym_zero_directive_token8] = ACTIONS(6391),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6391),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6391),
    [anon_sym_wire] = ACTIONS(6389),
    [anon_sym_tri] = ACTIONS(6389),
    [anon_sym_tri0] = ACTIONS(6389),
    [anon_sym_tri1] = ACTIONS(6389),
    [anon_sym_wand] = ACTIONS(6389),
    [anon_sym_triand] = ACTIONS(6389),
    [anon_sym_wor] = ACTIONS(6389),
    [anon_sym_trior] = ACTIONS(6389),
    [anon_sym_trireg] = ACTIONS(6389),
    [anon_sym_uwire] = ACTIONS(6389),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6391),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6391),
    [aux_sym_begin_keywords_token1] = ACTIONS(6391),
    [anon_sym_SEMI] = ACTIONS(6391),
    [anon_sym_endmodule] = ACTIONS(6389),
    [anon_sym_extern] = ACTIONS(6389),
    [anon_sym_module] = ACTIONS(6389),
    [anon_sym_macromodule] = ACTIONS(6389),
    [anon_sym_endinterface] = ACTIONS(6389),
    [anon_sym_interface] = ACTIONS(6389),
    [anon_sym_endprogram] = ACTIONS(6389),
    [anon_sym_program] = ACTIONS(6389),
    [anon_sym_checker] = ACTIONS(6389),
    [anon_sym_virtual] = ACTIONS(6389),
    [anon_sym_class] = ACTIONS(6389),
    [anon_sym_timeunit] = ACTIONS(6389),
    [anon_sym_timeprecision] = ACTIONS(6389),
    [anon_sym_type] = ACTIONS(6389),
    [anon_sym_input] = ACTIONS(6389),
    [anon_sym_output] = ACTIONS(6389),
    [anon_sym_inout] = ACTIONS(6389),
    [anon_sym_ref] = ACTIONS(6389),
    [anon_sym_DOLLARfatal] = ACTIONS(6391),
    [anon_sym_DOLLARerror] = ACTIONS(6391),
    [anon_sym_DOLLARwarning] = ACTIONS(6391),
    [anon_sym_DOLLARinfo] = ACTIONS(6391),
    [anon_sym_default] = ACTIONS(6389),
    [anon_sym_clocking] = ACTIONS(6389),
    [anon_sym_defparam] = ACTIONS(6389),
    [anon_sym_bind] = ACTIONS(6389),
    [anon_sym_const] = ACTIONS(6389),
    [anon_sym_function] = ACTIONS(6389),
    [anon_sym_static] = ACTIONS(6389),
    [anon_sym_constraint] = ACTIONS(6389),
    [anon_sym_if] = ACTIONS(6389),
    [anon_sym_else] = ACTIONS(6389),
    [anon_sym_LBRACK] = ACTIONS(6391),
    [anon_sym_localparam] = ACTIONS(6389),
    [anon_sym_parameter] = ACTIONS(6389),
    [anon_sym_specparam] = ACTIONS(6389),
    [anon_sym_var] = ACTIONS(6389),
    [anon_sym_import] = ACTIONS(6389),
    [anon_sym_export] = ACTIONS(6389),
    [anon_sym_genvar] = ACTIONS(6389),
    [anon_sym_interconnect] = ACTIONS(6389),
    [anon_sym_typedef] = ACTIONS(6389),
    [anon_sym_enum] = ACTIONS(6389),
    [anon_sym_struct] = ACTIONS(6389),
    [anon_sym_union] = ACTIONS(6389),
    [anon_sym_nettype] = ACTIONS(6389),
    [anon_sym_automatic] = ACTIONS(6389),
    [anon_sym_string] = ACTIONS(6389),
    [anon_sym_chandle] = ACTIONS(6389),
    [anon_sym_event] = ACTIONS(6389),
    [anon_sym_byte] = ACTIONS(6389),
    [anon_sym_shortint] = ACTIONS(6389),
    [anon_sym_int] = ACTIONS(6389),
    [anon_sym_longint] = ACTIONS(6389),
    [anon_sym_integer] = ACTIONS(6389),
    [anon_sym_time] = ACTIONS(6389),
    [anon_sym_bit] = ACTIONS(6389),
    [anon_sym_logic] = ACTIONS(6389),
    [anon_sym_reg] = ACTIONS(6389),
    [anon_sym_shortreal] = ACTIONS(6389),
    [anon_sym_real] = ACTIONS(6389),
    [anon_sym_realtime] = ACTIONS(6389),
    [anon_sym_supply0] = ACTIONS(6389),
    [anon_sym_supply1] = ACTIONS(6389),
    [anon_sym_signed] = ACTIONS(6389),
    [anon_sym_unsigned] = ACTIONS(6389),
    [anon_sym_task] = ACTIONS(6389),
    [anon_sym_modport] = ACTIONS(6389),
    [anon_sym_assert] = ACTIONS(6389),
    [anon_sym_property] = ACTIONS(6389),
    [anon_sym_assume] = ACTIONS(6389),
    [anon_sym_cover] = ACTIONS(6389),
    [anon_sym_sequence] = ACTIONS(6389),
    [anon_sym_restrict] = ACTIONS(6389),
    [anon_sym_not] = ACTIONS(6389),
    [anon_sym_or] = ACTIONS(6389),
    [anon_sym_and] = ACTIONS(6389),
    [anon_sym_case] = ACTIONS(6389),
    [anon_sym_always] = ACTIONS(6389),
    [anon_sym_covergroup] = ACTIONS(6389),
    [anon_sym_let] = ACTIONS(6389),
    [anon_sym_pulldown] = ACTIONS(6389),
    [anon_sym_pullup] = ACTIONS(6389),
    [anon_sym_cmos] = ACTIONS(6389),
    [anon_sym_rcmos] = ACTIONS(6389),
    [anon_sym_bufif0] = ACTIONS(6389),
    [anon_sym_bufif1] = ACTIONS(6389),
    [anon_sym_notif0] = ACTIONS(6389),
    [anon_sym_notif1] = ACTIONS(6389),
    [anon_sym_nmos] = ACTIONS(6389),
    [anon_sym_pmos] = ACTIONS(6389),
    [anon_sym_rnmos] = ACTIONS(6389),
    [anon_sym_rpmos] = ACTIONS(6389),
    [anon_sym_nand] = ACTIONS(6389),
    [anon_sym_nor] = ACTIONS(6389),
    [anon_sym_xor] = ACTIONS(6389),
    [anon_sym_xnor] = ACTIONS(6389),
    [anon_sym_buf] = ACTIONS(6389),
    [anon_sym_tranif0] = ACTIONS(6389),
    [anon_sym_tranif1] = ACTIONS(6389),
    [anon_sym_rtranif1] = ACTIONS(6389),
    [anon_sym_rtranif0] = ACTIONS(6389),
    [anon_sym_tran] = ACTIONS(6389),
    [anon_sym_rtran] = ACTIONS(6389),
    [anon_sym_generate] = ACTIONS(6389),
    [anon_sym_for] = ACTIONS(6389),
    [anon_sym_initial] = ACTIONS(6389),
    [anon_sym_assign] = ACTIONS(6389),
    [anon_sym_alias] = ACTIONS(6389),
    [anon_sym_always_comb] = ACTIONS(6389),
    [anon_sym_always_latch] = ACTIONS(6389),
    [anon_sym_always_ff] = ACTIONS(6389),
    [anon_sym_final] = ACTIONS(6389),
    [anon_sym_while] = ACTIONS(6389),
    [anon_sym_global] = ACTIONS(6389),
    [anon_sym_specify] = ACTIONS(6389),
    [anon_sym_LPAREN_STAR] = ACTIONS(6391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6391),
    [anon_sym_DOLLARunit] = ACTIONS(6391),
  },
  [1166] = {
    [sym_simple_identifier] = ACTIONS(6393),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6395),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6395),
    [anon_sym_BQUOTE] = ACTIONS(6393),
    [aux_sym_id_directive_token1] = ACTIONS(6395),
    [aux_sym_id_directive_token2] = ACTIONS(6395),
    [aux_sym_id_directive_token3] = ACTIONS(6395),
    [aux_sym_id_directive_token4] = ACTIONS(6393),
    [aux_sym_zero_directive_token1] = ACTIONS(6395),
    [aux_sym_zero_directive_token2] = ACTIONS(6395),
    [aux_sym_zero_directive_token3] = ACTIONS(6395),
    [aux_sym_zero_directive_token4] = ACTIONS(6395),
    [aux_sym_zero_directive_token5] = ACTIONS(6395),
    [aux_sym_zero_directive_token6] = ACTIONS(6395),
    [aux_sym_zero_directive_token7] = ACTIONS(6395),
    [aux_sym_zero_directive_token8] = ACTIONS(6395),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6395),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6395),
    [anon_sym_wire] = ACTIONS(6393),
    [anon_sym_tri] = ACTIONS(6393),
    [anon_sym_tri0] = ACTIONS(6393),
    [anon_sym_tri1] = ACTIONS(6393),
    [anon_sym_wand] = ACTIONS(6393),
    [anon_sym_triand] = ACTIONS(6393),
    [anon_sym_wor] = ACTIONS(6393),
    [anon_sym_trior] = ACTIONS(6393),
    [anon_sym_trireg] = ACTIONS(6393),
    [anon_sym_uwire] = ACTIONS(6393),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6395),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6395),
    [aux_sym_begin_keywords_token1] = ACTIONS(6395),
    [anon_sym_SEMI] = ACTIONS(6395),
    [anon_sym_endmodule] = ACTIONS(6393),
    [anon_sym_extern] = ACTIONS(6393),
    [anon_sym_module] = ACTIONS(6393),
    [anon_sym_macromodule] = ACTIONS(6393),
    [anon_sym_endinterface] = ACTIONS(6393),
    [anon_sym_interface] = ACTIONS(6393),
    [anon_sym_endprogram] = ACTIONS(6393),
    [anon_sym_program] = ACTIONS(6393),
    [anon_sym_checker] = ACTIONS(6393),
    [anon_sym_virtual] = ACTIONS(6393),
    [anon_sym_class] = ACTIONS(6393),
    [anon_sym_timeunit] = ACTIONS(6393),
    [anon_sym_timeprecision] = ACTIONS(6393),
    [anon_sym_type] = ACTIONS(6393),
    [anon_sym_input] = ACTIONS(6393),
    [anon_sym_output] = ACTIONS(6393),
    [anon_sym_inout] = ACTIONS(6393),
    [anon_sym_ref] = ACTIONS(6393),
    [anon_sym_DOLLARfatal] = ACTIONS(6395),
    [anon_sym_DOLLARerror] = ACTIONS(6395),
    [anon_sym_DOLLARwarning] = ACTIONS(6395),
    [anon_sym_DOLLARinfo] = ACTIONS(6395),
    [anon_sym_default] = ACTIONS(6393),
    [anon_sym_clocking] = ACTIONS(6393),
    [anon_sym_defparam] = ACTIONS(6393),
    [anon_sym_bind] = ACTIONS(6393),
    [anon_sym_const] = ACTIONS(6393),
    [anon_sym_function] = ACTIONS(6393),
    [anon_sym_static] = ACTIONS(6393),
    [anon_sym_constraint] = ACTIONS(6393),
    [anon_sym_if] = ACTIONS(6393),
    [anon_sym_else] = ACTIONS(6393),
    [anon_sym_LBRACK] = ACTIONS(6395),
    [anon_sym_localparam] = ACTIONS(6393),
    [anon_sym_parameter] = ACTIONS(6393),
    [anon_sym_specparam] = ACTIONS(6393),
    [anon_sym_var] = ACTIONS(6393),
    [anon_sym_import] = ACTIONS(6393),
    [anon_sym_export] = ACTIONS(6393),
    [anon_sym_genvar] = ACTIONS(6393),
    [anon_sym_interconnect] = ACTIONS(6393),
    [anon_sym_typedef] = ACTIONS(6393),
    [anon_sym_enum] = ACTIONS(6393),
    [anon_sym_struct] = ACTIONS(6393),
    [anon_sym_union] = ACTIONS(6393),
    [anon_sym_nettype] = ACTIONS(6393),
    [anon_sym_automatic] = ACTIONS(6393),
    [anon_sym_string] = ACTIONS(6393),
    [anon_sym_chandle] = ACTIONS(6393),
    [anon_sym_event] = ACTIONS(6393),
    [anon_sym_byte] = ACTIONS(6393),
    [anon_sym_shortint] = ACTIONS(6393),
    [anon_sym_int] = ACTIONS(6393),
    [anon_sym_longint] = ACTIONS(6393),
    [anon_sym_integer] = ACTIONS(6393),
    [anon_sym_time] = ACTIONS(6393),
    [anon_sym_bit] = ACTIONS(6393),
    [anon_sym_logic] = ACTIONS(6393),
    [anon_sym_reg] = ACTIONS(6393),
    [anon_sym_shortreal] = ACTIONS(6393),
    [anon_sym_real] = ACTIONS(6393),
    [anon_sym_realtime] = ACTIONS(6393),
    [anon_sym_supply0] = ACTIONS(6393),
    [anon_sym_supply1] = ACTIONS(6393),
    [anon_sym_signed] = ACTIONS(6393),
    [anon_sym_unsigned] = ACTIONS(6393),
    [anon_sym_task] = ACTIONS(6393),
    [anon_sym_modport] = ACTIONS(6393),
    [anon_sym_assert] = ACTIONS(6393),
    [anon_sym_property] = ACTIONS(6393),
    [anon_sym_assume] = ACTIONS(6393),
    [anon_sym_cover] = ACTIONS(6393),
    [anon_sym_sequence] = ACTIONS(6393),
    [anon_sym_restrict] = ACTIONS(6393),
    [anon_sym_not] = ACTIONS(6393),
    [anon_sym_or] = ACTIONS(6393),
    [anon_sym_and] = ACTIONS(6393),
    [anon_sym_case] = ACTIONS(6393),
    [anon_sym_always] = ACTIONS(6393),
    [anon_sym_covergroup] = ACTIONS(6393),
    [anon_sym_let] = ACTIONS(6393),
    [anon_sym_pulldown] = ACTIONS(6393),
    [anon_sym_pullup] = ACTIONS(6393),
    [anon_sym_cmos] = ACTIONS(6393),
    [anon_sym_rcmos] = ACTIONS(6393),
    [anon_sym_bufif0] = ACTIONS(6393),
    [anon_sym_bufif1] = ACTIONS(6393),
    [anon_sym_notif0] = ACTIONS(6393),
    [anon_sym_notif1] = ACTIONS(6393),
    [anon_sym_nmos] = ACTIONS(6393),
    [anon_sym_pmos] = ACTIONS(6393),
    [anon_sym_rnmos] = ACTIONS(6393),
    [anon_sym_rpmos] = ACTIONS(6393),
    [anon_sym_nand] = ACTIONS(6393),
    [anon_sym_nor] = ACTIONS(6393),
    [anon_sym_xor] = ACTIONS(6393),
    [anon_sym_xnor] = ACTIONS(6393),
    [anon_sym_buf] = ACTIONS(6393),
    [anon_sym_tranif0] = ACTIONS(6393),
    [anon_sym_tranif1] = ACTIONS(6393),
    [anon_sym_rtranif1] = ACTIONS(6393),
    [anon_sym_rtranif0] = ACTIONS(6393),
    [anon_sym_tran] = ACTIONS(6393),
    [anon_sym_rtran] = ACTIONS(6393),
    [anon_sym_generate] = ACTIONS(6393),
    [anon_sym_for] = ACTIONS(6393),
    [anon_sym_initial] = ACTIONS(6393),
    [anon_sym_assign] = ACTIONS(6393),
    [anon_sym_alias] = ACTIONS(6393),
    [anon_sym_always_comb] = ACTIONS(6393),
    [anon_sym_always_latch] = ACTIONS(6393),
    [anon_sym_always_ff] = ACTIONS(6393),
    [anon_sym_final] = ACTIONS(6393),
    [anon_sym_while] = ACTIONS(6393),
    [anon_sym_global] = ACTIONS(6393),
    [anon_sym_specify] = ACTIONS(6393),
    [anon_sym_LPAREN_STAR] = ACTIONS(6395),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6395),
    [anon_sym_DOLLARunit] = ACTIONS(6395),
  },
  [1167] = {
    [ts_builtin_sym_end] = ACTIONS(6397),
    [sym_simple_identifier] = ACTIONS(6399),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6397),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6397),
    [anon_sym_BQUOTE] = ACTIONS(6399),
    [aux_sym_id_directive_token1] = ACTIONS(6397),
    [aux_sym_id_directive_token2] = ACTIONS(6397),
    [aux_sym_id_directive_token3] = ACTIONS(6397),
    [aux_sym_id_directive_token4] = ACTIONS(6399),
    [aux_sym_zero_directive_token1] = ACTIONS(6397),
    [aux_sym_zero_directive_token2] = ACTIONS(6397),
    [aux_sym_zero_directive_token3] = ACTIONS(6397),
    [aux_sym_zero_directive_token4] = ACTIONS(6397),
    [aux_sym_zero_directive_token5] = ACTIONS(6397),
    [aux_sym_zero_directive_token6] = ACTIONS(6397),
    [aux_sym_zero_directive_token7] = ACTIONS(6397),
    [aux_sym_zero_directive_token8] = ACTIONS(6397),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6397),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6397),
    [anon_sym_wire] = ACTIONS(6399),
    [anon_sym_tri] = ACTIONS(6399),
    [anon_sym_tri0] = ACTIONS(6399),
    [anon_sym_tri1] = ACTIONS(6399),
    [anon_sym_wand] = ACTIONS(6399),
    [anon_sym_triand] = ACTIONS(6399),
    [anon_sym_wor] = ACTIONS(6399),
    [anon_sym_trior] = ACTIONS(6399),
    [anon_sym_trireg] = ACTIONS(6399),
    [anon_sym_uwire] = ACTIONS(6399),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6397),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6397),
    [aux_sym_begin_keywords_token1] = ACTIONS(6397),
    [anon_sym_SEMI] = ACTIONS(6397),
    [anon_sym_endmodule] = ACTIONS(6399),
    [anon_sym_extern] = ACTIONS(6399),
    [anon_sym_module] = ACTIONS(6399),
    [anon_sym_macromodule] = ACTIONS(6399),
    [anon_sym_endinterface] = ACTIONS(6399),
    [anon_sym_interface] = ACTIONS(6399),
    [anon_sym_program] = ACTIONS(6399),
    [anon_sym_checker] = ACTIONS(6399),
    [anon_sym_virtual] = ACTIONS(6399),
    [anon_sym_class] = ACTIONS(6399),
    [anon_sym_package] = ACTIONS(6399),
    [anon_sym_timeunit] = ACTIONS(6399),
    [anon_sym_timeprecision] = ACTIONS(6399),
    [anon_sym_type] = ACTIONS(6399),
    [anon_sym_input] = ACTIONS(6399),
    [anon_sym_output] = ACTIONS(6399),
    [anon_sym_inout] = ACTIONS(6399),
    [anon_sym_ref] = ACTIONS(6399),
    [anon_sym_DOLLARfatal] = ACTIONS(6397),
    [anon_sym_DOLLARerror] = ACTIONS(6397),
    [anon_sym_DOLLARwarning] = ACTIONS(6397),
    [anon_sym_DOLLARinfo] = ACTIONS(6397),
    [anon_sym_default] = ACTIONS(6399),
    [anon_sym_clocking] = ACTIONS(6399),
    [anon_sym_defparam] = ACTIONS(6399),
    [anon_sym_bind] = ACTIONS(6399),
    [anon_sym_const] = ACTIONS(6399),
    [anon_sym_function] = ACTIONS(6399),
    [anon_sym_static] = ACTIONS(6399),
    [anon_sym_constraint] = ACTIONS(6399),
    [anon_sym_if] = ACTIONS(6399),
    [anon_sym_LBRACK] = ACTIONS(6397),
    [anon_sym_localparam] = ACTIONS(6399),
    [anon_sym_parameter] = ACTIONS(6399),
    [anon_sym_specparam] = ACTIONS(6399),
    [anon_sym_var] = ACTIONS(6399),
    [anon_sym_import] = ACTIONS(6399),
    [anon_sym_export] = ACTIONS(6399),
    [anon_sym_genvar] = ACTIONS(6399),
    [anon_sym_interconnect] = ACTIONS(6399),
    [anon_sym_typedef] = ACTIONS(6399),
    [anon_sym_enum] = ACTIONS(6399),
    [anon_sym_struct] = ACTIONS(6399),
    [anon_sym_union] = ACTIONS(6399),
    [anon_sym_nettype] = ACTIONS(6399),
    [anon_sym_automatic] = ACTIONS(6399),
    [anon_sym_string] = ACTIONS(6399),
    [anon_sym_chandle] = ACTIONS(6399),
    [anon_sym_event] = ACTIONS(6399),
    [anon_sym_byte] = ACTIONS(6399),
    [anon_sym_shortint] = ACTIONS(6399),
    [anon_sym_int] = ACTIONS(6399),
    [anon_sym_longint] = ACTIONS(6399),
    [anon_sym_integer] = ACTIONS(6399),
    [anon_sym_time] = ACTIONS(6399),
    [anon_sym_bit] = ACTIONS(6399),
    [anon_sym_logic] = ACTIONS(6399),
    [anon_sym_reg] = ACTIONS(6399),
    [anon_sym_shortreal] = ACTIONS(6399),
    [anon_sym_real] = ACTIONS(6399),
    [anon_sym_realtime] = ACTIONS(6399),
    [anon_sym_supply0] = ACTIONS(6399),
    [anon_sym_supply1] = ACTIONS(6399),
    [anon_sym_signed] = ACTIONS(6399),
    [anon_sym_unsigned] = ACTIONS(6399),
    [anon_sym_task] = ACTIONS(6399),
    [anon_sym_modport] = ACTIONS(6399),
    [anon_sym_assert] = ACTIONS(6399),
    [anon_sym_property] = ACTIONS(6399),
    [anon_sym_assume] = ACTIONS(6399),
    [anon_sym_cover] = ACTIONS(6399),
    [anon_sym_sequence] = ACTIONS(6399),
    [anon_sym_restrict] = ACTIONS(6399),
    [anon_sym_not] = ACTIONS(6399),
    [anon_sym_or] = ACTIONS(6399),
    [anon_sym_and] = ACTIONS(6399),
    [anon_sym_case] = ACTIONS(6399),
    [anon_sym_always] = ACTIONS(6399),
    [anon_sym_covergroup] = ACTIONS(6399),
    [anon_sym_let] = ACTIONS(6399),
    [anon_sym_pulldown] = ACTIONS(6399),
    [anon_sym_pullup] = ACTIONS(6399),
    [anon_sym_cmos] = ACTIONS(6399),
    [anon_sym_rcmos] = ACTIONS(6399),
    [anon_sym_bufif0] = ACTIONS(6399),
    [anon_sym_bufif1] = ACTIONS(6399),
    [anon_sym_notif0] = ACTIONS(6399),
    [anon_sym_notif1] = ACTIONS(6399),
    [anon_sym_nmos] = ACTIONS(6399),
    [anon_sym_pmos] = ACTIONS(6399),
    [anon_sym_rnmos] = ACTIONS(6399),
    [anon_sym_rpmos] = ACTIONS(6399),
    [anon_sym_nand] = ACTIONS(6399),
    [anon_sym_nor] = ACTIONS(6399),
    [anon_sym_xor] = ACTIONS(6399),
    [anon_sym_xnor] = ACTIONS(6399),
    [anon_sym_buf] = ACTIONS(6399),
    [anon_sym_tranif0] = ACTIONS(6399),
    [anon_sym_tranif1] = ACTIONS(6399),
    [anon_sym_rtranif1] = ACTIONS(6399),
    [anon_sym_rtranif0] = ACTIONS(6399),
    [anon_sym_tran] = ACTIONS(6399),
    [anon_sym_rtran] = ACTIONS(6399),
    [anon_sym_generate] = ACTIONS(6399),
    [anon_sym_for] = ACTIONS(6399),
    [anon_sym_primitive] = ACTIONS(6399),
    [anon_sym_initial] = ACTIONS(6399),
    [anon_sym_assign] = ACTIONS(6399),
    [anon_sym_alias] = ACTIONS(6399),
    [anon_sym_always_comb] = ACTIONS(6399),
    [anon_sym_always_latch] = ACTIONS(6399),
    [anon_sym_always_ff] = ACTIONS(6399),
    [anon_sym_final] = ACTIONS(6399),
    [anon_sym_global] = ACTIONS(6399),
    [anon_sym_specify] = ACTIONS(6399),
    [anon_sym_LPAREN_STAR] = ACTIONS(6397),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6397),
    [anon_sym_DOLLARunit] = ACTIONS(6397),
  },
  [1168] = {
    [sym_simple_identifier] = ACTIONS(6401),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6403),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6403),
    [anon_sym_BQUOTE] = ACTIONS(6401),
    [aux_sym_id_directive_token1] = ACTIONS(6403),
    [aux_sym_id_directive_token2] = ACTIONS(6403),
    [aux_sym_id_directive_token3] = ACTIONS(6403),
    [aux_sym_id_directive_token4] = ACTIONS(6401),
    [aux_sym_zero_directive_token1] = ACTIONS(6403),
    [aux_sym_zero_directive_token2] = ACTIONS(6403),
    [aux_sym_zero_directive_token3] = ACTIONS(6403),
    [aux_sym_zero_directive_token4] = ACTIONS(6403),
    [aux_sym_zero_directive_token5] = ACTIONS(6403),
    [aux_sym_zero_directive_token6] = ACTIONS(6403),
    [aux_sym_zero_directive_token7] = ACTIONS(6403),
    [aux_sym_zero_directive_token8] = ACTIONS(6403),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6403),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6403),
    [anon_sym_wire] = ACTIONS(6401),
    [anon_sym_tri] = ACTIONS(6401),
    [anon_sym_tri0] = ACTIONS(6401),
    [anon_sym_tri1] = ACTIONS(6401),
    [anon_sym_wand] = ACTIONS(6401),
    [anon_sym_triand] = ACTIONS(6401),
    [anon_sym_wor] = ACTIONS(6401),
    [anon_sym_trior] = ACTIONS(6401),
    [anon_sym_trireg] = ACTIONS(6401),
    [anon_sym_uwire] = ACTIONS(6401),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6403),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6403),
    [aux_sym_begin_keywords_token1] = ACTIONS(6403),
    [anon_sym_SEMI] = ACTIONS(6403),
    [anon_sym_endmodule] = ACTIONS(6401),
    [anon_sym_extern] = ACTIONS(6401),
    [anon_sym_module] = ACTIONS(6401),
    [anon_sym_macromodule] = ACTIONS(6401),
    [anon_sym_endinterface] = ACTIONS(6401),
    [anon_sym_interface] = ACTIONS(6401),
    [anon_sym_endprogram] = ACTIONS(6401),
    [anon_sym_program] = ACTIONS(6401),
    [anon_sym_checker] = ACTIONS(6401),
    [anon_sym_virtual] = ACTIONS(6401),
    [anon_sym_class] = ACTIONS(6401),
    [anon_sym_timeunit] = ACTIONS(6401),
    [anon_sym_timeprecision] = ACTIONS(6401),
    [anon_sym_type] = ACTIONS(6401),
    [anon_sym_input] = ACTIONS(6401),
    [anon_sym_output] = ACTIONS(6401),
    [anon_sym_inout] = ACTIONS(6401),
    [anon_sym_ref] = ACTIONS(6401),
    [anon_sym_DOLLARfatal] = ACTIONS(6403),
    [anon_sym_DOLLARerror] = ACTIONS(6403),
    [anon_sym_DOLLARwarning] = ACTIONS(6403),
    [anon_sym_DOLLARinfo] = ACTIONS(6403),
    [anon_sym_default] = ACTIONS(6401),
    [anon_sym_clocking] = ACTIONS(6401),
    [anon_sym_defparam] = ACTIONS(6401),
    [anon_sym_bind] = ACTIONS(6401),
    [anon_sym_const] = ACTIONS(6401),
    [anon_sym_function] = ACTIONS(6401),
    [anon_sym_static] = ACTIONS(6401),
    [anon_sym_constraint] = ACTIONS(6401),
    [anon_sym_if] = ACTIONS(6401),
    [anon_sym_else] = ACTIONS(6401),
    [anon_sym_LBRACK] = ACTIONS(6403),
    [anon_sym_localparam] = ACTIONS(6401),
    [anon_sym_parameter] = ACTIONS(6401),
    [anon_sym_specparam] = ACTIONS(6401),
    [anon_sym_var] = ACTIONS(6401),
    [anon_sym_import] = ACTIONS(6401),
    [anon_sym_export] = ACTIONS(6401),
    [anon_sym_genvar] = ACTIONS(6401),
    [anon_sym_interconnect] = ACTIONS(6401),
    [anon_sym_typedef] = ACTIONS(6401),
    [anon_sym_enum] = ACTIONS(6401),
    [anon_sym_struct] = ACTIONS(6401),
    [anon_sym_union] = ACTIONS(6401),
    [anon_sym_nettype] = ACTIONS(6401),
    [anon_sym_automatic] = ACTIONS(6401),
    [anon_sym_string] = ACTIONS(6401),
    [anon_sym_chandle] = ACTIONS(6401),
    [anon_sym_event] = ACTIONS(6401),
    [anon_sym_byte] = ACTIONS(6401),
    [anon_sym_shortint] = ACTIONS(6401),
    [anon_sym_int] = ACTIONS(6401),
    [anon_sym_longint] = ACTIONS(6401),
    [anon_sym_integer] = ACTIONS(6401),
    [anon_sym_time] = ACTIONS(6401),
    [anon_sym_bit] = ACTIONS(6401),
    [anon_sym_logic] = ACTIONS(6401),
    [anon_sym_reg] = ACTIONS(6401),
    [anon_sym_shortreal] = ACTIONS(6401),
    [anon_sym_real] = ACTIONS(6401),
    [anon_sym_realtime] = ACTIONS(6401),
    [anon_sym_supply0] = ACTIONS(6401),
    [anon_sym_supply1] = ACTIONS(6401),
    [anon_sym_signed] = ACTIONS(6401),
    [anon_sym_unsigned] = ACTIONS(6401),
    [anon_sym_task] = ACTIONS(6401),
    [anon_sym_modport] = ACTIONS(6401),
    [anon_sym_assert] = ACTIONS(6401),
    [anon_sym_property] = ACTIONS(6401),
    [anon_sym_assume] = ACTIONS(6401),
    [anon_sym_cover] = ACTIONS(6401),
    [anon_sym_sequence] = ACTIONS(6401),
    [anon_sym_restrict] = ACTIONS(6401),
    [anon_sym_not] = ACTIONS(6401),
    [anon_sym_or] = ACTIONS(6401),
    [anon_sym_and] = ACTIONS(6401),
    [anon_sym_case] = ACTIONS(6401),
    [anon_sym_always] = ACTIONS(6401),
    [anon_sym_covergroup] = ACTIONS(6401),
    [anon_sym_let] = ACTIONS(6401),
    [anon_sym_pulldown] = ACTIONS(6401),
    [anon_sym_pullup] = ACTIONS(6401),
    [anon_sym_cmos] = ACTIONS(6401),
    [anon_sym_rcmos] = ACTIONS(6401),
    [anon_sym_bufif0] = ACTIONS(6401),
    [anon_sym_bufif1] = ACTIONS(6401),
    [anon_sym_notif0] = ACTIONS(6401),
    [anon_sym_notif1] = ACTIONS(6401),
    [anon_sym_nmos] = ACTIONS(6401),
    [anon_sym_pmos] = ACTIONS(6401),
    [anon_sym_rnmos] = ACTIONS(6401),
    [anon_sym_rpmos] = ACTIONS(6401),
    [anon_sym_nand] = ACTIONS(6401),
    [anon_sym_nor] = ACTIONS(6401),
    [anon_sym_xor] = ACTIONS(6401),
    [anon_sym_xnor] = ACTIONS(6401),
    [anon_sym_buf] = ACTIONS(6401),
    [anon_sym_tranif0] = ACTIONS(6401),
    [anon_sym_tranif1] = ACTIONS(6401),
    [anon_sym_rtranif1] = ACTIONS(6401),
    [anon_sym_rtranif0] = ACTIONS(6401),
    [anon_sym_tran] = ACTIONS(6401),
    [anon_sym_rtran] = ACTIONS(6401),
    [anon_sym_generate] = ACTIONS(6401),
    [anon_sym_for] = ACTIONS(6401),
    [anon_sym_initial] = ACTIONS(6401),
    [anon_sym_assign] = ACTIONS(6401),
    [anon_sym_alias] = ACTIONS(6401),
    [anon_sym_always_comb] = ACTIONS(6401),
    [anon_sym_always_latch] = ACTIONS(6401),
    [anon_sym_always_ff] = ACTIONS(6401),
    [anon_sym_final] = ACTIONS(6401),
    [anon_sym_while] = ACTIONS(6401),
    [anon_sym_global] = ACTIONS(6401),
    [anon_sym_specify] = ACTIONS(6401),
    [anon_sym_LPAREN_STAR] = ACTIONS(6403),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6403),
    [anon_sym_DOLLARunit] = ACTIONS(6403),
  },
  [1169] = {
    [ts_builtin_sym_end] = ACTIONS(6405),
    [sym_simple_identifier] = ACTIONS(6407),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6405),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6405),
    [anon_sym_BQUOTE] = ACTIONS(6407),
    [aux_sym_id_directive_token1] = ACTIONS(6405),
    [aux_sym_id_directive_token2] = ACTIONS(6405),
    [aux_sym_id_directive_token3] = ACTIONS(6405),
    [aux_sym_id_directive_token4] = ACTIONS(6407),
    [aux_sym_zero_directive_token1] = ACTIONS(6405),
    [aux_sym_zero_directive_token2] = ACTIONS(6405),
    [aux_sym_zero_directive_token3] = ACTIONS(6405),
    [aux_sym_zero_directive_token4] = ACTIONS(6405),
    [aux_sym_zero_directive_token5] = ACTIONS(6405),
    [aux_sym_zero_directive_token6] = ACTIONS(6405),
    [aux_sym_zero_directive_token7] = ACTIONS(6405),
    [aux_sym_zero_directive_token8] = ACTIONS(6405),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6405),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6405),
    [anon_sym_wire] = ACTIONS(6407),
    [anon_sym_tri] = ACTIONS(6407),
    [anon_sym_tri0] = ACTIONS(6407),
    [anon_sym_tri1] = ACTIONS(6407),
    [anon_sym_wand] = ACTIONS(6407),
    [anon_sym_triand] = ACTIONS(6407),
    [anon_sym_wor] = ACTIONS(6407),
    [anon_sym_trior] = ACTIONS(6407),
    [anon_sym_trireg] = ACTIONS(6407),
    [anon_sym_uwire] = ACTIONS(6407),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6405),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6405),
    [aux_sym_begin_keywords_token1] = ACTIONS(6405),
    [anon_sym_SEMI] = ACTIONS(6405),
    [anon_sym_endmodule] = ACTIONS(6407),
    [anon_sym_extern] = ACTIONS(6407),
    [anon_sym_module] = ACTIONS(6407),
    [anon_sym_macromodule] = ACTIONS(6407),
    [anon_sym_endinterface] = ACTIONS(6407),
    [anon_sym_interface] = ACTIONS(6407),
    [anon_sym_program] = ACTIONS(6407),
    [anon_sym_checker] = ACTIONS(6407),
    [anon_sym_virtual] = ACTIONS(6407),
    [anon_sym_class] = ACTIONS(6407),
    [anon_sym_package] = ACTIONS(6407),
    [anon_sym_timeunit] = ACTIONS(6407),
    [anon_sym_timeprecision] = ACTIONS(6407),
    [anon_sym_type] = ACTIONS(6407),
    [anon_sym_input] = ACTIONS(6407),
    [anon_sym_output] = ACTIONS(6407),
    [anon_sym_inout] = ACTIONS(6407),
    [anon_sym_ref] = ACTIONS(6407),
    [anon_sym_DOLLARfatal] = ACTIONS(6405),
    [anon_sym_DOLLARerror] = ACTIONS(6405),
    [anon_sym_DOLLARwarning] = ACTIONS(6405),
    [anon_sym_DOLLARinfo] = ACTIONS(6405),
    [anon_sym_default] = ACTIONS(6407),
    [anon_sym_clocking] = ACTIONS(6407),
    [anon_sym_defparam] = ACTIONS(6407),
    [anon_sym_bind] = ACTIONS(6407),
    [anon_sym_const] = ACTIONS(6407),
    [anon_sym_function] = ACTIONS(6407),
    [anon_sym_static] = ACTIONS(6407),
    [anon_sym_constraint] = ACTIONS(6407),
    [anon_sym_if] = ACTIONS(6407),
    [anon_sym_LBRACK] = ACTIONS(6405),
    [anon_sym_localparam] = ACTIONS(6407),
    [anon_sym_parameter] = ACTIONS(6407),
    [anon_sym_specparam] = ACTIONS(6407),
    [anon_sym_var] = ACTIONS(6407),
    [anon_sym_import] = ACTIONS(6407),
    [anon_sym_export] = ACTIONS(6407),
    [anon_sym_genvar] = ACTIONS(6407),
    [anon_sym_interconnect] = ACTIONS(6407),
    [anon_sym_typedef] = ACTIONS(6407),
    [anon_sym_enum] = ACTIONS(6407),
    [anon_sym_struct] = ACTIONS(6407),
    [anon_sym_union] = ACTIONS(6407),
    [anon_sym_nettype] = ACTIONS(6407),
    [anon_sym_automatic] = ACTIONS(6407),
    [anon_sym_string] = ACTIONS(6407),
    [anon_sym_chandle] = ACTIONS(6407),
    [anon_sym_event] = ACTIONS(6407),
    [anon_sym_byte] = ACTIONS(6407),
    [anon_sym_shortint] = ACTIONS(6407),
    [anon_sym_int] = ACTIONS(6407),
    [anon_sym_longint] = ACTIONS(6407),
    [anon_sym_integer] = ACTIONS(6407),
    [anon_sym_time] = ACTIONS(6407),
    [anon_sym_bit] = ACTIONS(6407),
    [anon_sym_logic] = ACTIONS(6407),
    [anon_sym_reg] = ACTIONS(6407),
    [anon_sym_shortreal] = ACTIONS(6407),
    [anon_sym_real] = ACTIONS(6407),
    [anon_sym_realtime] = ACTIONS(6407),
    [anon_sym_supply0] = ACTIONS(6407),
    [anon_sym_supply1] = ACTIONS(6407),
    [anon_sym_signed] = ACTIONS(6407),
    [anon_sym_unsigned] = ACTIONS(6407),
    [anon_sym_task] = ACTIONS(6407),
    [anon_sym_modport] = ACTIONS(6407),
    [anon_sym_assert] = ACTIONS(6407),
    [anon_sym_property] = ACTIONS(6407),
    [anon_sym_assume] = ACTIONS(6407),
    [anon_sym_cover] = ACTIONS(6407),
    [anon_sym_sequence] = ACTIONS(6407),
    [anon_sym_restrict] = ACTIONS(6407),
    [anon_sym_not] = ACTIONS(6407),
    [anon_sym_or] = ACTIONS(6407),
    [anon_sym_and] = ACTIONS(6407),
    [anon_sym_case] = ACTIONS(6407),
    [anon_sym_always] = ACTIONS(6407),
    [anon_sym_covergroup] = ACTIONS(6407),
    [anon_sym_let] = ACTIONS(6407),
    [anon_sym_pulldown] = ACTIONS(6407),
    [anon_sym_pullup] = ACTIONS(6407),
    [anon_sym_cmos] = ACTIONS(6407),
    [anon_sym_rcmos] = ACTIONS(6407),
    [anon_sym_bufif0] = ACTIONS(6407),
    [anon_sym_bufif1] = ACTIONS(6407),
    [anon_sym_notif0] = ACTIONS(6407),
    [anon_sym_notif1] = ACTIONS(6407),
    [anon_sym_nmos] = ACTIONS(6407),
    [anon_sym_pmos] = ACTIONS(6407),
    [anon_sym_rnmos] = ACTIONS(6407),
    [anon_sym_rpmos] = ACTIONS(6407),
    [anon_sym_nand] = ACTIONS(6407),
    [anon_sym_nor] = ACTIONS(6407),
    [anon_sym_xor] = ACTIONS(6407),
    [anon_sym_xnor] = ACTIONS(6407),
    [anon_sym_buf] = ACTIONS(6407),
    [anon_sym_tranif0] = ACTIONS(6407),
    [anon_sym_tranif1] = ACTIONS(6407),
    [anon_sym_rtranif1] = ACTIONS(6407),
    [anon_sym_rtranif0] = ACTIONS(6407),
    [anon_sym_tran] = ACTIONS(6407),
    [anon_sym_rtran] = ACTIONS(6407),
    [anon_sym_generate] = ACTIONS(6407),
    [anon_sym_for] = ACTIONS(6407),
    [anon_sym_primitive] = ACTIONS(6407),
    [anon_sym_initial] = ACTIONS(6407),
    [anon_sym_assign] = ACTIONS(6407),
    [anon_sym_alias] = ACTIONS(6407),
    [anon_sym_always_comb] = ACTIONS(6407),
    [anon_sym_always_latch] = ACTIONS(6407),
    [anon_sym_always_ff] = ACTIONS(6407),
    [anon_sym_final] = ACTIONS(6407),
    [anon_sym_global] = ACTIONS(6407),
    [anon_sym_specify] = ACTIONS(6407),
    [anon_sym_LPAREN_STAR] = ACTIONS(6405),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6405),
    [anon_sym_DOLLARunit] = ACTIONS(6405),
  },
  [1170] = {
    [ts_builtin_sym_end] = ACTIONS(6409),
    [sym_simple_identifier] = ACTIONS(6411),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6409),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6409),
    [anon_sym_BQUOTE] = ACTIONS(6411),
    [aux_sym_id_directive_token1] = ACTIONS(6409),
    [aux_sym_id_directive_token2] = ACTIONS(6409),
    [aux_sym_id_directive_token3] = ACTIONS(6409),
    [aux_sym_id_directive_token4] = ACTIONS(6411),
    [aux_sym_zero_directive_token1] = ACTIONS(6409),
    [aux_sym_zero_directive_token2] = ACTIONS(6409),
    [aux_sym_zero_directive_token3] = ACTIONS(6409),
    [aux_sym_zero_directive_token4] = ACTIONS(6409),
    [aux_sym_zero_directive_token5] = ACTIONS(6409),
    [aux_sym_zero_directive_token6] = ACTIONS(6409),
    [aux_sym_zero_directive_token7] = ACTIONS(6409),
    [aux_sym_zero_directive_token8] = ACTIONS(6409),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6409),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6409),
    [anon_sym_wire] = ACTIONS(6411),
    [anon_sym_tri] = ACTIONS(6411),
    [anon_sym_tri0] = ACTIONS(6411),
    [anon_sym_tri1] = ACTIONS(6411),
    [anon_sym_wand] = ACTIONS(6411),
    [anon_sym_triand] = ACTIONS(6411),
    [anon_sym_wor] = ACTIONS(6411),
    [anon_sym_trior] = ACTIONS(6411),
    [anon_sym_trireg] = ACTIONS(6411),
    [anon_sym_uwire] = ACTIONS(6411),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6409),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6409),
    [aux_sym_begin_keywords_token1] = ACTIONS(6409),
    [anon_sym_SEMI] = ACTIONS(6409),
    [anon_sym_endmodule] = ACTIONS(6411),
    [anon_sym_extern] = ACTIONS(6411),
    [anon_sym_module] = ACTIONS(6411),
    [anon_sym_macromodule] = ACTIONS(6411),
    [anon_sym_endinterface] = ACTIONS(6411),
    [anon_sym_interface] = ACTIONS(6411),
    [anon_sym_program] = ACTIONS(6411),
    [anon_sym_checker] = ACTIONS(6411),
    [anon_sym_virtual] = ACTIONS(6411),
    [anon_sym_class] = ACTIONS(6411),
    [anon_sym_package] = ACTIONS(6411),
    [anon_sym_timeunit] = ACTIONS(6411),
    [anon_sym_timeprecision] = ACTIONS(6411),
    [anon_sym_type] = ACTIONS(6411),
    [anon_sym_input] = ACTIONS(6411),
    [anon_sym_output] = ACTIONS(6411),
    [anon_sym_inout] = ACTIONS(6411),
    [anon_sym_ref] = ACTIONS(6411),
    [anon_sym_DOLLARfatal] = ACTIONS(6409),
    [anon_sym_DOLLARerror] = ACTIONS(6409),
    [anon_sym_DOLLARwarning] = ACTIONS(6409),
    [anon_sym_DOLLARinfo] = ACTIONS(6409),
    [anon_sym_default] = ACTIONS(6411),
    [anon_sym_clocking] = ACTIONS(6411),
    [anon_sym_defparam] = ACTIONS(6411),
    [anon_sym_bind] = ACTIONS(6411),
    [anon_sym_const] = ACTIONS(6411),
    [anon_sym_function] = ACTIONS(6411),
    [anon_sym_static] = ACTIONS(6411),
    [anon_sym_constraint] = ACTIONS(6411),
    [anon_sym_if] = ACTIONS(6411),
    [anon_sym_LBRACK] = ACTIONS(6409),
    [anon_sym_localparam] = ACTIONS(6411),
    [anon_sym_parameter] = ACTIONS(6411),
    [anon_sym_specparam] = ACTIONS(6411),
    [anon_sym_var] = ACTIONS(6411),
    [anon_sym_import] = ACTIONS(6411),
    [anon_sym_export] = ACTIONS(6411),
    [anon_sym_genvar] = ACTIONS(6411),
    [anon_sym_interconnect] = ACTIONS(6411),
    [anon_sym_typedef] = ACTIONS(6411),
    [anon_sym_enum] = ACTIONS(6411),
    [anon_sym_struct] = ACTIONS(6411),
    [anon_sym_union] = ACTIONS(6411),
    [anon_sym_nettype] = ACTIONS(6411),
    [anon_sym_automatic] = ACTIONS(6411),
    [anon_sym_string] = ACTIONS(6411),
    [anon_sym_chandle] = ACTIONS(6411),
    [anon_sym_event] = ACTIONS(6411),
    [anon_sym_byte] = ACTIONS(6411),
    [anon_sym_shortint] = ACTIONS(6411),
    [anon_sym_int] = ACTIONS(6411),
    [anon_sym_longint] = ACTIONS(6411),
    [anon_sym_integer] = ACTIONS(6411),
    [anon_sym_time] = ACTIONS(6411),
    [anon_sym_bit] = ACTIONS(6411),
    [anon_sym_logic] = ACTIONS(6411),
    [anon_sym_reg] = ACTIONS(6411),
    [anon_sym_shortreal] = ACTIONS(6411),
    [anon_sym_real] = ACTIONS(6411),
    [anon_sym_realtime] = ACTIONS(6411),
    [anon_sym_supply0] = ACTIONS(6411),
    [anon_sym_supply1] = ACTIONS(6411),
    [anon_sym_signed] = ACTIONS(6411),
    [anon_sym_unsigned] = ACTIONS(6411),
    [anon_sym_task] = ACTIONS(6411),
    [anon_sym_modport] = ACTIONS(6411),
    [anon_sym_assert] = ACTIONS(6411),
    [anon_sym_property] = ACTIONS(6411),
    [anon_sym_assume] = ACTIONS(6411),
    [anon_sym_cover] = ACTIONS(6411),
    [anon_sym_sequence] = ACTIONS(6411),
    [anon_sym_restrict] = ACTIONS(6411),
    [anon_sym_not] = ACTIONS(6411),
    [anon_sym_or] = ACTIONS(6411),
    [anon_sym_and] = ACTIONS(6411),
    [anon_sym_case] = ACTIONS(6411),
    [anon_sym_always] = ACTIONS(6411),
    [anon_sym_covergroup] = ACTIONS(6411),
    [anon_sym_let] = ACTIONS(6411),
    [anon_sym_pulldown] = ACTIONS(6411),
    [anon_sym_pullup] = ACTIONS(6411),
    [anon_sym_cmos] = ACTIONS(6411),
    [anon_sym_rcmos] = ACTIONS(6411),
    [anon_sym_bufif0] = ACTIONS(6411),
    [anon_sym_bufif1] = ACTIONS(6411),
    [anon_sym_notif0] = ACTIONS(6411),
    [anon_sym_notif1] = ACTIONS(6411),
    [anon_sym_nmos] = ACTIONS(6411),
    [anon_sym_pmos] = ACTIONS(6411),
    [anon_sym_rnmos] = ACTIONS(6411),
    [anon_sym_rpmos] = ACTIONS(6411),
    [anon_sym_nand] = ACTIONS(6411),
    [anon_sym_nor] = ACTIONS(6411),
    [anon_sym_xor] = ACTIONS(6411),
    [anon_sym_xnor] = ACTIONS(6411),
    [anon_sym_buf] = ACTIONS(6411),
    [anon_sym_tranif0] = ACTIONS(6411),
    [anon_sym_tranif1] = ACTIONS(6411),
    [anon_sym_rtranif1] = ACTIONS(6411),
    [anon_sym_rtranif0] = ACTIONS(6411),
    [anon_sym_tran] = ACTIONS(6411),
    [anon_sym_rtran] = ACTIONS(6411),
    [anon_sym_generate] = ACTIONS(6411),
    [anon_sym_for] = ACTIONS(6411),
    [anon_sym_primitive] = ACTIONS(6411),
    [anon_sym_initial] = ACTIONS(6411),
    [anon_sym_assign] = ACTIONS(6411),
    [anon_sym_alias] = ACTIONS(6411),
    [anon_sym_always_comb] = ACTIONS(6411),
    [anon_sym_always_latch] = ACTIONS(6411),
    [anon_sym_always_ff] = ACTIONS(6411),
    [anon_sym_final] = ACTIONS(6411),
    [anon_sym_global] = ACTIONS(6411),
    [anon_sym_specify] = ACTIONS(6411),
    [anon_sym_LPAREN_STAR] = ACTIONS(6409),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6409),
    [anon_sym_DOLLARunit] = ACTIONS(6409),
  },
  [1171] = {
    [ts_builtin_sym_end] = ACTIONS(6413),
    [sym_simple_identifier] = ACTIONS(6415),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6413),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6413),
    [anon_sym_BQUOTE] = ACTIONS(6415),
    [aux_sym_id_directive_token1] = ACTIONS(6413),
    [aux_sym_id_directive_token2] = ACTIONS(6413),
    [aux_sym_id_directive_token3] = ACTIONS(6413),
    [aux_sym_id_directive_token4] = ACTIONS(6415),
    [aux_sym_zero_directive_token1] = ACTIONS(6413),
    [aux_sym_zero_directive_token2] = ACTIONS(6413),
    [aux_sym_zero_directive_token3] = ACTIONS(6413),
    [aux_sym_zero_directive_token4] = ACTIONS(6413),
    [aux_sym_zero_directive_token5] = ACTIONS(6413),
    [aux_sym_zero_directive_token6] = ACTIONS(6413),
    [aux_sym_zero_directive_token7] = ACTIONS(6413),
    [aux_sym_zero_directive_token8] = ACTIONS(6413),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6413),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6413),
    [anon_sym_wire] = ACTIONS(6415),
    [anon_sym_tri] = ACTIONS(6415),
    [anon_sym_tri0] = ACTIONS(6415),
    [anon_sym_tri1] = ACTIONS(6415),
    [anon_sym_wand] = ACTIONS(6415),
    [anon_sym_triand] = ACTIONS(6415),
    [anon_sym_wor] = ACTIONS(6415),
    [anon_sym_trior] = ACTIONS(6415),
    [anon_sym_trireg] = ACTIONS(6415),
    [anon_sym_uwire] = ACTIONS(6415),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6413),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6413),
    [aux_sym_begin_keywords_token1] = ACTIONS(6413),
    [anon_sym_SEMI] = ACTIONS(6413),
    [anon_sym_endmodule] = ACTIONS(6415),
    [anon_sym_extern] = ACTIONS(6415),
    [anon_sym_module] = ACTIONS(6415),
    [anon_sym_macromodule] = ACTIONS(6415),
    [anon_sym_endinterface] = ACTIONS(6415),
    [anon_sym_interface] = ACTIONS(6415),
    [anon_sym_program] = ACTIONS(6415),
    [anon_sym_checker] = ACTIONS(6415),
    [anon_sym_virtual] = ACTIONS(6415),
    [anon_sym_class] = ACTIONS(6415),
    [anon_sym_package] = ACTIONS(6415),
    [anon_sym_timeunit] = ACTIONS(6415),
    [anon_sym_timeprecision] = ACTIONS(6415),
    [anon_sym_type] = ACTIONS(6415),
    [anon_sym_input] = ACTIONS(6415),
    [anon_sym_output] = ACTIONS(6415),
    [anon_sym_inout] = ACTIONS(6415),
    [anon_sym_ref] = ACTIONS(6415),
    [anon_sym_DOLLARfatal] = ACTIONS(6413),
    [anon_sym_DOLLARerror] = ACTIONS(6413),
    [anon_sym_DOLLARwarning] = ACTIONS(6413),
    [anon_sym_DOLLARinfo] = ACTIONS(6413),
    [anon_sym_default] = ACTIONS(6415),
    [anon_sym_clocking] = ACTIONS(6415),
    [anon_sym_defparam] = ACTIONS(6415),
    [anon_sym_bind] = ACTIONS(6415),
    [anon_sym_const] = ACTIONS(6415),
    [anon_sym_function] = ACTIONS(6415),
    [anon_sym_static] = ACTIONS(6415),
    [anon_sym_constraint] = ACTIONS(6415),
    [anon_sym_if] = ACTIONS(6415),
    [anon_sym_LBRACK] = ACTIONS(6413),
    [anon_sym_localparam] = ACTIONS(6415),
    [anon_sym_parameter] = ACTIONS(6415),
    [anon_sym_specparam] = ACTIONS(6415),
    [anon_sym_var] = ACTIONS(6415),
    [anon_sym_import] = ACTIONS(6415),
    [anon_sym_export] = ACTIONS(6415),
    [anon_sym_genvar] = ACTIONS(6415),
    [anon_sym_interconnect] = ACTIONS(6415),
    [anon_sym_typedef] = ACTIONS(6415),
    [anon_sym_enum] = ACTIONS(6415),
    [anon_sym_struct] = ACTIONS(6415),
    [anon_sym_union] = ACTIONS(6415),
    [anon_sym_nettype] = ACTIONS(6415),
    [anon_sym_automatic] = ACTIONS(6415),
    [anon_sym_string] = ACTIONS(6415),
    [anon_sym_chandle] = ACTIONS(6415),
    [anon_sym_event] = ACTIONS(6415),
    [anon_sym_byte] = ACTIONS(6415),
    [anon_sym_shortint] = ACTIONS(6415),
    [anon_sym_int] = ACTIONS(6415),
    [anon_sym_longint] = ACTIONS(6415),
    [anon_sym_integer] = ACTIONS(6415),
    [anon_sym_time] = ACTIONS(6415),
    [anon_sym_bit] = ACTIONS(6415),
    [anon_sym_logic] = ACTIONS(6415),
    [anon_sym_reg] = ACTIONS(6415),
    [anon_sym_shortreal] = ACTIONS(6415),
    [anon_sym_real] = ACTIONS(6415),
    [anon_sym_realtime] = ACTIONS(6415),
    [anon_sym_supply0] = ACTIONS(6415),
    [anon_sym_supply1] = ACTIONS(6415),
    [anon_sym_signed] = ACTIONS(6415),
    [anon_sym_unsigned] = ACTIONS(6415),
    [anon_sym_task] = ACTIONS(6415),
    [anon_sym_modport] = ACTIONS(6415),
    [anon_sym_assert] = ACTIONS(6415),
    [anon_sym_property] = ACTIONS(6415),
    [anon_sym_assume] = ACTIONS(6415),
    [anon_sym_cover] = ACTIONS(6415),
    [anon_sym_sequence] = ACTIONS(6415),
    [anon_sym_restrict] = ACTIONS(6415),
    [anon_sym_not] = ACTIONS(6415),
    [anon_sym_or] = ACTIONS(6415),
    [anon_sym_and] = ACTIONS(6415),
    [anon_sym_case] = ACTIONS(6415),
    [anon_sym_always] = ACTIONS(6415),
    [anon_sym_covergroup] = ACTIONS(6415),
    [anon_sym_let] = ACTIONS(6415),
    [anon_sym_pulldown] = ACTIONS(6415),
    [anon_sym_pullup] = ACTIONS(6415),
    [anon_sym_cmos] = ACTIONS(6415),
    [anon_sym_rcmos] = ACTIONS(6415),
    [anon_sym_bufif0] = ACTIONS(6415),
    [anon_sym_bufif1] = ACTIONS(6415),
    [anon_sym_notif0] = ACTIONS(6415),
    [anon_sym_notif1] = ACTIONS(6415),
    [anon_sym_nmos] = ACTIONS(6415),
    [anon_sym_pmos] = ACTIONS(6415),
    [anon_sym_rnmos] = ACTIONS(6415),
    [anon_sym_rpmos] = ACTIONS(6415),
    [anon_sym_nand] = ACTIONS(6415),
    [anon_sym_nor] = ACTIONS(6415),
    [anon_sym_xor] = ACTIONS(6415),
    [anon_sym_xnor] = ACTIONS(6415),
    [anon_sym_buf] = ACTIONS(6415),
    [anon_sym_tranif0] = ACTIONS(6415),
    [anon_sym_tranif1] = ACTIONS(6415),
    [anon_sym_rtranif1] = ACTIONS(6415),
    [anon_sym_rtranif0] = ACTIONS(6415),
    [anon_sym_tran] = ACTIONS(6415),
    [anon_sym_rtran] = ACTIONS(6415),
    [anon_sym_generate] = ACTIONS(6415),
    [anon_sym_for] = ACTIONS(6415),
    [anon_sym_primitive] = ACTIONS(6415),
    [anon_sym_initial] = ACTIONS(6415),
    [anon_sym_assign] = ACTIONS(6415),
    [anon_sym_alias] = ACTIONS(6415),
    [anon_sym_always_comb] = ACTIONS(6415),
    [anon_sym_always_latch] = ACTIONS(6415),
    [anon_sym_always_ff] = ACTIONS(6415),
    [anon_sym_final] = ACTIONS(6415),
    [anon_sym_global] = ACTIONS(6415),
    [anon_sym_specify] = ACTIONS(6415),
    [anon_sym_LPAREN_STAR] = ACTIONS(6413),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6413),
    [anon_sym_DOLLARunit] = ACTIONS(6413),
  },
  [1172] = {
    [sym_simple_identifier] = ACTIONS(6417),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6419),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6419),
    [anon_sym_BQUOTE] = ACTIONS(6417),
    [aux_sym_id_directive_token1] = ACTIONS(6419),
    [aux_sym_id_directive_token2] = ACTIONS(6419),
    [aux_sym_id_directive_token3] = ACTIONS(6419),
    [aux_sym_id_directive_token4] = ACTIONS(6417),
    [aux_sym_zero_directive_token1] = ACTIONS(6419),
    [aux_sym_zero_directive_token2] = ACTIONS(6419),
    [aux_sym_zero_directive_token3] = ACTIONS(6419),
    [aux_sym_zero_directive_token4] = ACTIONS(6419),
    [aux_sym_zero_directive_token5] = ACTIONS(6419),
    [aux_sym_zero_directive_token6] = ACTIONS(6419),
    [aux_sym_zero_directive_token7] = ACTIONS(6419),
    [aux_sym_zero_directive_token8] = ACTIONS(6419),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6419),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6419),
    [anon_sym_wire] = ACTIONS(6417),
    [anon_sym_tri] = ACTIONS(6417),
    [anon_sym_tri0] = ACTIONS(6417),
    [anon_sym_tri1] = ACTIONS(6417),
    [anon_sym_wand] = ACTIONS(6417),
    [anon_sym_triand] = ACTIONS(6417),
    [anon_sym_wor] = ACTIONS(6417),
    [anon_sym_trior] = ACTIONS(6417),
    [anon_sym_trireg] = ACTIONS(6417),
    [anon_sym_uwire] = ACTIONS(6417),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6419),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6419),
    [aux_sym_begin_keywords_token1] = ACTIONS(6419),
    [anon_sym_SEMI] = ACTIONS(6419),
    [anon_sym_endmodule] = ACTIONS(6417),
    [anon_sym_extern] = ACTIONS(6417),
    [anon_sym_module] = ACTIONS(6417),
    [anon_sym_macromodule] = ACTIONS(6417),
    [anon_sym_endinterface] = ACTIONS(6417),
    [anon_sym_interface] = ACTIONS(6417),
    [anon_sym_endprogram] = ACTIONS(6417),
    [anon_sym_program] = ACTIONS(6417),
    [anon_sym_checker] = ACTIONS(6417),
    [anon_sym_virtual] = ACTIONS(6417),
    [anon_sym_class] = ACTIONS(6417),
    [anon_sym_timeunit] = ACTIONS(6417),
    [anon_sym_timeprecision] = ACTIONS(6417),
    [anon_sym_type] = ACTIONS(6417),
    [anon_sym_input] = ACTIONS(6417),
    [anon_sym_output] = ACTIONS(6417),
    [anon_sym_inout] = ACTIONS(6417),
    [anon_sym_ref] = ACTIONS(6417),
    [anon_sym_DOLLARfatal] = ACTIONS(6419),
    [anon_sym_DOLLARerror] = ACTIONS(6419),
    [anon_sym_DOLLARwarning] = ACTIONS(6419),
    [anon_sym_DOLLARinfo] = ACTIONS(6419),
    [anon_sym_default] = ACTIONS(6417),
    [anon_sym_clocking] = ACTIONS(6417),
    [anon_sym_defparam] = ACTIONS(6417),
    [anon_sym_bind] = ACTIONS(6417),
    [anon_sym_const] = ACTIONS(6417),
    [anon_sym_function] = ACTIONS(6417),
    [anon_sym_static] = ACTIONS(6417),
    [anon_sym_constraint] = ACTIONS(6417),
    [anon_sym_if] = ACTIONS(6417),
    [anon_sym_else] = ACTIONS(6417),
    [anon_sym_LBRACK] = ACTIONS(6419),
    [anon_sym_localparam] = ACTIONS(6417),
    [anon_sym_parameter] = ACTIONS(6417),
    [anon_sym_specparam] = ACTIONS(6417),
    [anon_sym_var] = ACTIONS(6417),
    [anon_sym_import] = ACTIONS(6417),
    [anon_sym_export] = ACTIONS(6417),
    [anon_sym_genvar] = ACTIONS(6417),
    [anon_sym_interconnect] = ACTIONS(6417),
    [anon_sym_typedef] = ACTIONS(6417),
    [anon_sym_enum] = ACTIONS(6417),
    [anon_sym_struct] = ACTIONS(6417),
    [anon_sym_union] = ACTIONS(6417),
    [anon_sym_nettype] = ACTIONS(6417),
    [anon_sym_automatic] = ACTIONS(6417),
    [anon_sym_string] = ACTIONS(6417),
    [anon_sym_chandle] = ACTIONS(6417),
    [anon_sym_event] = ACTIONS(6417),
    [anon_sym_byte] = ACTIONS(6417),
    [anon_sym_shortint] = ACTIONS(6417),
    [anon_sym_int] = ACTIONS(6417),
    [anon_sym_longint] = ACTIONS(6417),
    [anon_sym_integer] = ACTIONS(6417),
    [anon_sym_time] = ACTIONS(6417),
    [anon_sym_bit] = ACTIONS(6417),
    [anon_sym_logic] = ACTIONS(6417),
    [anon_sym_reg] = ACTIONS(6417),
    [anon_sym_shortreal] = ACTIONS(6417),
    [anon_sym_real] = ACTIONS(6417),
    [anon_sym_realtime] = ACTIONS(6417),
    [anon_sym_supply0] = ACTIONS(6417),
    [anon_sym_supply1] = ACTIONS(6417),
    [anon_sym_signed] = ACTIONS(6417),
    [anon_sym_unsigned] = ACTIONS(6417),
    [anon_sym_task] = ACTIONS(6417),
    [anon_sym_modport] = ACTIONS(6417),
    [anon_sym_assert] = ACTIONS(6417),
    [anon_sym_property] = ACTIONS(6417),
    [anon_sym_assume] = ACTIONS(6417),
    [anon_sym_cover] = ACTIONS(6417),
    [anon_sym_sequence] = ACTIONS(6417),
    [anon_sym_restrict] = ACTIONS(6417),
    [anon_sym_not] = ACTIONS(6417),
    [anon_sym_or] = ACTIONS(6417),
    [anon_sym_and] = ACTIONS(6417),
    [anon_sym_case] = ACTIONS(6417),
    [anon_sym_always] = ACTIONS(6417),
    [anon_sym_covergroup] = ACTIONS(6417),
    [anon_sym_let] = ACTIONS(6417),
    [anon_sym_pulldown] = ACTIONS(6417),
    [anon_sym_pullup] = ACTIONS(6417),
    [anon_sym_cmos] = ACTIONS(6417),
    [anon_sym_rcmos] = ACTIONS(6417),
    [anon_sym_bufif0] = ACTIONS(6417),
    [anon_sym_bufif1] = ACTIONS(6417),
    [anon_sym_notif0] = ACTIONS(6417),
    [anon_sym_notif1] = ACTIONS(6417),
    [anon_sym_nmos] = ACTIONS(6417),
    [anon_sym_pmos] = ACTIONS(6417),
    [anon_sym_rnmos] = ACTIONS(6417),
    [anon_sym_rpmos] = ACTIONS(6417),
    [anon_sym_nand] = ACTIONS(6417),
    [anon_sym_nor] = ACTIONS(6417),
    [anon_sym_xor] = ACTIONS(6417),
    [anon_sym_xnor] = ACTIONS(6417),
    [anon_sym_buf] = ACTIONS(6417),
    [anon_sym_tranif0] = ACTIONS(6417),
    [anon_sym_tranif1] = ACTIONS(6417),
    [anon_sym_rtranif1] = ACTIONS(6417),
    [anon_sym_rtranif0] = ACTIONS(6417),
    [anon_sym_tran] = ACTIONS(6417),
    [anon_sym_rtran] = ACTIONS(6417),
    [anon_sym_generate] = ACTIONS(6417),
    [anon_sym_for] = ACTIONS(6417),
    [anon_sym_initial] = ACTIONS(6417),
    [anon_sym_assign] = ACTIONS(6417),
    [anon_sym_alias] = ACTIONS(6417),
    [anon_sym_always_comb] = ACTIONS(6417),
    [anon_sym_always_latch] = ACTIONS(6417),
    [anon_sym_always_ff] = ACTIONS(6417),
    [anon_sym_final] = ACTIONS(6417),
    [anon_sym_while] = ACTIONS(6417),
    [anon_sym_global] = ACTIONS(6417),
    [anon_sym_specify] = ACTIONS(6417),
    [anon_sym_LPAREN_STAR] = ACTIONS(6419),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6419),
    [anon_sym_DOLLARunit] = ACTIONS(6419),
  },
  [1173] = {
    [sym_simple_identifier] = ACTIONS(6421),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6423),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6423),
    [anon_sym_BQUOTE] = ACTIONS(6421),
    [aux_sym_id_directive_token1] = ACTIONS(6423),
    [aux_sym_id_directive_token2] = ACTIONS(6423),
    [aux_sym_id_directive_token3] = ACTIONS(6423),
    [aux_sym_id_directive_token4] = ACTIONS(6421),
    [aux_sym_zero_directive_token1] = ACTIONS(6423),
    [aux_sym_zero_directive_token2] = ACTIONS(6423),
    [aux_sym_zero_directive_token3] = ACTIONS(6423),
    [aux_sym_zero_directive_token4] = ACTIONS(6423),
    [aux_sym_zero_directive_token5] = ACTIONS(6423),
    [aux_sym_zero_directive_token6] = ACTIONS(6423),
    [aux_sym_zero_directive_token7] = ACTIONS(6423),
    [aux_sym_zero_directive_token8] = ACTIONS(6423),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6423),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6423),
    [anon_sym_wire] = ACTIONS(6421),
    [anon_sym_tri] = ACTIONS(6421),
    [anon_sym_tri0] = ACTIONS(6421),
    [anon_sym_tri1] = ACTIONS(6421),
    [anon_sym_wand] = ACTIONS(6421),
    [anon_sym_triand] = ACTIONS(6421),
    [anon_sym_wor] = ACTIONS(6421),
    [anon_sym_trior] = ACTIONS(6421),
    [anon_sym_trireg] = ACTIONS(6421),
    [anon_sym_uwire] = ACTIONS(6421),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6423),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6423),
    [aux_sym_begin_keywords_token1] = ACTIONS(6423),
    [anon_sym_SEMI] = ACTIONS(6423),
    [anon_sym_endmodule] = ACTIONS(6421),
    [anon_sym_extern] = ACTIONS(6421),
    [anon_sym_module] = ACTIONS(6421),
    [anon_sym_macromodule] = ACTIONS(6421),
    [anon_sym_endinterface] = ACTIONS(6421),
    [anon_sym_interface] = ACTIONS(6421),
    [anon_sym_endprogram] = ACTIONS(6421),
    [anon_sym_program] = ACTIONS(6421),
    [anon_sym_checker] = ACTIONS(6421),
    [anon_sym_virtual] = ACTIONS(6421),
    [anon_sym_class] = ACTIONS(6421),
    [anon_sym_timeunit] = ACTIONS(6421),
    [anon_sym_timeprecision] = ACTIONS(6421),
    [anon_sym_type] = ACTIONS(6421),
    [anon_sym_input] = ACTIONS(6421),
    [anon_sym_output] = ACTIONS(6421),
    [anon_sym_inout] = ACTIONS(6421),
    [anon_sym_ref] = ACTIONS(6421),
    [anon_sym_DOLLARfatal] = ACTIONS(6423),
    [anon_sym_DOLLARerror] = ACTIONS(6423),
    [anon_sym_DOLLARwarning] = ACTIONS(6423),
    [anon_sym_DOLLARinfo] = ACTIONS(6423),
    [anon_sym_default] = ACTIONS(6421),
    [anon_sym_clocking] = ACTIONS(6421),
    [anon_sym_defparam] = ACTIONS(6421),
    [anon_sym_bind] = ACTIONS(6421),
    [anon_sym_const] = ACTIONS(6421),
    [anon_sym_function] = ACTIONS(6421),
    [anon_sym_static] = ACTIONS(6421),
    [anon_sym_constraint] = ACTIONS(6421),
    [anon_sym_if] = ACTIONS(6421),
    [anon_sym_else] = ACTIONS(6421),
    [anon_sym_LBRACK] = ACTIONS(6423),
    [anon_sym_localparam] = ACTIONS(6421),
    [anon_sym_parameter] = ACTIONS(6421),
    [anon_sym_specparam] = ACTIONS(6421),
    [anon_sym_var] = ACTIONS(6421),
    [anon_sym_import] = ACTIONS(6421),
    [anon_sym_export] = ACTIONS(6421),
    [anon_sym_genvar] = ACTIONS(6421),
    [anon_sym_interconnect] = ACTIONS(6421),
    [anon_sym_typedef] = ACTIONS(6421),
    [anon_sym_enum] = ACTIONS(6421),
    [anon_sym_struct] = ACTIONS(6421),
    [anon_sym_union] = ACTIONS(6421),
    [anon_sym_nettype] = ACTIONS(6421),
    [anon_sym_automatic] = ACTIONS(6421),
    [anon_sym_string] = ACTIONS(6421),
    [anon_sym_chandle] = ACTIONS(6421),
    [anon_sym_event] = ACTIONS(6421),
    [anon_sym_byte] = ACTIONS(6421),
    [anon_sym_shortint] = ACTIONS(6421),
    [anon_sym_int] = ACTIONS(6421),
    [anon_sym_longint] = ACTIONS(6421),
    [anon_sym_integer] = ACTIONS(6421),
    [anon_sym_time] = ACTIONS(6421),
    [anon_sym_bit] = ACTIONS(6421),
    [anon_sym_logic] = ACTIONS(6421),
    [anon_sym_reg] = ACTIONS(6421),
    [anon_sym_shortreal] = ACTIONS(6421),
    [anon_sym_real] = ACTIONS(6421),
    [anon_sym_realtime] = ACTIONS(6421),
    [anon_sym_supply0] = ACTIONS(6421),
    [anon_sym_supply1] = ACTIONS(6421),
    [anon_sym_signed] = ACTIONS(6421),
    [anon_sym_unsigned] = ACTIONS(6421),
    [anon_sym_task] = ACTIONS(6421),
    [anon_sym_modport] = ACTIONS(6421),
    [anon_sym_assert] = ACTIONS(6421),
    [anon_sym_property] = ACTIONS(6421),
    [anon_sym_assume] = ACTIONS(6421),
    [anon_sym_cover] = ACTIONS(6421),
    [anon_sym_sequence] = ACTIONS(6421),
    [anon_sym_restrict] = ACTIONS(6421),
    [anon_sym_not] = ACTIONS(6421),
    [anon_sym_or] = ACTIONS(6421),
    [anon_sym_and] = ACTIONS(6421),
    [anon_sym_case] = ACTIONS(6421),
    [anon_sym_always] = ACTIONS(6421),
    [anon_sym_covergroup] = ACTIONS(6421),
    [anon_sym_let] = ACTIONS(6421),
    [anon_sym_pulldown] = ACTIONS(6421),
    [anon_sym_pullup] = ACTIONS(6421),
    [anon_sym_cmos] = ACTIONS(6421),
    [anon_sym_rcmos] = ACTIONS(6421),
    [anon_sym_bufif0] = ACTIONS(6421),
    [anon_sym_bufif1] = ACTIONS(6421),
    [anon_sym_notif0] = ACTIONS(6421),
    [anon_sym_notif1] = ACTIONS(6421),
    [anon_sym_nmos] = ACTIONS(6421),
    [anon_sym_pmos] = ACTIONS(6421),
    [anon_sym_rnmos] = ACTIONS(6421),
    [anon_sym_rpmos] = ACTIONS(6421),
    [anon_sym_nand] = ACTIONS(6421),
    [anon_sym_nor] = ACTIONS(6421),
    [anon_sym_xor] = ACTIONS(6421),
    [anon_sym_xnor] = ACTIONS(6421),
    [anon_sym_buf] = ACTIONS(6421),
    [anon_sym_tranif0] = ACTIONS(6421),
    [anon_sym_tranif1] = ACTIONS(6421),
    [anon_sym_rtranif1] = ACTIONS(6421),
    [anon_sym_rtranif0] = ACTIONS(6421),
    [anon_sym_tran] = ACTIONS(6421),
    [anon_sym_rtran] = ACTIONS(6421),
    [anon_sym_generate] = ACTIONS(6421),
    [anon_sym_for] = ACTIONS(6421),
    [anon_sym_initial] = ACTIONS(6421),
    [anon_sym_assign] = ACTIONS(6421),
    [anon_sym_alias] = ACTIONS(6421),
    [anon_sym_always_comb] = ACTIONS(6421),
    [anon_sym_always_latch] = ACTIONS(6421),
    [anon_sym_always_ff] = ACTIONS(6421),
    [anon_sym_final] = ACTIONS(6421),
    [anon_sym_while] = ACTIONS(6421),
    [anon_sym_global] = ACTIONS(6421),
    [anon_sym_specify] = ACTIONS(6421),
    [anon_sym_LPAREN_STAR] = ACTIONS(6423),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6423),
    [anon_sym_DOLLARunit] = ACTIONS(6423),
  },
  [1174] = {
    [ts_builtin_sym_end] = ACTIONS(6425),
    [sym_simple_identifier] = ACTIONS(6427),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6425),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6425),
    [anon_sym_BQUOTE] = ACTIONS(6427),
    [aux_sym_id_directive_token1] = ACTIONS(6425),
    [aux_sym_id_directive_token2] = ACTIONS(6425),
    [aux_sym_id_directive_token3] = ACTIONS(6425),
    [aux_sym_id_directive_token4] = ACTIONS(6427),
    [aux_sym_zero_directive_token1] = ACTIONS(6425),
    [aux_sym_zero_directive_token2] = ACTIONS(6425),
    [aux_sym_zero_directive_token3] = ACTIONS(6425),
    [aux_sym_zero_directive_token4] = ACTIONS(6425),
    [aux_sym_zero_directive_token5] = ACTIONS(6425),
    [aux_sym_zero_directive_token6] = ACTIONS(6425),
    [aux_sym_zero_directive_token7] = ACTIONS(6425),
    [aux_sym_zero_directive_token8] = ACTIONS(6425),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6425),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6425),
    [anon_sym_wire] = ACTIONS(6427),
    [anon_sym_tri] = ACTIONS(6427),
    [anon_sym_tri0] = ACTIONS(6427),
    [anon_sym_tri1] = ACTIONS(6427),
    [anon_sym_wand] = ACTIONS(6427),
    [anon_sym_triand] = ACTIONS(6427),
    [anon_sym_wor] = ACTIONS(6427),
    [anon_sym_trior] = ACTIONS(6427),
    [anon_sym_trireg] = ACTIONS(6427),
    [anon_sym_uwire] = ACTIONS(6427),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6425),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6425),
    [aux_sym_begin_keywords_token1] = ACTIONS(6425),
    [anon_sym_SEMI] = ACTIONS(6425),
    [anon_sym_endmodule] = ACTIONS(6427),
    [anon_sym_extern] = ACTIONS(6427),
    [anon_sym_module] = ACTIONS(6427),
    [anon_sym_macromodule] = ACTIONS(6427),
    [anon_sym_endinterface] = ACTIONS(6427),
    [anon_sym_interface] = ACTIONS(6427),
    [anon_sym_program] = ACTIONS(6427),
    [anon_sym_checker] = ACTIONS(6427),
    [anon_sym_virtual] = ACTIONS(6427),
    [anon_sym_class] = ACTIONS(6427),
    [anon_sym_package] = ACTIONS(6427),
    [anon_sym_timeunit] = ACTIONS(6427),
    [anon_sym_timeprecision] = ACTIONS(6427),
    [anon_sym_type] = ACTIONS(6427),
    [anon_sym_input] = ACTIONS(6427),
    [anon_sym_output] = ACTIONS(6427),
    [anon_sym_inout] = ACTIONS(6427),
    [anon_sym_ref] = ACTIONS(6427),
    [anon_sym_DOLLARfatal] = ACTIONS(6425),
    [anon_sym_DOLLARerror] = ACTIONS(6425),
    [anon_sym_DOLLARwarning] = ACTIONS(6425),
    [anon_sym_DOLLARinfo] = ACTIONS(6425),
    [anon_sym_default] = ACTIONS(6427),
    [anon_sym_clocking] = ACTIONS(6427),
    [anon_sym_defparam] = ACTIONS(6427),
    [anon_sym_bind] = ACTIONS(6427),
    [anon_sym_const] = ACTIONS(6427),
    [anon_sym_function] = ACTIONS(6427),
    [anon_sym_static] = ACTIONS(6427),
    [anon_sym_constraint] = ACTIONS(6427),
    [anon_sym_if] = ACTIONS(6427),
    [anon_sym_LBRACK] = ACTIONS(6425),
    [anon_sym_localparam] = ACTIONS(6427),
    [anon_sym_parameter] = ACTIONS(6427),
    [anon_sym_specparam] = ACTIONS(6427),
    [anon_sym_var] = ACTIONS(6427),
    [anon_sym_import] = ACTIONS(6427),
    [anon_sym_export] = ACTIONS(6427),
    [anon_sym_genvar] = ACTIONS(6427),
    [anon_sym_interconnect] = ACTIONS(6427),
    [anon_sym_typedef] = ACTIONS(6427),
    [anon_sym_enum] = ACTIONS(6427),
    [anon_sym_struct] = ACTIONS(6427),
    [anon_sym_union] = ACTIONS(6427),
    [anon_sym_nettype] = ACTIONS(6427),
    [anon_sym_automatic] = ACTIONS(6427),
    [anon_sym_string] = ACTIONS(6427),
    [anon_sym_chandle] = ACTIONS(6427),
    [anon_sym_event] = ACTIONS(6427),
    [anon_sym_byte] = ACTIONS(6427),
    [anon_sym_shortint] = ACTIONS(6427),
    [anon_sym_int] = ACTIONS(6427),
    [anon_sym_longint] = ACTIONS(6427),
    [anon_sym_integer] = ACTIONS(6427),
    [anon_sym_time] = ACTIONS(6427),
    [anon_sym_bit] = ACTIONS(6427),
    [anon_sym_logic] = ACTIONS(6427),
    [anon_sym_reg] = ACTIONS(6427),
    [anon_sym_shortreal] = ACTIONS(6427),
    [anon_sym_real] = ACTIONS(6427),
    [anon_sym_realtime] = ACTIONS(6427),
    [anon_sym_supply0] = ACTIONS(6427),
    [anon_sym_supply1] = ACTIONS(6427),
    [anon_sym_signed] = ACTIONS(6427),
    [anon_sym_unsigned] = ACTIONS(6427),
    [anon_sym_task] = ACTIONS(6427),
    [anon_sym_modport] = ACTIONS(6427),
    [anon_sym_assert] = ACTIONS(6427),
    [anon_sym_property] = ACTIONS(6427),
    [anon_sym_assume] = ACTIONS(6427),
    [anon_sym_cover] = ACTIONS(6427),
    [anon_sym_sequence] = ACTIONS(6427),
    [anon_sym_restrict] = ACTIONS(6427),
    [anon_sym_not] = ACTIONS(6427),
    [anon_sym_or] = ACTIONS(6427),
    [anon_sym_and] = ACTIONS(6427),
    [anon_sym_case] = ACTIONS(6427),
    [anon_sym_always] = ACTIONS(6427),
    [anon_sym_covergroup] = ACTIONS(6427),
    [anon_sym_let] = ACTIONS(6427),
    [anon_sym_pulldown] = ACTIONS(6427),
    [anon_sym_pullup] = ACTIONS(6427),
    [anon_sym_cmos] = ACTIONS(6427),
    [anon_sym_rcmos] = ACTIONS(6427),
    [anon_sym_bufif0] = ACTIONS(6427),
    [anon_sym_bufif1] = ACTIONS(6427),
    [anon_sym_notif0] = ACTIONS(6427),
    [anon_sym_notif1] = ACTIONS(6427),
    [anon_sym_nmos] = ACTIONS(6427),
    [anon_sym_pmos] = ACTIONS(6427),
    [anon_sym_rnmos] = ACTIONS(6427),
    [anon_sym_rpmos] = ACTIONS(6427),
    [anon_sym_nand] = ACTIONS(6427),
    [anon_sym_nor] = ACTIONS(6427),
    [anon_sym_xor] = ACTIONS(6427),
    [anon_sym_xnor] = ACTIONS(6427),
    [anon_sym_buf] = ACTIONS(6427),
    [anon_sym_tranif0] = ACTIONS(6427),
    [anon_sym_tranif1] = ACTIONS(6427),
    [anon_sym_rtranif1] = ACTIONS(6427),
    [anon_sym_rtranif0] = ACTIONS(6427),
    [anon_sym_tran] = ACTIONS(6427),
    [anon_sym_rtran] = ACTIONS(6427),
    [anon_sym_generate] = ACTIONS(6427),
    [anon_sym_for] = ACTIONS(6427),
    [anon_sym_primitive] = ACTIONS(6427),
    [anon_sym_initial] = ACTIONS(6427),
    [anon_sym_assign] = ACTIONS(6427),
    [anon_sym_alias] = ACTIONS(6427),
    [anon_sym_always_comb] = ACTIONS(6427),
    [anon_sym_always_latch] = ACTIONS(6427),
    [anon_sym_always_ff] = ACTIONS(6427),
    [anon_sym_final] = ACTIONS(6427),
    [anon_sym_global] = ACTIONS(6427),
    [anon_sym_specify] = ACTIONS(6427),
    [anon_sym_LPAREN_STAR] = ACTIONS(6425),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6425),
    [anon_sym_DOLLARunit] = ACTIONS(6425),
  },
  [1175] = {
    [ts_builtin_sym_end] = ACTIONS(6429),
    [sym_simple_identifier] = ACTIONS(6431),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6429),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6429),
    [anon_sym_BQUOTE] = ACTIONS(6431),
    [aux_sym_id_directive_token1] = ACTIONS(6429),
    [aux_sym_id_directive_token2] = ACTIONS(6429),
    [aux_sym_id_directive_token3] = ACTIONS(6429),
    [aux_sym_id_directive_token4] = ACTIONS(6431),
    [aux_sym_zero_directive_token1] = ACTIONS(6429),
    [aux_sym_zero_directive_token2] = ACTIONS(6429),
    [aux_sym_zero_directive_token3] = ACTIONS(6429),
    [aux_sym_zero_directive_token4] = ACTIONS(6429),
    [aux_sym_zero_directive_token5] = ACTIONS(6429),
    [aux_sym_zero_directive_token6] = ACTIONS(6429),
    [aux_sym_zero_directive_token7] = ACTIONS(6429),
    [aux_sym_zero_directive_token8] = ACTIONS(6429),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6429),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6429),
    [anon_sym_wire] = ACTIONS(6431),
    [anon_sym_tri] = ACTIONS(6431),
    [anon_sym_tri0] = ACTIONS(6431),
    [anon_sym_tri1] = ACTIONS(6431),
    [anon_sym_wand] = ACTIONS(6431),
    [anon_sym_triand] = ACTIONS(6431),
    [anon_sym_wor] = ACTIONS(6431),
    [anon_sym_trior] = ACTIONS(6431),
    [anon_sym_trireg] = ACTIONS(6431),
    [anon_sym_uwire] = ACTIONS(6431),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6429),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6429),
    [aux_sym_begin_keywords_token1] = ACTIONS(6429),
    [anon_sym_SEMI] = ACTIONS(6429),
    [anon_sym_endmodule] = ACTIONS(6431),
    [anon_sym_extern] = ACTIONS(6431),
    [anon_sym_module] = ACTIONS(6431),
    [anon_sym_macromodule] = ACTIONS(6431),
    [anon_sym_endinterface] = ACTIONS(6431),
    [anon_sym_interface] = ACTIONS(6431),
    [anon_sym_program] = ACTIONS(6431),
    [anon_sym_checker] = ACTIONS(6431),
    [anon_sym_virtual] = ACTIONS(6431),
    [anon_sym_class] = ACTIONS(6431),
    [anon_sym_package] = ACTIONS(6431),
    [anon_sym_timeunit] = ACTIONS(6431),
    [anon_sym_timeprecision] = ACTIONS(6431),
    [anon_sym_type] = ACTIONS(6431),
    [anon_sym_input] = ACTIONS(6431),
    [anon_sym_output] = ACTIONS(6431),
    [anon_sym_inout] = ACTIONS(6431),
    [anon_sym_ref] = ACTIONS(6431),
    [anon_sym_DOLLARfatal] = ACTIONS(6429),
    [anon_sym_DOLLARerror] = ACTIONS(6429),
    [anon_sym_DOLLARwarning] = ACTIONS(6429),
    [anon_sym_DOLLARinfo] = ACTIONS(6429),
    [anon_sym_default] = ACTIONS(6431),
    [anon_sym_clocking] = ACTIONS(6431),
    [anon_sym_defparam] = ACTIONS(6431),
    [anon_sym_bind] = ACTIONS(6431),
    [anon_sym_const] = ACTIONS(6431),
    [anon_sym_function] = ACTIONS(6431),
    [anon_sym_static] = ACTIONS(6431),
    [anon_sym_constraint] = ACTIONS(6431),
    [anon_sym_if] = ACTIONS(6431),
    [anon_sym_LBRACK] = ACTIONS(6429),
    [anon_sym_localparam] = ACTIONS(6431),
    [anon_sym_parameter] = ACTIONS(6431),
    [anon_sym_specparam] = ACTIONS(6431),
    [anon_sym_var] = ACTIONS(6431),
    [anon_sym_import] = ACTIONS(6431),
    [anon_sym_export] = ACTIONS(6431),
    [anon_sym_genvar] = ACTIONS(6431),
    [anon_sym_interconnect] = ACTIONS(6431),
    [anon_sym_typedef] = ACTIONS(6431),
    [anon_sym_enum] = ACTIONS(6431),
    [anon_sym_struct] = ACTIONS(6431),
    [anon_sym_union] = ACTIONS(6431),
    [anon_sym_nettype] = ACTIONS(6431),
    [anon_sym_automatic] = ACTIONS(6431),
    [anon_sym_string] = ACTIONS(6431),
    [anon_sym_chandle] = ACTIONS(6431),
    [anon_sym_event] = ACTIONS(6431),
    [anon_sym_byte] = ACTIONS(6431),
    [anon_sym_shortint] = ACTIONS(6431),
    [anon_sym_int] = ACTIONS(6431),
    [anon_sym_longint] = ACTIONS(6431),
    [anon_sym_integer] = ACTIONS(6431),
    [anon_sym_time] = ACTIONS(6431),
    [anon_sym_bit] = ACTIONS(6431),
    [anon_sym_logic] = ACTIONS(6431),
    [anon_sym_reg] = ACTIONS(6431),
    [anon_sym_shortreal] = ACTIONS(6431),
    [anon_sym_real] = ACTIONS(6431),
    [anon_sym_realtime] = ACTIONS(6431),
    [anon_sym_supply0] = ACTIONS(6431),
    [anon_sym_supply1] = ACTIONS(6431),
    [anon_sym_signed] = ACTIONS(6431),
    [anon_sym_unsigned] = ACTIONS(6431),
    [anon_sym_task] = ACTIONS(6431),
    [anon_sym_modport] = ACTIONS(6431),
    [anon_sym_assert] = ACTIONS(6431),
    [anon_sym_property] = ACTIONS(6431),
    [anon_sym_assume] = ACTIONS(6431),
    [anon_sym_cover] = ACTIONS(6431),
    [anon_sym_sequence] = ACTIONS(6431),
    [anon_sym_restrict] = ACTIONS(6431),
    [anon_sym_not] = ACTIONS(6431),
    [anon_sym_or] = ACTIONS(6431),
    [anon_sym_and] = ACTIONS(6431),
    [anon_sym_case] = ACTIONS(6431),
    [anon_sym_always] = ACTIONS(6431),
    [anon_sym_covergroup] = ACTIONS(6431),
    [anon_sym_let] = ACTIONS(6431),
    [anon_sym_pulldown] = ACTIONS(6431),
    [anon_sym_pullup] = ACTIONS(6431),
    [anon_sym_cmos] = ACTIONS(6431),
    [anon_sym_rcmos] = ACTIONS(6431),
    [anon_sym_bufif0] = ACTIONS(6431),
    [anon_sym_bufif1] = ACTIONS(6431),
    [anon_sym_notif0] = ACTIONS(6431),
    [anon_sym_notif1] = ACTIONS(6431),
    [anon_sym_nmos] = ACTIONS(6431),
    [anon_sym_pmos] = ACTIONS(6431),
    [anon_sym_rnmos] = ACTIONS(6431),
    [anon_sym_rpmos] = ACTIONS(6431),
    [anon_sym_nand] = ACTIONS(6431),
    [anon_sym_nor] = ACTIONS(6431),
    [anon_sym_xor] = ACTIONS(6431),
    [anon_sym_xnor] = ACTIONS(6431),
    [anon_sym_buf] = ACTIONS(6431),
    [anon_sym_tranif0] = ACTIONS(6431),
    [anon_sym_tranif1] = ACTIONS(6431),
    [anon_sym_rtranif1] = ACTIONS(6431),
    [anon_sym_rtranif0] = ACTIONS(6431),
    [anon_sym_tran] = ACTIONS(6431),
    [anon_sym_rtran] = ACTIONS(6431),
    [anon_sym_generate] = ACTIONS(6431),
    [anon_sym_for] = ACTIONS(6431),
    [anon_sym_primitive] = ACTIONS(6431),
    [anon_sym_initial] = ACTIONS(6431),
    [anon_sym_assign] = ACTIONS(6431),
    [anon_sym_alias] = ACTIONS(6431),
    [anon_sym_always_comb] = ACTIONS(6431),
    [anon_sym_always_latch] = ACTIONS(6431),
    [anon_sym_always_ff] = ACTIONS(6431),
    [anon_sym_final] = ACTIONS(6431),
    [anon_sym_global] = ACTIONS(6431),
    [anon_sym_specify] = ACTIONS(6431),
    [anon_sym_LPAREN_STAR] = ACTIONS(6429),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6429),
    [anon_sym_DOLLARunit] = ACTIONS(6429),
  },
  [1176] = {
    [sym_simple_identifier] = ACTIONS(6433),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6435),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6435),
    [anon_sym_BQUOTE] = ACTIONS(6433),
    [aux_sym_id_directive_token1] = ACTIONS(6435),
    [aux_sym_id_directive_token2] = ACTIONS(6435),
    [aux_sym_id_directive_token3] = ACTIONS(6435),
    [aux_sym_id_directive_token4] = ACTIONS(6433),
    [aux_sym_zero_directive_token1] = ACTIONS(6435),
    [aux_sym_zero_directive_token2] = ACTIONS(6435),
    [aux_sym_zero_directive_token3] = ACTIONS(6435),
    [aux_sym_zero_directive_token4] = ACTIONS(6435),
    [aux_sym_zero_directive_token5] = ACTIONS(6435),
    [aux_sym_zero_directive_token6] = ACTIONS(6435),
    [aux_sym_zero_directive_token7] = ACTIONS(6435),
    [aux_sym_zero_directive_token8] = ACTIONS(6435),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6435),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6435),
    [anon_sym_wire] = ACTIONS(6433),
    [anon_sym_tri] = ACTIONS(6433),
    [anon_sym_tri0] = ACTIONS(6433),
    [anon_sym_tri1] = ACTIONS(6433),
    [anon_sym_wand] = ACTIONS(6433),
    [anon_sym_triand] = ACTIONS(6433),
    [anon_sym_wor] = ACTIONS(6433),
    [anon_sym_trior] = ACTIONS(6433),
    [anon_sym_trireg] = ACTIONS(6433),
    [anon_sym_uwire] = ACTIONS(6433),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6435),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6435),
    [aux_sym_begin_keywords_token1] = ACTIONS(6435),
    [anon_sym_SEMI] = ACTIONS(6435),
    [anon_sym_endmodule] = ACTIONS(6433),
    [anon_sym_extern] = ACTIONS(6433),
    [anon_sym_module] = ACTIONS(6433),
    [anon_sym_macromodule] = ACTIONS(6433),
    [anon_sym_endinterface] = ACTIONS(6433),
    [anon_sym_interface] = ACTIONS(6433),
    [anon_sym_endprogram] = ACTIONS(6433),
    [anon_sym_program] = ACTIONS(6433),
    [anon_sym_checker] = ACTIONS(6433),
    [anon_sym_virtual] = ACTIONS(6433),
    [anon_sym_class] = ACTIONS(6433),
    [anon_sym_timeunit] = ACTIONS(6433),
    [anon_sym_timeprecision] = ACTIONS(6433),
    [anon_sym_type] = ACTIONS(6433),
    [anon_sym_input] = ACTIONS(6433),
    [anon_sym_output] = ACTIONS(6433),
    [anon_sym_inout] = ACTIONS(6433),
    [anon_sym_ref] = ACTIONS(6433),
    [anon_sym_DOLLARfatal] = ACTIONS(6435),
    [anon_sym_DOLLARerror] = ACTIONS(6435),
    [anon_sym_DOLLARwarning] = ACTIONS(6435),
    [anon_sym_DOLLARinfo] = ACTIONS(6435),
    [anon_sym_default] = ACTIONS(6433),
    [anon_sym_clocking] = ACTIONS(6433),
    [anon_sym_defparam] = ACTIONS(6433),
    [anon_sym_bind] = ACTIONS(6433),
    [anon_sym_const] = ACTIONS(6433),
    [anon_sym_function] = ACTIONS(6433),
    [anon_sym_static] = ACTIONS(6433),
    [anon_sym_constraint] = ACTIONS(6433),
    [anon_sym_if] = ACTIONS(6433),
    [anon_sym_else] = ACTIONS(6433),
    [anon_sym_LBRACK] = ACTIONS(6435),
    [anon_sym_localparam] = ACTIONS(6433),
    [anon_sym_parameter] = ACTIONS(6433),
    [anon_sym_specparam] = ACTIONS(6433),
    [anon_sym_var] = ACTIONS(6433),
    [anon_sym_import] = ACTIONS(6433),
    [anon_sym_export] = ACTIONS(6433),
    [anon_sym_genvar] = ACTIONS(6433),
    [anon_sym_interconnect] = ACTIONS(6433),
    [anon_sym_typedef] = ACTIONS(6433),
    [anon_sym_enum] = ACTIONS(6433),
    [anon_sym_struct] = ACTIONS(6433),
    [anon_sym_union] = ACTIONS(6433),
    [anon_sym_nettype] = ACTIONS(6433),
    [anon_sym_automatic] = ACTIONS(6433),
    [anon_sym_string] = ACTIONS(6433),
    [anon_sym_chandle] = ACTIONS(6433),
    [anon_sym_event] = ACTIONS(6433),
    [anon_sym_byte] = ACTIONS(6433),
    [anon_sym_shortint] = ACTIONS(6433),
    [anon_sym_int] = ACTIONS(6433),
    [anon_sym_longint] = ACTIONS(6433),
    [anon_sym_integer] = ACTIONS(6433),
    [anon_sym_time] = ACTIONS(6433),
    [anon_sym_bit] = ACTIONS(6433),
    [anon_sym_logic] = ACTIONS(6433),
    [anon_sym_reg] = ACTIONS(6433),
    [anon_sym_shortreal] = ACTIONS(6433),
    [anon_sym_real] = ACTIONS(6433),
    [anon_sym_realtime] = ACTIONS(6433),
    [anon_sym_supply0] = ACTIONS(6433),
    [anon_sym_supply1] = ACTIONS(6433),
    [anon_sym_signed] = ACTIONS(6433),
    [anon_sym_unsigned] = ACTIONS(6433),
    [anon_sym_task] = ACTIONS(6433),
    [anon_sym_modport] = ACTIONS(6433),
    [anon_sym_assert] = ACTIONS(6433),
    [anon_sym_property] = ACTIONS(6433),
    [anon_sym_assume] = ACTIONS(6433),
    [anon_sym_cover] = ACTIONS(6433),
    [anon_sym_sequence] = ACTIONS(6433),
    [anon_sym_restrict] = ACTIONS(6433),
    [anon_sym_not] = ACTIONS(6433),
    [anon_sym_or] = ACTIONS(6433),
    [anon_sym_and] = ACTIONS(6433),
    [anon_sym_case] = ACTIONS(6433),
    [anon_sym_always] = ACTIONS(6433),
    [anon_sym_covergroup] = ACTIONS(6433),
    [anon_sym_let] = ACTIONS(6433),
    [anon_sym_pulldown] = ACTIONS(6433),
    [anon_sym_pullup] = ACTIONS(6433),
    [anon_sym_cmos] = ACTIONS(6433),
    [anon_sym_rcmos] = ACTIONS(6433),
    [anon_sym_bufif0] = ACTIONS(6433),
    [anon_sym_bufif1] = ACTIONS(6433),
    [anon_sym_notif0] = ACTIONS(6433),
    [anon_sym_notif1] = ACTIONS(6433),
    [anon_sym_nmos] = ACTIONS(6433),
    [anon_sym_pmos] = ACTIONS(6433),
    [anon_sym_rnmos] = ACTIONS(6433),
    [anon_sym_rpmos] = ACTIONS(6433),
    [anon_sym_nand] = ACTIONS(6433),
    [anon_sym_nor] = ACTIONS(6433),
    [anon_sym_xor] = ACTIONS(6433),
    [anon_sym_xnor] = ACTIONS(6433),
    [anon_sym_buf] = ACTIONS(6433),
    [anon_sym_tranif0] = ACTIONS(6433),
    [anon_sym_tranif1] = ACTIONS(6433),
    [anon_sym_rtranif1] = ACTIONS(6433),
    [anon_sym_rtranif0] = ACTIONS(6433),
    [anon_sym_tran] = ACTIONS(6433),
    [anon_sym_rtran] = ACTIONS(6433),
    [anon_sym_generate] = ACTIONS(6433),
    [anon_sym_for] = ACTIONS(6433),
    [anon_sym_initial] = ACTIONS(6433),
    [anon_sym_assign] = ACTIONS(6433),
    [anon_sym_alias] = ACTIONS(6433),
    [anon_sym_always_comb] = ACTIONS(6433),
    [anon_sym_always_latch] = ACTIONS(6433),
    [anon_sym_always_ff] = ACTIONS(6433),
    [anon_sym_final] = ACTIONS(6433),
    [anon_sym_while] = ACTIONS(6433),
    [anon_sym_global] = ACTIONS(6433),
    [anon_sym_specify] = ACTIONS(6433),
    [anon_sym_LPAREN_STAR] = ACTIONS(6435),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6435),
    [anon_sym_DOLLARunit] = ACTIONS(6435),
  },
  [1177] = {
    [ts_builtin_sym_end] = ACTIONS(6437),
    [sym_simple_identifier] = ACTIONS(6439),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6437),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6437),
    [anon_sym_BQUOTE] = ACTIONS(6439),
    [aux_sym_id_directive_token1] = ACTIONS(6437),
    [aux_sym_id_directive_token2] = ACTIONS(6437),
    [aux_sym_id_directive_token3] = ACTIONS(6437),
    [aux_sym_id_directive_token4] = ACTIONS(6439),
    [aux_sym_zero_directive_token1] = ACTIONS(6437),
    [aux_sym_zero_directive_token2] = ACTIONS(6437),
    [aux_sym_zero_directive_token3] = ACTIONS(6437),
    [aux_sym_zero_directive_token4] = ACTIONS(6437),
    [aux_sym_zero_directive_token5] = ACTIONS(6437),
    [aux_sym_zero_directive_token6] = ACTIONS(6437),
    [aux_sym_zero_directive_token7] = ACTIONS(6437),
    [aux_sym_zero_directive_token8] = ACTIONS(6437),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6437),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6437),
    [anon_sym_wire] = ACTIONS(6439),
    [anon_sym_tri] = ACTIONS(6439),
    [anon_sym_tri0] = ACTIONS(6439),
    [anon_sym_tri1] = ACTIONS(6439),
    [anon_sym_wand] = ACTIONS(6439),
    [anon_sym_triand] = ACTIONS(6439),
    [anon_sym_wor] = ACTIONS(6439),
    [anon_sym_trior] = ACTIONS(6439),
    [anon_sym_trireg] = ACTIONS(6439),
    [anon_sym_uwire] = ACTIONS(6439),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6437),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6437),
    [aux_sym_begin_keywords_token1] = ACTIONS(6437),
    [anon_sym_SEMI] = ACTIONS(6437),
    [anon_sym_endmodule] = ACTIONS(6439),
    [anon_sym_extern] = ACTIONS(6439),
    [anon_sym_module] = ACTIONS(6439),
    [anon_sym_macromodule] = ACTIONS(6439),
    [anon_sym_endinterface] = ACTIONS(6439),
    [anon_sym_interface] = ACTIONS(6439),
    [anon_sym_program] = ACTIONS(6439),
    [anon_sym_checker] = ACTIONS(6439),
    [anon_sym_virtual] = ACTIONS(6439),
    [anon_sym_class] = ACTIONS(6439),
    [anon_sym_package] = ACTIONS(6439),
    [anon_sym_timeunit] = ACTIONS(6439),
    [anon_sym_timeprecision] = ACTIONS(6439),
    [anon_sym_type] = ACTIONS(6439),
    [anon_sym_input] = ACTIONS(6439),
    [anon_sym_output] = ACTIONS(6439),
    [anon_sym_inout] = ACTIONS(6439),
    [anon_sym_ref] = ACTIONS(6439),
    [anon_sym_DOLLARfatal] = ACTIONS(6437),
    [anon_sym_DOLLARerror] = ACTIONS(6437),
    [anon_sym_DOLLARwarning] = ACTIONS(6437),
    [anon_sym_DOLLARinfo] = ACTIONS(6437),
    [anon_sym_default] = ACTIONS(6439),
    [anon_sym_clocking] = ACTIONS(6439),
    [anon_sym_defparam] = ACTIONS(6439),
    [anon_sym_bind] = ACTIONS(6439),
    [anon_sym_const] = ACTIONS(6439),
    [anon_sym_function] = ACTIONS(6439),
    [anon_sym_static] = ACTIONS(6439),
    [anon_sym_constraint] = ACTIONS(6439),
    [anon_sym_if] = ACTIONS(6439),
    [anon_sym_LBRACK] = ACTIONS(6437),
    [anon_sym_localparam] = ACTIONS(6439),
    [anon_sym_parameter] = ACTIONS(6439),
    [anon_sym_specparam] = ACTIONS(6439),
    [anon_sym_var] = ACTIONS(6439),
    [anon_sym_import] = ACTIONS(6439),
    [anon_sym_export] = ACTIONS(6439),
    [anon_sym_genvar] = ACTIONS(6439),
    [anon_sym_interconnect] = ACTIONS(6439),
    [anon_sym_typedef] = ACTIONS(6439),
    [anon_sym_enum] = ACTIONS(6439),
    [anon_sym_struct] = ACTIONS(6439),
    [anon_sym_union] = ACTIONS(6439),
    [anon_sym_nettype] = ACTIONS(6439),
    [anon_sym_automatic] = ACTIONS(6439),
    [anon_sym_string] = ACTIONS(6439),
    [anon_sym_chandle] = ACTIONS(6439),
    [anon_sym_event] = ACTIONS(6439),
    [anon_sym_byte] = ACTIONS(6439),
    [anon_sym_shortint] = ACTIONS(6439),
    [anon_sym_int] = ACTIONS(6439),
    [anon_sym_longint] = ACTIONS(6439),
    [anon_sym_integer] = ACTIONS(6439),
    [anon_sym_time] = ACTIONS(6439),
    [anon_sym_bit] = ACTIONS(6439),
    [anon_sym_logic] = ACTIONS(6439),
    [anon_sym_reg] = ACTIONS(6439),
    [anon_sym_shortreal] = ACTIONS(6439),
    [anon_sym_real] = ACTIONS(6439),
    [anon_sym_realtime] = ACTIONS(6439),
    [anon_sym_supply0] = ACTIONS(6439),
    [anon_sym_supply1] = ACTIONS(6439),
    [anon_sym_signed] = ACTIONS(6439),
    [anon_sym_unsigned] = ACTIONS(6439),
    [anon_sym_task] = ACTIONS(6439),
    [anon_sym_modport] = ACTIONS(6439),
    [anon_sym_assert] = ACTIONS(6439),
    [anon_sym_property] = ACTIONS(6439),
    [anon_sym_assume] = ACTIONS(6439),
    [anon_sym_cover] = ACTIONS(6439),
    [anon_sym_sequence] = ACTIONS(6439),
    [anon_sym_restrict] = ACTIONS(6439),
    [anon_sym_not] = ACTIONS(6439),
    [anon_sym_or] = ACTIONS(6439),
    [anon_sym_and] = ACTIONS(6439),
    [anon_sym_case] = ACTIONS(6439),
    [anon_sym_always] = ACTIONS(6439),
    [anon_sym_covergroup] = ACTIONS(6439),
    [anon_sym_let] = ACTIONS(6439),
    [anon_sym_pulldown] = ACTIONS(6439),
    [anon_sym_pullup] = ACTIONS(6439),
    [anon_sym_cmos] = ACTIONS(6439),
    [anon_sym_rcmos] = ACTIONS(6439),
    [anon_sym_bufif0] = ACTIONS(6439),
    [anon_sym_bufif1] = ACTIONS(6439),
    [anon_sym_notif0] = ACTIONS(6439),
    [anon_sym_notif1] = ACTIONS(6439),
    [anon_sym_nmos] = ACTIONS(6439),
    [anon_sym_pmos] = ACTIONS(6439),
    [anon_sym_rnmos] = ACTIONS(6439),
    [anon_sym_rpmos] = ACTIONS(6439),
    [anon_sym_nand] = ACTIONS(6439),
    [anon_sym_nor] = ACTIONS(6439),
    [anon_sym_xor] = ACTIONS(6439),
    [anon_sym_xnor] = ACTIONS(6439),
    [anon_sym_buf] = ACTIONS(6439),
    [anon_sym_tranif0] = ACTIONS(6439),
    [anon_sym_tranif1] = ACTIONS(6439),
    [anon_sym_rtranif1] = ACTIONS(6439),
    [anon_sym_rtranif0] = ACTIONS(6439),
    [anon_sym_tran] = ACTIONS(6439),
    [anon_sym_rtran] = ACTIONS(6439),
    [anon_sym_generate] = ACTIONS(6439),
    [anon_sym_for] = ACTIONS(6439),
    [anon_sym_primitive] = ACTIONS(6439),
    [anon_sym_initial] = ACTIONS(6439),
    [anon_sym_assign] = ACTIONS(6439),
    [anon_sym_alias] = ACTIONS(6439),
    [anon_sym_always_comb] = ACTIONS(6439),
    [anon_sym_always_latch] = ACTIONS(6439),
    [anon_sym_always_ff] = ACTIONS(6439),
    [anon_sym_final] = ACTIONS(6439),
    [anon_sym_global] = ACTIONS(6439),
    [anon_sym_specify] = ACTIONS(6439),
    [anon_sym_LPAREN_STAR] = ACTIONS(6437),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6437),
    [anon_sym_DOLLARunit] = ACTIONS(6437),
  },
  [1178] = {
    [sym_simple_identifier] = ACTIONS(6441),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6445),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6445),
    [anon_sym_BQUOTE] = ACTIONS(6441),
    [aux_sym_id_directive_token1] = ACTIONS(6445),
    [aux_sym_id_directive_token2] = ACTIONS(6445),
    [aux_sym_id_directive_token3] = ACTIONS(6445),
    [aux_sym_id_directive_token4] = ACTIONS(6441),
    [aux_sym_zero_directive_token1] = ACTIONS(6445),
    [aux_sym_zero_directive_token2] = ACTIONS(6445),
    [aux_sym_zero_directive_token3] = ACTIONS(6445),
    [aux_sym_zero_directive_token4] = ACTIONS(6445),
    [aux_sym_zero_directive_token5] = ACTIONS(6445),
    [aux_sym_zero_directive_token6] = ACTIONS(6445),
    [aux_sym_zero_directive_token7] = ACTIONS(6445),
    [aux_sym_zero_directive_token8] = ACTIONS(6445),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6445),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6445),
    [anon_sym_wire] = ACTIONS(6441),
    [anon_sym_tri] = ACTIONS(6441),
    [anon_sym_tri0] = ACTIONS(6441),
    [anon_sym_tri1] = ACTIONS(6441),
    [anon_sym_wand] = ACTIONS(6441),
    [anon_sym_triand] = ACTIONS(6441),
    [anon_sym_wor] = ACTIONS(6441),
    [anon_sym_trior] = ACTIONS(6441),
    [anon_sym_trireg] = ACTIONS(6441),
    [anon_sym_uwire] = ACTIONS(6441),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6445),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6445),
    [aux_sym_begin_keywords_token1] = ACTIONS(6445),
    [anon_sym_SEMI] = ACTIONS(6445),
    [anon_sym_endmodule] = ACTIONS(6441),
    [anon_sym_extern] = ACTIONS(6441),
    [anon_sym_module] = ACTIONS(6441),
    [anon_sym_macromodule] = ACTIONS(6441),
    [anon_sym_endinterface] = ACTIONS(6441),
    [anon_sym_interface] = ACTIONS(6441),
    [anon_sym_endprogram] = ACTIONS(6441),
    [anon_sym_program] = ACTIONS(6441),
    [anon_sym_checker] = ACTIONS(6441),
    [anon_sym_virtual] = ACTIONS(6441),
    [anon_sym_class] = ACTIONS(6441),
    [anon_sym_timeunit] = ACTIONS(6441),
    [anon_sym_timeprecision] = ACTIONS(6441),
    [anon_sym_type] = ACTIONS(6441),
    [anon_sym_input] = ACTIONS(6441),
    [anon_sym_output] = ACTIONS(6441),
    [anon_sym_inout] = ACTIONS(6441),
    [anon_sym_ref] = ACTIONS(6441),
    [anon_sym_DOLLARfatal] = ACTIONS(6445),
    [anon_sym_DOLLARerror] = ACTIONS(6445),
    [anon_sym_DOLLARwarning] = ACTIONS(6445),
    [anon_sym_DOLLARinfo] = ACTIONS(6445),
    [anon_sym_default] = ACTIONS(6441),
    [anon_sym_clocking] = ACTIONS(6441),
    [anon_sym_defparam] = ACTIONS(6441),
    [anon_sym_bind] = ACTIONS(6441),
    [anon_sym_const] = ACTIONS(6441),
    [anon_sym_function] = ACTIONS(6441),
    [anon_sym_static] = ACTIONS(6441),
    [anon_sym_constraint] = ACTIONS(6441),
    [anon_sym_if] = ACTIONS(6441),
    [anon_sym_else] = ACTIONS(6441),
    [anon_sym_LBRACK] = ACTIONS(6445),
    [anon_sym_localparam] = ACTIONS(6441),
    [anon_sym_parameter] = ACTIONS(6441),
    [anon_sym_specparam] = ACTIONS(6441),
    [anon_sym_var] = ACTIONS(6441),
    [anon_sym_import] = ACTIONS(6441),
    [anon_sym_export] = ACTIONS(6441),
    [anon_sym_genvar] = ACTIONS(6441),
    [anon_sym_interconnect] = ACTIONS(6441),
    [anon_sym_typedef] = ACTIONS(6441),
    [anon_sym_enum] = ACTIONS(6441),
    [anon_sym_struct] = ACTIONS(6441),
    [anon_sym_union] = ACTIONS(6441),
    [anon_sym_nettype] = ACTIONS(6441),
    [anon_sym_automatic] = ACTIONS(6441),
    [anon_sym_string] = ACTIONS(6441),
    [anon_sym_chandle] = ACTIONS(6441),
    [anon_sym_event] = ACTIONS(6441),
    [anon_sym_byte] = ACTIONS(6441),
    [anon_sym_shortint] = ACTIONS(6441),
    [anon_sym_int] = ACTIONS(6441),
    [anon_sym_longint] = ACTIONS(6441),
    [anon_sym_integer] = ACTIONS(6441),
    [anon_sym_time] = ACTIONS(6441),
    [anon_sym_bit] = ACTIONS(6441),
    [anon_sym_logic] = ACTIONS(6441),
    [anon_sym_reg] = ACTIONS(6441),
    [anon_sym_shortreal] = ACTIONS(6441),
    [anon_sym_real] = ACTIONS(6441),
    [anon_sym_realtime] = ACTIONS(6441),
    [anon_sym_supply0] = ACTIONS(6441),
    [anon_sym_supply1] = ACTIONS(6441),
    [anon_sym_signed] = ACTIONS(6441),
    [anon_sym_unsigned] = ACTIONS(6441),
    [anon_sym_task] = ACTIONS(6441),
    [anon_sym_modport] = ACTIONS(6441),
    [anon_sym_assert] = ACTIONS(6441),
    [anon_sym_property] = ACTIONS(6441),
    [anon_sym_assume] = ACTIONS(6441),
    [anon_sym_cover] = ACTIONS(6441),
    [anon_sym_sequence] = ACTIONS(6441),
    [anon_sym_restrict] = ACTIONS(6441),
    [anon_sym_not] = ACTIONS(6441),
    [anon_sym_or] = ACTIONS(6441),
    [anon_sym_and] = ACTIONS(6441),
    [anon_sym_case] = ACTIONS(6441),
    [anon_sym_always] = ACTIONS(6441),
    [anon_sym_covergroup] = ACTIONS(6441),
    [anon_sym_let] = ACTIONS(6441),
    [anon_sym_pulldown] = ACTIONS(6441),
    [anon_sym_pullup] = ACTIONS(6441),
    [anon_sym_cmos] = ACTIONS(6441),
    [anon_sym_rcmos] = ACTIONS(6441),
    [anon_sym_bufif0] = ACTIONS(6441),
    [anon_sym_bufif1] = ACTIONS(6441),
    [anon_sym_notif0] = ACTIONS(6441),
    [anon_sym_notif1] = ACTIONS(6441),
    [anon_sym_nmos] = ACTIONS(6441),
    [anon_sym_pmos] = ACTIONS(6441),
    [anon_sym_rnmos] = ACTIONS(6441),
    [anon_sym_rpmos] = ACTIONS(6441),
    [anon_sym_nand] = ACTIONS(6441),
    [anon_sym_nor] = ACTIONS(6441),
    [anon_sym_xor] = ACTIONS(6441),
    [anon_sym_xnor] = ACTIONS(6441),
    [anon_sym_buf] = ACTIONS(6441),
    [anon_sym_tranif0] = ACTIONS(6441),
    [anon_sym_tranif1] = ACTIONS(6441),
    [anon_sym_rtranif1] = ACTIONS(6441),
    [anon_sym_rtranif0] = ACTIONS(6441),
    [anon_sym_tran] = ACTIONS(6441),
    [anon_sym_rtran] = ACTIONS(6441),
    [anon_sym_generate] = ACTIONS(6441),
    [anon_sym_for] = ACTIONS(6441),
    [anon_sym_initial] = ACTIONS(6441),
    [anon_sym_assign] = ACTIONS(6441),
    [anon_sym_alias] = ACTIONS(6441),
    [anon_sym_always_comb] = ACTIONS(6441),
    [anon_sym_always_latch] = ACTIONS(6441),
    [anon_sym_always_ff] = ACTIONS(6441),
    [anon_sym_final] = ACTIONS(6441),
    [anon_sym_global] = ACTIONS(6441),
    [anon_sym_specify] = ACTIONS(6441),
    [anon_sym_LPAREN_STAR] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6445),
    [anon_sym_DOLLARunit] = ACTIONS(6445),
  },
  [1179] = {
    [sym_simple_identifier] = ACTIONS(6449),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6451),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6451),
    [anon_sym_BQUOTE] = ACTIONS(6449),
    [aux_sym_id_directive_token1] = ACTIONS(6451),
    [aux_sym_id_directive_token2] = ACTIONS(6451),
    [aux_sym_id_directive_token3] = ACTIONS(6451),
    [aux_sym_id_directive_token4] = ACTIONS(6449),
    [aux_sym_zero_directive_token1] = ACTIONS(6451),
    [aux_sym_zero_directive_token2] = ACTIONS(6451),
    [aux_sym_zero_directive_token3] = ACTIONS(6451),
    [aux_sym_zero_directive_token4] = ACTIONS(6451),
    [aux_sym_zero_directive_token5] = ACTIONS(6451),
    [aux_sym_zero_directive_token6] = ACTIONS(6451),
    [aux_sym_zero_directive_token7] = ACTIONS(6451),
    [aux_sym_zero_directive_token8] = ACTIONS(6451),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6451),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6451),
    [anon_sym_wire] = ACTIONS(6449),
    [anon_sym_tri] = ACTIONS(6449),
    [anon_sym_tri0] = ACTIONS(6449),
    [anon_sym_tri1] = ACTIONS(6449),
    [anon_sym_wand] = ACTIONS(6449),
    [anon_sym_triand] = ACTIONS(6449),
    [anon_sym_wor] = ACTIONS(6449),
    [anon_sym_trior] = ACTIONS(6449),
    [anon_sym_trireg] = ACTIONS(6449),
    [anon_sym_uwire] = ACTIONS(6449),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6451),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6451),
    [aux_sym_begin_keywords_token1] = ACTIONS(6451),
    [anon_sym_SEMI] = ACTIONS(6451),
    [anon_sym_endmodule] = ACTIONS(6449),
    [anon_sym_extern] = ACTIONS(6449),
    [anon_sym_module] = ACTIONS(6449),
    [anon_sym_macromodule] = ACTIONS(6449),
    [anon_sym_endinterface] = ACTIONS(6449),
    [anon_sym_interface] = ACTIONS(6449),
    [anon_sym_endprogram] = ACTIONS(6449),
    [anon_sym_program] = ACTIONS(6449),
    [anon_sym_checker] = ACTIONS(6449),
    [anon_sym_virtual] = ACTIONS(6449),
    [anon_sym_class] = ACTIONS(6449),
    [anon_sym_timeunit] = ACTIONS(6449),
    [anon_sym_timeprecision] = ACTIONS(6449),
    [anon_sym_type] = ACTIONS(6449),
    [anon_sym_input] = ACTIONS(6449),
    [anon_sym_output] = ACTIONS(6449),
    [anon_sym_inout] = ACTIONS(6449),
    [anon_sym_ref] = ACTIONS(6449),
    [anon_sym_DOLLARfatal] = ACTIONS(6451),
    [anon_sym_DOLLARerror] = ACTIONS(6451),
    [anon_sym_DOLLARwarning] = ACTIONS(6451),
    [anon_sym_DOLLARinfo] = ACTIONS(6451),
    [anon_sym_default] = ACTIONS(6449),
    [anon_sym_clocking] = ACTIONS(6449),
    [anon_sym_defparam] = ACTIONS(6449),
    [anon_sym_bind] = ACTIONS(6449),
    [anon_sym_const] = ACTIONS(6449),
    [anon_sym_function] = ACTIONS(6449),
    [anon_sym_static] = ACTIONS(6449),
    [anon_sym_constraint] = ACTIONS(6449),
    [anon_sym_if] = ACTIONS(6449),
    [anon_sym_else] = ACTIONS(6449),
    [anon_sym_LBRACK] = ACTIONS(6451),
    [anon_sym_localparam] = ACTIONS(6449),
    [anon_sym_parameter] = ACTIONS(6449),
    [anon_sym_specparam] = ACTIONS(6449),
    [anon_sym_var] = ACTIONS(6449),
    [anon_sym_import] = ACTIONS(6449),
    [anon_sym_export] = ACTIONS(6449),
    [anon_sym_genvar] = ACTIONS(6449),
    [anon_sym_interconnect] = ACTIONS(6449),
    [anon_sym_typedef] = ACTIONS(6449),
    [anon_sym_enum] = ACTIONS(6449),
    [anon_sym_struct] = ACTIONS(6449),
    [anon_sym_union] = ACTIONS(6449),
    [anon_sym_nettype] = ACTIONS(6449),
    [anon_sym_automatic] = ACTIONS(6449),
    [anon_sym_string] = ACTIONS(6449),
    [anon_sym_chandle] = ACTIONS(6449),
    [anon_sym_event] = ACTIONS(6449),
    [anon_sym_byte] = ACTIONS(6449),
    [anon_sym_shortint] = ACTIONS(6449),
    [anon_sym_int] = ACTIONS(6449),
    [anon_sym_longint] = ACTIONS(6449),
    [anon_sym_integer] = ACTIONS(6449),
    [anon_sym_time] = ACTIONS(6449),
    [anon_sym_bit] = ACTIONS(6449),
    [anon_sym_logic] = ACTIONS(6449),
    [anon_sym_reg] = ACTIONS(6449),
    [anon_sym_shortreal] = ACTIONS(6449),
    [anon_sym_real] = ACTIONS(6449),
    [anon_sym_realtime] = ACTIONS(6449),
    [anon_sym_supply0] = ACTIONS(6449),
    [anon_sym_supply1] = ACTIONS(6449),
    [anon_sym_signed] = ACTIONS(6449),
    [anon_sym_unsigned] = ACTIONS(6449),
    [anon_sym_task] = ACTIONS(6449),
    [anon_sym_modport] = ACTIONS(6449),
    [anon_sym_assert] = ACTIONS(6449),
    [anon_sym_property] = ACTIONS(6449),
    [anon_sym_assume] = ACTIONS(6449),
    [anon_sym_cover] = ACTIONS(6449),
    [anon_sym_sequence] = ACTIONS(6449),
    [anon_sym_restrict] = ACTIONS(6449),
    [anon_sym_not] = ACTIONS(6449),
    [anon_sym_or] = ACTIONS(6449),
    [anon_sym_and] = ACTIONS(6449),
    [anon_sym_case] = ACTIONS(6449),
    [anon_sym_always] = ACTIONS(6449),
    [anon_sym_covergroup] = ACTIONS(6449),
    [anon_sym_let] = ACTIONS(6449),
    [anon_sym_pulldown] = ACTIONS(6449),
    [anon_sym_pullup] = ACTIONS(6449),
    [anon_sym_cmos] = ACTIONS(6449),
    [anon_sym_rcmos] = ACTIONS(6449),
    [anon_sym_bufif0] = ACTIONS(6449),
    [anon_sym_bufif1] = ACTIONS(6449),
    [anon_sym_notif0] = ACTIONS(6449),
    [anon_sym_notif1] = ACTIONS(6449),
    [anon_sym_nmos] = ACTIONS(6449),
    [anon_sym_pmos] = ACTIONS(6449),
    [anon_sym_rnmos] = ACTIONS(6449),
    [anon_sym_rpmos] = ACTIONS(6449),
    [anon_sym_nand] = ACTIONS(6449),
    [anon_sym_nor] = ACTIONS(6449),
    [anon_sym_xor] = ACTIONS(6449),
    [anon_sym_xnor] = ACTIONS(6449),
    [anon_sym_buf] = ACTIONS(6449),
    [anon_sym_tranif0] = ACTIONS(6449),
    [anon_sym_tranif1] = ACTIONS(6449),
    [anon_sym_rtranif1] = ACTIONS(6449),
    [anon_sym_rtranif0] = ACTIONS(6449),
    [anon_sym_tran] = ACTIONS(6449),
    [anon_sym_rtran] = ACTIONS(6449),
    [anon_sym_generate] = ACTIONS(6449),
    [anon_sym_for] = ACTIONS(6449),
    [anon_sym_initial] = ACTIONS(6449),
    [anon_sym_assign] = ACTIONS(6449),
    [anon_sym_alias] = ACTIONS(6449),
    [anon_sym_always_comb] = ACTIONS(6449),
    [anon_sym_always_latch] = ACTIONS(6449),
    [anon_sym_always_ff] = ACTIONS(6449),
    [anon_sym_final] = ACTIONS(6449),
    [anon_sym_global] = ACTIONS(6449),
    [anon_sym_specify] = ACTIONS(6449),
    [anon_sym_LPAREN_STAR] = ACTIONS(6451),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6451),
    [anon_sym_DOLLARunit] = ACTIONS(6451),
  },
  [1180] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9420),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_RBRACE] = ACTIONS(2648),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_with] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [1181] = {
    [sym_simple_identifier] = ACTIONS(6457),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6459),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6459),
    [anon_sym_BQUOTE] = ACTIONS(6457),
    [aux_sym_id_directive_token1] = ACTIONS(6459),
    [aux_sym_id_directive_token2] = ACTIONS(6459),
    [aux_sym_id_directive_token3] = ACTIONS(6459),
    [aux_sym_id_directive_token4] = ACTIONS(6457),
    [aux_sym_zero_directive_token1] = ACTIONS(6459),
    [aux_sym_zero_directive_token2] = ACTIONS(6459),
    [aux_sym_zero_directive_token3] = ACTIONS(6459),
    [aux_sym_zero_directive_token4] = ACTIONS(6459),
    [aux_sym_zero_directive_token5] = ACTIONS(6459),
    [aux_sym_zero_directive_token6] = ACTIONS(6459),
    [aux_sym_zero_directive_token7] = ACTIONS(6459),
    [aux_sym_zero_directive_token8] = ACTIONS(6459),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6459),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6459),
    [anon_sym_wire] = ACTIONS(6457),
    [anon_sym_tri] = ACTIONS(6457),
    [anon_sym_tri0] = ACTIONS(6457),
    [anon_sym_tri1] = ACTIONS(6457),
    [anon_sym_wand] = ACTIONS(6457),
    [anon_sym_triand] = ACTIONS(6457),
    [anon_sym_wor] = ACTIONS(6457),
    [anon_sym_trior] = ACTIONS(6457),
    [anon_sym_trireg] = ACTIONS(6457),
    [anon_sym_uwire] = ACTIONS(6457),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6459),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6459),
    [aux_sym_begin_keywords_token1] = ACTIONS(6459),
    [anon_sym_SEMI] = ACTIONS(6459),
    [anon_sym_endmodule] = ACTIONS(6457),
    [anon_sym_extern] = ACTIONS(6457),
    [anon_sym_module] = ACTIONS(6457),
    [anon_sym_macromodule] = ACTIONS(6457),
    [anon_sym_endinterface] = ACTIONS(6457),
    [anon_sym_interface] = ACTIONS(6457),
    [anon_sym_endprogram] = ACTIONS(6457),
    [anon_sym_program] = ACTIONS(6457),
    [anon_sym_checker] = ACTIONS(6457),
    [anon_sym_virtual] = ACTIONS(6457),
    [anon_sym_class] = ACTIONS(6457),
    [anon_sym_timeunit] = ACTIONS(6457),
    [anon_sym_timeprecision] = ACTIONS(6457),
    [anon_sym_type] = ACTIONS(6457),
    [anon_sym_input] = ACTIONS(6457),
    [anon_sym_output] = ACTIONS(6457),
    [anon_sym_inout] = ACTIONS(6457),
    [anon_sym_ref] = ACTIONS(6457),
    [anon_sym_DOLLARfatal] = ACTIONS(6459),
    [anon_sym_DOLLARerror] = ACTIONS(6459),
    [anon_sym_DOLLARwarning] = ACTIONS(6459),
    [anon_sym_DOLLARinfo] = ACTIONS(6459),
    [anon_sym_default] = ACTIONS(6457),
    [anon_sym_clocking] = ACTIONS(6457),
    [anon_sym_defparam] = ACTIONS(6457),
    [anon_sym_bind] = ACTIONS(6457),
    [anon_sym_const] = ACTIONS(6457),
    [anon_sym_function] = ACTIONS(6457),
    [anon_sym_static] = ACTIONS(6457),
    [anon_sym_constraint] = ACTIONS(6457),
    [anon_sym_if] = ACTIONS(6457),
    [anon_sym_else] = ACTIONS(6457),
    [anon_sym_LBRACK] = ACTIONS(6459),
    [anon_sym_localparam] = ACTIONS(6457),
    [anon_sym_parameter] = ACTIONS(6457),
    [anon_sym_specparam] = ACTIONS(6457),
    [anon_sym_var] = ACTIONS(6457),
    [anon_sym_import] = ACTIONS(6457),
    [anon_sym_export] = ACTIONS(6457),
    [anon_sym_genvar] = ACTIONS(6457),
    [anon_sym_interconnect] = ACTIONS(6457),
    [anon_sym_typedef] = ACTIONS(6457),
    [anon_sym_enum] = ACTIONS(6457),
    [anon_sym_struct] = ACTIONS(6457),
    [anon_sym_union] = ACTIONS(6457),
    [anon_sym_nettype] = ACTIONS(6457),
    [anon_sym_automatic] = ACTIONS(6457),
    [anon_sym_string] = ACTIONS(6457),
    [anon_sym_chandle] = ACTIONS(6457),
    [anon_sym_event] = ACTIONS(6457),
    [anon_sym_byte] = ACTIONS(6457),
    [anon_sym_shortint] = ACTIONS(6457),
    [anon_sym_int] = ACTIONS(6457),
    [anon_sym_longint] = ACTIONS(6457),
    [anon_sym_integer] = ACTIONS(6457),
    [anon_sym_time] = ACTIONS(6457),
    [anon_sym_bit] = ACTIONS(6457),
    [anon_sym_logic] = ACTIONS(6457),
    [anon_sym_reg] = ACTIONS(6457),
    [anon_sym_shortreal] = ACTIONS(6457),
    [anon_sym_real] = ACTIONS(6457),
    [anon_sym_realtime] = ACTIONS(6457),
    [anon_sym_supply0] = ACTIONS(6457),
    [anon_sym_supply1] = ACTIONS(6457),
    [anon_sym_signed] = ACTIONS(6457),
    [anon_sym_unsigned] = ACTIONS(6457),
    [anon_sym_task] = ACTIONS(6457),
    [anon_sym_modport] = ACTIONS(6457),
    [anon_sym_assert] = ACTIONS(6457),
    [anon_sym_property] = ACTIONS(6457),
    [anon_sym_assume] = ACTIONS(6457),
    [anon_sym_cover] = ACTIONS(6457),
    [anon_sym_sequence] = ACTIONS(6457),
    [anon_sym_restrict] = ACTIONS(6457),
    [anon_sym_not] = ACTIONS(6457),
    [anon_sym_or] = ACTIONS(6457),
    [anon_sym_and] = ACTIONS(6457),
    [anon_sym_case] = ACTIONS(6457),
    [anon_sym_always] = ACTIONS(6457),
    [anon_sym_covergroup] = ACTIONS(6457),
    [anon_sym_let] = ACTIONS(6457),
    [anon_sym_pulldown] = ACTIONS(6457),
    [anon_sym_pullup] = ACTIONS(6457),
    [anon_sym_cmos] = ACTIONS(6457),
    [anon_sym_rcmos] = ACTIONS(6457),
    [anon_sym_bufif0] = ACTIONS(6457),
    [anon_sym_bufif1] = ACTIONS(6457),
    [anon_sym_notif0] = ACTIONS(6457),
    [anon_sym_notif1] = ACTIONS(6457),
    [anon_sym_nmos] = ACTIONS(6457),
    [anon_sym_pmos] = ACTIONS(6457),
    [anon_sym_rnmos] = ACTIONS(6457),
    [anon_sym_rpmos] = ACTIONS(6457),
    [anon_sym_nand] = ACTIONS(6457),
    [anon_sym_nor] = ACTIONS(6457),
    [anon_sym_xor] = ACTIONS(6457),
    [anon_sym_xnor] = ACTIONS(6457),
    [anon_sym_buf] = ACTIONS(6457),
    [anon_sym_tranif0] = ACTIONS(6457),
    [anon_sym_tranif1] = ACTIONS(6457),
    [anon_sym_rtranif1] = ACTIONS(6457),
    [anon_sym_rtranif0] = ACTIONS(6457),
    [anon_sym_tran] = ACTIONS(6457),
    [anon_sym_rtran] = ACTIONS(6457),
    [anon_sym_generate] = ACTIONS(6457),
    [anon_sym_for] = ACTIONS(6457),
    [anon_sym_initial] = ACTIONS(6457),
    [anon_sym_assign] = ACTIONS(6457),
    [anon_sym_alias] = ACTIONS(6457),
    [anon_sym_always_comb] = ACTIONS(6457),
    [anon_sym_always_latch] = ACTIONS(6457),
    [anon_sym_always_ff] = ACTIONS(6457),
    [anon_sym_final] = ACTIONS(6457),
    [anon_sym_global] = ACTIONS(6457),
    [anon_sym_specify] = ACTIONS(6457),
    [anon_sym_LPAREN_STAR] = ACTIONS(6459),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6459),
    [anon_sym_DOLLARunit] = ACTIONS(6459),
  },
  [1182] = {
    [ts_builtin_sym_end] = ACTIONS(6461),
    [sym_simple_identifier] = ACTIONS(6463),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6461),
    [anon_sym_BQUOTE] = ACTIONS(6463),
    [aux_sym_id_directive_token1] = ACTIONS(6461),
    [aux_sym_id_directive_token2] = ACTIONS(6461),
    [aux_sym_id_directive_token3] = ACTIONS(6461),
    [aux_sym_id_directive_token4] = ACTIONS(6463),
    [aux_sym_zero_directive_token1] = ACTIONS(6461),
    [aux_sym_zero_directive_token2] = ACTIONS(6461),
    [aux_sym_zero_directive_token3] = ACTIONS(6461),
    [aux_sym_zero_directive_token4] = ACTIONS(6461),
    [aux_sym_zero_directive_token5] = ACTIONS(6461),
    [aux_sym_zero_directive_token6] = ACTIONS(6461),
    [aux_sym_zero_directive_token7] = ACTIONS(6461),
    [aux_sym_zero_directive_token8] = ACTIONS(6461),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6461),
    [anon_sym_wire] = ACTIONS(6463),
    [anon_sym_tri] = ACTIONS(6463),
    [anon_sym_tri0] = ACTIONS(6463),
    [anon_sym_tri1] = ACTIONS(6463),
    [anon_sym_wand] = ACTIONS(6463),
    [anon_sym_triand] = ACTIONS(6463),
    [anon_sym_wor] = ACTIONS(6463),
    [anon_sym_trior] = ACTIONS(6463),
    [anon_sym_trireg] = ACTIONS(6463),
    [anon_sym_uwire] = ACTIONS(6463),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6461),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_begin_keywords_token1] = ACTIONS(6461),
    [anon_sym_SEMI] = ACTIONS(6461),
    [anon_sym_endmodule] = ACTIONS(6463),
    [anon_sym_COLON] = ACTIONS(6465),
    [anon_sym_extern] = ACTIONS(6463),
    [anon_sym_module] = ACTIONS(6463),
    [anon_sym_macromodule] = ACTIONS(6463),
    [anon_sym_interface] = ACTIONS(6463),
    [anon_sym_program] = ACTIONS(6463),
    [anon_sym_checker] = ACTIONS(6463),
    [anon_sym_virtual] = ACTIONS(6463),
    [anon_sym_class] = ACTIONS(6463),
    [anon_sym_package] = ACTIONS(6463),
    [anon_sym_timeunit] = ACTIONS(6463),
    [anon_sym_timeprecision] = ACTIONS(6463),
    [anon_sym_type] = ACTIONS(6463),
    [anon_sym_input] = ACTIONS(6463),
    [anon_sym_output] = ACTIONS(6463),
    [anon_sym_inout] = ACTIONS(6463),
    [anon_sym_ref] = ACTIONS(6463),
    [anon_sym_DOLLARfatal] = ACTIONS(6461),
    [anon_sym_DOLLARerror] = ACTIONS(6461),
    [anon_sym_DOLLARwarning] = ACTIONS(6461),
    [anon_sym_DOLLARinfo] = ACTIONS(6461),
    [anon_sym_default] = ACTIONS(6463),
    [anon_sym_clocking] = ACTIONS(6463),
    [anon_sym_defparam] = ACTIONS(6463),
    [anon_sym_bind] = ACTIONS(6463),
    [anon_sym_const] = ACTIONS(6463),
    [anon_sym_function] = ACTIONS(6463),
    [anon_sym_static] = ACTIONS(6463),
    [anon_sym_constraint] = ACTIONS(6463),
    [anon_sym_if] = ACTIONS(6463),
    [anon_sym_LBRACK] = ACTIONS(6461),
    [anon_sym_localparam] = ACTIONS(6463),
    [anon_sym_parameter] = ACTIONS(6463),
    [anon_sym_specparam] = ACTIONS(6463),
    [anon_sym_var] = ACTIONS(6463),
    [anon_sym_import] = ACTIONS(6463),
    [anon_sym_export] = ACTIONS(6463),
    [anon_sym_genvar] = ACTIONS(6463),
    [anon_sym_interconnect] = ACTIONS(6463),
    [anon_sym_typedef] = ACTIONS(6463),
    [anon_sym_enum] = ACTIONS(6463),
    [anon_sym_struct] = ACTIONS(6463),
    [anon_sym_union] = ACTIONS(6463),
    [anon_sym_nettype] = ACTIONS(6463),
    [anon_sym_automatic] = ACTIONS(6463),
    [anon_sym_string] = ACTIONS(6463),
    [anon_sym_chandle] = ACTIONS(6463),
    [anon_sym_event] = ACTIONS(6463),
    [anon_sym_byte] = ACTIONS(6463),
    [anon_sym_shortint] = ACTIONS(6463),
    [anon_sym_int] = ACTIONS(6463),
    [anon_sym_longint] = ACTIONS(6463),
    [anon_sym_integer] = ACTIONS(6463),
    [anon_sym_time] = ACTIONS(6463),
    [anon_sym_bit] = ACTIONS(6463),
    [anon_sym_logic] = ACTIONS(6463),
    [anon_sym_reg] = ACTIONS(6463),
    [anon_sym_shortreal] = ACTIONS(6463),
    [anon_sym_real] = ACTIONS(6463),
    [anon_sym_realtime] = ACTIONS(6463),
    [anon_sym_supply0] = ACTIONS(6463),
    [anon_sym_supply1] = ACTIONS(6463),
    [anon_sym_signed] = ACTIONS(6463),
    [anon_sym_unsigned] = ACTIONS(6463),
    [anon_sym_task] = ACTIONS(6463),
    [anon_sym_assert] = ACTIONS(6463),
    [anon_sym_property] = ACTIONS(6463),
    [anon_sym_assume] = ACTIONS(6463),
    [anon_sym_cover] = ACTIONS(6463),
    [anon_sym_sequence] = ACTIONS(6463),
    [anon_sym_restrict] = ACTIONS(6463),
    [anon_sym_not] = ACTIONS(6463),
    [anon_sym_or] = ACTIONS(6463),
    [anon_sym_and] = ACTIONS(6463),
    [anon_sym_case] = ACTIONS(6463),
    [anon_sym_always] = ACTIONS(6463),
    [anon_sym_covergroup] = ACTIONS(6463),
    [anon_sym_let] = ACTIONS(6463),
    [anon_sym_pulldown] = ACTIONS(6463),
    [anon_sym_pullup] = ACTIONS(6463),
    [anon_sym_cmos] = ACTIONS(6463),
    [anon_sym_rcmos] = ACTIONS(6463),
    [anon_sym_bufif0] = ACTIONS(6463),
    [anon_sym_bufif1] = ACTIONS(6463),
    [anon_sym_notif0] = ACTIONS(6463),
    [anon_sym_notif1] = ACTIONS(6463),
    [anon_sym_nmos] = ACTIONS(6463),
    [anon_sym_pmos] = ACTIONS(6463),
    [anon_sym_rnmos] = ACTIONS(6463),
    [anon_sym_rpmos] = ACTIONS(6463),
    [anon_sym_nand] = ACTIONS(6463),
    [anon_sym_nor] = ACTIONS(6463),
    [anon_sym_xor] = ACTIONS(6463),
    [anon_sym_xnor] = ACTIONS(6463),
    [anon_sym_buf] = ACTIONS(6463),
    [anon_sym_tranif0] = ACTIONS(6463),
    [anon_sym_tranif1] = ACTIONS(6463),
    [anon_sym_rtranif1] = ACTIONS(6463),
    [anon_sym_rtranif0] = ACTIONS(6463),
    [anon_sym_tran] = ACTIONS(6463),
    [anon_sym_rtran] = ACTIONS(6463),
    [anon_sym_generate] = ACTIONS(6463),
    [anon_sym_for] = ACTIONS(6463),
    [anon_sym_primitive] = ACTIONS(6463),
    [anon_sym_initial] = ACTIONS(6463),
    [anon_sym_assign] = ACTIONS(6463),
    [anon_sym_alias] = ACTIONS(6463),
    [anon_sym_always_comb] = ACTIONS(6463),
    [anon_sym_always_latch] = ACTIONS(6463),
    [anon_sym_always_ff] = ACTIONS(6463),
    [anon_sym_final] = ACTIONS(6463),
    [anon_sym_global] = ACTIONS(6463),
    [anon_sym_specify] = ACTIONS(6463),
    [anon_sym_LPAREN_STAR] = ACTIONS(6461),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6461),
    [anon_sym_DOLLARunit] = ACTIONS(6461),
  },
  [1183] = {
    [sym_simple_identifier] = ACTIONS(6467),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6469),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6469),
    [anon_sym_BQUOTE] = ACTIONS(6467),
    [aux_sym_id_directive_token1] = ACTIONS(6469),
    [aux_sym_id_directive_token2] = ACTIONS(6469),
    [aux_sym_id_directive_token3] = ACTIONS(6469),
    [aux_sym_id_directive_token4] = ACTIONS(6467),
    [aux_sym_zero_directive_token1] = ACTIONS(6469),
    [aux_sym_zero_directive_token2] = ACTIONS(6469),
    [aux_sym_zero_directive_token3] = ACTIONS(6469),
    [aux_sym_zero_directive_token4] = ACTIONS(6469),
    [aux_sym_zero_directive_token5] = ACTIONS(6469),
    [aux_sym_zero_directive_token6] = ACTIONS(6469),
    [aux_sym_zero_directive_token7] = ACTIONS(6469),
    [aux_sym_zero_directive_token8] = ACTIONS(6469),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6469),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6469),
    [anon_sym_wire] = ACTIONS(6467),
    [anon_sym_tri] = ACTIONS(6467),
    [anon_sym_tri0] = ACTIONS(6467),
    [anon_sym_tri1] = ACTIONS(6467),
    [anon_sym_wand] = ACTIONS(6467),
    [anon_sym_triand] = ACTIONS(6467),
    [anon_sym_wor] = ACTIONS(6467),
    [anon_sym_trior] = ACTIONS(6467),
    [anon_sym_trireg] = ACTIONS(6467),
    [anon_sym_uwire] = ACTIONS(6467),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6469),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6469),
    [aux_sym_begin_keywords_token1] = ACTIONS(6469),
    [anon_sym_SEMI] = ACTIONS(6469),
    [anon_sym_endmodule] = ACTIONS(6467),
    [anon_sym_extern] = ACTIONS(6467),
    [anon_sym_module] = ACTIONS(6467),
    [anon_sym_macromodule] = ACTIONS(6467),
    [anon_sym_endinterface] = ACTIONS(6467),
    [anon_sym_interface] = ACTIONS(6467),
    [anon_sym_endprogram] = ACTIONS(6467),
    [anon_sym_program] = ACTIONS(6467),
    [anon_sym_checker] = ACTIONS(6467),
    [anon_sym_virtual] = ACTIONS(6467),
    [anon_sym_class] = ACTIONS(6467),
    [anon_sym_timeunit] = ACTIONS(6467),
    [anon_sym_timeprecision] = ACTIONS(6467),
    [anon_sym_type] = ACTIONS(6467),
    [anon_sym_input] = ACTIONS(6467),
    [anon_sym_output] = ACTIONS(6467),
    [anon_sym_inout] = ACTIONS(6467),
    [anon_sym_ref] = ACTIONS(6467),
    [anon_sym_DOLLARfatal] = ACTIONS(6469),
    [anon_sym_DOLLARerror] = ACTIONS(6469),
    [anon_sym_DOLLARwarning] = ACTIONS(6469),
    [anon_sym_DOLLARinfo] = ACTIONS(6469),
    [anon_sym_default] = ACTIONS(6467),
    [anon_sym_clocking] = ACTIONS(6467),
    [anon_sym_defparam] = ACTIONS(6467),
    [anon_sym_bind] = ACTIONS(6467),
    [anon_sym_const] = ACTIONS(6467),
    [anon_sym_function] = ACTIONS(6467),
    [anon_sym_static] = ACTIONS(6467),
    [anon_sym_constraint] = ACTIONS(6467),
    [anon_sym_if] = ACTIONS(6467),
    [anon_sym_else] = ACTIONS(6467),
    [anon_sym_LBRACK] = ACTIONS(6469),
    [anon_sym_localparam] = ACTIONS(6467),
    [anon_sym_parameter] = ACTIONS(6467),
    [anon_sym_specparam] = ACTIONS(6467),
    [anon_sym_var] = ACTIONS(6467),
    [anon_sym_import] = ACTIONS(6467),
    [anon_sym_export] = ACTIONS(6467),
    [anon_sym_genvar] = ACTIONS(6467),
    [anon_sym_interconnect] = ACTIONS(6467),
    [anon_sym_typedef] = ACTIONS(6467),
    [anon_sym_enum] = ACTIONS(6467),
    [anon_sym_struct] = ACTIONS(6467),
    [anon_sym_union] = ACTIONS(6467),
    [anon_sym_nettype] = ACTIONS(6467),
    [anon_sym_automatic] = ACTIONS(6467),
    [anon_sym_string] = ACTIONS(6467),
    [anon_sym_chandle] = ACTIONS(6467),
    [anon_sym_event] = ACTIONS(6467),
    [anon_sym_byte] = ACTIONS(6467),
    [anon_sym_shortint] = ACTIONS(6467),
    [anon_sym_int] = ACTIONS(6467),
    [anon_sym_longint] = ACTIONS(6467),
    [anon_sym_integer] = ACTIONS(6467),
    [anon_sym_time] = ACTIONS(6467),
    [anon_sym_bit] = ACTIONS(6467),
    [anon_sym_logic] = ACTIONS(6467),
    [anon_sym_reg] = ACTIONS(6467),
    [anon_sym_shortreal] = ACTIONS(6467),
    [anon_sym_real] = ACTIONS(6467),
    [anon_sym_realtime] = ACTIONS(6467),
    [anon_sym_supply0] = ACTIONS(6467),
    [anon_sym_supply1] = ACTIONS(6467),
    [anon_sym_signed] = ACTIONS(6467),
    [anon_sym_unsigned] = ACTIONS(6467),
    [anon_sym_task] = ACTIONS(6467),
    [anon_sym_modport] = ACTIONS(6467),
    [anon_sym_assert] = ACTIONS(6467),
    [anon_sym_property] = ACTIONS(6467),
    [anon_sym_assume] = ACTIONS(6467),
    [anon_sym_cover] = ACTIONS(6467),
    [anon_sym_sequence] = ACTIONS(6467),
    [anon_sym_restrict] = ACTIONS(6467),
    [anon_sym_not] = ACTIONS(6467),
    [anon_sym_or] = ACTIONS(6467),
    [anon_sym_and] = ACTIONS(6467),
    [anon_sym_case] = ACTIONS(6467),
    [anon_sym_always] = ACTIONS(6467),
    [anon_sym_covergroup] = ACTIONS(6467),
    [anon_sym_let] = ACTIONS(6467),
    [anon_sym_pulldown] = ACTIONS(6467),
    [anon_sym_pullup] = ACTIONS(6467),
    [anon_sym_cmos] = ACTIONS(6467),
    [anon_sym_rcmos] = ACTIONS(6467),
    [anon_sym_bufif0] = ACTIONS(6467),
    [anon_sym_bufif1] = ACTIONS(6467),
    [anon_sym_notif0] = ACTIONS(6467),
    [anon_sym_notif1] = ACTIONS(6467),
    [anon_sym_nmos] = ACTIONS(6467),
    [anon_sym_pmos] = ACTIONS(6467),
    [anon_sym_rnmos] = ACTIONS(6467),
    [anon_sym_rpmos] = ACTIONS(6467),
    [anon_sym_nand] = ACTIONS(6467),
    [anon_sym_nor] = ACTIONS(6467),
    [anon_sym_xor] = ACTIONS(6467),
    [anon_sym_xnor] = ACTIONS(6467),
    [anon_sym_buf] = ACTIONS(6467),
    [anon_sym_tranif0] = ACTIONS(6467),
    [anon_sym_tranif1] = ACTIONS(6467),
    [anon_sym_rtranif1] = ACTIONS(6467),
    [anon_sym_rtranif0] = ACTIONS(6467),
    [anon_sym_tran] = ACTIONS(6467),
    [anon_sym_rtran] = ACTIONS(6467),
    [anon_sym_generate] = ACTIONS(6467),
    [anon_sym_for] = ACTIONS(6467),
    [anon_sym_initial] = ACTIONS(6467),
    [anon_sym_assign] = ACTIONS(6467),
    [anon_sym_alias] = ACTIONS(6467),
    [anon_sym_always_comb] = ACTIONS(6467),
    [anon_sym_always_latch] = ACTIONS(6467),
    [anon_sym_always_ff] = ACTIONS(6467),
    [anon_sym_final] = ACTIONS(6467),
    [anon_sym_global] = ACTIONS(6467),
    [anon_sym_specify] = ACTIONS(6467),
    [anon_sym_LPAREN_STAR] = ACTIONS(6469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6469),
    [anon_sym_DOLLARunit] = ACTIONS(6469),
  },
  [1184] = {
    [sym_simple_identifier] = ACTIONS(6471),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6473),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6473),
    [anon_sym_BQUOTE] = ACTIONS(6471),
    [aux_sym_id_directive_token1] = ACTIONS(6473),
    [aux_sym_id_directive_token2] = ACTIONS(6473),
    [aux_sym_id_directive_token3] = ACTIONS(6473),
    [aux_sym_id_directive_token4] = ACTIONS(6471),
    [aux_sym_zero_directive_token1] = ACTIONS(6473),
    [aux_sym_zero_directive_token2] = ACTIONS(6473),
    [aux_sym_zero_directive_token3] = ACTIONS(6473),
    [aux_sym_zero_directive_token4] = ACTIONS(6473),
    [aux_sym_zero_directive_token5] = ACTIONS(6473),
    [aux_sym_zero_directive_token6] = ACTIONS(6473),
    [aux_sym_zero_directive_token7] = ACTIONS(6473),
    [aux_sym_zero_directive_token8] = ACTIONS(6473),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6473),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6473),
    [anon_sym_wire] = ACTIONS(6471),
    [anon_sym_tri] = ACTIONS(6471),
    [anon_sym_tri0] = ACTIONS(6471),
    [anon_sym_tri1] = ACTIONS(6471),
    [anon_sym_wand] = ACTIONS(6471),
    [anon_sym_triand] = ACTIONS(6471),
    [anon_sym_wor] = ACTIONS(6471),
    [anon_sym_trior] = ACTIONS(6471),
    [anon_sym_trireg] = ACTIONS(6471),
    [anon_sym_uwire] = ACTIONS(6471),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6473),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6473),
    [aux_sym_begin_keywords_token1] = ACTIONS(6473),
    [anon_sym_SEMI] = ACTIONS(6473),
    [anon_sym_endmodule] = ACTIONS(6471),
    [anon_sym_extern] = ACTIONS(6471),
    [anon_sym_module] = ACTIONS(6471),
    [anon_sym_macromodule] = ACTIONS(6471),
    [anon_sym_endinterface] = ACTIONS(6471),
    [anon_sym_interface] = ACTIONS(6471),
    [anon_sym_endprogram] = ACTIONS(6471),
    [anon_sym_program] = ACTIONS(6471),
    [anon_sym_checker] = ACTIONS(6471),
    [anon_sym_virtual] = ACTIONS(6471),
    [anon_sym_class] = ACTIONS(6471),
    [anon_sym_timeunit] = ACTIONS(6471),
    [anon_sym_timeprecision] = ACTIONS(6471),
    [anon_sym_type] = ACTIONS(6471),
    [anon_sym_input] = ACTIONS(6471),
    [anon_sym_output] = ACTIONS(6471),
    [anon_sym_inout] = ACTIONS(6471),
    [anon_sym_ref] = ACTIONS(6471),
    [anon_sym_DOLLARfatal] = ACTIONS(6473),
    [anon_sym_DOLLARerror] = ACTIONS(6473),
    [anon_sym_DOLLARwarning] = ACTIONS(6473),
    [anon_sym_DOLLARinfo] = ACTIONS(6473),
    [anon_sym_default] = ACTIONS(6471),
    [anon_sym_clocking] = ACTIONS(6471),
    [anon_sym_defparam] = ACTIONS(6471),
    [anon_sym_bind] = ACTIONS(6471),
    [anon_sym_const] = ACTIONS(6471),
    [anon_sym_function] = ACTIONS(6471),
    [anon_sym_static] = ACTIONS(6471),
    [anon_sym_constraint] = ACTIONS(6471),
    [anon_sym_if] = ACTIONS(6471),
    [anon_sym_else] = ACTIONS(6471),
    [anon_sym_LBRACK] = ACTIONS(6473),
    [anon_sym_localparam] = ACTIONS(6471),
    [anon_sym_parameter] = ACTIONS(6471),
    [anon_sym_specparam] = ACTIONS(6471),
    [anon_sym_var] = ACTIONS(6471),
    [anon_sym_import] = ACTIONS(6471),
    [anon_sym_export] = ACTIONS(6471),
    [anon_sym_genvar] = ACTIONS(6471),
    [anon_sym_interconnect] = ACTIONS(6471),
    [anon_sym_typedef] = ACTIONS(6471),
    [anon_sym_enum] = ACTIONS(6471),
    [anon_sym_struct] = ACTIONS(6471),
    [anon_sym_union] = ACTIONS(6471),
    [anon_sym_nettype] = ACTIONS(6471),
    [anon_sym_automatic] = ACTIONS(6471),
    [anon_sym_string] = ACTIONS(6471),
    [anon_sym_chandle] = ACTIONS(6471),
    [anon_sym_event] = ACTIONS(6471),
    [anon_sym_byte] = ACTIONS(6471),
    [anon_sym_shortint] = ACTIONS(6471),
    [anon_sym_int] = ACTIONS(6471),
    [anon_sym_longint] = ACTIONS(6471),
    [anon_sym_integer] = ACTIONS(6471),
    [anon_sym_time] = ACTIONS(6471),
    [anon_sym_bit] = ACTIONS(6471),
    [anon_sym_logic] = ACTIONS(6471),
    [anon_sym_reg] = ACTIONS(6471),
    [anon_sym_shortreal] = ACTIONS(6471),
    [anon_sym_real] = ACTIONS(6471),
    [anon_sym_realtime] = ACTIONS(6471),
    [anon_sym_supply0] = ACTIONS(6471),
    [anon_sym_supply1] = ACTIONS(6471),
    [anon_sym_signed] = ACTIONS(6471),
    [anon_sym_unsigned] = ACTIONS(6471),
    [anon_sym_task] = ACTIONS(6471),
    [anon_sym_modport] = ACTIONS(6471),
    [anon_sym_assert] = ACTIONS(6471),
    [anon_sym_property] = ACTIONS(6471),
    [anon_sym_assume] = ACTIONS(6471),
    [anon_sym_cover] = ACTIONS(6471),
    [anon_sym_sequence] = ACTIONS(6471),
    [anon_sym_restrict] = ACTIONS(6471),
    [anon_sym_not] = ACTIONS(6471),
    [anon_sym_or] = ACTIONS(6471),
    [anon_sym_and] = ACTIONS(6471),
    [anon_sym_case] = ACTIONS(6471),
    [anon_sym_always] = ACTIONS(6471),
    [anon_sym_covergroup] = ACTIONS(6471),
    [anon_sym_let] = ACTIONS(6471),
    [anon_sym_pulldown] = ACTIONS(6471),
    [anon_sym_pullup] = ACTIONS(6471),
    [anon_sym_cmos] = ACTIONS(6471),
    [anon_sym_rcmos] = ACTIONS(6471),
    [anon_sym_bufif0] = ACTIONS(6471),
    [anon_sym_bufif1] = ACTIONS(6471),
    [anon_sym_notif0] = ACTIONS(6471),
    [anon_sym_notif1] = ACTIONS(6471),
    [anon_sym_nmos] = ACTIONS(6471),
    [anon_sym_pmos] = ACTIONS(6471),
    [anon_sym_rnmos] = ACTIONS(6471),
    [anon_sym_rpmos] = ACTIONS(6471),
    [anon_sym_nand] = ACTIONS(6471),
    [anon_sym_nor] = ACTIONS(6471),
    [anon_sym_xor] = ACTIONS(6471),
    [anon_sym_xnor] = ACTIONS(6471),
    [anon_sym_buf] = ACTIONS(6471),
    [anon_sym_tranif0] = ACTIONS(6471),
    [anon_sym_tranif1] = ACTIONS(6471),
    [anon_sym_rtranif1] = ACTIONS(6471),
    [anon_sym_rtranif0] = ACTIONS(6471),
    [anon_sym_tran] = ACTIONS(6471),
    [anon_sym_rtran] = ACTIONS(6471),
    [anon_sym_generate] = ACTIONS(6471),
    [anon_sym_for] = ACTIONS(6471),
    [anon_sym_initial] = ACTIONS(6471),
    [anon_sym_assign] = ACTIONS(6471),
    [anon_sym_alias] = ACTIONS(6471),
    [anon_sym_always_comb] = ACTIONS(6471),
    [anon_sym_always_latch] = ACTIONS(6471),
    [anon_sym_always_ff] = ACTIONS(6471),
    [anon_sym_final] = ACTIONS(6471),
    [anon_sym_global] = ACTIONS(6471),
    [anon_sym_specify] = ACTIONS(6471),
    [anon_sym_LPAREN_STAR] = ACTIONS(6473),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6473),
    [anon_sym_DOLLARunit] = ACTIONS(6473),
  },
  [1185] = {
    [sym_simple_identifier] = ACTIONS(6475),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6477),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6477),
    [anon_sym_BQUOTE] = ACTIONS(6475),
    [aux_sym_id_directive_token1] = ACTIONS(6477),
    [aux_sym_id_directive_token2] = ACTIONS(6477),
    [aux_sym_id_directive_token3] = ACTIONS(6477),
    [aux_sym_id_directive_token4] = ACTIONS(6475),
    [aux_sym_zero_directive_token1] = ACTIONS(6477),
    [aux_sym_zero_directive_token2] = ACTIONS(6477),
    [aux_sym_zero_directive_token3] = ACTIONS(6477),
    [aux_sym_zero_directive_token4] = ACTIONS(6477),
    [aux_sym_zero_directive_token5] = ACTIONS(6477),
    [aux_sym_zero_directive_token6] = ACTIONS(6477),
    [aux_sym_zero_directive_token7] = ACTIONS(6477),
    [aux_sym_zero_directive_token8] = ACTIONS(6477),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6477),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6477),
    [anon_sym_wire] = ACTIONS(6475),
    [anon_sym_tri] = ACTIONS(6475),
    [anon_sym_tri0] = ACTIONS(6475),
    [anon_sym_tri1] = ACTIONS(6475),
    [anon_sym_wand] = ACTIONS(6475),
    [anon_sym_triand] = ACTIONS(6475),
    [anon_sym_wor] = ACTIONS(6475),
    [anon_sym_trior] = ACTIONS(6475),
    [anon_sym_trireg] = ACTIONS(6475),
    [anon_sym_uwire] = ACTIONS(6475),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6477),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6477),
    [aux_sym_begin_keywords_token1] = ACTIONS(6477),
    [anon_sym_SEMI] = ACTIONS(6477),
    [anon_sym_endmodule] = ACTIONS(6475),
    [anon_sym_extern] = ACTIONS(6475),
    [anon_sym_module] = ACTIONS(6475),
    [anon_sym_macromodule] = ACTIONS(6475),
    [anon_sym_endinterface] = ACTIONS(6475),
    [anon_sym_interface] = ACTIONS(6475),
    [anon_sym_endprogram] = ACTIONS(6475),
    [anon_sym_program] = ACTIONS(6475),
    [anon_sym_checker] = ACTIONS(6475),
    [anon_sym_virtual] = ACTIONS(6475),
    [anon_sym_class] = ACTIONS(6475),
    [anon_sym_timeunit] = ACTIONS(6475),
    [anon_sym_timeprecision] = ACTIONS(6475),
    [anon_sym_type] = ACTIONS(6475),
    [anon_sym_input] = ACTIONS(6475),
    [anon_sym_output] = ACTIONS(6475),
    [anon_sym_inout] = ACTIONS(6475),
    [anon_sym_ref] = ACTIONS(6475),
    [anon_sym_DOLLARfatal] = ACTIONS(6477),
    [anon_sym_DOLLARerror] = ACTIONS(6477),
    [anon_sym_DOLLARwarning] = ACTIONS(6477),
    [anon_sym_DOLLARinfo] = ACTIONS(6477),
    [anon_sym_default] = ACTIONS(6475),
    [anon_sym_clocking] = ACTIONS(6475),
    [anon_sym_defparam] = ACTIONS(6475),
    [anon_sym_bind] = ACTIONS(6475),
    [anon_sym_const] = ACTIONS(6475),
    [anon_sym_function] = ACTIONS(6475),
    [anon_sym_static] = ACTIONS(6475),
    [anon_sym_constraint] = ACTIONS(6475),
    [anon_sym_if] = ACTIONS(6475),
    [anon_sym_else] = ACTIONS(6475),
    [anon_sym_LBRACK] = ACTIONS(6477),
    [anon_sym_localparam] = ACTIONS(6475),
    [anon_sym_parameter] = ACTIONS(6475),
    [anon_sym_specparam] = ACTIONS(6475),
    [anon_sym_var] = ACTIONS(6475),
    [anon_sym_import] = ACTIONS(6475),
    [anon_sym_export] = ACTIONS(6475),
    [anon_sym_genvar] = ACTIONS(6475),
    [anon_sym_interconnect] = ACTIONS(6475),
    [anon_sym_typedef] = ACTIONS(6475),
    [anon_sym_enum] = ACTIONS(6475),
    [anon_sym_struct] = ACTIONS(6475),
    [anon_sym_union] = ACTIONS(6475),
    [anon_sym_nettype] = ACTIONS(6475),
    [anon_sym_automatic] = ACTIONS(6475),
    [anon_sym_string] = ACTIONS(6475),
    [anon_sym_chandle] = ACTIONS(6475),
    [anon_sym_event] = ACTIONS(6475),
    [anon_sym_byte] = ACTIONS(6475),
    [anon_sym_shortint] = ACTIONS(6475),
    [anon_sym_int] = ACTIONS(6475),
    [anon_sym_longint] = ACTIONS(6475),
    [anon_sym_integer] = ACTIONS(6475),
    [anon_sym_time] = ACTIONS(6475),
    [anon_sym_bit] = ACTIONS(6475),
    [anon_sym_logic] = ACTIONS(6475),
    [anon_sym_reg] = ACTIONS(6475),
    [anon_sym_shortreal] = ACTIONS(6475),
    [anon_sym_real] = ACTIONS(6475),
    [anon_sym_realtime] = ACTIONS(6475),
    [anon_sym_supply0] = ACTIONS(6475),
    [anon_sym_supply1] = ACTIONS(6475),
    [anon_sym_signed] = ACTIONS(6475),
    [anon_sym_unsigned] = ACTIONS(6475),
    [anon_sym_task] = ACTIONS(6475),
    [anon_sym_modport] = ACTIONS(6475),
    [anon_sym_assert] = ACTIONS(6475),
    [anon_sym_property] = ACTIONS(6475),
    [anon_sym_assume] = ACTIONS(6475),
    [anon_sym_cover] = ACTIONS(6475),
    [anon_sym_sequence] = ACTIONS(6475),
    [anon_sym_restrict] = ACTIONS(6475),
    [anon_sym_not] = ACTIONS(6475),
    [anon_sym_or] = ACTIONS(6475),
    [anon_sym_and] = ACTIONS(6475),
    [anon_sym_case] = ACTIONS(6475),
    [anon_sym_always] = ACTIONS(6475),
    [anon_sym_covergroup] = ACTIONS(6475),
    [anon_sym_let] = ACTIONS(6475),
    [anon_sym_pulldown] = ACTIONS(6475),
    [anon_sym_pullup] = ACTIONS(6475),
    [anon_sym_cmos] = ACTIONS(6475),
    [anon_sym_rcmos] = ACTIONS(6475),
    [anon_sym_bufif0] = ACTIONS(6475),
    [anon_sym_bufif1] = ACTIONS(6475),
    [anon_sym_notif0] = ACTIONS(6475),
    [anon_sym_notif1] = ACTIONS(6475),
    [anon_sym_nmos] = ACTIONS(6475),
    [anon_sym_pmos] = ACTIONS(6475),
    [anon_sym_rnmos] = ACTIONS(6475),
    [anon_sym_rpmos] = ACTIONS(6475),
    [anon_sym_nand] = ACTIONS(6475),
    [anon_sym_nor] = ACTIONS(6475),
    [anon_sym_xor] = ACTIONS(6475),
    [anon_sym_xnor] = ACTIONS(6475),
    [anon_sym_buf] = ACTIONS(6475),
    [anon_sym_tranif0] = ACTIONS(6475),
    [anon_sym_tranif1] = ACTIONS(6475),
    [anon_sym_rtranif1] = ACTIONS(6475),
    [anon_sym_rtranif0] = ACTIONS(6475),
    [anon_sym_tran] = ACTIONS(6475),
    [anon_sym_rtran] = ACTIONS(6475),
    [anon_sym_generate] = ACTIONS(6475),
    [anon_sym_for] = ACTIONS(6475),
    [anon_sym_initial] = ACTIONS(6475),
    [anon_sym_assign] = ACTIONS(6475),
    [anon_sym_alias] = ACTIONS(6475),
    [anon_sym_always_comb] = ACTIONS(6475),
    [anon_sym_always_latch] = ACTIONS(6475),
    [anon_sym_always_ff] = ACTIONS(6475),
    [anon_sym_final] = ACTIONS(6475),
    [anon_sym_global] = ACTIONS(6475),
    [anon_sym_specify] = ACTIONS(6475),
    [anon_sym_LPAREN_STAR] = ACTIONS(6477),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6477),
    [anon_sym_DOLLARunit] = ACTIONS(6477),
  },
  [1186] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5788),
    [anon_sym_BQUOTE] = ACTIONS(5786),
    [aux_sym_id_directive_token1] = ACTIONS(5788),
    [aux_sym_id_directive_token2] = ACTIONS(5788),
    [aux_sym_id_directive_token3] = ACTIONS(5788),
    [aux_sym_id_directive_token4] = ACTIONS(5786),
    [aux_sym_zero_directive_token1] = ACTIONS(5788),
    [aux_sym_zero_directive_token2] = ACTIONS(5788),
    [aux_sym_zero_directive_token3] = ACTIONS(5788),
    [aux_sym_zero_directive_token4] = ACTIONS(5788),
    [aux_sym_zero_directive_token5] = ACTIONS(5788),
    [aux_sym_zero_directive_token6] = ACTIONS(5788),
    [aux_sym_zero_directive_token7] = ACTIONS(5788),
    [aux_sym_zero_directive_token8] = ACTIONS(5788),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5788),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5788),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5788),
    [aux_sym_begin_keywords_token1] = ACTIONS(5788),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_endmodule] = ACTIONS(5786),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_module] = ACTIONS(5786),
    [anon_sym_macromodule] = ACTIONS(5786),
    [anon_sym_endinterface] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_endprogram] = ACTIONS(5786),
    [anon_sym_program] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_timeunit] = ACTIONS(5786),
    [anon_sym_timeprecision] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_input] = ACTIONS(5786),
    [anon_sym_output] = ACTIONS(5786),
    [anon_sym_inout] = ACTIONS(5786),
    [anon_sym_ref] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_specparam] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_modport] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_specify] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [1187] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6049),
    [anon_sym_BQUOTE] = ACTIONS(6047),
    [aux_sym_id_directive_token1] = ACTIONS(6049),
    [aux_sym_id_directive_token2] = ACTIONS(6049),
    [aux_sym_id_directive_token3] = ACTIONS(6049),
    [aux_sym_id_directive_token4] = ACTIONS(6047),
    [aux_sym_zero_directive_token1] = ACTIONS(6049),
    [aux_sym_zero_directive_token2] = ACTIONS(6049),
    [aux_sym_zero_directive_token3] = ACTIONS(6049),
    [aux_sym_zero_directive_token4] = ACTIONS(6049),
    [aux_sym_zero_directive_token5] = ACTIONS(6049),
    [aux_sym_zero_directive_token6] = ACTIONS(6049),
    [aux_sym_zero_directive_token7] = ACTIONS(6049),
    [aux_sym_zero_directive_token8] = ACTIONS(6049),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6049),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6049),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6049),
    [aux_sym_begin_keywords_token1] = ACTIONS(6049),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_endmodule] = ACTIONS(6047),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_module] = ACTIONS(6047),
    [anon_sym_macromodule] = ACTIONS(6047),
    [anon_sym_endinterface] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_endprogram] = ACTIONS(6047),
    [anon_sym_program] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_timeunit] = ACTIONS(6047),
    [anon_sym_timeprecision] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_input] = ACTIONS(6047),
    [anon_sym_output] = ACTIONS(6047),
    [anon_sym_inout] = ACTIONS(6047),
    [anon_sym_ref] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_specparam] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_modport] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_specify] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [1188] = {
    [sym_simple_identifier] = ACTIONS(6479),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6481),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6481),
    [anon_sym_BQUOTE] = ACTIONS(6479),
    [aux_sym_id_directive_token1] = ACTIONS(6481),
    [aux_sym_id_directive_token2] = ACTIONS(6481),
    [aux_sym_id_directive_token3] = ACTIONS(6481),
    [aux_sym_id_directive_token4] = ACTIONS(6479),
    [aux_sym_zero_directive_token1] = ACTIONS(6481),
    [aux_sym_zero_directive_token2] = ACTIONS(6481),
    [aux_sym_zero_directive_token3] = ACTIONS(6481),
    [aux_sym_zero_directive_token4] = ACTIONS(6481),
    [aux_sym_zero_directive_token5] = ACTIONS(6481),
    [aux_sym_zero_directive_token6] = ACTIONS(6481),
    [aux_sym_zero_directive_token7] = ACTIONS(6481),
    [aux_sym_zero_directive_token8] = ACTIONS(6481),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6481),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6481),
    [anon_sym_wire] = ACTIONS(6479),
    [anon_sym_tri] = ACTIONS(6479),
    [anon_sym_tri0] = ACTIONS(6479),
    [anon_sym_tri1] = ACTIONS(6479),
    [anon_sym_wand] = ACTIONS(6479),
    [anon_sym_triand] = ACTIONS(6479),
    [anon_sym_wor] = ACTIONS(6479),
    [anon_sym_trior] = ACTIONS(6479),
    [anon_sym_trireg] = ACTIONS(6479),
    [anon_sym_uwire] = ACTIONS(6479),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6481),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6481),
    [aux_sym_begin_keywords_token1] = ACTIONS(6481),
    [anon_sym_SEMI] = ACTIONS(6481),
    [anon_sym_endmodule] = ACTIONS(6479),
    [anon_sym_extern] = ACTIONS(6479),
    [anon_sym_module] = ACTIONS(6479),
    [anon_sym_macromodule] = ACTIONS(6479),
    [anon_sym_endinterface] = ACTIONS(6479),
    [anon_sym_interface] = ACTIONS(6479),
    [anon_sym_endprogram] = ACTIONS(6479),
    [anon_sym_program] = ACTIONS(6479),
    [anon_sym_checker] = ACTIONS(6479),
    [anon_sym_virtual] = ACTIONS(6479),
    [anon_sym_class] = ACTIONS(6479),
    [anon_sym_timeunit] = ACTIONS(6479),
    [anon_sym_timeprecision] = ACTIONS(6479),
    [anon_sym_type] = ACTIONS(6479),
    [anon_sym_input] = ACTIONS(6479),
    [anon_sym_output] = ACTIONS(6479),
    [anon_sym_inout] = ACTIONS(6479),
    [anon_sym_ref] = ACTIONS(6479),
    [anon_sym_DOLLARfatal] = ACTIONS(6481),
    [anon_sym_DOLLARerror] = ACTIONS(6481),
    [anon_sym_DOLLARwarning] = ACTIONS(6481),
    [anon_sym_DOLLARinfo] = ACTIONS(6481),
    [anon_sym_default] = ACTIONS(6479),
    [anon_sym_clocking] = ACTIONS(6479),
    [anon_sym_defparam] = ACTIONS(6479),
    [anon_sym_bind] = ACTIONS(6479),
    [anon_sym_const] = ACTIONS(6479),
    [anon_sym_function] = ACTIONS(6479),
    [anon_sym_static] = ACTIONS(6479),
    [anon_sym_constraint] = ACTIONS(6479),
    [anon_sym_if] = ACTIONS(6479),
    [anon_sym_else] = ACTIONS(6479),
    [anon_sym_LBRACK] = ACTIONS(6481),
    [anon_sym_localparam] = ACTIONS(6479),
    [anon_sym_parameter] = ACTIONS(6479),
    [anon_sym_specparam] = ACTIONS(6479),
    [anon_sym_var] = ACTIONS(6479),
    [anon_sym_import] = ACTIONS(6479),
    [anon_sym_export] = ACTIONS(6479),
    [anon_sym_genvar] = ACTIONS(6479),
    [anon_sym_interconnect] = ACTIONS(6479),
    [anon_sym_typedef] = ACTIONS(6479),
    [anon_sym_enum] = ACTIONS(6479),
    [anon_sym_struct] = ACTIONS(6479),
    [anon_sym_union] = ACTIONS(6479),
    [anon_sym_nettype] = ACTIONS(6479),
    [anon_sym_automatic] = ACTIONS(6479),
    [anon_sym_string] = ACTIONS(6479),
    [anon_sym_chandle] = ACTIONS(6479),
    [anon_sym_event] = ACTIONS(6479),
    [anon_sym_byte] = ACTIONS(6479),
    [anon_sym_shortint] = ACTIONS(6479),
    [anon_sym_int] = ACTIONS(6479),
    [anon_sym_longint] = ACTIONS(6479),
    [anon_sym_integer] = ACTIONS(6479),
    [anon_sym_time] = ACTIONS(6479),
    [anon_sym_bit] = ACTIONS(6479),
    [anon_sym_logic] = ACTIONS(6479),
    [anon_sym_reg] = ACTIONS(6479),
    [anon_sym_shortreal] = ACTIONS(6479),
    [anon_sym_real] = ACTIONS(6479),
    [anon_sym_realtime] = ACTIONS(6479),
    [anon_sym_supply0] = ACTIONS(6479),
    [anon_sym_supply1] = ACTIONS(6479),
    [anon_sym_signed] = ACTIONS(6479),
    [anon_sym_unsigned] = ACTIONS(6479),
    [anon_sym_task] = ACTIONS(6479),
    [anon_sym_modport] = ACTIONS(6479),
    [anon_sym_assert] = ACTIONS(6479),
    [anon_sym_property] = ACTIONS(6479),
    [anon_sym_assume] = ACTIONS(6479),
    [anon_sym_cover] = ACTIONS(6479),
    [anon_sym_sequence] = ACTIONS(6479),
    [anon_sym_restrict] = ACTIONS(6479),
    [anon_sym_not] = ACTIONS(6479),
    [anon_sym_or] = ACTIONS(6479),
    [anon_sym_and] = ACTIONS(6479),
    [anon_sym_case] = ACTIONS(6479),
    [anon_sym_always] = ACTIONS(6479),
    [anon_sym_covergroup] = ACTIONS(6479),
    [anon_sym_let] = ACTIONS(6479),
    [anon_sym_pulldown] = ACTIONS(6479),
    [anon_sym_pullup] = ACTIONS(6479),
    [anon_sym_cmos] = ACTIONS(6479),
    [anon_sym_rcmos] = ACTIONS(6479),
    [anon_sym_bufif0] = ACTIONS(6479),
    [anon_sym_bufif1] = ACTIONS(6479),
    [anon_sym_notif0] = ACTIONS(6479),
    [anon_sym_notif1] = ACTIONS(6479),
    [anon_sym_nmos] = ACTIONS(6479),
    [anon_sym_pmos] = ACTIONS(6479),
    [anon_sym_rnmos] = ACTIONS(6479),
    [anon_sym_rpmos] = ACTIONS(6479),
    [anon_sym_nand] = ACTIONS(6479),
    [anon_sym_nor] = ACTIONS(6479),
    [anon_sym_xor] = ACTIONS(6479),
    [anon_sym_xnor] = ACTIONS(6479),
    [anon_sym_buf] = ACTIONS(6479),
    [anon_sym_tranif0] = ACTIONS(6479),
    [anon_sym_tranif1] = ACTIONS(6479),
    [anon_sym_rtranif1] = ACTIONS(6479),
    [anon_sym_rtranif0] = ACTIONS(6479),
    [anon_sym_tran] = ACTIONS(6479),
    [anon_sym_rtran] = ACTIONS(6479),
    [anon_sym_generate] = ACTIONS(6479),
    [anon_sym_for] = ACTIONS(6479),
    [anon_sym_initial] = ACTIONS(6479),
    [anon_sym_assign] = ACTIONS(6479),
    [anon_sym_alias] = ACTIONS(6479),
    [anon_sym_always_comb] = ACTIONS(6479),
    [anon_sym_always_latch] = ACTIONS(6479),
    [anon_sym_always_ff] = ACTIONS(6479),
    [anon_sym_final] = ACTIONS(6479),
    [anon_sym_global] = ACTIONS(6479),
    [anon_sym_specify] = ACTIONS(6479),
    [anon_sym_LPAREN_STAR] = ACTIONS(6481),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6481),
    [anon_sym_DOLLARunit] = ACTIONS(6481),
  },
  [1189] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9410),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(6485),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_with] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2662),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [1190] = {
    [sym_simple_identifier] = ACTIONS(6517),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6520),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6520),
    [anon_sym_BQUOTE] = ACTIONS(6517),
    [aux_sym_id_directive_token1] = ACTIONS(6520),
    [aux_sym_id_directive_token2] = ACTIONS(6520),
    [aux_sym_id_directive_token3] = ACTIONS(6520),
    [aux_sym_id_directive_token4] = ACTIONS(6517),
    [aux_sym_zero_directive_token1] = ACTIONS(6520),
    [aux_sym_zero_directive_token2] = ACTIONS(6520),
    [aux_sym_zero_directive_token3] = ACTIONS(6520),
    [aux_sym_zero_directive_token4] = ACTIONS(6520),
    [aux_sym_zero_directive_token5] = ACTIONS(6520),
    [aux_sym_zero_directive_token6] = ACTIONS(6520),
    [aux_sym_zero_directive_token7] = ACTIONS(6520),
    [aux_sym_zero_directive_token8] = ACTIONS(6520),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6520),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6520),
    [anon_sym_wire] = ACTIONS(6517),
    [anon_sym_tri] = ACTIONS(6517),
    [anon_sym_tri0] = ACTIONS(6517),
    [anon_sym_tri1] = ACTIONS(6517),
    [anon_sym_wand] = ACTIONS(6517),
    [anon_sym_triand] = ACTIONS(6517),
    [anon_sym_wor] = ACTIONS(6517),
    [anon_sym_trior] = ACTIONS(6517),
    [anon_sym_trireg] = ACTIONS(6517),
    [anon_sym_uwire] = ACTIONS(6517),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6520),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6520),
    [aux_sym_begin_keywords_token1] = ACTIONS(6520),
    [anon_sym_SEMI] = ACTIONS(6520),
    [anon_sym_endmodule] = ACTIONS(6517),
    [anon_sym_extern] = ACTIONS(6517),
    [anon_sym_module] = ACTIONS(6517),
    [anon_sym_macromodule] = ACTIONS(6517),
    [anon_sym_endinterface] = ACTIONS(6517),
    [anon_sym_interface] = ACTIONS(6517),
    [anon_sym_endprogram] = ACTIONS(6517),
    [anon_sym_program] = ACTIONS(6517),
    [anon_sym_checker] = ACTIONS(6517),
    [anon_sym_virtual] = ACTIONS(6517),
    [anon_sym_class] = ACTIONS(6517),
    [anon_sym_timeunit] = ACTIONS(6517),
    [anon_sym_timeprecision] = ACTIONS(6517),
    [anon_sym_type] = ACTIONS(6517),
    [anon_sym_input] = ACTIONS(6517),
    [anon_sym_output] = ACTIONS(6517),
    [anon_sym_inout] = ACTIONS(6517),
    [anon_sym_ref] = ACTIONS(6517),
    [anon_sym_DOLLARfatal] = ACTIONS(6520),
    [anon_sym_DOLLARerror] = ACTIONS(6520),
    [anon_sym_DOLLARwarning] = ACTIONS(6520),
    [anon_sym_DOLLARinfo] = ACTIONS(6520),
    [anon_sym_default] = ACTIONS(6517),
    [anon_sym_clocking] = ACTIONS(6517),
    [anon_sym_defparam] = ACTIONS(6517),
    [anon_sym_bind] = ACTIONS(6517),
    [anon_sym_const] = ACTIONS(6517),
    [anon_sym_function] = ACTIONS(6517),
    [anon_sym_static] = ACTIONS(6517),
    [anon_sym_constraint] = ACTIONS(6517),
    [anon_sym_if] = ACTIONS(6517),
    [anon_sym_else] = ACTIONS(6517),
    [anon_sym_LBRACK] = ACTIONS(6520),
    [anon_sym_localparam] = ACTIONS(6517),
    [anon_sym_parameter] = ACTIONS(6517),
    [anon_sym_specparam] = ACTIONS(6517),
    [anon_sym_var] = ACTIONS(6517),
    [anon_sym_import] = ACTIONS(6517),
    [anon_sym_export] = ACTIONS(6517),
    [anon_sym_genvar] = ACTIONS(6517),
    [anon_sym_interconnect] = ACTIONS(6517),
    [anon_sym_typedef] = ACTIONS(6517),
    [anon_sym_enum] = ACTIONS(6517),
    [anon_sym_struct] = ACTIONS(6517),
    [anon_sym_union] = ACTIONS(6517),
    [anon_sym_nettype] = ACTIONS(6517),
    [anon_sym_automatic] = ACTIONS(6517),
    [anon_sym_string] = ACTIONS(6517),
    [anon_sym_chandle] = ACTIONS(6517),
    [anon_sym_event] = ACTIONS(6517),
    [anon_sym_byte] = ACTIONS(6517),
    [anon_sym_shortint] = ACTIONS(6517),
    [anon_sym_int] = ACTIONS(6517),
    [anon_sym_longint] = ACTIONS(6517),
    [anon_sym_integer] = ACTIONS(6517),
    [anon_sym_time] = ACTIONS(6517),
    [anon_sym_bit] = ACTIONS(6517),
    [anon_sym_logic] = ACTIONS(6517),
    [anon_sym_reg] = ACTIONS(6517),
    [anon_sym_shortreal] = ACTIONS(6517),
    [anon_sym_real] = ACTIONS(6517),
    [anon_sym_realtime] = ACTIONS(6517),
    [anon_sym_supply0] = ACTIONS(6517),
    [anon_sym_supply1] = ACTIONS(6517),
    [anon_sym_signed] = ACTIONS(6517),
    [anon_sym_unsigned] = ACTIONS(6517),
    [anon_sym_task] = ACTIONS(6517),
    [anon_sym_modport] = ACTIONS(6517),
    [anon_sym_assert] = ACTIONS(6517),
    [anon_sym_property] = ACTIONS(6517),
    [anon_sym_assume] = ACTIONS(6517),
    [anon_sym_cover] = ACTIONS(6517),
    [anon_sym_sequence] = ACTIONS(6517),
    [anon_sym_restrict] = ACTIONS(6517),
    [anon_sym_not] = ACTIONS(6517),
    [anon_sym_or] = ACTIONS(6517),
    [anon_sym_and] = ACTIONS(6517),
    [anon_sym_case] = ACTIONS(6517),
    [anon_sym_always] = ACTIONS(6517),
    [anon_sym_covergroup] = ACTIONS(6517),
    [anon_sym_let] = ACTIONS(6517),
    [anon_sym_pulldown] = ACTIONS(6517),
    [anon_sym_pullup] = ACTIONS(6517),
    [anon_sym_cmos] = ACTIONS(6517),
    [anon_sym_rcmos] = ACTIONS(6517),
    [anon_sym_bufif0] = ACTIONS(6517),
    [anon_sym_bufif1] = ACTIONS(6517),
    [anon_sym_notif0] = ACTIONS(6517),
    [anon_sym_notif1] = ACTIONS(6517),
    [anon_sym_nmos] = ACTIONS(6517),
    [anon_sym_pmos] = ACTIONS(6517),
    [anon_sym_rnmos] = ACTIONS(6517),
    [anon_sym_rpmos] = ACTIONS(6517),
    [anon_sym_nand] = ACTIONS(6517),
    [anon_sym_nor] = ACTIONS(6517),
    [anon_sym_xor] = ACTIONS(6517),
    [anon_sym_xnor] = ACTIONS(6517),
    [anon_sym_buf] = ACTIONS(6517),
    [anon_sym_tranif0] = ACTIONS(6517),
    [anon_sym_tranif1] = ACTIONS(6517),
    [anon_sym_rtranif1] = ACTIONS(6517),
    [anon_sym_rtranif0] = ACTIONS(6517),
    [anon_sym_tran] = ACTIONS(6517),
    [anon_sym_rtran] = ACTIONS(6517),
    [anon_sym_generate] = ACTIONS(6517),
    [anon_sym_for] = ACTIONS(6517),
    [anon_sym_initial] = ACTIONS(6517),
    [anon_sym_assign] = ACTIONS(6517),
    [anon_sym_alias] = ACTIONS(6517),
    [anon_sym_always_comb] = ACTIONS(6517),
    [anon_sym_always_latch] = ACTIONS(6517),
    [anon_sym_always_ff] = ACTIONS(6517),
    [anon_sym_final] = ACTIONS(6517),
    [anon_sym_global] = ACTIONS(6517),
    [anon_sym_specify] = ACTIONS(6517),
    [anon_sym_LPAREN_STAR] = ACTIONS(6520),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6520),
    [anon_sym_DOLLARunit] = ACTIONS(6520),
  },
  [1191] = {
    [sym_simple_identifier] = ACTIONS(6523),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6526),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6526),
    [anon_sym_BQUOTE] = ACTIONS(6523),
    [aux_sym_id_directive_token1] = ACTIONS(6526),
    [aux_sym_id_directive_token2] = ACTIONS(6526),
    [aux_sym_id_directive_token3] = ACTIONS(6526),
    [aux_sym_id_directive_token4] = ACTIONS(6523),
    [aux_sym_zero_directive_token1] = ACTIONS(6526),
    [aux_sym_zero_directive_token2] = ACTIONS(6526),
    [aux_sym_zero_directive_token3] = ACTIONS(6526),
    [aux_sym_zero_directive_token4] = ACTIONS(6526),
    [aux_sym_zero_directive_token5] = ACTIONS(6526),
    [aux_sym_zero_directive_token6] = ACTIONS(6526),
    [aux_sym_zero_directive_token7] = ACTIONS(6526),
    [aux_sym_zero_directive_token8] = ACTIONS(6526),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6526),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6526),
    [anon_sym_wire] = ACTIONS(6523),
    [anon_sym_tri] = ACTIONS(6523),
    [anon_sym_tri0] = ACTIONS(6523),
    [anon_sym_tri1] = ACTIONS(6523),
    [anon_sym_wand] = ACTIONS(6523),
    [anon_sym_triand] = ACTIONS(6523),
    [anon_sym_wor] = ACTIONS(6523),
    [anon_sym_trior] = ACTIONS(6523),
    [anon_sym_trireg] = ACTIONS(6523),
    [anon_sym_uwire] = ACTIONS(6523),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6526),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6526),
    [aux_sym_begin_keywords_token1] = ACTIONS(6526),
    [anon_sym_SEMI] = ACTIONS(6526),
    [anon_sym_endmodule] = ACTIONS(6523),
    [anon_sym_extern] = ACTIONS(6523),
    [anon_sym_module] = ACTIONS(6523),
    [anon_sym_macromodule] = ACTIONS(6523),
    [anon_sym_endinterface] = ACTIONS(6523),
    [anon_sym_interface] = ACTIONS(6523),
    [anon_sym_endprogram] = ACTIONS(6523),
    [anon_sym_program] = ACTIONS(6523),
    [anon_sym_checker] = ACTIONS(6523),
    [anon_sym_virtual] = ACTIONS(6523),
    [anon_sym_class] = ACTIONS(6523),
    [anon_sym_timeunit] = ACTIONS(6523),
    [anon_sym_timeprecision] = ACTIONS(6523),
    [anon_sym_type] = ACTIONS(6523),
    [anon_sym_input] = ACTIONS(6523),
    [anon_sym_output] = ACTIONS(6523),
    [anon_sym_inout] = ACTIONS(6523),
    [anon_sym_ref] = ACTIONS(6523),
    [anon_sym_DOLLARfatal] = ACTIONS(6526),
    [anon_sym_DOLLARerror] = ACTIONS(6526),
    [anon_sym_DOLLARwarning] = ACTIONS(6526),
    [anon_sym_DOLLARinfo] = ACTIONS(6526),
    [anon_sym_default] = ACTIONS(6523),
    [anon_sym_clocking] = ACTIONS(6523),
    [anon_sym_defparam] = ACTIONS(6523),
    [anon_sym_bind] = ACTIONS(6523),
    [anon_sym_const] = ACTIONS(6523),
    [anon_sym_function] = ACTIONS(6523),
    [anon_sym_static] = ACTIONS(6523),
    [anon_sym_constraint] = ACTIONS(6523),
    [anon_sym_if] = ACTIONS(6523),
    [anon_sym_else] = ACTIONS(6523),
    [anon_sym_LBRACK] = ACTIONS(6526),
    [anon_sym_localparam] = ACTIONS(6523),
    [anon_sym_parameter] = ACTIONS(6523),
    [anon_sym_specparam] = ACTIONS(6523),
    [anon_sym_var] = ACTIONS(6523),
    [anon_sym_import] = ACTIONS(6523),
    [anon_sym_export] = ACTIONS(6523),
    [anon_sym_genvar] = ACTIONS(6523),
    [anon_sym_interconnect] = ACTIONS(6523),
    [anon_sym_typedef] = ACTIONS(6523),
    [anon_sym_enum] = ACTIONS(6523),
    [anon_sym_struct] = ACTIONS(6523),
    [anon_sym_union] = ACTIONS(6523),
    [anon_sym_nettype] = ACTIONS(6523),
    [anon_sym_automatic] = ACTIONS(6523),
    [anon_sym_string] = ACTIONS(6523),
    [anon_sym_chandle] = ACTIONS(6523),
    [anon_sym_event] = ACTIONS(6523),
    [anon_sym_byte] = ACTIONS(6523),
    [anon_sym_shortint] = ACTIONS(6523),
    [anon_sym_int] = ACTIONS(6523),
    [anon_sym_longint] = ACTIONS(6523),
    [anon_sym_integer] = ACTIONS(6523),
    [anon_sym_time] = ACTIONS(6523),
    [anon_sym_bit] = ACTIONS(6523),
    [anon_sym_logic] = ACTIONS(6523),
    [anon_sym_reg] = ACTIONS(6523),
    [anon_sym_shortreal] = ACTIONS(6523),
    [anon_sym_real] = ACTIONS(6523),
    [anon_sym_realtime] = ACTIONS(6523),
    [anon_sym_supply0] = ACTIONS(6523),
    [anon_sym_supply1] = ACTIONS(6523),
    [anon_sym_signed] = ACTIONS(6523),
    [anon_sym_unsigned] = ACTIONS(6523),
    [anon_sym_task] = ACTIONS(6523),
    [anon_sym_modport] = ACTIONS(6523),
    [anon_sym_assert] = ACTIONS(6523),
    [anon_sym_property] = ACTIONS(6523),
    [anon_sym_assume] = ACTIONS(6523),
    [anon_sym_cover] = ACTIONS(6523),
    [anon_sym_sequence] = ACTIONS(6523),
    [anon_sym_restrict] = ACTIONS(6523),
    [anon_sym_not] = ACTIONS(6523),
    [anon_sym_or] = ACTIONS(6523),
    [anon_sym_and] = ACTIONS(6523),
    [anon_sym_case] = ACTIONS(6523),
    [anon_sym_always] = ACTIONS(6523),
    [anon_sym_covergroup] = ACTIONS(6523),
    [anon_sym_let] = ACTIONS(6523),
    [anon_sym_pulldown] = ACTIONS(6523),
    [anon_sym_pullup] = ACTIONS(6523),
    [anon_sym_cmos] = ACTIONS(6523),
    [anon_sym_rcmos] = ACTIONS(6523),
    [anon_sym_bufif0] = ACTIONS(6523),
    [anon_sym_bufif1] = ACTIONS(6523),
    [anon_sym_notif0] = ACTIONS(6523),
    [anon_sym_notif1] = ACTIONS(6523),
    [anon_sym_nmos] = ACTIONS(6523),
    [anon_sym_pmos] = ACTIONS(6523),
    [anon_sym_rnmos] = ACTIONS(6523),
    [anon_sym_rpmos] = ACTIONS(6523),
    [anon_sym_nand] = ACTIONS(6523),
    [anon_sym_nor] = ACTIONS(6523),
    [anon_sym_xor] = ACTIONS(6523),
    [anon_sym_xnor] = ACTIONS(6523),
    [anon_sym_buf] = ACTIONS(6523),
    [anon_sym_tranif0] = ACTIONS(6523),
    [anon_sym_tranif1] = ACTIONS(6523),
    [anon_sym_rtranif1] = ACTIONS(6523),
    [anon_sym_rtranif0] = ACTIONS(6523),
    [anon_sym_tran] = ACTIONS(6523),
    [anon_sym_rtran] = ACTIONS(6523),
    [anon_sym_generate] = ACTIONS(6523),
    [anon_sym_for] = ACTIONS(6523),
    [anon_sym_initial] = ACTIONS(6523),
    [anon_sym_assign] = ACTIONS(6523),
    [anon_sym_alias] = ACTIONS(6523),
    [anon_sym_always_comb] = ACTIONS(6523),
    [anon_sym_always_latch] = ACTIONS(6523),
    [anon_sym_always_ff] = ACTIONS(6523),
    [anon_sym_final] = ACTIONS(6523),
    [anon_sym_global] = ACTIONS(6523),
    [anon_sym_specify] = ACTIONS(6523),
    [anon_sym_LPAREN_STAR] = ACTIONS(6526),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6526),
    [anon_sym_DOLLARunit] = ACTIONS(6526),
  },
  [1192] = {
    [sym_simple_identifier] = ACTIONS(6529),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6531),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6531),
    [anon_sym_BQUOTE] = ACTIONS(6529),
    [aux_sym_id_directive_token1] = ACTIONS(6531),
    [aux_sym_id_directive_token2] = ACTIONS(6531),
    [aux_sym_id_directive_token3] = ACTIONS(6531),
    [aux_sym_id_directive_token4] = ACTIONS(6529),
    [aux_sym_zero_directive_token1] = ACTIONS(6531),
    [aux_sym_zero_directive_token2] = ACTIONS(6531),
    [aux_sym_zero_directive_token3] = ACTIONS(6531),
    [aux_sym_zero_directive_token4] = ACTIONS(6531),
    [aux_sym_zero_directive_token5] = ACTIONS(6531),
    [aux_sym_zero_directive_token6] = ACTIONS(6531),
    [aux_sym_zero_directive_token7] = ACTIONS(6531),
    [aux_sym_zero_directive_token8] = ACTIONS(6531),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6531),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6531),
    [anon_sym_wire] = ACTIONS(6529),
    [anon_sym_tri] = ACTIONS(6529),
    [anon_sym_tri0] = ACTIONS(6529),
    [anon_sym_tri1] = ACTIONS(6529),
    [anon_sym_wand] = ACTIONS(6529),
    [anon_sym_triand] = ACTIONS(6529),
    [anon_sym_wor] = ACTIONS(6529),
    [anon_sym_trior] = ACTIONS(6529),
    [anon_sym_trireg] = ACTIONS(6529),
    [anon_sym_uwire] = ACTIONS(6529),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6531),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6531),
    [aux_sym_begin_keywords_token1] = ACTIONS(6531),
    [anon_sym_SEMI] = ACTIONS(6531),
    [anon_sym_endmodule] = ACTIONS(6529),
    [anon_sym_extern] = ACTIONS(6529),
    [anon_sym_module] = ACTIONS(6529),
    [anon_sym_macromodule] = ACTIONS(6529),
    [anon_sym_endinterface] = ACTIONS(6529),
    [anon_sym_interface] = ACTIONS(6529),
    [anon_sym_endprogram] = ACTIONS(6529),
    [anon_sym_program] = ACTIONS(6529),
    [anon_sym_checker] = ACTIONS(6529),
    [anon_sym_virtual] = ACTIONS(6529),
    [anon_sym_class] = ACTIONS(6529),
    [anon_sym_timeunit] = ACTIONS(6529),
    [anon_sym_timeprecision] = ACTIONS(6529),
    [anon_sym_type] = ACTIONS(6529),
    [anon_sym_input] = ACTIONS(6529),
    [anon_sym_output] = ACTIONS(6529),
    [anon_sym_inout] = ACTIONS(6529),
    [anon_sym_ref] = ACTIONS(6529),
    [anon_sym_DOLLARfatal] = ACTIONS(6531),
    [anon_sym_DOLLARerror] = ACTIONS(6531),
    [anon_sym_DOLLARwarning] = ACTIONS(6531),
    [anon_sym_DOLLARinfo] = ACTIONS(6531),
    [anon_sym_default] = ACTIONS(6529),
    [anon_sym_clocking] = ACTIONS(6529),
    [anon_sym_defparam] = ACTIONS(6529),
    [anon_sym_bind] = ACTIONS(6529),
    [anon_sym_const] = ACTIONS(6529),
    [anon_sym_function] = ACTIONS(6529),
    [anon_sym_static] = ACTIONS(6529),
    [anon_sym_constraint] = ACTIONS(6529),
    [anon_sym_if] = ACTIONS(6529),
    [anon_sym_else] = ACTIONS(6529),
    [anon_sym_LBRACK] = ACTIONS(6531),
    [anon_sym_localparam] = ACTIONS(6529),
    [anon_sym_parameter] = ACTIONS(6529),
    [anon_sym_specparam] = ACTIONS(6529),
    [anon_sym_var] = ACTIONS(6529),
    [anon_sym_import] = ACTIONS(6529),
    [anon_sym_export] = ACTIONS(6529),
    [anon_sym_genvar] = ACTIONS(6529),
    [anon_sym_interconnect] = ACTIONS(6529),
    [anon_sym_typedef] = ACTIONS(6529),
    [anon_sym_enum] = ACTIONS(6529),
    [anon_sym_struct] = ACTIONS(6529),
    [anon_sym_union] = ACTIONS(6529),
    [anon_sym_nettype] = ACTIONS(6529),
    [anon_sym_automatic] = ACTIONS(6529),
    [anon_sym_string] = ACTIONS(6529),
    [anon_sym_chandle] = ACTIONS(6529),
    [anon_sym_event] = ACTIONS(6529),
    [anon_sym_byte] = ACTIONS(6529),
    [anon_sym_shortint] = ACTIONS(6529),
    [anon_sym_int] = ACTIONS(6529),
    [anon_sym_longint] = ACTIONS(6529),
    [anon_sym_integer] = ACTIONS(6529),
    [anon_sym_time] = ACTIONS(6529),
    [anon_sym_bit] = ACTIONS(6529),
    [anon_sym_logic] = ACTIONS(6529),
    [anon_sym_reg] = ACTIONS(6529),
    [anon_sym_shortreal] = ACTIONS(6529),
    [anon_sym_real] = ACTIONS(6529),
    [anon_sym_realtime] = ACTIONS(6529),
    [anon_sym_supply0] = ACTIONS(6529),
    [anon_sym_supply1] = ACTIONS(6529),
    [anon_sym_signed] = ACTIONS(6529),
    [anon_sym_unsigned] = ACTIONS(6529),
    [anon_sym_task] = ACTIONS(6529),
    [anon_sym_modport] = ACTIONS(6529),
    [anon_sym_assert] = ACTIONS(6529),
    [anon_sym_property] = ACTIONS(6529),
    [anon_sym_assume] = ACTIONS(6529),
    [anon_sym_cover] = ACTIONS(6529),
    [anon_sym_sequence] = ACTIONS(6529),
    [anon_sym_restrict] = ACTIONS(6529),
    [anon_sym_not] = ACTIONS(6529),
    [anon_sym_or] = ACTIONS(6529),
    [anon_sym_and] = ACTIONS(6529),
    [anon_sym_case] = ACTIONS(6529),
    [anon_sym_always] = ACTIONS(6529),
    [anon_sym_covergroup] = ACTIONS(6529),
    [anon_sym_let] = ACTIONS(6529),
    [anon_sym_pulldown] = ACTIONS(6529),
    [anon_sym_pullup] = ACTIONS(6529),
    [anon_sym_cmos] = ACTIONS(6529),
    [anon_sym_rcmos] = ACTIONS(6529),
    [anon_sym_bufif0] = ACTIONS(6529),
    [anon_sym_bufif1] = ACTIONS(6529),
    [anon_sym_notif0] = ACTIONS(6529),
    [anon_sym_notif1] = ACTIONS(6529),
    [anon_sym_nmos] = ACTIONS(6529),
    [anon_sym_pmos] = ACTIONS(6529),
    [anon_sym_rnmos] = ACTIONS(6529),
    [anon_sym_rpmos] = ACTIONS(6529),
    [anon_sym_nand] = ACTIONS(6529),
    [anon_sym_nor] = ACTIONS(6529),
    [anon_sym_xor] = ACTIONS(6529),
    [anon_sym_xnor] = ACTIONS(6529),
    [anon_sym_buf] = ACTIONS(6529),
    [anon_sym_tranif0] = ACTIONS(6529),
    [anon_sym_tranif1] = ACTIONS(6529),
    [anon_sym_rtranif1] = ACTIONS(6529),
    [anon_sym_rtranif0] = ACTIONS(6529),
    [anon_sym_tran] = ACTIONS(6529),
    [anon_sym_rtran] = ACTIONS(6529),
    [anon_sym_generate] = ACTIONS(6529),
    [anon_sym_for] = ACTIONS(6529),
    [anon_sym_initial] = ACTIONS(6529),
    [anon_sym_assign] = ACTIONS(6529),
    [anon_sym_alias] = ACTIONS(6529),
    [anon_sym_always_comb] = ACTIONS(6529),
    [anon_sym_always_latch] = ACTIONS(6529),
    [anon_sym_always_ff] = ACTIONS(6529),
    [anon_sym_final] = ACTIONS(6529),
    [anon_sym_global] = ACTIONS(6529),
    [anon_sym_specify] = ACTIONS(6529),
    [anon_sym_LPAREN_STAR] = ACTIONS(6531),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6531),
    [anon_sym_DOLLARunit] = ACTIONS(6531),
  },
  [1193] = {
    [sym_simple_identifier] = ACTIONS(6533),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6535),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6535),
    [anon_sym_BQUOTE] = ACTIONS(6533),
    [aux_sym_id_directive_token1] = ACTIONS(6535),
    [aux_sym_id_directive_token2] = ACTIONS(6535),
    [aux_sym_id_directive_token3] = ACTIONS(6535),
    [aux_sym_id_directive_token4] = ACTIONS(6533),
    [aux_sym_zero_directive_token1] = ACTIONS(6535),
    [aux_sym_zero_directive_token2] = ACTIONS(6535),
    [aux_sym_zero_directive_token3] = ACTIONS(6535),
    [aux_sym_zero_directive_token4] = ACTIONS(6535),
    [aux_sym_zero_directive_token5] = ACTIONS(6535),
    [aux_sym_zero_directive_token6] = ACTIONS(6535),
    [aux_sym_zero_directive_token7] = ACTIONS(6535),
    [aux_sym_zero_directive_token8] = ACTIONS(6535),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6535),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6535),
    [anon_sym_wire] = ACTIONS(6533),
    [anon_sym_tri] = ACTIONS(6533),
    [anon_sym_tri0] = ACTIONS(6533),
    [anon_sym_tri1] = ACTIONS(6533),
    [anon_sym_wand] = ACTIONS(6533),
    [anon_sym_triand] = ACTIONS(6533),
    [anon_sym_wor] = ACTIONS(6533),
    [anon_sym_trior] = ACTIONS(6533),
    [anon_sym_trireg] = ACTIONS(6533),
    [anon_sym_uwire] = ACTIONS(6533),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6535),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6535),
    [aux_sym_begin_keywords_token1] = ACTIONS(6535),
    [anon_sym_SEMI] = ACTIONS(6535),
    [anon_sym_endmodule] = ACTIONS(6533),
    [anon_sym_extern] = ACTIONS(6533),
    [anon_sym_module] = ACTIONS(6533),
    [anon_sym_macromodule] = ACTIONS(6533),
    [anon_sym_endinterface] = ACTIONS(6533),
    [anon_sym_interface] = ACTIONS(6533),
    [anon_sym_endprogram] = ACTIONS(6533),
    [anon_sym_program] = ACTIONS(6533),
    [anon_sym_checker] = ACTIONS(6533),
    [anon_sym_virtual] = ACTIONS(6533),
    [anon_sym_class] = ACTIONS(6533),
    [anon_sym_timeunit] = ACTIONS(6533),
    [anon_sym_timeprecision] = ACTIONS(6533),
    [anon_sym_type] = ACTIONS(6533),
    [anon_sym_input] = ACTIONS(6533),
    [anon_sym_output] = ACTIONS(6533),
    [anon_sym_inout] = ACTIONS(6533),
    [anon_sym_ref] = ACTIONS(6533),
    [anon_sym_DOLLARfatal] = ACTIONS(6535),
    [anon_sym_DOLLARerror] = ACTIONS(6535),
    [anon_sym_DOLLARwarning] = ACTIONS(6535),
    [anon_sym_DOLLARinfo] = ACTIONS(6535),
    [anon_sym_default] = ACTIONS(6533),
    [anon_sym_clocking] = ACTIONS(6533),
    [anon_sym_defparam] = ACTIONS(6533),
    [anon_sym_bind] = ACTIONS(6533),
    [anon_sym_const] = ACTIONS(6533),
    [anon_sym_function] = ACTIONS(6533),
    [anon_sym_static] = ACTIONS(6533),
    [anon_sym_constraint] = ACTIONS(6533),
    [anon_sym_if] = ACTIONS(6533),
    [anon_sym_else] = ACTIONS(6533),
    [anon_sym_LBRACK] = ACTIONS(6535),
    [anon_sym_localparam] = ACTIONS(6533),
    [anon_sym_parameter] = ACTIONS(6533),
    [anon_sym_specparam] = ACTIONS(6533),
    [anon_sym_var] = ACTIONS(6533),
    [anon_sym_import] = ACTIONS(6533),
    [anon_sym_export] = ACTIONS(6533),
    [anon_sym_genvar] = ACTIONS(6533),
    [anon_sym_interconnect] = ACTIONS(6533),
    [anon_sym_typedef] = ACTIONS(6533),
    [anon_sym_enum] = ACTIONS(6533),
    [anon_sym_struct] = ACTIONS(6533),
    [anon_sym_union] = ACTIONS(6533),
    [anon_sym_nettype] = ACTIONS(6533),
    [anon_sym_automatic] = ACTIONS(6533),
    [anon_sym_string] = ACTIONS(6533),
    [anon_sym_chandle] = ACTIONS(6533),
    [anon_sym_event] = ACTIONS(6533),
    [anon_sym_byte] = ACTIONS(6533),
    [anon_sym_shortint] = ACTIONS(6533),
    [anon_sym_int] = ACTIONS(6533),
    [anon_sym_longint] = ACTIONS(6533),
    [anon_sym_integer] = ACTIONS(6533),
    [anon_sym_time] = ACTIONS(6533),
    [anon_sym_bit] = ACTIONS(6533),
    [anon_sym_logic] = ACTIONS(6533),
    [anon_sym_reg] = ACTIONS(6533),
    [anon_sym_shortreal] = ACTIONS(6533),
    [anon_sym_real] = ACTIONS(6533),
    [anon_sym_realtime] = ACTIONS(6533),
    [anon_sym_supply0] = ACTIONS(6533),
    [anon_sym_supply1] = ACTIONS(6533),
    [anon_sym_signed] = ACTIONS(6533),
    [anon_sym_unsigned] = ACTIONS(6533),
    [anon_sym_task] = ACTIONS(6533),
    [anon_sym_modport] = ACTIONS(6533),
    [anon_sym_assert] = ACTIONS(6533),
    [anon_sym_property] = ACTIONS(6533),
    [anon_sym_assume] = ACTIONS(6533),
    [anon_sym_cover] = ACTIONS(6533),
    [anon_sym_sequence] = ACTIONS(6533),
    [anon_sym_restrict] = ACTIONS(6533),
    [anon_sym_not] = ACTIONS(6533),
    [anon_sym_or] = ACTIONS(6533),
    [anon_sym_and] = ACTIONS(6533),
    [anon_sym_case] = ACTIONS(6533),
    [anon_sym_always] = ACTIONS(6533),
    [anon_sym_covergroup] = ACTIONS(6533),
    [anon_sym_let] = ACTIONS(6533),
    [anon_sym_pulldown] = ACTIONS(6533),
    [anon_sym_pullup] = ACTIONS(6533),
    [anon_sym_cmos] = ACTIONS(6533),
    [anon_sym_rcmos] = ACTIONS(6533),
    [anon_sym_bufif0] = ACTIONS(6533),
    [anon_sym_bufif1] = ACTIONS(6533),
    [anon_sym_notif0] = ACTIONS(6533),
    [anon_sym_notif1] = ACTIONS(6533),
    [anon_sym_nmos] = ACTIONS(6533),
    [anon_sym_pmos] = ACTIONS(6533),
    [anon_sym_rnmos] = ACTIONS(6533),
    [anon_sym_rpmos] = ACTIONS(6533),
    [anon_sym_nand] = ACTIONS(6533),
    [anon_sym_nor] = ACTIONS(6533),
    [anon_sym_xor] = ACTIONS(6533),
    [anon_sym_xnor] = ACTIONS(6533),
    [anon_sym_buf] = ACTIONS(6533),
    [anon_sym_tranif0] = ACTIONS(6533),
    [anon_sym_tranif1] = ACTIONS(6533),
    [anon_sym_rtranif1] = ACTIONS(6533),
    [anon_sym_rtranif0] = ACTIONS(6533),
    [anon_sym_tran] = ACTIONS(6533),
    [anon_sym_rtran] = ACTIONS(6533),
    [anon_sym_generate] = ACTIONS(6533),
    [anon_sym_for] = ACTIONS(6533),
    [anon_sym_initial] = ACTIONS(6533),
    [anon_sym_assign] = ACTIONS(6533),
    [anon_sym_alias] = ACTIONS(6533),
    [anon_sym_always_comb] = ACTIONS(6533),
    [anon_sym_always_latch] = ACTIONS(6533),
    [anon_sym_always_ff] = ACTIONS(6533),
    [anon_sym_final] = ACTIONS(6533),
    [anon_sym_global] = ACTIONS(6533),
    [anon_sym_specify] = ACTIONS(6533),
    [anon_sym_LPAREN_STAR] = ACTIONS(6535),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6535),
    [anon_sym_DOLLARunit] = ACTIONS(6535),
  },
  [1194] = {
    [sym_simple_identifier] = ACTIONS(6537),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6541),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6541),
    [anon_sym_BQUOTE] = ACTIONS(6537),
    [aux_sym_id_directive_token1] = ACTIONS(6541),
    [aux_sym_id_directive_token2] = ACTIONS(6541),
    [aux_sym_id_directive_token3] = ACTIONS(6541),
    [aux_sym_id_directive_token4] = ACTIONS(6537),
    [aux_sym_zero_directive_token1] = ACTIONS(6541),
    [aux_sym_zero_directive_token2] = ACTIONS(6541),
    [aux_sym_zero_directive_token3] = ACTIONS(6541),
    [aux_sym_zero_directive_token4] = ACTIONS(6541),
    [aux_sym_zero_directive_token5] = ACTIONS(6541),
    [aux_sym_zero_directive_token6] = ACTIONS(6541),
    [aux_sym_zero_directive_token7] = ACTIONS(6541),
    [aux_sym_zero_directive_token8] = ACTIONS(6541),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6541),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6541),
    [anon_sym_wire] = ACTIONS(6537),
    [anon_sym_tri] = ACTIONS(6537),
    [anon_sym_tri0] = ACTIONS(6537),
    [anon_sym_tri1] = ACTIONS(6537),
    [anon_sym_wand] = ACTIONS(6537),
    [anon_sym_triand] = ACTIONS(6537),
    [anon_sym_wor] = ACTIONS(6537),
    [anon_sym_trior] = ACTIONS(6537),
    [anon_sym_trireg] = ACTIONS(6537),
    [anon_sym_uwire] = ACTIONS(6537),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6541),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6541),
    [aux_sym_begin_keywords_token1] = ACTIONS(6541),
    [anon_sym_SEMI] = ACTIONS(6541),
    [anon_sym_endmodule] = ACTIONS(6537),
    [anon_sym_extern] = ACTIONS(6537),
    [anon_sym_module] = ACTIONS(6537),
    [anon_sym_macromodule] = ACTIONS(6537),
    [anon_sym_endinterface] = ACTIONS(6537),
    [anon_sym_interface] = ACTIONS(6537),
    [anon_sym_endprogram] = ACTIONS(6537),
    [anon_sym_program] = ACTIONS(6537),
    [anon_sym_checker] = ACTIONS(6537),
    [anon_sym_virtual] = ACTIONS(6537),
    [anon_sym_class] = ACTIONS(6537),
    [anon_sym_timeunit] = ACTIONS(6537),
    [anon_sym_timeprecision] = ACTIONS(6537),
    [anon_sym_type] = ACTIONS(6537),
    [anon_sym_input] = ACTIONS(6537),
    [anon_sym_output] = ACTIONS(6537),
    [anon_sym_inout] = ACTIONS(6537),
    [anon_sym_ref] = ACTIONS(6537),
    [anon_sym_DOLLARfatal] = ACTIONS(6541),
    [anon_sym_DOLLARerror] = ACTIONS(6541),
    [anon_sym_DOLLARwarning] = ACTIONS(6541),
    [anon_sym_DOLLARinfo] = ACTIONS(6541),
    [anon_sym_default] = ACTIONS(6537),
    [anon_sym_clocking] = ACTIONS(6537),
    [anon_sym_defparam] = ACTIONS(6537),
    [anon_sym_bind] = ACTIONS(6537),
    [anon_sym_const] = ACTIONS(6537),
    [anon_sym_function] = ACTIONS(6537),
    [anon_sym_static] = ACTIONS(6537),
    [anon_sym_constraint] = ACTIONS(6537),
    [anon_sym_if] = ACTIONS(6537),
    [anon_sym_else] = ACTIONS(6537),
    [anon_sym_LBRACK] = ACTIONS(6541),
    [anon_sym_localparam] = ACTIONS(6537),
    [anon_sym_parameter] = ACTIONS(6537),
    [anon_sym_specparam] = ACTIONS(6537),
    [anon_sym_var] = ACTIONS(6537),
    [anon_sym_import] = ACTIONS(6537),
    [anon_sym_export] = ACTIONS(6537),
    [anon_sym_genvar] = ACTIONS(6537),
    [anon_sym_interconnect] = ACTIONS(6537),
    [anon_sym_typedef] = ACTIONS(6537),
    [anon_sym_enum] = ACTIONS(6537),
    [anon_sym_struct] = ACTIONS(6537),
    [anon_sym_union] = ACTIONS(6537),
    [anon_sym_nettype] = ACTIONS(6537),
    [anon_sym_automatic] = ACTIONS(6537),
    [anon_sym_string] = ACTIONS(6537),
    [anon_sym_chandle] = ACTIONS(6537),
    [anon_sym_event] = ACTIONS(6537),
    [anon_sym_byte] = ACTIONS(6537),
    [anon_sym_shortint] = ACTIONS(6537),
    [anon_sym_int] = ACTIONS(6537),
    [anon_sym_longint] = ACTIONS(6537),
    [anon_sym_integer] = ACTIONS(6537),
    [anon_sym_time] = ACTIONS(6537),
    [anon_sym_bit] = ACTIONS(6537),
    [anon_sym_logic] = ACTIONS(6537),
    [anon_sym_reg] = ACTIONS(6537),
    [anon_sym_shortreal] = ACTIONS(6537),
    [anon_sym_real] = ACTIONS(6537),
    [anon_sym_realtime] = ACTIONS(6537),
    [anon_sym_supply0] = ACTIONS(6537),
    [anon_sym_supply1] = ACTIONS(6537),
    [anon_sym_signed] = ACTIONS(6537),
    [anon_sym_unsigned] = ACTIONS(6537),
    [anon_sym_task] = ACTIONS(6537),
    [anon_sym_modport] = ACTIONS(6537),
    [anon_sym_assert] = ACTIONS(6537),
    [anon_sym_property] = ACTIONS(6537),
    [anon_sym_assume] = ACTIONS(6537),
    [anon_sym_cover] = ACTIONS(6537),
    [anon_sym_sequence] = ACTIONS(6537),
    [anon_sym_restrict] = ACTIONS(6537),
    [anon_sym_not] = ACTIONS(6537),
    [anon_sym_or] = ACTIONS(6537),
    [anon_sym_and] = ACTIONS(6537),
    [anon_sym_case] = ACTIONS(6537),
    [anon_sym_always] = ACTIONS(6537),
    [anon_sym_covergroup] = ACTIONS(6537),
    [anon_sym_let] = ACTIONS(6537),
    [anon_sym_pulldown] = ACTIONS(6537),
    [anon_sym_pullup] = ACTIONS(6537),
    [anon_sym_cmos] = ACTIONS(6537),
    [anon_sym_rcmos] = ACTIONS(6537),
    [anon_sym_bufif0] = ACTIONS(6537),
    [anon_sym_bufif1] = ACTIONS(6537),
    [anon_sym_notif0] = ACTIONS(6537),
    [anon_sym_notif1] = ACTIONS(6537),
    [anon_sym_nmos] = ACTIONS(6537),
    [anon_sym_pmos] = ACTIONS(6537),
    [anon_sym_rnmos] = ACTIONS(6537),
    [anon_sym_rpmos] = ACTIONS(6537),
    [anon_sym_nand] = ACTIONS(6537),
    [anon_sym_nor] = ACTIONS(6537),
    [anon_sym_xor] = ACTIONS(6537),
    [anon_sym_xnor] = ACTIONS(6537),
    [anon_sym_buf] = ACTIONS(6537),
    [anon_sym_tranif0] = ACTIONS(6537),
    [anon_sym_tranif1] = ACTIONS(6537),
    [anon_sym_rtranif1] = ACTIONS(6537),
    [anon_sym_rtranif0] = ACTIONS(6537),
    [anon_sym_tran] = ACTIONS(6537),
    [anon_sym_rtran] = ACTIONS(6537),
    [anon_sym_generate] = ACTIONS(6537),
    [anon_sym_for] = ACTIONS(6537),
    [anon_sym_initial] = ACTIONS(6537),
    [anon_sym_assign] = ACTIONS(6537),
    [anon_sym_alias] = ACTIONS(6537),
    [anon_sym_always_comb] = ACTIONS(6537),
    [anon_sym_always_latch] = ACTIONS(6537),
    [anon_sym_always_ff] = ACTIONS(6537),
    [anon_sym_final] = ACTIONS(6537),
    [anon_sym_global] = ACTIONS(6537),
    [anon_sym_specify] = ACTIONS(6537),
    [anon_sym_LPAREN_STAR] = ACTIONS(6541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6541),
    [anon_sym_DOLLARunit] = ACTIONS(6541),
  },
  [1195] = {
    [sym_simple_identifier] = ACTIONS(6545),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6547),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6547),
    [anon_sym_BQUOTE] = ACTIONS(6545),
    [aux_sym_id_directive_token1] = ACTIONS(6547),
    [aux_sym_id_directive_token2] = ACTIONS(6547),
    [aux_sym_id_directive_token3] = ACTIONS(6547),
    [aux_sym_id_directive_token4] = ACTIONS(6545),
    [aux_sym_zero_directive_token1] = ACTIONS(6547),
    [aux_sym_zero_directive_token2] = ACTIONS(6547),
    [aux_sym_zero_directive_token3] = ACTIONS(6547),
    [aux_sym_zero_directive_token4] = ACTIONS(6547),
    [aux_sym_zero_directive_token5] = ACTIONS(6547),
    [aux_sym_zero_directive_token6] = ACTIONS(6547),
    [aux_sym_zero_directive_token7] = ACTIONS(6547),
    [aux_sym_zero_directive_token8] = ACTIONS(6547),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6547),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6547),
    [anon_sym_wire] = ACTIONS(6545),
    [anon_sym_tri] = ACTIONS(6545),
    [anon_sym_tri0] = ACTIONS(6545),
    [anon_sym_tri1] = ACTIONS(6545),
    [anon_sym_wand] = ACTIONS(6545),
    [anon_sym_triand] = ACTIONS(6545),
    [anon_sym_wor] = ACTIONS(6545),
    [anon_sym_trior] = ACTIONS(6545),
    [anon_sym_trireg] = ACTIONS(6545),
    [anon_sym_uwire] = ACTIONS(6545),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6547),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6547),
    [aux_sym_begin_keywords_token1] = ACTIONS(6547),
    [anon_sym_SEMI] = ACTIONS(6547),
    [anon_sym_endmodule] = ACTIONS(6545),
    [anon_sym_extern] = ACTIONS(6545),
    [anon_sym_module] = ACTIONS(6545),
    [anon_sym_macromodule] = ACTIONS(6545),
    [anon_sym_endinterface] = ACTIONS(6545),
    [anon_sym_interface] = ACTIONS(6545),
    [anon_sym_endprogram] = ACTIONS(6545),
    [anon_sym_program] = ACTIONS(6545),
    [anon_sym_checker] = ACTIONS(6545),
    [anon_sym_virtual] = ACTIONS(6545),
    [anon_sym_class] = ACTIONS(6545),
    [anon_sym_timeunit] = ACTIONS(6545),
    [anon_sym_timeprecision] = ACTIONS(6545),
    [anon_sym_type] = ACTIONS(6545),
    [anon_sym_input] = ACTIONS(6545),
    [anon_sym_output] = ACTIONS(6545),
    [anon_sym_inout] = ACTIONS(6545),
    [anon_sym_ref] = ACTIONS(6545),
    [anon_sym_DOLLARfatal] = ACTIONS(6547),
    [anon_sym_DOLLARerror] = ACTIONS(6547),
    [anon_sym_DOLLARwarning] = ACTIONS(6547),
    [anon_sym_DOLLARinfo] = ACTIONS(6547),
    [anon_sym_default] = ACTIONS(6545),
    [anon_sym_clocking] = ACTIONS(6545),
    [anon_sym_defparam] = ACTIONS(6545),
    [anon_sym_bind] = ACTIONS(6545),
    [anon_sym_const] = ACTIONS(6545),
    [anon_sym_function] = ACTIONS(6545),
    [anon_sym_static] = ACTIONS(6545),
    [anon_sym_constraint] = ACTIONS(6545),
    [anon_sym_if] = ACTIONS(6545),
    [anon_sym_else] = ACTIONS(6545),
    [anon_sym_LBRACK] = ACTIONS(6547),
    [anon_sym_localparam] = ACTIONS(6545),
    [anon_sym_parameter] = ACTIONS(6545),
    [anon_sym_specparam] = ACTIONS(6545),
    [anon_sym_var] = ACTIONS(6545),
    [anon_sym_import] = ACTIONS(6545),
    [anon_sym_export] = ACTIONS(6545),
    [anon_sym_genvar] = ACTIONS(6545),
    [anon_sym_interconnect] = ACTIONS(6545),
    [anon_sym_typedef] = ACTIONS(6545),
    [anon_sym_enum] = ACTIONS(6545),
    [anon_sym_struct] = ACTIONS(6545),
    [anon_sym_union] = ACTIONS(6545),
    [anon_sym_nettype] = ACTIONS(6545),
    [anon_sym_automatic] = ACTIONS(6545),
    [anon_sym_string] = ACTIONS(6545),
    [anon_sym_chandle] = ACTIONS(6545),
    [anon_sym_event] = ACTIONS(6545),
    [anon_sym_byte] = ACTIONS(6545),
    [anon_sym_shortint] = ACTIONS(6545),
    [anon_sym_int] = ACTIONS(6545),
    [anon_sym_longint] = ACTIONS(6545),
    [anon_sym_integer] = ACTIONS(6545),
    [anon_sym_time] = ACTIONS(6545),
    [anon_sym_bit] = ACTIONS(6545),
    [anon_sym_logic] = ACTIONS(6545),
    [anon_sym_reg] = ACTIONS(6545),
    [anon_sym_shortreal] = ACTIONS(6545),
    [anon_sym_real] = ACTIONS(6545),
    [anon_sym_realtime] = ACTIONS(6545),
    [anon_sym_supply0] = ACTIONS(6545),
    [anon_sym_supply1] = ACTIONS(6545),
    [anon_sym_signed] = ACTIONS(6545),
    [anon_sym_unsigned] = ACTIONS(6545),
    [anon_sym_task] = ACTIONS(6545),
    [anon_sym_modport] = ACTIONS(6545),
    [anon_sym_assert] = ACTIONS(6545),
    [anon_sym_property] = ACTIONS(6545),
    [anon_sym_assume] = ACTIONS(6545),
    [anon_sym_cover] = ACTIONS(6545),
    [anon_sym_sequence] = ACTIONS(6545),
    [anon_sym_restrict] = ACTIONS(6545),
    [anon_sym_not] = ACTIONS(6545),
    [anon_sym_or] = ACTIONS(6545),
    [anon_sym_and] = ACTIONS(6545),
    [anon_sym_case] = ACTIONS(6545),
    [anon_sym_always] = ACTIONS(6545),
    [anon_sym_covergroup] = ACTIONS(6545),
    [anon_sym_let] = ACTIONS(6545),
    [anon_sym_pulldown] = ACTIONS(6545),
    [anon_sym_pullup] = ACTIONS(6545),
    [anon_sym_cmos] = ACTIONS(6545),
    [anon_sym_rcmos] = ACTIONS(6545),
    [anon_sym_bufif0] = ACTIONS(6545),
    [anon_sym_bufif1] = ACTIONS(6545),
    [anon_sym_notif0] = ACTIONS(6545),
    [anon_sym_notif1] = ACTIONS(6545),
    [anon_sym_nmos] = ACTIONS(6545),
    [anon_sym_pmos] = ACTIONS(6545),
    [anon_sym_rnmos] = ACTIONS(6545),
    [anon_sym_rpmos] = ACTIONS(6545),
    [anon_sym_nand] = ACTIONS(6545),
    [anon_sym_nor] = ACTIONS(6545),
    [anon_sym_xor] = ACTIONS(6545),
    [anon_sym_xnor] = ACTIONS(6545),
    [anon_sym_buf] = ACTIONS(6545),
    [anon_sym_tranif0] = ACTIONS(6545),
    [anon_sym_tranif1] = ACTIONS(6545),
    [anon_sym_rtranif1] = ACTIONS(6545),
    [anon_sym_rtranif0] = ACTIONS(6545),
    [anon_sym_tran] = ACTIONS(6545),
    [anon_sym_rtran] = ACTIONS(6545),
    [anon_sym_generate] = ACTIONS(6545),
    [anon_sym_for] = ACTIONS(6545),
    [anon_sym_initial] = ACTIONS(6545),
    [anon_sym_assign] = ACTIONS(6545),
    [anon_sym_alias] = ACTIONS(6545),
    [anon_sym_always_comb] = ACTIONS(6545),
    [anon_sym_always_latch] = ACTIONS(6545),
    [anon_sym_always_ff] = ACTIONS(6545),
    [anon_sym_final] = ACTIONS(6545),
    [anon_sym_global] = ACTIONS(6545),
    [anon_sym_specify] = ACTIONS(6545),
    [anon_sym_LPAREN_STAR] = ACTIONS(6547),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6547),
    [anon_sym_DOLLARunit] = ACTIONS(6547),
  },
  [1196] = {
    [sym_simple_identifier] = ACTIONS(6549),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6551),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6551),
    [anon_sym_BQUOTE] = ACTIONS(6549),
    [aux_sym_id_directive_token1] = ACTIONS(6551),
    [aux_sym_id_directive_token2] = ACTIONS(6551),
    [aux_sym_id_directive_token3] = ACTIONS(6551),
    [aux_sym_id_directive_token4] = ACTIONS(6549),
    [aux_sym_zero_directive_token1] = ACTIONS(6551),
    [aux_sym_zero_directive_token2] = ACTIONS(6551),
    [aux_sym_zero_directive_token3] = ACTIONS(6551),
    [aux_sym_zero_directive_token4] = ACTIONS(6551),
    [aux_sym_zero_directive_token5] = ACTIONS(6551),
    [aux_sym_zero_directive_token6] = ACTIONS(6551),
    [aux_sym_zero_directive_token7] = ACTIONS(6551),
    [aux_sym_zero_directive_token8] = ACTIONS(6551),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6551),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6551),
    [anon_sym_wire] = ACTIONS(6549),
    [anon_sym_tri] = ACTIONS(6549),
    [anon_sym_tri0] = ACTIONS(6549),
    [anon_sym_tri1] = ACTIONS(6549),
    [anon_sym_wand] = ACTIONS(6549),
    [anon_sym_triand] = ACTIONS(6549),
    [anon_sym_wor] = ACTIONS(6549),
    [anon_sym_trior] = ACTIONS(6549),
    [anon_sym_trireg] = ACTIONS(6549),
    [anon_sym_uwire] = ACTIONS(6549),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6551),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6551),
    [aux_sym_begin_keywords_token1] = ACTIONS(6551),
    [anon_sym_SEMI] = ACTIONS(6551),
    [anon_sym_endmodule] = ACTIONS(6549),
    [anon_sym_extern] = ACTIONS(6549),
    [anon_sym_module] = ACTIONS(6549),
    [anon_sym_macromodule] = ACTIONS(6549),
    [anon_sym_endinterface] = ACTIONS(6549),
    [anon_sym_interface] = ACTIONS(6549),
    [anon_sym_endprogram] = ACTIONS(6549),
    [anon_sym_program] = ACTIONS(6549),
    [anon_sym_checker] = ACTIONS(6549),
    [anon_sym_virtual] = ACTIONS(6549),
    [anon_sym_class] = ACTIONS(6549),
    [anon_sym_timeunit] = ACTIONS(6549),
    [anon_sym_timeprecision] = ACTIONS(6549),
    [anon_sym_type] = ACTIONS(6549),
    [anon_sym_input] = ACTIONS(6549),
    [anon_sym_output] = ACTIONS(6549),
    [anon_sym_inout] = ACTIONS(6549),
    [anon_sym_ref] = ACTIONS(6549),
    [anon_sym_DOLLARfatal] = ACTIONS(6551),
    [anon_sym_DOLLARerror] = ACTIONS(6551),
    [anon_sym_DOLLARwarning] = ACTIONS(6551),
    [anon_sym_DOLLARinfo] = ACTIONS(6551),
    [anon_sym_default] = ACTIONS(6549),
    [anon_sym_clocking] = ACTIONS(6549),
    [anon_sym_defparam] = ACTIONS(6549),
    [anon_sym_bind] = ACTIONS(6549),
    [anon_sym_const] = ACTIONS(6549),
    [anon_sym_function] = ACTIONS(6549),
    [anon_sym_static] = ACTIONS(6549),
    [anon_sym_constraint] = ACTIONS(6549),
    [anon_sym_if] = ACTIONS(6549),
    [anon_sym_else] = ACTIONS(6549),
    [anon_sym_LBRACK] = ACTIONS(6551),
    [anon_sym_localparam] = ACTIONS(6549),
    [anon_sym_parameter] = ACTIONS(6549),
    [anon_sym_specparam] = ACTIONS(6549),
    [anon_sym_var] = ACTIONS(6549),
    [anon_sym_import] = ACTIONS(6549),
    [anon_sym_export] = ACTIONS(6549),
    [anon_sym_genvar] = ACTIONS(6549),
    [anon_sym_interconnect] = ACTIONS(6549),
    [anon_sym_typedef] = ACTIONS(6549),
    [anon_sym_enum] = ACTIONS(6549),
    [anon_sym_struct] = ACTIONS(6549),
    [anon_sym_union] = ACTIONS(6549),
    [anon_sym_nettype] = ACTIONS(6549),
    [anon_sym_automatic] = ACTIONS(6549),
    [anon_sym_string] = ACTIONS(6549),
    [anon_sym_chandle] = ACTIONS(6549),
    [anon_sym_event] = ACTIONS(6549),
    [anon_sym_byte] = ACTIONS(6549),
    [anon_sym_shortint] = ACTIONS(6549),
    [anon_sym_int] = ACTIONS(6549),
    [anon_sym_longint] = ACTIONS(6549),
    [anon_sym_integer] = ACTIONS(6549),
    [anon_sym_time] = ACTIONS(6549),
    [anon_sym_bit] = ACTIONS(6549),
    [anon_sym_logic] = ACTIONS(6549),
    [anon_sym_reg] = ACTIONS(6549),
    [anon_sym_shortreal] = ACTIONS(6549),
    [anon_sym_real] = ACTIONS(6549),
    [anon_sym_realtime] = ACTIONS(6549),
    [anon_sym_supply0] = ACTIONS(6549),
    [anon_sym_supply1] = ACTIONS(6549),
    [anon_sym_signed] = ACTIONS(6549),
    [anon_sym_unsigned] = ACTIONS(6549),
    [anon_sym_task] = ACTIONS(6549),
    [anon_sym_modport] = ACTIONS(6549),
    [anon_sym_assert] = ACTIONS(6549),
    [anon_sym_property] = ACTIONS(6549),
    [anon_sym_assume] = ACTIONS(6549),
    [anon_sym_cover] = ACTIONS(6549),
    [anon_sym_sequence] = ACTIONS(6549),
    [anon_sym_restrict] = ACTIONS(6549),
    [anon_sym_not] = ACTIONS(6549),
    [anon_sym_or] = ACTIONS(6549),
    [anon_sym_and] = ACTIONS(6549),
    [anon_sym_case] = ACTIONS(6549),
    [anon_sym_always] = ACTIONS(6549),
    [anon_sym_covergroup] = ACTIONS(6549),
    [anon_sym_let] = ACTIONS(6549),
    [anon_sym_pulldown] = ACTIONS(6549),
    [anon_sym_pullup] = ACTIONS(6549),
    [anon_sym_cmos] = ACTIONS(6549),
    [anon_sym_rcmos] = ACTIONS(6549),
    [anon_sym_bufif0] = ACTIONS(6549),
    [anon_sym_bufif1] = ACTIONS(6549),
    [anon_sym_notif0] = ACTIONS(6549),
    [anon_sym_notif1] = ACTIONS(6549),
    [anon_sym_nmos] = ACTIONS(6549),
    [anon_sym_pmos] = ACTIONS(6549),
    [anon_sym_rnmos] = ACTIONS(6549),
    [anon_sym_rpmos] = ACTIONS(6549),
    [anon_sym_nand] = ACTIONS(6549),
    [anon_sym_nor] = ACTIONS(6549),
    [anon_sym_xor] = ACTIONS(6549),
    [anon_sym_xnor] = ACTIONS(6549),
    [anon_sym_buf] = ACTIONS(6549),
    [anon_sym_tranif0] = ACTIONS(6549),
    [anon_sym_tranif1] = ACTIONS(6549),
    [anon_sym_rtranif1] = ACTIONS(6549),
    [anon_sym_rtranif0] = ACTIONS(6549),
    [anon_sym_tran] = ACTIONS(6549),
    [anon_sym_rtran] = ACTIONS(6549),
    [anon_sym_generate] = ACTIONS(6549),
    [anon_sym_for] = ACTIONS(6549),
    [anon_sym_initial] = ACTIONS(6549),
    [anon_sym_assign] = ACTIONS(6549),
    [anon_sym_alias] = ACTIONS(6549),
    [anon_sym_always_comb] = ACTIONS(6549),
    [anon_sym_always_latch] = ACTIONS(6549),
    [anon_sym_always_ff] = ACTIONS(6549),
    [anon_sym_final] = ACTIONS(6549),
    [anon_sym_global] = ACTIONS(6549),
    [anon_sym_specify] = ACTIONS(6549),
    [anon_sym_LPAREN_STAR] = ACTIONS(6551),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6551),
    [anon_sym_DOLLARunit] = ACTIONS(6551),
  },
  [1197] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11720),
    [sym_sequence_expr] = STATE(10820),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_operator_assignment] = STATE(17798),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1404),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(5795),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(7195),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_mintypmax_expression] = STATE(17799),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(7112),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(10942),
    [sym_unary_operator] = STATE(5343),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5745),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5397),
    [sym_package_scope] = STATE(12245),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12933),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(6553),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6555),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(6557),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6559),
    [anon_sym_DOLLARroot] = ACTIONS(6561),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1198] = {
    [ts_builtin_sym_end] = ACTIONS(6563),
    [sym_simple_identifier] = ACTIONS(6565),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6563),
    [anon_sym_LPAREN] = ACTIONS(6567),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6563),
    [anon_sym_BQUOTE] = ACTIONS(6565),
    [aux_sym_id_directive_token1] = ACTIONS(6563),
    [aux_sym_id_directive_token2] = ACTIONS(6563),
    [aux_sym_id_directive_token3] = ACTIONS(6563),
    [aux_sym_id_directive_token4] = ACTIONS(6565),
    [aux_sym_zero_directive_token1] = ACTIONS(6563),
    [aux_sym_zero_directive_token2] = ACTIONS(6563),
    [aux_sym_zero_directive_token3] = ACTIONS(6563),
    [aux_sym_zero_directive_token4] = ACTIONS(6563),
    [aux_sym_zero_directive_token5] = ACTIONS(6563),
    [aux_sym_zero_directive_token6] = ACTIONS(6563),
    [aux_sym_zero_directive_token7] = ACTIONS(6563),
    [aux_sym_zero_directive_token8] = ACTIONS(6563),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6563),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6563),
    [anon_sym_wire] = ACTIONS(6565),
    [anon_sym_tri] = ACTIONS(6565),
    [anon_sym_tri0] = ACTIONS(6565),
    [anon_sym_tri1] = ACTIONS(6565),
    [anon_sym_wand] = ACTIONS(6565),
    [anon_sym_triand] = ACTIONS(6565),
    [anon_sym_wor] = ACTIONS(6565),
    [anon_sym_trior] = ACTIONS(6565),
    [anon_sym_trireg] = ACTIONS(6565),
    [anon_sym_uwire] = ACTIONS(6565),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6563),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6563),
    [aux_sym_begin_keywords_token1] = ACTIONS(6563),
    [anon_sym_SEMI] = ACTIONS(6563),
    [anon_sym_endmodule] = ACTIONS(6565),
    [anon_sym_extern] = ACTIONS(6565),
    [anon_sym_module] = ACTIONS(6565),
    [anon_sym_macromodule] = ACTIONS(6565),
    [anon_sym_interface] = ACTIONS(6565),
    [anon_sym_program] = ACTIONS(6565),
    [anon_sym_checker] = ACTIONS(6565),
    [anon_sym_virtual] = ACTIONS(6565),
    [anon_sym_class] = ACTIONS(6565),
    [anon_sym_package] = ACTIONS(6565),
    [anon_sym_timeunit] = ACTIONS(6565),
    [anon_sym_timeprecision] = ACTIONS(6565),
    [anon_sym_type] = ACTIONS(6565),
    [anon_sym_input] = ACTIONS(6565),
    [anon_sym_output] = ACTIONS(6565),
    [anon_sym_inout] = ACTIONS(6565),
    [anon_sym_ref] = ACTIONS(6565),
    [anon_sym_DOLLARfatal] = ACTIONS(6563),
    [anon_sym_DOLLARerror] = ACTIONS(6563),
    [anon_sym_DOLLARwarning] = ACTIONS(6563),
    [anon_sym_DOLLARinfo] = ACTIONS(6563),
    [anon_sym_default] = ACTIONS(6565),
    [anon_sym_clocking] = ACTIONS(6565),
    [anon_sym_defparam] = ACTIONS(6565),
    [anon_sym_bind] = ACTIONS(6565),
    [anon_sym_const] = ACTIONS(6565),
    [anon_sym_function] = ACTIONS(6565),
    [anon_sym_static] = ACTIONS(6565),
    [anon_sym_constraint] = ACTIONS(6565),
    [anon_sym_if] = ACTIONS(6565),
    [anon_sym_LBRACK] = ACTIONS(6563),
    [anon_sym_localparam] = ACTIONS(6565),
    [anon_sym_parameter] = ACTIONS(6565),
    [anon_sym_specparam] = ACTIONS(6565),
    [anon_sym_var] = ACTIONS(6565),
    [anon_sym_import] = ACTIONS(6565),
    [anon_sym_export] = ACTIONS(6565),
    [anon_sym_genvar] = ACTIONS(6565),
    [anon_sym_interconnect] = ACTIONS(6565),
    [anon_sym_typedef] = ACTIONS(6565),
    [anon_sym_enum] = ACTIONS(6565),
    [anon_sym_struct] = ACTIONS(6565),
    [anon_sym_union] = ACTIONS(6565),
    [anon_sym_nettype] = ACTIONS(6565),
    [anon_sym_automatic] = ACTIONS(6565),
    [anon_sym_string] = ACTIONS(6565),
    [anon_sym_chandle] = ACTIONS(6565),
    [anon_sym_event] = ACTIONS(6565),
    [anon_sym_byte] = ACTIONS(6565),
    [anon_sym_shortint] = ACTIONS(6565),
    [anon_sym_int] = ACTIONS(6565),
    [anon_sym_longint] = ACTIONS(6565),
    [anon_sym_integer] = ACTIONS(6565),
    [anon_sym_time] = ACTIONS(6565),
    [anon_sym_bit] = ACTIONS(6565),
    [anon_sym_logic] = ACTIONS(6565),
    [anon_sym_reg] = ACTIONS(6565),
    [anon_sym_shortreal] = ACTIONS(6565),
    [anon_sym_real] = ACTIONS(6565),
    [anon_sym_realtime] = ACTIONS(6565),
    [anon_sym_supply0] = ACTIONS(6565),
    [anon_sym_supply1] = ACTIONS(6565),
    [anon_sym_signed] = ACTIONS(6565),
    [anon_sym_unsigned] = ACTIONS(6565),
    [anon_sym_task] = ACTIONS(6565),
    [anon_sym_assert] = ACTIONS(6565),
    [anon_sym_property] = ACTIONS(6565),
    [anon_sym_assume] = ACTIONS(6565),
    [anon_sym_cover] = ACTIONS(6565),
    [anon_sym_sequence] = ACTIONS(6565),
    [anon_sym_restrict] = ACTIONS(6565),
    [anon_sym_not] = ACTIONS(6565),
    [anon_sym_or] = ACTIONS(6565),
    [anon_sym_and] = ACTIONS(6565),
    [anon_sym_case] = ACTIONS(6565),
    [anon_sym_always] = ACTIONS(6565),
    [anon_sym_covergroup] = ACTIONS(6565),
    [anon_sym_let] = ACTIONS(6565),
    [anon_sym_pulldown] = ACTIONS(6565),
    [anon_sym_pullup] = ACTIONS(6565),
    [anon_sym_cmos] = ACTIONS(6565),
    [anon_sym_rcmos] = ACTIONS(6565),
    [anon_sym_bufif0] = ACTIONS(6565),
    [anon_sym_bufif1] = ACTIONS(6565),
    [anon_sym_notif0] = ACTIONS(6565),
    [anon_sym_notif1] = ACTIONS(6565),
    [anon_sym_nmos] = ACTIONS(6565),
    [anon_sym_pmos] = ACTIONS(6565),
    [anon_sym_rnmos] = ACTIONS(6565),
    [anon_sym_rpmos] = ACTIONS(6565),
    [anon_sym_nand] = ACTIONS(6565),
    [anon_sym_nor] = ACTIONS(6565),
    [anon_sym_xor] = ACTIONS(6565),
    [anon_sym_xnor] = ACTIONS(6565),
    [anon_sym_buf] = ACTIONS(6565),
    [anon_sym_tranif0] = ACTIONS(6565),
    [anon_sym_tranif1] = ACTIONS(6565),
    [anon_sym_rtranif1] = ACTIONS(6565),
    [anon_sym_rtranif0] = ACTIONS(6565),
    [anon_sym_tran] = ACTIONS(6565),
    [anon_sym_rtran] = ACTIONS(6565),
    [anon_sym_generate] = ACTIONS(6565),
    [anon_sym_for] = ACTIONS(6565),
    [anon_sym_primitive] = ACTIONS(6565),
    [anon_sym_initial] = ACTIONS(6565),
    [anon_sym_assign] = ACTIONS(6565),
    [anon_sym_alias] = ACTIONS(6565),
    [anon_sym_always_comb] = ACTIONS(6565),
    [anon_sym_always_latch] = ACTIONS(6565),
    [anon_sym_always_ff] = ACTIONS(6565),
    [anon_sym_final] = ACTIONS(6565),
    [anon_sym_global] = ACTIONS(6565),
    [anon_sym_specify] = ACTIONS(6565),
    [anon_sym_LPAREN_STAR] = ACTIONS(6563),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6563),
    [anon_sym_DOLLARunit] = ACTIONS(6563),
  },
  [1199] = {
    [sym_simple_identifier] = ACTIONS(6569),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6571),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6571),
    [anon_sym_BQUOTE] = ACTIONS(6569),
    [aux_sym_id_directive_token1] = ACTIONS(6571),
    [aux_sym_id_directive_token2] = ACTIONS(6571),
    [aux_sym_id_directive_token3] = ACTIONS(6571),
    [aux_sym_id_directive_token4] = ACTIONS(6569),
    [aux_sym_zero_directive_token1] = ACTIONS(6571),
    [aux_sym_zero_directive_token2] = ACTIONS(6571),
    [aux_sym_zero_directive_token3] = ACTIONS(6571),
    [aux_sym_zero_directive_token4] = ACTIONS(6571),
    [aux_sym_zero_directive_token5] = ACTIONS(6571),
    [aux_sym_zero_directive_token6] = ACTIONS(6571),
    [aux_sym_zero_directive_token7] = ACTIONS(6571),
    [aux_sym_zero_directive_token8] = ACTIONS(6571),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6571),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6571),
    [anon_sym_wire] = ACTIONS(6569),
    [anon_sym_tri] = ACTIONS(6569),
    [anon_sym_tri0] = ACTIONS(6569),
    [anon_sym_tri1] = ACTIONS(6569),
    [anon_sym_wand] = ACTIONS(6569),
    [anon_sym_triand] = ACTIONS(6569),
    [anon_sym_wor] = ACTIONS(6569),
    [anon_sym_trior] = ACTIONS(6569),
    [anon_sym_trireg] = ACTIONS(6569),
    [anon_sym_uwire] = ACTIONS(6569),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6571),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6571),
    [aux_sym_begin_keywords_token1] = ACTIONS(6571),
    [anon_sym_SEMI] = ACTIONS(6571),
    [anon_sym_endmodule] = ACTIONS(6569),
    [anon_sym_extern] = ACTIONS(6569),
    [anon_sym_module] = ACTIONS(6569),
    [anon_sym_macromodule] = ACTIONS(6569),
    [anon_sym_endinterface] = ACTIONS(6569),
    [anon_sym_interface] = ACTIONS(6569),
    [anon_sym_endprogram] = ACTIONS(6569),
    [anon_sym_program] = ACTIONS(6569),
    [anon_sym_checker] = ACTIONS(6569),
    [anon_sym_virtual] = ACTIONS(6569),
    [anon_sym_class] = ACTIONS(6569),
    [anon_sym_timeunit] = ACTIONS(6569),
    [anon_sym_timeprecision] = ACTIONS(6569),
    [anon_sym_type] = ACTIONS(6569),
    [anon_sym_input] = ACTIONS(6569),
    [anon_sym_output] = ACTIONS(6569),
    [anon_sym_inout] = ACTIONS(6569),
    [anon_sym_ref] = ACTIONS(6569),
    [anon_sym_DOLLARfatal] = ACTIONS(6571),
    [anon_sym_DOLLARerror] = ACTIONS(6571),
    [anon_sym_DOLLARwarning] = ACTIONS(6571),
    [anon_sym_DOLLARinfo] = ACTIONS(6571),
    [anon_sym_default] = ACTIONS(6569),
    [anon_sym_clocking] = ACTIONS(6569),
    [anon_sym_defparam] = ACTIONS(6569),
    [anon_sym_bind] = ACTIONS(6569),
    [anon_sym_const] = ACTIONS(6569),
    [anon_sym_function] = ACTIONS(6569),
    [anon_sym_static] = ACTIONS(6569),
    [anon_sym_constraint] = ACTIONS(6569),
    [anon_sym_if] = ACTIONS(6569),
    [anon_sym_else] = ACTIONS(6569),
    [anon_sym_LBRACK] = ACTIONS(6571),
    [anon_sym_localparam] = ACTIONS(6569),
    [anon_sym_parameter] = ACTIONS(6569),
    [anon_sym_specparam] = ACTIONS(6569),
    [anon_sym_var] = ACTIONS(6569),
    [anon_sym_import] = ACTIONS(6569),
    [anon_sym_export] = ACTIONS(6569),
    [anon_sym_genvar] = ACTIONS(6569),
    [anon_sym_interconnect] = ACTIONS(6569),
    [anon_sym_typedef] = ACTIONS(6569),
    [anon_sym_enum] = ACTIONS(6569),
    [anon_sym_struct] = ACTIONS(6569),
    [anon_sym_union] = ACTIONS(6569),
    [anon_sym_nettype] = ACTIONS(6569),
    [anon_sym_automatic] = ACTIONS(6569),
    [anon_sym_string] = ACTIONS(6569),
    [anon_sym_chandle] = ACTIONS(6569),
    [anon_sym_event] = ACTIONS(6569),
    [anon_sym_byte] = ACTIONS(6569),
    [anon_sym_shortint] = ACTIONS(6569),
    [anon_sym_int] = ACTIONS(6569),
    [anon_sym_longint] = ACTIONS(6569),
    [anon_sym_integer] = ACTIONS(6569),
    [anon_sym_time] = ACTIONS(6569),
    [anon_sym_bit] = ACTIONS(6569),
    [anon_sym_logic] = ACTIONS(6569),
    [anon_sym_reg] = ACTIONS(6569),
    [anon_sym_shortreal] = ACTIONS(6569),
    [anon_sym_real] = ACTIONS(6569),
    [anon_sym_realtime] = ACTIONS(6569),
    [anon_sym_supply0] = ACTIONS(6569),
    [anon_sym_supply1] = ACTIONS(6569),
    [anon_sym_signed] = ACTIONS(6569),
    [anon_sym_unsigned] = ACTIONS(6569),
    [anon_sym_task] = ACTIONS(6569),
    [anon_sym_modport] = ACTIONS(6569),
    [anon_sym_assert] = ACTIONS(6569),
    [anon_sym_property] = ACTIONS(6569),
    [anon_sym_assume] = ACTIONS(6569),
    [anon_sym_cover] = ACTIONS(6569),
    [anon_sym_sequence] = ACTIONS(6569),
    [anon_sym_restrict] = ACTIONS(6569),
    [anon_sym_not] = ACTIONS(6569),
    [anon_sym_or] = ACTIONS(6569),
    [anon_sym_and] = ACTIONS(6569),
    [anon_sym_case] = ACTIONS(6569),
    [anon_sym_always] = ACTIONS(6569),
    [anon_sym_covergroup] = ACTIONS(6569),
    [anon_sym_let] = ACTIONS(6569),
    [anon_sym_pulldown] = ACTIONS(6569),
    [anon_sym_pullup] = ACTIONS(6569),
    [anon_sym_cmos] = ACTIONS(6569),
    [anon_sym_rcmos] = ACTIONS(6569),
    [anon_sym_bufif0] = ACTIONS(6569),
    [anon_sym_bufif1] = ACTIONS(6569),
    [anon_sym_notif0] = ACTIONS(6569),
    [anon_sym_notif1] = ACTIONS(6569),
    [anon_sym_nmos] = ACTIONS(6569),
    [anon_sym_pmos] = ACTIONS(6569),
    [anon_sym_rnmos] = ACTIONS(6569),
    [anon_sym_rpmos] = ACTIONS(6569),
    [anon_sym_nand] = ACTIONS(6569),
    [anon_sym_nor] = ACTIONS(6569),
    [anon_sym_xor] = ACTIONS(6569),
    [anon_sym_xnor] = ACTIONS(6569),
    [anon_sym_buf] = ACTIONS(6569),
    [anon_sym_tranif0] = ACTIONS(6569),
    [anon_sym_tranif1] = ACTIONS(6569),
    [anon_sym_rtranif1] = ACTIONS(6569),
    [anon_sym_rtranif0] = ACTIONS(6569),
    [anon_sym_tran] = ACTIONS(6569),
    [anon_sym_rtran] = ACTIONS(6569),
    [anon_sym_generate] = ACTIONS(6569),
    [anon_sym_for] = ACTIONS(6569),
    [anon_sym_initial] = ACTIONS(6569),
    [anon_sym_assign] = ACTIONS(6569),
    [anon_sym_alias] = ACTIONS(6569),
    [anon_sym_always_comb] = ACTIONS(6569),
    [anon_sym_always_latch] = ACTIONS(6569),
    [anon_sym_always_ff] = ACTIONS(6569),
    [anon_sym_final] = ACTIONS(6569),
    [anon_sym_global] = ACTIONS(6569),
    [anon_sym_specify] = ACTIONS(6569),
    [anon_sym_LPAREN_STAR] = ACTIONS(6571),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6571),
    [anon_sym_DOLLARunit] = ACTIONS(6571),
  },
  [1200] = {
    [sym_simple_identifier] = ACTIONS(6573),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6575),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6575),
    [anon_sym_BQUOTE] = ACTIONS(6573),
    [aux_sym_id_directive_token1] = ACTIONS(6575),
    [aux_sym_id_directive_token2] = ACTIONS(6575),
    [aux_sym_id_directive_token3] = ACTIONS(6575),
    [aux_sym_id_directive_token4] = ACTIONS(6573),
    [aux_sym_zero_directive_token1] = ACTIONS(6575),
    [aux_sym_zero_directive_token2] = ACTIONS(6575),
    [aux_sym_zero_directive_token3] = ACTIONS(6575),
    [aux_sym_zero_directive_token4] = ACTIONS(6575),
    [aux_sym_zero_directive_token5] = ACTIONS(6575),
    [aux_sym_zero_directive_token6] = ACTIONS(6575),
    [aux_sym_zero_directive_token7] = ACTIONS(6575),
    [aux_sym_zero_directive_token8] = ACTIONS(6575),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6575),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6575),
    [anon_sym_wire] = ACTIONS(6573),
    [anon_sym_tri] = ACTIONS(6573),
    [anon_sym_tri0] = ACTIONS(6573),
    [anon_sym_tri1] = ACTIONS(6573),
    [anon_sym_wand] = ACTIONS(6573),
    [anon_sym_triand] = ACTIONS(6573),
    [anon_sym_wor] = ACTIONS(6573),
    [anon_sym_trior] = ACTIONS(6573),
    [anon_sym_trireg] = ACTIONS(6573),
    [anon_sym_uwire] = ACTIONS(6573),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6575),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6575),
    [aux_sym_begin_keywords_token1] = ACTIONS(6575),
    [anon_sym_SEMI] = ACTIONS(6575),
    [anon_sym_endmodule] = ACTIONS(6573),
    [anon_sym_extern] = ACTIONS(6573),
    [anon_sym_module] = ACTIONS(6573),
    [anon_sym_macromodule] = ACTIONS(6573),
    [anon_sym_endinterface] = ACTIONS(6573),
    [anon_sym_interface] = ACTIONS(6573),
    [anon_sym_endprogram] = ACTIONS(6573),
    [anon_sym_program] = ACTIONS(6573),
    [anon_sym_checker] = ACTIONS(6573),
    [anon_sym_virtual] = ACTIONS(6573),
    [anon_sym_class] = ACTIONS(6573),
    [anon_sym_timeunit] = ACTIONS(6573),
    [anon_sym_timeprecision] = ACTIONS(6573),
    [anon_sym_type] = ACTIONS(6573),
    [anon_sym_input] = ACTIONS(6573),
    [anon_sym_output] = ACTIONS(6573),
    [anon_sym_inout] = ACTIONS(6573),
    [anon_sym_ref] = ACTIONS(6573),
    [anon_sym_DOLLARfatal] = ACTIONS(6575),
    [anon_sym_DOLLARerror] = ACTIONS(6575),
    [anon_sym_DOLLARwarning] = ACTIONS(6575),
    [anon_sym_DOLLARinfo] = ACTIONS(6575),
    [anon_sym_default] = ACTIONS(6573),
    [anon_sym_clocking] = ACTIONS(6573),
    [anon_sym_defparam] = ACTIONS(6573),
    [anon_sym_bind] = ACTIONS(6573),
    [anon_sym_const] = ACTIONS(6573),
    [anon_sym_function] = ACTIONS(6573),
    [anon_sym_static] = ACTIONS(6573),
    [anon_sym_constraint] = ACTIONS(6573),
    [anon_sym_if] = ACTIONS(6573),
    [anon_sym_else] = ACTIONS(6573),
    [anon_sym_LBRACK] = ACTIONS(6575),
    [anon_sym_localparam] = ACTIONS(6573),
    [anon_sym_parameter] = ACTIONS(6573),
    [anon_sym_specparam] = ACTIONS(6573),
    [anon_sym_var] = ACTIONS(6573),
    [anon_sym_import] = ACTIONS(6573),
    [anon_sym_export] = ACTIONS(6573),
    [anon_sym_genvar] = ACTIONS(6573),
    [anon_sym_interconnect] = ACTIONS(6573),
    [anon_sym_typedef] = ACTIONS(6573),
    [anon_sym_enum] = ACTIONS(6573),
    [anon_sym_struct] = ACTIONS(6573),
    [anon_sym_union] = ACTIONS(6573),
    [anon_sym_nettype] = ACTIONS(6573),
    [anon_sym_automatic] = ACTIONS(6573),
    [anon_sym_string] = ACTIONS(6573),
    [anon_sym_chandle] = ACTIONS(6573),
    [anon_sym_event] = ACTIONS(6573),
    [anon_sym_byte] = ACTIONS(6573),
    [anon_sym_shortint] = ACTIONS(6573),
    [anon_sym_int] = ACTIONS(6573),
    [anon_sym_longint] = ACTIONS(6573),
    [anon_sym_integer] = ACTIONS(6573),
    [anon_sym_time] = ACTIONS(6573),
    [anon_sym_bit] = ACTIONS(6573),
    [anon_sym_logic] = ACTIONS(6573),
    [anon_sym_reg] = ACTIONS(6573),
    [anon_sym_shortreal] = ACTIONS(6573),
    [anon_sym_real] = ACTIONS(6573),
    [anon_sym_realtime] = ACTIONS(6573),
    [anon_sym_supply0] = ACTIONS(6573),
    [anon_sym_supply1] = ACTIONS(6573),
    [anon_sym_signed] = ACTIONS(6573),
    [anon_sym_unsigned] = ACTIONS(6573),
    [anon_sym_task] = ACTIONS(6573),
    [anon_sym_modport] = ACTIONS(6573),
    [anon_sym_assert] = ACTIONS(6573),
    [anon_sym_property] = ACTIONS(6573),
    [anon_sym_assume] = ACTIONS(6573),
    [anon_sym_cover] = ACTIONS(6573),
    [anon_sym_sequence] = ACTIONS(6573),
    [anon_sym_restrict] = ACTIONS(6573),
    [anon_sym_not] = ACTIONS(6573),
    [anon_sym_or] = ACTIONS(6573),
    [anon_sym_and] = ACTIONS(6573),
    [anon_sym_case] = ACTIONS(6573),
    [anon_sym_always] = ACTIONS(6573),
    [anon_sym_covergroup] = ACTIONS(6573),
    [anon_sym_let] = ACTIONS(6573),
    [anon_sym_pulldown] = ACTIONS(6573),
    [anon_sym_pullup] = ACTIONS(6573),
    [anon_sym_cmos] = ACTIONS(6573),
    [anon_sym_rcmos] = ACTIONS(6573),
    [anon_sym_bufif0] = ACTIONS(6573),
    [anon_sym_bufif1] = ACTIONS(6573),
    [anon_sym_notif0] = ACTIONS(6573),
    [anon_sym_notif1] = ACTIONS(6573),
    [anon_sym_nmos] = ACTIONS(6573),
    [anon_sym_pmos] = ACTIONS(6573),
    [anon_sym_rnmos] = ACTIONS(6573),
    [anon_sym_rpmos] = ACTIONS(6573),
    [anon_sym_nand] = ACTIONS(6573),
    [anon_sym_nor] = ACTIONS(6573),
    [anon_sym_xor] = ACTIONS(6573),
    [anon_sym_xnor] = ACTIONS(6573),
    [anon_sym_buf] = ACTIONS(6573),
    [anon_sym_tranif0] = ACTIONS(6573),
    [anon_sym_tranif1] = ACTIONS(6573),
    [anon_sym_rtranif1] = ACTIONS(6573),
    [anon_sym_rtranif0] = ACTIONS(6573),
    [anon_sym_tran] = ACTIONS(6573),
    [anon_sym_rtran] = ACTIONS(6573),
    [anon_sym_generate] = ACTIONS(6573),
    [anon_sym_for] = ACTIONS(6573),
    [anon_sym_initial] = ACTIONS(6573),
    [anon_sym_assign] = ACTIONS(6573),
    [anon_sym_alias] = ACTIONS(6573),
    [anon_sym_always_comb] = ACTIONS(6573),
    [anon_sym_always_latch] = ACTIONS(6573),
    [anon_sym_always_ff] = ACTIONS(6573),
    [anon_sym_final] = ACTIONS(6573),
    [anon_sym_global] = ACTIONS(6573),
    [anon_sym_specify] = ACTIONS(6573),
    [anon_sym_LPAREN_STAR] = ACTIONS(6575),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6575),
    [anon_sym_DOLLARunit] = ACTIONS(6575),
  },
  [1201] = {
    [sym_simple_identifier] = ACTIONS(6577),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6579),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6579),
    [anon_sym_BQUOTE] = ACTIONS(6577),
    [aux_sym_id_directive_token1] = ACTIONS(6579),
    [aux_sym_id_directive_token2] = ACTIONS(6579),
    [aux_sym_id_directive_token3] = ACTIONS(6579),
    [aux_sym_id_directive_token4] = ACTIONS(6577),
    [aux_sym_zero_directive_token1] = ACTIONS(6579),
    [aux_sym_zero_directive_token2] = ACTIONS(6579),
    [aux_sym_zero_directive_token3] = ACTIONS(6579),
    [aux_sym_zero_directive_token4] = ACTIONS(6579),
    [aux_sym_zero_directive_token5] = ACTIONS(6579),
    [aux_sym_zero_directive_token6] = ACTIONS(6579),
    [aux_sym_zero_directive_token7] = ACTIONS(6579),
    [aux_sym_zero_directive_token8] = ACTIONS(6579),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6579),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6579),
    [anon_sym_wire] = ACTIONS(6577),
    [anon_sym_tri] = ACTIONS(6577),
    [anon_sym_tri0] = ACTIONS(6577),
    [anon_sym_tri1] = ACTIONS(6577),
    [anon_sym_wand] = ACTIONS(6577),
    [anon_sym_triand] = ACTIONS(6577),
    [anon_sym_wor] = ACTIONS(6577),
    [anon_sym_trior] = ACTIONS(6577),
    [anon_sym_trireg] = ACTIONS(6577),
    [anon_sym_uwire] = ACTIONS(6577),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6579),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6579),
    [aux_sym_begin_keywords_token1] = ACTIONS(6579),
    [anon_sym_SEMI] = ACTIONS(6579),
    [anon_sym_endmodule] = ACTIONS(6577),
    [anon_sym_extern] = ACTIONS(6577),
    [anon_sym_module] = ACTIONS(6577),
    [anon_sym_macromodule] = ACTIONS(6577),
    [anon_sym_endinterface] = ACTIONS(6577),
    [anon_sym_interface] = ACTIONS(6577),
    [anon_sym_endprogram] = ACTIONS(6577),
    [anon_sym_program] = ACTIONS(6577),
    [anon_sym_checker] = ACTIONS(6577),
    [anon_sym_virtual] = ACTIONS(6577),
    [anon_sym_class] = ACTIONS(6577),
    [anon_sym_timeunit] = ACTIONS(6577),
    [anon_sym_timeprecision] = ACTIONS(6577),
    [anon_sym_type] = ACTIONS(6577),
    [anon_sym_input] = ACTIONS(6577),
    [anon_sym_output] = ACTIONS(6577),
    [anon_sym_inout] = ACTIONS(6577),
    [anon_sym_ref] = ACTIONS(6577),
    [anon_sym_DOLLARfatal] = ACTIONS(6579),
    [anon_sym_DOLLARerror] = ACTIONS(6579),
    [anon_sym_DOLLARwarning] = ACTIONS(6579),
    [anon_sym_DOLLARinfo] = ACTIONS(6579),
    [anon_sym_default] = ACTIONS(6577),
    [anon_sym_clocking] = ACTIONS(6577),
    [anon_sym_defparam] = ACTIONS(6577),
    [anon_sym_bind] = ACTIONS(6577),
    [anon_sym_const] = ACTIONS(6577),
    [anon_sym_function] = ACTIONS(6577),
    [anon_sym_static] = ACTIONS(6577),
    [anon_sym_constraint] = ACTIONS(6577),
    [anon_sym_if] = ACTIONS(6577),
    [anon_sym_else] = ACTIONS(6577),
    [anon_sym_LBRACK] = ACTIONS(6579),
    [anon_sym_localparam] = ACTIONS(6577),
    [anon_sym_parameter] = ACTIONS(6577),
    [anon_sym_specparam] = ACTIONS(6577),
    [anon_sym_var] = ACTIONS(6577),
    [anon_sym_import] = ACTIONS(6577),
    [anon_sym_export] = ACTIONS(6577),
    [anon_sym_genvar] = ACTIONS(6577),
    [anon_sym_interconnect] = ACTIONS(6577),
    [anon_sym_typedef] = ACTIONS(6577),
    [anon_sym_enum] = ACTIONS(6577),
    [anon_sym_struct] = ACTIONS(6577),
    [anon_sym_union] = ACTIONS(6577),
    [anon_sym_nettype] = ACTIONS(6577),
    [anon_sym_automatic] = ACTIONS(6577),
    [anon_sym_string] = ACTIONS(6577),
    [anon_sym_chandle] = ACTIONS(6577),
    [anon_sym_event] = ACTIONS(6577),
    [anon_sym_byte] = ACTIONS(6577),
    [anon_sym_shortint] = ACTIONS(6577),
    [anon_sym_int] = ACTIONS(6577),
    [anon_sym_longint] = ACTIONS(6577),
    [anon_sym_integer] = ACTIONS(6577),
    [anon_sym_time] = ACTIONS(6577),
    [anon_sym_bit] = ACTIONS(6577),
    [anon_sym_logic] = ACTIONS(6577),
    [anon_sym_reg] = ACTIONS(6577),
    [anon_sym_shortreal] = ACTIONS(6577),
    [anon_sym_real] = ACTIONS(6577),
    [anon_sym_realtime] = ACTIONS(6577),
    [anon_sym_supply0] = ACTIONS(6577),
    [anon_sym_supply1] = ACTIONS(6577),
    [anon_sym_signed] = ACTIONS(6577),
    [anon_sym_unsigned] = ACTIONS(6577),
    [anon_sym_task] = ACTIONS(6577),
    [anon_sym_modport] = ACTIONS(6577),
    [anon_sym_assert] = ACTIONS(6577),
    [anon_sym_property] = ACTIONS(6577),
    [anon_sym_assume] = ACTIONS(6577),
    [anon_sym_cover] = ACTIONS(6577),
    [anon_sym_sequence] = ACTIONS(6577),
    [anon_sym_restrict] = ACTIONS(6577),
    [anon_sym_not] = ACTIONS(6577),
    [anon_sym_or] = ACTIONS(6577),
    [anon_sym_and] = ACTIONS(6577),
    [anon_sym_case] = ACTIONS(6577),
    [anon_sym_always] = ACTIONS(6577),
    [anon_sym_covergroup] = ACTIONS(6577),
    [anon_sym_let] = ACTIONS(6577),
    [anon_sym_pulldown] = ACTIONS(6577),
    [anon_sym_pullup] = ACTIONS(6577),
    [anon_sym_cmos] = ACTIONS(6577),
    [anon_sym_rcmos] = ACTIONS(6577),
    [anon_sym_bufif0] = ACTIONS(6577),
    [anon_sym_bufif1] = ACTIONS(6577),
    [anon_sym_notif0] = ACTIONS(6577),
    [anon_sym_notif1] = ACTIONS(6577),
    [anon_sym_nmos] = ACTIONS(6577),
    [anon_sym_pmos] = ACTIONS(6577),
    [anon_sym_rnmos] = ACTIONS(6577),
    [anon_sym_rpmos] = ACTIONS(6577),
    [anon_sym_nand] = ACTIONS(6577),
    [anon_sym_nor] = ACTIONS(6577),
    [anon_sym_xor] = ACTIONS(6577),
    [anon_sym_xnor] = ACTIONS(6577),
    [anon_sym_buf] = ACTIONS(6577),
    [anon_sym_tranif0] = ACTIONS(6577),
    [anon_sym_tranif1] = ACTIONS(6577),
    [anon_sym_rtranif1] = ACTIONS(6577),
    [anon_sym_rtranif0] = ACTIONS(6577),
    [anon_sym_tran] = ACTIONS(6577),
    [anon_sym_rtran] = ACTIONS(6577),
    [anon_sym_generate] = ACTIONS(6577),
    [anon_sym_for] = ACTIONS(6577),
    [anon_sym_initial] = ACTIONS(6577),
    [anon_sym_assign] = ACTIONS(6577),
    [anon_sym_alias] = ACTIONS(6577),
    [anon_sym_always_comb] = ACTIONS(6577),
    [anon_sym_always_latch] = ACTIONS(6577),
    [anon_sym_always_ff] = ACTIONS(6577),
    [anon_sym_final] = ACTIONS(6577),
    [anon_sym_global] = ACTIONS(6577),
    [anon_sym_specify] = ACTIONS(6577),
    [anon_sym_LPAREN_STAR] = ACTIONS(6579),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6579),
    [anon_sym_DOLLARunit] = ACTIONS(6579),
  },
  [1202] = {
    [sym_simple_identifier] = ACTIONS(6581),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6583),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6583),
    [anon_sym_BQUOTE] = ACTIONS(6581),
    [aux_sym_id_directive_token1] = ACTIONS(6583),
    [aux_sym_id_directive_token2] = ACTIONS(6583),
    [aux_sym_id_directive_token3] = ACTIONS(6583),
    [aux_sym_id_directive_token4] = ACTIONS(6581),
    [aux_sym_zero_directive_token1] = ACTIONS(6583),
    [aux_sym_zero_directive_token2] = ACTIONS(6583),
    [aux_sym_zero_directive_token3] = ACTIONS(6583),
    [aux_sym_zero_directive_token4] = ACTIONS(6583),
    [aux_sym_zero_directive_token5] = ACTIONS(6583),
    [aux_sym_zero_directive_token6] = ACTIONS(6583),
    [aux_sym_zero_directive_token7] = ACTIONS(6583),
    [aux_sym_zero_directive_token8] = ACTIONS(6583),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6583),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6583),
    [anon_sym_wire] = ACTIONS(6581),
    [anon_sym_tri] = ACTIONS(6581),
    [anon_sym_tri0] = ACTIONS(6581),
    [anon_sym_tri1] = ACTIONS(6581),
    [anon_sym_wand] = ACTIONS(6581),
    [anon_sym_triand] = ACTIONS(6581),
    [anon_sym_wor] = ACTIONS(6581),
    [anon_sym_trior] = ACTIONS(6581),
    [anon_sym_trireg] = ACTIONS(6581),
    [anon_sym_uwire] = ACTIONS(6581),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6583),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6583),
    [aux_sym_begin_keywords_token1] = ACTIONS(6583),
    [anon_sym_SEMI] = ACTIONS(6583),
    [anon_sym_endmodule] = ACTIONS(6581),
    [anon_sym_extern] = ACTIONS(6581),
    [anon_sym_module] = ACTIONS(6581),
    [anon_sym_macromodule] = ACTIONS(6581),
    [anon_sym_endinterface] = ACTIONS(6581),
    [anon_sym_interface] = ACTIONS(6581),
    [anon_sym_endprogram] = ACTIONS(6581),
    [anon_sym_program] = ACTIONS(6581),
    [anon_sym_checker] = ACTIONS(6581),
    [anon_sym_virtual] = ACTIONS(6581),
    [anon_sym_class] = ACTIONS(6581),
    [anon_sym_timeunit] = ACTIONS(6581),
    [anon_sym_timeprecision] = ACTIONS(6581),
    [anon_sym_type] = ACTIONS(6581),
    [anon_sym_input] = ACTIONS(6581),
    [anon_sym_output] = ACTIONS(6581),
    [anon_sym_inout] = ACTIONS(6581),
    [anon_sym_ref] = ACTIONS(6581),
    [anon_sym_DOLLARfatal] = ACTIONS(6583),
    [anon_sym_DOLLARerror] = ACTIONS(6583),
    [anon_sym_DOLLARwarning] = ACTIONS(6583),
    [anon_sym_DOLLARinfo] = ACTIONS(6583),
    [anon_sym_default] = ACTIONS(6581),
    [anon_sym_clocking] = ACTIONS(6581),
    [anon_sym_defparam] = ACTIONS(6581),
    [anon_sym_bind] = ACTIONS(6581),
    [anon_sym_const] = ACTIONS(6581),
    [anon_sym_function] = ACTIONS(6581),
    [anon_sym_static] = ACTIONS(6581),
    [anon_sym_constraint] = ACTIONS(6581),
    [anon_sym_if] = ACTIONS(6581),
    [anon_sym_else] = ACTIONS(6581),
    [anon_sym_LBRACK] = ACTIONS(6583),
    [anon_sym_localparam] = ACTIONS(6581),
    [anon_sym_parameter] = ACTIONS(6581),
    [anon_sym_specparam] = ACTIONS(6581),
    [anon_sym_var] = ACTIONS(6581),
    [anon_sym_import] = ACTIONS(6581),
    [anon_sym_export] = ACTIONS(6581),
    [anon_sym_genvar] = ACTIONS(6581),
    [anon_sym_interconnect] = ACTIONS(6581),
    [anon_sym_typedef] = ACTIONS(6581),
    [anon_sym_enum] = ACTIONS(6581),
    [anon_sym_struct] = ACTIONS(6581),
    [anon_sym_union] = ACTIONS(6581),
    [anon_sym_nettype] = ACTIONS(6581),
    [anon_sym_automatic] = ACTIONS(6581),
    [anon_sym_string] = ACTIONS(6581),
    [anon_sym_chandle] = ACTIONS(6581),
    [anon_sym_event] = ACTIONS(6581),
    [anon_sym_byte] = ACTIONS(6581),
    [anon_sym_shortint] = ACTIONS(6581),
    [anon_sym_int] = ACTIONS(6581),
    [anon_sym_longint] = ACTIONS(6581),
    [anon_sym_integer] = ACTIONS(6581),
    [anon_sym_time] = ACTIONS(6581),
    [anon_sym_bit] = ACTIONS(6581),
    [anon_sym_logic] = ACTIONS(6581),
    [anon_sym_reg] = ACTIONS(6581),
    [anon_sym_shortreal] = ACTIONS(6581),
    [anon_sym_real] = ACTIONS(6581),
    [anon_sym_realtime] = ACTIONS(6581),
    [anon_sym_supply0] = ACTIONS(6581),
    [anon_sym_supply1] = ACTIONS(6581),
    [anon_sym_signed] = ACTIONS(6581),
    [anon_sym_unsigned] = ACTIONS(6581),
    [anon_sym_task] = ACTIONS(6581),
    [anon_sym_modport] = ACTIONS(6581),
    [anon_sym_assert] = ACTIONS(6581),
    [anon_sym_property] = ACTIONS(6581),
    [anon_sym_assume] = ACTIONS(6581),
    [anon_sym_cover] = ACTIONS(6581),
    [anon_sym_sequence] = ACTIONS(6581),
    [anon_sym_restrict] = ACTIONS(6581),
    [anon_sym_not] = ACTIONS(6581),
    [anon_sym_or] = ACTIONS(6581),
    [anon_sym_and] = ACTIONS(6581),
    [anon_sym_case] = ACTIONS(6581),
    [anon_sym_always] = ACTIONS(6581),
    [anon_sym_covergroup] = ACTIONS(6581),
    [anon_sym_let] = ACTIONS(6581),
    [anon_sym_pulldown] = ACTIONS(6581),
    [anon_sym_pullup] = ACTIONS(6581),
    [anon_sym_cmos] = ACTIONS(6581),
    [anon_sym_rcmos] = ACTIONS(6581),
    [anon_sym_bufif0] = ACTIONS(6581),
    [anon_sym_bufif1] = ACTIONS(6581),
    [anon_sym_notif0] = ACTIONS(6581),
    [anon_sym_notif1] = ACTIONS(6581),
    [anon_sym_nmos] = ACTIONS(6581),
    [anon_sym_pmos] = ACTIONS(6581),
    [anon_sym_rnmos] = ACTIONS(6581),
    [anon_sym_rpmos] = ACTIONS(6581),
    [anon_sym_nand] = ACTIONS(6581),
    [anon_sym_nor] = ACTIONS(6581),
    [anon_sym_xor] = ACTIONS(6581),
    [anon_sym_xnor] = ACTIONS(6581),
    [anon_sym_buf] = ACTIONS(6581),
    [anon_sym_tranif0] = ACTIONS(6581),
    [anon_sym_tranif1] = ACTIONS(6581),
    [anon_sym_rtranif1] = ACTIONS(6581),
    [anon_sym_rtranif0] = ACTIONS(6581),
    [anon_sym_tran] = ACTIONS(6581),
    [anon_sym_rtran] = ACTIONS(6581),
    [anon_sym_generate] = ACTIONS(6581),
    [anon_sym_for] = ACTIONS(6581),
    [anon_sym_initial] = ACTIONS(6581),
    [anon_sym_assign] = ACTIONS(6581),
    [anon_sym_alias] = ACTIONS(6581),
    [anon_sym_always_comb] = ACTIONS(6581),
    [anon_sym_always_latch] = ACTIONS(6581),
    [anon_sym_always_ff] = ACTIONS(6581),
    [anon_sym_final] = ACTIONS(6581),
    [anon_sym_global] = ACTIONS(6581),
    [anon_sym_specify] = ACTIONS(6581),
    [anon_sym_LPAREN_STAR] = ACTIONS(6583),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6583),
    [anon_sym_DOLLARunit] = ACTIONS(6583),
  },
  [1203] = {
    [sym_simple_identifier] = ACTIONS(6585),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6587),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6587),
    [anon_sym_BQUOTE] = ACTIONS(6585),
    [aux_sym_id_directive_token1] = ACTIONS(6587),
    [aux_sym_id_directive_token2] = ACTIONS(6587),
    [aux_sym_id_directive_token3] = ACTIONS(6587),
    [aux_sym_id_directive_token4] = ACTIONS(6585),
    [aux_sym_zero_directive_token1] = ACTIONS(6587),
    [aux_sym_zero_directive_token2] = ACTIONS(6587),
    [aux_sym_zero_directive_token3] = ACTIONS(6587),
    [aux_sym_zero_directive_token4] = ACTIONS(6587),
    [aux_sym_zero_directive_token5] = ACTIONS(6587),
    [aux_sym_zero_directive_token6] = ACTIONS(6587),
    [aux_sym_zero_directive_token7] = ACTIONS(6587),
    [aux_sym_zero_directive_token8] = ACTIONS(6587),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6587),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6587),
    [anon_sym_wire] = ACTIONS(6585),
    [anon_sym_tri] = ACTIONS(6585),
    [anon_sym_tri0] = ACTIONS(6585),
    [anon_sym_tri1] = ACTIONS(6585),
    [anon_sym_wand] = ACTIONS(6585),
    [anon_sym_triand] = ACTIONS(6585),
    [anon_sym_wor] = ACTIONS(6585),
    [anon_sym_trior] = ACTIONS(6585),
    [anon_sym_trireg] = ACTIONS(6585),
    [anon_sym_uwire] = ACTIONS(6585),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6587),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6587),
    [aux_sym_begin_keywords_token1] = ACTIONS(6587),
    [anon_sym_SEMI] = ACTIONS(6587),
    [anon_sym_endmodule] = ACTIONS(6585),
    [anon_sym_extern] = ACTIONS(6585),
    [anon_sym_module] = ACTIONS(6585),
    [anon_sym_macromodule] = ACTIONS(6585),
    [anon_sym_endinterface] = ACTIONS(6585),
    [anon_sym_interface] = ACTIONS(6585),
    [anon_sym_endprogram] = ACTIONS(6585),
    [anon_sym_program] = ACTIONS(6585),
    [anon_sym_checker] = ACTIONS(6585),
    [anon_sym_virtual] = ACTIONS(6585),
    [anon_sym_class] = ACTIONS(6585),
    [anon_sym_timeunit] = ACTIONS(6585),
    [anon_sym_timeprecision] = ACTIONS(6585),
    [anon_sym_type] = ACTIONS(6585),
    [anon_sym_input] = ACTIONS(6585),
    [anon_sym_output] = ACTIONS(6585),
    [anon_sym_inout] = ACTIONS(6585),
    [anon_sym_ref] = ACTIONS(6585),
    [anon_sym_DOLLARfatal] = ACTIONS(6587),
    [anon_sym_DOLLARerror] = ACTIONS(6587),
    [anon_sym_DOLLARwarning] = ACTIONS(6587),
    [anon_sym_DOLLARinfo] = ACTIONS(6587),
    [anon_sym_default] = ACTIONS(6585),
    [anon_sym_clocking] = ACTIONS(6585),
    [anon_sym_defparam] = ACTIONS(6585),
    [anon_sym_bind] = ACTIONS(6585),
    [anon_sym_const] = ACTIONS(6585),
    [anon_sym_function] = ACTIONS(6585),
    [anon_sym_static] = ACTIONS(6585),
    [anon_sym_constraint] = ACTIONS(6585),
    [anon_sym_if] = ACTIONS(6585),
    [anon_sym_else] = ACTIONS(6585),
    [anon_sym_LBRACK] = ACTIONS(6587),
    [anon_sym_localparam] = ACTIONS(6585),
    [anon_sym_parameter] = ACTIONS(6585),
    [anon_sym_specparam] = ACTIONS(6585),
    [anon_sym_var] = ACTIONS(6585),
    [anon_sym_import] = ACTIONS(6585),
    [anon_sym_export] = ACTIONS(6585),
    [anon_sym_genvar] = ACTIONS(6585),
    [anon_sym_interconnect] = ACTIONS(6585),
    [anon_sym_typedef] = ACTIONS(6585),
    [anon_sym_enum] = ACTIONS(6585),
    [anon_sym_struct] = ACTIONS(6585),
    [anon_sym_union] = ACTIONS(6585),
    [anon_sym_nettype] = ACTIONS(6585),
    [anon_sym_automatic] = ACTIONS(6585),
    [anon_sym_string] = ACTIONS(6585),
    [anon_sym_chandle] = ACTIONS(6585),
    [anon_sym_event] = ACTIONS(6585),
    [anon_sym_byte] = ACTIONS(6585),
    [anon_sym_shortint] = ACTIONS(6585),
    [anon_sym_int] = ACTIONS(6585),
    [anon_sym_longint] = ACTIONS(6585),
    [anon_sym_integer] = ACTIONS(6585),
    [anon_sym_time] = ACTIONS(6585),
    [anon_sym_bit] = ACTIONS(6585),
    [anon_sym_logic] = ACTIONS(6585),
    [anon_sym_reg] = ACTIONS(6585),
    [anon_sym_shortreal] = ACTIONS(6585),
    [anon_sym_real] = ACTIONS(6585),
    [anon_sym_realtime] = ACTIONS(6585),
    [anon_sym_supply0] = ACTIONS(6585),
    [anon_sym_supply1] = ACTIONS(6585),
    [anon_sym_signed] = ACTIONS(6585),
    [anon_sym_unsigned] = ACTIONS(6585),
    [anon_sym_task] = ACTIONS(6585),
    [anon_sym_modport] = ACTIONS(6585),
    [anon_sym_assert] = ACTIONS(6585),
    [anon_sym_property] = ACTIONS(6585),
    [anon_sym_assume] = ACTIONS(6585),
    [anon_sym_cover] = ACTIONS(6585),
    [anon_sym_sequence] = ACTIONS(6585),
    [anon_sym_restrict] = ACTIONS(6585),
    [anon_sym_not] = ACTIONS(6585),
    [anon_sym_or] = ACTIONS(6585),
    [anon_sym_and] = ACTIONS(6585),
    [anon_sym_case] = ACTIONS(6585),
    [anon_sym_always] = ACTIONS(6585),
    [anon_sym_covergroup] = ACTIONS(6585),
    [anon_sym_let] = ACTIONS(6585),
    [anon_sym_pulldown] = ACTIONS(6585),
    [anon_sym_pullup] = ACTIONS(6585),
    [anon_sym_cmos] = ACTIONS(6585),
    [anon_sym_rcmos] = ACTIONS(6585),
    [anon_sym_bufif0] = ACTIONS(6585),
    [anon_sym_bufif1] = ACTIONS(6585),
    [anon_sym_notif0] = ACTIONS(6585),
    [anon_sym_notif1] = ACTIONS(6585),
    [anon_sym_nmos] = ACTIONS(6585),
    [anon_sym_pmos] = ACTIONS(6585),
    [anon_sym_rnmos] = ACTIONS(6585),
    [anon_sym_rpmos] = ACTIONS(6585),
    [anon_sym_nand] = ACTIONS(6585),
    [anon_sym_nor] = ACTIONS(6585),
    [anon_sym_xor] = ACTIONS(6585),
    [anon_sym_xnor] = ACTIONS(6585),
    [anon_sym_buf] = ACTIONS(6585),
    [anon_sym_tranif0] = ACTIONS(6585),
    [anon_sym_tranif1] = ACTIONS(6585),
    [anon_sym_rtranif1] = ACTIONS(6585),
    [anon_sym_rtranif0] = ACTIONS(6585),
    [anon_sym_tran] = ACTIONS(6585),
    [anon_sym_rtran] = ACTIONS(6585),
    [anon_sym_generate] = ACTIONS(6585),
    [anon_sym_for] = ACTIONS(6585),
    [anon_sym_initial] = ACTIONS(6585),
    [anon_sym_assign] = ACTIONS(6585),
    [anon_sym_alias] = ACTIONS(6585),
    [anon_sym_always_comb] = ACTIONS(6585),
    [anon_sym_always_latch] = ACTIONS(6585),
    [anon_sym_always_ff] = ACTIONS(6585),
    [anon_sym_final] = ACTIONS(6585),
    [anon_sym_global] = ACTIONS(6585),
    [anon_sym_specify] = ACTIONS(6585),
    [anon_sym_LPAREN_STAR] = ACTIONS(6587),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6587),
    [anon_sym_DOLLARunit] = ACTIONS(6587),
  },
  [1204] = {
    [sym_simple_identifier] = ACTIONS(6589),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6591),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6591),
    [anon_sym_BQUOTE] = ACTIONS(6589),
    [aux_sym_id_directive_token1] = ACTIONS(6591),
    [aux_sym_id_directive_token2] = ACTIONS(6591),
    [aux_sym_id_directive_token3] = ACTIONS(6591),
    [aux_sym_id_directive_token4] = ACTIONS(6589),
    [aux_sym_zero_directive_token1] = ACTIONS(6591),
    [aux_sym_zero_directive_token2] = ACTIONS(6591),
    [aux_sym_zero_directive_token3] = ACTIONS(6591),
    [aux_sym_zero_directive_token4] = ACTIONS(6591),
    [aux_sym_zero_directive_token5] = ACTIONS(6591),
    [aux_sym_zero_directive_token6] = ACTIONS(6591),
    [aux_sym_zero_directive_token7] = ACTIONS(6591),
    [aux_sym_zero_directive_token8] = ACTIONS(6591),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6591),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6591),
    [anon_sym_wire] = ACTIONS(6589),
    [anon_sym_tri] = ACTIONS(6589),
    [anon_sym_tri0] = ACTIONS(6589),
    [anon_sym_tri1] = ACTIONS(6589),
    [anon_sym_wand] = ACTIONS(6589),
    [anon_sym_triand] = ACTIONS(6589),
    [anon_sym_wor] = ACTIONS(6589),
    [anon_sym_trior] = ACTIONS(6589),
    [anon_sym_trireg] = ACTIONS(6589),
    [anon_sym_uwire] = ACTIONS(6589),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6591),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6591),
    [aux_sym_begin_keywords_token1] = ACTIONS(6591),
    [anon_sym_SEMI] = ACTIONS(6591),
    [anon_sym_endmodule] = ACTIONS(6589),
    [anon_sym_extern] = ACTIONS(6589),
    [anon_sym_module] = ACTIONS(6589),
    [anon_sym_macromodule] = ACTIONS(6589),
    [anon_sym_endinterface] = ACTIONS(6589),
    [anon_sym_interface] = ACTIONS(6589),
    [anon_sym_endprogram] = ACTIONS(6589),
    [anon_sym_program] = ACTIONS(6589),
    [anon_sym_checker] = ACTIONS(6589),
    [anon_sym_virtual] = ACTIONS(6589),
    [anon_sym_class] = ACTIONS(6589),
    [anon_sym_timeunit] = ACTIONS(6589),
    [anon_sym_timeprecision] = ACTIONS(6589),
    [anon_sym_type] = ACTIONS(6589),
    [anon_sym_input] = ACTIONS(6589),
    [anon_sym_output] = ACTIONS(6589),
    [anon_sym_inout] = ACTIONS(6589),
    [anon_sym_ref] = ACTIONS(6589),
    [anon_sym_DOLLARfatal] = ACTIONS(6591),
    [anon_sym_DOLLARerror] = ACTIONS(6591),
    [anon_sym_DOLLARwarning] = ACTIONS(6591),
    [anon_sym_DOLLARinfo] = ACTIONS(6591),
    [anon_sym_default] = ACTIONS(6589),
    [anon_sym_clocking] = ACTIONS(6589),
    [anon_sym_defparam] = ACTIONS(6589),
    [anon_sym_bind] = ACTIONS(6589),
    [anon_sym_const] = ACTIONS(6589),
    [anon_sym_function] = ACTIONS(6589),
    [anon_sym_static] = ACTIONS(6589),
    [anon_sym_constraint] = ACTIONS(6589),
    [anon_sym_if] = ACTIONS(6589),
    [anon_sym_else] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6591),
    [anon_sym_localparam] = ACTIONS(6589),
    [anon_sym_parameter] = ACTIONS(6589),
    [anon_sym_specparam] = ACTIONS(6589),
    [anon_sym_var] = ACTIONS(6589),
    [anon_sym_import] = ACTIONS(6589),
    [anon_sym_export] = ACTIONS(6589),
    [anon_sym_genvar] = ACTIONS(6589),
    [anon_sym_interconnect] = ACTIONS(6589),
    [anon_sym_typedef] = ACTIONS(6589),
    [anon_sym_enum] = ACTIONS(6589),
    [anon_sym_struct] = ACTIONS(6589),
    [anon_sym_union] = ACTIONS(6589),
    [anon_sym_nettype] = ACTIONS(6589),
    [anon_sym_automatic] = ACTIONS(6589),
    [anon_sym_string] = ACTIONS(6589),
    [anon_sym_chandle] = ACTIONS(6589),
    [anon_sym_event] = ACTIONS(6589),
    [anon_sym_byte] = ACTIONS(6589),
    [anon_sym_shortint] = ACTIONS(6589),
    [anon_sym_int] = ACTIONS(6589),
    [anon_sym_longint] = ACTIONS(6589),
    [anon_sym_integer] = ACTIONS(6589),
    [anon_sym_time] = ACTIONS(6589),
    [anon_sym_bit] = ACTIONS(6589),
    [anon_sym_logic] = ACTIONS(6589),
    [anon_sym_reg] = ACTIONS(6589),
    [anon_sym_shortreal] = ACTIONS(6589),
    [anon_sym_real] = ACTIONS(6589),
    [anon_sym_realtime] = ACTIONS(6589),
    [anon_sym_supply0] = ACTIONS(6589),
    [anon_sym_supply1] = ACTIONS(6589),
    [anon_sym_signed] = ACTIONS(6589),
    [anon_sym_unsigned] = ACTIONS(6589),
    [anon_sym_task] = ACTIONS(6589),
    [anon_sym_modport] = ACTIONS(6589),
    [anon_sym_assert] = ACTIONS(6589),
    [anon_sym_property] = ACTIONS(6589),
    [anon_sym_assume] = ACTIONS(6589),
    [anon_sym_cover] = ACTIONS(6589),
    [anon_sym_sequence] = ACTIONS(6589),
    [anon_sym_restrict] = ACTIONS(6589),
    [anon_sym_not] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_case] = ACTIONS(6589),
    [anon_sym_always] = ACTIONS(6589),
    [anon_sym_covergroup] = ACTIONS(6589),
    [anon_sym_let] = ACTIONS(6589),
    [anon_sym_pulldown] = ACTIONS(6589),
    [anon_sym_pullup] = ACTIONS(6589),
    [anon_sym_cmos] = ACTIONS(6589),
    [anon_sym_rcmos] = ACTIONS(6589),
    [anon_sym_bufif0] = ACTIONS(6589),
    [anon_sym_bufif1] = ACTIONS(6589),
    [anon_sym_notif0] = ACTIONS(6589),
    [anon_sym_notif1] = ACTIONS(6589),
    [anon_sym_nmos] = ACTIONS(6589),
    [anon_sym_pmos] = ACTIONS(6589),
    [anon_sym_rnmos] = ACTIONS(6589),
    [anon_sym_rpmos] = ACTIONS(6589),
    [anon_sym_nand] = ACTIONS(6589),
    [anon_sym_nor] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_xnor] = ACTIONS(6589),
    [anon_sym_buf] = ACTIONS(6589),
    [anon_sym_tranif0] = ACTIONS(6589),
    [anon_sym_tranif1] = ACTIONS(6589),
    [anon_sym_rtranif1] = ACTIONS(6589),
    [anon_sym_rtranif0] = ACTIONS(6589),
    [anon_sym_tran] = ACTIONS(6589),
    [anon_sym_rtran] = ACTIONS(6589),
    [anon_sym_generate] = ACTIONS(6589),
    [anon_sym_for] = ACTIONS(6589),
    [anon_sym_initial] = ACTIONS(6589),
    [anon_sym_assign] = ACTIONS(6589),
    [anon_sym_alias] = ACTIONS(6589),
    [anon_sym_always_comb] = ACTIONS(6589),
    [anon_sym_always_latch] = ACTIONS(6589),
    [anon_sym_always_ff] = ACTIONS(6589),
    [anon_sym_final] = ACTIONS(6589),
    [anon_sym_global] = ACTIONS(6589),
    [anon_sym_specify] = ACTIONS(6589),
    [anon_sym_LPAREN_STAR] = ACTIONS(6591),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6591),
    [anon_sym_DOLLARunit] = ACTIONS(6591),
  },
  [1205] = {
    [sym_simple_identifier] = ACTIONS(6593),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6595),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6595),
    [anon_sym_BQUOTE] = ACTIONS(6593),
    [aux_sym_id_directive_token1] = ACTIONS(6595),
    [aux_sym_id_directive_token2] = ACTIONS(6595),
    [aux_sym_id_directive_token3] = ACTIONS(6595),
    [aux_sym_id_directive_token4] = ACTIONS(6593),
    [aux_sym_zero_directive_token1] = ACTIONS(6595),
    [aux_sym_zero_directive_token2] = ACTIONS(6595),
    [aux_sym_zero_directive_token3] = ACTIONS(6595),
    [aux_sym_zero_directive_token4] = ACTIONS(6595),
    [aux_sym_zero_directive_token5] = ACTIONS(6595),
    [aux_sym_zero_directive_token6] = ACTIONS(6595),
    [aux_sym_zero_directive_token7] = ACTIONS(6595),
    [aux_sym_zero_directive_token8] = ACTIONS(6595),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6595),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6595),
    [anon_sym_wire] = ACTIONS(6593),
    [anon_sym_tri] = ACTIONS(6593),
    [anon_sym_tri0] = ACTIONS(6593),
    [anon_sym_tri1] = ACTIONS(6593),
    [anon_sym_wand] = ACTIONS(6593),
    [anon_sym_triand] = ACTIONS(6593),
    [anon_sym_wor] = ACTIONS(6593),
    [anon_sym_trior] = ACTIONS(6593),
    [anon_sym_trireg] = ACTIONS(6593),
    [anon_sym_uwire] = ACTIONS(6593),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6595),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6595),
    [aux_sym_begin_keywords_token1] = ACTIONS(6595),
    [anon_sym_SEMI] = ACTIONS(6595),
    [anon_sym_endmodule] = ACTIONS(6593),
    [anon_sym_extern] = ACTIONS(6593),
    [anon_sym_module] = ACTIONS(6593),
    [anon_sym_macromodule] = ACTIONS(6593),
    [anon_sym_endinterface] = ACTIONS(6593),
    [anon_sym_interface] = ACTIONS(6593),
    [anon_sym_endprogram] = ACTIONS(6593),
    [anon_sym_program] = ACTIONS(6593),
    [anon_sym_checker] = ACTIONS(6593),
    [anon_sym_virtual] = ACTIONS(6593),
    [anon_sym_class] = ACTIONS(6593),
    [anon_sym_timeunit] = ACTIONS(6593),
    [anon_sym_timeprecision] = ACTIONS(6593),
    [anon_sym_type] = ACTIONS(6593),
    [anon_sym_input] = ACTIONS(6593),
    [anon_sym_output] = ACTIONS(6593),
    [anon_sym_inout] = ACTIONS(6593),
    [anon_sym_ref] = ACTIONS(6593),
    [anon_sym_DOLLARfatal] = ACTIONS(6595),
    [anon_sym_DOLLARerror] = ACTIONS(6595),
    [anon_sym_DOLLARwarning] = ACTIONS(6595),
    [anon_sym_DOLLARinfo] = ACTIONS(6595),
    [anon_sym_default] = ACTIONS(6593),
    [anon_sym_clocking] = ACTIONS(6593),
    [anon_sym_defparam] = ACTIONS(6593),
    [anon_sym_bind] = ACTIONS(6593),
    [anon_sym_const] = ACTIONS(6593),
    [anon_sym_function] = ACTIONS(6593),
    [anon_sym_static] = ACTIONS(6593),
    [anon_sym_constraint] = ACTIONS(6593),
    [anon_sym_if] = ACTIONS(6593),
    [anon_sym_else] = ACTIONS(6593),
    [anon_sym_LBRACK] = ACTIONS(6595),
    [anon_sym_localparam] = ACTIONS(6593),
    [anon_sym_parameter] = ACTIONS(6593),
    [anon_sym_specparam] = ACTIONS(6593),
    [anon_sym_var] = ACTIONS(6593),
    [anon_sym_import] = ACTIONS(6593),
    [anon_sym_export] = ACTIONS(6593),
    [anon_sym_genvar] = ACTIONS(6593),
    [anon_sym_interconnect] = ACTIONS(6593),
    [anon_sym_typedef] = ACTIONS(6593),
    [anon_sym_enum] = ACTIONS(6593),
    [anon_sym_struct] = ACTIONS(6593),
    [anon_sym_union] = ACTIONS(6593),
    [anon_sym_nettype] = ACTIONS(6593),
    [anon_sym_automatic] = ACTIONS(6593),
    [anon_sym_string] = ACTIONS(6593),
    [anon_sym_chandle] = ACTIONS(6593),
    [anon_sym_event] = ACTIONS(6593),
    [anon_sym_byte] = ACTIONS(6593),
    [anon_sym_shortint] = ACTIONS(6593),
    [anon_sym_int] = ACTIONS(6593),
    [anon_sym_longint] = ACTIONS(6593),
    [anon_sym_integer] = ACTIONS(6593),
    [anon_sym_time] = ACTIONS(6593),
    [anon_sym_bit] = ACTIONS(6593),
    [anon_sym_logic] = ACTIONS(6593),
    [anon_sym_reg] = ACTIONS(6593),
    [anon_sym_shortreal] = ACTIONS(6593),
    [anon_sym_real] = ACTIONS(6593),
    [anon_sym_realtime] = ACTIONS(6593),
    [anon_sym_supply0] = ACTIONS(6593),
    [anon_sym_supply1] = ACTIONS(6593),
    [anon_sym_signed] = ACTIONS(6593),
    [anon_sym_unsigned] = ACTIONS(6593),
    [anon_sym_task] = ACTIONS(6593),
    [anon_sym_modport] = ACTIONS(6593),
    [anon_sym_assert] = ACTIONS(6593),
    [anon_sym_property] = ACTIONS(6593),
    [anon_sym_assume] = ACTIONS(6593),
    [anon_sym_cover] = ACTIONS(6593),
    [anon_sym_sequence] = ACTIONS(6593),
    [anon_sym_restrict] = ACTIONS(6593),
    [anon_sym_not] = ACTIONS(6593),
    [anon_sym_or] = ACTIONS(6593),
    [anon_sym_and] = ACTIONS(6593),
    [anon_sym_case] = ACTIONS(6593),
    [anon_sym_always] = ACTIONS(6593),
    [anon_sym_covergroup] = ACTIONS(6593),
    [anon_sym_let] = ACTIONS(6593),
    [anon_sym_pulldown] = ACTIONS(6593),
    [anon_sym_pullup] = ACTIONS(6593),
    [anon_sym_cmos] = ACTIONS(6593),
    [anon_sym_rcmos] = ACTIONS(6593),
    [anon_sym_bufif0] = ACTIONS(6593),
    [anon_sym_bufif1] = ACTIONS(6593),
    [anon_sym_notif0] = ACTIONS(6593),
    [anon_sym_notif1] = ACTIONS(6593),
    [anon_sym_nmos] = ACTIONS(6593),
    [anon_sym_pmos] = ACTIONS(6593),
    [anon_sym_rnmos] = ACTIONS(6593),
    [anon_sym_rpmos] = ACTIONS(6593),
    [anon_sym_nand] = ACTIONS(6593),
    [anon_sym_nor] = ACTIONS(6593),
    [anon_sym_xor] = ACTIONS(6593),
    [anon_sym_xnor] = ACTIONS(6593),
    [anon_sym_buf] = ACTIONS(6593),
    [anon_sym_tranif0] = ACTIONS(6593),
    [anon_sym_tranif1] = ACTIONS(6593),
    [anon_sym_rtranif1] = ACTIONS(6593),
    [anon_sym_rtranif0] = ACTIONS(6593),
    [anon_sym_tran] = ACTIONS(6593),
    [anon_sym_rtran] = ACTIONS(6593),
    [anon_sym_generate] = ACTIONS(6593),
    [anon_sym_for] = ACTIONS(6593),
    [anon_sym_initial] = ACTIONS(6593),
    [anon_sym_assign] = ACTIONS(6593),
    [anon_sym_alias] = ACTIONS(6593),
    [anon_sym_always_comb] = ACTIONS(6593),
    [anon_sym_always_latch] = ACTIONS(6593),
    [anon_sym_always_ff] = ACTIONS(6593),
    [anon_sym_final] = ACTIONS(6593),
    [anon_sym_global] = ACTIONS(6593),
    [anon_sym_specify] = ACTIONS(6593),
    [anon_sym_LPAREN_STAR] = ACTIONS(6595),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6595),
    [anon_sym_DOLLARunit] = ACTIONS(6595),
  },
  [1206] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6267),
    [anon_sym_BQUOTE] = ACTIONS(6265),
    [aux_sym_id_directive_token1] = ACTIONS(6267),
    [aux_sym_id_directive_token2] = ACTIONS(6267),
    [aux_sym_id_directive_token3] = ACTIONS(6267),
    [aux_sym_id_directive_token4] = ACTIONS(6265),
    [aux_sym_zero_directive_token1] = ACTIONS(6267),
    [aux_sym_zero_directive_token2] = ACTIONS(6267),
    [aux_sym_zero_directive_token3] = ACTIONS(6267),
    [aux_sym_zero_directive_token4] = ACTIONS(6267),
    [aux_sym_zero_directive_token5] = ACTIONS(6267),
    [aux_sym_zero_directive_token6] = ACTIONS(6267),
    [aux_sym_zero_directive_token7] = ACTIONS(6267),
    [aux_sym_zero_directive_token8] = ACTIONS(6267),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6267),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6267),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6267),
    [aux_sym_begin_keywords_token1] = ACTIONS(6267),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_endmodule] = ACTIONS(6265),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_module] = ACTIONS(6265),
    [anon_sym_macromodule] = ACTIONS(6265),
    [anon_sym_endinterface] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_endprogram] = ACTIONS(6265),
    [anon_sym_program] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_timeunit] = ACTIONS(6265),
    [anon_sym_timeprecision] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_input] = ACTIONS(6265),
    [anon_sym_output] = ACTIONS(6265),
    [anon_sym_inout] = ACTIONS(6265),
    [anon_sym_ref] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_specparam] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_modport] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_specify] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [1207] = {
    [sym_simple_identifier] = ACTIONS(6597),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6599),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6599),
    [anon_sym_BQUOTE] = ACTIONS(6597),
    [aux_sym_id_directive_token1] = ACTIONS(6599),
    [aux_sym_id_directive_token2] = ACTIONS(6599),
    [aux_sym_id_directive_token3] = ACTIONS(6599),
    [aux_sym_id_directive_token4] = ACTIONS(6597),
    [aux_sym_zero_directive_token1] = ACTIONS(6599),
    [aux_sym_zero_directive_token2] = ACTIONS(6599),
    [aux_sym_zero_directive_token3] = ACTIONS(6599),
    [aux_sym_zero_directive_token4] = ACTIONS(6599),
    [aux_sym_zero_directive_token5] = ACTIONS(6599),
    [aux_sym_zero_directive_token6] = ACTIONS(6599),
    [aux_sym_zero_directive_token7] = ACTIONS(6599),
    [aux_sym_zero_directive_token8] = ACTIONS(6599),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6599),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6599),
    [anon_sym_wire] = ACTIONS(6597),
    [anon_sym_tri] = ACTIONS(6597),
    [anon_sym_tri0] = ACTIONS(6597),
    [anon_sym_tri1] = ACTIONS(6597),
    [anon_sym_wand] = ACTIONS(6597),
    [anon_sym_triand] = ACTIONS(6597),
    [anon_sym_wor] = ACTIONS(6597),
    [anon_sym_trior] = ACTIONS(6597),
    [anon_sym_trireg] = ACTIONS(6597),
    [anon_sym_uwire] = ACTIONS(6597),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6599),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6599),
    [aux_sym_begin_keywords_token1] = ACTIONS(6599),
    [anon_sym_SEMI] = ACTIONS(6599),
    [anon_sym_endmodule] = ACTIONS(6597),
    [anon_sym_extern] = ACTIONS(6597),
    [anon_sym_module] = ACTIONS(6597),
    [anon_sym_macromodule] = ACTIONS(6597),
    [anon_sym_endinterface] = ACTIONS(6597),
    [anon_sym_interface] = ACTIONS(6597),
    [anon_sym_endprogram] = ACTIONS(6597),
    [anon_sym_program] = ACTIONS(6597),
    [anon_sym_checker] = ACTIONS(6597),
    [anon_sym_virtual] = ACTIONS(6597),
    [anon_sym_class] = ACTIONS(6597),
    [anon_sym_timeunit] = ACTIONS(6597),
    [anon_sym_timeprecision] = ACTIONS(6597),
    [anon_sym_type] = ACTIONS(6597),
    [anon_sym_input] = ACTIONS(6597),
    [anon_sym_output] = ACTIONS(6597),
    [anon_sym_inout] = ACTIONS(6597),
    [anon_sym_ref] = ACTIONS(6597),
    [anon_sym_DOLLARfatal] = ACTIONS(6599),
    [anon_sym_DOLLARerror] = ACTIONS(6599),
    [anon_sym_DOLLARwarning] = ACTIONS(6599),
    [anon_sym_DOLLARinfo] = ACTIONS(6599),
    [anon_sym_default] = ACTIONS(6597),
    [anon_sym_clocking] = ACTIONS(6597),
    [anon_sym_defparam] = ACTIONS(6597),
    [anon_sym_bind] = ACTIONS(6597),
    [anon_sym_const] = ACTIONS(6597),
    [anon_sym_function] = ACTIONS(6597),
    [anon_sym_static] = ACTIONS(6597),
    [anon_sym_constraint] = ACTIONS(6597),
    [anon_sym_if] = ACTIONS(6597),
    [anon_sym_else] = ACTIONS(6597),
    [anon_sym_LBRACK] = ACTIONS(6599),
    [anon_sym_localparam] = ACTIONS(6597),
    [anon_sym_parameter] = ACTIONS(6597),
    [anon_sym_specparam] = ACTIONS(6597),
    [anon_sym_var] = ACTIONS(6597),
    [anon_sym_import] = ACTIONS(6597),
    [anon_sym_export] = ACTIONS(6597),
    [anon_sym_genvar] = ACTIONS(6597),
    [anon_sym_interconnect] = ACTIONS(6597),
    [anon_sym_typedef] = ACTIONS(6597),
    [anon_sym_enum] = ACTIONS(6597),
    [anon_sym_struct] = ACTIONS(6597),
    [anon_sym_union] = ACTIONS(6597),
    [anon_sym_nettype] = ACTIONS(6597),
    [anon_sym_automatic] = ACTIONS(6597),
    [anon_sym_string] = ACTIONS(6597),
    [anon_sym_chandle] = ACTIONS(6597),
    [anon_sym_event] = ACTIONS(6597),
    [anon_sym_byte] = ACTIONS(6597),
    [anon_sym_shortint] = ACTIONS(6597),
    [anon_sym_int] = ACTIONS(6597),
    [anon_sym_longint] = ACTIONS(6597),
    [anon_sym_integer] = ACTIONS(6597),
    [anon_sym_time] = ACTIONS(6597),
    [anon_sym_bit] = ACTIONS(6597),
    [anon_sym_logic] = ACTIONS(6597),
    [anon_sym_reg] = ACTIONS(6597),
    [anon_sym_shortreal] = ACTIONS(6597),
    [anon_sym_real] = ACTIONS(6597),
    [anon_sym_realtime] = ACTIONS(6597),
    [anon_sym_supply0] = ACTIONS(6597),
    [anon_sym_supply1] = ACTIONS(6597),
    [anon_sym_signed] = ACTIONS(6597),
    [anon_sym_unsigned] = ACTIONS(6597),
    [anon_sym_task] = ACTIONS(6597),
    [anon_sym_modport] = ACTIONS(6597),
    [anon_sym_assert] = ACTIONS(6597),
    [anon_sym_property] = ACTIONS(6597),
    [anon_sym_assume] = ACTIONS(6597),
    [anon_sym_cover] = ACTIONS(6597),
    [anon_sym_sequence] = ACTIONS(6597),
    [anon_sym_restrict] = ACTIONS(6597),
    [anon_sym_not] = ACTIONS(6597),
    [anon_sym_or] = ACTIONS(6597),
    [anon_sym_and] = ACTIONS(6597),
    [anon_sym_case] = ACTIONS(6597),
    [anon_sym_always] = ACTIONS(6597),
    [anon_sym_covergroup] = ACTIONS(6597),
    [anon_sym_let] = ACTIONS(6597),
    [anon_sym_pulldown] = ACTIONS(6597),
    [anon_sym_pullup] = ACTIONS(6597),
    [anon_sym_cmos] = ACTIONS(6597),
    [anon_sym_rcmos] = ACTIONS(6597),
    [anon_sym_bufif0] = ACTIONS(6597),
    [anon_sym_bufif1] = ACTIONS(6597),
    [anon_sym_notif0] = ACTIONS(6597),
    [anon_sym_notif1] = ACTIONS(6597),
    [anon_sym_nmos] = ACTIONS(6597),
    [anon_sym_pmos] = ACTIONS(6597),
    [anon_sym_rnmos] = ACTIONS(6597),
    [anon_sym_rpmos] = ACTIONS(6597),
    [anon_sym_nand] = ACTIONS(6597),
    [anon_sym_nor] = ACTIONS(6597),
    [anon_sym_xor] = ACTIONS(6597),
    [anon_sym_xnor] = ACTIONS(6597),
    [anon_sym_buf] = ACTIONS(6597),
    [anon_sym_tranif0] = ACTIONS(6597),
    [anon_sym_tranif1] = ACTIONS(6597),
    [anon_sym_rtranif1] = ACTIONS(6597),
    [anon_sym_rtranif0] = ACTIONS(6597),
    [anon_sym_tran] = ACTIONS(6597),
    [anon_sym_rtran] = ACTIONS(6597),
    [anon_sym_generate] = ACTIONS(6597),
    [anon_sym_for] = ACTIONS(6597),
    [anon_sym_initial] = ACTIONS(6597),
    [anon_sym_assign] = ACTIONS(6597),
    [anon_sym_alias] = ACTIONS(6597),
    [anon_sym_always_comb] = ACTIONS(6597),
    [anon_sym_always_latch] = ACTIONS(6597),
    [anon_sym_always_ff] = ACTIONS(6597),
    [anon_sym_final] = ACTIONS(6597),
    [anon_sym_global] = ACTIONS(6597),
    [anon_sym_specify] = ACTIONS(6597),
    [anon_sym_LPAREN_STAR] = ACTIONS(6599),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6599),
    [anon_sym_DOLLARunit] = ACTIONS(6599),
  },
  [1208] = {
    [sym_simple_identifier] = ACTIONS(6601),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6603),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6603),
    [anon_sym_BQUOTE] = ACTIONS(6601),
    [aux_sym_id_directive_token1] = ACTIONS(6603),
    [aux_sym_id_directive_token2] = ACTIONS(6603),
    [aux_sym_id_directive_token3] = ACTIONS(6603),
    [aux_sym_id_directive_token4] = ACTIONS(6601),
    [aux_sym_zero_directive_token1] = ACTIONS(6603),
    [aux_sym_zero_directive_token2] = ACTIONS(6603),
    [aux_sym_zero_directive_token3] = ACTIONS(6603),
    [aux_sym_zero_directive_token4] = ACTIONS(6603),
    [aux_sym_zero_directive_token5] = ACTIONS(6603),
    [aux_sym_zero_directive_token6] = ACTIONS(6603),
    [aux_sym_zero_directive_token7] = ACTIONS(6603),
    [aux_sym_zero_directive_token8] = ACTIONS(6603),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6603),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6603),
    [anon_sym_wire] = ACTIONS(6601),
    [anon_sym_tri] = ACTIONS(6601),
    [anon_sym_tri0] = ACTIONS(6601),
    [anon_sym_tri1] = ACTIONS(6601),
    [anon_sym_wand] = ACTIONS(6601),
    [anon_sym_triand] = ACTIONS(6601),
    [anon_sym_wor] = ACTIONS(6601),
    [anon_sym_trior] = ACTIONS(6601),
    [anon_sym_trireg] = ACTIONS(6601),
    [anon_sym_uwire] = ACTIONS(6601),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6603),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6603),
    [aux_sym_begin_keywords_token1] = ACTIONS(6603),
    [anon_sym_SEMI] = ACTIONS(6603),
    [anon_sym_endmodule] = ACTIONS(6601),
    [anon_sym_extern] = ACTIONS(6601),
    [anon_sym_module] = ACTIONS(6601),
    [anon_sym_macromodule] = ACTIONS(6601),
    [anon_sym_endinterface] = ACTIONS(6601),
    [anon_sym_interface] = ACTIONS(6601),
    [anon_sym_endprogram] = ACTIONS(6601),
    [anon_sym_program] = ACTIONS(6601),
    [anon_sym_checker] = ACTIONS(6601),
    [anon_sym_virtual] = ACTIONS(6601),
    [anon_sym_class] = ACTIONS(6601),
    [anon_sym_timeunit] = ACTIONS(6601),
    [anon_sym_timeprecision] = ACTIONS(6601),
    [anon_sym_type] = ACTIONS(6601),
    [anon_sym_input] = ACTIONS(6601),
    [anon_sym_output] = ACTIONS(6601),
    [anon_sym_inout] = ACTIONS(6601),
    [anon_sym_ref] = ACTIONS(6601),
    [anon_sym_DOLLARfatal] = ACTIONS(6603),
    [anon_sym_DOLLARerror] = ACTIONS(6603),
    [anon_sym_DOLLARwarning] = ACTIONS(6603),
    [anon_sym_DOLLARinfo] = ACTIONS(6603),
    [anon_sym_default] = ACTIONS(6601),
    [anon_sym_clocking] = ACTIONS(6601),
    [anon_sym_defparam] = ACTIONS(6601),
    [anon_sym_bind] = ACTIONS(6601),
    [anon_sym_const] = ACTIONS(6601),
    [anon_sym_function] = ACTIONS(6601),
    [anon_sym_static] = ACTIONS(6601),
    [anon_sym_constraint] = ACTIONS(6601),
    [anon_sym_if] = ACTIONS(6601),
    [anon_sym_else] = ACTIONS(6601),
    [anon_sym_LBRACK] = ACTIONS(6603),
    [anon_sym_localparam] = ACTIONS(6601),
    [anon_sym_parameter] = ACTIONS(6601),
    [anon_sym_specparam] = ACTIONS(6601),
    [anon_sym_var] = ACTIONS(6601),
    [anon_sym_import] = ACTIONS(6601),
    [anon_sym_export] = ACTIONS(6601),
    [anon_sym_genvar] = ACTIONS(6601),
    [anon_sym_interconnect] = ACTIONS(6601),
    [anon_sym_typedef] = ACTIONS(6601),
    [anon_sym_enum] = ACTIONS(6601),
    [anon_sym_struct] = ACTIONS(6601),
    [anon_sym_union] = ACTIONS(6601),
    [anon_sym_nettype] = ACTIONS(6601),
    [anon_sym_automatic] = ACTIONS(6601),
    [anon_sym_string] = ACTIONS(6601),
    [anon_sym_chandle] = ACTIONS(6601),
    [anon_sym_event] = ACTIONS(6601),
    [anon_sym_byte] = ACTIONS(6601),
    [anon_sym_shortint] = ACTIONS(6601),
    [anon_sym_int] = ACTIONS(6601),
    [anon_sym_longint] = ACTIONS(6601),
    [anon_sym_integer] = ACTIONS(6601),
    [anon_sym_time] = ACTIONS(6601),
    [anon_sym_bit] = ACTIONS(6601),
    [anon_sym_logic] = ACTIONS(6601),
    [anon_sym_reg] = ACTIONS(6601),
    [anon_sym_shortreal] = ACTIONS(6601),
    [anon_sym_real] = ACTIONS(6601),
    [anon_sym_realtime] = ACTIONS(6601),
    [anon_sym_supply0] = ACTIONS(6601),
    [anon_sym_supply1] = ACTIONS(6601),
    [anon_sym_signed] = ACTIONS(6601),
    [anon_sym_unsigned] = ACTIONS(6601),
    [anon_sym_task] = ACTIONS(6601),
    [anon_sym_modport] = ACTIONS(6601),
    [anon_sym_assert] = ACTIONS(6601),
    [anon_sym_property] = ACTIONS(6601),
    [anon_sym_assume] = ACTIONS(6601),
    [anon_sym_cover] = ACTIONS(6601),
    [anon_sym_sequence] = ACTIONS(6601),
    [anon_sym_restrict] = ACTIONS(6601),
    [anon_sym_not] = ACTIONS(6601),
    [anon_sym_or] = ACTIONS(6601),
    [anon_sym_and] = ACTIONS(6601),
    [anon_sym_case] = ACTIONS(6601),
    [anon_sym_always] = ACTIONS(6601),
    [anon_sym_covergroup] = ACTIONS(6601),
    [anon_sym_let] = ACTIONS(6601),
    [anon_sym_pulldown] = ACTIONS(6601),
    [anon_sym_pullup] = ACTIONS(6601),
    [anon_sym_cmos] = ACTIONS(6601),
    [anon_sym_rcmos] = ACTIONS(6601),
    [anon_sym_bufif0] = ACTIONS(6601),
    [anon_sym_bufif1] = ACTIONS(6601),
    [anon_sym_notif0] = ACTIONS(6601),
    [anon_sym_notif1] = ACTIONS(6601),
    [anon_sym_nmos] = ACTIONS(6601),
    [anon_sym_pmos] = ACTIONS(6601),
    [anon_sym_rnmos] = ACTIONS(6601),
    [anon_sym_rpmos] = ACTIONS(6601),
    [anon_sym_nand] = ACTIONS(6601),
    [anon_sym_nor] = ACTIONS(6601),
    [anon_sym_xor] = ACTIONS(6601),
    [anon_sym_xnor] = ACTIONS(6601),
    [anon_sym_buf] = ACTIONS(6601),
    [anon_sym_tranif0] = ACTIONS(6601),
    [anon_sym_tranif1] = ACTIONS(6601),
    [anon_sym_rtranif1] = ACTIONS(6601),
    [anon_sym_rtranif0] = ACTIONS(6601),
    [anon_sym_tran] = ACTIONS(6601),
    [anon_sym_rtran] = ACTIONS(6601),
    [anon_sym_generate] = ACTIONS(6601),
    [anon_sym_for] = ACTIONS(6601),
    [anon_sym_initial] = ACTIONS(6601),
    [anon_sym_assign] = ACTIONS(6601),
    [anon_sym_alias] = ACTIONS(6601),
    [anon_sym_always_comb] = ACTIONS(6601),
    [anon_sym_always_latch] = ACTIONS(6601),
    [anon_sym_always_ff] = ACTIONS(6601),
    [anon_sym_final] = ACTIONS(6601),
    [anon_sym_global] = ACTIONS(6601),
    [anon_sym_specify] = ACTIONS(6601),
    [anon_sym_LPAREN_STAR] = ACTIONS(6603),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6603),
    [anon_sym_DOLLARunit] = ACTIONS(6603),
  },
  [1209] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6075),
    [anon_sym_BQUOTE] = ACTIONS(6073),
    [aux_sym_id_directive_token1] = ACTIONS(6075),
    [aux_sym_id_directive_token2] = ACTIONS(6075),
    [aux_sym_id_directive_token3] = ACTIONS(6075),
    [aux_sym_id_directive_token4] = ACTIONS(6073),
    [aux_sym_zero_directive_token1] = ACTIONS(6075),
    [aux_sym_zero_directive_token2] = ACTIONS(6075),
    [aux_sym_zero_directive_token3] = ACTIONS(6075),
    [aux_sym_zero_directive_token4] = ACTIONS(6075),
    [aux_sym_zero_directive_token5] = ACTIONS(6075),
    [aux_sym_zero_directive_token6] = ACTIONS(6075),
    [aux_sym_zero_directive_token7] = ACTIONS(6075),
    [aux_sym_zero_directive_token8] = ACTIONS(6075),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6075),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6075),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6075),
    [aux_sym_begin_keywords_token1] = ACTIONS(6075),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_endmodule] = ACTIONS(6073),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_module] = ACTIONS(6073),
    [anon_sym_macromodule] = ACTIONS(6073),
    [anon_sym_endinterface] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_endprogram] = ACTIONS(6073),
    [anon_sym_program] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_timeunit] = ACTIONS(6073),
    [anon_sym_timeprecision] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_input] = ACTIONS(6073),
    [anon_sym_output] = ACTIONS(6073),
    [anon_sym_inout] = ACTIONS(6073),
    [anon_sym_ref] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_specparam] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_modport] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_specify] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [1210] = {
    [sym_simple_identifier] = ACTIONS(6605),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6607),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6607),
    [anon_sym_BQUOTE] = ACTIONS(6605),
    [aux_sym_id_directive_token1] = ACTIONS(6607),
    [aux_sym_id_directive_token2] = ACTIONS(6607),
    [aux_sym_id_directive_token3] = ACTIONS(6607),
    [aux_sym_id_directive_token4] = ACTIONS(6605),
    [aux_sym_zero_directive_token1] = ACTIONS(6607),
    [aux_sym_zero_directive_token2] = ACTIONS(6607),
    [aux_sym_zero_directive_token3] = ACTIONS(6607),
    [aux_sym_zero_directive_token4] = ACTIONS(6607),
    [aux_sym_zero_directive_token5] = ACTIONS(6607),
    [aux_sym_zero_directive_token6] = ACTIONS(6607),
    [aux_sym_zero_directive_token7] = ACTIONS(6607),
    [aux_sym_zero_directive_token8] = ACTIONS(6607),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6607),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6607),
    [anon_sym_wire] = ACTIONS(6605),
    [anon_sym_tri] = ACTIONS(6605),
    [anon_sym_tri0] = ACTIONS(6605),
    [anon_sym_tri1] = ACTIONS(6605),
    [anon_sym_wand] = ACTIONS(6605),
    [anon_sym_triand] = ACTIONS(6605),
    [anon_sym_wor] = ACTIONS(6605),
    [anon_sym_trior] = ACTIONS(6605),
    [anon_sym_trireg] = ACTIONS(6605),
    [anon_sym_uwire] = ACTIONS(6605),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6607),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6607),
    [aux_sym_begin_keywords_token1] = ACTIONS(6607),
    [anon_sym_SEMI] = ACTIONS(6607),
    [anon_sym_endmodule] = ACTIONS(6605),
    [anon_sym_extern] = ACTIONS(6605),
    [anon_sym_module] = ACTIONS(6605),
    [anon_sym_macromodule] = ACTIONS(6605),
    [anon_sym_endinterface] = ACTIONS(6605),
    [anon_sym_interface] = ACTIONS(6605),
    [anon_sym_endprogram] = ACTIONS(6605),
    [anon_sym_program] = ACTIONS(6605),
    [anon_sym_checker] = ACTIONS(6605),
    [anon_sym_virtual] = ACTIONS(6605),
    [anon_sym_class] = ACTIONS(6605),
    [anon_sym_timeunit] = ACTIONS(6605),
    [anon_sym_timeprecision] = ACTIONS(6605),
    [anon_sym_type] = ACTIONS(6605),
    [anon_sym_input] = ACTIONS(6605),
    [anon_sym_output] = ACTIONS(6605),
    [anon_sym_inout] = ACTIONS(6605),
    [anon_sym_ref] = ACTIONS(6605),
    [anon_sym_DOLLARfatal] = ACTIONS(6607),
    [anon_sym_DOLLARerror] = ACTIONS(6607),
    [anon_sym_DOLLARwarning] = ACTIONS(6607),
    [anon_sym_DOLLARinfo] = ACTIONS(6607),
    [anon_sym_default] = ACTIONS(6605),
    [anon_sym_clocking] = ACTIONS(6605),
    [anon_sym_defparam] = ACTIONS(6605),
    [anon_sym_bind] = ACTIONS(6605),
    [anon_sym_const] = ACTIONS(6605),
    [anon_sym_function] = ACTIONS(6605),
    [anon_sym_static] = ACTIONS(6605),
    [anon_sym_constraint] = ACTIONS(6605),
    [anon_sym_if] = ACTIONS(6605),
    [anon_sym_else] = ACTIONS(6605),
    [anon_sym_LBRACK] = ACTIONS(6607),
    [anon_sym_localparam] = ACTIONS(6605),
    [anon_sym_parameter] = ACTIONS(6605),
    [anon_sym_specparam] = ACTIONS(6605),
    [anon_sym_var] = ACTIONS(6605),
    [anon_sym_import] = ACTIONS(6605),
    [anon_sym_export] = ACTIONS(6605),
    [anon_sym_genvar] = ACTIONS(6605),
    [anon_sym_interconnect] = ACTIONS(6605),
    [anon_sym_typedef] = ACTIONS(6605),
    [anon_sym_enum] = ACTIONS(6605),
    [anon_sym_struct] = ACTIONS(6605),
    [anon_sym_union] = ACTIONS(6605),
    [anon_sym_nettype] = ACTIONS(6605),
    [anon_sym_automatic] = ACTIONS(6605),
    [anon_sym_string] = ACTIONS(6605),
    [anon_sym_chandle] = ACTIONS(6605),
    [anon_sym_event] = ACTIONS(6605),
    [anon_sym_byte] = ACTIONS(6605),
    [anon_sym_shortint] = ACTIONS(6605),
    [anon_sym_int] = ACTIONS(6605),
    [anon_sym_longint] = ACTIONS(6605),
    [anon_sym_integer] = ACTIONS(6605),
    [anon_sym_time] = ACTIONS(6605),
    [anon_sym_bit] = ACTIONS(6605),
    [anon_sym_logic] = ACTIONS(6605),
    [anon_sym_reg] = ACTIONS(6605),
    [anon_sym_shortreal] = ACTIONS(6605),
    [anon_sym_real] = ACTIONS(6605),
    [anon_sym_realtime] = ACTIONS(6605),
    [anon_sym_supply0] = ACTIONS(6605),
    [anon_sym_supply1] = ACTIONS(6605),
    [anon_sym_signed] = ACTIONS(6605),
    [anon_sym_unsigned] = ACTIONS(6605),
    [anon_sym_task] = ACTIONS(6605),
    [anon_sym_modport] = ACTIONS(6605),
    [anon_sym_assert] = ACTIONS(6605),
    [anon_sym_property] = ACTIONS(6605),
    [anon_sym_assume] = ACTIONS(6605),
    [anon_sym_cover] = ACTIONS(6605),
    [anon_sym_sequence] = ACTIONS(6605),
    [anon_sym_restrict] = ACTIONS(6605),
    [anon_sym_not] = ACTIONS(6605),
    [anon_sym_or] = ACTIONS(6605),
    [anon_sym_and] = ACTIONS(6605),
    [anon_sym_case] = ACTIONS(6605),
    [anon_sym_always] = ACTIONS(6605),
    [anon_sym_covergroup] = ACTIONS(6605),
    [anon_sym_let] = ACTIONS(6605),
    [anon_sym_pulldown] = ACTIONS(6605),
    [anon_sym_pullup] = ACTIONS(6605),
    [anon_sym_cmos] = ACTIONS(6605),
    [anon_sym_rcmos] = ACTIONS(6605),
    [anon_sym_bufif0] = ACTIONS(6605),
    [anon_sym_bufif1] = ACTIONS(6605),
    [anon_sym_notif0] = ACTIONS(6605),
    [anon_sym_notif1] = ACTIONS(6605),
    [anon_sym_nmos] = ACTIONS(6605),
    [anon_sym_pmos] = ACTIONS(6605),
    [anon_sym_rnmos] = ACTIONS(6605),
    [anon_sym_rpmos] = ACTIONS(6605),
    [anon_sym_nand] = ACTIONS(6605),
    [anon_sym_nor] = ACTIONS(6605),
    [anon_sym_xor] = ACTIONS(6605),
    [anon_sym_xnor] = ACTIONS(6605),
    [anon_sym_buf] = ACTIONS(6605),
    [anon_sym_tranif0] = ACTIONS(6605),
    [anon_sym_tranif1] = ACTIONS(6605),
    [anon_sym_rtranif1] = ACTIONS(6605),
    [anon_sym_rtranif0] = ACTIONS(6605),
    [anon_sym_tran] = ACTIONS(6605),
    [anon_sym_rtran] = ACTIONS(6605),
    [anon_sym_generate] = ACTIONS(6605),
    [anon_sym_for] = ACTIONS(6605),
    [anon_sym_initial] = ACTIONS(6605),
    [anon_sym_assign] = ACTIONS(6605),
    [anon_sym_alias] = ACTIONS(6605),
    [anon_sym_always_comb] = ACTIONS(6605),
    [anon_sym_always_latch] = ACTIONS(6605),
    [anon_sym_always_ff] = ACTIONS(6605),
    [anon_sym_final] = ACTIONS(6605),
    [anon_sym_global] = ACTIONS(6605),
    [anon_sym_specify] = ACTIONS(6605),
    [anon_sym_LPAREN_STAR] = ACTIONS(6607),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6607),
    [anon_sym_DOLLARunit] = ACTIONS(6607),
  },
  [1211] = {
    [sym_simple_identifier] = ACTIONS(6609),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6611),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6611),
    [anon_sym_BQUOTE] = ACTIONS(6609),
    [aux_sym_id_directive_token1] = ACTIONS(6611),
    [aux_sym_id_directive_token2] = ACTIONS(6611),
    [aux_sym_id_directive_token3] = ACTIONS(6611),
    [aux_sym_id_directive_token4] = ACTIONS(6609),
    [aux_sym_zero_directive_token1] = ACTIONS(6611),
    [aux_sym_zero_directive_token2] = ACTIONS(6611),
    [aux_sym_zero_directive_token3] = ACTIONS(6611),
    [aux_sym_zero_directive_token4] = ACTIONS(6611),
    [aux_sym_zero_directive_token5] = ACTIONS(6611),
    [aux_sym_zero_directive_token6] = ACTIONS(6611),
    [aux_sym_zero_directive_token7] = ACTIONS(6611),
    [aux_sym_zero_directive_token8] = ACTIONS(6611),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6611),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6611),
    [anon_sym_wire] = ACTIONS(6609),
    [anon_sym_tri] = ACTIONS(6609),
    [anon_sym_tri0] = ACTIONS(6609),
    [anon_sym_tri1] = ACTIONS(6609),
    [anon_sym_wand] = ACTIONS(6609),
    [anon_sym_triand] = ACTIONS(6609),
    [anon_sym_wor] = ACTIONS(6609),
    [anon_sym_trior] = ACTIONS(6609),
    [anon_sym_trireg] = ACTIONS(6609),
    [anon_sym_uwire] = ACTIONS(6609),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6611),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6611),
    [aux_sym_begin_keywords_token1] = ACTIONS(6611),
    [anon_sym_SEMI] = ACTIONS(6611),
    [anon_sym_endmodule] = ACTIONS(6609),
    [anon_sym_extern] = ACTIONS(6609),
    [anon_sym_module] = ACTIONS(6609),
    [anon_sym_macromodule] = ACTIONS(6609),
    [anon_sym_endinterface] = ACTIONS(6609),
    [anon_sym_interface] = ACTIONS(6609),
    [anon_sym_endprogram] = ACTIONS(6609),
    [anon_sym_program] = ACTIONS(6609),
    [anon_sym_checker] = ACTIONS(6609),
    [anon_sym_virtual] = ACTIONS(6609),
    [anon_sym_class] = ACTIONS(6609),
    [anon_sym_timeunit] = ACTIONS(6609),
    [anon_sym_timeprecision] = ACTIONS(6609),
    [anon_sym_type] = ACTIONS(6609),
    [anon_sym_input] = ACTIONS(6609),
    [anon_sym_output] = ACTIONS(6609),
    [anon_sym_inout] = ACTIONS(6609),
    [anon_sym_ref] = ACTIONS(6609),
    [anon_sym_DOLLARfatal] = ACTIONS(6611),
    [anon_sym_DOLLARerror] = ACTIONS(6611),
    [anon_sym_DOLLARwarning] = ACTIONS(6611),
    [anon_sym_DOLLARinfo] = ACTIONS(6611),
    [anon_sym_default] = ACTIONS(6609),
    [anon_sym_clocking] = ACTIONS(6609),
    [anon_sym_defparam] = ACTIONS(6609),
    [anon_sym_bind] = ACTIONS(6609),
    [anon_sym_const] = ACTIONS(6609),
    [anon_sym_function] = ACTIONS(6609),
    [anon_sym_static] = ACTIONS(6609),
    [anon_sym_constraint] = ACTIONS(6609),
    [anon_sym_if] = ACTIONS(6609),
    [anon_sym_else] = ACTIONS(6609),
    [anon_sym_LBRACK] = ACTIONS(6611),
    [anon_sym_localparam] = ACTIONS(6609),
    [anon_sym_parameter] = ACTIONS(6609),
    [anon_sym_specparam] = ACTIONS(6609),
    [anon_sym_var] = ACTIONS(6609),
    [anon_sym_import] = ACTIONS(6609),
    [anon_sym_export] = ACTIONS(6609),
    [anon_sym_genvar] = ACTIONS(6609),
    [anon_sym_interconnect] = ACTIONS(6609),
    [anon_sym_typedef] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6609),
    [anon_sym_struct] = ACTIONS(6609),
    [anon_sym_union] = ACTIONS(6609),
    [anon_sym_nettype] = ACTIONS(6609),
    [anon_sym_automatic] = ACTIONS(6609),
    [anon_sym_string] = ACTIONS(6609),
    [anon_sym_chandle] = ACTIONS(6609),
    [anon_sym_event] = ACTIONS(6609),
    [anon_sym_byte] = ACTIONS(6609),
    [anon_sym_shortint] = ACTIONS(6609),
    [anon_sym_int] = ACTIONS(6609),
    [anon_sym_longint] = ACTIONS(6609),
    [anon_sym_integer] = ACTIONS(6609),
    [anon_sym_time] = ACTIONS(6609),
    [anon_sym_bit] = ACTIONS(6609),
    [anon_sym_logic] = ACTIONS(6609),
    [anon_sym_reg] = ACTIONS(6609),
    [anon_sym_shortreal] = ACTIONS(6609),
    [anon_sym_real] = ACTIONS(6609),
    [anon_sym_realtime] = ACTIONS(6609),
    [anon_sym_supply0] = ACTIONS(6609),
    [anon_sym_supply1] = ACTIONS(6609),
    [anon_sym_signed] = ACTIONS(6609),
    [anon_sym_unsigned] = ACTIONS(6609),
    [anon_sym_task] = ACTIONS(6609),
    [anon_sym_modport] = ACTIONS(6609),
    [anon_sym_assert] = ACTIONS(6609),
    [anon_sym_property] = ACTIONS(6609),
    [anon_sym_assume] = ACTIONS(6609),
    [anon_sym_cover] = ACTIONS(6609),
    [anon_sym_sequence] = ACTIONS(6609),
    [anon_sym_restrict] = ACTIONS(6609),
    [anon_sym_not] = ACTIONS(6609),
    [anon_sym_or] = ACTIONS(6609),
    [anon_sym_and] = ACTIONS(6609),
    [anon_sym_case] = ACTIONS(6609),
    [anon_sym_always] = ACTIONS(6609),
    [anon_sym_covergroup] = ACTIONS(6609),
    [anon_sym_let] = ACTIONS(6609),
    [anon_sym_pulldown] = ACTIONS(6609),
    [anon_sym_pullup] = ACTIONS(6609),
    [anon_sym_cmos] = ACTIONS(6609),
    [anon_sym_rcmos] = ACTIONS(6609),
    [anon_sym_bufif0] = ACTIONS(6609),
    [anon_sym_bufif1] = ACTIONS(6609),
    [anon_sym_notif0] = ACTIONS(6609),
    [anon_sym_notif1] = ACTIONS(6609),
    [anon_sym_nmos] = ACTIONS(6609),
    [anon_sym_pmos] = ACTIONS(6609),
    [anon_sym_rnmos] = ACTIONS(6609),
    [anon_sym_rpmos] = ACTIONS(6609),
    [anon_sym_nand] = ACTIONS(6609),
    [anon_sym_nor] = ACTIONS(6609),
    [anon_sym_xor] = ACTIONS(6609),
    [anon_sym_xnor] = ACTIONS(6609),
    [anon_sym_buf] = ACTIONS(6609),
    [anon_sym_tranif0] = ACTIONS(6609),
    [anon_sym_tranif1] = ACTIONS(6609),
    [anon_sym_rtranif1] = ACTIONS(6609),
    [anon_sym_rtranif0] = ACTIONS(6609),
    [anon_sym_tran] = ACTIONS(6609),
    [anon_sym_rtran] = ACTIONS(6609),
    [anon_sym_generate] = ACTIONS(6609),
    [anon_sym_for] = ACTIONS(6609),
    [anon_sym_initial] = ACTIONS(6609),
    [anon_sym_assign] = ACTIONS(6609),
    [anon_sym_alias] = ACTIONS(6609),
    [anon_sym_always_comb] = ACTIONS(6609),
    [anon_sym_always_latch] = ACTIONS(6609),
    [anon_sym_always_ff] = ACTIONS(6609),
    [anon_sym_final] = ACTIONS(6609),
    [anon_sym_global] = ACTIONS(6609),
    [anon_sym_specify] = ACTIONS(6609),
    [anon_sym_LPAREN_STAR] = ACTIONS(6611),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6611),
    [anon_sym_DOLLARunit] = ACTIONS(6611),
  },
  [1212] = {
    [ts_builtin_sym_end] = ACTIONS(6613),
    [sym_simple_identifier] = ACTIONS(6615),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6613),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6613),
    [anon_sym_BQUOTE] = ACTIONS(6615),
    [aux_sym_id_directive_token1] = ACTIONS(6613),
    [aux_sym_id_directive_token2] = ACTIONS(6613),
    [aux_sym_id_directive_token3] = ACTIONS(6613),
    [aux_sym_id_directive_token4] = ACTIONS(6615),
    [aux_sym_zero_directive_token1] = ACTIONS(6613),
    [aux_sym_zero_directive_token2] = ACTIONS(6613),
    [aux_sym_zero_directive_token3] = ACTIONS(6613),
    [aux_sym_zero_directive_token4] = ACTIONS(6613),
    [aux_sym_zero_directive_token5] = ACTIONS(6613),
    [aux_sym_zero_directive_token6] = ACTIONS(6613),
    [aux_sym_zero_directive_token7] = ACTIONS(6613),
    [aux_sym_zero_directive_token8] = ACTIONS(6613),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6613),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6613),
    [anon_sym_wire] = ACTIONS(6615),
    [anon_sym_tri] = ACTIONS(6615),
    [anon_sym_tri0] = ACTIONS(6615),
    [anon_sym_tri1] = ACTIONS(6615),
    [anon_sym_wand] = ACTIONS(6615),
    [anon_sym_triand] = ACTIONS(6615),
    [anon_sym_wor] = ACTIONS(6615),
    [anon_sym_trior] = ACTIONS(6615),
    [anon_sym_trireg] = ACTIONS(6615),
    [anon_sym_uwire] = ACTIONS(6615),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6613),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6613),
    [aux_sym_begin_keywords_token1] = ACTIONS(6613),
    [anon_sym_SEMI] = ACTIONS(6613),
    [anon_sym_endmodule] = ACTIONS(6615),
    [anon_sym_extern] = ACTIONS(6615),
    [anon_sym_module] = ACTIONS(6615),
    [anon_sym_macromodule] = ACTIONS(6615),
    [anon_sym_interface] = ACTIONS(6615),
    [anon_sym_program] = ACTIONS(6615),
    [anon_sym_checker] = ACTIONS(6615),
    [anon_sym_virtual] = ACTIONS(6615),
    [anon_sym_class] = ACTIONS(6615),
    [anon_sym_package] = ACTIONS(6615),
    [anon_sym_timeunit] = ACTIONS(6615),
    [anon_sym_timeprecision] = ACTIONS(6615),
    [anon_sym_type] = ACTIONS(6615),
    [anon_sym_input] = ACTIONS(6615),
    [anon_sym_output] = ACTIONS(6615),
    [anon_sym_inout] = ACTIONS(6615),
    [anon_sym_ref] = ACTIONS(6615),
    [anon_sym_DOLLARfatal] = ACTIONS(6613),
    [anon_sym_DOLLARerror] = ACTIONS(6613),
    [anon_sym_DOLLARwarning] = ACTIONS(6613),
    [anon_sym_DOLLARinfo] = ACTIONS(6613),
    [anon_sym_default] = ACTIONS(6615),
    [anon_sym_clocking] = ACTIONS(6615),
    [anon_sym_defparam] = ACTIONS(6615),
    [anon_sym_bind] = ACTIONS(6615),
    [anon_sym_const] = ACTIONS(6615),
    [anon_sym_function] = ACTIONS(6615),
    [anon_sym_static] = ACTIONS(6615),
    [anon_sym_constraint] = ACTIONS(6615),
    [anon_sym_if] = ACTIONS(6615),
    [anon_sym_LBRACK] = ACTIONS(6613),
    [anon_sym_localparam] = ACTIONS(6615),
    [anon_sym_parameter] = ACTIONS(6615),
    [anon_sym_specparam] = ACTIONS(6615),
    [anon_sym_var] = ACTIONS(6615),
    [anon_sym_import] = ACTIONS(6615),
    [anon_sym_export] = ACTIONS(6615),
    [anon_sym_genvar] = ACTIONS(6615),
    [anon_sym_interconnect] = ACTIONS(6615),
    [anon_sym_typedef] = ACTIONS(6615),
    [anon_sym_enum] = ACTIONS(6615),
    [anon_sym_struct] = ACTIONS(6615),
    [anon_sym_union] = ACTIONS(6615),
    [anon_sym_nettype] = ACTIONS(6615),
    [anon_sym_automatic] = ACTIONS(6615),
    [anon_sym_string] = ACTIONS(6615),
    [anon_sym_chandle] = ACTIONS(6615),
    [anon_sym_event] = ACTIONS(6615),
    [anon_sym_byte] = ACTIONS(6615),
    [anon_sym_shortint] = ACTIONS(6615),
    [anon_sym_int] = ACTIONS(6615),
    [anon_sym_longint] = ACTIONS(6615),
    [anon_sym_integer] = ACTIONS(6615),
    [anon_sym_time] = ACTIONS(6615),
    [anon_sym_bit] = ACTIONS(6615),
    [anon_sym_logic] = ACTIONS(6615),
    [anon_sym_reg] = ACTIONS(6615),
    [anon_sym_shortreal] = ACTIONS(6615),
    [anon_sym_real] = ACTIONS(6615),
    [anon_sym_realtime] = ACTIONS(6615),
    [anon_sym_supply0] = ACTIONS(6615),
    [anon_sym_supply1] = ACTIONS(6615),
    [anon_sym_signed] = ACTIONS(6615),
    [anon_sym_unsigned] = ACTIONS(6615),
    [anon_sym_task] = ACTIONS(6615),
    [anon_sym_assert] = ACTIONS(6615),
    [anon_sym_property] = ACTIONS(6615),
    [anon_sym_assume] = ACTIONS(6615),
    [anon_sym_cover] = ACTIONS(6615),
    [anon_sym_sequence] = ACTIONS(6615),
    [anon_sym_restrict] = ACTIONS(6615),
    [anon_sym_not] = ACTIONS(6615),
    [anon_sym_or] = ACTIONS(6615),
    [anon_sym_and] = ACTIONS(6615),
    [anon_sym_case] = ACTIONS(6615),
    [anon_sym_always] = ACTIONS(6615),
    [anon_sym_covergroup] = ACTIONS(6615),
    [anon_sym_let] = ACTIONS(6615),
    [anon_sym_pulldown] = ACTIONS(6615),
    [anon_sym_pullup] = ACTIONS(6615),
    [anon_sym_cmos] = ACTIONS(6615),
    [anon_sym_rcmos] = ACTIONS(6615),
    [anon_sym_bufif0] = ACTIONS(6615),
    [anon_sym_bufif1] = ACTIONS(6615),
    [anon_sym_notif0] = ACTIONS(6615),
    [anon_sym_notif1] = ACTIONS(6615),
    [anon_sym_nmos] = ACTIONS(6615),
    [anon_sym_pmos] = ACTIONS(6615),
    [anon_sym_rnmos] = ACTIONS(6615),
    [anon_sym_rpmos] = ACTIONS(6615),
    [anon_sym_nand] = ACTIONS(6615),
    [anon_sym_nor] = ACTIONS(6615),
    [anon_sym_xor] = ACTIONS(6615),
    [anon_sym_xnor] = ACTIONS(6615),
    [anon_sym_buf] = ACTIONS(6615),
    [anon_sym_tranif0] = ACTIONS(6615),
    [anon_sym_tranif1] = ACTIONS(6615),
    [anon_sym_rtranif1] = ACTIONS(6615),
    [anon_sym_rtranif0] = ACTIONS(6615),
    [anon_sym_tran] = ACTIONS(6615),
    [anon_sym_rtran] = ACTIONS(6615),
    [anon_sym_generate] = ACTIONS(6615),
    [anon_sym_for] = ACTIONS(6615),
    [anon_sym_primitive] = ACTIONS(6615),
    [anon_sym_initial] = ACTIONS(6615),
    [anon_sym_assign] = ACTIONS(6615),
    [anon_sym_alias] = ACTIONS(6615),
    [anon_sym_always_comb] = ACTIONS(6615),
    [anon_sym_always_latch] = ACTIONS(6615),
    [anon_sym_always_ff] = ACTIONS(6615),
    [anon_sym_final] = ACTIONS(6615),
    [anon_sym_global] = ACTIONS(6615),
    [anon_sym_specify] = ACTIONS(6615),
    [sym_unsigned_number] = ACTIONS(6613),
    [anon_sym_LPAREN_STAR] = ACTIONS(6613),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6613),
    [anon_sym_DOLLARunit] = ACTIONS(6613),
  },
  [1213] = {
    [sym_simple_identifier] = ACTIONS(6617),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6619),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6619),
    [anon_sym_BQUOTE] = ACTIONS(6617),
    [aux_sym_id_directive_token1] = ACTIONS(6619),
    [aux_sym_id_directive_token2] = ACTIONS(6619),
    [aux_sym_id_directive_token3] = ACTIONS(6619),
    [aux_sym_id_directive_token4] = ACTIONS(6617),
    [aux_sym_zero_directive_token1] = ACTIONS(6619),
    [aux_sym_zero_directive_token2] = ACTIONS(6619),
    [aux_sym_zero_directive_token3] = ACTIONS(6619),
    [aux_sym_zero_directive_token4] = ACTIONS(6619),
    [aux_sym_zero_directive_token5] = ACTIONS(6619),
    [aux_sym_zero_directive_token6] = ACTIONS(6619),
    [aux_sym_zero_directive_token7] = ACTIONS(6619),
    [aux_sym_zero_directive_token8] = ACTIONS(6619),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6619),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6619),
    [anon_sym_wire] = ACTIONS(6617),
    [anon_sym_tri] = ACTIONS(6617),
    [anon_sym_tri0] = ACTIONS(6617),
    [anon_sym_tri1] = ACTIONS(6617),
    [anon_sym_wand] = ACTIONS(6617),
    [anon_sym_triand] = ACTIONS(6617),
    [anon_sym_wor] = ACTIONS(6617),
    [anon_sym_trior] = ACTIONS(6617),
    [anon_sym_trireg] = ACTIONS(6617),
    [anon_sym_uwire] = ACTIONS(6617),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6619),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6619),
    [aux_sym_begin_keywords_token1] = ACTIONS(6619),
    [anon_sym_SEMI] = ACTIONS(6619),
    [anon_sym_endmodule] = ACTIONS(6617),
    [anon_sym_extern] = ACTIONS(6617),
    [anon_sym_module] = ACTIONS(6617),
    [anon_sym_macromodule] = ACTIONS(6617),
    [anon_sym_endinterface] = ACTIONS(6617),
    [anon_sym_interface] = ACTIONS(6617),
    [anon_sym_endprogram] = ACTIONS(6617),
    [anon_sym_program] = ACTIONS(6617),
    [anon_sym_checker] = ACTIONS(6617),
    [anon_sym_virtual] = ACTIONS(6617),
    [anon_sym_class] = ACTIONS(6617),
    [anon_sym_timeunit] = ACTIONS(6617),
    [anon_sym_timeprecision] = ACTIONS(6617),
    [anon_sym_type] = ACTIONS(6617),
    [anon_sym_input] = ACTIONS(6617),
    [anon_sym_output] = ACTIONS(6617),
    [anon_sym_inout] = ACTIONS(6617),
    [anon_sym_ref] = ACTIONS(6617),
    [anon_sym_DOLLARfatal] = ACTIONS(6619),
    [anon_sym_DOLLARerror] = ACTIONS(6619),
    [anon_sym_DOLLARwarning] = ACTIONS(6619),
    [anon_sym_DOLLARinfo] = ACTIONS(6619),
    [anon_sym_default] = ACTIONS(6617),
    [anon_sym_clocking] = ACTIONS(6617),
    [anon_sym_defparam] = ACTIONS(6617),
    [anon_sym_bind] = ACTIONS(6617),
    [anon_sym_const] = ACTIONS(6617),
    [anon_sym_function] = ACTIONS(6617),
    [anon_sym_static] = ACTIONS(6617),
    [anon_sym_constraint] = ACTIONS(6617),
    [anon_sym_if] = ACTIONS(6617),
    [anon_sym_else] = ACTIONS(6617),
    [anon_sym_LBRACK] = ACTIONS(6619),
    [anon_sym_localparam] = ACTIONS(6617),
    [anon_sym_parameter] = ACTIONS(6617),
    [anon_sym_specparam] = ACTIONS(6617),
    [anon_sym_var] = ACTIONS(6617),
    [anon_sym_import] = ACTIONS(6617),
    [anon_sym_export] = ACTIONS(6617),
    [anon_sym_genvar] = ACTIONS(6617),
    [anon_sym_interconnect] = ACTIONS(6617),
    [anon_sym_typedef] = ACTIONS(6617),
    [anon_sym_enum] = ACTIONS(6617),
    [anon_sym_struct] = ACTIONS(6617),
    [anon_sym_union] = ACTIONS(6617),
    [anon_sym_nettype] = ACTIONS(6617),
    [anon_sym_automatic] = ACTIONS(6617),
    [anon_sym_string] = ACTIONS(6617),
    [anon_sym_chandle] = ACTIONS(6617),
    [anon_sym_event] = ACTIONS(6617),
    [anon_sym_byte] = ACTIONS(6617),
    [anon_sym_shortint] = ACTIONS(6617),
    [anon_sym_int] = ACTIONS(6617),
    [anon_sym_longint] = ACTIONS(6617),
    [anon_sym_integer] = ACTIONS(6617),
    [anon_sym_time] = ACTIONS(6617),
    [anon_sym_bit] = ACTIONS(6617),
    [anon_sym_logic] = ACTIONS(6617),
    [anon_sym_reg] = ACTIONS(6617),
    [anon_sym_shortreal] = ACTIONS(6617),
    [anon_sym_real] = ACTIONS(6617),
    [anon_sym_realtime] = ACTIONS(6617),
    [anon_sym_supply0] = ACTIONS(6617),
    [anon_sym_supply1] = ACTIONS(6617),
    [anon_sym_signed] = ACTIONS(6617),
    [anon_sym_unsigned] = ACTIONS(6617),
    [anon_sym_task] = ACTIONS(6617),
    [anon_sym_modport] = ACTIONS(6617),
    [anon_sym_assert] = ACTIONS(6617),
    [anon_sym_property] = ACTIONS(6617),
    [anon_sym_assume] = ACTIONS(6617),
    [anon_sym_cover] = ACTIONS(6617),
    [anon_sym_sequence] = ACTIONS(6617),
    [anon_sym_restrict] = ACTIONS(6617),
    [anon_sym_not] = ACTIONS(6617),
    [anon_sym_or] = ACTIONS(6617),
    [anon_sym_and] = ACTIONS(6617),
    [anon_sym_case] = ACTIONS(6617),
    [anon_sym_always] = ACTIONS(6617),
    [anon_sym_covergroup] = ACTIONS(6617),
    [anon_sym_let] = ACTIONS(6617),
    [anon_sym_pulldown] = ACTIONS(6617),
    [anon_sym_pullup] = ACTIONS(6617),
    [anon_sym_cmos] = ACTIONS(6617),
    [anon_sym_rcmos] = ACTIONS(6617),
    [anon_sym_bufif0] = ACTIONS(6617),
    [anon_sym_bufif1] = ACTIONS(6617),
    [anon_sym_notif0] = ACTIONS(6617),
    [anon_sym_notif1] = ACTIONS(6617),
    [anon_sym_nmos] = ACTIONS(6617),
    [anon_sym_pmos] = ACTIONS(6617),
    [anon_sym_rnmos] = ACTIONS(6617),
    [anon_sym_rpmos] = ACTIONS(6617),
    [anon_sym_nand] = ACTIONS(6617),
    [anon_sym_nor] = ACTIONS(6617),
    [anon_sym_xor] = ACTIONS(6617),
    [anon_sym_xnor] = ACTIONS(6617),
    [anon_sym_buf] = ACTIONS(6617),
    [anon_sym_tranif0] = ACTIONS(6617),
    [anon_sym_tranif1] = ACTIONS(6617),
    [anon_sym_rtranif1] = ACTIONS(6617),
    [anon_sym_rtranif0] = ACTIONS(6617),
    [anon_sym_tran] = ACTIONS(6617),
    [anon_sym_rtran] = ACTIONS(6617),
    [anon_sym_generate] = ACTIONS(6617),
    [anon_sym_for] = ACTIONS(6617),
    [anon_sym_initial] = ACTIONS(6617),
    [anon_sym_assign] = ACTIONS(6617),
    [anon_sym_alias] = ACTIONS(6617),
    [anon_sym_always_comb] = ACTIONS(6617),
    [anon_sym_always_latch] = ACTIONS(6617),
    [anon_sym_always_ff] = ACTIONS(6617),
    [anon_sym_final] = ACTIONS(6617),
    [anon_sym_global] = ACTIONS(6617),
    [anon_sym_specify] = ACTIONS(6617),
    [anon_sym_LPAREN_STAR] = ACTIONS(6619),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6619),
    [anon_sym_DOLLARunit] = ACTIONS(6619),
  },
  [1214] = {
    [ts_builtin_sym_end] = ACTIONS(6621),
    [sym_simple_identifier] = ACTIONS(6623),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6621),
    [anon_sym_BQUOTE] = ACTIONS(6623),
    [aux_sym_id_directive_token1] = ACTIONS(6621),
    [aux_sym_id_directive_token2] = ACTIONS(6621),
    [aux_sym_id_directive_token3] = ACTIONS(6621),
    [aux_sym_id_directive_token4] = ACTIONS(6623),
    [aux_sym_zero_directive_token1] = ACTIONS(6621),
    [aux_sym_zero_directive_token2] = ACTIONS(6621),
    [aux_sym_zero_directive_token3] = ACTIONS(6621),
    [aux_sym_zero_directive_token4] = ACTIONS(6621),
    [aux_sym_zero_directive_token5] = ACTIONS(6621),
    [aux_sym_zero_directive_token6] = ACTIONS(6621),
    [aux_sym_zero_directive_token7] = ACTIONS(6621),
    [aux_sym_zero_directive_token8] = ACTIONS(6621),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6621),
    [anon_sym_wire] = ACTIONS(6623),
    [anon_sym_tri] = ACTIONS(6623),
    [anon_sym_tri0] = ACTIONS(6623),
    [anon_sym_tri1] = ACTIONS(6623),
    [anon_sym_wand] = ACTIONS(6623),
    [anon_sym_triand] = ACTIONS(6623),
    [anon_sym_wor] = ACTIONS(6623),
    [anon_sym_trior] = ACTIONS(6623),
    [anon_sym_trireg] = ACTIONS(6623),
    [anon_sym_uwire] = ACTIONS(6623),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6621),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_begin_keywords_token1] = ACTIONS(6621),
    [anon_sym_SEMI] = ACTIONS(6621),
    [anon_sym_endmodule] = ACTIONS(6623),
    [anon_sym_COLON] = ACTIONS(6625),
    [anon_sym_extern] = ACTIONS(6623),
    [anon_sym_module] = ACTIONS(6623),
    [anon_sym_macromodule] = ACTIONS(6623),
    [anon_sym_interface] = ACTIONS(6623),
    [anon_sym_program] = ACTIONS(6623),
    [anon_sym_checker] = ACTIONS(6623),
    [anon_sym_virtual] = ACTIONS(6623),
    [anon_sym_class] = ACTIONS(6623),
    [anon_sym_package] = ACTIONS(6623),
    [anon_sym_timeunit] = ACTIONS(6623),
    [anon_sym_timeprecision] = ACTIONS(6623),
    [anon_sym_type] = ACTIONS(6623),
    [anon_sym_input] = ACTIONS(6623),
    [anon_sym_output] = ACTIONS(6623),
    [anon_sym_inout] = ACTIONS(6623),
    [anon_sym_ref] = ACTIONS(6623),
    [anon_sym_DOLLARfatal] = ACTIONS(6621),
    [anon_sym_DOLLARerror] = ACTIONS(6621),
    [anon_sym_DOLLARwarning] = ACTIONS(6621),
    [anon_sym_DOLLARinfo] = ACTIONS(6621),
    [anon_sym_default] = ACTIONS(6623),
    [anon_sym_clocking] = ACTIONS(6623),
    [anon_sym_defparam] = ACTIONS(6623),
    [anon_sym_bind] = ACTIONS(6623),
    [anon_sym_const] = ACTIONS(6623),
    [anon_sym_function] = ACTIONS(6623),
    [anon_sym_static] = ACTIONS(6623),
    [anon_sym_constraint] = ACTIONS(6623),
    [anon_sym_if] = ACTIONS(6623),
    [anon_sym_LBRACK] = ACTIONS(6621),
    [anon_sym_localparam] = ACTIONS(6623),
    [anon_sym_parameter] = ACTIONS(6623),
    [anon_sym_specparam] = ACTIONS(6623),
    [anon_sym_var] = ACTIONS(6623),
    [anon_sym_import] = ACTIONS(6623),
    [anon_sym_export] = ACTIONS(6623),
    [anon_sym_genvar] = ACTIONS(6623),
    [anon_sym_interconnect] = ACTIONS(6623),
    [anon_sym_typedef] = ACTIONS(6623),
    [anon_sym_enum] = ACTIONS(6623),
    [anon_sym_struct] = ACTIONS(6623),
    [anon_sym_union] = ACTIONS(6623),
    [anon_sym_nettype] = ACTIONS(6623),
    [anon_sym_automatic] = ACTIONS(6623),
    [anon_sym_string] = ACTIONS(6623),
    [anon_sym_chandle] = ACTIONS(6623),
    [anon_sym_event] = ACTIONS(6623),
    [anon_sym_byte] = ACTIONS(6623),
    [anon_sym_shortint] = ACTIONS(6623),
    [anon_sym_int] = ACTIONS(6623),
    [anon_sym_longint] = ACTIONS(6623),
    [anon_sym_integer] = ACTIONS(6623),
    [anon_sym_time] = ACTIONS(6623),
    [anon_sym_bit] = ACTIONS(6623),
    [anon_sym_logic] = ACTIONS(6623),
    [anon_sym_reg] = ACTIONS(6623),
    [anon_sym_shortreal] = ACTIONS(6623),
    [anon_sym_real] = ACTIONS(6623),
    [anon_sym_realtime] = ACTIONS(6623),
    [anon_sym_supply0] = ACTIONS(6623),
    [anon_sym_supply1] = ACTIONS(6623),
    [anon_sym_signed] = ACTIONS(6623),
    [anon_sym_unsigned] = ACTIONS(6623),
    [anon_sym_task] = ACTIONS(6623),
    [anon_sym_assert] = ACTIONS(6623),
    [anon_sym_property] = ACTIONS(6623),
    [anon_sym_assume] = ACTIONS(6623),
    [anon_sym_cover] = ACTIONS(6623),
    [anon_sym_sequence] = ACTIONS(6623),
    [anon_sym_restrict] = ACTIONS(6623),
    [anon_sym_not] = ACTIONS(6623),
    [anon_sym_or] = ACTIONS(6623),
    [anon_sym_and] = ACTIONS(6623),
    [anon_sym_case] = ACTIONS(6623),
    [anon_sym_always] = ACTIONS(6623),
    [anon_sym_covergroup] = ACTIONS(6623),
    [anon_sym_let] = ACTIONS(6623),
    [anon_sym_pulldown] = ACTIONS(6623),
    [anon_sym_pullup] = ACTIONS(6623),
    [anon_sym_cmos] = ACTIONS(6623),
    [anon_sym_rcmos] = ACTIONS(6623),
    [anon_sym_bufif0] = ACTIONS(6623),
    [anon_sym_bufif1] = ACTIONS(6623),
    [anon_sym_notif0] = ACTIONS(6623),
    [anon_sym_notif1] = ACTIONS(6623),
    [anon_sym_nmos] = ACTIONS(6623),
    [anon_sym_pmos] = ACTIONS(6623),
    [anon_sym_rnmos] = ACTIONS(6623),
    [anon_sym_rpmos] = ACTIONS(6623),
    [anon_sym_nand] = ACTIONS(6623),
    [anon_sym_nor] = ACTIONS(6623),
    [anon_sym_xor] = ACTIONS(6623),
    [anon_sym_xnor] = ACTIONS(6623),
    [anon_sym_buf] = ACTIONS(6623),
    [anon_sym_tranif0] = ACTIONS(6623),
    [anon_sym_tranif1] = ACTIONS(6623),
    [anon_sym_rtranif1] = ACTIONS(6623),
    [anon_sym_rtranif0] = ACTIONS(6623),
    [anon_sym_tran] = ACTIONS(6623),
    [anon_sym_rtran] = ACTIONS(6623),
    [anon_sym_generate] = ACTIONS(6623),
    [anon_sym_for] = ACTIONS(6623),
    [anon_sym_primitive] = ACTIONS(6623),
    [anon_sym_initial] = ACTIONS(6623),
    [anon_sym_assign] = ACTIONS(6623),
    [anon_sym_alias] = ACTIONS(6623),
    [anon_sym_always_comb] = ACTIONS(6623),
    [anon_sym_always_latch] = ACTIONS(6623),
    [anon_sym_always_ff] = ACTIONS(6623),
    [anon_sym_final] = ACTIONS(6623),
    [anon_sym_global] = ACTIONS(6623),
    [anon_sym_specify] = ACTIONS(6623),
    [anon_sym_LPAREN_STAR] = ACTIONS(6621),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6621),
    [anon_sym_DOLLARunit] = ACTIONS(6621),
  },
  [1215] = {
    [sym_simple_identifier] = ACTIONS(6627),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6629),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6629),
    [anon_sym_BQUOTE] = ACTIONS(6627),
    [aux_sym_id_directive_token1] = ACTIONS(6629),
    [aux_sym_id_directive_token2] = ACTIONS(6629),
    [aux_sym_id_directive_token3] = ACTIONS(6629),
    [aux_sym_id_directive_token4] = ACTIONS(6627),
    [aux_sym_zero_directive_token1] = ACTIONS(6629),
    [aux_sym_zero_directive_token2] = ACTIONS(6629),
    [aux_sym_zero_directive_token3] = ACTIONS(6629),
    [aux_sym_zero_directive_token4] = ACTIONS(6629),
    [aux_sym_zero_directive_token5] = ACTIONS(6629),
    [aux_sym_zero_directive_token6] = ACTIONS(6629),
    [aux_sym_zero_directive_token7] = ACTIONS(6629),
    [aux_sym_zero_directive_token8] = ACTIONS(6629),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6629),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6629),
    [anon_sym_wire] = ACTIONS(6627),
    [anon_sym_tri] = ACTIONS(6627),
    [anon_sym_tri0] = ACTIONS(6627),
    [anon_sym_tri1] = ACTIONS(6627),
    [anon_sym_wand] = ACTIONS(6627),
    [anon_sym_triand] = ACTIONS(6627),
    [anon_sym_wor] = ACTIONS(6627),
    [anon_sym_trior] = ACTIONS(6627),
    [anon_sym_trireg] = ACTIONS(6627),
    [anon_sym_uwire] = ACTIONS(6627),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6629),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6629),
    [aux_sym_begin_keywords_token1] = ACTIONS(6629),
    [anon_sym_SEMI] = ACTIONS(6629),
    [anon_sym_endmodule] = ACTIONS(6627),
    [anon_sym_extern] = ACTIONS(6627),
    [anon_sym_module] = ACTIONS(6627),
    [anon_sym_macromodule] = ACTIONS(6627),
    [anon_sym_endinterface] = ACTIONS(6627),
    [anon_sym_interface] = ACTIONS(6627),
    [anon_sym_endprogram] = ACTIONS(6627),
    [anon_sym_program] = ACTIONS(6627),
    [anon_sym_checker] = ACTIONS(6627),
    [anon_sym_virtual] = ACTIONS(6627),
    [anon_sym_class] = ACTIONS(6627),
    [anon_sym_timeunit] = ACTIONS(6627),
    [anon_sym_timeprecision] = ACTIONS(6627),
    [anon_sym_type] = ACTIONS(6627),
    [anon_sym_input] = ACTIONS(6627),
    [anon_sym_output] = ACTIONS(6627),
    [anon_sym_inout] = ACTIONS(6627),
    [anon_sym_ref] = ACTIONS(6627),
    [anon_sym_DOLLARfatal] = ACTIONS(6629),
    [anon_sym_DOLLARerror] = ACTIONS(6629),
    [anon_sym_DOLLARwarning] = ACTIONS(6629),
    [anon_sym_DOLLARinfo] = ACTIONS(6629),
    [anon_sym_default] = ACTIONS(6627),
    [anon_sym_clocking] = ACTIONS(6627),
    [anon_sym_defparam] = ACTIONS(6627),
    [anon_sym_bind] = ACTIONS(6627),
    [anon_sym_const] = ACTIONS(6627),
    [anon_sym_function] = ACTIONS(6627),
    [anon_sym_static] = ACTIONS(6627),
    [anon_sym_constraint] = ACTIONS(6627),
    [anon_sym_if] = ACTIONS(6627),
    [anon_sym_else] = ACTIONS(6627),
    [anon_sym_LBRACK] = ACTIONS(6629),
    [anon_sym_localparam] = ACTIONS(6627),
    [anon_sym_parameter] = ACTIONS(6627),
    [anon_sym_specparam] = ACTIONS(6627),
    [anon_sym_var] = ACTIONS(6627),
    [anon_sym_import] = ACTIONS(6627),
    [anon_sym_export] = ACTIONS(6627),
    [anon_sym_genvar] = ACTIONS(6627),
    [anon_sym_interconnect] = ACTIONS(6627),
    [anon_sym_typedef] = ACTIONS(6627),
    [anon_sym_enum] = ACTIONS(6627),
    [anon_sym_struct] = ACTIONS(6627),
    [anon_sym_union] = ACTIONS(6627),
    [anon_sym_nettype] = ACTIONS(6627),
    [anon_sym_automatic] = ACTIONS(6627),
    [anon_sym_string] = ACTIONS(6627),
    [anon_sym_chandle] = ACTIONS(6627),
    [anon_sym_event] = ACTIONS(6627),
    [anon_sym_byte] = ACTIONS(6627),
    [anon_sym_shortint] = ACTIONS(6627),
    [anon_sym_int] = ACTIONS(6627),
    [anon_sym_longint] = ACTIONS(6627),
    [anon_sym_integer] = ACTIONS(6627),
    [anon_sym_time] = ACTIONS(6627),
    [anon_sym_bit] = ACTIONS(6627),
    [anon_sym_logic] = ACTIONS(6627),
    [anon_sym_reg] = ACTIONS(6627),
    [anon_sym_shortreal] = ACTIONS(6627),
    [anon_sym_real] = ACTIONS(6627),
    [anon_sym_realtime] = ACTIONS(6627),
    [anon_sym_supply0] = ACTIONS(6627),
    [anon_sym_supply1] = ACTIONS(6627),
    [anon_sym_signed] = ACTIONS(6627),
    [anon_sym_unsigned] = ACTIONS(6627),
    [anon_sym_task] = ACTIONS(6627),
    [anon_sym_modport] = ACTIONS(6627),
    [anon_sym_assert] = ACTIONS(6627),
    [anon_sym_property] = ACTIONS(6627),
    [anon_sym_assume] = ACTIONS(6627),
    [anon_sym_cover] = ACTIONS(6627),
    [anon_sym_sequence] = ACTIONS(6627),
    [anon_sym_restrict] = ACTIONS(6627),
    [anon_sym_not] = ACTIONS(6627),
    [anon_sym_or] = ACTIONS(6627),
    [anon_sym_and] = ACTIONS(6627),
    [anon_sym_case] = ACTIONS(6627),
    [anon_sym_always] = ACTIONS(6627),
    [anon_sym_covergroup] = ACTIONS(6627),
    [anon_sym_let] = ACTIONS(6627),
    [anon_sym_pulldown] = ACTIONS(6627),
    [anon_sym_pullup] = ACTIONS(6627),
    [anon_sym_cmos] = ACTIONS(6627),
    [anon_sym_rcmos] = ACTIONS(6627),
    [anon_sym_bufif0] = ACTIONS(6627),
    [anon_sym_bufif1] = ACTIONS(6627),
    [anon_sym_notif0] = ACTIONS(6627),
    [anon_sym_notif1] = ACTIONS(6627),
    [anon_sym_nmos] = ACTIONS(6627),
    [anon_sym_pmos] = ACTIONS(6627),
    [anon_sym_rnmos] = ACTIONS(6627),
    [anon_sym_rpmos] = ACTIONS(6627),
    [anon_sym_nand] = ACTIONS(6627),
    [anon_sym_nor] = ACTIONS(6627),
    [anon_sym_xor] = ACTIONS(6627),
    [anon_sym_xnor] = ACTIONS(6627),
    [anon_sym_buf] = ACTIONS(6627),
    [anon_sym_tranif0] = ACTIONS(6627),
    [anon_sym_tranif1] = ACTIONS(6627),
    [anon_sym_rtranif1] = ACTIONS(6627),
    [anon_sym_rtranif0] = ACTIONS(6627),
    [anon_sym_tran] = ACTIONS(6627),
    [anon_sym_rtran] = ACTIONS(6627),
    [anon_sym_generate] = ACTIONS(6627),
    [anon_sym_for] = ACTIONS(6627),
    [anon_sym_initial] = ACTIONS(6627),
    [anon_sym_assign] = ACTIONS(6627),
    [anon_sym_alias] = ACTIONS(6627),
    [anon_sym_always_comb] = ACTIONS(6627),
    [anon_sym_always_latch] = ACTIONS(6627),
    [anon_sym_always_ff] = ACTIONS(6627),
    [anon_sym_final] = ACTIONS(6627),
    [anon_sym_global] = ACTIONS(6627),
    [anon_sym_specify] = ACTIONS(6627),
    [anon_sym_LPAREN_STAR] = ACTIONS(6629),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6629),
    [anon_sym_DOLLARunit] = ACTIONS(6629),
  },
  [1216] = {
    [ts_builtin_sym_end] = ACTIONS(6631),
    [sym_simple_identifier] = ACTIONS(6633),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6631),
    [anon_sym_BQUOTE] = ACTIONS(6633),
    [aux_sym_id_directive_token1] = ACTIONS(6631),
    [aux_sym_id_directive_token2] = ACTIONS(6631),
    [aux_sym_id_directive_token3] = ACTIONS(6631),
    [aux_sym_id_directive_token4] = ACTIONS(6633),
    [aux_sym_zero_directive_token1] = ACTIONS(6631),
    [aux_sym_zero_directive_token2] = ACTIONS(6631),
    [aux_sym_zero_directive_token3] = ACTIONS(6631),
    [aux_sym_zero_directive_token4] = ACTIONS(6631),
    [aux_sym_zero_directive_token5] = ACTIONS(6631),
    [aux_sym_zero_directive_token6] = ACTIONS(6631),
    [aux_sym_zero_directive_token7] = ACTIONS(6631),
    [aux_sym_zero_directive_token8] = ACTIONS(6631),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6631),
    [anon_sym_wire] = ACTIONS(6633),
    [anon_sym_tri] = ACTIONS(6633),
    [anon_sym_tri0] = ACTIONS(6633),
    [anon_sym_tri1] = ACTIONS(6633),
    [anon_sym_wand] = ACTIONS(6633),
    [anon_sym_triand] = ACTIONS(6633),
    [anon_sym_wor] = ACTIONS(6633),
    [anon_sym_trior] = ACTIONS(6633),
    [anon_sym_trireg] = ACTIONS(6633),
    [anon_sym_uwire] = ACTIONS(6633),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6631),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_begin_keywords_token1] = ACTIONS(6631),
    [anon_sym_SEMI] = ACTIONS(6631),
    [anon_sym_endmodule] = ACTIONS(6633),
    [anon_sym_COLON] = ACTIONS(6635),
    [anon_sym_extern] = ACTIONS(6633),
    [anon_sym_module] = ACTIONS(6633),
    [anon_sym_macromodule] = ACTIONS(6633),
    [anon_sym_interface] = ACTIONS(6633),
    [anon_sym_program] = ACTIONS(6633),
    [anon_sym_checker] = ACTIONS(6633),
    [anon_sym_virtual] = ACTIONS(6633),
    [anon_sym_class] = ACTIONS(6633),
    [anon_sym_package] = ACTIONS(6633),
    [anon_sym_timeunit] = ACTIONS(6633),
    [anon_sym_timeprecision] = ACTIONS(6633),
    [anon_sym_type] = ACTIONS(6633),
    [anon_sym_input] = ACTIONS(6633),
    [anon_sym_output] = ACTIONS(6633),
    [anon_sym_inout] = ACTIONS(6633),
    [anon_sym_ref] = ACTIONS(6633),
    [anon_sym_DOLLARfatal] = ACTIONS(6631),
    [anon_sym_DOLLARerror] = ACTIONS(6631),
    [anon_sym_DOLLARwarning] = ACTIONS(6631),
    [anon_sym_DOLLARinfo] = ACTIONS(6631),
    [anon_sym_default] = ACTIONS(6633),
    [anon_sym_clocking] = ACTIONS(6633),
    [anon_sym_defparam] = ACTIONS(6633),
    [anon_sym_bind] = ACTIONS(6633),
    [anon_sym_const] = ACTIONS(6633),
    [anon_sym_function] = ACTIONS(6633),
    [anon_sym_static] = ACTIONS(6633),
    [anon_sym_constraint] = ACTIONS(6633),
    [anon_sym_if] = ACTIONS(6633),
    [anon_sym_LBRACK] = ACTIONS(6631),
    [anon_sym_localparam] = ACTIONS(6633),
    [anon_sym_parameter] = ACTIONS(6633),
    [anon_sym_specparam] = ACTIONS(6633),
    [anon_sym_var] = ACTIONS(6633),
    [anon_sym_import] = ACTIONS(6633),
    [anon_sym_export] = ACTIONS(6633),
    [anon_sym_genvar] = ACTIONS(6633),
    [anon_sym_interconnect] = ACTIONS(6633),
    [anon_sym_typedef] = ACTIONS(6633),
    [anon_sym_enum] = ACTIONS(6633),
    [anon_sym_struct] = ACTIONS(6633),
    [anon_sym_union] = ACTIONS(6633),
    [anon_sym_nettype] = ACTIONS(6633),
    [anon_sym_automatic] = ACTIONS(6633),
    [anon_sym_string] = ACTIONS(6633),
    [anon_sym_chandle] = ACTIONS(6633),
    [anon_sym_event] = ACTIONS(6633),
    [anon_sym_byte] = ACTIONS(6633),
    [anon_sym_shortint] = ACTIONS(6633),
    [anon_sym_int] = ACTIONS(6633),
    [anon_sym_longint] = ACTIONS(6633),
    [anon_sym_integer] = ACTIONS(6633),
    [anon_sym_time] = ACTIONS(6633),
    [anon_sym_bit] = ACTIONS(6633),
    [anon_sym_logic] = ACTIONS(6633),
    [anon_sym_reg] = ACTIONS(6633),
    [anon_sym_shortreal] = ACTIONS(6633),
    [anon_sym_real] = ACTIONS(6633),
    [anon_sym_realtime] = ACTIONS(6633),
    [anon_sym_supply0] = ACTIONS(6633),
    [anon_sym_supply1] = ACTIONS(6633),
    [anon_sym_signed] = ACTIONS(6633),
    [anon_sym_unsigned] = ACTIONS(6633),
    [anon_sym_task] = ACTIONS(6633),
    [anon_sym_assert] = ACTIONS(6633),
    [anon_sym_property] = ACTIONS(6633),
    [anon_sym_assume] = ACTIONS(6633),
    [anon_sym_cover] = ACTIONS(6633),
    [anon_sym_sequence] = ACTIONS(6633),
    [anon_sym_restrict] = ACTIONS(6633),
    [anon_sym_not] = ACTIONS(6633),
    [anon_sym_or] = ACTIONS(6633),
    [anon_sym_and] = ACTIONS(6633),
    [anon_sym_case] = ACTIONS(6633),
    [anon_sym_always] = ACTIONS(6633),
    [anon_sym_covergroup] = ACTIONS(6633),
    [anon_sym_let] = ACTIONS(6633),
    [anon_sym_pulldown] = ACTIONS(6633),
    [anon_sym_pullup] = ACTIONS(6633),
    [anon_sym_cmos] = ACTIONS(6633),
    [anon_sym_rcmos] = ACTIONS(6633),
    [anon_sym_bufif0] = ACTIONS(6633),
    [anon_sym_bufif1] = ACTIONS(6633),
    [anon_sym_notif0] = ACTIONS(6633),
    [anon_sym_notif1] = ACTIONS(6633),
    [anon_sym_nmos] = ACTIONS(6633),
    [anon_sym_pmos] = ACTIONS(6633),
    [anon_sym_rnmos] = ACTIONS(6633),
    [anon_sym_rpmos] = ACTIONS(6633),
    [anon_sym_nand] = ACTIONS(6633),
    [anon_sym_nor] = ACTIONS(6633),
    [anon_sym_xor] = ACTIONS(6633),
    [anon_sym_xnor] = ACTIONS(6633),
    [anon_sym_buf] = ACTIONS(6633),
    [anon_sym_tranif0] = ACTIONS(6633),
    [anon_sym_tranif1] = ACTIONS(6633),
    [anon_sym_rtranif1] = ACTIONS(6633),
    [anon_sym_rtranif0] = ACTIONS(6633),
    [anon_sym_tran] = ACTIONS(6633),
    [anon_sym_rtran] = ACTIONS(6633),
    [anon_sym_generate] = ACTIONS(6633),
    [anon_sym_for] = ACTIONS(6633),
    [anon_sym_primitive] = ACTIONS(6633),
    [anon_sym_initial] = ACTIONS(6633),
    [anon_sym_assign] = ACTIONS(6633),
    [anon_sym_alias] = ACTIONS(6633),
    [anon_sym_always_comb] = ACTIONS(6633),
    [anon_sym_always_latch] = ACTIONS(6633),
    [anon_sym_always_ff] = ACTIONS(6633),
    [anon_sym_final] = ACTIONS(6633),
    [anon_sym_global] = ACTIONS(6633),
    [anon_sym_specify] = ACTIONS(6633),
    [anon_sym_LPAREN_STAR] = ACTIONS(6631),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6631),
    [anon_sym_DOLLARunit] = ACTIONS(6631),
  },
  [1217] = {
    [sym_simple_identifier] = ACTIONS(6637),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6639),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6639),
    [anon_sym_BQUOTE] = ACTIONS(6637),
    [aux_sym_id_directive_token1] = ACTIONS(6639),
    [aux_sym_id_directive_token2] = ACTIONS(6639),
    [aux_sym_id_directive_token3] = ACTIONS(6639),
    [aux_sym_id_directive_token4] = ACTIONS(6637),
    [aux_sym_zero_directive_token1] = ACTIONS(6639),
    [aux_sym_zero_directive_token2] = ACTIONS(6639),
    [aux_sym_zero_directive_token3] = ACTIONS(6639),
    [aux_sym_zero_directive_token4] = ACTIONS(6639),
    [aux_sym_zero_directive_token5] = ACTIONS(6639),
    [aux_sym_zero_directive_token6] = ACTIONS(6639),
    [aux_sym_zero_directive_token7] = ACTIONS(6639),
    [aux_sym_zero_directive_token8] = ACTIONS(6639),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6639),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6639),
    [anon_sym_wire] = ACTIONS(6637),
    [anon_sym_tri] = ACTIONS(6637),
    [anon_sym_tri0] = ACTIONS(6637),
    [anon_sym_tri1] = ACTIONS(6637),
    [anon_sym_wand] = ACTIONS(6637),
    [anon_sym_triand] = ACTIONS(6637),
    [anon_sym_wor] = ACTIONS(6637),
    [anon_sym_trior] = ACTIONS(6637),
    [anon_sym_trireg] = ACTIONS(6637),
    [anon_sym_uwire] = ACTIONS(6637),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6639),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6639),
    [aux_sym_begin_keywords_token1] = ACTIONS(6639),
    [anon_sym_SEMI] = ACTIONS(6639),
    [anon_sym_endmodule] = ACTIONS(6637),
    [anon_sym_extern] = ACTIONS(6637),
    [anon_sym_module] = ACTIONS(6637),
    [anon_sym_macromodule] = ACTIONS(6637),
    [anon_sym_endinterface] = ACTIONS(6637),
    [anon_sym_interface] = ACTIONS(6637),
    [anon_sym_endprogram] = ACTIONS(6637),
    [anon_sym_program] = ACTIONS(6637),
    [anon_sym_checker] = ACTIONS(6637),
    [anon_sym_virtual] = ACTIONS(6637),
    [anon_sym_class] = ACTIONS(6637),
    [anon_sym_timeunit] = ACTIONS(6637),
    [anon_sym_timeprecision] = ACTIONS(6637),
    [anon_sym_type] = ACTIONS(6637),
    [anon_sym_input] = ACTIONS(6637),
    [anon_sym_output] = ACTIONS(6637),
    [anon_sym_inout] = ACTIONS(6637),
    [anon_sym_ref] = ACTIONS(6637),
    [anon_sym_DOLLARfatal] = ACTIONS(6639),
    [anon_sym_DOLLARerror] = ACTIONS(6639),
    [anon_sym_DOLLARwarning] = ACTIONS(6639),
    [anon_sym_DOLLARinfo] = ACTIONS(6639),
    [anon_sym_default] = ACTIONS(6637),
    [anon_sym_clocking] = ACTIONS(6637),
    [anon_sym_defparam] = ACTIONS(6637),
    [anon_sym_bind] = ACTIONS(6637),
    [anon_sym_const] = ACTIONS(6637),
    [anon_sym_function] = ACTIONS(6637),
    [anon_sym_static] = ACTIONS(6637),
    [anon_sym_constraint] = ACTIONS(6637),
    [anon_sym_if] = ACTIONS(6637),
    [anon_sym_else] = ACTIONS(6637),
    [anon_sym_LBRACK] = ACTIONS(6639),
    [anon_sym_localparam] = ACTIONS(6637),
    [anon_sym_parameter] = ACTIONS(6637),
    [anon_sym_specparam] = ACTIONS(6637),
    [anon_sym_var] = ACTIONS(6637),
    [anon_sym_import] = ACTIONS(6637),
    [anon_sym_export] = ACTIONS(6637),
    [anon_sym_genvar] = ACTIONS(6637),
    [anon_sym_interconnect] = ACTIONS(6637),
    [anon_sym_typedef] = ACTIONS(6637),
    [anon_sym_enum] = ACTIONS(6637),
    [anon_sym_struct] = ACTIONS(6637),
    [anon_sym_union] = ACTIONS(6637),
    [anon_sym_nettype] = ACTIONS(6637),
    [anon_sym_automatic] = ACTIONS(6637),
    [anon_sym_string] = ACTIONS(6637),
    [anon_sym_chandle] = ACTIONS(6637),
    [anon_sym_event] = ACTIONS(6637),
    [anon_sym_byte] = ACTIONS(6637),
    [anon_sym_shortint] = ACTIONS(6637),
    [anon_sym_int] = ACTIONS(6637),
    [anon_sym_longint] = ACTIONS(6637),
    [anon_sym_integer] = ACTIONS(6637),
    [anon_sym_time] = ACTIONS(6637),
    [anon_sym_bit] = ACTIONS(6637),
    [anon_sym_logic] = ACTIONS(6637),
    [anon_sym_reg] = ACTIONS(6637),
    [anon_sym_shortreal] = ACTIONS(6637),
    [anon_sym_real] = ACTIONS(6637),
    [anon_sym_realtime] = ACTIONS(6637),
    [anon_sym_supply0] = ACTIONS(6637),
    [anon_sym_supply1] = ACTIONS(6637),
    [anon_sym_signed] = ACTIONS(6637),
    [anon_sym_unsigned] = ACTIONS(6637),
    [anon_sym_task] = ACTIONS(6637),
    [anon_sym_modport] = ACTIONS(6637),
    [anon_sym_assert] = ACTIONS(6637),
    [anon_sym_property] = ACTIONS(6637),
    [anon_sym_assume] = ACTIONS(6637),
    [anon_sym_cover] = ACTIONS(6637),
    [anon_sym_sequence] = ACTIONS(6637),
    [anon_sym_restrict] = ACTIONS(6637),
    [anon_sym_not] = ACTIONS(6637),
    [anon_sym_or] = ACTIONS(6637),
    [anon_sym_and] = ACTIONS(6637),
    [anon_sym_case] = ACTIONS(6637),
    [anon_sym_always] = ACTIONS(6637),
    [anon_sym_covergroup] = ACTIONS(6637),
    [anon_sym_let] = ACTIONS(6637),
    [anon_sym_pulldown] = ACTIONS(6637),
    [anon_sym_pullup] = ACTIONS(6637),
    [anon_sym_cmos] = ACTIONS(6637),
    [anon_sym_rcmos] = ACTIONS(6637),
    [anon_sym_bufif0] = ACTIONS(6637),
    [anon_sym_bufif1] = ACTIONS(6637),
    [anon_sym_notif0] = ACTIONS(6637),
    [anon_sym_notif1] = ACTIONS(6637),
    [anon_sym_nmos] = ACTIONS(6637),
    [anon_sym_pmos] = ACTIONS(6637),
    [anon_sym_rnmos] = ACTIONS(6637),
    [anon_sym_rpmos] = ACTIONS(6637),
    [anon_sym_nand] = ACTIONS(6637),
    [anon_sym_nor] = ACTIONS(6637),
    [anon_sym_xor] = ACTIONS(6637),
    [anon_sym_xnor] = ACTIONS(6637),
    [anon_sym_buf] = ACTIONS(6637),
    [anon_sym_tranif0] = ACTIONS(6637),
    [anon_sym_tranif1] = ACTIONS(6637),
    [anon_sym_rtranif1] = ACTIONS(6637),
    [anon_sym_rtranif0] = ACTIONS(6637),
    [anon_sym_tran] = ACTIONS(6637),
    [anon_sym_rtran] = ACTIONS(6637),
    [anon_sym_generate] = ACTIONS(6637),
    [anon_sym_for] = ACTIONS(6637),
    [anon_sym_initial] = ACTIONS(6637),
    [anon_sym_assign] = ACTIONS(6637),
    [anon_sym_alias] = ACTIONS(6637),
    [anon_sym_always_comb] = ACTIONS(6637),
    [anon_sym_always_latch] = ACTIONS(6637),
    [anon_sym_always_ff] = ACTIONS(6637),
    [anon_sym_final] = ACTIONS(6637),
    [anon_sym_global] = ACTIONS(6637),
    [anon_sym_specify] = ACTIONS(6637),
    [anon_sym_LPAREN_STAR] = ACTIONS(6639),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6639),
    [anon_sym_DOLLARunit] = ACTIONS(6639),
  },
  [1218] = {
    [sym_simple_identifier] = ACTIONS(6641),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6643),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6643),
    [anon_sym_BQUOTE] = ACTIONS(6641),
    [aux_sym_id_directive_token1] = ACTIONS(6643),
    [aux_sym_id_directive_token2] = ACTIONS(6643),
    [aux_sym_id_directive_token3] = ACTIONS(6643),
    [aux_sym_id_directive_token4] = ACTIONS(6641),
    [aux_sym_zero_directive_token1] = ACTIONS(6643),
    [aux_sym_zero_directive_token2] = ACTIONS(6643),
    [aux_sym_zero_directive_token3] = ACTIONS(6643),
    [aux_sym_zero_directive_token4] = ACTIONS(6643),
    [aux_sym_zero_directive_token5] = ACTIONS(6643),
    [aux_sym_zero_directive_token6] = ACTIONS(6643),
    [aux_sym_zero_directive_token7] = ACTIONS(6643),
    [aux_sym_zero_directive_token8] = ACTIONS(6643),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6643),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6643),
    [anon_sym_wire] = ACTIONS(6641),
    [anon_sym_tri] = ACTIONS(6641),
    [anon_sym_tri0] = ACTIONS(6641),
    [anon_sym_tri1] = ACTIONS(6641),
    [anon_sym_wand] = ACTIONS(6641),
    [anon_sym_triand] = ACTIONS(6641),
    [anon_sym_wor] = ACTIONS(6641),
    [anon_sym_trior] = ACTIONS(6641),
    [anon_sym_trireg] = ACTIONS(6641),
    [anon_sym_uwire] = ACTIONS(6641),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6643),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6643),
    [aux_sym_begin_keywords_token1] = ACTIONS(6643),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_endmodule] = ACTIONS(6641),
    [anon_sym_extern] = ACTIONS(6641),
    [anon_sym_module] = ACTIONS(6641),
    [anon_sym_macromodule] = ACTIONS(6641),
    [anon_sym_endinterface] = ACTIONS(6641),
    [anon_sym_interface] = ACTIONS(6641),
    [anon_sym_endprogram] = ACTIONS(6641),
    [anon_sym_program] = ACTIONS(6641),
    [anon_sym_checker] = ACTIONS(6641),
    [anon_sym_virtual] = ACTIONS(6641),
    [anon_sym_class] = ACTIONS(6641),
    [anon_sym_timeunit] = ACTIONS(6641),
    [anon_sym_timeprecision] = ACTIONS(6641),
    [anon_sym_type] = ACTIONS(6641),
    [anon_sym_input] = ACTIONS(6641),
    [anon_sym_output] = ACTIONS(6641),
    [anon_sym_inout] = ACTIONS(6641),
    [anon_sym_ref] = ACTIONS(6641),
    [anon_sym_DOLLARfatal] = ACTIONS(6643),
    [anon_sym_DOLLARerror] = ACTIONS(6643),
    [anon_sym_DOLLARwarning] = ACTIONS(6643),
    [anon_sym_DOLLARinfo] = ACTIONS(6643),
    [anon_sym_default] = ACTIONS(6641),
    [anon_sym_clocking] = ACTIONS(6641),
    [anon_sym_defparam] = ACTIONS(6641),
    [anon_sym_bind] = ACTIONS(6641),
    [anon_sym_const] = ACTIONS(6641),
    [anon_sym_function] = ACTIONS(6641),
    [anon_sym_static] = ACTIONS(6641),
    [anon_sym_constraint] = ACTIONS(6641),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_else] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [anon_sym_localparam] = ACTIONS(6641),
    [anon_sym_parameter] = ACTIONS(6641),
    [anon_sym_specparam] = ACTIONS(6641),
    [anon_sym_var] = ACTIONS(6641),
    [anon_sym_import] = ACTIONS(6641),
    [anon_sym_export] = ACTIONS(6641),
    [anon_sym_genvar] = ACTIONS(6641),
    [anon_sym_interconnect] = ACTIONS(6641),
    [anon_sym_typedef] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_struct] = ACTIONS(6641),
    [anon_sym_union] = ACTIONS(6641),
    [anon_sym_nettype] = ACTIONS(6641),
    [anon_sym_automatic] = ACTIONS(6641),
    [anon_sym_string] = ACTIONS(6641),
    [anon_sym_chandle] = ACTIONS(6641),
    [anon_sym_event] = ACTIONS(6641),
    [anon_sym_byte] = ACTIONS(6641),
    [anon_sym_shortint] = ACTIONS(6641),
    [anon_sym_int] = ACTIONS(6641),
    [anon_sym_longint] = ACTIONS(6641),
    [anon_sym_integer] = ACTIONS(6641),
    [anon_sym_time] = ACTIONS(6641),
    [anon_sym_bit] = ACTIONS(6641),
    [anon_sym_logic] = ACTIONS(6641),
    [anon_sym_reg] = ACTIONS(6641),
    [anon_sym_shortreal] = ACTIONS(6641),
    [anon_sym_real] = ACTIONS(6641),
    [anon_sym_realtime] = ACTIONS(6641),
    [anon_sym_supply0] = ACTIONS(6641),
    [anon_sym_supply1] = ACTIONS(6641),
    [anon_sym_signed] = ACTIONS(6641),
    [anon_sym_unsigned] = ACTIONS(6641),
    [anon_sym_task] = ACTIONS(6641),
    [anon_sym_modport] = ACTIONS(6641),
    [anon_sym_assert] = ACTIONS(6641),
    [anon_sym_property] = ACTIONS(6641),
    [anon_sym_assume] = ACTIONS(6641),
    [anon_sym_cover] = ACTIONS(6641),
    [anon_sym_sequence] = ACTIONS(6641),
    [anon_sym_restrict] = ACTIONS(6641),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_or] = ACTIONS(6641),
    [anon_sym_and] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_always] = ACTIONS(6641),
    [anon_sym_covergroup] = ACTIONS(6641),
    [anon_sym_let] = ACTIONS(6641),
    [anon_sym_pulldown] = ACTIONS(6641),
    [anon_sym_pullup] = ACTIONS(6641),
    [anon_sym_cmos] = ACTIONS(6641),
    [anon_sym_rcmos] = ACTIONS(6641),
    [anon_sym_bufif0] = ACTIONS(6641),
    [anon_sym_bufif1] = ACTIONS(6641),
    [anon_sym_notif0] = ACTIONS(6641),
    [anon_sym_notif1] = ACTIONS(6641),
    [anon_sym_nmos] = ACTIONS(6641),
    [anon_sym_pmos] = ACTIONS(6641),
    [anon_sym_rnmos] = ACTIONS(6641),
    [anon_sym_rpmos] = ACTIONS(6641),
    [anon_sym_nand] = ACTIONS(6641),
    [anon_sym_nor] = ACTIONS(6641),
    [anon_sym_xor] = ACTIONS(6641),
    [anon_sym_xnor] = ACTIONS(6641),
    [anon_sym_buf] = ACTIONS(6641),
    [anon_sym_tranif0] = ACTIONS(6641),
    [anon_sym_tranif1] = ACTIONS(6641),
    [anon_sym_rtranif1] = ACTIONS(6641),
    [anon_sym_rtranif0] = ACTIONS(6641),
    [anon_sym_tran] = ACTIONS(6641),
    [anon_sym_rtran] = ACTIONS(6641),
    [anon_sym_generate] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_initial] = ACTIONS(6641),
    [anon_sym_assign] = ACTIONS(6641),
    [anon_sym_alias] = ACTIONS(6641),
    [anon_sym_always_comb] = ACTIONS(6641),
    [anon_sym_always_latch] = ACTIONS(6641),
    [anon_sym_always_ff] = ACTIONS(6641),
    [anon_sym_final] = ACTIONS(6641),
    [anon_sym_global] = ACTIONS(6641),
    [anon_sym_specify] = ACTIONS(6641),
    [anon_sym_LPAREN_STAR] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6643),
    [anon_sym_DOLLARunit] = ACTIONS(6643),
  },
  [1219] = {
    [sym_simple_identifier] = ACTIONS(6645),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6649),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6649),
    [anon_sym_BQUOTE] = ACTIONS(6645),
    [aux_sym_id_directive_token1] = ACTIONS(6649),
    [aux_sym_id_directive_token2] = ACTIONS(6649),
    [aux_sym_id_directive_token3] = ACTIONS(6649),
    [aux_sym_id_directive_token4] = ACTIONS(6645),
    [aux_sym_zero_directive_token1] = ACTIONS(6649),
    [aux_sym_zero_directive_token2] = ACTIONS(6649),
    [aux_sym_zero_directive_token3] = ACTIONS(6649),
    [aux_sym_zero_directive_token4] = ACTIONS(6649),
    [aux_sym_zero_directive_token5] = ACTIONS(6649),
    [aux_sym_zero_directive_token6] = ACTIONS(6649),
    [aux_sym_zero_directive_token7] = ACTIONS(6649),
    [aux_sym_zero_directive_token8] = ACTIONS(6649),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6649),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6649),
    [anon_sym_wire] = ACTIONS(6645),
    [anon_sym_tri] = ACTIONS(6645),
    [anon_sym_tri0] = ACTIONS(6645),
    [anon_sym_tri1] = ACTIONS(6645),
    [anon_sym_wand] = ACTIONS(6645),
    [anon_sym_triand] = ACTIONS(6645),
    [anon_sym_wor] = ACTIONS(6645),
    [anon_sym_trior] = ACTIONS(6645),
    [anon_sym_trireg] = ACTIONS(6645),
    [anon_sym_uwire] = ACTIONS(6645),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6649),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6649),
    [aux_sym_begin_keywords_token1] = ACTIONS(6649),
    [anon_sym_SEMI] = ACTIONS(6649),
    [anon_sym_endmodule] = ACTIONS(6645),
    [anon_sym_extern] = ACTIONS(6645),
    [anon_sym_module] = ACTIONS(6645),
    [anon_sym_macromodule] = ACTIONS(6645),
    [anon_sym_endinterface] = ACTIONS(6645),
    [anon_sym_interface] = ACTIONS(6645),
    [anon_sym_endprogram] = ACTIONS(6645),
    [anon_sym_program] = ACTIONS(6645),
    [anon_sym_checker] = ACTIONS(6645),
    [anon_sym_virtual] = ACTIONS(6645),
    [anon_sym_class] = ACTIONS(6645),
    [anon_sym_timeunit] = ACTIONS(6645),
    [anon_sym_timeprecision] = ACTIONS(6645),
    [anon_sym_type] = ACTIONS(6645),
    [anon_sym_input] = ACTIONS(6645),
    [anon_sym_output] = ACTIONS(6645),
    [anon_sym_inout] = ACTIONS(6645),
    [anon_sym_ref] = ACTIONS(6645),
    [anon_sym_DOLLARfatal] = ACTIONS(6649),
    [anon_sym_DOLLARerror] = ACTIONS(6649),
    [anon_sym_DOLLARwarning] = ACTIONS(6649),
    [anon_sym_DOLLARinfo] = ACTIONS(6649),
    [anon_sym_default] = ACTIONS(6645),
    [anon_sym_clocking] = ACTIONS(6645),
    [anon_sym_defparam] = ACTIONS(6645),
    [anon_sym_bind] = ACTIONS(6645),
    [anon_sym_const] = ACTIONS(6645),
    [anon_sym_function] = ACTIONS(6645),
    [anon_sym_static] = ACTIONS(6645),
    [anon_sym_constraint] = ACTIONS(6645),
    [anon_sym_if] = ACTIONS(6645),
    [anon_sym_else] = ACTIONS(6645),
    [anon_sym_LBRACK] = ACTIONS(6649),
    [anon_sym_localparam] = ACTIONS(6645),
    [anon_sym_parameter] = ACTIONS(6645),
    [anon_sym_specparam] = ACTIONS(6645),
    [anon_sym_var] = ACTIONS(6645),
    [anon_sym_import] = ACTIONS(6645),
    [anon_sym_export] = ACTIONS(6645),
    [anon_sym_genvar] = ACTIONS(6645),
    [anon_sym_interconnect] = ACTIONS(6645),
    [anon_sym_typedef] = ACTIONS(6645),
    [anon_sym_enum] = ACTIONS(6645),
    [anon_sym_struct] = ACTIONS(6645),
    [anon_sym_union] = ACTIONS(6645),
    [anon_sym_nettype] = ACTIONS(6645),
    [anon_sym_automatic] = ACTIONS(6645),
    [anon_sym_string] = ACTIONS(6645),
    [anon_sym_chandle] = ACTIONS(6645),
    [anon_sym_event] = ACTIONS(6645),
    [anon_sym_byte] = ACTIONS(6645),
    [anon_sym_shortint] = ACTIONS(6645),
    [anon_sym_int] = ACTIONS(6645),
    [anon_sym_longint] = ACTIONS(6645),
    [anon_sym_integer] = ACTIONS(6645),
    [anon_sym_time] = ACTIONS(6645),
    [anon_sym_bit] = ACTIONS(6645),
    [anon_sym_logic] = ACTIONS(6645),
    [anon_sym_reg] = ACTIONS(6645),
    [anon_sym_shortreal] = ACTIONS(6645),
    [anon_sym_real] = ACTIONS(6645),
    [anon_sym_realtime] = ACTIONS(6645),
    [anon_sym_supply0] = ACTIONS(6645),
    [anon_sym_supply1] = ACTIONS(6645),
    [anon_sym_signed] = ACTIONS(6645),
    [anon_sym_unsigned] = ACTIONS(6645),
    [anon_sym_task] = ACTIONS(6645),
    [anon_sym_modport] = ACTIONS(6645),
    [anon_sym_assert] = ACTIONS(6645),
    [anon_sym_property] = ACTIONS(6645),
    [anon_sym_assume] = ACTIONS(6645),
    [anon_sym_cover] = ACTIONS(6645),
    [anon_sym_sequence] = ACTIONS(6645),
    [anon_sym_restrict] = ACTIONS(6645),
    [anon_sym_not] = ACTIONS(6645),
    [anon_sym_or] = ACTIONS(6645),
    [anon_sym_and] = ACTIONS(6645),
    [anon_sym_case] = ACTIONS(6645),
    [anon_sym_always] = ACTIONS(6645),
    [anon_sym_covergroup] = ACTIONS(6645),
    [anon_sym_let] = ACTIONS(6645),
    [anon_sym_pulldown] = ACTIONS(6645),
    [anon_sym_pullup] = ACTIONS(6645),
    [anon_sym_cmos] = ACTIONS(6645),
    [anon_sym_rcmos] = ACTIONS(6645),
    [anon_sym_bufif0] = ACTIONS(6645),
    [anon_sym_bufif1] = ACTIONS(6645),
    [anon_sym_notif0] = ACTIONS(6645),
    [anon_sym_notif1] = ACTIONS(6645),
    [anon_sym_nmos] = ACTIONS(6645),
    [anon_sym_pmos] = ACTIONS(6645),
    [anon_sym_rnmos] = ACTIONS(6645),
    [anon_sym_rpmos] = ACTIONS(6645),
    [anon_sym_nand] = ACTIONS(6645),
    [anon_sym_nor] = ACTIONS(6645),
    [anon_sym_xor] = ACTIONS(6645),
    [anon_sym_xnor] = ACTIONS(6645),
    [anon_sym_buf] = ACTIONS(6645),
    [anon_sym_tranif0] = ACTIONS(6645),
    [anon_sym_tranif1] = ACTIONS(6645),
    [anon_sym_rtranif1] = ACTIONS(6645),
    [anon_sym_rtranif0] = ACTIONS(6645),
    [anon_sym_tran] = ACTIONS(6645),
    [anon_sym_rtran] = ACTIONS(6645),
    [anon_sym_generate] = ACTIONS(6645),
    [anon_sym_for] = ACTIONS(6645),
    [anon_sym_initial] = ACTIONS(6645),
    [anon_sym_assign] = ACTIONS(6645),
    [anon_sym_alias] = ACTIONS(6645),
    [anon_sym_always_comb] = ACTIONS(6645),
    [anon_sym_always_latch] = ACTIONS(6645),
    [anon_sym_always_ff] = ACTIONS(6645),
    [anon_sym_final] = ACTIONS(6645),
    [anon_sym_global] = ACTIONS(6645),
    [anon_sym_specify] = ACTIONS(6645),
    [anon_sym_LPAREN_STAR] = ACTIONS(6649),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6649),
    [anon_sym_DOLLARunit] = ACTIONS(6649),
  },
  [1220] = {
    [sym_simple_identifier] = ACTIONS(6653),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6655),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6655),
    [anon_sym_BQUOTE] = ACTIONS(6653),
    [aux_sym_id_directive_token1] = ACTIONS(6655),
    [aux_sym_id_directive_token2] = ACTIONS(6655),
    [aux_sym_id_directive_token3] = ACTIONS(6655),
    [aux_sym_id_directive_token4] = ACTIONS(6653),
    [aux_sym_zero_directive_token1] = ACTIONS(6655),
    [aux_sym_zero_directive_token2] = ACTIONS(6655),
    [aux_sym_zero_directive_token3] = ACTIONS(6655),
    [aux_sym_zero_directive_token4] = ACTIONS(6655),
    [aux_sym_zero_directive_token5] = ACTIONS(6655),
    [aux_sym_zero_directive_token6] = ACTIONS(6655),
    [aux_sym_zero_directive_token7] = ACTIONS(6655),
    [aux_sym_zero_directive_token8] = ACTIONS(6655),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6655),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6655),
    [anon_sym_wire] = ACTIONS(6653),
    [anon_sym_tri] = ACTIONS(6653),
    [anon_sym_tri0] = ACTIONS(6653),
    [anon_sym_tri1] = ACTIONS(6653),
    [anon_sym_wand] = ACTIONS(6653),
    [anon_sym_triand] = ACTIONS(6653),
    [anon_sym_wor] = ACTIONS(6653),
    [anon_sym_trior] = ACTIONS(6653),
    [anon_sym_trireg] = ACTIONS(6653),
    [anon_sym_uwire] = ACTIONS(6653),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6655),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6655),
    [aux_sym_begin_keywords_token1] = ACTIONS(6655),
    [anon_sym_SEMI] = ACTIONS(6655),
    [anon_sym_endmodule] = ACTIONS(6653),
    [anon_sym_extern] = ACTIONS(6653),
    [anon_sym_module] = ACTIONS(6653),
    [anon_sym_macromodule] = ACTIONS(6653),
    [anon_sym_endinterface] = ACTIONS(6653),
    [anon_sym_interface] = ACTIONS(6653),
    [anon_sym_endprogram] = ACTIONS(6653),
    [anon_sym_program] = ACTIONS(6653),
    [anon_sym_checker] = ACTIONS(6653),
    [anon_sym_virtual] = ACTIONS(6653),
    [anon_sym_class] = ACTIONS(6653),
    [anon_sym_timeunit] = ACTIONS(6653),
    [anon_sym_timeprecision] = ACTIONS(6653),
    [anon_sym_type] = ACTIONS(6653),
    [anon_sym_input] = ACTIONS(6653),
    [anon_sym_output] = ACTIONS(6653),
    [anon_sym_inout] = ACTIONS(6653),
    [anon_sym_ref] = ACTIONS(6653),
    [anon_sym_DOLLARfatal] = ACTIONS(6655),
    [anon_sym_DOLLARerror] = ACTIONS(6655),
    [anon_sym_DOLLARwarning] = ACTIONS(6655),
    [anon_sym_DOLLARinfo] = ACTIONS(6655),
    [anon_sym_default] = ACTIONS(6653),
    [anon_sym_clocking] = ACTIONS(6653),
    [anon_sym_defparam] = ACTIONS(6653),
    [anon_sym_bind] = ACTIONS(6653),
    [anon_sym_const] = ACTIONS(6653),
    [anon_sym_function] = ACTIONS(6653),
    [anon_sym_static] = ACTIONS(6653),
    [anon_sym_constraint] = ACTIONS(6653),
    [anon_sym_if] = ACTIONS(6653),
    [anon_sym_else] = ACTIONS(6653),
    [anon_sym_LBRACK] = ACTIONS(6655),
    [anon_sym_localparam] = ACTIONS(6653),
    [anon_sym_parameter] = ACTIONS(6653),
    [anon_sym_specparam] = ACTIONS(6653),
    [anon_sym_var] = ACTIONS(6653),
    [anon_sym_import] = ACTIONS(6653),
    [anon_sym_export] = ACTIONS(6653),
    [anon_sym_genvar] = ACTIONS(6653),
    [anon_sym_interconnect] = ACTIONS(6653),
    [anon_sym_typedef] = ACTIONS(6653),
    [anon_sym_enum] = ACTIONS(6653),
    [anon_sym_struct] = ACTIONS(6653),
    [anon_sym_union] = ACTIONS(6653),
    [anon_sym_nettype] = ACTIONS(6653),
    [anon_sym_automatic] = ACTIONS(6653),
    [anon_sym_string] = ACTIONS(6653),
    [anon_sym_chandle] = ACTIONS(6653),
    [anon_sym_event] = ACTIONS(6653),
    [anon_sym_byte] = ACTIONS(6653),
    [anon_sym_shortint] = ACTIONS(6653),
    [anon_sym_int] = ACTIONS(6653),
    [anon_sym_longint] = ACTIONS(6653),
    [anon_sym_integer] = ACTIONS(6653),
    [anon_sym_time] = ACTIONS(6653),
    [anon_sym_bit] = ACTIONS(6653),
    [anon_sym_logic] = ACTIONS(6653),
    [anon_sym_reg] = ACTIONS(6653),
    [anon_sym_shortreal] = ACTIONS(6653),
    [anon_sym_real] = ACTIONS(6653),
    [anon_sym_realtime] = ACTIONS(6653),
    [anon_sym_supply0] = ACTIONS(6653),
    [anon_sym_supply1] = ACTIONS(6653),
    [anon_sym_signed] = ACTIONS(6653),
    [anon_sym_unsigned] = ACTIONS(6653),
    [anon_sym_task] = ACTIONS(6653),
    [anon_sym_modport] = ACTIONS(6653),
    [anon_sym_assert] = ACTIONS(6653),
    [anon_sym_property] = ACTIONS(6653),
    [anon_sym_assume] = ACTIONS(6653),
    [anon_sym_cover] = ACTIONS(6653),
    [anon_sym_sequence] = ACTIONS(6653),
    [anon_sym_restrict] = ACTIONS(6653),
    [anon_sym_not] = ACTIONS(6653),
    [anon_sym_or] = ACTIONS(6653),
    [anon_sym_and] = ACTIONS(6653),
    [anon_sym_case] = ACTIONS(6653),
    [anon_sym_always] = ACTIONS(6653),
    [anon_sym_covergroup] = ACTIONS(6653),
    [anon_sym_let] = ACTIONS(6653),
    [anon_sym_pulldown] = ACTIONS(6653),
    [anon_sym_pullup] = ACTIONS(6653),
    [anon_sym_cmos] = ACTIONS(6653),
    [anon_sym_rcmos] = ACTIONS(6653),
    [anon_sym_bufif0] = ACTIONS(6653),
    [anon_sym_bufif1] = ACTIONS(6653),
    [anon_sym_notif0] = ACTIONS(6653),
    [anon_sym_notif1] = ACTIONS(6653),
    [anon_sym_nmos] = ACTIONS(6653),
    [anon_sym_pmos] = ACTIONS(6653),
    [anon_sym_rnmos] = ACTIONS(6653),
    [anon_sym_rpmos] = ACTIONS(6653),
    [anon_sym_nand] = ACTIONS(6653),
    [anon_sym_nor] = ACTIONS(6653),
    [anon_sym_xor] = ACTIONS(6653),
    [anon_sym_xnor] = ACTIONS(6653),
    [anon_sym_buf] = ACTIONS(6653),
    [anon_sym_tranif0] = ACTIONS(6653),
    [anon_sym_tranif1] = ACTIONS(6653),
    [anon_sym_rtranif1] = ACTIONS(6653),
    [anon_sym_rtranif0] = ACTIONS(6653),
    [anon_sym_tran] = ACTIONS(6653),
    [anon_sym_rtran] = ACTIONS(6653),
    [anon_sym_generate] = ACTIONS(6653),
    [anon_sym_for] = ACTIONS(6653),
    [anon_sym_initial] = ACTIONS(6653),
    [anon_sym_assign] = ACTIONS(6653),
    [anon_sym_alias] = ACTIONS(6653),
    [anon_sym_always_comb] = ACTIONS(6653),
    [anon_sym_always_latch] = ACTIONS(6653),
    [anon_sym_always_ff] = ACTIONS(6653),
    [anon_sym_final] = ACTIONS(6653),
    [anon_sym_global] = ACTIONS(6653),
    [anon_sym_specify] = ACTIONS(6653),
    [anon_sym_LPAREN_STAR] = ACTIONS(6655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6655),
    [anon_sym_DOLLARunit] = ACTIONS(6655),
  },
  [1221] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5624),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2644),
    [anon_sym_DQUOTE] = ACTIONS(2648),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(2648),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_COMMA] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(2648),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(2644),
    [anon_sym_LBRACE] = ACTIONS(2648),
    [anon_sym_const] = ACTIONS(2644),
    [anon_sym_local] = ACTIONS(2644),
    [anon_sym_super] = ACTIONS(2644),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2644),
    [anon_sym_byte] = ACTIONS(2644),
    [anon_sym_shortint] = ACTIONS(2644),
    [anon_sym_int] = ACTIONS(2644),
    [anon_sym_longint] = ACTIONS(2644),
    [anon_sym_integer] = ACTIONS(2644),
    [anon_sym_time] = ACTIONS(2644),
    [anon_sym_bit] = ACTIONS(2644),
    [anon_sym_logic] = ACTIONS(2644),
    [anon_sym_reg] = ACTIONS(2644),
    [anon_sym_shortreal] = ACTIONS(2644),
    [anon_sym_real] = ACTIONS(2644),
    [anon_sym_realtime] = ACTIONS(2644),
    [anon_sym_signed] = ACTIONS(2644),
    [anon_sym_unsigned] = ACTIONS(2644),
    [anon_sym_tagged] = ACTIONS(2644),
    [anon_sym_DOLLAR] = ACTIONS(2644),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2648),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2644),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2648),
    [anon_sym_TILDE] = ACTIONS(2644),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(2644),
    [anon_sym_randomize] = ACTIONS(2644),
    [anon_sym_null] = ACTIONS(2644),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(2644),
    [anon_sym_TILDE_AMP] = ACTIONS(2648),
    [anon_sym_TILDE_PIPE] = ACTIONS(2648),
    [anon_sym_DASH_DASH] = ACTIONS(2648),
    [aux_sym_decimal_number_token1] = ACTIONS(2648),
    [aux_sym_decimal_number_token2] = ACTIONS(2648),
    [sym_binary_number] = ACTIONS(2648),
    [sym_octal_number] = ACTIONS(2648),
    [sym_hex_number] = ACTIONS(2648),
    [aux_sym_real_number_token1] = ACTIONS(2648),
    [sym_fixed_point_number] = ACTIONS(2644),
    [sym_unsigned_number] = ACTIONS(2644),
    [anon_sym_SQUOTE0] = ACTIONS(2648),
    [anon_sym_SQUOTE1] = ACTIONS(2648),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2648),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2648),
    [anon_sym_DOLLARroot] = ACTIONS(2644),
    [anon_sym_DOLLARunit] = ACTIONS(2644),
    [sym_system_tf_identifier] = ACTIONS(2644),
  },
  [1222] = {
    [sym_simple_identifier] = ACTIONS(6657),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6659),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6659),
    [anon_sym_BQUOTE] = ACTIONS(6657),
    [aux_sym_id_directive_token1] = ACTIONS(6659),
    [aux_sym_id_directive_token2] = ACTIONS(6659),
    [aux_sym_id_directive_token3] = ACTIONS(6659),
    [aux_sym_id_directive_token4] = ACTIONS(6657),
    [aux_sym_zero_directive_token1] = ACTIONS(6659),
    [aux_sym_zero_directive_token2] = ACTIONS(6659),
    [aux_sym_zero_directive_token3] = ACTIONS(6659),
    [aux_sym_zero_directive_token4] = ACTIONS(6659),
    [aux_sym_zero_directive_token5] = ACTIONS(6659),
    [aux_sym_zero_directive_token6] = ACTIONS(6659),
    [aux_sym_zero_directive_token7] = ACTIONS(6659),
    [aux_sym_zero_directive_token8] = ACTIONS(6659),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6659),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6659),
    [anon_sym_wire] = ACTIONS(6657),
    [anon_sym_tri] = ACTIONS(6657),
    [anon_sym_tri0] = ACTIONS(6657),
    [anon_sym_tri1] = ACTIONS(6657),
    [anon_sym_wand] = ACTIONS(6657),
    [anon_sym_triand] = ACTIONS(6657),
    [anon_sym_wor] = ACTIONS(6657),
    [anon_sym_trior] = ACTIONS(6657),
    [anon_sym_trireg] = ACTIONS(6657),
    [anon_sym_uwire] = ACTIONS(6657),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6659),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6659),
    [aux_sym_begin_keywords_token1] = ACTIONS(6659),
    [anon_sym_SEMI] = ACTIONS(6659),
    [anon_sym_endmodule] = ACTIONS(6657),
    [anon_sym_extern] = ACTIONS(6657),
    [anon_sym_module] = ACTIONS(6657),
    [anon_sym_macromodule] = ACTIONS(6657),
    [anon_sym_endinterface] = ACTIONS(6657),
    [anon_sym_interface] = ACTIONS(6657),
    [anon_sym_endprogram] = ACTIONS(6657),
    [anon_sym_program] = ACTIONS(6657),
    [anon_sym_checker] = ACTIONS(6657),
    [anon_sym_virtual] = ACTIONS(6657),
    [anon_sym_class] = ACTIONS(6657),
    [anon_sym_timeunit] = ACTIONS(6657),
    [anon_sym_timeprecision] = ACTIONS(6657),
    [anon_sym_type] = ACTIONS(6657),
    [anon_sym_input] = ACTIONS(6657),
    [anon_sym_output] = ACTIONS(6657),
    [anon_sym_inout] = ACTIONS(6657),
    [anon_sym_ref] = ACTIONS(6657),
    [anon_sym_DOLLARfatal] = ACTIONS(6659),
    [anon_sym_DOLLARerror] = ACTIONS(6659),
    [anon_sym_DOLLARwarning] = ACTIONS(6659),
    [anon_sym_DOLLARinfo] = ACTIONS(6659),
    [anon_sym_default] = ACTIONS(6657),
    [anon_sym_clocking] = ACTIONS(6657),
    [anon_sym_defparam] = ACTIONS(6657),
    [anon_sym_bind] = ACTIONS(6657),
    [anon_sym_const] = ACTIONS(6657),
    [anon_sym_function] = ACTIONS(6657),
    [anon_sym_static] = ACTIONS(6657),
    [anon_sym_constraint] = ACTIONS(6657),
    [anon_sym_if] = ACTIONS(6657),
    [anon_sym_else] = ACTIONS(6657),
    [anon_sym_LBRACK] = ACTIONS(6659),
    [anon_sym_localparam] = ACTIONS(6657),
    [anon_sym_parameter] = ACTIONS(6657),
    [anon_sym_specparam] = ACTIONS(6657),
    [anon_sym_var] = ACTIONS(6657),
    [anon_sym_import] = ACTIONS(6657),
    [anon_sym_export] = ACTIONS(6657),
    [anon_sym_genvar] = ACTIONS(6657),
    [anon_sym_interconnect] = ACTIONS(6657),
    [anon_sym_typedef] = ACTIONS(6657),
    [anon_sym_enum] = ACTIONS(6657),
    [anon_sym_struct] = ACTIONS(6657),
    [anon_sym_union] = ACTIONS(6657),
    [anon_sym_nettype] = ACTIONS(6657),
    [anon_sym_automatic] = ACTIONS(6657),
    [anon_sym_string] = ACTIONS(6657),
    [anon_sym_chandle] = ACTIONS(6657),
    [anon_sym_event] = ACTIONS(6657),
    [anon_sym_byte] = ACTIONS(6657),
    [anon_sym_shortint] = ACTIONS(6657),
    [anon_sym_int] = ACTIONS(6657),
    [anon_sym_longint] = ACTIONS(6657),
    [anon_sym_integer] = ACTIONS(6657),
    [anon_sym_time] = ACTIONS(6657),
    [anon_sym_bit] = ACTIONS(6657),
    [anon_sym_logic] = ACTIONS(6657),
    [anon_sym_reg] = ACTIONS(6657),
    [anon_sym_shortreal] = ACTIONS(6657),
    [anon_sym_real] = ACTIONS(6657),
    [anon_sym_realtime] = ACTIONS(6657),
    [anon_sym_supply0] = ACTIONS(6657),
    [anon_sym_supply1] = ACTIONS(6657),
    [anon_sym_signed] = ACTIONS(6657),
    [anon_sym_unsigned] = ACTIONS(6657),
    [anon_sym_task] = ACTIONS(6657),
    [anon_sym_modport] = ACTIONS(6657),
    [anon_sym_assert] = ACTIONS(6657),
    [anon_sym_property] = ACTIONS(6657),
    [anon_sym_assume] = ACTIONS(6657),
    [anon_sym_cover] = ACTIONS(6657),
    [anon_sym_sequence] = ACTIONS(6657),
    [anon_sym_restrict] = ACTIONS(6657),
    [anon_sym_not] = ACTIONS(6657),
    [anon_sym_or] = ACTIONS(6657),
    [anon_sym_and] = ACTIONS(6657),
    [anon_sym_case] = ACTIONS(6657),
    [anon_sym_always] = ACTIONS(6657),
    [anon_sym_covergroup] = ACTIONS(6657),
    [anon_sym_let] = ACTIONS(6657),
    [anon_sym_pulldown] = ACTIONS(6657),
    [anon_sym_pullup] = ACTIONS(6657),
    [anon_sym_cmos] = ACTIONS(6657),
    [anon_sym_rcmos] = ACTIONS(6657),
    [anon_sym_bufif0] = ACTIONS(6657),
    [anon_sym_bufif1] = ACTIONS(6657),
    [anon_sym_notif0] = ACTIONS(6657),
    [anon_sym_notif1] = ACTIONS(6657),
    [anon_sym_nmos] = ACTIONS(6657),
    [anon_sym_pmos] = ACTIONS(6657),
    [anon_sym_rnmos] = ACTIONS(6657),
    [anon_sym_rpmos] = ACTIONS(6657),
    [anon_sym_nand] = ACTIONS(6657),
    [anon_sym_nor] = ACTIONS(6657),
    [anon_sym_xor] = ACTIONS(6657),
    [anon_sym_xnor] = ACTIONS(6657),
    [anon_sym_buf] = ACTIONS(6657),
    [anon_sym_tranif0] = ACTIONS(6657),
    [anon_sym_tranif1] = ACTIONS(6657),
    [anon_sym_rtranif1] = ACTIONS(6657),
    [anon_sym_rtranif0] = ACTIONS(6657),
    [anon_sym_tran] = ACTIONS(6657),
    [anon_sym_rtran] = ACTIONS(6657),
    [anon_sym_generate] = ACTIONS(6657),
    [anon_sym_for] = ACTIONS(6657),
    [anon_sym_initial] = ACTIONS(6657),
    [anon_sym_assign] = ACTIONS(6657),
    [anon_sym_alias] = ACTIONS(6657),
    [anon_sym_always_comb] = ACTIONS(6657),
    [anon_sym_always_latch] = ACTIONS(6657),
    [anon_sym_always_ff] = ACTIONS(6657),
    [anon_sym_final] = ACTIONS(6657),
    [anon_sym_global] = ACTIONS(6657),
    [anon_sym_specify] = ACTIONS(6657),
    [anon_sym_LPAREN_STAR] = ACTIONS(6659),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6659),
    [anon_sym_DOLLARunit] = ACTIONS(6659),
  },
  [1223] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6093),
    [anon_sym_BQUOTE] = ACTIONS(6091),
    [aux_sym_id_directive_token1] = ACTIONS(6093),
    [aux_sym_id_directive_token2] = ACTIONS(6093),
    [aux_sym_id_directive_token3] = ACTIONS(6093),
    [aux_sym_id_directive_token4] = ACTIONS(6091),
    [aux_sym_zero_directive_token1] = ACTIONS(6093),
    [aux_sym_zero_directive_token2] = ACTIONS(6093),
    [aux_sym_zero_directive_token3] = ACTIONS(6093),
    [aux_sym_zero_directive_token4] = ACTIONS(6093),
    [aux_sym_zero_directive_token5] = ACTIONS(6093),
    [aux_sym_zero_directive_token6] = ACTIONS(6093),
    [aux_sym_zero_directive_token7] = ACTIONS(6093),
    [aux_sym_zero_directive_token8] = ACTIONS(6093),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6093),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6093),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6093),
    [aux_sym_begin_keywords_token1] = ACTIONS(6093),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_endmodule] = ACTIONS(6091),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_module] = ACTIONS(6091),
    [anon_sym_macromodule] = ACTIONS(6091),
    [anon_sym_endinterface] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_endprogram] = ACTIONS(6091),
    [anon_sym_program] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_timeunit] = ACTIONS(6091),
    [anon_sym_timeprecision] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_input] = ACTIONS(6091),
    [anon_sym_output] = ACTIONS(6091),
    [anon_sym_inout] = ACTIONS(6091),
    [anon_sym_ref] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_specparam] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_modport] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_specify] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [1224] = {
    [sym_simple_identifier] = ACTIONS(6661),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6663),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6663),
    [anon_sym_BQUOTE] = ACTIONS(6661),
    [aux_sym_id_directive_token1] = ACTIONS(6663),
    [aux_sym_id_directive_token2] = ACTIONS(6663),
    [aux_sym_id_directive_token3] = ACTIONS(6663),
    [aux_sym_id_directive_token4] = ACTIONS(6661),
    [aux_sym_zero_directive_token1] = ACTIONS(6663),
    [aux_sym_zero_directive_token2] = ACTIONS(6663),
    [aux_sym_zero_directive_token3] = ACTIONS(6663),
    [aux_sym_zero_directive_token4] = ACTIONS(6663),
    [aux_sym_zero_directive_token5] = ACTIONS(6663),
    [aux_sym_zero_directive_token6] = ACTIONS(6663),
    [aux_sym_zero_directive_token7] = ACTIONS(6663),
    [aux_sym_zero_directive_token8] = ACTIONS(6663),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6663),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6663),
    [anon_sym_wire] = ACTIONS(6661),
    [anon_sym_tri] = ACTIONS(6661),
    [anon_sym_tri0] = ACTIONS(6661),
    [anon_sym_tri1] = ACTIONS(6661),
    [anon_sym_wand] = ACTIONS(6661),
    [anon_sym_triand] = ACTIONS(6661),
    [anon_sym_wor] = ACTIONS(6661),
    [anon_sym_trior] = ACTIONS(6661),
    [anon_sym_trireg] = ACTIONS(6661),
    [anon_sym_uwire] = ACTIONS(6661),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6663),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6663),
    [aux_sym_begin_keywords_token1] = ACTIONS(6663),
    [anon_sym_SEMI] = ACTIONS(6663),
    [anon_sym_endmodule] = ACTIONS(6661),
    [anon_sym_extern] = ACTIONS(6661),
    [anon_sym_module] = ACTIONS(6661),
    [anon_sym_macromodule] = ACTIONS(6661),
    [anon_sym_endinterface] = ACTIONS(6661),
    [anon_sym_interface] = ACTIONS(6661),
    [anon_sym_endprogram] = ACTIONS(6661),
    [anon_sym_program] = ACTIONS(6661),
    [anon_sym_checker] = ACTIONS(6661),
    [anon_sym_virtual] = ACTIONS(6661),
    [anon_sym_class] = ACTIONS(6661),
    [anon_sym_timeunit] = ACTIONS(6661),
    [anon_sym_timeprecision] = ACTIONS(6661),
    [anon_sym_type] = ACTIONS(6661),
    [anon_sym_input] = ACTIONS(6661),
    [anon_sym_output] = ACTIONS(6661),
    [anon_sym_inout] = ACTIONS(6661),
    [anon_sym_ref] = ACTIONS(6661),
    [anon_sym_DOLLARfatal] = ACTIONS(6663),
    [anon_sym_DOLLARerror] = ACTIONS(6663),
    [anon_sym_DOLLARwarning] = ACTIONS(6663),
    [anon_sym_DOLLARinfo] = ACTIONS(6663),
    [anon_sym_default] = ACTIONS(6661),
    [anon_sym_clocking] = ACTIONS(6661),
    [anon_sym_defparam] = ACTIONS(6661),
    [anon_sym_bind] = ACTIONS(6661),
    [anon_sym_const] = ACTIONS(6661),
    [anon_sym_function] = ACTIONS(6661),
    [anon_sym_static] = ACTIONS(6661),
    [anon_sym_constraint] = ACTIONS(6661),
    [anon_sym_if] = ACTIONS(6661),
    [anon_sym_else] = ACTIONS(6661),
    [anon_sym_LBRACK] = ACTIONS(6663),
    [anon_sym_localparam] = ACTIONS(6661),
    [anon_sym_parameter] = ACTIONS(6661),
    [anon_sym_specparam] = ACTIONS(6661),
    [anon_sym_var] = ACTIONS(6661),
    [anon_sym_import] = ACTIONS(6661),
    [anon_sym_export] = ACTIONS(6661),
    [anon_sym_genvar] = ACTIONS(6661),
    [anon_sym_interconnect] = ACTIONS(6661),
    [anon_sym_typedef] = ACTIONS(6661),
    [anon_sym_enum] = ACTIONS(6661),
    [anon_sym_struct] = ACTIONS(6661),
    [anon_sym_union] = ACTIONS(6661),
    [anon_sym_nettype] = ACTIONS(6661),
    [anon_sym_automatic] = ACTIONS(6661),
    [anon_sym_string] = ACTIONS(6661),
    [anon_sym_chandle] = ACTIONS(6661),
    [anon_sym_event] = ACTIONS(6661),
    [anon_sym_byte] = ACTIONS(6661),
    [anon_sym_shortint] = ACTIONS(6661),
    [anon_sym_int] = ACTIONS(6661),
    [anon_sym_longint] = ACTIONS(6661),
    [anon_sym_integer] = ACTIONS(6661),
    [anon_sym_time] = ACTIONS(6661),
    [anon_sym_bit] = ACTIONS(6661),
    [anon_sym_logic] = ACTIONS(6661),
    [anon_sym_reg] = ACTIONS(6661),
    [anon_sym_shortreal] = ACTIONS(6661),
    [anon_sym_real] = ACTIONS(6661),
    [anon_sym_realtime] = ACTIONS(6661),
    [anon_sym_supply0] = ACTIONS(6661),
    [anon_sym_supply1] = ACTIONS(6661),
    [anon_sym_signed] = ACTIONS(6661),
    [anon_sym_unsigned] = ACTIONS(6661),
    [anon_sym_task] = ACTIONS(6661),
    [anon_sym_modport] = ACTIONS(6661),
    [anon_sym_assert] = ACTIONS(6661),
    [anon_sym_property] = ACTIONS(6661),
    [anon_sym_assume] = ACTIONS(6661),
    [anon_sym_cover] = ACTIONS(6661),
    [anon_sym_sequence] = ACTIONS(6661),
    [anon_sym_restrict] = ACTIONS(6661),
    [anon_sym_not] = ACTIONS(6661),
    [anon_sym_or] = ACTIONS(6661),
    [anon_sym_and] = ACTIONS(6661),
    [anon_sym_case] = ACTIONS(6661),
    [anon_sym_always] = ACTIONS(6661),
    [anon_sym_covergroup] = ACTIONS(6661),
    [anon_sym_let] = ACTIONS(6661),
    [anon_sym_pulldown] = ACTIONS(6661),
    [anon_sym_pullup] = ACTIONS(6661),
    [anon_sym_cmos] = ACTIONS(6661),
    [anon_sym_rcmos] = ACTIONS(6661),
    [anon_sym_bufif0] = ACTIONS(6661),
    [anon_sym_bufif1] = ACTIONS(6661),
    [anon_sym_notif0] = ACTIONS(6661),
    [anon_sym_notif1] = ACTIONS(6661),
    [anon_sym_nmos] = ACTIONS(6661),
    [anon_sym_pmos] = ACTIONS(6661),
    [anon_sym_rnmos] = ACTIONS(6661),
    [anon_sym_rpmos] = ACTIONS(6661),
    [anon_sym_nand] = ACTIONS(6661),
    [anon_sym_nor] = ACTIONS(6661),
    [anon_sym_xor] = ACTIONS(6661),
    [anon_sym_xnor] = ACTIONS(6661),
    [anon_sym_buf] = ACTIONS(6661),
    [anon_sym_tranif0] = ACTIONS(6661),
    [anon_sym_tranif1] = ACTIONS(6661),
    [anon_sym_rtranif1] = ACTIONS(6661),
    [anon_sym_rtranif0] = ACTIONS(6661),
    [anon_sym_tran] = ACTIONS(6661),
    [anon_sym_rtran] = ACTIONS(6661),
    [anon_sym_generate] = ACTIONS(6661),
    [anon_sym_for] = ACTIONS(6661),
    [anon_sym_initial] = ACTIONS(6661),
    [anon_sym_assign] = ACTIONS(6661),
    [anon_sym_alias] = ACTIONS(6661),
    [anon_sym_always_comb] = ACTIONS(6661),
    [anon_sym_always_latch] = ACTIONS(6661),
    [anon_sym_always_ff] = ACTIONS(6661),
    [anon_sym_final] = ACTIONS(6661),
    [anon_sym_global] = ACTIONS(6661),
    [anon_sym_specify] = ACTIONS(6661),
    [anon_sym_LPAREN_STAR] = ACTIONS(6663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6663),
    [anon_sym_DOLLARunit] = ACTIONS(6663),
  },
  [1225] = {
    [sym_simple_identifier] = ACTIONS(6665),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6667),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6667),
    [anon_sym_BQUOTE] = ACTIONS(6665),
    [aux_sym_id_directive_token1] = ACTIONS(6667),
    [aux_sym_id_directive_token2] = ACTIONS(6667),
    [aux_sym_id_directive_token3] = ACTIONS(6667),
    [aux_sym_id_directive_token4] = ACTIONS(6665),
    [aux_sym_zero_directive_token1] = ACTIONS(6667),
    [aux_sym_zero_directive_token2] = ACTIONS(6667),
    [aux_sym_zero_directive_token3] = ACTIONS(6667),
    [aux_sym_zero_directive_token4] = ACTIONS(6667),
    [aux_sym_zero_directive_token5] = ACTIONS(6667),
    [aux_sym_zero_directive_token6] = ACTIONS(6667),
    [aux_sym_zero_directive_token7] = ACTIONS(6667),
    [aux_sym_zero_directive_token8] = ACTIONS(6667),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6667),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6667),
    [anon_sym_wire] = ACTIONS(6665),
    [anon_sym_tri] = ACTIONS(6665),
    [anon_sym_tri0] = ACTIONS(6665),
    [anon_sym_tri1] = ACTIONS(6665),
    [anon_sym_wand] = ACTIONS(6665),
    [anon_sym_triand] = ACTIONS(6665),
    [anon_sym_wor] = ACTIONS(6665),
    [anon_sym_trior] = ACTIONS(6665),
    [anon_sym_trireg] = ACTIONS(6665),
    [anon_sym_uwire] = ACTIONS(6665),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6667),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6667),
    [aux_sym_begin_keywords_token1] = ACTIONS(6667),
    [anon_sym_SEMI] = ACTIONS(6667),
    [anon_sym_endmodule] = ACTIONS(6665),
    [anon_sym_extern] = ACTIONS(6665),
    [anon_sym_module] = ACTIONS(6665),
    [anon_sym_macromodule] = ACTIONS(6665),
    [anon_sym_endinterface] = ACTIONS(6665),
    [anon_sym_interface] = ACTIONS(6665),
    [anon_sym_endprogram] = ACTIONS(6665),
    [anon_sym_program] = ACTIONS(6665),
    [anon_sym_checker] = ACTIONS(6665),
    [anon_sym_virtual] = ACTIONS(6665),
    [anon_sym_class] = ACTIONS(6665),
    [anon_sym_timeunit] = ACTIONS(6665),
    [anon_sym_timeprecision] = ACTIONS(6665),
    [anon_sym_type] = ACTIONS(6665),
    [anon_sym_input] = ACTIONS(6665),
    [anon_sym_output] = ACTIONS(6665),
    [anon_sym_inout] = ACTIONS(6665),
    [anon_sym_ref] = ACTIONS(6665),
    [anon_sym_DOLLARfatal] = ACTIONS(6667),
    [anon_sym_DOLLARerror] = ACTIONS(6667),
    [anon_sym_DOLLARwarning] = ACTIONS(6667),
    [anon_sym_DOLLARinfo] = ACTIONS(6667),
    [anon_sym_default] = ACTIONS(6665),
    [anon_sym_clocking] = ACTIONS(6665),
    [anon_sym_defparam] = ACTIONS(6665),
    [anon_sym_bind] = ACTIONS(6665),
    [anon_sym_const] = ACTIONS(6665),
    [anon_sym_function] = ACTIONS(6665),
    [anon_sym_static] = ACTIONS(6665),
    [anon_sym_constraint] = ACTIONS(6665),
    [anon_sym_if] = ACTIONS(6665),
    [anon_sym_else] = ACTIONS(6665),
    [anon_sym_LBRACK] = ACTIONS(6667),
    [anon_sym_localparam] = ACTIONS(6665),
    [anon_sym_parameter] = ACTIONS(6665),
    [anon_sym_specparam] = ACTIONS(6665),
    [anon_sym_var] = ACTIONS(6665),
    [anon_sym_import] = ACTIONS(6665),
    [anon_sym_export] = ACTIONS(6665),
    [anon_sym_genvar] = ACTIONS(6665),
    [anon_sym_interconnect] = ACTIONS(6665),
    [anon_sym_typedef] = ACTIONS(6665),
    [anon_sym_enum] = ACTIONS(6665),
    [anon_sym_struct] = ACTIONS(6665),
    [anon_sym_union] = ACTIONS(6665),
    [anon_sym_nettype] = ACTIONS(6665),
    [anon_sym_automatic] = ACTIONS(6665),
    [anon_sym_string] = ACTIONS(6665),
    [anon_sym_chandle] = ACTIONS(6665),
    [anon_sym_event] = ACTIONS(6665),
    [anon_sym_byte] = ACTIONS(6665),
    [anon_sym_shortint] = ACTIONS(6665),
    [anon_sym_int] = ACTIONS(6665),
    [anon_sym_longint] = ACTIONS(6665),
    [anon_sym_integer] = ACTIONS(6665),
    [anon_sym_time] = ACTIONS(6665),
    [anon_sym_bit] = ACTIONS(6665),
    [anon_sym_logic] = ACTIONS(6665),
    [anon_sym_reg] = ACTIONS(6665),
    [anon_sym_shortreal] = ACTIONS(6665),
    [anon_sym_real] = ACTIONS(6665),
    [anon_sym_realtime] = ACTIONS(6665),
    [anon_sym_supply0] = ACTIONS(6665),
    [anon_sym_supply1] = ACTIONS(6665),
    [anon_sym_signed] = ACTIONS(6665),
    [anon_sym_unsigned] = ACTIONS(6665),
    [anon_sym_task] = ACTIONS(6665),
    [anon_sym_modport] = ACTIONS(6665),
    [anon_sym_assert] = ACTIONS(6665),
    [anon_sym_property] = ACTIONS(6665),
    [anon_sym_assume] = ACTIONS(6665),
    [anon_sym_cover] = ACTIONS(6665),
    [anon_sym_sequence] = ACTIONS(6665),
    [anon_sym_restrict] = ACTIONS(6665),
    [anon_sym_not] = ACTIONS(6665),
    [anon_sym_or] = ACTIONS(6665),
    [anon_sym_and] = ACTIONS(6665),
    [anon_sym_case] = ACTIONS(6665),
    [anon_sym_always] = ACTIONS(6665),
    [anon_sym_covergroup] = ACTIONS(6665),
    [anon_sym_let] = ACTIONS(6665),
    [anon_sym_pulldown] = ACTIONS(6665),
    [anon_sym_pullup] = ACTIONS(6665),
    [anon_sym_cmos] = ACTIONS(6665),
    [anon_sym_rcmos] = ACTIONS(6665),
    [anon_sym_bufif0] = ACTIONS(6665),
    [anon_sym_bufif1] = ACTIONS(6665),
    [anon_sym_notif0] = ACTIONS(6665),
    [anon_sym_notif1] = ACTIONS(6665),
    [anon_sym_nmos] = ACTIONS(6665),
    [anon_sym_pmos] = ACTIONS(6665),
    [anon_sym_rnmos] = ACTIONS(6665),
    [anon_sym_rpmos] = ACTIONS(6665),
    [anon_sym_nand] = ACTIONS(6665),
    [anon_sym_nor] = ACTIONS(6665),
    [anon_sym_xor] = ACTIONS(6665),
    [anon_sym_xnor] = ACTIONS(6665),
    [anon_sym_buf] = ACTIONS(6665),
    [anon_sym_tranif0] = ACTIONS(6665),
    [anon_sym_tranif1] = ACTIONS(6665),
    [anon_sym_rtranif1] = ACTIONS(6665),
    [anon_sym_rtranif0] = ACTIONS(6665),
    [anon_sym_tran] = ACTIONS(6665),
    [anon_sym_rtran] = ACTIONS(6665),
    [anon_sym_generate] = ACTIONS(6665),
    [anon_sym_for] = ACTIONS(6665),
    [anon_sym_initial] = ACTIONS(6665),
    [anon_sym_assign] = ACTIONS(6665),
    [anon_sym_alias] = ACTIONS(6665),
    [anon_sym_always_comb] = ACTIONS(6665),
    [anon_sym_always_latch] = ACTIONS(6665),
    [anon_sym_always_ff] = ACTIONS(6665),
    [anon_sym_final] = ACTIONS(6665),
    [anon_sym_global] = ACTIONS(6665),
    [anon_sym_specify] = ACTIONS(6665),
    [anon_sym_LPAREN_STAR] = ACTIONS(6667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6667),
    [anon_sym_DOLLARunit] = ACTIONS(6667),
  },
  [1226] = {
    [sym_simple_identifier] = ACTIONS(6669),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6671),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6671),
    [anon_sym_BQUOTE] = ACTIONS(6669),
    [aux_sym_id_directive_token1] = ACTIONS(6671),
    [aux_sym_id_directive_token2] = ACTIONS(6671),
    [aux_sym_id_directive_token3] = ACTIONS(6671),
    [aux_sym_id_directive_token4] = ACTIONS(6669),
    [aux_sym_zero_directive_token1] = ACTIONS(6671),
    [aux_sym_zero_directive_token2] = ACTIONS(6671),
    [aux_sym_zero_directive_token3] = ACTIONS(6671),
    [aux_sym_zero_directive_token4] = ACTIONS(6671),
    [aux_sym_zero_directive_token5] = ACTIONS(6671),
    [aux_sym_zero_directive_token6] = ACTIONS(6671),
    [aux_sym_zero_directive_token7] = ACTIONS(6671),
    [aux_sym_zero_directive_token8] = ACTIONS(6671),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6671),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6671),
    [anon_sym_wire] = ACTIONS(6669),
    [anon_sym_tri] = ACTIONS(6669),
    [anon_sym_tri0] = ACTIONS(6669),
    [anon_sym_tri1] = ACTIONS(6669),
    [anon_sym_wand] = ACTIONS(6669),
    [anon_sym_triand] = ACTIONS(6669),
    [anon_sym_wor] = ACTIONS(6669),
    [anon_sym_trior] = ACTIONS(6669),
    [anon_sym_trireg] = ACTIONS(6669),
    [anon_sym_uwire] = ACTIONS(6669),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6671),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6671),
    [aux_sym_begin_keywords_token1] = ACTIONS(6671),
    [anon_sym_SEMI] = ACTIONS(6671),
    [anon_sym_endmodule] = ACTIONS(6669),
    [anon_sym_extern] = ACTIONS(6669),
    [anon_sym_module] = ACTIONS(6669),
    [anon_sym_macromodule] = ACTIONS(6669),
    [anon_sym_endinterface] = ACTIONS(6669),
    [anon_sym_interface] = ACTIONS(6669),
    [anon_sym_endprogram] = ACTIONS(6669),
    [anon_sym_program] = ACTIONS(6669),
    [anon_sym_checker] = ACTIONS(6669),
    [anon_sym_virtual] = ACTIONS(6669),
    [anon_sym_class] = ACTIONS(6669),
    [anon_sym_timeunit] = ACTIONS(6669),
    [anon_sym_timeprecision] = ACTIONS(6669),
    [anon_sym_type] = ACTIONS(6669),
    [anon_sym_input] = ACTIONS(6669),
    [anon_sym_output] = ACTIONS(6669),
    [anon_sym_inout] = ACTIONS(6669),
    [anon_sym_ref] = ACTIONS(6669),
    [anon_sym_DOLLARfatal] = ACTIONS(6671),
    [anon_sym_DOLLARerror] = ACTIONS(6671),
    [anon_sym_DOLLARwarning] = ACTIONS(6671),
    [anon_sym_DOLLARinfo] = ACTIONS(6671),
    [anon_sym_default] = ACTIONS(6669),
    [anon_sym_clocking] = ACTIONS(6669),
    [anon_sym_defparam] = ACTIONS(6669),
    [anon_sym_bind] = ACTIONS(6669),
    [anon_sym_const] = ACTIONS(6669),
    [anon_sym_function] = ACTIONS(6669),
    [anon_sym_static] = ACTIONS(6669),
    [anon_sym_constraint] = ACTIONS(6669),
    [anon_sym_if] = ACTIONS(6669),
    [anon_sym_else] = ACTIONS(6669),
    [anon_sym_LBRACK] = ACTIONS(6671),
    [anon_sym_localparam] = ACTIONS(6669),
    [anon_sym_parameter] = ACTIONS(6669),
    [anon_sym_specparam] = ACTIONS(6669),
    [anon_sym_var] = ACTIONS(6669),
    [anon_sym_import] = ACTIONS(6669),
    [anon_sym_export] = ACTIONS(6669),
    [anon_sym_genvar] = ACTIONS(6669),
    [anon_sym_interconnect] = ACTIONS(6669),
    [anon_sym_typedef] = ACTIONS(6669),
    [anon_sym_enum] = ACTIONS(6669),
    [anon_sym_struct] = ACTIONS(6669),
    [anon_sym_union] = ACTIONS(6669),
    [anon_sym_nettype] = ACTIONS(6669),
    [anon_sym_automatic] = ACTIONS(6669),
    [anon_sym_string] = ACTIONS(6669),
    [anon_sym_chandle] = ACTIONS(6669),
    [anon_sym_event] = ACTIONS(6669),
    [anon_sym_byte] = ACTIONS(6669),
    [anon_sym_shortint] = ACTIONS(6669),
    [anon_sym_int] = ACTIONS(6669),
    [anon_sym_longint] = ACTIONS(6669),
    [anon_sym_integer] = ACTIONS(6669),
    [anon_sym_time] = ACTIONS(6669),
    [anon_sym_bit] = ACTIONS(6669),
    [anon_sym_logic] = ACTIONS(6669),
    [anon_sym_reg] = ACTIONS(6669),
    [anon_sym_shortreal] = ACTIONS(6669),
    [anon_sym_real] = ACTIONS(6669),
    [anon_sym_realtime] = ACTIONS(6669),
    [anon_sym_supply0] = ACTIONS(6669),
    [anon_sym_supply1] = ACTIONS(6669),
    [anon_sym_signed] = ACTIONS(6669),
    [anon_sym_unsigned] = ACTIONS(6669),
    [anon_sym_task] = ACTIONS(6669),
    [anon_sym_modport] = ACTIONS(6669),
    [anon_sym_assert] = ACTIONS(6669),
    [anon_sym_property] = ACTIONS(6669),
    [anon_sym_assume] = ACTIONS(6669),
    [anon_sym_cover] = ACTIONS(6669),
    [anon_sym_sequence] = ACTIONS(6669),
    [anon_sym_restrict] = ACTIONS(6669),
    [anon_sym_not] = ACTIONS(6669),
    [anon_sym_or] = ACTIONS(6669),
    [anon_sym_and] = ACTIONS(6669),
    [anon_sym_case] = ACTIONS(6669),
    [anon_sym_always] = ACTIONS(6669),
    [anon_sym_covergroup] = ACTIONS(6669),
    [anon_sym_let] = ACTIONS(6669),
    [anon_sym_pulldown] = ACTIONS(6669),
    [anon_sym_pullup] = ACTIONS(6669),
    [anon_sym_cmos] = ACTIONS(6669),
    [anon_sym_rcmos] = ACTIONS(6669),
    [anon_sym_bufif0] = ACTIONS(6669),
    [anon_sym_bufif1] = ACTIONS(6669),
    [anon_sym_notif0] = ACTIONS(6669),
    [anon_sym_notif1] = ACTIONS(6669),
    [anon_sym_nmos] = ACTIONS(6669),
    [anon_sym_pmos] = ACTIONS(6669),
    [anon_sym_rnmos] = ACTIONS(6669),
    [anon_sym_rpmos] = ACTIONS(6669),
    [anon_sym_nand] = ACTIONS(6669),
    [anon_sym_nor] = ACTIONS(6669),
    [anon_sym_xor] = ACTIONS(6669),
    [anon_sym_xnor] = ACTIONS(6669),
    [anon_sym_buf] = ACTIONS(6669),
    [anon_sym_tranif0] = ACTIONS(6669),
    [anon_sym_tranif1] = ACTIONS(6669),
    [anon_sym_rtranif1] = ACTIONS(6669),
    [anon_sym_rtranif0] = ACTIONS(6669),
    [anon_sym_tran] = ACTIONS(6669),
    [anon_sym_rtran] = ACTIONS(6669),
    [anon_sym_generate] = ACTIONS(6669),
    [anon_sym_for] = ACTIONS(6669),
    [anon_sym_initial] = ACTIONS(6669),
    [anon_sym_assign] = ACTIONS(6669),
    [anon_sym_alias] = ACTIONS(6669),
    [anon_sym_always_comb] = ACTIONS(6669),
    [anon_sym_always_latch] = ACTIONS(6669),
    [anon_sym_always_ff] = ACTIONS(6669),
    [anon_sym_final] = ACTIONS(6669),
    [anon_sym_global] = ACTIONS(6669),
    [anon_sym_specify] = ACTIONS(6669),
    [anon_sym_LPAREN_STAR] = ACTIONS(6671),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6671),
    [anon_sym_DOLLARunit] = ACTIONS(6671),
  },
  [1227] = {
    [sym_simple_identifier] = ACTIONS(6673),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6675),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6675),
    [anon_sym_BQUOTE] = ACTIONS(6673),
    [aux_sym_id_directive_token1] = ACTIONS(6675),
    [aux_sym_id_directive_token2] = ACTIONS(6675),
    [aux_sym_id_directive_token3] = ACTIONS(6675),
    [aux_sym_id_directive_token4] = ACTIONS(6673),
    [aux_sym_zero_directive_token1] = ACTIONS(6675),
    [aux_sym_zero_directive_token2] = ACTIONS(6675),
    [aux_sym_zero_directive_token3] = ACTIONS(6675),
    [aux_sym_zero_directive_token4] = ACTIONS(6675),
    [aux_sym_zero_directive_token5] = ACTIONS(6675),
    [aux_sym_zero_directive_token6] = ACTIONS(6675),
    [aux_sym_zero_directive_token7] = ACTIONS(6675),
    [aux_sym_zero_directive_token8] = ACTIONS(6675),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6675),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6675),
    [anon_sym_wire] = ACTIONS(6673),
    [anon_sym_tri] = ACTIONS(6673),
    [anon_sym_tri0] = ACTIONS(6673),
    [anon_sym_tri1] = ACTIONS(6673),
    [anon_sym_wand] = ACTIONS(6673),
    [anon_sym_triand] = ACTIONS(6673),
    [anon_sym_wor] = ACTIONS(6673),
    [anon_sym_trior] = ACTIONS(6673),
    [anon_sym_trireg] = ACTIONS(6673),
    [anon_sym_uwire] = ACTIONS(6673),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6675),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6675),
    [aux_sym_begin_keywords_token1] = ACTIONS(6675),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_endmodule] = ACTIONS(6673),
    [anon_sym_extern] = ACTIONS(6673),
    [anon_sym_module] = ACTIONS(6673),
    [anon_sym_macromodule] = ACTIONS(6673),
    [anon_sym_endinterface] = ACTIONS(6673),
    [anon_sym_interface] = ACTIONS(6673),
    [anon_sym_endprogram] = ACTIONS(6673),
    [anon_sym_program] = ACTIONS(6673),
    [anon_sym_checker] = ACTIONS(6673),
    [anon_sym_virtual] = ACTIONS(6673),
    [anon_sym_class] = ACTIONS(6673),
    [anon_sym_timeunit] = ACTIONS(6673),
    [anon_sym_timeprecision] = ACTIONS(6673),
    [anon_sym_type] = ACTIONS(6673),
    [anon_sym_input] = ACTIONS(6673),
    [anon_sym_output] = ACTIONS(6673),
    [anon_sym_inout] = ACTIONS(6673),
    [anon_sym_ref] = ACTIONS(6673),
    [anon_sym_DOLLARfatal] = ACTIONS(6675),
    [anon_sym_DOLLARerror] = ACTIONS(6675),
    [anon_sym_DOLLARwarning] = ACTIONS(6675),
    [anon_sym_DOLLARinfo] = ACTIONS(6675),
    [anon_sym_default] = ACTIONS(6673),
    [anon_sym_clocking] = ACTIONS(6673),
    [anon_sym_defparam] = ACTIONS(6673),
    [anon_sym_bind] = ACTIONS(6673),
    [anon_sym_const] = ACTIONS(6673),
    [anon_sym_function] = ACTIONS(6673),
    [anon_sym_static] = ACTIONS(6673),
    [anon_sym_constraint] = ACTIONS(6673),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_else] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [anon_sym_localparam] = ACTIONS(6673),
    [anon_sym_parameter] = ACTIONS(6673),
    [anon_sym_specparam] = ACTIONS(6673),
    [anon_sym_var] = ACTIONS(6673),
    [anon_sym_import] = ACTIONS(6673),
    [anon_sym_export] = ACTIONS(6673),
    [anon_sym_genvar] = ACTIONS(6673),
    [anon_sym_interconnect] = ACTIONS(6673),
    [anon_sym_typedef] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_struct] = ACTIONS(6673),
    [anon_sym_union] = ACTIONS(6673),
    [anon_sym_nettype] = ACTIONS(6673),
    [anon_sym_automatic] = ACTIONS(6673),
    [anon_sym_string] = ACTIONS(6673),
    [anon_sym_chandle] = ACTIONS(6673),
    [anon_sym_event] = ACTIONS(6673),
    [anon_sym_byte] = ACTIONS(6673),
    [anon_sym_shortint] = ACTIONS(6673),
    [anon_sym_int] = ACTIONS(6673),
    [anon_sym_longint] = ACTIONS(6673),
    [anon_sym_integer] = ACTIONS(6673),
    [anon_sym_time] = ACTIONS(6673),
    [anon_sym_bit] = ACTIONS(6673),
    [anon_sym_logic] = ACTIONS(6673),
    [anon_sym_reg] = ACTIONS(6673),
    [anon_sym_shortreal] = ACTIONS(6673),
    [anon_sym_real] = ACTIONS(6673),
    [anon_sym_realtime] = ACTIONS(6673),
    [anon_sym_supply0] = ACTIONS(6673),
    [anon_sym_supply1] = ACTIONS(6673),
    [anon_sym_signed] = ACTIONS(6673),
    [anon_sym_unsigned] = ACTIONS(6673),
    [anon_sym_task] = ACTIONS(6673),
    [anon_sym_modport] = ACTIONS(6673),
    [anon_sym_assert] = ACTIONS(6673),
    [anon_sym_property] = ACTIONS(6673),
    [anon_sym_assume] = ACTIONS(6673),
    [anon_sym_cover] = ACTIONS(6673),
    [anon_sym_sequence] = ACTIONS(6673),
    [anon_sym_restrict] = ACTIONS(6673),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_or] = ACTIONS(6673),
    [anon_sym_and] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_always] = ACTIONS(6673),
    [anon_sym_covergroup] = ACTIONS(6673),
    [anon_sym_let] = ACTIONS(6673),
    [anon_sym_pulldown] = ACTIONS(6673),
    [anon_sym_pullup] = ACTIONS(6673),
    [anon_sym_cmos] = ACTIONS(6673),
    [anon_sym_rcmos] = ACTIONS(6673),
    [anon_sym_bufif0] = ACTIONS(6673),
    [anon_sym_bufif1] = ACTIONS(6673),
    [anon_sym_notif0] = ACTIONS(6673),
    [anon_sym_notif1] = ACTIONS(6673),
    [anon_sym_nmos] = ACTIONS(6673),
    [anon_sym_pmos] = ACTIONS(6673),
    [anon_sym_rnmos] = ACTIONS(6673),
    [anon_sym_rpmos] = ACTIONS(6673),
    [anon_sym_nand] = ACTIONS(6673),
    [anon_sym_nor] = ACTIONS(6673),
    [anon_sym_xor] = ACTIONS(6673),
    [anon_sym_xnor] = ACTIONS(6673),
    [anon_sym_buf] = ACTIONS(6673),
    [anon_sym_tranif0] = ACTIONS(6673),
    [anon_sym_tranif1] = ACTIONS(6673),
    [anon_sym_rtranif1] = ACTIONS(6673),
    [anon_sym_rtranif0] = ACTIONS(6673),
    [anon_sym_tran] = ACTIONS(6673),
    [anon_sym_rtran] = ACTIONS(6673),
    [anon_sym_generate] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_initial] = ACTIONS(6673),
    [anon_sym_assign] = ACTIONS(6673),
    [anon_sym_alias] = ACTIONS(6673),
    [anon_sym_always_comb] = ACTIONS(6673),
    [anon_sym_always_latch] = ACTIONS(6673),
    [anon_sym_always_ff] = ACTIONS(6673),
    [anon_sym_final] = ACTIONS(6673),
    [anon_sym_global] = ACTIONS(6673),
    [anon_sym_specify] = ACTIONS(6673),
    [anon_sym_LPAREN_STAR] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6675),
    [anon_sym_DOLLARunit] = ACTIONS(6675),
  },
  [1228] = {
    [ts_builtin_sym_end] = ACTIONS(6677),
    [sym_simple_identifier] = ACTIONS(6679),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6677),
    [anon_sym_BQUOTE] = ACTIONS(6679),
    [aux_sym_id_directive_token1] = ACTIONS(6677),
    [aux_sym_id_directive_token2] = ACTIONS(6677),
    [aux_sym_id_directive_token3] = ACTIONS(6677),
    [aux_sym_id_directive_token4] = ACTIONS(6679),
    [aux_sym_zero_directive_token1] = ACTIONS(6677),
    [aux_sym_zero_directive_token2] = ACTIONS(6677),
    [aux_sym_zero_directive_token3] = ACTIONS(6677),
    [aux_sym_zero_directive_token4] = ACTIONS(6677),
    [aux_sym_zero_directive_token5] = ACTIONS(6677),
    [aux_sym_zero_directive_token6] = ACTIONS(6677),
    [aux_sym_zero_directive_token7] = ACTIONS(6677),
    [aux_sym_zero_directive_token8] = ACTIONS(6677),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6677),
    [anon_sym_wire] = ACTIONS(6679),
    [anon_sym_tri] = ACTIONS(6679),
    [anon_sym_tri0] = ACTIONS(6679),
    [anon_sym_tri1] = ACTIONS(6679),
    [anon_sym_wand] = ACTIONS(6679),
    [anon_sym_triand] = ACTIONS(6679),
    [anon_sym_wor] = ACTIONS(6679),
    [anon_sym_trior] = ACTIONS(6679),
    [anon_sym_trireg] = ACTIONS(6679),
    [anon_sym_uwire] = ACTIONS(6679),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6677),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_begin_keywords_token1] = ACTIONS(6677),
    [anon_sym_SEMI] = ACTIONS(6677),
    [anon_sym_endmodule] = ACTIONS(6679),
    [anon_sym_COLON] = ACTIONS(6681),
    [anon_sym_extern] = ACTIONS(6679),
    [anon_sym_module] = ACTIONS(6679),
    [anon_sym_macromodule] = ACTIONS(6679),
    [anon_sym_interface] = ACTIONS(6679),
    [anon_sym_program] = ACTIONS(6679),
    [anon_sym_checker] = ACTIONS(6679),
    [anon_sym_virtual] = ACTIONS(6679),
    [anon_sym_class] = ACTIONS(6679),
    [anon_sym_package] = ACTIONS(6679),
    [anon_sym_timeunit] = ACTIONS(6679),
    [anon_sym_timeprecision] = ACTIONS(6679),
    [anon_sym_type] = ACTIONS(6679),
    [anon_sym_input] = ACTIONS(6679),
    [anon_sym_output] = ACTIONS(6679),
    [anon_sym_inout] = ACTIONS(6679),
    [anon_sym_ref] = ACTIONS(6679),
    [anon_sym_DOLLARfatal] = ACTIONS(6677),
    [anon_sym_DOLLARerror] = ACTIONS(6677),
    [anon_sym_DOLLARwarning] = ACTIONS(6677),
    [anon_sym_DOLLARinfo] = ACTIONS(6677),
    [anon_sym_default] = ACTIONS(6679),
    [anon_sym_clocking] = ACTIONS(6679),
    [anon_sym_defparam] = ACTIONS(6679),
    [anon_sym_bind] = ACTIONS(6679),
    [anon_sym_const] = ACTIONS(6679),
    [anon_sym_function] = ACTIONS(6679),
    [anon_sym_static] = ACTIONS(6679),
    [anon_sym_constraint] = ACTIONS(6679),
    [anon_sym_if] = ACTIONS(6679),
    [anon_sym_LBRACK] = ACTIONS(6677),
    [anon_sym_localparam] = ACTIONS(6679),
    [anon_sym_parameter] = ACTIONS(6679),
    [anon_sym_specparam] = ACTIONS(6679),
    [anon_sym_var] = ACTIONS(6679),
    [anon_sym_import] = ACTIONS(6679),
    [anon_sym_export] = ACTIONS(6679),
    [anon_sym_genvar] = ACTIONS(6679),
    [anon_sym_interconnect] = ACTIONS(6679),
    [anon_sym_typedef] = ACTIONS(6679),
    [anon_sym_enum] = ACTIONS(6679),
    [anon_sym_struct] = ACTIONS(6679),
    [anon_sym_union] = ACTIONS(6679),
    [anon_sym_nettype] = ACTIONS(6679),
    [anon_sym_automatic] = ACTIONS(6679),
    [anon_sym_string] = ACTIONS(6679),
    [anon_sym_chandle] = ACTIONS(6679),
    [anon_sym_event] = ACTIONS(6679),
    [anon_sym_byte] = ACTIONS(6679),
    [anon_sym_shortint] = ACTIONS(6679),
    [anon_sym_int] = ACTIONS(6679),
    [anon_sym_longint] = ACTIONS(6679),
    [anon_sym_integer] = ACTIONS(6679),
    [anon_sym_time] = ACTIONS(6679),
    [anon_sym_bit] = ACTIONS(6679),
    [anon_sym_logic] = ACTIONS(6679),
    [anon_sym_reg] = ACTIONS(6679),
    [anon_sym_shortreal] = ACTIONS(6679),
    [anon_sym_real] = ACTIONS(6679),
    [anon_sym_realtime] = ACTIONS(6679),
    [anon_sym_supply0] = ACTIONS(6679),
    [anon_sym_supply1] = ACTIONS(6679),
    [anon_sym_signed] = ACTIONS(6679),
    [anon_sym_unsigned] = ACTIONS(6679),
    [anon_sym_task] = ACTIONS(6679),
    [anon_sym_assert] = ACTIONS(6679),
    [anon_sym_property] = ACTIONS(6679),
    [anon_sym_assume] = ACTIONS(6679),
    [anon_sym_cover] = ACTIONS(6679),
    [anon_sym_sequence] = ACTIONS(6679),
    [anon_sym_restrict] = ACTIONS(6679),
    [anon_sym_not] = ACTIONS(6679),
    [anon_sym_or] = ACTIONS(6679),
    [anon_sym_and] = ACTIONS(6679),
    [anon_sym_case] = ACTIONS(6679),
    [anon_sym_always] = ACTIONS(6679),
    [anon_sym_covergroup] = ACTIONS(6679),
    [anon_sym_let] = ACTIONS(6679),
    [anon_sym_pulldown] = ACTIONS(6679),
    [anon_sym_pullup] = ACTIONS(6679),
    [anon_sym_cmos] = ACTIONS(6679),
    [anon_sym_rcmos] = ACTIONS(6679),
    [anon_sym_bufif0] = ACTIONS(6679),
    [anon_sym_bufif1] = ACTIONS(6679),
    [anon_sym_notif0] = ACTIONS(6679),
    [anon_sym_notif1] = ACTIONS(6679),
    [anon_sym_nmos] = ACTIONS(6679),
    [anon_sym_pmos] = ACTIONS(6679),
    [anon_sym_rnmos] = ACTIONS(6679),
    [anon_sym_rpmos] = ACTIONS(6679),
    [anon_sym_nand] = ACTIONS(6679),
    [anon_sym_nor] = ACTIONS(6679),
    [anon_sym_xor] = ACTIONS(6679),
    [anon_sym_xnor] = ACTIONS(6679),
    [anon_sym_buf] = ACTIONS(6679),
    [anon_sym_tranif0] = ACTIONS(6679),
    [anon_sym_tranif1] = ACTIONS(6679),
    [anon_sym_rtranif1] = ACTIONS(6679),
    [anon_sym_rtranif0] = ACTIONS(6679),
    [anon_sym_tran] = ACTIONS(6679),
    [anon_sym_rtran] = ACTIONS(6679),
    [anon_sym_generate] = ACTIONS(6679),
    [anon_sym_for] = ACTIONS(6679),
    [anon_sym_primitive] = ACTIONS(6679),
    [anon_sym_initial] = ACTIONS(6679),
    [anon_sym_assign] = ACTIONS(6679),
    [anon_sym_alias] = ACTIONS(6679),
    [anon_sym_always_comb] = ACTIONS(6679),
    [anon_sym_always_latch] = ACTIONS(6679),
    [anon_sym_always_ff] = ACTIONS(6679),
    [anon_sym_final] = ACTIONS(6679),
    [anon_sym_global] = ACTIONS(6679),
    [anon_sym_specify] = ACTIONS(6679),
    [anon_sym_LPAREN_STAR] = ACTIONS(6677),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6677),
    [anon_sym_DOLLARunit] = ACTIONS(6677),
  },
  [1229] = {
    [sym_simple_identifier] = ACTIONS(6683),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6685),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6685),
    [anon_sym_BQUOTE] = ACTIONS(6683),
    [aux_sym_id_directive_token1] = ACTIONS(6685),
    [aux_sym_id_directive_token2] = ACTIONS(6685),
    [aux_sym_id_directive_token3] = ACTIONS(6685),
    [aux_sym_id_directive_token4] = ACTIONS(6683),
    [aux_sym_zero_directive_token1] = ACTIONS(6685),
    [aux_sym_zero_directive_token2] = ACTIONS(6685),
    [aux_sym_zero_directive_token3] = ACTIONS(6685),
    [aux_sym_zero_directive_token4] = ACTIONS(6685),
    [aux_sym_zero_directive_token5] = ACTIONS(6685),
    [aux_sym_zero_directive_token6] = ACTIONS(6685),
    [aux_sym_zero_directive_token7] = ACTIONS(6685),
    [aux_sym_zero_directive_token8] = ACTIONS(6685),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6685),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6685),
    [anon_sym_wire] = ACTIONS(6683),
    [anon_sym_tri] = ACTIONS(6683),
    [anon_sym_tri0] = ACTIONS(6683),
    [anon_sym_tri1] = ACTIONS(6683),
    [anon_sym_wand] = ACTIONS(6683),
    [anon_sym_triand] = ACTIONS(6683),
    [anon_sym_wor] = ACTIONS(6683),
    [anon_sym_trior] = ACTIONS(6683),
    [anon_sym_trireg] = ACTIONS(6683),
    [anon_sym_uwire] = ACTIONS(6683),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6685),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6685),
    [aux_sym_begin_keywords_token1] = ACTIONS(6685),
    [anon_sym_SEMI] = ACTIONS(6685),
    [anon_sym_endmodule] = ACTIONS(6683),
    [anon_sym_extern] = ACTIONS(6683),
    [anon_sym_module] = ACTIONS(6683),
    [anon_sym_macromodule] = ACTIONS(6683),
    [anon_sym_endinterface] = ACTIONS(6683),
    [anon_sym_interface] = ACTIONS(6683),
    [anon_sym_endprogram] = ACTIONS(6683),
    [anon_sym_program] = ACTIONS(6683),
    [anon_sym_checker] = ACTIONS(6683),
    [anon_sym_virtual] = ACTIONS(6683),
    [anon_sym_class] = ACTIONS(6683),
    [anon_sym_timeunit] = ACTIONS(6683),
    [anon_sym_timeprecision] = ACTIONS(6683),
    [anon_sym_type] = ACTIONS(6683),
    [anon_sym_input] = ACTIONS(6683),
    [anon_sym_output] = ACTIONS(6683),
    [anon_sym_inout] = ACTIONS(6683),
    [anon_sym_ref] = ACTIONS(6683),
    [anon_sym_DOLLARfatal] = ACTIONS(6685),
    [anon_sym_DOLLARerror] = ACTIONS(6685),
    [anon_sym_DOLLARwarning] = ACTIONS(6685),
    [anon_sym_DOLLARinfo] = ACTIONS(6685),
    [anon_sym_default] = ACTIONS(6683),
    [anon_sym_clocking] = ACTIONS(6683),
    [anon_sym_defparam] = ACTIONS(6683),
    [anon_sym_bind] = ACTIONS(6683),
    [anon_sym_const] = ACTIONS(6683),
    [anon_sym_function] = ACTIONS(6683),
    [anon_sym_static] = ACTIONS(6683),
    [anon_sym_constraint] = ACTIONS(6683),
    [anon_sym_if] = ACTIONS(6683),
    [anon_sym_else] = ACTIONS(6683),
    [anon_sym_LBRACK] = ACTIONS(6685),
    [anon_sym_localparam] = ACTIONS(6683),
    [anon_sym_parameter] = ACTIONS(6683),
    [anon_sym_specparam] = ACTIONS(6683),
    [anon_sym_var] = ACTIONS(6683),
    [anon_sym_import] = ACTIONS(6683),
    [anon_sym_export] = ACTIONS(6683),
    [anon_sym_genvar] = ACTIONS(6683),
    [anon_sym_interconnect] = ACTIONS(6683),
    [anon_sym_typedef] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_struct] = ACTIONS(6683),
    [anon_sym_union] = ACTIONS(6683),
    [anon_sym_nettype] = ACTIONS(6683),
    [anon_sym_automatic] = ACTIONS(6683),
    [anon_sym_string] = ACTIONS(6683),
    [anon_sym_chandle] = ACTIONS(6683),
    [anon_sym_event] = ACTIONS(6683),
    [anon_sym_byte] = ACTIONS(6683),
    [anon_sym_shortint] = ACTIONS(6683),
    [anon_sym_int] = ACTIONS(6683),
    [anon_sym_longint] = ACTIONS(6683),
    [anon_sym_integer] = ACTIONS(6683),
    [anon_sym_time] = ACTIONS(6683),
    [anon_sym_bit] = ACTIONS(6683),
    [anon_sym_logic] = ACTIONS(6683),
    [anon_sym_reg] = ACTIONS(6683),
    [anon_sym_shortreal] = ACTIONS(6683),
    [anon_sym_real] = ACTIONS(6683),
    [anon_sym_realtime] = ACTIONS(6683),
    [anon_sym_supply0] = ACTIONS(6683),
    [anon_sym_supply1] = ACTIONS(6683),
    [anon_sym_signed] = ACTIONS(6683),
    [anon_sym_unsigned] = ACTIONS(6683),
    [anon_sym_task] = ACTIONS(6683),
    [anon_sym_modport] = ACTIONS(6683),
    [anon_sym_assert] = ACTIONS(6683),
    [anon_sym_property] = ACTIONS(6683),
    [anon_sym_assume] = ACTIONS(6683),
    [anon_sym_cover] = ACTIONS(6683),
    [anon_sym_sequence] = ACTIONS(6683),
    [anon_sym_restrict] = ACTIONS(6683),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_or] = ACTIONS(6683),
    [anon_sym_and] = ACTIONS(6683),
    [anon_sym_case] = ACTIONS(6683),
    [anon_sym_always] = ACTIONS(6683),
    [anon_sym_covergroup] = ACTIONS(6683),
    [anon_sym_let] = ACTIONS(6683),
    [anon_sym_pulldown] = ACTIONS(6683),
    [anon_sym_pullup] = ACTIONS(6683),
    [anon_sym_cmos] = ACTIONS(6683),
    [anon_sym_rcmos] = ACTIONS(6683),
    [anon_sym_bufif0] = ACTIONS(6683),
    [anon_sym_bufif1] = ACTIONS(6683),
    [anon_sym_notif0] = ACTIONS(6683),
    [anon_sym_notif1] = ACTIONS(6683),
    [anon_sym_nmos] = ACTIONS(6683),
    [anon_sym_pmos] = ACTIONS(6683),
    [anon_sym_rnmos] = ACTIONS(6683),
    [anon_sym_rpmos] = ACTIONS(6683),
    [anon_sym_nand] = ACTIONS(6683),
    [anon_sym_nor] = ACTIONS(6683),
    [anon_sym_xor] = ACTIONS(6683),
    [anon_sym_xnor] = ACTIONS(6683),
    [anon_sym_buf] = ACTIONS(6683),
    [anon_sym_tranif0] = ACTIONS(6683),
    [anon_sym_tranif1] = ACTIONS(6683),
    [anon_sym_rtranif1] = ACTIONS(6683),
    [anon_sym_rtranif0] = ACTIONS(6683),
    [anon_sym_tran] = ACTIONS(6683),
    [anon_sym_rtran] = ACTIONS(6683),
    [anon_sym_generate] = ACTIONS(6683),
    [anon_sym_for] = ACTIONS(6683),
    [anon_sym_initial] = ACTIONS(6683),
    [anon_sym_assign] = ACTIONS(6683),
    [anon_sym_alias] = ACTIONS(6683),
    [anon_sym_always_comb] = ACTIONS(6683),
    [anon_sym_always_latch] = ACTIONS(6683),
    [anon_sym_always_ff] = ACTIONS(6683),
    [anon_sym_final] = ACTIONS(6683),
    [anon_sym_global] = ACTIONS(6683),
    [anon_sym_specify] = ACTIONS(6683),
    [anon_sym_LPAREN_STAR] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6685),
    [anon_sym_DOLLARunit] = ACTIONS(6685),
  },
  [1230] = {
    [sym_simple_identifier] = ACTIONS(6687),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6689),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6689),
    [anon_sym_BQUOTE] = ACTIONS(6687),
    [aux_sym_id_directive_token1] = ACTIONS(6689),
    [aux_sym_id_directive_token2] = ACTIONS(6689),
    [aux_sym_id_directive_token3] = ACTIONS(6689),
    [aux_sym_id_directive_token4] = ACTIONS(6687),
    [aux_sym_zero_directive_token1] = ACTIONS(6689),
    [aux_sym_zero_directive_token2] = ACTIONS(6689),
    [aux_sym_zero_directive_token3] = ACTIONS(6689),
    [aux_sym_zero_directive_token4] = ACTIONS(6689),
    [aux_sym_zero_directive_token5] = ACTIONS(6689),
    [aux_sym_zero_directive_token6] = ACTIONS(6689),
    [aux_sym_zero_directive_token7] = ACTIONS(6689),
    [aux_sym_zero_directive_token8] = ACTIONS(6689),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6689),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6689),
    [anon_sym_wire] = ACTIONS(6687),
    [anon_sym_tri] = ACTIONS(6687),
    [anon_sym_tri0] = ACTIONS(6687),
    [anon_sym_tri1] = ACTIONS(6687),
    [anon_sym_wand] = ACTIONS(6687),
    [anon_sym_triand] = ACTIONS(6687),
    [anon_sym_wor] = ACTIONS(6687),
    [anon_sym_trior] = ACTIONS(6687),
    [anon_sym_trireg] = ACTIONS(6687),
    [anon_sym_uwire] = ACTIONS(6687),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6689),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6689),
    [aux_sym_begin_keywords_token1] = ACTIONS(6689),
    [anon_sym_SEMI] = ACTIONS(6689),
    [anon_sym_endmodule] = ACTIONS(6687),
    [anon_sym_extern] = ACTIONS(6687),
    [anon_sym_module] = ACTIONS(6687),
    [anon_sym_macromodule] = ACTIONS(6687),
    [anon_sym_endinterface] = ACTIONS(6687),
    [anon_sym_interface] = ACTIONS(6687),
    [anon_sym_endprogram] = ACTIONS(6687),
    [anon_sym_program] = ACTIONS(6687),
    [anon_sym_checker] = ACTIONS(6687),
    [anon_sym_virtual] = ACTIONS(6687),
    [anon_sym_class] = ACTIONS(6687),
    [anon_sym_timeunit] = ACTIONS(6687),
    [anon_sym_timeprecision] = ACTIONS(6687),
    [anon_sym_type] = ACTIONS(6687),
    [anon_sym_input] = ACTIONS(6687),
    [anon_sym_output] = ACTIONS(6687),
    [anon_sym_inout] = ACTIONS(6687),
    [anon_sym_ref] = ACTIONS(6687),
    [anon_sym_DOLLARfatal] = ACTIONS(6689),
    [anon_sym_DOLLARerror] = ACTIONS(6689),
    [anon_sym_DOLLARwarning] = ACTIONS(6689),
    [anon_sym_DOLLARinfo] = ACTIONS(6689),
    [anon_sym_default] = ACTIONS(6687),
    [anon_sym_clocking] = ACTIONS(6687),
    [anon_sym_defparam] = ACTIONS(6687),
    [anon_sym_bind] = ACTIONS(6687),
    [anon_sym_const] = ACTIONS(6687),
    [anon_sym_function] = ACTIONS(6687),
    [anon_sym_static] = ACTIONS(6687),
    [anon_sym_constraint] = ACTIONS(6687),
    [anon_sym_if] = ACTIONS(6687),
    [anon_sym_else] = ACTIONS(6687),
    [anon_sym_LBRACK] = ACTIONS(6689),
    [anon_sym_localparam] = ACTIONS(6687),
    [anon_sym_parameter] = ACTIONS(6687),
    [anon_sym_specparam] = ACTIONS(6687),
    [anon_sym_var] = ACTIONS(6687),
    [anon_sym_import] = ACTIONS(6687),
    [anon_sym_export] = ACTIONS(6687),
    [anon_sym_genvar] = ACTIONS(6687),
    [anon_sym_interconnect] = ACTIONS(6687),
    [anon_sym_typedef] = ACTIONS(6687),
    [anon_sym_enum] = ACTIONS(6687),
    [anon_sym_struct] = ACTIONS(6687),
    [anon_sym_union] = ACTIONS(6687),
    [anon_sym_nettype] = ACTIONS(6687),
    [anon_sym_automatic] = ACTIONS(6687),
    [anon_sym_string] = ACTIONS(6687),
    [anon_sym_chandle] = ACTIONS(6687),
    [anon_sym_event] = ACTIONS(6687),
    [anon_sym_byte] = ACTIONS(6687),
    [anon_sym_shortint] = ACTIONS(6687),
    [anon_sym_int] = ACTIONS(6687),
    [anon_sym_longint] = ACTIONS(6687),
    [anon_sym_integer] = ACTIONS(6687),
    [anon_sym_time] = ACTIONS(6687),
    [anon_sym_bit] = ACTIONS(6687),
    [anon_sym_logic] = ACTIONS(6687),
    [anon_sym_reg] = ACTIONS(6687),
    [anon_sym_shortreal] = ACTIONS(6687),
    [anon_sym_real] = ACTIONS(6687),
    [anon_sym_realtime] = ACTIONS(6687),
    [anon_sym_supply0] = ACTIONS(6687),
    [anon_sym_supply1] = ACTIONS(6687),
    [anon_sym_signed] = ACTIONS(6687),
    [anon_sym_unsigned] = ACTIONS(6687),
    [anon_sym_task] = ACTIONS(6687),
    [anon_sym_modport] = ACTIONS(6687),
    [anon_sym_assert] = ACTIONS(6687),
    [anon_sym_property] = ACTIONS(6687),
    [anon_sym_assume] = ACTIONS(6687),
    [anon_sym_cover] = ACTIONS(6687),
    [anon_sym_sequence] = ACTIONS(6687),
    [anon_sym_restrict] = ACTIONS(6687),
    [anon_sym_not] = ACTIONS(6687),
    [anon_sym_or] = ACTIONS(6687),
    [anon_sym_and] = ACTIONS(6687),
    [anon_sym_case] = ACTIONS(6687),
    [anon_sym_always] = ACTIONS(6687),
    [anon_sym_covergroup] = ACTIONS(6687),
    [anon_sym_let] = ACTIONS(6687),
    [anon_sym_pulldown] = ACTIONS(6687),
    [anon_sym_pullup] = ACTIONS(6687),
    [anon_sym_cmos] = ACTIONS(6687),
    [anon_sym_rcmos] = ACTIONS(6687),
    [anon_sym_bufif0] = ACTIONS(6687),
    [anon_sym_bufif1] = ACTIONS(6687),
    [anon_sym_notif0] = ACTIONS(6687),
    [anon_sym_notif1] = ACTIONS(6687),
    [anon_sym_nmos] = ACTIONS(6687),
    [anon_sym_pmos] = ACTIONS(6687),
    [anon_sym_rnmos] = ACTIONS(6687),
    [anon_sym_rpmos] = ACTIONS(6687),
    [anon_sym_nand] = ACTIONS(6687),
    [anon_sym_nor] = ACTIONS(6687),
    [anon_sym_xor] = ACTIONS(6687),
    [anon_sym_xnor] = ACTIONS(6687),
    [anon_sym_buf] = ACTIONS(6687),
    [anon_sym_tranif0] = ACTIONS(6687),
    [anon_sym_tranif1] = ACTIONS(6687),
    [anon_sym_rtranif1] = ACTIONS(6687),
    [anon_sym_rtranif0] = ACTIONS(6687),
    [anon_sym_tran] = ACTIONS(6687),
    [anon_sym_rtran] = ACTIONS(6687),
    [anon_sym_generate] = ACTIONS(6687),
    [anon_sym_for] = ACTIONS(6687),
    [anon_sym_initial] = ACTIONS(6687),
    [anon_sym_assign] = ACTIONS(6687),
    [anon_sym_alias] = ACTIONS(6687),
    [anon_sym_always_comb] = ACTIONS(6687),
    [anon_sym_always_latch] = ACTIONS(6687),
    [anon_sym_always_ff] = ACTIONS(6687),
    [anon_sym_final] = ACTIONS(6687),
    [anon_sym_global] = ACTIONS(6687),
    [anon_sym_specify] = ACTIONS(6687),
    [anon_sym_LPAREN_STAR] = ACTIONS(6689),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6689),
    [anon_sym_DOLLARunit] = ACTIONS(6689),
  },
  [1231] = {
    [sym_simple_identifier] = ACTIONS(6691),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6693),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6693),
    [anon_sym_BQUOTE] = ACTIONS(6691),
    [aux_sym_id_directive_token1] = ACTIONS(6693),
    [aux_sym_id_directive_token2] = ACTIONS(6693),
    [aux_sym_id_directive_token3] = ACTIONS(6693),
    [aux_sym_id_directive_token4] = ACTIONS(6691),
    [aux_sym_zero_directive_token1] = ACTIONS(6693),
    [aux_sym_zero_directive_token2] = ACTIONS(6693),
    [aux_sym_zero_directive_token3] = ACTIONS(6693),
    [aux_sym_zero_directive_token4] = ACTIONS(6693),
    [aux_sym_zero_directive_token5] = ACTIONS(6693),
    [aux_sym_zero_directive_token6] = ACTIONS(6693),
    [aux_sym_zero_directive_token7] = ACTIONS(6693),
    [aux_sym_zero_directive_token8] = ACTIONS(6693),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6693),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6693),
    [anon_sym_wire] = ACTIONS(6691),
    [anon_sym_tri] = ACTIONS(6691),
    [anon_sym_tri0] = ACTIONS(6691),
    [anon_sym_tri1] = ACTIONS(6691),
    [anon_sym_wand] = ACTIONS(6691),
    [anon_sym_triand] = ACTIONS(6691),
    [anon_sym_wor] = ACTIONS(6691),
    [anon_sym_trior] = ACTIONS(6691),
    [anon_sym_trireg] = ACTIONS(6691),
    [anon_sym_uwire] = ACTIONS(6691),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6693),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6693),
    [aux_sym_begin_keywords_token1] = ACTIONS(6693),
    [anon_sym_SEMI] = ACTIONS(6693),
    [anon_sym_endmodule] = ACTIONS(6691),
    [anon_sym_extern] = ACTIONS(6691),
    [anon_sym_module] = ACTIONS(6691),
    [anon_sym_macromodule] = ACTIONS(6691),
    [anon_sym_endinterface] = ACTIONS(6691),
    [anon_sym_interface] = ACTIONS(6691),
    [anon_sym_endprogram] = ACTIONS(6691),
    [anon_sym_program] = ACTIONS(6691),
    [anon_sym_checker] = ACTIONS(6691),
    [anon_sym_virtual] = ACTIONS(6691),
    [anon_sym_class] = ACTIONS(6691),
    [anon_sym_timeunit] = ACTIONS(6691),
    [anon_sym_timeprecision] = ACTIONS(6691),
    [anon_sym_type] = ACTIONS(6691),
    [anon_sym_input] = ACTIONS(6691),
    [anon_sym_output] = ACTIONS(6691),
    [anon_sym_inout] = ACTIONS(6691),
    [anon_sym_ref] = ACTIONS(6691),
    [anon_sym_DOLLARfatal] = ACTIONS(6693),
    [anon_sym_DOLLARerror] = ACTIONS(6693),
    [anon_sym_DOLLARwarning] = ACTIONS(6693),
    [anon_sym_DOLLARinfo] = ACTIONS(6693),
    [anon_sym_default] = ACTIONS(6691),
    [anon_sym_clocking] = ACTIONS(6691),
    [anon_sym_defparam] = ACTIONS(6691),
    [anon_sym_bind] = ACTIONS(6691),
    [anon_sym_const] = ACTIONS(6691),
    [anon_sym_function] = ACTIONS(6691),
    [anon_sym_static] = ACTIONS(6691),
    [anon_sym_constraint] = ACTIONS(6691),
    [anon_sym_if] = ACTIONS(6691),
    [anon_sym_else] = ACTIONS(6691),
    [anon_sym_LBRACK] = ACTIONS(6693),
    [anon_sym_localparam] = ACTIONS(6691),
    [anon_sym_parameter] = ACTIONS(6691),
    [anon_sym_specparam] = ACTIONS(6691),
    [anon_sym_var] = ACTIONS(6691),
    [anon_sym_import] = ACTIONS(6691),
    [anon_sym_export] = ACTIONS(6691),
    [anon_sym_genvar] = ACTIONS(6691),
    [anon_sym_interconnect] = ACTIONS(6691),
    [anon_sym_typedef] = ACTIONS(6691),
    [anon_sym_enum] = ACTIONS(6691),
    [anon_sym_struct] = ACTIONS(6691),
    [anon_sym_union] = ACTIONS(6691),
    [anon_sym_nettype] = ACTIONS(6691),
    [anon_sym_automatic] = ACTIONS(6691),
    [anon_sym_string] = ACTIONS(6691),
    [anon_sym_chandle] = ACTIONS(6691),
    [anon_sym_event] = ACTIONS(6691),
    [anon_sym_byte] = ACTIONS(6691),
    [anon_sym_shortint] = ACTIONS(6691),
    [anon_sym_int] = ACTIONS(6691),
    [anon_sym_longint] = ACTIONS(6691),
    [anon_sym_integer] = ACTIONS(6691),
    [anon_sym_time] = ACTIONS(6691),
    [anon_sym_bit] = ACTIONS(6691),
    [anon_sym_logic] = ACTIONS(6691),
    [anon_sym_reg] = ACTIONS(6691),
    [anon_sym_shortreal] = ACTIONS(6691),
    [anon_sym_real] = ACTIONS(6691),
    [anon_sym_realtime] = ACTIONS(6691),
    [anon_sym_supply0] = ACTIONS(6691),
    [anon_sym_supply1] = ACTIONS(6691),
    [anon_sym_signed] = ACTIONS(6691),
    [anon_sym_unsigned] = ACTIONS(6691),
    [anon_sym_task] = ACTIONS(6691),
    [anon_sym_modport] = ACTIONS(6691),
    [anon_sym_assert] = ACTIONS(6691),
    [anon_sym_property] = ACTIONS(6691),
    [anon_sym_assume] = ACTIONS(6691),
    [anon_sym_cover] = ACTIONS(6691),
    [anon_sym_sequence] = ACTIONS(6691),
    [anon_sym_restrict] = ACTIONS(6691),
    [anon_sym_not] = ACTIONS(6691),
    [anon_sym_or] = ACTIONS(6691),
    [anon_sym_and] = ACTIONS(6691),
    [anon_sym_case] = ACTIONS(6691),
    [anon_sym_always] = ACTIONS(6691),
    [anon_sym_covergroup] = ACTIONS(6691),
    [anon_sym_let] = ACTIONS(6691),
    [anon_sym_pulldown] = ACTIONS(6691),
    [anon_sym_pullup] = ACTIONS(6691),
    [anon_sym_cmos] = ACTIONS(6691),
    [anon_sym_rcmos] = ACTIONS(6691),
    [anon_sym_bufif0] = ACTIONS(6691),
    [anon_sym_bufif1] = ACTIONS(6691),
    [anon_sym_notif0] = ACTIONS(6691),
    [anon_sym_notif1] = ACTIONS(6691),
    [anon_sym_nmos] = ACTIONS(6691),
    [anon_sym_pmos] = ACTIONS(6691),
    [anon_sym_rnmos] = ACTIONS(6691),
    [anon_sym_rpmos] = ACTIONS(6691),
    [anon_sym_nand] = ACTIONS(6691),
    [anon_sym_nor] = ACTIONS(6691),
    [anon_sym_xor] = ACTIONS(6691),
    [anon_sym_xnor] = ACTIONS(6691),
    [anon_sym_buf] = ACTIONS(6691),
    [anon_sym_tranif0] = ACTIONS(6691),
    [anon_sym_tranif1] = ACTIONS(6691),
    [anon_sym_rtranif1] = ACTIONS(6691),
    [anon_sym_rtranif0] = ACTIONS(6691),
    [anon_sym_tran] = ACTIONS(6691),
    [anon_sym_rtran] = ACTIONS(6691),
    [anon_sym_generate] = ACTIONS(6691),
    [anon_sym_for] = ACTIONS(6691),
    [anon_sym_initial] = ACTIONS(6691),
    [anon_sym_assign] = ACTIONS(6691),
    [anon_sym_alias] = ACTIONS(6691),
    [anon_sym_always_comb] = ACTIONS(6691),
    [anon_sym_always_latch] = ACTIONS(6691),
    [anon_sym_always_ff] = ACTIONS(6691),
    [anon_sym_final] = ACTIONS(6691),
    [anon_sym_global] = ACTIONS(6691),
    [anon_sym_specify] = ACTIONS(6691),
    [anon_sym_LPAREN_STAR] = ACTIONS(6693),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6693),
    [anon_sym_DOLLARunit] = ACTIONS(6693),
  },
  [1232] = {
    [sym_simple_identifier] = ACTIONS(6695),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6697),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6697),
    [anon_sym_BQUOTE] = ACTIONS(6695),
    [aux_sym_id_directive_token1] = ACTIONS(6697),
    [aux_sym_id_directive_token2] = ACTIONS(6697),
    [aux_sym_id_directive_token3] = ACTIONS(6697),
    [aux_sym_id_directive_token4] = ACTIONS(6695),
    [aux_sym_zero_directive_token1] = ACTIONS(6697),
    [aux_sym_zero_directive_token2] = ACTIONS(6697),
    [aux_sym_zero_directive_token3] = ACTIONS(6697),
    [aux_sym_zero_directive_token4] = ACTIONS(6697),
    [aux_sym_zero_directive_token5] = ACTIONS(6697),
    [aux_sym_zero_directive_token6] = ACTIONS(6697),
    [aux_sym_zero_directive_token7] = ACTIONS(6697),
    [aux_sym_zero_directive_token8] = ACTIONS(6697),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6697),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6697),
    [anon_sym_wire] = ACTIONS(6695),
    [anon_sym_tri] = ACTIONS(6695),
    [anon_sym_tri0] = ACTIONS(6695),
    [anon_sym_tri1] = ACTIONS(6695),
    [anon_sym_wand] = ACTIONS(6695),
    [anon_sym_triand] = ACTIONS(6695),
    [anon_sym_wor] = ACTIONS(6695),
    [anon_sym_trior] = ACTIONS(6695),
    [anon_sym_trireg] = ACTIONS(6695),
    [anon_sym_uwire] = ACTIONS(6695),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6697),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6697),
    [aux_sym_begin_keywords_token1] = ACTIONS(6697),
    [anon_sym_SEMI] = ACTIONS(6697),
    [anon_sym_endmodule] = ACTIONS(6695),
    [anon_sym_extern] = ACTIONS(6695),
    [anon_sym_module] = ACTIONS(6695),
    [anon_sym_macromodule] = ACTIONS(6695),
    [anon_sym_endinterface] = ACTIONS(6695),
    [anon_sym_interface] = ACTIONS(6695),
    [anon_sym_endprogram] = ACTIONS(6695),
    [anon_sym_program] = ACTIONS(6695),
    [anon_sym_checker] = ACTIONS(6695),
    [anon_sym_virtual] = ACTIONS(6695),
    [anon_sym_class] = ACTIONS(6695),
    [anon_sym_timeunit] = ACTIONS(6695),
    [anon_sym_timeprecision] = ACTIONS(6695),
    [anon_sym_type] = ACTIONS(6695),
    [anon_sym_input] = ACTIONS(6695),
    [anon_sym_output] = ACTIONS(6695),
    [anon_sym_inout] = ACTIONS(6695),
    [anon_sym_ref] = ACTIONS(6695),
    [anon_sym_DOLLARfatal] = ACTIONS(6697),
    [anon_sym_DOLLARerror] = ACTIONS(6697),
    [anon_sym_DOLLARwarning] = ACTIONS(6697),
    [anon_sym_DOLLARinfo] = ACTIONS(6697),
    [anon_sym_default] = ACTIONS(6695),
    [anon_sym_clocking] = ACTIONS(6695),
    [anon_sym_defparam] = ACTIONS(6695),
    [anon_sym_bind] = ACTIONS(6695),
    [anon_sym_const] = ACTIONS(6695),
    [anon_sym_function] = ACTIONS(6695),
    [anon_sym_static] = ACTIONS(6695),
    [anon_sym_constraint] = ACTIONS(6695),
    [anon_sym_if] = ACTIONS(6695),
    [anon_sym_else] = ACTIONS(6695),
    [anon_sym_LBRACK] = ACTIONS(6697),
    [anon_sym_localparam] = ACTIONS(6695),
    [anon_sym_parameter] = ACTIONS(6695),
    [anon_sym_specparam] = ACTIONS(6695),
    [anon_sym_var] = ACTIONS(6695),
    [anon_sym_import] = ACTIONS(6695),
    [anon_sym_export] = ACTIONS(6695),
    [anon_sym_genvar] = ACTIONS(6695),
    [anon_sym_interconnect] = ACTIONS(6695),
    [anon_sym_typedef] = ACTIONS(6695),
    [anon_sym_enum] = ACTIONS(6695),
    [anon_sym_struct] = ACTIONS(6695),
    [anon_sym_union] = ACTIONS(6695),
    [anon_sym_nettype] = ACTIONS(6695),
    [anon_sym_automatic] = ACTIONS(6695),
    [anon_sym_string] = ACTIONS(6695),
    [anon_sym_chandle] = ACTIONS(6695),
    [anon_sym_event] = ACTIONS(6695),
    [anon_sym_byte] = ACTIONS(6695),
    [anon_sym_shortint] = ACTIONS(6695),
    [anon_sym_int] = ACTIONS(6695),
    [anon_sym_longint] = ACTIONS(6695),
    [anon_sym_integer] = ACTIONS(6695),
    [anon_sym_time] = ACTIONS(6695),
    [anon_sym_bit] = ACTIONS(6695),
    [anon_sym_logic] = ACTIONS(6695),
    [anon_sym_reg] = ACTIONS(6695),
    [anon_sym_shortreal] = ACTIONS(6695),
    [anon_sym_real] = ACTIONS(6695),
    [anon_sym_realtime] = ACTIONS(6695),
    [anon_sym_supply0] = ACTIONS(6695),
    [anon_sym_supply1] = ACTIONS(6695),
    [anon_sym_signed] = ACTIONS(6695),
    [anon_sym_unsigned] = ACTIONS(6695),
    [anon_sym_task] = ACTIONS(6695),
    [anon_sym_modport] = ACTIONS(6695),
    [anon_sym_assert] = ACTIONS(6695),
    [anon_sym_property] = ACTIONS(6695),
    [anon_sym_assume] = ACTIONS(6695),
    [anon_sym_cover] = ACTIONS(6695),
    [anon_sym_sequence] = ACTIONS(6695),
    [anon_sym_restrict] = ACTIONS(6695),
    [anon_sym_not] = ACTIONS(6695),
    [anon_sym_or] = ACTIONS(6695),
    [anon_sym_and] = ACTIONS(6695),
    [anon_sym_case] = ACTIONS(6695),
    [anon_sym_always] = ACTIONS(6695),
    [anon_sym_covergroup] = ACTIONS(6695),
    [anon_sym_let] = ACTIONS(6695),
    [anon_sym_pulldown] = ACTIONS(6695),
    [anon_sym_pullup] = ACTIONS(6695),
    [anon_sym_cmos] = ACTIONS(6695),
    [anon_sym_rcmos] = ACTIONS(6695),
    [anon_sym_bufif0] = ACTIONS(6695),
    [anon_sym_bufif1] = ACTIONS(6695),
    [anon_sym_notif0] = ACTIONS(6695),
    [anon_sym_notif1] = ACTIONS(6695),
    [anon_sym_nmos] = ACTIONS(6695),
    [anon_sym_pmos] = ACTIONS(6695),
    [anon_sym_rnmos] = ACTIONS(6695),
    [anon_sym_rpmos] = ACTIONS(6695),
    [anon_sym_nand] = ACTIONS(6695),
    [anon_sym_nor] = ACTIONS(6695),
    [anon_sym_xor] = ACTIONS(6695),
    [anon_sym_xnor] = ACTIONS(6695),
    [anon_sym_buf] = ACTIONS(6695),
    [anon_sym_tranif0] = ACTIONS(6695),
    [anon_sym_tranif1] = ACTIONS(6695),
    [anon_sym_rtranif1] = ACTIONS(6695),
    [anon_sym_rtranif0] = ACTIONS(6695),
    [anon_sym_tran] = ACTIONS(6695),
    [anon_sym_rtran] = ACTIONS(6695),
    [anon_sym_generate] = ACTIONS(6695),
    [anon_sym_for] = ACTIONS(6695),
    [anon_sym_initial] = ACTIONS(6695),
    [anon_sym_assign] = ACTIONS(6695),
    [anon_sym_alias] = ACTIONS(6695),
    [anon_sym_always_comb] = ACTIONS(6695),
    [anon_sym_always_latch] = ACTIONS(6695),
    [anon_sym_always_ff] = ACTIONS(6695),
    [anon_sym_final] = ACTIONS(6695),
    [anon_sym_global] = ACTIONS(6695),
    [anon_sym_specify] = ACTIONS(6695),
    [anon_sym_LPAREN_STAR] = ACTIONS(6697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6697),
    [anon_sym_DOLLARunit] = ACTIONS(6697),
  },
  [1233] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6701),
    [anon_sym_BQUOTE] = ACTIONS(6699),
    [aux_sym_id_directive_token1] = ACTIONS(6701),
    [aux_sym_id_directive_token2] = ACTIONS(6701),
    [aux_sym_id_directive_token3] = ACTIONS(6701),
    [aux_sym_id_directive_token4] = ACTIONS(6699),
    [aux_sym_zero_directive_token1] = ACTIONS(6701),
    [aux_sym_zero_directive_token2] = ACTIONS(6701),
    [aux_sym_zero_directive_token3] = ACTIONS(6701),
    [aux_sym_zero_directive_token4] = ACTIONS(6701),
    [aux_sym_zero_directive_token5] = ACTIONS(6701),
    [aux_sym_zero_directive_token6] = ACTIONS(6701),
    [aux_sym_zero_directive_token7] = ACTIONS(6701),
    [aux_sym_zero_directive_token8] = ACTIONS(6701),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6701),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6701),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_begin_keywords_token1] = ACTIONS(6701),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_endmodule] = ACTIONS(6699),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_module] = ACTIONS(6699),
    [anon_sym_macromodule] = ACTIONS(6699),
    [anon_sym_endinterface] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_endprogram] = ACTIONS(6699),
    [anon_sym_program] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_timeunit] = ACTIONS(6699),
    [anon_sym_timeprecision] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_input] = ACTIONS(6699),
    [anon_sym_output] = ACTIONS(6699),
    [anon_sym_inout] = ACTIONS(6699),
    [anon_sym_ref] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(6703),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_specparam] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_modport] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_specify] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [1234] = {
    [sym_simple_identifier] = ACTIONS(6705),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6707),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6707),
    [anon_sym_BQUOTE] = ACTIONS(6705),
    [aux_sym_id_directive_token1] = ACTIONS(6707),
    [aux_sym_id_directive_token2] = ACTIONS(6707),
    [aux_sym_id_directive_token3] = ACTIONS(6707),
    [aux_sym_id_directive_token4] = ACTIONS(6705),
    [aux_sym_zero_directive_token1] = ACTIONS(6707),
    [aux_sym_zero_directive_token2] = ACTIONS(6707),
    [aux_sym_zero_directive_token3] = ACTIONS(6707),
    [aux_sym_zero_directive_token4] = ACTIONS(6707),
    [aux_sym_zero_directive_token5] = ACTIONS(6707),
    [aux_sym_zero_directive_token6] = ACTIONS(6707),
    [aux_sym_zero_directive_token7] = ACTIONS(6707),
    [aux_sym_zero_directive_token8] = ACTIONS(6707),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6707),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6707),
    [anon_sym_wire] = ACTIONS(6705),
    [anon_sym_tri] = ACTIONS(6705),
    [anon_sym_tri0] = ACTIONS(6705),
    [anon_sym_tri1] = ACTIONS(6705),
    [anon_sym_wand] = ACTIONS(6705),
    [anon_sym_triand] = ACTIONS(6705),
    [anon_sym_wor] = ACTIONS(6705),
    [anon_sym_trior] = ACTIONS(6705),
    [anon_sym_trireg] = ACTIONS(6705),
    [anon_sym_uwire] = ACTIONS(6705),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6707),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6707),
    [aux_sym_begin_keywords_token1] = ACTIONS(6707),
    [anon_sym_SEMI] = ACTIONS(6707),
    [anon_sym_endmodule] = ACTIONS(6705),
    [anon_sym_extern] = ACTIONS(6705),
    [anon_sym_module] = ACTIONS(6705),
    [anon_sym_macromodule] = ACTIONS(6705),
    [anon_sym_endinterface] = ACTIONS(6705),
    [anon_sym_interface] = ACTIONS(6705),
    [anon_sym_endprogram] = ACTIONS(6705),
    [anon_sym_program] = ACTIONS(6705),
    [anon_sym_checker] = ACTIONS(6705),
    [anon_sym_virtual] = ACTIONS(6705),
    [anon_sym_class] = ACTIONS(6705),
    [anon_sym_timeunit] = ACTIONS(6705),
    [anon_sym_timeprecision] = ACTIONS(6705),
    [anon_sym_type] = ACTIONS(6705),
    [anon_sym_input] = ACTIONS(6705),
    [anon_sym_output] = ACTIONS(6705),
    [anon_sym_inout] = ACTIONS(6705),
    [anon_sym_ref] = ACTIONS(6705),
    [anon_sym_DOLLARfatal] = ACTIONS(6707),
    [anon_sym_DOLLARerror] = ACTIONS(6707),
    [anon_sym_DOLLARwarning] = ACTIONS(6707),
    [anon_sym_DOLLARinfo] = ACTIONS(6707),
    [anon_sym_default] = ACTIONS(6705),
    [anon_sym_clocking] = ACTIONS(6705),
    [anon_sym_defparam] = ACTIONS(6705),
    [anon_sym_bind] = ACTIONS(6705),
    [anon_sym_const] = ACTIONS(6705),
    [anon_sym_function] = ACTIONS(6705),
    [anon_sym_static] = ACTIONS(6705),
    [anon_sym_constraint] = ACTIONS(6705),
    [anon_sym_if] = ACTIONS(6705),
    [anon_sym_else] = ACTIONS(6705),
    [anon_sym_LBRACK] = ACTIONS(6707),
    [anon_sym_localparam] = ACTIONS(6705),
    [anon_sym_parameter] = ACTIONS(6705),
    [anon_sym_specparam] = ACTIONS(6705),
    [anon_sym_var] = ACTIONS(6705),
    [anon_sym_import] = ACTIONS(6705),
    [anon_sym_export] = ACTIONS(6705),
    [anon_sym_genvar] = ACTIONS(6705),
    [anon_sym_interconnect] = ACTIONS(6705),
    [anon_sym_typedef] = ACTIONS(6705),
    [anon_sym_enum] = ACTIONS(6705),
    [anon_sym_struct] = ACTIONS(6705),
    [anon_sym_union] = ACTIONS(6705),
    [anon_sym_nettype] = ACTIONS(6705),
    [anon_sym_automatic] = ACTIONS(6705),
    [anon_sym_string] = ACTIONS(6705),
    [anon_sym_chandle] = ACTIONS(6705),
    [anon_sym_event] = ACTIONS(6705),
    [anon_sym_byte] = ACTIONS(6705),
    [anon_sym_shortint] = ACTIONS(6705),
    [anon_sym_int] = ACTIONS(6705),
    [anon_sym_longint] = ACTIONS(6705),
    [anon_sym_integer] = ACTIONS(6705),
    [anon_sym_time] = ACTIONS(6705),
    [anon_sym_bit] = ACTIONS(6705),
    [anon_sym_logic] = ACTIONS(6705),
    [anon_sym_reg] = ACTIONS(6705),
    [anon_sym_shortreal] = ACTIONS(6705),
    [anon_sym_real] = ACTIONS(6705),
    [anon_sym_realtime] = ACTIONS(6705),
    [anon_sym_supply0] = ACTIONS(6705),
    [anon_sym_supply1] = ACTIONS(6705),
    [anon_sym_signed] = ACTIONS(6705),
    [anon_sym_unsigned] = ACTIONS(6705),
    [anon_sym_task] = ACTIONS(6705),
    [anon_sym_modport] = ACTIONS(6705),
    [anon_sym_assert] = ACTIONS(6705),
    [anon_sym_property] = ACTIONS(6705),
    [anon_sym_assume] = ACTIONS(6705),
    [anon_sym_cover] = ACTIONS(6705),
    [anon_sym_sequence] = ACTIONS(6705),
    [anon_sym_restrict] = ACTIONS(6705),
    [anon_sym_not] = ACTIONS(6705),
    [anon_sym_or] = ACTIONS(6705),
    [anon_sym_and] = ACTIONS(6705),
    [anon_sym_case] = ACTIONS(6705),
    [anon_sym_always] = ACTIONS(6705),
    [anon_sym_covergroup] = ACTIONS(6705),
    [anon_sym_let] = ACTIONS(6705),
    [anon_sym_pulldown] = ACTIONS(6705),
    [anon_sym_pullup] = ACTIONS(6705),
    [anon_sym_cmos] = ACTIONS(6705),
    [anon_sym_rcmos] = ACTIONS(6705),
    [anon_sym_bufif0] = ACTIONS(6705),
    [anon_sym_bufif1] = ACTIONS(6705),
    [anon_sym_notif0] = ACTIONS(6705),
    [anon_sym_notif1] = ACTIONS(6705),
    [anon_sym_nmos] = ACTIONS(6705),
    [anon_sym_pmos] = ACTIONS(6705),
    [anon_sym_rnmos] = ACTIONS(6705),
    [anon_sym_rpmos] = ACTIONS(6705),
    [anon_sym_nand] = ACTIONS(6705),
    [anon_sym_nor] = ACTIONS(6705),
    [anon_sym_xor] = ACTIONS(6705),
    [anon_sym_xnor] = ACTIONS(6705),
    [anon_sym_buf] = ACTIONS(6705),
    [anon_sym_tranif0] = ACTIONS(6705),
    [anon_sym_tranif1] = ACTIONS(6705),
    [anon_sym_rtranif1] = ACTIONS(6705),
    [anon_sym_rtranif0] = ACTIONS(6705),
    [anon_sym_tran] = ACTIONS(6705),
    [anon_sym_rtran] = ACTIONS(6705),
    [anon_sym_generate] = ACTIONS(6705),
    [anon_sym_for] = ACTIONS(6705),
    [anon_sym_initial] = ACTIONS(6705),
    [anon_sym_assign] = ACTIONS(6705),
    [anon_sym_alias] = ACTIONS(6705),
    [anon_sym_always_comb] = ACTIONS(6705),
    [anon_sym_always_latch] = ACTIONS(6705),
    [anon_sym_always_ff] = ACTIONS(6705),
    [anon_sym_final] = ACTIONS(6705),
    [anon_sym_global] = ACTIONS(6705),
    [anon_sym_specify] = ACTIONS(6705),
    [anon_sym_LPAREN_STAR] = ACTIONS(6707),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6707),
    [anon_sym_DOLLARunit] = ACTIONS(6707),
  },
  [1235] = {
    [ts_builtin_sym_end] = ACTIONS(6709),
    [sym_simple_identifier] = ACTIONS(6711),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6709),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6709),
    [anon_sym_BQUOTE] = ACTIONS(6711),
    [aux_sym_id_directive_token1] = ACTIONS(6709),
    [aux_sym_id_directive_token2] = ACTIONS(6709),
    [aux_sym_id_directive_token3] = ACTIONS(6709),
    [aux_sym_id_directive_token4] = ACTIONS(6711),
    [aux_sym_zero_directive_token1] = ACTIONS(6709),
    [aux_sym_zero_directive_token2] = ACTIONS(6709),
    [aux_sym_zero_directive_token3] = ACTIONS(6709),
    [aux_sym_zero_directive_token4] = ACTIONS(6709),
    [aux_sym_zero_directive_token5] = ACTIONS(6709),
    [aux_sym_zero_directive_token6] = ACTIONS(6709),
    [aux_sym_zero_directive_token7] = ACTIONS(6709),
    [aux_sym_zero_directive_token8] = ACTIONS(6709),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6709),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6709),
    [anon_sym_wire] = ACTIONS(6711),
    [anon_sym_tri] = ACTIONS(6711),
    [anon_sym_tri0] = ACTIONS(6711),
    [anon_sym_tri1] = ACTIONS(6711),
    [anon_sym_wand] = ACTIONS(6711),
    [anon_sym_triand] = ACTIONS(6711),
    [anon_sym_wor] = ACTIONS(6711),
    [anon_sym_trior] = ACTIONS(6711),
    [anon_sym_trireg] = ACTIONS(6711),
    [anon_sym_uwire] = ACTIONS(6711),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6709),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6709),
    [aux_sym_begin_keywords_token1] = ACTIONS(6709),
    [anon_sym_SEMI] = ACTIONS(6709),
    [anon_sym_endmodule] = ACTIONS(6711),
    [anon_sym_COLON] = ACTIONS(6713),
    [anon_sym_extern] = ACTIONS(6711),
    [anon_sym_module] = ACTIONS(6711),
    [anon_sym_macromodule] = ACTIONS(6711),
    [anon_sym_interface] = ACTIONS(6711),
    [anon_sym_program] = ACTIONS(6711),
    [anon_sym_checker] = ACTIONS(6711),
    [anon_sym_virtual] = ACTIONS(6711),
    [anon_sym_class] = ACTIONS(6711),
    [anon_sym_package] = ACTIONS(6711),
    [anon_sym_timeunit] = ACTIONS(6711),
    [anon_sym_timeprecision] = ACTIONS(6711),
    [anon_sym_type] = ACTIONS(6711),
    [anon_sym_input] = ACTIONS(6711),
    [anon_sym_output] = ACTIONS(6711),
    [anon_sym_inout] = ACTIONS(6711),
    [anon_sym_ref] = ACTIONS(6711),
    [anon_sym_DOLLARfatal] = ACTIONS(6709),
    [anon_sym_DOLLARerror] = ACTIONS(6709),
    [anon_sym_DOLLARwarning] = ACTIONS(6709),
    [anon_sym_DOLLARinfo] = ACTIONS(6709),
    [anon_sym_default] = ACTIONS(6711),
    [anon_sym_clocking] = ACTIONS(6711),
    [anon_sym_defparam] = ACTIONS(6711),
    [anon_sym_bind] = ACTIONS(6711),
    [anon_sym_const] = ACTIONS(6711),
    [anon_sym_function] = ACTIONS(6711),
    [anon_sym_static] = ACTIONS(6711),
    [anon_sym_constraint] = ACTIONS(6711),
    [anon_sym_if] = ACTIONS(6711),
    [anon_sym_LBRACK] = ACTIONS(6709),
    [anon_sym_localparam] = ACTIONS(6711),
    [anon_sym_parameter] = ACTIONS(6711),
    [anon_sym_specparam] = ACTIONS(6711),
    [anon_sym_var] = ACTIONS(6711),
    [anon_sym_import] = ACTIONS(6711),
    [anon_sym_export] = ACTIONS(6711),
    [anon_sym_genvar] = ACTIONS(6711),
    [anon_sym_interconnect] = ACTIONS(6711),
    [anon_sym_typedef] = ACTIONS(6711),
    [anon_sym_enum] = ACTIONS(6711),
    [anon_sym_struct] = ACTIONS(6711),
    [anon_sym_union] = ACTIONS(6711),
    [anon_sym_nettype] = ACTIONS(6711),
    [anon_sym_automatic] = ACTIONS(6711),
    [anon_sym_string] = ACTIONS(6711),
    [anon_sym_chandle] = ACTIONS(6711),
    [anon_sym_event] = ACTIONS(6711),
    [anon_sym_byte] = ACTIONS(6711),
    [anon_sym_shortint] = ACTIONS(6711),
    [anon_sym_int] = ACTIONS(6711),
    [anon_sym_longint] = ACTIONS(6711),
    [anon_sym_integer] = ACTIONS(6711),
    [anon_sym_time] = ACTIONS(6711),
    [anon_sym_bit] = ACTIONS(6711),
    [anon_sym_logic] = ACTIONS(6711),
    [anon_sym_reg] = ACTIONS(6711),
    [anon_sym_shortreal] = ACTIONS(6711),
    [anon_sym_real] = ACTIONS(6711),
    [anon_sym_realtime] = ACTIONS(6711),
    [anon_sym_supply0] = ACTIONS(6711),
    [anon_sym_supply1] = ACTIONS(6711),
    [anon_sym_signed] = ACTIONS(6711),
    [anon_sym_unsigned] = ACTIONS(6711),
    [anon_sym_task] = ACTIONS(6711),
    [anon_sym_assert] = ACTIONS(6711),
    [anon_sym_property] = ACTIONS(6711),
    [anon_sym_assume] = ACTIONS(6711),
    [anon_sym_cover] = ACTIONS(6711),
    [anon_sym_sequence] = ACTIONS(6711),
    [anon_sym_restrict] = ACTIONS(6711),
    [anon_sym_not] = ACTIONS(6711),
    [anon_sym_or] = ACTIONS(6711),
    [anon_sym_and] = ACTIONS(6711),
    [anon_sym_case] = ACTIONS(6711),
    [anon_sym_always] = ACTIONS(6711),
    [anon_sym_covergroup] = ACTIONS(6711),
    [anon_sym_let] = ACTIONS(6711),
    [anon_sym_pulldown] = ACTIONS(6711),
    [anon_sym_pullup] = ACTIONS(6711),
    [anon_sym_cmos] = ACTIONS(6711),
    [anon_sym_rcmos] = ACTIONS(6711),
    [anon_sym_bufif0] = ACTIONS(6711),
    [anon_sym_bufif1] = ACTIONS(6711),
    [anon_sym_notif0] = ACTIONS(6711),
    [anon_sym_notif1] = ACTIONS(6711),
    [anon_sym_nmos] = ACTIONS(6711),
    [anon_sym_pmos] = ACTIONS(6711),
    [anon_sym_rnmos] = ACTIONS(6711),
    [anon_sym_rpmos] = ACTIONS(6711),
    [anon_sym_nand] = ACTIONS(6711),
    [anon_sym_nor] = ACTIONS(6711),
    [anon_sym_xor] = ACTIONS(6711),
    [anon_sym_xnor] = ACTIONS(6711),
    [anon_sym_buf] = ACTIONS(6711),
    [anon_sym_tranif0] = ACTIONS(6711),
    [anon_sym_tranif1] = ACTIONS(6711),
    [anon_sym_rtranif1] = ACTIONS(6711),
    [anon_sym_rtranif0] = ACTIONS(6711),
    [anon_sym_tran] = ACTIONS(6711),
    [anon_sym_rtran] = ACTIONS(6711),
    [anon_sym_generate] = ACTIONS(6711),
    [anon_sym_for] = ACTIONS(6711),
    [anon_sym_primitive] = ACTIONS(6711),
    [anon_sym_initial] = ACTIONS(6711),
    [anon_sym_assign] = ACTIONS(6711),
    [anon_sym_alias] = ACTIONS(6711),
    [anon_sym_always_comb] = ACTIONS(6711),
    [anon_sym_always_latch] = ACTIONS(6711),
    [anon_sym_always_ff] = ACTIONS(6711),
    [anon_sym_final] = ACTIONS(6711),
    [anon_sym_global] = ACTIONS(6711),
    [anon_sym_specify] = ACTIONS(6711),
    [anon_sym_LPAREN_STAR] = ACTIONS(6709),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6709),
    [anon_sym_DOLLARunit] = ACTIONS(6709),
  },
  [1236] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6381),
    [anon_sym_BQUOTE] = ACTIONS(6379),
    [aux_sym_id_directive_token1] = ACTIONS(6381),
    [aux_sym_id_directive_token2] = ACTIONS(6381),
    [aux_sym_id_directive_token3] = ACTIONS(6381),
    [aux_sym_id_directive_token4] = ACTIONS(6379),
    [aux_sym_zero_directive_token1] = ACTIONS(6381),
    [aux_sym_zero_directive_token2] = ACTIONS(6381),
    [aux_sym_zero_directive_token3] = ACTIONS(6381),
    [aux_sym_zero_directive_token4] = ACTIONS(6381),
    [aux_sym_zero_directive_token5] = ACTIONS(6381),
    [aux_sym_zero_directive_token6] = ACTIONS(6381),
    [aux_sym_zero_directive_token7] = ACTIONS(6381),
    [aux_sym_zero_directive_token8] = ACTIONS(6381),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6381),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6381),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6381),
    [aux_sym_begin_keywords_token1] = ACTIONS(6381),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_endmodule] = ACTIONS(6379),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_module] = ACTIONS(6379),
    [anon_sym_macromodule] = ACTIONS(6379),
    [anon_sym_endinterface] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_endprogram] = ACTIONS(6379),
    [anon_sym_program] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_timeunit] = ACTIONS(6379),
    [anon_sym_timeprecision] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_input] = ACTIONS(6379),
    [anon_sym_output] = ACTIONS(6379),
    [anon_sym_inout] = ACTIONS(6379),
    [anon_sym_ref] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_specparam] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_modport] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_specify] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [1237] = {
    [sym_simple_identifier] = ACTIONS(6715),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6717),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6717),
    [anon_sym_BQUOTE] = ACTIONS(6715),
    [aux_sym_id_directive_token1] = ACTIONS(6717),
    [aux_sym_id_directive_token2] = ACTIONS(6717),
    [aux_sym_id_directive_token3] = ACTIONS(6717),
    [aux_sym_id_directive_token4] = ACTIONS(6715),
    [aux_sym_zero_directive_token1] = ACTIONS(6717),
    [aux_sym_zero_directive_token2] = ACTIONS(6717),
    [aux_sym_zero_directive_token3] = ACTIONS(6717),
    [aux_sym_zero_directive_token4] = ACTIONS(6717),
    [aux_sym_zero_directive_token5] = ACTIONS(6717),
    [aux_sym_zero_directive_token6] = ACTIONS(6717),
    [aux_sym_zero_directive_token7] = ACTIONS(6717),
    [aux_sym_zero_directive_token8] = ACTIONS(6717),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6717),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6717),
    [anon_sym_wire] = ACTIONS(6715),
    [anon_sym_tri] = ACTIONS(6715),
    [anon_sym_tri0] = ACTIONS(6715),
    [anon_sym_tri1] = ACTIONS(6715),
    [anon_sym_wand] = ACTIONS(6715),
    [anon_sym_triand] = ACTIONS(6715),
    [anon_sym_wor] = ACTIONS(6715),
    [anon_sym_trior] = ACTIONS(6715),
    [anon_sym_trireg] = ACTIONS(6715),
    [anon_sym_uwire] = ACTIONS(6715),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6717),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6717),
    [aux_sym_begin_keywords_token1] = ACTIONS(6717),
    [anon_sym_SEMI] = ACTIONS(6717),
    [anon_sym_endmodule] = ACTIONS(6715),
    [anon_sym_extern] = ACTIONS(6715),
    [anon_sym_module] = ACTIONS(6715),
    [anon_sym_macromodule] = ACTIONS(6715),
    [anon_sym_endinterface] = ACTIONS(6715),
    [anon_sym_interface] = ACTIONS(6715),
    [anon_sym_endprogram] = ACTIONS(6715),
    [anon_sym_program] = ACTIONS(6715),
    [anon_sym_checker] = ACTIONS(6715),
    [anon_sym_virtual] = ACTIONS(6715),
    [anon_sym_class] = ACTIONS(6715),
    [anon_sym_timeunit] = ACTIONS(6715),
    [anon_sym_timeprecision] = ACTIONS(6715),
    [anon_sym_type] = ACTIONS(6715),
    [anon_sym_input] = ACTIONS(6715),
    [anon_sym_output] = ACTIONS(6715),
    [anon_sym_inout] = ACTIONS(6715),
    [anon_sym_ref] = ACTIONS(6715),
    [anon_sym_DOLLARfatal] = ACTIONS(6717),
    [anon_sym_DOLLARerror] = ACTIONS(6717),
    [anon_sym_DOLLARwarning] = ACTIONS(6717),
    [anon_sym_DOLLARinfo] = ACTIONS(6717),
    [anon_sym_default] = ACTIONS(6715),
    [anon_sym_clocking] = ACTIONS(6715),
    [anon_sym_defparam] = ACTIONS(6715),
    [anon_sym_bind] = ACTIONS(6715),
    [anon_sym_const] = ACTIONS(6715),
    [anon_sym_function] = ACTIONS(6715),
    [anon_sym_static] = ACTIONS(6715),
    [anon_sym_constraint] = ACTIONS(6715),
    [anon_sym_if] = ACTIONS(6715),
    [anon_sym_else] = ACTIONS(6715),
    [anon_sym_LBRACK] = ACTIONS(6717),
    [anon_sym_localparam] = ACTIONS(6715),
    [anon_sym_parameter] = ACTIONS(6715),
    [anon_sym_specparam] = ACTIONS(6715),
    [anon_sym_var] = ACTIONS(6715),
    [anon_sym_import] = ACTIONS(6715),
    [anon_sym_export] = ACTIONS(6715),
    [anon_sym_genvar] = ACTIONS(6715),
    [anon_sym_interconnect] = ACTIONS(6715),
    [anon_sym_typedef] = ACTIONS(6715),
    [anon_sym_enum] = ACTIONS(6715),
    [anon_sym_struct] = ACTIONS(6715),
    [anon_sym_union] = ACTIONS(6715),
    [anon_sym_nettype] = ACTIONS(6715),
    [anon_sym_automatic] = ACTIONS(6715),
    [anon_sym_string] = ACTIONS(6715),
    [anon_sym_chandle] = ACTIONS(6715),
    [anon_sym_event] = ACTIONS(6715),
    [anon_sym_byte] = ACTIONS(6715),
    [anon_sym_shortint] = ACTIONS(6715),
    [anon_sym_int] = ACTIONS(6715),
    [anon_sym_longint] = ACTIONS(6715),
    [anon_sym_integer] = ACTIONS(6715),
    [anon_sym_time] = ACTIONS(6715),
    [anon_sym_bit] = ACTIONS(6715),
    [anon_sym_logic] = ACTIONS(6715),
    [anon_sym_reg] = ACTIONS(6715),
    [anon_sym_shortreal] = ACTIONS(6715),
    [anon_sym_real] = ACTIONS(6715),
    [anon_sym_realtime] = ACTIONS(6715),
    [anon_sym_supply0] = ACTIONS(6715),
    [anon_sym_supply1] = ACTIONS(6715),
    [anon_sym_signed] = ACTIONS(6715),
    [anon_sym_unsigned] = ACTIONS(6715),
    [anon_sym_task] = ACTIONS(6715),
    [anon_sym_modport] = ACTIONS(6715),
    [anon_sym_assert] = ACTIONS(6715),
    [anon_sym_property] = ACTIONS(6715),
    [anon_sym_assume] = ACTIONS(6715),
    [anon_sym_cover] = ACTIONS(6715),
    [anon_sym_sequence] = ACTIONS(6715),
    [anon_sym_restrict] = ACTIONS(6715),
    [anon_sym_not] = ACTIONS(6715),
    [anon_sym_or] = ACTIONS(6715),
    [anon_sym_and] = ACTIONS(6715),
    [anon_sym_case] = ACTIONS(6715),
    [anon_sym_always] = ACTIONS(6715),
    [anon_sym_covergroup] = ACTIONS(6715),
    [anon_sym_let] = ACTIONS(6715),
    [anon_sym_pulldown] = ACTIONS(6715),
    [anon_sym_pullup] = ACTIONS(6715),
    [anon_sym_cmos] = ACTIONS(6715),
    [anon_sym_rcmos] = ACTIONS(6715),
    [anon_sym_bufif0] = ACTIONS(6715),
    [anon_sym_bufif1] = ACTIONS(6715),
    [anon_sym_notif0] = ACTIONS(6715),
    [anon_sym_notif1] = ACTIONS(6715),
    [anon_sym_nmos] = ACTIONS(6715),
    [anon_sym_pmos] = ACTIONS(6715),
    [anon_sym_rnmos] = ACTIONS(6715),
    [anon_sym_rpmos] = ACTIONS(6715),
    [anon_sym_nand] = ACTIONS(6715),
    [anon_sym_nor] = ACTIONS(6715),
    [anon_sym_xor] = ACTIONS(6715),
    [anon_sym_xnor] = ACTIONS(6715),
    [anon_sym_buf] = ACTIONS(6715),
    [anon_sym_tranif0] = ACTIONS(6715),
    [anon_sym_tranif1] = ACTIONS(6715),
    [anon_sym_rtranif1] = ACTIONS(6715),
    [anon_sym_rtranif0] = ACTIONS(6715),
    [anon_sym_tran] = ACTIONS(6715),
    [anon_sym_rtran] = ACTIONS(6715),
    [anon_sym_generate] = ACTIONS(6715),
    [anon_sym_for] = ACTIONS(6715),
    [anon_sym_initial] = ACTIONS(6715),
    [anon_sym_assign] = ACTIONS(6715),
    [anon_sym_alias] = ACTIONS(6715),
    [anon_sym_always_comb] = ACTIONS(6715),
    [anon_sym_always_latch] = ACTIONS(6715),
    [anon_sym_always_ff] = ACTIONS(6715),
    [anon_sym_final] = ACTIONS(6715),
    [anon_sym_global] = ACTIONS(6715),
    [anon_sym_specify] = ACTIONS(6715),
    [anon_sym_LPAREN_STAR] = ACTIONS(6717),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6717),
    [anon_sym_DOLLARunit] = ACTIONS(6717),
  },
  [1238] = {
    [sym_simple_identifier] = ACTIONS(6719),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6721),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6721),
    [anon_sym_BQUOTE] = ACTIONS(6719),
    [aux_sym_id_directive_token1] = ACTIONS(6721),
    [aux_sym_id_directive_token2] = ACTIONS(6721),
    [aux_sym_id_directive_token3] = ACTIONS(6721),
    [aux_sym_id_directive_token4] = ACTIONS(6719),
    [aux_sym_zero_directive_token1] = ACTIONS(6721),
    [aux_sym_zero_directive_token2] = ACTIONS(6721),
    [aux_sym_zero_directive_token3] = ACTIONS(6721),
    [aux_sym_zero_directive_token4] = ACTIONS(6721),
    [aux_sym_zero_directive_token5] = ACTIONS(6721),
    [aux_sym_zero_directive_token6] = ACTIONS(6721),
    [aux_sym_zero_directive_token7] = ACTIONS(6721),
    [aux_sym_zero_directive_token8] = ACTIONS(6721),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6721),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6721),
    [anon_sym_wire] = ACTIONS(6719),
    [anon_sym_tri] = ACTIONS(6719),
    [anon_sym_tri0] = ACTIONS(6719),
    [anon_sym_tri1] = ACTIONS(6719),
    [anon_sym_wand] = ACTIONS(6719),
    [anon_sym_triand] = ACTIONS(6719),
    [anon_sym_wor] = ACTIONS(6719),
    [anon_sym_trior] = ACTIONS(6719),
    [anon_sym_trireg] = ACTIONS(6719),
    [anon_sym_uwire] = ACTIONS(6719),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6721),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6721),
    [aux_sym_begin_keywords_token1] = ACTIONS(6721),
    [anon_sym_SEMI] = ACTIONS(6721),
    [anon_sym_endmodule] = ACTIONS(6719),
    [anon_sym_extern] = ACTIONS(6719),
    [anon_sym_module] = ACTIONS(6719),
    [anon_sym_macromodule] = ACTIONS(6719),
    [anon_sym_endinterface] = ACTIONS(6719),
    [anon_sym_interface] = ACTIONS(6719),
    [anon_sym_endprogram] = ACTIONS(6719),
    [anon_sym_program] = ACTIONS(6719),
    [anon_sym_checker] = ACTIONS(6719),
    [anon_sym_virtual] = ACTIONS(6719),
    [anon_sym_class] = ACTIONS(6719),
    [anon_sym_timeunit] = ACTIONS(6719),
    [anon_sym_timeprecision] = ACTIONS(6719),
    [anon_sym_type] = ACTIONS(6719),
    [anon_sym_input] = ACTIONS(6719),
    [anon_sym_output] = ACTIONS(6719),
    [anon_sym_inout] = ACTIONS(6719),
    [anon_sym_ref] = ACTIONS(6719),
    [anon_sym_DOLLARfatal] = ACTIONS(6721),
    [anon_sym_DOLLARerror] = ACTIONS(6721),
    [anon_sym_DOLLARwarning] = ACTIONS(6721),
    [anon_sym_DOLLARinfo] = ACTIONS(6721),
    [anon_sym_default] = ACTIONS(6719),
    [anon_sym_clocking] = ACTIONS(6719),
    [anon_sym_defparam] = ACTIONS(6719),
    [anon_sym_bind] = ACTIONS(6719),
    [anon_sym_const] = ACTIONS(6719),
    [anon_sym_function] = ACTIONS(6719),
    [anon_sym_static] = ACTIONS(6719),
    [anon_sym_constraint] = ACTIONS(6719),
    [anon_sym_if] = ACTIONS(6719),
    [anon_sym_else] = ACTIONS(6719),
    [anon_sym_LBRACK] = ACTIONS(6721),
    [anon_sym_localparam] = ACTIONS(6719),
    [anon_sym_parameter] = ACTIONS(6719),
    [anon_sym_specparam] = ACTIONS(6719),
    [anon_sym_var] = ACTIONS(6719),
    [anon_sym_import] = ACTIONS(6719),
    [anon_sym_export] = ACTIONS(6719),
    [anon_sym_genvar] = ACTIONS(6719),
    [anon_sym_interconnect] = ACTIONS(6719),
    [anon_sym_typedef] = ACTIONS(6719),
    [anon_sym_enum] = ACTIONS(6719),
    [anon_sym_struct] = ACTIONS(6719),
    [anon_sym_union] = ACTIONS(6719),
    [anon_sym_nettype] = ACTIONS(6719),
    [anon_sym_automatic] = ACTIONS(6719),
    [anon_sym_string] = ACTIONS(6719),
    [anon_sym_chandle] = ACTIONS(6719),
    [anon_sym_event] = ACTIONS(6719),
    [anon_sym_byte] = ACTIONS(6719),
    [anon_sym_shortint] = ACTIONS(6719),
    [anon_sym_int] = ACTIONS(6719),
    [anon_sym_longint] = ACTIONS(6719),
    [anon_sym_integer] = ACTIONS(6719),
    [anon_sym_time] = ACTIONS(6719),
    [anon_sym_bit] = ACTIONS(6719),
    [anon_sym_logic] = ACTIONS(6719),
    [anon_sym_reg] = ACTIONS(6719),
    [anon_sym_shortreal] = ACTIONS(6719),
    [anon_sym_real] = ACTIONS(6719),
    [anon_sym_realtime] = ACTIONS(6719),
    [anon_sym_supply0] = ACTIONS(6719),
    [anon_sym_supply1] = ACTIONS(6719),
    [anon_sym_signed] = ACTIONS(6719),
    [anon_sym_unsigned] = ACTIONS(6719),
    [anon_sym_task] = ACTIONS(6719),
    [anon_sym_modport] = ACTIONS(6719),
    [anon_sym_assert] = ACTIONS(6719),
    [anon_sym_property] = ACTIONS(6719),
    [anon_sym_assume] = ACTIONS(6719),
    [anon_sym_cover] = ACTIONS(6719),
    [anon_sym_sequence] = ACTIONS(6719),
    [anon_sym_restrict] = ACTIONS(6719),
    [anon_sym_not] = ACTIONS(6719),
    [anon_sym_or] = ACTIONS(6719),
    [anon_sym_and] = ACTIONS(6719),
    [anon_sym_case] = ACTIONS(6719),
    [anon_sym_always] = ACTIONS(6719),
    [anon_sym_covergroup] = ACTIONS(6719),
    [anon_sym_let] = ACTIONS(6719),
    [anon_sym_pulldown] = ACTIONS(6719),
    [anon_sym_pullup] = ACTIONS(6719),
    [anon_sym_cmos] = ACTIONS(6719),
    [anon_sym_rcmos] = ACTIONS(6719),
    [anon_sym_bufif0] = ACTIONS(6719),
    [anon_sym_bufif1] = ACTIONS(6719),
    [anon_sym_notif0] = ACTIONS(6719),
    [anon_sym_notif1] = ACTIONS(6719),
    [anon_sym_nmos] = ACTIONS(6719),
    [anon_sym_pmos] = ACTIONS(6719),
    [anon_sym_rnmos] = ACTIONS(6719),
    [anon_sym_rpmos] = ACTIONS(6719),
    [anon_sym_nand] = ACTIONS(6719),
    [anon_sym_nor] = ACTIONS(6719),
    [anon_sym_xor] = ACTIONS(6719),
    [anon_sym_xnor] = ACTIONS(6719),
    [anon_sym_buf] = ACTIONS(6719),
    [anon_sym_tranif0] = ACTIONS(6719),
    [anon_sym_tranif1] = ACTIONS(6719),
    [anon_sym_rtranif1] = ACTIONS(6719),
    [anon_sym_rtranif0] = ACTIONS(6719),
    [anon_sym_tran] = ACTIONS(6719),
    [anon_sym_rtran] = ACTIONS(6719),
    [anon_sym_generate] = ACTIONS(6719),
    [anon_sym_for] = ACTIONS(6719),
    [anon_sym_initial] = ACTIONS(6719),
    [anon_sym_assign] = ACTIONS(6719),
    [anon_sym_alias] = ACTIONS(6719),
    [anon_sym_always_comb] = ACTIONS(6719),
    [anon_sym_always_latch] = ACTIONS(6719),
    [anon_sym_always_ff] = ACTIONS(6719),
    [anon_sym_final] = ACTIONS(6719),
    [anon_sym_global] = ACTIONS(6719),
    [anon_sym_specify] = ACTIONS(6719),
    [anon_sym_LPAREN_STAR] = ACTIONS(6721),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6721),
    [anon_sym_DOLLARunit] = ACTIONS(6721),
  },
  [1239] = {
    [sym_simple_identifier] = ACTIONS(6723),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6725),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6725),
    [anon_sym_BQUOTE] = ACTIONS(6723),
    [aux_sym_id_directive_token1] = ACTIONS(6725),
    [aux_sym_id_directive_token2] = ACTIONS(6725),
    [aux_sym_id_directive_token3] = ACTIONS(6725),
    [aux_sym_id_directive_token4] = ACTIONS(6723),
    [aux_sym_zero_directive_token1] = ACTIONS(6725),
    [aux_sym_zero_directive_token2] = ACTIONS(6725),
    [aux_sym_zero_directive_token3] = ACTIONS(6725),
    [aux_sym_zero_directive_token4] = ACTIONS(6725),
    [aux_sym_zero_directive_token5] = ACTIONS(6725),
    [aux_sym_zero_directive_token6] = ACTIONS(6725),
    [aux_sym_zero_directive_token7] = ACTIONS(6725),
    [aux_sym_zero_directive_token8] = ACTIONS(6725),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6725),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6725),
    [anon_sym_wire] = ACTIONS(6723),
    [anon_sym_tri] = ACTIONS(6723),
    [anon_sym_tri0] = ACTIONS(6723),
    [anon_sym_tri1] = ACTIONS(6723),
    [anon_sym_wand] = ACTIONS(6723),
    [anon_sym_triand] = ACTIONS(6723),
    [anon_sym_wor] = ACTIONS(6723),
    [anon_sym_trior] = ACTIONS(6723),
    [anon_sym_trireg] = ACTIONS(6723),
    [anon_sym_uwire] = ACTIONS(6723),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6725),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6725),
    [aux_sym_begin_keywords_token1] = ACTIONS(6725),
    [anon_sym_SEMI] = ACTIONS(6725),
    [anon_sym_endmodule] = ACTIONS(6723),
    [anon_sym_extern] = ACTIONS(6723),
    [anon_sym_module] = ACTIONS(6723),
    [anon_sym_macromodule] = ACTIONS(6723),
    [anon_sym_endinterface] = ACTIONS(6723),
    [anon_sym_interface] = ACTIONS(6723),
    [anon_sym_endprogram] = ACTIONS(6723),
    [anon_sym_program] = ACTIONS(6723),
    [anon_sym_checker] = ACTIONS(6723),
    [anon_sym_virtual] = ACTIONS(6723),
    [anon_sym_class] = ACTIONS(6723),
    [anon_sym_timeunit] = ACTIONS(6723),
    [anon_sym_timeprecision] = ACTIONS(6723),
    [anon_sym_type] = ACTIONS(6723),
    [anon_sym_input] = ACTIONS(6723),
    [anon_sym_output] = ACTIONS(6723),
    [anon_sym_inout] = ACTIONS(6723),
    [anon_sym_ref] = ACTIONS(6723),
    [anon_sym_DOLLARfatal] = ACTIONS(6725),
    [anon_sym_DOLLARerror] = ACTIONS(6725),
    [anon_sym_DOLLARwarning] = ACTIONS(6725),
    [anon_sym_DOLLARinfo] = ACTIONS(6725),
    [anon_sym_default] = ACTIONS(6723),
    [anon_sym_clocking] = ACTIONS(6723),
    [anon_sym_defparam] = ACTIONS(6723),
    [anon_sym_bind] = ACTIONS(6723),
    [anon_sym_const] = ACTIONS(6723),
    [anon_sym_function] = ACTIONS(6723),
    [anon_sym_static] = ACTIONS(6723),
    [anon_sym_constraint] = ACTIONS(6723),
    [anon_sym_if] = ACTIONS(6723),
    [anon_sym_else] = ACTIONS(6723),
    [anon_sym_LBRACK] = ACTIONS(6725),
    [anon_sym_localparam] = ACTIONS(6723),
    [anon_sym_parameter] = ACTIONS(6723),
    [anon_sym_specparam] = ACTIONS(6723),
    [anon_sym_var] = ACTIONS(6723),
    [anon_sym_import] = ACTIONS(6723),
    [anon_sym_export] = ACTIONS(6723),
    [anon_sym_genvar] = ACTIONS(6723),
    [anon_sym_interconnect] = ACTIONS(6723),
    [anon_sym_typedef] = ACTIONS(6723),
    [anon_sym_enum] = ACTIONS(6723),
    [anon_sym_struct] = ACTIONS(6723),
    [anon_sym_union] = ACTIONS(6723),
    [anon_sym_nettype] = ACTIONS(6723),
    [anon_sym_automatic] = ACTIONS(6723),
    [anon_sym_string] = ACTIONS(6723),
    [anon_sym_chandle] = ACTIONS(6723),
    [anon_sym_event] = ACTIONS(6723),
    [anon_sym_byte] = ACTIONS(6723),
    [anon_sym_shortint] = ACTIONS(6723),
    [anon_sym_int] = ACTIONS(6723),
    [anon_sym_longint] = ACTIONS(6723),
    [anon_sym_integer] = ACTIONS(6723),
    [anon_sym_time] = ACTIONS(6723),
    [anon_sym_bit] = ACTIONS(6723),
    [anon_sym_logic] = ACTIONS(6723),
    [anon_sym_reg] = ACTIONS(6723),
    [anon_sym_shortreal] = ACTIONS(6723),
    [anon_sym_real] = ACTIONS(6723),
    [anon_sym_realtime] = ACTIONS(6723),
    [anon_sym_supply0] = ACTIONS(6723),
    [anon_sym_supply1] = ACTIONS(6723),
    [anon_sym_signed] = ACTIONS(6723),
    [anon_sym_unsigned] = ACTIONS(6723),
    [anon_sym_task] = ACTIONS(6723),
    [anon_sym_modport] = ACTIONS(6723),
    [anon_sym_assert] = ACTIONS(6723),
    [anon_sym_property] = ACTIONS(6723),
    [anon_sym_assume] = ACTIONS(6723),
    [anon_sym_cover] = ACTIONS(6723),
    [anon_sym_sequence] = ACTIONS(6723),
    [anon_sym_restrict] = ACTIONS(6723),
    [anon_sym_not] = ACTIONS(6723),
    [anon_sym_or] = ACTIONS(6723),
    [anon_sym_and] = ACTIONS(6723),
    [anon_sym_case] = ACTIONS(6723),
    [anon_sym_always] = ACTIONS(6723),
    [anon_sym_covergroup] = ACTIONS(6723),
    [anon_sym_let] = ACTIONS(6723),
    [anon_sym_pulldown] = ACTIONS(6723),
    [anon_sym_pullup] = ACTIONS(6723),
    [anon_sym_cmos] = ACTIONS(6723),
    [anon_sym_rcmos] = ACTIONS(6723),
    [anon_sym_bufif0] = ACTIONS(6723),
    [anon_sym_bufif1] = ACTIONS(6723),
    [anon_sym_notif0] = ACTIONS(6723),
    [anon_sym_notif1] = ACTIONS(6723),
    [anon_sym_nmos] = ACTIONS(6723),
    [anon_sym_pmos] = ACTIONS(6723),
    [anon_sym_rnmos] = ACTIONS(6723),
    [anon_sym_rpmos] = ACTIONS(6723),
    [anon_sym_nand] = ACTIONS(6723),
    [anon_sym_nor] = ACTIONS(6723),
    [anon_sym_xor] = ACTIONS(6723),
    [anon_sym_xnor] = ACTIONS(6723),
    [anon_sym_buf] = ACTIONS(6723),
    [anon_sym_tranif0] = ACTIONS(6723),
    [anon_sym_tranif1] = ACTIONS(6723),
    [anon_sym_rtranif1] = ACTIONS(6723),
    [anon_sym_rtranif0] = ACTIONS(6723),
    [anon_sym_tran] = ACTIONS(6723),
    [anon_sym_rtran] = ACTIONS(6723),
    [anon_sym_generate] = ACTIONS(6723),
    [anon_sym_for] = ACTIONS(6723),
    [anon_sym_initial] = ACTIONS(6723),
    [anon_sym_assign] = ACTIONS(6723),
    [anon_sym_alias] = ACTIONS(6723),
    [anon_sym_always_comb] = ACTIONS(6723),
    [anon_sym_always_latch] = ACTIONS(6723),
    [anon_sym_always_ff] = ACTIONS(6723),
    [anon_sym_final] = ACTIONS(6723),
    [anon_sym_global] = ACTIONS(6723),
    [anon_sym_specify] = ACTIONS(6723),
    [anon_sym_LPAREN_STAR] = ACTIONS(6725),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6725),
    [anon_sym_DOLLARunit] = ACTIONS(6725),
  },
  [1240] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6701),
    [anon_sym_BQUOTE] = ACTIONS(6699),
    [aux_sym_id_directive_token1] = ACTIONS(6701),
    [aux_sym_id_directive_token2] = ACTIONS(6701),
    [aux_sym_id_directive_token3] = ACTIONS(6701),
    [aux_sym_id_directive_token4] = ACTIONS(6699),
    [aux_sym_zero_directive_token1] = ACTIONS(6701),
    [aux_sym_zero_directive_token2] = ACTIONS(6701),
    [aux_sym_zero_directive_token3] = ACTIONS(6701),
    [aux_sym_zero_directive_token4] = ACTIONS(6701),
    [aux_sym_zero_directive_token5] = ACTIONS(6701),
    [aux_sym_zero_directive_token6] = ACTIONS(6701),
    [aux_sym_zero_directive_token7] = ACTIONS(6701),
    [aux_sym_zero_directive_token8] = ACTIONS(6701),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6701),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6701),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6701),
    [aux_sym_begin_keywords_token1] = ACTIONS(6701),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_endmodule] = ACTIONS(6699),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_module] = ACTIONS(6699),
    [anon_sym_macromodule] = ACTIONS(6699),
    [anon_sym_endinterface] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_endprogram] = ACTIONS(6699),
    [anon_sym_program] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_timeunit] = ACTIONS(6699),
    [anon_sym_timeprecision] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_input] = ACTIONS(6699),
    [anon_sym_output] = ACTIONS(6699),
    [anon_sym_inout] = ACTIONS(6699),
    [anon_sym_ref] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(6699),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_specparam] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_modport] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_specify] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [1241] = {
    [sym_simple_identifier] = ACTIONS(6727),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6729),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6729),
    [anon_sym_BQUOTE] = ACTIONS(6727),
    [aux_sym_id_directive_token1] = ACTIONS(6729),
    [aux_sym_id_directive_token2] = ACTIONS(6729),
    [aux_sym_id_directive_token3] = ACTIONS(6729),
    [aux_sym_id_directive_token4] = ACTIONS(6727),
    [aux_sym_zero_directive_token1] = ACTIONS(6729),
    [aux_sym_zero_directive_token2] = ACTIONS(6729),
    [aux_sym_zero_directive_token3] = ACTIONS(6729),
    [aux_sym_zero_directive_token4] = ACTIONS(6729),
    [aux_sym_zero_directive_token5] = ACTIONS(6729),
    [aux_sym_zero_directive_token6] = ACTIONS(6729),
    [aux_sym_zero_directive_token7] = ACTIONS(6729),
    [aux_sym_zero_directive_token8] = ACTIONS(6729),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6729),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6729),
    [anon_sym_wire] = ACTIONS(6727),
    [anon_sym_tri] = ACTIONS(6727),
    [anon_sym_tri0] = ACTIONS(6727),
    [anon_sym_tri1] = ACTIONS(6727),
    [anon_sym_wand] = ACTIONS(6727),
    [anon_sym_triand] = ACTIONS(6727),
    [anon_sym_wor] = ACTIONS(6727),
    [anon_sym_trior] = ACTIONS(6727),
    [anon_sym_trireg] = ACTIONS(6727),
    [anon_sym_uwire] = ACTIONS(6727),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6729),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6729),
    [aux_sym_begin_keywords_token1] = ACTIONS(6729),
    [anon_sym_SEMI] = ACTIONS(6729),
    [anon_sym_endmodule] = ACTIONS(6727),
    [anon_sym_extern] = ACTIONS(6727),
    [anon_sym_module] = ACTIONS(6727),
    [anon_sym_macromodule] = ACTIONS(6727),
    [anon_sym_endinterface] = ACTIONS(6727),
    [anon_sym_interface] = ACTIONS(6727),
    [anon_sym_endprogram] = ACTIONS(6727),
    [anon_sym_program] = ACTIONS(6727),
    [anon_sym_checker] = ACTIONS(6727),
    [anon_sym_virtual] = ACTIONS(6727),
    [anon_sym_class] = ACTIONS(6727),
    [anon_sym_timeunit] = ACTIONS(6727),
    [anon_sym_timeprecision] = ACTIONS(6727),
    [anon_sym_type] = ACTIONS(6727),
    [anon_sym_input] = ACTIONS(6727),
    [anon_sym_output] = ACTIONS(6727),
    [anon_sym_inout] = ACTIONS(6727),
    [anon_sym_ref] = ACTIONS(6727),
    [anon_sym_DOLLARfatal] = ACTIONS(6729),
    [anon_sym_DOLLARerror] = ACTIONS(6729),
    [anon_sym_DOLLARwarning] = ACTIONS(6729),
    [anon_sym_DOLLARinfo] = ACTIONS(6729),
    [anon_sym_default] = ACTIONS(6727),
    [anon_sym_clocking] = ACTIONS(6727),
    [anon_sym_defparam] = ACTIONS(6727),
    [anon_sym_bind] = ACTIONS(6727),
    [anon_sym_const] = ACTIONS(6727),
    [anon_sym_function] = ACTIONS(6727),
    [anon_sym_static] = ACTIONS(6727),
    [anon_sym_constraint] = ACTIONS(6727),
    [anon_sym_if] = ACTIONS(6727),
    [anon_sym_else] = ACTIONS(6727),
    [anon_sym_LBRACK] = ACTIONS(6729),
    [anon_sym_localparam] = ACTIONS(6727),
    [anon_sym_parameter] = ACTIONS(6727),
    [anon_sym_specparam] = ACTIONS(6727),
    [anon_sym_var] = ACTIONS(6727),
    [anon_sym_import] = ACTIONS(6727),
    [anon_sym_export] = ACTIONS(6727),
    [anon_sym_genvar] = ACTIONS(6727),
    [anon_sym_interconnect] = ACTIONS(6727),
    [anon_sym_typedef] = ACTIONS(6727),
    [anon_sym_enum] = ACTIONS(6727),
    [anon_sym_struct] = ACTIONS(6727),
    [anon_sym_union] = ACTIONS(6727),
    [anon_sym_nettype] = ACTIONS(6727),
    [anon_sym_automatic] = ACTIONS(6727),
    [anon_sym_string] = ACTIONS(6727),
    [anon_sym_chandle] = ACTIONS(6727),
    [anon_sym_event] = ACTIONS(6727),
    [anon_sym_byte] = ACTIONS(6727),
    [anon_sym_shortint] = ACTIONS(6727),
    [anon_sym_int] = ACTIONS(6727),
    [anon_sym_longint] = ACTIONS(6727),
    [anon_sym_integer] = ACTIONS(6727),
    [anon_sym_time] = ACTIONS(6727),
    [anon_sym_bit] = ACTIONS(6727),
    [anon_sym_logic] = ACTIONS(6727),
    [anon_sym_reg] = ACTIONS(6727),
    [anon_sym_shortreal] = ACTIONS(6727),
    [anon_sym_real] = ACTIONS(6727),
    [anon_sym_realtime] = ACTIONS(6727),
    [anon_sym_supply0] = ACTIONS(6727),
    [anon_sym_supply1] = ACTIONS(6727),
    [anon_sym_signed] = ACTIONS(6727),
    [anon_sym_unsigned] = ACTIONS(6727),
    [anon_sym_task] = ACTIONS(6727),
    [anon_sym_modport] = ACTIONS(6727),
    [anon_sym_assert] = ACTIONS(6727),
    [anon_sym_property] = ACTIONS(6727),
    [anon_sym_assume] = ACTIONS(6727),
    [anon_sym_cover] = ACTIONS(6727),
    [anon_sym_sequence] = ACTIONS(6727),
    [anon_sym_restrict] = ACTIONS(6727),
    [anon_sym_not] = ACTIONS(6727),
    [anon_sym_or] = ACTIONS(6727),
    [anon_sym_and] = ACTIONS(6727),
    [anon_sym_case] = ACTIONS(6727),
    [anon_sym_always] = ACTIONS(6727),
    [anon_sym_covergroup] = ACTIONS(6727),
    [anon_sym_let] = ACTIONS(6727),
    [anon_sym_pulldown] = ACTIONS(6727),
    [anon_sym_pullup] = ACTIONS(6727),
    [anon_sym_cmos] = ACTIONS(6727),
    [anon_sym_rcmos] = ACTIONS(6727),
    [anon_sym_bufif0] = ACTIONS(6727),
    [anon_sym_bufif1] = ACTIONS(6727),
    [anon_sym_notif0] = ACTIONS(6727),
    [anon_sym_notif1] = ACTIONS(6727),
    [anon_sym_nmos] = ACTIONS(6727),
    [anon_sym_pmos] = ACTIONS(6727),
    [anon_sym_rnmos] = ACTIONS(6727),
    [anon_sym_rpmos] = ACTIONS(6727),
    [anon_sym_nand] = ACTIONS(6727),
    [anon_sym_nor] = ACTIONS(6727),
    [anon_sym_xor] = ACTIONS(6727),
    [anon_sym_xnor] = ACTIONS(6727),
    [anon_sym_buf] = ACTIONS(6727),
    [anon_sym_tranif0] = ACTIONS(6727),
    [anon_sym_tranif1] = ACTIONS(6727),
    [anon_sym_rtranif1] = ACTIONS(6727),
    [anon_sym_rtranif0] = ACTIONS(6727),
    [anon_sym_tran] = ACTIONS(6727),
    [anon_sym_rtran] = ACTIONS(6727),
    [anon_sym_generate] = ACTIONS(6727),
    [anon_sym_for] = ACTIONS(6727),
    [anon_sym_initial] = ACTIONS(6727),
    [anon_sym_assign] = ACTIONS(6727),
    [anon_sym_alias] = ACTIONS(6727),
    [anon_sym_always_comb] = ACTIONS(6727),
    [anon_sym_always_latch] = ACTIONS(6727),
    [anon_sym_always_ff] = ACTIONS(6727),
    [anon_sym_final] = ACTIONS(6727),
    [anon_sym_global] = ACTIONS(6727),
    [anon_sym_specify] = ACTIONS(6727),
    [anon_sym_LPAREN_STAR] = ACTIONS(6729),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6729),
    [anon_sym_DOLLARunit] = ACTIONS(6729),
  },
  [1242] = {
    [sym_simple_identifier] = ACTIONS(6731),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6733),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6733),
    [anon_sym_BQUOTE] = ACTIONS(6731),
    [aux_sym_id_directive_token1] = ACTIONS(6733),
    [aux_sym_id_directive_token2] = ACTIONS(6733),
    [aux_sym_id_directive_token3] = ACTIONS(6733),
    [aux_sym_id_directive_token4] = ACTIONS(6731),
    [aux_sym_zero_directive_token1] = ACTIONS(6733),
    [aux_sym_zero_directive_token2] = ACTIONS(6733),
    [aux_sym_zero_directive_token3] = ACTIONS(6733),
    [aux_sym_zero_directive_token4] = ACTIONS(6733),
    [aux_sym_zero_directive_token5] = ACTIONS(6733),
    [aux_sym_zero_directive_token6] = ACTIONS(6733),
    [aux_sym_zero_directive_token7] = ACTIONS(6733),
    [aux_sym_zero_directive_token8] = ACTIONS(6733),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6733),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6733),
    [anon_sym_wire] = ACTIONS(6731),
    [anon_sym_tri] = ACTIONS(6731),
    [anon_sym_tri0] = ACTIONS(6731),
    [anon_sym_tri1] = ACTIONS(6731),
    [anon_sym_wand] = ACTIONS(6731),
    [anon_sym_triand] = ACTIONS(6731),
    [anon_sym_wor] = ACTIONS(6731),
    [anon_sym_trior] = ACTIONS(6731),
    [anon_sym_trireg] = ACTIONS(6731),
    [anon_sym_uwire] = ACTIONS(6731),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6733),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6733),
    [aux_sym_begin_keywords_token1] = ACTIONS(6733),
    [anon_sym_SEMI] = ACTIONS(6733),
    [anon_sym_endmodule] = ACTIONS(6731),
    [anon_sym_extern] = ACTIONS(6731),
    [anon_sym_module] = ACTIONS(6731),
    [anon_sym_macromodule] = ACTIONS(6731),
    [anon_sym_endinterface] = ACTIONS(6731),
    [anon_sym_interface] = ACTIONS(6731),
    [anon_sym_endprogram] = ACTIONS(6731),
    [anon_sym_program] = ACTIONS(6731),
    [anon_sym_checker] = ACTIONS(6731),
    [anon_sym_virtual] = ACTIONS(6731),
    [anon_sym_class] = ACTIONS(6731),
    [anon_sym_timeunit] = ACTIONS(6731),
    [anon_sym_timeprecision] = ACTIONS(6731),
    [anon_sym_type] = ACTIONS(6731),
    [anon_sym_input] = ACTIONS(6731),
    [anon_sym_output] = ACTIONS(6731),
    [anon_sym_inout] = ACTIONS(6731),
    [anon_sym_ref] = ACTIONS(6731),
    [anon_sym_DOLLARfatal] = ACTIONS(6733),
    [anon_sym_DOLLARerror] = ACTIONS(6733),
    [anon_sym_DOLLARwarning] = ACTIONS(6733),
    [anon_sym_DOLLARinfo] = ACTIONS(6733),
    [anon_sym_default] = ACTIONS(6731),
    [anon_sym_clocking] = ACTIONS(6731),
    [anon_sym_defparam] = ACTIONS(6731),
    [anon_sym_bind] = ACTIONS(6731),
    [anon_sym_const] = ACTIONS(6731),
    [anon_sym_function] = ACTIONS(6731),
    [anon_sym_static] = ACTIONS(6731),
    [anon_sym_constraint] = ACTIONS(6731),
    [anon_sym_if] = ACTIONS(6731),
    [anon_sym_else] = ACTIONS(6731),
    [anon_sym_LBRACK] = ACTIONS(6733),
    [anon_sym_localparam] = ACTIONS(6731),
    [anon_sym_parameter] = ACTIONS(6731),
    [anon_sym_specparam] = ACTIONS(6731),
    [anon_sym_var] = ACTIONS(6731),
    [anon_sym_import] = ACTIONS(6731),
    [anon_sym_export] = ACTIONS(6731),
    [anon_sym_genvar] = ACTIONS(6731),
    [anon_sym_interconnect] = ACTIONS(6731),
    [anon_sym_typedef] = ACTIONS(6731),
    [anon_sym_enum] = ACTIONS(6731),
    [anon_sym_struct] = ACTIONS(6731),
    [anon_sym_union] = ACTIONS(6731),
    [anon_sym_nettype] = ACTIONS(6731),
    [anon_sym_automatic] = ACTIONS(6731),
    [anon_sym_string] = ACTIONS(6731),
    [anon_sym_chandle] = ACTIONS(6731),
    [anon_sym_event] = ACTIONS(6731),
    [anon_sym_byte] = ACTIONS(6731),
    [anon_sym_shortint] = ACTIONS(6731),
    [anon_sym_int] = ACTIONS(6731),
    [anon_sym_longint] = ACTIONS(6731),
    [anon_sym_integer] = ACTIONS(6731),
    [anon_sym_time] = ACTIONS(6731),
    [anon_sym_bit] = ACTIONS(6731),
    [anon_sym_logic] = ACTIONS(6731),
    [anon_sym_reg] = ACTIONS(6731),
    [anon_sym_shortreal] = ACTIONS(6731),
    [anon_sym_real] = ACTIONS(6731),
    [anon_sym_realtime] = ACTIONS(6731),
    [anon_sym_supply0] = ACTIONS(6731),
    [anon_sym_supply1] = ACTIONS(6731),
    [anon_sym_signed] = ACTIONS(6731),
    [anon_sym_unsigned] = ACTIONS(6731),
    [anon_sym_task] = ACTIONS(6731),
    [anon_sym_modport] = ACTIONS(6731),
    [anon_sym_assert] = ACTIONS(6731),
    [anon_sym_property] = ACTIONS(6731),
    [anon_sym_assume] = ACTIONS(6731),
    [anon_sym_cover] = ACTIONS(6731),
    [anon_sym_sequence] = ACTIONS(6731),
    [anon_sym_restrict] = ACTIONS(6731),
    [anon_sym_not] = ACTIONS(6731),
    [anon_sym_or] = ACTIONS(6731),
    [anon_sym_and] = ACTIONS(6731),
    [anon_sym_case] = ACTIONS(6731),
    [anon_sym_always] = ACTIONS(6731),
    [anon_sym_covergroup] = ACTIONS(6731),
    [anon_sym_let] = ACTIONS(6731),
    [anon_sym_pulldown] = ACTIONS(6731),
    [anon_sym_pullup] = ACTIONS(6731),
    [anon_sym_cmos] = ACTIONS(6731),
    [anon_sym_rcmos] = ACTIONS(6731),
    [anon_sym_bufif0] = ACTIONS(6731),
    [anon_sym_bufif1] = ACTIONS(6731),
    [anon_sym_notif0] = ACTIONS(6731),
    [anon_sym_notif1] = ACTIONS(6731),
    [anon_sym_nmos] = ACTIONS(6731),
    [anon_sym_pmos] = ACTIONS(6731),
    [anon_sym_rnmos] = ACTIONS(6731),
    [anon_sym_rpmos] = ACTIONS(6731),
    [anon_sym_nand] = ACTIONS(6731),
    [anon_sym_nor] = ACTIONS(6731),
    [anon_sym_xor] = ACTIONS(6731),
    [anon_sym_xnor] = ACTIONS(6731),
    [anon_sym_buf] = ACTIONS(6731),
    [anon_sym_tranif0] = ACTIONS(6731),
    [anon_sym_tranif1] = ACTIONS(6731),
    [anon_sym_rtranif1] = ACTIONS(6731),
    [anon_sym_rtranif0] = ACTIONS(6731),
    [anon_sym_tran] = ACTIONS(6731),
    [anon_sym_rtran] = ACTIONS(6731),
    [anon_sym_generate] = ACTIONS(6731),
    [anon_sym_for] = ACTIONS(6731),
    [anon_sym_initial] = ACTIONS(6731),
    [anon_sym_assign] = ACTIONS(6731),
    [anon_sym_alias] = ACTIONS(6731),
    [anon_sym_always_comb] = ACTIONS(6731),
    [anon_sym_always_latch] = ACTIONS(6731),
    [anon_sym_always_ff] = ACTIONS(6731),
    [anon_sym_final] = ACTIONS(6731),
    [anon_sym_global] = ACTIONS(6731),
    [anon_sym_specify] = ACTIONS(6731),
    [anon_sym_LPAREN_STAR] = ACTIONS(6733),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6733),
    [anon_sym_DOLLARunit] = ACTIONS(6733),
  },
  [1243] = {
    [sym_simple_identifier] = ACTIONS(6735),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6737),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6737),
    [anon_sym_BQUOTE] = ACTIONS(6735),
    [aux_sym_id_directive_token1] = ACTIONS(6737),
    [aux_sym_id_directive_token2] = ACTIONS(6737),
    [aux_sym_id_directive_token3] = ACTIONS(6737),
    [aux_sym_id_directive_token4] = ACTIONS(6735),
    [aux_sym_zero_directive_token1] = ACTIONS(6737),
    [aux_sym_zero_directive_token2] = ACTIONS(6737),
    [aux_sym_zero_directive_token3] = ACTIONS(6737),
    [aux_sym_zero_directive_token4] = ACTIONS(6737),
    [aux_sym_zero_directive_token5] = ACTIONS(6737),
    [aux_sym_zero_directive_token6] = ACTIONS(6737),
    [aux_sym_zero_directive_token7] = ACTIONS(6737),
    [aux_sym_zero_directive_token8] = ACTIONS(6737),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6737),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6737),
    [anon_sym_wire] = ACTIONS(6735),
    [anon_sym_tri] = ACTIONS(6735),
    [anon_sym_tri0] = ACTIONS(6735),
    [anon_sym_tri1] = ACTIONS(6735),
    [anon_sym_wand] = ACTIONS(6735),
    [anon_sym_triand] = ACTIONS(6735),
    [anon_sym_wor] = ACTIONS(6735),
    [anon_sym_trior] = ACTIONS(6735),
    [anon_sym_trireg] = ACTIONS(6735),
    [anon_sym_uwire] = ACTIONS(6735),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6737),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6737),
    [aux_sym_begin_keywords_token1] = ACTIONS(6737),
    [anon_sym_SEMI] = ACTIONS(6737),
    [anon_sym_endmodule] = ACTIONS(6735),
    [anon_sym_extern] = ACTIONS(6735),
    [anon_sym_module] = ACTIONS(6735),
    [anon_sym_macromodule] = ACTIONS(6735),
    [anon_sym_endinterface] = ACTIONS(6735),
    [anon_sym_interface] = ACTIONS(6735),
    [anon_sym_endprogram] = ACTIONS(6735),
    [anon_sym_program] = ACTIONS(6735),
    [anon_sym_checker] = ACTIONS(6735),
    [anon_sym_virtual] = ACTIONS(6735),
    [anon_sym_class] = ACTIONS(6735),
    [anon_sym_timeunit] = ACTIONS(6735),
    [anon_sym_timeprecision] = ACTIONS(6735),
    [anon_sym_type] = ACTIONS(6735),
    [anon_sym_input] = ACTIONS(6735),
    [anon_sym_output] = ACTIONS(6735),
    [anon_sym_inout] = ACTIONS(6735),
    [anon_sym_ref] = ACTIONS(6735),
    [anon_sym_DOLLARfatal] = ACTIONS(6737),
    [anon_sym_DOLLARerror] = ACTIONS(6737),
    [anon_sym_DOLLARwarning] = ACTIONS(6737),
    [anon_sym_DOLLARinfo] = ACTIONS(6737),
    [anon_sym_default] = ACTIONS(6735),
    [anon_sym_clocking] = ACTIONS(6735),
    [anon_sym_defparam] = ACTIONS(6735),
    [anon_sym_bind] = ACTIONS(6735),
    [anon_sym_const] = ACTIONS(6735),
    [anon_sym_function] = ACTIONS(6735),
    [anon_sym_static] = ACTIONS(6735),
    [anon_sym_constraint] = ACTIONS(6735),
    [anon_sym_if] = ACTIONS(6735),
    [anon_sym_else] = ACTIONS(6735),
    [anon_sym_LBRACK] = ACTIONS(6737),
    [anon_sym_localparam] = ACTIONS(6735),
    [anon_sym_parameter] = ACTIONS(6735),
    [anon_sym_specparam] = ACTIONS(6735),
    [anon_sym_var] = ACTIONS(6735),
    [anon_sym_import] = ACTIONS(6735),
    [anon_sym_export] = ACTIONS(6735),
    [anon_sym_genvar] = ACTIONS(6735),
    [anon_sym_interconnect] = ACTIONS(6735),
    [anon_sym_typedef] = ACTIONS(6735),
    [anon_sym_enum] = ACTIONS(6735),
    [anon_sym_struct] = ACTIONS(6735),
    [anon_sym_union] = ACTIONS(6735),
    [anon_sym_nettype] = ACTIONS(6735),
    [anon_sym_automatic] = ACTIONS(6735),
    [anon_sym_string] = ACTIONS(6735),
    [anon_sym_chandle] = ACTIONS(6735),
    [anon_sym_event] = ACTIONS(6735),
    [anon_sym_byte] = ACTIONS(6735),
    [anon_sym_shortint] = ACTIONS(6735),
    [anon_sym_int] = ACTIONS(6735),
    [anon_sym_longint] = ACTIONS(6735),
    [anon_sym_integer] = ACTIONS(6735),
    [anon_sym_time] = ACTIONS(6735),
    [anon_sym_bit] = ACTIONS(6735),
    [anon_sym_logic] = ACTIONS(6735),
    [anon_sym_reg] = ACTIONS(6735),
    [anon_sym_shortreal] = ACTIONS(6735),
    [anon_sym_real] = ACTIONS(6735),
    [anon_sym_realtime] = ACTIONS(6735),
    [anon_sym_supply0] = ACTIONS(6735),
    [anon_sym_supply1] = ACTIONS(6735),
    [anon_sym_signed] = ACTIONS(6735),
    [anon_sym_unsigned] = ACTIONS(6735),
    [anon_sym_task] = ACTIONS(6735),
    [anon_sym_modport] = ACTIONS(6735),
    [anon_sym_assert] = ACTIONS(6735),
    [anon_sym_property] = ACTIONS(6735),
    [anon_sym_assume] = ACTIONS(6735),
    [anon_sym_cover] = ACTIONS(6735),
    [anon_sym_sequence] = ACTIONS(6735),
    [anon_sym_restrict] = ACTIONS(6735),
    [anon_sym_not] = ACTIONS(6735),
    [anon_sym_or] = ACTIONS(6735),
    [anon_sym_and] = ACTIONS(6735),
    [anon_sym_case] = ACTIONS(6735),
    [anon_sym_always] = ACTIONS(6735),
    [anon_sym_covergroup] = ACTIONS(6735),
    [anon_sym_let] = ACTIONS(6735),
    [anon_sym_pulldown] = ACTIONS(6735),
    [anon_sym_pullup] = ACTIONS(6735),
    [anon_sym_cmos] = ACTIONS(6735),
    [anon_sym_rcmos] = ACTIONS(6735),
    [anon_sym_bufif0] = ACTIONS(6735),
    [anon_sym_bufif1] = ACTIONS(6735),
    [anon_sym_notif0] = ACTIONS(6735),
    [anon_sym_notif1] = ACTIONS(6735),
    [anon_sym_nmos] = ACTIONS(6735),
    [anon_sym_pmos] = ACTIONS(6735),
    [anon_sym_rnmos] = ACTIONS(6735),
    [anon_sym_rpmos] = ACTIONS(6735),
    [anon_sym_nand] = ACTIONS(6735),
    [anon_sym_nor] = ACTIONS(6735),
    [anon_sym_xor] = ACTIONS(6735),
    [anon_sym_xnor] = ACTIONS(6735),
    [anon_sym_buf] = ACTIONS(6735),
    [anon_sym_tranif0] = ACTIONS(6735),
    [anon_sym_tranif1] = ACTIONS(6735),
    [anon_sym_rtranif1] = ACTIONS(6735),
    [anon_sym_rtranif0] = ACTIONS(6735),
    [anon_sym_tran] = ACTIONS(6735),
    [anon_sym_rtran] = ACTIONS(6735),
    [anon_sym_generate] = ACTIONS(6735),
    [anon_sym_for] = ACTIONS(6735),
    [anon_sym_initial] = ACTIONS(6735),
    [anon_sym_assign] = ACTIONS(6735),
    [anon_sym_alias] = ACTIONS(6735),
    [anon_sym_always_comb] = ACTIONS(6735),
    [anon_sym_always_latch] = ACTIONS(6735),
    [anon_sym_always_ff] = ACTIONS(6735),
    [anon_sym_final] = ACTIONS(6735),
    [anon_sym_global] = ACTIONS(6735),
    [anon_sym_specify] = ACTIONS(6735),
    [anon_sym_LPAREN_STAR] = ACTIONS(6737),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6737),
    [anon_sym_DOLLARunit] = ACTIONS(6737),
  },
  [1244] = {
    [sym_simple_identifier] = ACTIONS(6739),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6741),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6741),
    [anon_sym_BQUOTE] = ACTIONS(6739),
    [aux_sym_id_directive_token1] = ACTIONS(6741),
    [aux_sym_id_directive_token2] = ACTIONS(6741),
    [aux_sym_id_directive_token3] = ACTIONS(6741),
    [aux_sym_id_directive_token4] = ACTIONS(6739),
    [aux_sym_zero_directive_token1] = ACTIONS(6741),
    [aux_sym_zero_directive_token2] = ACTIONS(6741),
    [aux_sym_zero_directive_token3] = ACTIONS(6741),
    [aux_sym_zero_directive_token4] = ACTIONS(6741),
    [aux_sym_zero_directive_token5] = ACTIONS(6741),
    [aux_sym_zero_directive_token6] = ACTIONS(6741),
    [aux_sym_zero_directive_token7] = ACTIONS(6741),
    [aux_sym_zero_directive_token8] = ACTIONS(6741),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6741),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6741),
    [anon_sym_wire] = ACTIONS(6739),
    [anon_sym_tri] = ACTIONS(6739),
    [anon_sym_tri0] = ACTIONS(6739),
    [anon_sym_tri1] = ACTIONS(6739),
    [anon_sym_wand] = ACTIONS(6739),
    [anon_sym_triand] = ACTIONS(6739),
    [anon_sym_wor] = ACTIONS(6739),
    [anon_sym_trior] = ACTIONS(6739),
    [anon_sym_trireg] = ACTIONS(6739),
    [anon_sym_uwire] = ACTIONS(6739),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6741),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6741),
    [aux_sym_begin_keywords_token1] = ACTIONS(6741),
    [anon_sym_SEMI] = ACTIONS(6741),
    [anon_sym_endmodule] = ACTIONS(6739),
    [anon_sym_extern] = ACTIONS(6739),
    [anon_sym_module] = ACTIONS(6739),
    [anon_sym_macromodule] = ACTIONS(6739),
    [anon_sym_endinterface] = ACTIONS(6739),
    [anon_sym_interface] = ACTIONS(6739),
    [anon_sym_endprogram] = ACTIONS(6739),
    [anon_sym_program] = ACTIONS(6739),
    [anon_sym_checker] = ACTIONS(6739),
    [anon_sym_virtual] = ACTIONS(6739),
    [anon_sym_class] = ACTIONS(6739),
    [anon_sym_timeunit] = ACTIONS(6739),
    [anon_sym_timeprecision] = ACTIONS(6739),
    [anon_sym_type] = ACTIONS(6739),
    [anon_sym_input] = ACTIONS(6739),
    [anon_sym_output] = ACTIONS(6739),
    [anon_sym_inout] = ACTIONS(6739),
    [anon_sym_ref] = ACTIONS(6739),
    [anon_sym_DOLLARfatal] = ACTIONS(6741),
    [anon_sym_DOLLARerror] = ACTIONS(6741),
    [anon_sym_DOLLARwarning] = ACTIONS(6741),
    [anon_sym_DOLLARinfo] = ACTIONS(6741),
    [anon_sym_default] = ACTIONS(6739),
    [anon_sym_clocking] = ACTIONS(6739),
    [anon_sym_defparam] = ACTIONS(6739),
    [anon_sym_bind] = ACTIONS(6739),
    [anon_sym_const] = ACTIONS(6739),
    [anon_sym_function] = ACTIONS(6739),
    [anon_sym_static] = ACTIONS(6739),
    [anon_sym_constraint] = ACTIONS(6739),
    [anon_sym_if] = ACTIONS(6739),
    [anon_sym_else] = ACTIONS(6739),
    [anon_sym_LBRACK] = ACTIONS(6741),
    [anon_sym_localparam] = ACTIONS(6739),
    [anon_sym_parameter] = ACTIONS(6739),
    [anon_sym_specparam] = ACTIONS(6739),
    [anon_sym_var] = ACTIONS(6739),
    [anon_sym_import] = ACTIONS(6739),
    [anon_sym_export] = ACTIONS(6739),
    [anon_sym_genvar] = ACTIONS(6739),
    [anon_sym_interconnect] = ACTIONS(6739),
    [anon_sym_typedef] = ACTIONS(6739),
    [anon_sym_enum] = ACTIONS(6739),
    [anon_sym_struct] = ACTIONS(6739),
    [anon_sym_union] = ACTIONS(6739),
    [anon_sym_nettype] = ACTIONS(6739),
    [anon_sym_automatic] = ACTIONS(6739),
    [anon_sym_string] = ACTIONS(6739),
    [anon_sym_chandle] = ACTIONS(6739),
    [anon_sym_event] = ACTIONS(6739),
    [anon_sym_byte] = ACTIONS(6739),
    [anon_sym_shortint] = ACTIONS(6739),
    [anon_sym_int] = ACTIONS(6739),
    [anon_sym_longint] = ACTIONS(6739),
    [anon_sym_integer] = ACTIONS(6739),
    [anon_sym_time] = ACTIONS(6739),
    [anon_sym_bit] = ACTIONS(6739),
    [anon_sym_logic] = ACTIONS(6739),
    [anon_sym_reg] = ACTIONS(6739),
    [anon_sym_shortreal] = ACTIONS(6739),
    [anon_sym_real] = ACTIONS(6739),
    [anon_sym_realtime] = ACTIONS(6739),
    [anon_sym_supply0] = ACTIONS(6739),
    [anon_sym_supply1] = ACTIONS(6739),
    [anon_sym_signed] = ACTIONS(6739),
    [anon_sym_unsigned] = ACTIONS(6739),
    [anon_sym_task] = ACTIONS(6739),
    [anon_sym_modport] = ACTIONS(6739),
    [anon_sym_assert] = ACTIONS(6739),
    [anon_sym_property] = ACTIONS(6739),
    [anon_sym_assume] = ACTIONS(6739),
    [anon_sym_cover] = ACTIONS(6739),
    [anon_sym_sequence] = ACTIONS(6739),
    [anon_sym_restrict] = ACTIONS(6739),
    [anon_sym_not] = ACTIONS(6739),
    [anon_sym_or] = ACTIONS(6739),
    [anon_sym_and] = ACTIONS(6739),
    [anon_sym_case] = ACTIONS(6739),
    [anon_sym_always] = ACTIONS(6739),
    [anon_sym_covergroup] = ACTIONS(6739),
    [anon_sym_let] = ACTIONS(6739),
    [anon_sym_pulldown] = ACTIONS(6739),
    [anon_sym_pullup] = ACTIONS(6739),
    [anon_sym_cmos] = ACTIONS(6739),
    [anon_sym_rcmos] = ACTIONS(6739),
    [anon_sym_bufif0] = ACTIONS(6739),
    [anon_sym_bufif1] = ACTIONS(6739),
    [anon_sym_notif0] = ACTIONS(6739),
    [anon_sym_notif1] = ACTIONS(6739),
    [anon_sym_nmos] = ACTIONS(6739),
    [anon_sym_pmos] = ACTIONS(6739),
    [anon_sym_rnmos] = ACTIONS(6739),
    [anon_sym_rpmos] = ACTIONS(6739),
    [anon_sym_nand] = ACTIONS(6739),
    [anon_sym_nor] = ACTIONS(6739),
    [anon_sym_xor] = ACTIONS(6739),
    [anon_sym_xnor] = ACTIONS(6739),
    [anon_sym_buf] = ACTIONS(6739),
    [anon_sym_tranif0] = ACTIONS(6739),
    [anon_sym_tranif1] = ACTIONS(6739),
    [anon_sym_rtranif1] = ACTIONS(6739),
    [anon_sym_rtranif0] = ACTIONS(6739),
    [anon_sym_tran] = ACTIONS(6739),
    [anon_sym_rtran] = ACTIONS(6739),
    [anon_sym_generate] = ACTIONS(6739),
    [anon_sym_for] = ACTIONS(6739),
    [anon_sym_initial] = ACTIONS(6739),
    [anon_sym_assign] = ACTIONS(6739),
    [anon_sym_alias] = ACTIONS(6739),
    [anon_sym_always_comb] = ACTIONS(6739),
    [anon_sym_always_latch] = ACTIONS(6739),
    [anon_sym_always_ff] = ACTIONS(6739),
    [anon_sym_final] = ACTIONS(6739),
    [anon_sym_global] = ACTIONS(6739),
    [anon_sym_specify] = ACTIONS(6739),
    [anon_sym_LPAREN_STAR] = ACTIONS(6741),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6741),
    [anon_sym_DOLLARunit] = ACTIONS(6741),
  },
  [1245] = {
    [sym_simple_identifier] = ACTIONS(6743),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6745),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6745),
    [anon_sym_BQUOTE] = ACTIONS(6743),
    [aux_sym_id_directive_token1] = ACTIONS(6745),
    [aux_sym_id_directive_token2] = ACTIONS(6745),
    [aux_sym_id_directive_token3] = ACTIONS(6745),
    [aux_sym_id_directive_token4] = ACTIONS(6743),
    [aux_sym_zero_directive_token1] = ACTIONS(6745),
    [aux_sym_zero_directive_token2] = ACTIONS(6745),
    [aux_sym_zero_directive_token3] = ACTIONS(6745),
    [aux_sym_zero_directive_token4] = ACTIONS(6745),
    [aux_sym_zero_directive_token5] = ACTIONS(6745),
    [aux_sym_zero_directive_token6] = ACTIONS(6745),
    [aux_sym_zero_directive_token7] = ACTIONS(6745),
    [aux_sym_zero_directive_token8] = ACTIONS(6745),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6745),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6745),
    [anon_sym_wire] = ACTIONS(6743),
    [anon_sym_tri] = ACTIONS(6743),
    [anon_sym_tri0] = ACTIONS(6743),
    [anon_sym_tri1] = ACTIONS(6743),
    [anon_sym_wand] = ACTIONS(6743),
    [anon_sym_triand] = ACTIONS(6743),
    [anon_sym_wor] = ACTIONS(6743),
    [anon_sym_trior] = ACTIONS(6743),
    [anon_sym_trireg] = ACTIONS(6743),
    [anon_sym_uwire] = ACTIONS(6743),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6745),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6745),
    [aux_sym_begin_keywords_token1] = ACTIONS(6745),
    [anon_sym_SEMI] = ACTIONS(6745),
    [anon_sym_endmodule] = ACTIONS(6743),
    [anon_sym_extern] = ACTIONS(6743),
    [anon_sym_module] = ACTIONS(6743),
    [anon_sym_macromodule] = ACTIONS(6743),
    [anon_sym_endinterface] = ACTIONS(6743),
    [anon_sym_interface] = ACTIONS(6743),
    [anon_sym_endprogram] = ACTIONS(6743),
    [anon_sym_program] = ACTIONS(6743),
    [anon_sym_checker] = ACTIONS(6743),
    [anon_sym_virtual] = ACTIONS(6743),
    [anon_sym_class] = ACTIONS(6743),
    [anon_sym_timeunit] = ACTIONS(6743),
    [anon_sym_timeprecision] = ACTIONS(6743),
    [anon_sym_type] = ACTIONS(6743),
    [anon_sym_input] = ACTIONS(6743),
    [anon_sym_output] = ACTIONS(6743),
    [anon_sym_inout] = ACTIONS(6743),
    [anon_sym_ref] = ACTIONS(6743),
    [anon_sym_DOLLARfatal] = ACTIONS(6745),
    [anon_sym_DOLLARerror] = ACTIONS(6745),
    [anon_sym_DOLLARwarning] = ACTIONS(6745),
    [anon_sym_DOLLARinfo] = ACTIONS(6745),
    [anon_sym_default] = ACTIONS(6743),
    [anon_sym_clocking] = ACTIONS(6743),
    [anon_sym_defparam] = ACTIONS(6743),
    [anon_sym_bind] = ACTIONS(6743),
    [anon_sym_const] = ACTIONS(6743),
    [anon_sym_function] = ACTIONS(6743),
    [anon_sym_static] = ACTIONS(6743),
    [anon_sym_constraint] = ACTIONS(6743),
    [anon_sym_if] = ACTIONS(6743),
    [anon_sym_else] = ACTIONS(6743),
    [anon_sym_LBRACK] = ACTIONS(6745),
    [anon_sym_localparam] = ACTIONS(6743),
    [anon_sym_parameter] = ACTIONS(6743),
    [anon_sym_specparam] = ACTIONS(6743),
    [anon_sym_var] = ACTIONS(6743),
    [anon_sym_import] = ACTIONS(6743),
    [anon_sym_export] = ACTIONS(6743),
    [anon_sym_genvar] = ACTIONS(6743),
    [anon_sym_interconnect] = ACTIONS(6743),
    [anon_sym_typedef] = ACTIONS(6743),
    [anon_sym_enum] = ACTIONS(6743),
    [anon_sym_struct] = ACTIONS(6743),
    [anon_sym_union] = ACTIONS(6743),
    [anon_sym_nettype] = ACTIONS(6743),
    [anon_sym_automatic] = ACTIONS(6743),
    [anon_sym_string] = ACTIONS(6743),
    [anon_sym_chandle] = ACTIONS(6743),
    [anon_sym_event] = ACTIONS(6743),
    [anon_sym_byte] = ACTIONS(6743),
    [anon_sym_shortint] = ACTIONS(6743),
    [anon_sym_int] = ACTIONS(6743),
    [anon_sym_longint] = ACTIONS(6743),
    [anon_sym_integer] = ACTIONS(6743),
    [anon_sym_time] = ACTIONS(6743),
    [anon_sym_bit] = ACTIONS(6743),
    [anon_sym_logic] = ACTIONS(6743),
    [anon_sym_reg] = ACTIONS(6743),
    [anon_sym_shortreal] = ACTIONS(6743),
    [anon_sym_real] = ACTIONS(6743),
    [anon_sym_realtime] = ACTIONS(6743),
    [anon_sym_supply0] = ACTIONS(6743),
    [anon_sym_supply1] = ACTIONS(6743),
    [anon_sym_signed] = ACTIONS(6743),
    [anon_sym_unsigned] = ACTIONS(6743),
    [anon_sym_task] = ACTIONS(6743),
    [anon_sym_modport] = ACTIONS(6743),
    [anon_sym_assert] = ACTIONS(6743),
    [anon_sym_property] = ACTIONS(6743),
    [anon_sym_assume] = ACTIONS(6743),
    [anon_sym_cover] = ACTIONS(6743),
    [anon_sym_sequence] = ACTIONS(6743),
    [anon_sym_restrict] = ACTIONS(6743),
    [anon_sym_not] = ACTIONS(6743),
    [anon_sym_or] = ACTIONS(6743),
    [anon_sym_and] = ACTIONS(6743),
    [anon_sym_case] = ACTIONS(6743),
    [anon_sym_always] = ACTIONS(6743),
    [anon_sym_covergroup] = ACTIONS(6743),
    [anon_sym_let] = ACTIONS(6743),
    [anon_sym_pulldown] = ACTIONS(6743),
    [anon_sym_pullup] = ACTIONS(6743),
    [anon_sym_cmos] = ACTIONS(6743),
    [anon_sym_rcmos] = ACTIONS(6743),
    [anon_sym_bufif0] = ACTIONS(6743),
    [anon_sym_bufif1] = ACTIONS(6743),
    [anon_sym_notif0] = ACTIONS(6743),
    [anon_sym_notif1] = ACTIONS(6743),
    [anon_sym_nmos] = ACTIONS(6743),
    [anon_sym_pmos] = ACTIONS(6743),
    [anon_sym_rnmos] = ACTIONS(6743),
    [anon_sym_rpmos] = ACTIONS(6743),
    [anon_sym_nand] = ACTIONS(6743),
    [anon_sym_nor] = ACTIONS(6743),
    [anon_sym_xor] = ACTIONS(6743),
    [anon_sym_xnor] = ACTIONS(6743),
    [anon_sym_buf] = ACTIONS(6743),
    [anon_sym_tranif0] = ACTIONS(6743),
    [anon_sym_tranif1] = ACTIONS(6743),
    [anon_sym_rtranif1] = ACTIONS(6743),
    [anon_sym_rtranif0] = ACTIONS(6743),
    [anon_sym_tran] = ACTIONS(6743),
    [anon_sym_rtran] = ACTIONS(6743),
    [anon_sym_generate] = ACTIONS(6743),
    [anon_sym_for] = ACTIONS(6743),
    [anon_sym_initial] = ACTIONS(6743),
    [anon_sym_assign] = ACTIONS(6743),
    [anon_sym_alias] = ACTIONS(6743),
    [anon_sym_always_comb] = ACTIONS(6743),
    [anon_sym_always_latch] = ACTIONS(6743),
    [anon_sym_always_ff] = ACTIONS(6743),
    [anon_sym_final] = ACTIONS(6743),
    [anon_sym_global] = ACTIONS(6743),
    [anon_sym_specify] = ACTIONS(6743),
    [anon_sym_LPAREN_STAR] = ACTIONS(6745),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6745),
    [anon_sym_DOLLARunit] = ACTIONS(6745),
  },
  [1246] = {
    [sym_simple_identifier] = ACTIONS(6747),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6749),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6749),
    [anon_sym_BQUOTE] = ACTIONS(6747),
    [aux_sym_id_directive_token1] = ACTIONS(6749),
    [aux_sym_id_directive_token2] = ACTIONS(6749),
    [aux_sym_id_directive_token3] = ACTIONS(6749),
    [aux_sym_id_directive_token4] = ACTIONS(6747),
    [aux_sym_zero_directive_token1] = ACTIONS(6749),
    [aux_sym_zero_directive_token2] = ACTIONS(6749),
    [aux_sym_zero_directive_token3] = ACTIONS(6749),
    [aux_sym_zero_directive_token4] = ACTIONS(6749),
    [aux_sym_zero_directive_token5] = ACTIONS(6749),
    [aux_sym_zero_directive_token6] = ACTIONS(6749),
    [aux_sym_zero_directive_token7] = ACTIONS(6749),
    [aux_sym_zero_directive_token8] = ACTIONS(6749),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6749),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6749),
    [anon_sym_wire] = ACTIONS(6747),
    [anon_sym_tri] = ACTIONS(6747),
    [anon_sym_tri0] = ACTIONS(6747),
    [anon_sym_tri1] = ACTIONS(6747),
    [anon_sym_wand] = ACTIONS(6747),
    [anon_sym_triand] = ACTIONS(6747),
    [anon_sym_wor] = ACTIONS(6747),
    [anon_sym_trior] = ACTIONS(6747),
    [anon_sym_trireg] = ACTIONS(6747),
    [anon_sym_uwire] = ACTIONS(6747),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6749),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6749),
    [aux_sym_begin_keywords_token1] = ACTIONS(6749),
    [anon_sym_SEMI] = ACTIONS(6749),
    [anon_sym_endmodule] = ACTIONS(6747),
    [anon_sym_extern] = ACTIONS(6747),
    [anon_sym_module] = ACTIONS(6747),
    [anon_sym_macromodule] = ACTIONS(6747),
    [anon_sym_endinterface] = ACTIONS(6747),
    [anon_sym_interface] = ACTIONS(6747),
    [anon_sym_endprogram] = ACTIONS(6747),
    [anon_sym_program] = ACTIONS(6747),
    [anon_sym_checker] = ACTIONS(6747),
    [anon_sym_virtual] = ACTIONS(6747),
    [anon_sym_class] = ACTIONS(6747),
    [anon_sym_timeunit] = ACTIONS(6747),
    [anon_sym_timeprecision] = ACTIONS(6747),
    [anon_sym_type] = ACTIONS(6747),
    [anon_sym_input] = ACTIONS(6747),
    [anon_sym_output] = ACTIONS(6747),
    [anon_sym_inout] = ACTIONS(6747),
    [anon_sym_ref] = ACTIONS(6747),
    [anon_sym_DOLLARfatal] = ACTIONS(6749),
    [anon_sym_DOLLARerror] = ACTIONS(6749),
    [anon_sym_DOLLARwarning] = ACTIONS(6749),
    [anon_sym_DOLLARinfo] = ACTIONS(6749),
    [anon_sym_default] = ACTIONS(6747),
    [anon_sym_clocking] = ACTIONS(6747),
    [anon_sym_defparam] = ACTIONS(6747),
    [anon_sym_bind] = ACTIONS(6747),
    [anon_sym_const] = ACTIONS(6747),
    [anon_sym_function] = ACTIONS(6747),
    [anon_sym_static] = ACTIONS(6747),
    [anon_sym_constraint] = ACTIONS(6747),
    [anon_sym_if] = ACTIONS(6747),
    [anon_sym_else] = ACTIONS(6747),
    [anon_sym_LBRACK] = ACTIONS(6749),
    [anon_sym_localparam] = ACTIONS(6747),
    [anon_sym_parameter] = ACTIONS(6747),
    [anon_sym_specparam] = ACTIONS(6747),
    [anon_sym_var] = ACTIONS(6747),
    [anon_sym_import] = ACTIONS(6747),
    [anon_sym_export] = ACTIONS(6747),
    [anon_sym_genvar] = ACTIONS(6747),
    [anon_sym_interconnect] = ACTIONS(6747),
    [anon_sym_typedef] = ACTIONS(6747),
    [anon_sym_enum] = ACTIONS(6747),
    [anon_sym_struct] = ACTIONS(6747),
    [anon_sym_union] = ACTIONS(6747),
    [anon_sym_nettype] = ACTIONS(6747),
    [anon_sym_automatic] = ACTIONS(6747),
    [anon_sym_string] = ACTIONS(6747),
    [anon_sym_chandle] = ACTIONS(6747),
    [anon_sym_event] = ACTIONS(6747),
    [anon_sym_byte] = ACTIONS(6747),
    [anon_sym_shortint] = ACTIONS(6747),
    [anon_sym_int] = ACTIONS(6747),
    [anon_sym_longint] = ACTIONS(6747),
    [anon_sym_integer] = ACTIONS(6747),
    [anon_sym_time] = ACTIONS(6747),
    [anon_sym_bit] = ACTIONS(6747),
    [anon_sym_logic] = ACTIONS(6747),
    [anon_sym_reg] = ACTIONS(6747),
    [anon_sym_shortreal] = ACTIONS(6747),
    [anon_sym_real] = ACTIONS(6747),
    [anon_sym_realtime] = ACTIONS(6747),
    [anon_sym_supply0] = ACTIONS(6747),
    [anon_sym_supply1] = ACTIONS(6747),
    [anon_sym_signed] = ACTIONS(6747),
    [anon_sym_unsigned] = ACTIONS(6747),
    [anon_sym_task] = ACTIONS(6747),
    [anon_sym_modport] = ACTIONS(6747),
    [anon_sym_assert] = ACTIONS(6747),
    [anon_sym_property] = ACTIONS(6747),
    [anon_sym_assume] = ACTIONS(6747),
    [anon_sym_cover] = ACTIONS(6747),
    [anon_sym_sequence] = ACTIONS(6747),
    [anon_sym_restrict] = ACTIONS(6747),
    [anon_sym_not] = ACTIONS(6747),
    [anon_sym_or] = ACTIONS(6747),
    [anon_sym_and] = ACTIONS(6747),
    [anon_sym_case] = ACTIONS(6747),
    [anon_sym_always] = ACTIONS(6747),
    [anon_sym_covergroup] = ACTIONS(6747),
    [anon_sym_let] = ACTIONS(6747),
    [anon_sym_pulldown] = ACTIONS(6747),
    [anon_sym_pullup] = ACTIONS(6747),
    [anon_sym_cmos] = ACTIONS(6747),
    [anon_sym_rcmos] = ACTIONS(6747),
    [anon_sym_bufif0] = ACTIONS(6747),
    [anon_sym_bufif1] = ACTIONS(6747),
    [anon_sym_notif0] = ACTIONS(6747),
    [anon_sym_notif1] = ACTIONS(6747),
    [anon_sym_nmos] = ACTIONS(6747),
    [anon_sym_pmos] = ACTIONS(6747),
    [anon_sym_rnmos] = ACTIONS(6747),
    [anon_sym_rpmos] = ACTIONS(6747),
    [anon_sym_nand] = ACTIONS(6747),
    [anon_sym_nor] = ACTIONS(6747),
    [anon_sym_xor] = ACTIONS(6747),
    [anon_sym_xnor] = ACTIONS(6747),
    [anon_sym_buf] = ACTIONS(6747),
    [anon_sym_tranif0] = ACTIONS(6747),
    [anon_sym_tranif1] = ACTIONS(6747),
    [anon_sym_rtranif1] = ACTIONS(6747),
    [anon_sym_rtranif0] = ACTIONS(6747),
    [anon_sym_tran] = ACTIONS(6747),
    [anon_sym_rtran] = ACTIONS(6747),
    [anon_sym_generate] = ACTIONS(6747),
    [anon_sym_for] = ACTIONS(6747),
    [anon_sym_initial] = ACTIONS(6747),
    [anon_sym_assign] = ACTIONS(6747),
    [anon_sym_alias] = ACTIONS(6747),
    [anon_sym_always_comb] = ACTIONS(6747),
    [anon_sym_always_latch] = ACTIONS(6747),
    [anon_sym_always_ff] = ACTIONS(6747),
    [anon_sym_final] = ACTIONS(6747),
    [anon_sym_global] = ACTIONS(6747),
    [anon_sym_specify] = ACTIONS(6747),
    [anon_sym_LPAREN_STAR] = ACTIONS(6749),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6749),
    [anon_sym_DOLLARunit] = ACTIONS(6749),
  },
  [1247] = {
    [sym_simple_identifier] = ACTIONS(6751),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6753),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6753),
    [anon_sym_BQUOTE] = ACTIONS(6751),
    [aux_sym_id_directive_token1] = ACTIONS(6753),
    [aux_sym_id_directive_token2] = ACTIONS(6753),
    [aux_sym_id_directive_token3] = ACTIONS(6753),
    [aux_sym_id_directive_token4] = ACTIONS(6751),
    [aux_sym_zero_directive_token1] = ACTIONS(6753),
    [aux_sym_zero_directive_token2] = ACTIONS(6753),
    [aux_sym_zero_directive_token3] = ACTIONS(6753),
    [aux_sym_zero_directive_token4] = ACTIONS(6753),
    [aux_sym_zero_directive_token5] = ACTIONS(6753),
    [aux_sym_zero_directive_token6] = ACTIONS(6753),
    [aux_sym_zero_directive_token7] = ACTIONS(6753),
    [aux_sym_zero_directive_token8] = ACTIONS(6753),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6753),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6753),
    [anon_sym_wire] = ACTIONS(6751),
    [anon_sym_tri] = ACTIONS(6751),
    [anon_sym_tri0] = ACTIONS(6751),
    [anon_sym_tri1] = ACTIONS(6751),
    [anon_sym_wand] = ACTIONS(6751),
    [anon_sym_triand] = ACTIONS(6751),
    [anon_sym_wor] = ACTIONS(6751),
    [anon_sym_trior] = ACTIONS(6751),
    [anon_sym_trireg] = ACTIONS(6751),
    [anon_sym_uwire] = ACTIONS(6751),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6753),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6753),
    [aux_sym_begin_keywords_token1] = ACTIONS(6753),
    [anon_sym_SEMI] = ACTIONS(6753),
    [anon_sym_endmodule] = ACTIONS(6751),
    [anon_sym_extern] = ACTIONS(6751),
    [anon_sym_module] = ACTIONS(6751),
    [anon_sym_macromodule] = ACTIONS(6751),
    [anon_sym_endinterface] = ACTIONS(6751),
    [anon_sym_interface] = ACTIONS(6751),
    [anon_sym_endprogram] = ACTIONS(6751),
    [anon_sym_program] = ACTIONS(6751),
    [anon_sym_checker] = ACTIONS(6751),
    [anon_sym_virtual] = ACTIONS(6751),
    [anon_sym_class] = ACTIONS(6751),
    [anon_sym_timeunit] = ACTIONS(6751),
    [anon_sym_timeprecision] = ACTIONS(6751),
    [anon_sym_type] = ACTIONS(6751),
    [anon_sym_input] = ACTIONS(6751),
    [anon_sym_output] = ACTIONS(6751),
    [anon_sym_inout] = ACTIONS(6751),
    [anon_sym_ref] = ACTIONS(6751),
    [anon_sym_DOLLARfatal] = ACTIONS(6753),
    [anon_sym_DOLLARerror] = ACTIONS(6753),
    [anon_sym_DOLLARwarning] = ACTIONS(6753),
    [anon_sym_DOLLARinfo] = ACTIONS(6753),
    [anon_sym_default] = ACTIONS(6751),
    [anon_sym_clocking] = ACTIONS(6751),
    [anon_sym_defparam] = ACTIONS(6751),
    [anon_sym_bind] = ACTIONS(6751),
    [anon_sym_const] = ACTIONS(6751),
    [anon_sym_function] = ACTIONS(6751),
    [anon_sym_static] = ACTIONS(6751),
    [anon_sym_constraint] = ACTIONS(6751),
    [anon_sym_if] = ACTIONS(6751),
    [anon_sym_else] = ACTIONS(6751),
    [anon_sym_LBRACK] = ACTIONS(6753),
    [anon_sym_localparam] = ACTIONS(6751),
    [anon_sym_parameter] = ACTIONS(6751),
    [anon_sym_specparam] = ACTIONS(6751),
    [anon_sym_var] = ACTIONS(6751),
    [anon_sym_import] = ACTIONS(6751),
    [anon_sym_export] = ACTIONS(6751),
    [anon_sym_genvar] = ACTIONS(6751),
    [anon_sym_interconnect] = ACTIONS(6751),
    [anon_sym_typedef] = ACTIONS(6751),
    [anon_sym_enum] = ACTIONS(6751),
    [anon_sym_struct] = ACTIONS(6751),
    [anon_sym_union] = ACTIONS(6751),
    [anon_sym_nettype] = ACTIONS(6751),
    [anon_sym_automatic] = ACTIONS(6751),
    [anon_sym_string] = ACTIONS(6751),
    [anon_sym_chandle] = ACTIONS(6751),
    [anon_sym_event] = ACTIONS(6751),
    [anon_sym_byte] = ACTIONS(6751),
    [anon_sym_shortint] = ACTIONS(6751),
    [anon_sym_int] = ACTIONS(6751),
    [anon_sym_longint] = ACTIONS(6751),
    [anon_sym_integer] = ACTIONS(6751),
    [anon_sym_time] = ACTIONS(6751),
    [anon_sym_bit] = ACTIONS(6751),
    [anon_sym_logic] = ACTIONS(6751),
    [anon_sym_reg] = ACTIONS(6751),
    [anon_sym_shortreal] = ACTIONS(6751),
    [anon_sym_real] = ACTIONS(6751),
    [anon_sym_realtime] = ACTIONS(6751),
    [anon_sym_supply0] = ACTIONS(6751),
    [anon_sym_supply1] = ACTIONS(6751),
    [anon_sym_signed] = ACTIONS(6751),
    [anon_sym_unsigned] = ACTIONS(6751),
    [anon_sym_task] = ACTIONS(6751),
    [anon_sym_modport] = ACTIONS(6751),
    [anon_sym_assert] = ACTIONS(6751),
    [anon_sym_property] = ACTIONS(6751),
    [anon_sym_assume] = ACTIONS(6751),
    [anon_sym_cover] = ACTIONS(6751),
    [anon_sym_sequence] = ACTIONS(6751),
    [anon_sym_restrict] = ACTIONS(6751),
    [anon_sym_not] = ACTIONS(6751),
    [anon_sym_or] = ACTIONS(6751),
    [anon_sym_and] = ACTIONS(6751),
    [anon_sym_case] = ACTIONS(6751),
    [anon_sym_always] = ACTIONS(6751),
    [anon_sym_covergroup] = ACTIONS(6751),
    [anon_sym_let] = ACTIONS(6751),
    [anon_sym_pulldown] = ACTIONS(6751),
    [anon_sym_pullup] = ACTIONS(6751),
    [anon_sym_cmos] = ACTIONS(6751),
    [anon_sym_rcmos] = ACTIONS(6751),
    [anon_sym_bufif0] = ACTIONS(6751),
    [anon_sym_bufif1] = ACTIONS(6751),
    [anon_sym_notif0] = ACTIONS(6751),
    [anon_sym_notif1] = ACTIONS(6751),
    [anon_sym_nmos] = ACTIONS(6751),
    [anon_sym_pmos] = ACTIONS(6751),
    [anon_sym_rnmos] = ACTIONS(6751),
    [anon_sym_rpmos] = ACTIONS(6751),
    [anon_sym_nand] = ACTIONS(6751),
    [anon_sym_nor] = ACTIONS(6751),
    [anon_sym_xor] = ACTIONS(6751),
    [anon_sym_xnor] = ACTIONS(6751),
    [anon_sym_buf] = ACTIONS(6751),
    [anon_sym_tranif0] = ACTIONS(6751),
    [anon_sym_tranif1] = ACTIONS(6751),
    [anon_sym_rtranif1] = ACTIONS(6751),
    [anon_sym_rtranif0] = ACTIONS(6751),
    [anon_sym_tran] = ACTIONS(6751),
    [anon_sym_rtran] = ACTIONS(6751),
    [anon_sym_generate] = ACTIONS(6751),
    [anon_sym_for] = ACTIONS(6751),
    [anon_sym_initial] = ACTIONS(6751),
    [anon_sym_assign] = ACTIONS(6751),
    [anon_sym_alias] = ACTIONS(6751),
    [anon_sym_always_comb] = ACTIONS(6751),
    [anon_sym_always_latch] = ACTIONS(6751),
    [anon_sym_always_ff] = ACTIONS(6751),
    [anon_sym_final] = ACTIONS(6751),
    [anon_sym_global] = ACTIONS(6751),
    [anon_sym_specify] = ACTIONS(6751),
    [anon_sym_LPAREN_STAR] = ACTIONS(6753),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6753),
    [anon_sym_DOLLARunit] = ACTIONS(6753),
  },
  [1248] = {
    [sym_simple_identifier] = ACTIONS(6755),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6757),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6757),
    [anon_sym_BQUOTE] = ACTIONS(6755),
    [aux_sym_id_directive_token1] = ACTIONS(6757),
    [aux_sym_id_directive_token2] = ACTIONS(6757),
    [aux_sym_id_directive_token3] = ACTIONS(6757),
    [aux_sym_id_directive_token4] = ACTIONS(6755),
    [aux_sym_zero_directive_token1] = ACTIONS(6757),
    [aux_sym_zero_directive_token2] = ACTIONS(6757),
    [aux_sym_zero_directive_token3] = ACTIONS(6757),
    [aux_sym_zero_directive_token4] = ACTIONS(6757),
    [aux_sym_zero_directive_token5] = ACTIONS(6757),
    [aux_sym_zero_directive_token6] = ACTIONS(6757),
    [aux_sym_zero_directive_token7] = ACTIONS(6757),
    [aux_sym_zero_directive_token8] = ACTIONS(6757),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6757),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6757),
    [anon_sym_wire] = ACTIONS(6755),
    [anon_sym_tri] = ACTIONS(6755),
    [anon_sym_tri0] = ACTIONS(6755),
    [anon_sym_tri1] = ACTIONS(6755),
    [anon_sym_wand] = ACTIONS(6755),
    [anon_sym_triand] = ACTIONS(6755),
    [anon_sym_wor] = ACTIONS(6755),
    [anon_sym_trior] = ACTIONS(6755),
    [anon_sym_trireg] = ACTIONS(6755),
    [anon_sym_uwire] = ACTIONS(6755),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6757),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6757),
    [aux_sym_begin_keywords_token1] = ACTIONS(6757),
    [anon_sym_SEMI] = ACTIONS(6757),
    [anon_sym_endmodule] = ACTIONS(6755),
    [anon_sym_extern] = ACTIONS(6755),
    [anon_sym_module] = ACTIONS(6755),
    [anon_sym_macromodule] = ACTIONS(6755),
    [anon_sym_endinterface] = ACTIONS(6755),
    [anon_sym_interface] = ACTIONS(6755),
    [anon_sym_endprogram] = ACTIONS(6755),
    [anon_sym_program] = ACTIONS(6755),
    [anon_sym_checker] = ACTIONS(6755),
    [anon_sym_virtual] = ACTIONS(6755),
    [anon_sym_class] = ACTIONS(6755),
    [anon_sym_timeunit] = ACTIONS(6755),
    [anon_sym_timeprecision] = ACTIONS(6755),
    [anon_sym_type] = ACTIONS(6755),
    [anon_sym_input] = ACTIONS(6755),
    [anon_sym_output] = ACTIONS(6755),
    [anon_sym_inout] = ACTIONS(6755),
    [anon_sym_ref] = ACTIONS(6755),
    [anon_sym_DOLLARfatal] = ACTIONS(6757),
    [anon_sym_DOLLARerror] = ACTIONS(6757),
    [anon_sym_DOLLARwarning] = ACTIONS(6757),
    [anon_sym_DOLLARinfo] = ACTIONS(6757),
    [anon_sym_default] = ACTIONS(6755),
    [anon_sym_clocking] = ACTIONS(6755),
    [anon_sym_defparam] = ACTIONS(6755),
    [anon_sym_bind] = ACTIONS(6755),
    [anon_sym_const] = ACTIONS(6755),
    [anon_sym_function] = ACTIONS(6755),
    [anon_sym_static] = ACTIONS(6755),
    [anon_sym_constraint] = ACTIONS(6755),
    [anon_sym_if] = ACTIONS(6755),
    [anon_sym_else] = ACTIONS(6755),
    [anon_sym_LBRACK] = ACTIONS(6757),
    [anon_sym_localparam] = ACTIONS(6755),
    [anon_sym_parameter] = ACTIONS(6755),
    [anon_sym_specparam] = ACTIONS(6755),
    [anon_sym_var] = ACTIONS(6755),
    [anon_sym_import] = ACTIONS(6755),
    [anon_sym_export] = ACTIONS(6755),
    [anon_sym_genvar] = ACTIONS(6755),
    [anon_sym_interconnect] = ACTIONS(6755),
    [anon_sym_typedef] = ACTIONS(6755),
    [anon_sym_enum] = ACTIONS(6755),
    [anon_sym_struct] = ACTIONS(6755),
    [anon_sym_union] = ACTIONS(6755),
    [anon_sym_nettype] = ACTIONS(6755),
    [anon_sym_automatic] = ACTIONS(6755),
    [anon_sym_string] = ACTIONS(6755),
    [anon_sym_chandle] = ACTIONS(6755),
    [anon_sym_event] = ACTIONS(6755),
    [anon_sym_byte] = ACTIONS(6755),
    [anon_sym_shortint] = ACTIONS(6755),
    [anon_sym_int] = ACTIONS(6755),
    [anon_sym_longint] = ACTIONS(6755),
    [anon_sym_integer] = ACTIONS(6755),
    [anon_sym_time] = ACTIONS(6755),
    [anon_sym_bit] = ACTIONS(6755),
    [anon_sym_logic] = ACTIONS(6755),
    [anon_sym_reg] = ACTIONS(6755),
    [anon_sym_shortreal] = ACTIONS(6755),
    [anon_sym_real] = ACTIONS(6755),
    [anon_sym_realtime] = ACTIONS(6755),
    [anon_sym_supply0] = ACTIONS(6755),
    [anon_sym_supply1] = ACTIONS(6755),
    [anon_sym_signed] = ACTIONS(6755),
    [anon_sym_unsigned] = ACTIONS(6755),
    [anon_sym_task] = ACTIONS(6755),
    [anon_sym_modport] = ACTIONS(6755),
    [anon_sym_assert] = ACTIONS(6755),
    [anon_sym_property] = ACTIONS(6755),
    [anon_sym_assume] = ACTIONS(6755),
    [anon_sym_cover] = ACTIONS(6755),
    [anon_sym_sequence] = ACTIONS(6755),
    [anon_sym_restrict] = ACTIONS(6755),
    [anon_sym_not] = ACTIONS(6755),
    [anon_sym_or] = ACTIONS(6755),
    [anon_sym_and] = ACTIONS(6755),
    [anon_sym_case] = ACTIONS(6755),
    [anon_sym_always] = ACTIONS(6755),
    [anon_sym_covergroup] = ACTIONS(6755),
    [anon_sym_let] = ACTIONS(6755),
    [anon_sym_pulldown] = ACTIONS(6755),
    [anon_sym_pullup] = ACTIONS(6755),
    [anon_sym_cmos] = ACTIONS(6755),
    [anon_sym_rcmos] = ACTIONS(6755),
    [anon_sym_bufif0] = ACTIONS(6755),
    [anon_sym_bufif1] = ACTIONS(6755),
    [anon_sym_notif0] = ACTIONS(6755),
    [anon_sym_notif1] = ACTIONS(6755),
    [anon_sym_nmos] = ACTIONS(6755),
    [anon_sym_pmos] = ACTIONS(6755),
    [anon_sym_rnmos] = ACTIONS(6755),
    [anon_sym_rpmos] = ACTIONS(6755),
    [anon_sym_nand] = ACTIONS(6755),
    [anon_sym_nor] = ACTIONS(6755),
    [anon_sym_xor] = ACTIONS(6755),
    [anon_sym_xnor] = ACTIONS(6755),
    [anon_sym_buf] = ACTIONS(6755),
    [anon_sym_tranif0] = ACTIONS(6755),
    [anon_sym_tranif1] = ACTIONS(6755),
    [anon_sym_rtranif1] = ACTIONS(6755),
    [anon_sym_rtranif0] = ACTIONS(6755),
    [anon_sym_tran] = ACTIONS(6755),
    [anon_sym_rtran] = ACTIONS(6755),
    [anon_sym_generate] = ACTIONS(6755),
    [anon_sym_for] = ACTIONS(6755),
    [anon_sym_initial] = ACTIONS(6755),
    [anon_sym_assign] = ACTIONS(6755),
    [anon_sym_alias] = ACTIONS(6755),
    [anon_sym_always_comb] = ACTIONS(6755),
    [anon_sym_always_latch] = ACTIONS(6755),
    [anon_sym_always_ff] = ACTIONS(6755),
    [anon_sym_final] = ACTIONS(6755),
    [anon_sym_global] = ACTIONS(6755),
    [anon_sym_specify] = ACTIONS(6755),
    [anon_sym_LPAREN_STAR] = ACTIONS(6757),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6757),
    [anon_sym_DOLLARunit] = ACTIONS(6757),
  },
  [1249] = {
    [sym_simple_identifier] = ACTIONS(6759),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6762),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6762),
    [anon_sym_BQUOTE] = ACTIONS(6759),
    [aux_sym_id_directive_token1] = ACTIONS(6762),
    [aux_sym_id_directive_token2] = ACTIONS(6762),
    [aux_sym_id_directive_token3] = ACTIONS(6762),
    [aux_sym_id_directive_token4] = ACTIONS(6759),
    [aux_sym_zero_directive_token1] = ACTIONS(6762),
    [aux_sym_zero_directive_token2] = ACTIONS(6762),
    [aux_sym_zero_directive_token3] = ACTIONS(6762),
    [aux_sym_zero_directive_token4] = ACTIONS(6762),
    [aux_sym_zero_directive_token5] = ACTIONS(6762),
    [aux_sym_zero_directive_token6] = ACTIONS(6762),
    [aux_sym_zero_directive_token7] = ACTIONS(6762),
    [aux_sym_zero_directive_token8] = ACTIONS(6762),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6762),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6762),
    [anon_sym_wire] = ACTIONS(6759),
    [anon_sym_tri] = ACTIONS(6759),
    [anon_sym_tri0] = ACTIONS(6759),
    [anon_sym_tri1] = ACTIONS(6759),
    [anon_sym_wand] = ACTIONS(6759),
    [anon_sym_triand] = ACTIONS(6759),
    [anon_sym_wor] = ACTIONS(6759),
    [anon_sym_trior] = ACTIONS(6759),
    [anon_sym_trireg] = ACTIONS(6759),
    [anon_sym_uwire] = ACTIONS(6759),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6762),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6762),
    [aux_sym_begin_keywords_token1] = ACTIONS(6762),
    [anon_sym_SEMI] = ACTIONS(6762),
    [anon_sym_endmodule] = ACTIONS(6759),
    [anon_sym_extern] = ACTIONS(6759),
    [anon_sym_module] = ACTIONS(6759),
    [anon_sym_macromodule] = ACTIONS(6759),
    [anon_sym_endinterface] = ACTIONS(6759),
    [anon_sym_interface] = ACTIONS(6759),
    [anon_sym_endprogram] = ACTIONS(6759),
    [anon_sym_program] = ACTIONS(6759),
    [anon_sym_checker] = ACTIONS(6759),
    [anon_sym_virtual] = ACTIONS(6759),
    [anon_sym_class] = ACTIONS(6759),
    [anon_sym_timeunit] = ACTIONS(6759),
    [anon_sym_timeprecision] = ACTIONS(6759),
    [anon_sym_type] = ACTIONS(6759),
    [anon_sym_input] = ACTIONS(6759),
    [anon_sym_output] = ACTIONS(6759),
    [anon_sym_inout] = ACTIONS(6759),
    [anon_sym_ref] = ACTIONS(6759),
    [anon_sym_DOLLARfatal] = ACTIONS(6762),
    [anon_sym_DOLLARerror] = ACTIONS(6762),
    [anon_sym_DOLLARwarning] = ACTIONS(6762),
    [anon_sym_DOLLARinfo] = ACTIONS(6762),
    [anon_sym_default] = ACTIONS(6759),
    [anon_sym_clocking] = ACTIONS(6759),
    [anon_sym_defparam] = ACTIONS(6759),
    [anon_sym_bind] = ACTIONS(6759),
    [anon_sym_const] = ACTIONS(6759),
    [anon_sym_function] = ACTIONS(6759),
    [anon_sym_static] = ACTIONS(6759),
    [anon_sym_constraint] = ACTIONS(6759),
    [anon_sym_if] = ACTIONS(6759),
    [anon_sym_else] = ACTIONS(6759),
    [anon_sym_LBRACK] = ACTIONS(6762),
    [anon_sym_localparam] = ACTIONS(6759),
    [anon_sym_parameter] = ACTIONS(6759),
    [anon_sym_specparam] = ACTIONS(6759),
    [anon_sym_var] = ACTIONS(6759),
    [anon_sym_import] = ACTIONS(6759),
    [anon_sym_export] = ACTIONS(6759),
    [anon_sym_genvar] = ACTIONS(6759),
    [anon_sym_interconnect] = ACTIONS(6759),
    [anon_sym_typedef] = ACTIONS(6759),
    [anon_sym_enum] = ACTIONS(6759),
    [anon_sym_struct] = ACTIONS(6759),
    [anon_sym_union] = ACTIONS(6759),
    [anon_sym_nettype] = ACTIONS(6759),
    [anon_sym_automatic] = ACTIONS(6759),
    [anon_sym_string] = ACTIONS(6759),
    [anon_sym_chandle] = ACTIONS(6759),
    [anon_sym_event] = ACTIONS(6759),
    [anon_sym_byte] = ACTIONS(6759),
    [anon_sym_shortint] = ACTIONS(6759),
    [anon_sym_int] = ACTIONS(6759),
    [anon_sym_longint] = ACTIONS(6759),
    [anon_sym_integer] = ACTIONS(6759),
    [anon_sym_time] = ACTIONS(6759),
    [anon_sym_bit] = ACTIONS(6759),
    [anon_sym_logic] = ACTIONS(6759),
    [anon_sym_reg] = ACTIONS(6759),
    [anon_sym_shortreal] = ACTIONS(6759),
    [anon_sym_real] = ACTIONS(6759),
    [anon_sym_realtime] = ACTIONS(6759),
    [anon_sym_supply0] = ACTIONS(6759),
    [anon_sym_supply1] = ACTIONS(6759),
    [anon_sym_signed] = ACTIONS(6759),
    [anon_sym_unsigned] = ACTIONS(6759),
    [anon_sym_task] = ACTIONS(6759),
    [anon_sym_modport] = ACTIONS(6759),
    [anon_sym_assert] = ACTIONS(6759),
    [anon_sym_property] = ACTIONS(6759),
    [anon_sym_assume] = ACTIONS(6759),
    [anon_sym_cover] = ACTIONS(6759),
    [anon_sym_sequence] = ACTIONS(6759),
    [anon_sym_restrict] = ACTIONS(6759),
    [anon_sym_not] = ACTIONS(6759),
    [anon_sym_or] = ACTIONS(6759),
    [anon_sym_and] = ACTIONS(6759),
    [anon_sym_case] = ACTIONS(6759),
    [anon_sym_always] = ACTIONS(6759),
    [anon_sym_covergroup] = ACTIONS(6759),
    [anon_sym_let] = ACTIONS(6759),
    [anon_sym_pulldown] = ACTIONS(6759),
    [anon_sym_pullup] = ACTIONS(6759),
    [anon_sym_cmos] = ACTIONS(6759),
    [anon_sym_rcmos] = ACTIONS(6759),
    [anon_sym_bufif0] = ACTIONS(6759),
    [anon_sym_bufif1] = ACTIONS(6759),
    [anon_sym_notif0] = ACTIONS(6759),
    [anon_sym_notif1] = ACTIONS(6759),
    [anon_sym_nmos] = ACTIONS(6759),
    [anon_sym_pmos] = ACTIONS(6759),
    [anon_sym_rnmos] = ACTIONS(6759),
    [anon_sym_rpmos] = ACTIONS(6759),
    [anon_sym_nand] = ACTIONS(6759),
    [anon_sym_nor] = ACTIONS(6759),
    [anon_sym_xor] = ACTIONS(6759),
    [anon_sym_xnor] = ACTIONS(6759),
    [anon_sym_buf] = ACTIONS(6759),
    [anon_sym_tranif0] = ACTIONS(6759),
    [anon_sym_tranif1] = ACTIONS(6759),
    [anon_sym_rtranif1] = ACTIONS(6759),
    [anon_sym_rtranif0] = ACTIONS(6759),
    [anon_sym_tran] = ACTIONS(6759),
    [anon_sym_rtran] = ACTIONS(6759),
    [anon_sym_generate] = ACTIONS(6759),
    [anon_sym_for] = ACTIONS(6759),
    [anon_sym_initial] = ACTIONS(6759),
    [anon_sym_assign] = ACTIONS(6759),
    [anon_sym_alias] = ACTIONS(6759),
    [anon_sym_always_comb] = ACTIONS(6759),
    [anon_sym_always_latch] = ACTIONS(6759),
    [anon_sym_always_ff] = ACTIONS(6759),
    [anon_sym_final] = ACTIONS(6759),
    [anon_sym_global] = ACTIONS(6759),
    [anon_sym_specify] = ACTIONS(6759),
    [anon_sym_LPAREN_STAR] = ACTIONS(6762),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6762),
    [anon_sym_DOLLARunit] = ACTIONS(6762),
  },
  [1250] = {
    [sym_simple_identifier] = ACTIONS(6765),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6768),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6768),
    [anon_sym_BQUOTE] = ACTIONS(6765),
    [aux_sym_id_directive_token1] = ACTIONS(6768),
    [aux_sym_id_directive_token2] = ACTIONS(6768),
    [aux_sym_id_directive_token3] = ACTIONS(6768),
    [aux_sym_id_directive_token4] = ACTIONS(6765),
    [aux_sym_zero_directive_token1] = ACTIONS(6768),
    [aux_sym_zero_directive_token2] = ACTIONS(6768),
    [aux_sym_zero_directive_token3] = ACTIONS(6768),
    [aux_sym_zero_directive_token4] = ACTIONS(6768),
    [aux_sym_zero_directive_token5] = ACTIONS(6768),
    [aux_sym_zero_directive_token6] = ACTIONS(6768),
    [aux_sym_zero_directive_token7] = ACTIONS(6768),
    [aux_sym_zero_directive_token8] = ACTIONS(6768),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6768),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6768),
    [anon_sym_wire] = ACTIONS(6765),
    [anon_sym_tri] = ACTIONS(6765),
    [anon_sym_tri0] = ACTIONS(6765),
    [anon_sym_tri1] = ACTIONS(6765),
    [anon_sym_wand] = ACTIONS(6765),
    [anon_sym_triand] = ACTIONS(6765),
    [anon_sym_wor] = ACTIONS(6765),
    [anon_sym_trior] = ACTIONS(6765),
    [anon_sym_trireg] = ACTIONS(6765),
    [anon_sym_uwire] = ACTIONS(6765),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6768),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6768),
    [aux_sym_begin_keywords_token1] = ACTIONS(6768),
    [anon_sym_SEMI] = ACTIONS(6768),
    [anon_sym_endmodule] = ACTIONS(6765),
    [anon_sym_extern] = ACTIONS(6765),
    [anon_sym_module] = ACTIONS(6765),
    [anon_sym_macromodule] = ACTIONS(6765),
    [anon_sym_endinterface] = ACTIONS(6765),
    [anon_sym_interface] = ACTIONS(6765),
    [anon_sym_endprogram] = ACTIONS(6765),
    [anon_sym_program] = ACTIONS(6765),
    [anon_sym_checker] = ACTIONS(6765),
    [anon_sym_virtual] = ACTIONS(6765),
    [anon_sym_class] = ACTIONS(6765),
    [anon_sym_timeunit] = ACTIONS(6765),
    [anon_sym_timeprecision] = ACTIONS(6765),
    [anon_sym_type] = ACTIONS(6765),
    [anon_sym_input] = ACTIONS(6765),
    [anon_sym_output] = ACTIONS(6765),
    [anon_sym_inout] = ACTIONS(6765),
    [anon_sym_ref] = ACTIONS(6765),
    [anon_sym_DOLLARfatal] = ACTIONS(6768),
    [anon_sym_DOLLARerror] = ACTIONS(6768),
    [anon_sym_DOLLARwarning] = ACTIONS(6768),
    [anon_sym_DOLLARinfo] = ACTIONS(6768),
    [anon_sym_default] = ACTIONS(6765),
    [anon_sym_clocking] = ACTIONS(6765),
    [anon_sym_defparam] = ACTIONS(6765),
    [anon_sym_bind] = ACTIONS(6765),
    [anon_sym_const] = ACTIONS(6765),
    [anon_sym_function] = ACTIONS(6765),
    [anon_sym_static] = ACTIONS(6765),
    [anon_sym_constraint] = ACTIONS(6765),
    [anon_sym_if] = ACTIONS(6765),
    [anon_sym_else] = ACTIONS(6765),
    [anon_sym_LBRACK] = ACTIONS(6768),
    [anon_sym_localparam] = ACTIONS(6765),
    [anon_sym_parameter] = ACTIONS(6765),
    [anon_sym_specparam] = ACTIONS(6765),
    [anon_sym_var] = ACTIONS(6765),
    [anon_sym_import] = ACTIONS(6765),
    [anon_sym_export] = ACTIONS(6765),
    [anon_sym_genvar] = ACTIONS(6765),
    [anon_sym_interconnect] = ACTIONS(6765),
    [anon_sym_typedef] = ACTIONS(6765),
    [anon_sym_enum] = ACTIONS(6765),
    [anon_sym_struct] = ACTIONS(6765),
    [anon_sym_union] = ACTIONS(6765),
    [anon_sym_nettype] = ACTIONS(6765),
    [anon_sym_automatic] = ACTIONS(6765),
    [anon_sym_string] = ACTIONS(6765),
    [anon_sym_chandle] = ACTIONS(6765),
    [anon_sym_event] = ACTIONS(6765),
    [anon_sym_byte] = ACTIONS(6765),
    [anon_sym_shortint] = ACTIONS(6765),
    [anon_sym_int] = ACTIONS(6765),
    [anon_sym_longint] = ACTIONS(6765),
    [anon_sym_integer] = ACTIONS(6765),
    [anon_sym_time] = ACTIONS(6765),
    [anon_sym_bit] = ACTIONS(6765),
    [anon_sym_logic] = ACTIONS(6765),
    [anon_sym_reg] = ACTIONS(6765),
    [anon_sym_shortreal] = ACTIONS(6765),
    [anon_sym_real] = ACTIONS(6765),
    [anon_sym_realtime] = ACTIONS(6765),
    [anon_sym_supply0] = ACTIONS(6765),
    [anon_sym_supply1] = ACTIONS(6765),
    [anon_sym_signed] = ACTIONS(6765),
    [anon_sym_unsigned] = ACTIONS(6765),
    [anon_sym_task] = ACTIONS(6765),
    [anon_sym_modport] = ACTIONS(6765),
    [anon_sym_assert] = ACTIONS(6765),
    [anon_sym_property] = ACTIONS(6765),
    [anon_sym_assume] = ACTIONS(6765),
    [anon_sym_cover] = ACTIONS(6765),
    [anon_sym_sequence] = ACTIONS(6765),
    [anon_sym_restrict] = ACTIONS(6765),
    [anon_sym_not] = ACTIONS(6765),
    [anon_sym_or] = ACTIONS(6765),
    [anon_sym_and] = ACTIONS(6765),
    [anon_sym_case] = ACTIONS(6765),
    [anon_sym_always] = ACTIONS(6765),
    [anon_sym_covergroup] = ACTIONS(6765),
    [anon_sym_let] = ACTIONS(6765),
    [anon_sym_pulldown] = ACTIONS(6765),
    [anon_sym_pullup] = ACTIONS(6765),
    [anon_sym_cmos] = ACTIONS(6765),
    [anon_sym_rcmos] = ACTIONS(6765),
    [anon_sym_bufif0] = ACTIONS(6765),
    [anon_sym_bufif1] = ACTIONS(6765),
    [anon_sym_notif0] = ACTIONS(6765),
    [anon_sym_notif1] = ACTIONS(6765),
    [anon_sym_nmos] = ACTIONS(6765),
    [anon_sym_pmos] = ACTIONS(6765),
    [anon_sym_rnmos] = ACTIONS(6765),
    [anon_sym_rpmos] = ACTIONS(6765),
    [anon_sym_nand] = ACTIONS(6765),
    [anon_sym_nor] = ACTIONS(6765),
    [anon_sym_xor] = ACTIONS(6765),
    [anon_sym_xnor] = ACTIONS(6765),
    [anon_sym_buf] = ACTIONS(6765),
    [anon_sym_tranif0] = ACTIONS(6765),
    [anon_sym_tranif1] = ACTIONS(6765),
    [anon_sym_rtranif1] = ACTIONS(6765),
    [anon_sym_rtranif0] = ACTIONS(6765),
    [anon_sym_tran] = ACTIONS(6765),
    [anon_sym_rtran] = ACTIONS(6765),
    [anon_sym_generate] = ACTIONS(6765),
    [anon_sym_for] = ACTIONS(6765),
    [anon_sym_initial] = ACTIONS(6765),
    [anon_sym_assign] = ACTIONS(6765),
    [anon_sym_alias] = ACTIONS(6765),
    [anon_sym_always_comb] = ACTIONS(6765),
    [anon_sym_always_latch] = ACTIONS(6765),
    [anon_sym_always_ff] = ACTIONS(6765),
    [anon_sym_final] = ACTIONS(6765),
    [anon_sym_global] = ACTIONS(6765),
    [anon_sym_specify] = ACTIONS(6765),
    [anon_sym_LPAREN_STAR] = ACTIONS(6768),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6768),
    [anon_sym_DOLLARunit] = ACTIONS(6768),
  },
  [1251] = {
    [ts_builtin_sym_end] = ACTIONS(6771),
    [sym_simple_identifier] = ACTIONS(6773),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6771),
    [anon_sym_BQUOTE] = ACTIONS(6773),
    [aux_sym_id_directive_token1] = ACTIONS(6771),
    [aux_sym_id_directive_token2] = ACTIONS(6771),
    [aux_sym_id_directive_token3] = ACTIONS(6771),
    [aux_sym_id_directive_token4] = ACTIONS(6773),
    [aux_sym_zero_directive_token1] = ACTIONS(6771),
    [aux_sym_zero_directive_token2] = ACTIONS(6771),
    [aux_sym_zero_directive_token3] = ACTIONS(6771),
    [aux_sym_zero_directive_token4] = ACTIONS(6771),
    [aux_sym_zero_directive_token5] = ACTIONS(6771),
    [aux_sym_zero_directive_token6] = ACTIONS(6771),
    [aux_sym_zero_directive_token7] = ACTIONS(6771),
    [aux_sym_zero_directive_token8] = ACTIONS(6771),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6771),
    [anon_sym_wire] = ACTIONS(6773),
    [anon_sym_tri] = ACTIONS(6773),
    [anon_sym_tri0] = ACTIONS(6773),
    [anon_sym_tri1] = ACTIONS(6773),
    [anon_sym_wand] = ACTIONS(6773),
    [anon_sym_triand] = ACTIONS(6773),
    [anon_sym_wor] = ACTIONS(6773),
    [anon_sym_trior] = ACTIONS(6773),
    [anon_sym_trireg] = ACTIONS(6773),
    [anon_sym_uwire] = ACTIONS(6773),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6771),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_begin_keywords_token1] = ACTIONS(6771),
    [anon_sym_SEMI] = ACTIONS(6771),
    [anon_sym_endmodule] = ACTIONS(6773),
    [anon_sym_COLON] = ACTIONS(6775),
    [anon_sym_extern] = ACTIONS(6773),
    [anon_sym_module] = ACTIONS(6773),
    [anon_sym_macromodule] = ACTIONS(6773),
    [anon_sym_interface] = ACTIONS(6773),
    [anon_sym_program] = ACTIONS(6773),
    [anon_sym_checker] = ACTIONS(6773),
    [anon_sym_virtual] = ACTIONS(6773),
    [anon_sym_class] = ACTIONS(6773),
    [anon_sym_package] = ACTIONS(6773),
    [anon_sym_timeunit] = ACTIONS(6773),
    [anon_sym_timeprecision] = ACTIONS(6773),
    [anon_sym_type] = ACTIONS(6773),
    [anon_sym_input] = ACTIONS(6773),
    [anon_sym_output] = ACTIONS(6773),
    [anon_sym_inout] = ACTIONS(6773),
    [anon_sym_ref] = ACTIONS(6773),
    [anon_sym_DOLLARfatal] = ACTIONS(6771),
    [anon_sym_DOLLARerror] = ACTIONS(6771),
    [anon_sym_DOLLARwarning] = ACTIONS(6771),
    [anon_sym_DOLLARinfo] = ACTIONS(6771),
    [anon_sym_default] = ACTIONS(6773),
    [anon_sym_clocking] = ACTIONS(6773),
    [anon_sym_defparam] = ACTIONS(6773),
    [anon_sym_bind] = ACTIONS(6773),
    [anon_sym_const] = ACTIONS(6773),
    [anon_sym_function] = ACTIONS(6773),
    [anon_sym_static] = ACTIONS(6773),
    [anon_sym_constraint] = ACTIONS(6773),
    [anon_sym_if] = ACTIONS(6773),
    [anon_sym_LBRACK] = ACTIONS(6771),
    [anon_sym_localparam] = ACTIONS(6773),
    [anon_sym_parameter] = ACTIONS(6773),
    [anon_sym_specparam] = ACTIONS(6773),
    [anon_sym_var] = ACTIONS(6773),
    [anon_sym_import] = ACTIONS(6773),
    [anon_sym_export] = ACTIONS(6773),
    [anon_sym_genvar] = ACTIONS(6773),
    [anon_sym_interconnect] = ACTIONS(6773),
    [anon_sym_typedef] = ACTIONS(6773),
    [anon_sym_enum] = ACTIONS(6773),
    [anon_sym_struct] = ACTIONS(6773),
    [anon_sym_union] = ACTIONS(6773),
    [anon_sym_nettype] = ACTIONS(6773),
    [anon_sym_automatic] = ACTIONS(6773),
    [anon_sym_string] = ACTIONS(6773),
    [anon_sym_chandle] = ACTIONS(6773),
    [anon_sym_event] = ACTIONS(6773),
    [anon_sym_byte] = ACTIONS(6773),
    [anon_sym_shortint] = ACTIONS(6773),
    [anon_sym_int] = ACTIONS(6773),
    [anon_sym_longint] = ACTIONS(6773),
    [anon_sym_integer] = ACTIONS(6773),
    [anon_sym_time] = ACTIONS(6773),
    [anon_sym_bit] = ACTIONS(6773),
    [anon_sym_logic] = ACTIONS(6773),
    [anon_sym_reg] = ACTIONS(6773),
    [anon_sym_shortreal] = ACTIONS(6773),
    [anon_sym_real] = ACTIONS(6773),
    [anon_sym_realtime] = ACTIONS(6773),
    [anon_sym_supply0] = ACTIONS(6773),
    [anon_sym_supply1] = ACTIONS(6773),
    [anon_sym_signed] = ACTIONS(6773),
    [anon_sym_unsigned] = ACTIONS(6773),
    [anon_sym_task] = ACTIONS(6773),
    [anon_sym_assert] = ACTIONS(6773),
    [anon_sym_property] = ACTIONS(6773),
    [anon_sym_assume] = ACTIONS(6773),
    [anon_sym_cover] = ACTIONS(6773),
    [anon_sym_sequence] = ACTIONS(6773),
    [anon_sym_restrict] = ACTIONS(6773),
    [anon_sym_not] = ACTIONS(6773),
    [anon_sym_or] = ACTIONS(6773),
    [anon_sym_and] = ACTIONS(6773),
    [anon_sym_case] = ACTIONS(6773),
    [anon_sym_always] = ACTIONS(6773),
    [anon_sym_covergroup] = ACTIONS(6773),
    [anon_sym_let] = ACTIONS(6773),
    [anon_sym_pulldown] = ACTIONS(6773),
    [anon_sym_pullup] = ACTIONS(6773),
    [anon_sym_cmos] = ACTIONS(6773),
    [anon_sym_rcmos] = ACTIONS(6773),
    [anon_sym_bufif0] = ACTIONS(6773),
    [anon_sym_bufif1] = ACTIONS(6773),
    [anon_sym_notif0] = ACTIONS(6773),
    [anon_sym_notif1] = ACTIONS(6773),
    [anon_sym_nmos] = ACTIONS(6773),
    [anon_sym_pmos] = ACTIONS(6773),
    [anon_sym_rnmos] = ACTIONS(6773),
    [anon_sym_rpmos] = ACTIONS(6773),
    [anon_sym_nand] = ACTIONS(6773),
    [anon_sym_nor] = ACTIONS(6773),
    [anon_sym_xor] = ACTIONS(6773),
    [anon_sym_xnor] = ACTIONS(6773),
    [anon_sym_buf] = ACTIONS(6773),
    [anon_sym_tranif0] = ACTIONS(6773),
    [anon_sym_tranif1] = ACTIONS(6773),
    [anon_sym_rtranif1] = ACTIONS(6773),
    [anon_sym_rtranif0] = ACTIONS(6773),
    [anon_sym_tran] = ACTIONS(6773),
    [anon_sym_rtran] = ACTIONS(6773),
    [anon_sym_generate] = ACTIONS(6773),
    [anon_sym_for] = ACTIONS(6773),
    [anon_sym_primitive] = ACTIONS(6773),
    [anon_sym_initial] = ACTIONS(6773),
    [anon_sym_assign] = ACTIONS(6773),
    [anon_sym_alias] = ACTIONS(6773),
    [anon_sym_always_comb] = ACTIONS(6773),
    [anon_sym_always_latch] = ACTIONS(6773),
    [anon_sym_always_ff] = ACTIONS(6773),
    [anon_sym_final] = ACTIONS(6773),
    [anon_sym_global] = ACTIONS(6773),
    [anon_sym_specify] = ACTIONS(6773),
    [anon_sym_LPAREN_STAR] = ACTIONS(6771),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6771),
    [anon_sym_DOLLARunit] = ACTIONS(6771),
  },
  [1252] = {
    [sym_simple_identifier] = ACTIONS(6777),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6780),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6780),
    [anon_sym_BQUOTE] = ACTIONS(6777),
    [aux_sym_id_directive_token1] = ACTIONS(6780),
    [aux_sym_id_directive_token2] = ACTIONS(6780),
    [aux_sym_id_directive_token3] = ACTIONS(6780),
    [aux_sym_id_directive_token4] = ACTIONS(6777),
    [aux_sym_zero_directive_token1] = ACTIONS(6780),
    [aux_sym_zero_directive_token2] = ACTIONS(6780),
    [aux_sym_zero_directive_token3] = ACTIONS(6780),
    [aux_sym_zero_directive_token4] = ACTIONS(6780),
    [aux_sym_zero_directive_token5] = ACTIONS(6780),
    [aux_sym_zero_directive_token6] = ACTIONS(6780),
    [aux_sym_zero_directive_token7] = ACTIONS(6780),
    [aux_sym_zero_directive_token8] = ACTIONS(6780),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6780),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6780),
    [anon_sym_wire] = ACTIONS(6777),
    [anon_sym_tri] = ACTIONS(6777),
    [anon_sym_tri0] = ACTIONS(6777),
    [anon_sym_tri1] = ACTIONS(6777),
    [anon_sym_wand] = ACTIONS(6777),
    [anon_sym_triand] = ACTIONS(6777),
    [anon_sym_wor] = ACTIONS(6777),
    [anon_sym_trior] = ACTIONS(6777),
    [anon_sym_trireg] = ACTIONS(6777),
    [anon_sym_uwire] = ACTIONS(6777),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6780),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6780),
    [aux_sym_begin_keywords_token1] = ACTIONS(6780),
    [anon_sym_SEMI] = ACTIONS(6780),
    [anon_sym_endmodule] = ACTIONS(6777),
    [anon_sym_extern] = ACTIONS(6777),
    [anon_sym_module] = ACTIONS(6777),
    [anon_sym_macromodule] = ACTIONS(6777),
    [anon_sym_endinterface] = ACTIONS(6777),
    [anon_sym_interface] = ACTIONS(6777),
    [anon_sym_endprogram] = ACTIONS(6777),
    [anon_sym_program] = ACTIONS(6777),
    [anon_sym_checker] = ACTIONS(6777),
    [anon_sym_virtual] = ACTIONS(6777),
    [anon_sym_class] = ACTIONS(6777),
    [anon_sym_timeunit] = ACTIONS(6777),
    [anon_sym_timeprecision] = ACTIONS(6777),
    [anon_sym_type] = ACTIONS(6777),
    [anon_sym_input] = ACTIONS(6777),
    [anon_sym_output] = ACTIONS(6777),
    [anon_sym_inout] = ACTIONS(6777),
    [anon_sym_ref] = ACTIONS(6777),
    [anon_sym_DOLLARfatal] = ACTIONS(6780),
    [anon_sym_DOLLARerror] = ACTIONS(6780),
    [anon_sym_DOLLARwarning] = ACTIONS(6780),
    [anon_sym_DOLLARinfo] = ACTIONS(6780),
    [anon_sym_default] = ACTIONS(6777),
    [anon_sym_clocking] = ACTIONS(6777),
    [anon_sym_defparam] = ACTIONS(6777),
    [anon_sym_bind] = ACTIONS(6777),
    [anon_sym_const] = ACTIONS(6777),
    [anon_sym_function] = ACTIONS(6777),
    [anon_sym_static] = ACTIONS(6777),
    [anon_sym_constraint] = ACTIONS(6777),
    [anon_sym_if] = ACTIONS(6777),
    [anon_sym_else] = ACTIONS(6777),
    [anon_sym_LBRACK] = ACTIONS(6780),
    [anon_sym_localparam] = ACTIONS(6777),
    [anon_sym_parameter] = ACTIONS(6777),
    [anon_sym_specparam] = ACTIONS(6777),
    [anon_sym_var] = ACTIONS(6777),
    [anon_sym_import] = ACTIONS(6777),
    [anon_sym_export] = ACTIONS(6777),
    [anon_sym_genvar] = ACTIONS(6777),
    [anon_sym_interconnect] = ACTIONS(6777),
    [anon_sym_typedef] = ACTIONS(6777),
    [anon_sym_enum] = ACTIONS(6777),
    [anon_sym_struct] = ACTIONS(6777),
    [anon_sym_union] = ACTIONS(6777),
    [anon_sym_nettype] = ACTIONS(6777),
    [anon_sym_automatic] = ACTIONS(6777),
    [anon_sym_string] = ACTIONS(6777),
    [anon_sym_chandle] = ACTIONS(6777),
    [anon_sym_event] = ACTIONS(6777),
    [anon_sym_byte] = ACTIONS(6777),
    [anon_sym_shortint] = ACTIONS(6777),
    [anon_sym_int] = ACTIONS(6777),
    [anon_sym_longint] = ACTIONS(6777),
    [anon_sym_integer] = ACTIONS(6777),
    [anon_sym_time] = ACTIONS(6777),
    [anon_sym_bit] = ACTIONS(6777),
    [anon_sym_logic] = ACTIONS(6777),
    [anon_sym_reg] = ACTIONS(6777),
    [anon_sym_shortreal] = ACTIONS(6777),
    [anon_sym_real] = ACTIONS(6777),
    [anon_sym_realtime] = ACTIONS(6777),
    [anon_sym_supply0] = ACTIONS(6777),
    [anon_sym_supply1] = ACTIONS(6777),
    [anon_sym_signed] = ACTIONS(6777),
    [anon_sym_unsigned] = ACTIONS(6777),
    [anon_sym_task] = ACTIONS(6777),
    [anon_sym_modport] = ACTIONS(6777),
    [anon_sym_assert] = ACTIONS(6777),
    [anon_sym_property] = ACTIONS(6777),
    [anon_sym_assume] = ACTIONS(6777),
    [anon_sym_cover] = ACTIONS(6777),
    [anon_sym_sequence] = ACTIONS(6777),
    [anon_sym_restrict] = ACTIONS(6777),
    [anon_sym_not] = ACTIONS(6777),
    [anon_sym_or] = ACTIONS(6777),
    [anon_sym_and] = ACTIONS(6777),
    [anon_sym_case] = ACTIONS(6777),
    [anon_sym_always] = ACTIONS(6777),
    [anon_sym_covergroup] = ACTIONS(6777),
    [anon_sym_let] = ACTIONS(6777),
    [anon_sym_pulldown] = ACTIONS(6777),
    [anon_sym_pullup] = ACTIONS(6777),
    [anon_sym_cmos] = ACTIONS(6777),
    [anon_sym_rcmos] = ACTIONS(6777),
    [anon_sym_bufif0] = ACTIONS(6777),
    [anon_sym_bufif1] = ACTIONS(6777),
    [anon_sym_notif0] = ACTIONS(6777),
    [anon_sym_notif1] = ACTIONS(6777),
    [anon_sym_nmos] = ACTIONS(6777),
    [anon_sym_pmos] = ACTIONS(6777),
    [anon_sym_rnmos] = ACTIONS(6777),
    [anon_sym_rpmos] = ACTIONS(6777),
    [anon_sym_nand] = ACTIONS(6777),
    [anon_sym_nor] = ACTIONS(6777),
    [anon_sym_xor] = ACTIONS(6777),
    [anon_sym_xnor] = ACTIONS(6777),
    [anon_sym_buf] = ACTIONS(6777),
    [anon_sym_tranif0] = ACTIONS(6777),
    [anon_sym_tranif1] = ACTIONS(6777),
    [anon_sym_rtranif1] = ACTIONS(6777),
    [anon_sym_rtranif0] = ACTIONS(6777),
    [anon_sym_tran] = ACTIONS(6777),
    [anon_sym_rtran] = ACTIONS(6777),
    [anon_sym_generate] = ACTIONS(6777),
    [anon_sym_for] = ACTIONS(6777),
    [anon_sym_initial] = ACTIONS(6777),
    [anon_sym_assign] = ACTIONS(6777),
    [anon_sym_alias] = ACTIONS(6777),
    [anon_sym_always_comb] = ACTIONS(6777),
    [anon_sym_always_latch] = ACTIONS(6777),
    [anon_sym_always_ff] = ACTIONS(6777),
    [anon_sym_final] = ACTIONS(6777),
    [anon_sym_global] = ACTIONS(6777),
    [anon_sym_specify] = ACTIONS(6777),
    [anon_sym_LPAREN_STAR] = ACTIONS(6780),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6780),
    [anon_sym_DOLLARunit] = ACTIONS(6780),
  },
  [1253] = {
    [sym_simple_identifier] = ACTIONS(6783),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6786),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6786),
    [anon_sym_BQUOTE] = ACTIONS(6783),
    [aux_sym_id_directive_token1] = ACTIONS(6786),
    [aux_sym_id_directive_token2] = ACTIONS(6786),
    [aux_sym_id_directive_token3] = ACTIONS(6786),
    [aux_sym_id_directive_token4] = ACTIONS(6783),
    [aux_sym_zero_directive_token1] = ACTIONS(6786),
    [aux_sym_zero_directive_token2] = ACTIONS(6786),
    [aux_sym_zero_directive_token3] = ACTIONS(6786),
    [aux_sym_zero_directive_token4] = ACTIONS(6786),
    [aux_sym_zero_directive_token5] = ACTIONS(6786),
    [aux_sym_zero_directive_token6] = ACTIONS(6786),
    [aux_sym_zero_directive_token7] = ACTIONS(6786),
    [aux_sym_zero_directive_token8] = ACTIONS(6786),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6786),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6786),
    [anon_sym_wire] = ACTIONS(6783),
    [anon_sym_tri] = ACTIONS(6783),
    [anon_sym_tri0] = ACTIONS(6783),
    [anon_sym_tri1] = ACTIONS(6783),
    [anon_sym_wand] = ACTIONS(6783),
    [anon_sym_triand] = ACTIONS(6783),
    [anon_sym_wor] = ACTIONS(6783),
    [anon_sym_trior] = ACTIONS(6783),
    [anon_sym_trireg] = ACTIONS(6783),
    [anon_sym_uwire] = ACTIONS(6783),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6786),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6786),
    [aux_sym_begin_keywords_token1] = ACTIONS(6786),
    [anon_sym_SEMI] = ACTIONS(6786),
    [anon_sym_endmodule] = ACTIONS(6783),
    [anon_sym_extern] = ACTIONS(6783),
    [anon_sym_module] = ACTIONS(6783),
    [anon_sym_macromodule] = ACTIONS(6783),
    [anon_sym_endinterface] = ACTIONS(6783),
    [anon_sym_interface] = ACTIONS(6783),
    [anon_sym_endprogram] = ACTIONS(6783),
    [anon_sym_program] = ACTIONS(6783),
    [anon_sym_checker] = ACTIONS(6783),
    [anon_sym_virtual] = ACTIONS(6783),
    [anon_sym_class] = ACTIONS(6783),
    [anon_sym_timeunit] = ACTIONS(6783),
    [anon_sym_timeprecision] = ACTIONS(6783),
    [anon_sym_type] = ACTIONS(6783),
    [anon_sym_input] = ACTIONS(6783),
    [anon_sym_output] = ACTIONS(6783),
    [anon_sym_inout] = ACTIONS(6783),
    [anon_sym_ref] = ACTIONS(6783),
    [anon_sym_DOLLARfatal] = ACTIONS(6786),
    [anon_sym_DOLLARerror] = ACTIONS(6786),
    [anon_sym_DOLLARwarning] = ACTIONS(6786),
    [anon_sym_DOLLARinfo] = ACTIONS(6786),
    [anon_sym_default] = ACTIONS(6783),
    [anon_sym_clocking] = ACTIONS(6783),
    [anon_sym_defparam] = ACTIONS(6783),
    [anon_sym_bind] = ACTIONS(6783),
    [anon_sym_const] = ACTIONS(6783),
    [anon_sym_function] = ACTIONS(6783),
    [anon_sym_static] = ACTIONS(6783),
    [anon_sym_constraint] = ACTIONS(6783),
    [anon_sym_if] = ACTIONS(6783),
    [anon_sym_else] = ACTIONS(6783),
    [anon_sym_LBRACK] = ACTIONS(6786),
    [anon_sym_localparam] = ACTIONS(6783),
    [anon_sym_parameter] = ACTIONS(6783),
    [anon_sym_specparam] = ACTIONS(6783),
    [anon_sym_var] = ACTIONS(6783),
    [anon_sym_import] = ACTIONS(6783),
    [anon_sym_export] = ACTIONS(6783),
    [anon_sym_genvar] = ACTIONS(6783),
    [anon_sym_interconnect] = ACTIONS(6783),
    [anon_sym_typedef] = ACTIONS(6783),
    [anon_sym_enum] = ACTIONS(6783),
    [anon_sym_struct] = ACTIONS(6783),
    [anon_sym_union] = ACTIONS(6783),
    [anon_sym_nettype] = ACTIONS(6783),
    [anon_sym_automatic] = ACTIONS(6783),
    [anon_sym_string] = ACTIONS(6783),
    [anon_sym_chandle] = ACTIONS(6783),
    [anon_sym_event] = ACTIONS(6783),
    [anon_sym_byte] = ACTIONS(6783),
    [anon_sym_shortint] = ACTIONS(6783),
    [anon_sym_int] = ACTIONS(6783),
    [anon_sym_longint] = ACTIONS(6783),
    [anon_sym_integer] = ACTIONS(6783),
    [anon_sym_time] = ACTIONS(6783),
    [anon_sym_bit] = ACTIONS(6783),
    [anon_sym_logic] = ACTIONS(6783),
    [anon_sym_reg] = ACTIONS(6783),
    [anon_sym_shortreal] = ACTIONS(6783),
    [anon_sym_real] = ACTIONS(6783),
    [anon_sym_realtime] = ACTIONS(6783),
    [anon_sym_supply0] = ACTIONS(6783),
    [anon_sym_supply1] = ACTIONS(6783),
    [anon_sym_signed] = ACTIONS(6783),
    [anon_sym_unsigned] = ACTIONS(6783),
    [anon_sym_task] = ACTIONS(6783),
    [anon_sym_modport] = ACTIONS(6783),
    [anon_sym_assert] = ACTIONS(6783),
    [anon_sym_property] = ACTIONS(6783),
    [anon_sym_assume] = ACTIONS(6783),
    [anon_sym_cover] = ACTIONS(6783),
    [anon_sym_sequence] = ACTIONS(6783),
    [anon_sym_restrict] = ACTIONS(6783),
    [anon_sym_not] = ACTIONS(6783),
    [anon_sym_or] = ACTIONS(6783),
    [anon_sym_and] = ACTIONS(6783),
    [anon_sym_case] = ACTIONS(6783),
    [anon_sym_always] = ACTIONS(6783),
    [anon_sym_covergroup] = ACTIONS(6783),
    [anon_sym_let] = ACTIONS(6783),
    [anon_sym_pulldown] = ACTIONS(6783),
    [anon_sym_pullup] = ACTIONS(6783),
    [anon_sym_cmos] = ACTIONS(6783),
    [anon_sym_rcmos] = ACTIONS(6783),
    [anon_sym_bufif0] = ACTIONS(6783),
    [anon_sym_bufif1] = ACTIONS(6783),
    [anon_sym_notif0] = ACTIONS(6783),
    [anon_sym_notif1] = ACTIONS(6783),
    [anon_sym_nmos] = ACTIONS(6783),
    [anon_sym_pmos] = ACTIONS(6783),
    [anon_sym_rnmos] = ACTIONS(6783),
    [anon_sym_rpmos] = ACTIONS(6783),
    [anon_sym_nand] = ACTIONS(6783),
    [anon_sym_nor] = ACTIONS(6783),
    [anon_sym_xor] = ACTIONS(6783),
    [anon_sym_xnor] = ACTIONS(6783),
    [anon_sym_buf] = ACTIONS(6783),
    [anon_sym_tranif0] = ACTIONS(6783),
    [anon_sym_tranif1] = ACTIONS(6783),
    [anon_sym_rtranif1] = ACTIONS(6783),
    [anon_sym_rtranif0] = ACTIONS(6783),
    [anon_sym_tran] = ACTIONS(6783),
    [anon_sym_rtran] = ACTIONS(6783),
    [anon_sym_generate] = ACTIONS(6783),
    [anon_sym_for] = ACTIONS(6783),
    [anon_sym_initial] = ACTIONS(6783),
    [anon_sym_assign] = ACTIONS(6783),
    [anon_sym_alias] = ACTIONS(6783),
    [anon_sym_always_comb] = ACTIONS(6783),
    [anon_sym_always_latch] = ACTIONS(6783),
    [anon_sym_always_ff] = ACTIONS(6783),
    [anon_sym_final] = ACTIONS(6783),
    [anon_sym_global] = ACTIONS(6783),
    [anon_sym_specify] = ACTIONS(6783),
    [anon_sym_LPAREN_STAR] = ACTIONS(6786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6786),
    [anon_sym_DOLLARunit] = ACTIONS(6786),
  },
  [1254] = {
    [sym_simple_identifier] = ACTIONS(6789),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6791),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6791),
    [anon_sym_BQUOTE] = ACTIONS(6789),
    [aux_sym_id_directive_token1] = ACTIONS(6791),
    [aux_sym_id_directive_token2] = ACTIONS(6791),
    [aux_sym_id_directive_token3] = ACTIONS(6791),
    [aux_sym_id_directive_token4] = ACTIONS(6789),
    [aux_sym_zero_directive_token1] = ACTIONS(6791),
    [aux_sym_zero_directive_token2] = ACTIONS(6791),
    [aux_sym_zero_directive_token3] = ACTIONS(6791),
    [aux_sym_zero_directive_token4] = ACTIONS(6791),
    [aux_sym_zero_directive_token5] = ACTIONS(6791),
    [aux_sym_zero_directive_token6] = ACTIONS(6791),
    [aux_sym_zero_directive_token7] = ACTIONS(6791),
    [aux_sym_zero_directive_token8] = ACTIONS(6791),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6791),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6791),
    [anon_sym_wire] = ACTIONS(6789),
    [anon_sym_tri] = ACTIONS(6789),
    [anon_sym_tri0] = ACTIONS(6789),
    [anon_sym_tri1] = ACTIONS(6789),
    [anon_sym_wand] = ACTIONS(6789),
    [anon_sym_triand] = ACTIONS(6789),
    [anon_sym_wor] = ACTIONS(6789),
    [anon_sym_trior] = ACTIONS(6789),
    [anon_sym_trireg] = ACTIONS(6789),
    [anon_sym_uwire] = ACTIONS(6789),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6791),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6791),
    [aux_sym_begin_keywords_token1] = ACTIONS(6791),
    [anon_sym_SEMI] = ACTIONS(6791),
    [anon_sym_endmodule] = ACTIONS(6789),
    [anon_sym_extern] = ACTIONS(6789),
    [anon_sym_module] = ACTIONS(6789),
    [anon_sym_macromodule] = ACTIONS(6789),
    [anon_sym_endinterface] = ACTIONS(6789),
    [anon_sym_interface] = ACTIONS(6789),
    [anon_sym_endprogram] = ACTIONS(6789),
    [anon_sym_program] = ACTIONS(6789),
    [anon_sym_checker] = ACTIONS(6789),
    [anon_sym_virtual] = ACTIONS(6789),
    [anon_sym_class] = ACTIONS(6789),
    [anon_sym_timeunit] = ACTIONS(6789),
    [anon_sym_timeprecision] = ACTIONS(6789),
    [anon_sym_type] = ACTIONS(6789),
    [anon_sym_input] = ACTIONS(6789),
    [anon_sym_output] = ACTIONS(6789),
    [anon_sym_inout] = ACTIONS(6789),
    [anon_sym_ref] = ACTIONS(6789),
    [anon_sym_DOLLARfatal] = ACTIONS(6791),
    [anon_sym_DOLLARerror] = ACTIONS(6791),
    [anon_sym_DOLLARwarning] = ACTIONS(6791),
    [anon_sym_DOLLARinfo] = ACTIONS(6791),
    [anon_sym_default] = ACTIONS(6789),
    [anon_sym_clocking] = ACTIONS(6789),
    [anon_sym_defparam] = ACTIONS(6789),
    [anon_sym_bind] = ACTIONS(6789),
    [anon_sym_const] = ACTIONS(6789),
    [anon_sym_function] = ACTIONS(6789),
    [anon_sym_static] = ACTIONS(6789),
    [anon_sym_constraint] = ACTIONS(6789),
    [anon_sym_if] = ACTIONS(6789),
    [anon_sym_else] = ACTIONS(6789),
    [anon_sym_LBRACK] = ACTIONS(6791),
    [anon_sym_localparam] = ACTIONS(6789),
    [anon_sym_parameter] = ACTIONS(6789),
    [anon_sym_specparam] = ACTIONS(6789),
    [anon_sym_var] = ACTIONS(6789),
    [anon_sym_import] = ACTIONS(6789),
    [anon_sym_export] = ACTIONS(6789),
    [anon_sym_genvar] = ACTIONS(6789),
    [anon_sym_interconnect] = ACTIONS(6789),
    [anon_sym_typedef] = ACTIONS(6789),
    [anon_sym_enum] = ACTIONS(6789),
    [anon_sym_struct] = ACTIONS(6789),
    [anon_sym_union] = ACTIONS(6789),
    [anon_sym_nettype] = ACTIONS(6789),
    [anon_sym_automatic] = ACTIONS(6789),
    [anon_sym_string] = ACTIONS(6789),
    [anon_sym_chandle] = ACTIONS(6789),
    [anon_sym_event] = ACTIONS(6789),
    [anon_sym_byte] = ACTIONS(6789),
    [anon_sym_shortint] = ACTIONS(6789),
    [anon_sym_int] = ACTIONS(6789),
    [anon_sym_longint] = ACTIONS(6789),
    [anon_sym_integer] = ACTIONS(6789),
    [anon_sym_time] = ACTIONS(6789),
    [anon_sym_bit] = ACTIONS(6789),
    [anon_sym_logic] = ACTIONS(6789),
    [anon_sym_reg] = ACTIONS(6789),
    [anon_sym_shortreal] = ACTIONS(6789),
    [anon_sym_real] = ACTIONS(6789),
    [anon_sym_realtime] = ACTIONS(6789),
    [anon_sym_supply0] = ACTIONS(6789),
    [anon_sym_supply1] = ACTIONS(6789),
    [anon_sym_signed] = ACTIONS(6789),
    [anon_sym_unsigned] = ACTIONS(6789),
    [anon_sym_task] = ACTIONS(6789),
    [anon_sym_modport] = ACTIONS(6789),
    [anon_sym_assert] = ACTIONS(6789),
    [anon_sym_property] = ACTIONS(6789),
    [anon_sym_assume] = ACTIONS(6789),
    [anon_sym_cover] = ACTIONS(6789),
    [anon_sym_sequence] = ACTIONS(6789),
    [anon_sym_restrict] = ACTIONS(6789),
    [anon_sym_not] = ACTIONS(6789),
    [anon_sym_or] = ACTIONS(6789),
    [anon_sym_and] = ACTIONS(6789),
    [anon_sym_case] = ACTIONS(6789),
    [anon_sym_always] = ACTIONS(6789),
    [anon_sym_covergroup] = ACTIONS(6789),
    [anon_sym_let] = ACTIONS(6789),
    [anon_sym_pulldown] = ACTIONS(6789),
    [anon_sym_pullup] = ACTIONS(6789),
    [anon_sym_cmos] = ACTIONS(6789),
    [anon_sym_rcmos] = ACTIONS(6789),
    [anon_sym_bufif0] = ACTIONS(6789),
    [anon_sym_bufif1] = ACTIONS(6789),
    [anon_sym_notif0] = ACTIONS(6789),
    [anon_sym_notif1] = ACTIONS(6789),
    [anon_sym_nmos] = ACTIONS(6789),
    [anon_sym_pmos] = ACTIONS(6789),
    [anon_sym_rnmos] = ACTIONS(6789),
    [anon_sym_rpmos] = ACTIONS(6789),
    [anon_sym_nand] = ACTIONS(6789),
    [anon_sym_nor] = ACTIONS(6789),
    [anon_sym_xor] = ACTIONS(6789),
    [anon_sym_xnor] = ACTIONS(6789),
    [anon_sym_buf] = ACTIONS(6789),
    [anon_sym_tranif0] = ACTIONS(6789),
    [anon_sym_tranif1] = ACTIONS(6789),
    [anon_sym_rtranif1] = ACTIONS(6789),
    [anon_sym_rtranif0] = ACTIONS(6789),
    [anon_sym_tran] = ACTIONS(6789),
    [anon_sym_rtran] = ACTIONS(6789),
    [anon_sym_generate] = ACTIONS(6789),
    [anon_sym_for] = ACTIONS(6789),
    [anon_sym_initial] = ACTIONS(6789),
    [anon_sym_assign] = ACTIONS(6789),
    [anon_sym_alias] = ACTIONS(6789),
    [anon_sym_always_comb] = ACTIONS(6789),
    [anon_sym_always_latch] = ACTIONS(6789),
    [anon_sym_always_ff] = ACTIONS(6789),
    [anon_sym_final] = ACTIONS(6789),
    [anon_sym_global] = ACTIONS(6789),
    [anon_sym_specify] = ACTIONS(6789),
    [anon_sym_LPAREN_STAR] = ACTIONS(6791),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6791),
    [anon_sym_DOLLARunit] = ACTIONS(6791),
  },
  [1255] = {
    [sym_simple_identifier] = ACTIONS(6793),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6796),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6796),
    [anon_sym_BQUOTE] = ACTIONS(6793),
    [aux_sym_id_directive_token1] = ACTIONS(6796),
    [aux_sym_id_directive_token2] = ACTIONS(6796),
    [aux_sym_id_directive_token3] = ACTIONS(6796),
    [aux_sym_id_directive_token4] = ACTIONS(6793),
    [aux_sym_zero_directive_token1] = ACTIONS(6796),
    [aux_sym_zero_directive_token2] = ACTIONS(6796),
    [aux_sym_zero_directive_token3] = ACTIONS(6796),
    [aux_sym_zero_directive_token4] = ACTIONS(6796),
    [aux_sym_zero_directive_token5] = ACTIONS(6796),
    [aux_sym_zero_directive_token6] = ACTIONS(6796),
    [aux_sym_zero_directive_token7] = ACTIONS(6796),
    [aux_sym_zero_directive_token8] = ACTIONS(6796),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6796),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6796),
    [anon_sym_wire] = ACTIONS(6793),
    [anon_sym_tri] = ACTIONS(6793),
    [anon_sym_tri0] = ACTIONS(6793),
    [anon_sym_tri1] = ACTIONS(6793),
    [anon_sym_wand] = ACTIONS(6793),
    [anon_sym_triand] = ACTIONS(6793),
    [anon_sym_wor] = ACTIONS(6793),
    [anon_sym_trior] = ACTIONS(6793),
    [anon_sym_trireg] = ACTIONS(6793),
    [anon_sym_uwire] = ACTIONS(6793),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6796),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6796),
    [aux_sym_begin_keywords_token1] = ACTIONS(6796),
    [anon_sym_SEMI] = ACTIONS(6796),
    [anon_sym_endmodule] = ACTIONS(6793),
    [anon_sym_extern] = ACTIONS(6793),
    [anon_sym_module] = ACTIONS(6793),
    [anon_sym_macromodule] = ACTIONS(6793),
    [anon_sym_endinterface] = ACTIONS(6793),
    [anon_sym_interface] = ACTIONS(6793),
    [anon_sym_endprogram] = ACTIONS(6793),
    [anon_sym_program] = ACTIONS(6793),
    [anon_sym_checker] = ACTIONS(6793),
    [anon_sym_virtual] = ACTIONS(6793),
    [anon_sym_class] = ACTIONS(6793),
    [anon_sym_timeunit] = ACTIONS(6793),
    [anon_sym_timeprecision] = ACTIONS(6793),
    [anon_sym_type] = ACTIONS(6793),
    [anon_sym_input] = ACTIONS(6793),
    [anon_sym_output] = ACTIONS(6793),
    [anon_sym_inout] = ACTIONS(6793),
    [anon_sym_ref] = ACTIONS(6793),
    [anon_sym_DOLLARfatal] = ACTIONS(6796),
    [anon_sym_DOLLARerror] = ACTIONS(6796),
    [anon_sym_DOLLARwarning] = ACTIONS(6796),
    [anon_sym_DOLLARinfo] = ACTIONS(6796),
    [anon_sym_default] = ACTIONS(6793),
    [anon_sym_clocking] = ACTIONS(6793),
    [anon_sym_defparam] = ACTIONS(6793),
    [anon_sym_bind] = ACTIONS(6793),
    [anon_sym_const] = ACTIONS(6793),
    [anon_sym_function] = ACTIONS(6793),
    [anon_sym_static] = ACTIONS(6793),
    [anon_sym_constraint] = ACTIONS(6793),
    [anon_sym_if] = ACTIONS(6793),
    [anon_sym_else] = ACTIONS(6793),
    [anon_sym_LBRACK] = ACTIONS(6796),
    [anon_sym_localparam] = ACTIONS(6793),
    [anon_sym_parameter] = ACTIONS(6793),
    [anon_sym_specparam] = ACTIONS(6793),
    [anon_sym_var] = ACTIONS(6793),
    [anon_sym_import] = ACTIONS(6793),
    [anon_sym_export] = ACTIONS(6793),
    [anon_sym_genvar] = ACTIONS(6793),
    [anon_sym_interconnect] = ACTIONS(6793),
    [anon_sym_typedef] = ACTIONS(6793),
    [anon_sym_enum] = ACTIONS(6793),
    [anon_sym_struct] = ACTIONS(6793),
    [anon_sym_union] = ACTIONS(6793),
    [anon_sym_nettype] = ACTIONS(6793),
    [anon_sym_automatic] = ACTIONS(6793),
    [anon_sym_string] = ACTIONS(6793),
    [anon_sym_chandle] = ACTIONS(6793),
    [anon_sym_event] = ACTIONS(6793),
    [anon_sym_byte] = ACTIONS(6793),
    [anon_sym_shortint] = ACTIONS(6793),
    [anon_sym_int] = ACTIONS(6793),
    [anon_sym_longint] = ACTIONS(6793),
    [anon_sym_integer] = ACTIONS(6793),
    [anon_sym_time] = ACTIONS(6793),
    [anon_sym_bit] = ACTIONS(6793),
    [anon_sym_logic] = ACTIONS(6793),
    [anon_sym_reg] = ACTIONS(6793),
    [anon_sym_shortreal] = ACTIONS(6793),
    [anon_sym_real] = ACTIONS(6793),
    [anon_sym_realtime] = ACTIONS(6793),
    [anon_sym_supply0] = ACTIONS(6793),
    [anon_sym_supply1] = ACTIONS(6793),
    [anon_sym_signed] = ACTIONS(6793),
    [anon_sym_unsigned] = ACTIONS(6793),
    [anon_sym_task] = ACTIONS(6793),
    [anon_sym_modport] = ACTIONS(6793),
    [anon_sym_assert] = ACTIONS(6793),
    [anon_sym_property] = ACTIONS(6793),
    [anon_sym_assume] = ACTIONS(6793),
    [anon_sym_cover] = ACTIONS(6793),
    [anon_sym_sequence] = ACTIONS(6793),
    [anon_sym_restrict] = ACTIONS(6793),
    [anon_sym_not] = ACTIONS(6793),
    [anon_sym_or] = ACTIONS(6793),
    [anon_sym_and] = ACTIONS(6793),
    [anon_sym_case] = ACTIONS(6793),
    [anon_sym_always] = ACTIONS(6793),
    [anon_sym_covergroup] = ACTIONS(6793),
    [anon_sym_let] = ACTIONS(6793),
    [anon_sym_pulldown] = ACTIONS(6793),
    [anon_sym_pullup] = ACTIONS(6793),
    [anon_sym_cmos] = ACTIONS(6793),
    [anon_sym_rcmos] = ACTIONS(6793),
    [anon_sym_bufif0] = ACTIONS(6793),
    [anon_sym_bufif1] = ACTIONS(6793),
    [anon_sym_notif0] = ACTIONS(6793),
    [anon_sym_notif1] = ACTIONS(6793),
    [anon_sym_nmos] = ACTIONS(6793),
    [anon_sym_pmos] = ACTIONS(6793),
    [anon_sym_rnmos] = ACTIONS(6793),
    [anon_sym_rpmos] = ACTIONS(6793),
    [anon_sym_nand] = ACTIONS(6793),
    [anon_sym_nor] = ACTIONS(6793),
    [anon_sym_xor] = ACTIONS(6793),
    [anon_sym_xnor] = ACTIONS(6793),
    [anon_sym_buf] = ACTIONS(6793),
    [anon_sym_tranif0] = ACTIONS(6793),
    [anon_sym_tranif1] = ACTIONS(6793),
    [anon_sym_rtranif1] = ACTIONS(6793),
    [anon_sym_rtranif0] = ACTIONS(6793),
    [anon_sym_tran] = ACTIONS(6793),
    [anon_sym_rtran] = ACTIONS(6793),
    [anon_sym_generate] = ACTIONS(6793),
    [anon_sym_for] = ACTIONS(6793),
    [anon_sym_initial] = ACTIONS(6793),
    [anon_sym_assign] = ACTIONS(6793),
    [anon_sym_alias] = ACTIONS(6793),
    [anon_sym_always_comb] = ACTIONS(6793),
    [anon_sym_always_latch] = ACTIONS(6793),
    [anon_sym_always_ff] = ACTIONS(6793),
    [anon_sym_final] = ACTIONS(6793),
    [anon_sym_global] = ACTIONS(6793),
    [anon_sym_specify] = ACTIONS(6793),
    [anon_sym_LPAREN_STAR] = ACTIONS(6796),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6796),
    [anon_sym_DOLLARunit] = ACTIONS(6796),
  },
  [1256] = {
    [sym_simple_identifier] = ACTIONS(6799),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6801),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6801),
    [anon_sym_BQUOTE] = ACTIONS(6799),
    [aux_sym_id_directive_token1] = ACTIONS(6801),
    [aux_sym_id_directive_token2] = ACTIONS(6801),
    [aux_sym_id_directive_token3] = ACTIONS(6801),
    [aux_sym_id_directive_token4] = ACTIONS(6799),
    [aux_sym_zero_directive_token1] = ACTIONS(6801),
    [aux_sym_zero_directive_token2] = ACTIONS(6801),
    [aux_sym_zero_directive_token3] = ACTIONS(6801),
    [aux_sym_zero_directive_token4] = ACTIONS(6801),
    [aux_sym_zero_directive_token5] = ACTIONS(6801),
    [aux_sym_zero_directive_token6] = ACTIONS(6801),
    [aux_sym_zero_directive_token7] = ACTIONS(6801),
    [aux_sym_zero_directive_token8] = ACTIONS(6801),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6801),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6801),
    [anon_sym_wire] = ACTIONS(6799),
    [anon_sym_tri] = ACTIONS(6799),
    [anon_sym_tri0] = ACTIONS(6799),
    [anon_sym_tri1] = ACTIONS(6799),
    [anon_sym_wand] = ACTIONS(6799),
    [anon_sym_triand] = ACTIONS(6799),
    [anon_sym_wor] = ACTIONS(6799),
    [anon_sym_trior] = ACTIONS(6799),
    [anon_sym_trireg] = ACTIONS(6799),
    [anon_sym_uwire] = ACTIONS(6799),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6801),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6801),
    [aux_sym_begin_keywords_token1] = ACTIONS(6801),
    [anon_sym_SEMI] = ACTIONS(6801),
    [anon_sym_endmodule] = ACTIONS(6799),
    [anon_sym_extern] = ACTIONS(6799),
    [anon_sym_module] = ACTIONS(6799),
    [anon_sym_macromodule] = ACTIONS(6799),
    [anon_sym_endinterface] = ACTIONS(6799),
    [anon_sym_interface] = ACTIONS(6799),
    [anon_sym_endprogram] = ACTIONS(6799),
    [anon_sym_program] = ACTIONS(6799),
    [anon_sym_checker] = ACTIONS(6799),
    [anon_sym_virtual] = ACTIONS(6799),
    [anon_sym_class] = ACTIONS(6799),
    [anon_sym_timeunit] = ACTIONS(6799),
    [anon_sym_timeprecision] = ACTIONS(6799),
    [anon_sym_type] = ACTIONS(6799),
    [anon_sym_input] = ACTIONS(6799),
    [anon_sym_output] = ACTIONS(6799),
    [anon_sym_inout] = ACTIONS(6799),
    [anon_sym_ref] = ACTIONS(6799),
    [anon_sym_DOLLARfatal] = ACTIONS(6801),
    [anon_sym_DOLLARerror] = ACTIONS(6801),
    [anon_sym_DOLLARwarning] = ACTIONS(6801),
    [anon_sym_DOLLARinfo] = ACTIONS(6801),
    [anon_sym_default] = ACTIONS(6799),
    [anon_sym_clocking] = ACTIONS(6799),
    [anon_sym_defparam] = ACTIONS(6799),
    [anon_sym_bind] = ACTIONS(6799),
    [anon_sym_const] = ACTIONS(6799),
    [anon_sym_function] = ACTIONS(6799),
    [anon_sym_static] = ACTIONS(6799),
    [anon_sym_constraint] = ACTIONS(6799),
    [anon_sym_if] = ACTIONS(6799),
    [anon_sym_else] = ACTIONS(6799),
    [anon_sym_LBRACK] = ACTIONS(6801),
    [anon_sym_localparam] = ACTIONS(6799),
    [anon_sym_parameter] = ACTIONS(6799),
    [anon_sym_specparam] = ACTIONS(6799),
    [anon_sym_var] = ACTIONS(6799),
    [anon_sym_import] = ACTIONS(6799),
    [anon_sym_export] = ACTIONS(6799),
    [anon_sym_genvar] = ACTIONS(6799),
    [anon_sym_interconnect] = ACTIONS(6799),
    [anon_sym_typedef] = ACTIONS(6799),
    [anon_sym_enum] = ACTIONS(6799),
    [anon_sym_struct] = ACTIONS(6799),
    [anon_sym_union] = ACTIONS(6799),
    [anon_sym_nettype] = ACTIONS(6799),
    [anon_sym_automatic] = ACTIONS(6799),
    [anon_sym_string] = ACTIONS(6799),
    [anon_sym_chandle] = ACTIONS(6799),
    [anon_sym_event] = ACTIONS(6799),
    [anon_sym_byte] = ACTIONS(6799),
    [anon_sym_shortint] = ACTIONS(6799),
    [anon_sym_int] = ACTIONS(6799),
    [anon_sym_longint] = ACTIONS(6799),
    [anon_sym_integer] = ACTIONS(6799),
    [anon_sym_time] = ACTIONS(6799),
    [anon_sym_bit] = ACTIONS(6799),
    [anon_sym_logic] = ACTIONS(6799),
    [anon_sym_reg] = ACTIONS(6799),
    [anon_sym_shortreal] = ACTIONS(6799),
    [anon_sym_real] = ACTIONS(6799),
    [anon_sym_realtime] = ACTIONS(6799),
    [anon_sym_supply0] = ACTIONS(6799),
    [anon_sym_supply1] = ACTIONS(6799),
    [anon_sym_signed] = ACTIONS(6799),
    [anon_sym_unsigned] = ACTIONS(6799),
    [anon_sym_task] = ACTIONS(6799),
    [anon_sym_modport] = ACTIONS(6799),
    [anon_sym_assert] = ACTIONS(6799),
    [anon_sym_property] = ACTIONS(6799),
    [anon_sym_assume] = ACTIONS(6799),
    [anon_sym_cover] = ACTIONS(6799),
    [anon_sym_sequence] = ACTIONS(6799),
    [anon_sym_restrict] = ACTIONS(6799),
    [anon_sym_not] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(6799),
    [anon_sym_and] = ACTIONS(6799),
    [anon_sym_case] = ACTIONS(6799),
    [anon_sym_always] = ACTIONS(6799),
    [anon_sym_covergroup] = ACTIONS(6799),
    [anon_sym_let] = ACTIONS(6799),
    [anon_sym_pulldown] = ACTIONS(6799),
    [anon_sym_pullup] = ACTIONS(6799),
    [anon_sym_cmos] = ACTIONS(6799),
    [anon_sym_rcmos] = ACTIONS(6799),
    [anon_sym_bufif0] = ACTIONS(6799),
    [anon_sym_bufif1] = ACTIONS(6799),
    [anon_sym_notif0] = ACTIONS(6799),
    [anon_sym_notif1] = ACTIONS(6799),
    [anon_sym_nmos] = ACTIONS(6799),
    [anon_sym_pmos] = ACTIONS(6799),
    [anon_sym_rnmos] = ACTIONS(6799),
    [anon_sym_rpmos] = ACTIONS(6799),
    [anon_sym_nand] = ACTIONS(6799),
    [anon_sym_nor] = ACTIONS(6799),
    [anon_sym_xor] = ACTIONS(6799),
    [anon_sym_xnor] = ACTIONS(6799),
    [anon_sym_buf] = ACTIONS(6799),
    [anon_sym_tranif0] = ACTIONS(6799),
    [anon_sym_tranif1] = ACTIONS(6799),
    [anon_sym_rtranif1] = ACTIONS(6799),
    [anon_sym_rtranif0] = ACTIONS(6799),
    [anon_sym_tran] = ACTIONS(6799),
    [anon_sym_rtran] = ACTIONS(6799),
    [anon_sym_generate] = ACTIONS(6799),
    [anon_sym_for] = ACTIONS(6799),
    [anon_sym_initial] = ACTIONS(6799),
    [anon_sym_assign] = ACTIONS(6799),
    [anon_sym_alias] = ACTIONS(6799),
    [anon_sym_always_comb] = ACTIONS(6799),
    [anon_sym_always_latch] = ACTIONS(6799),
    [anon_sym_always_ff] = ACTIONS(6799),
    [anon_sym_final] = ACTIONS(6799),
    [anon_sym_global] = ACTIONS(6799),
    [anon_sym_specify] = ACTIONS(6799),
    [anon_sym_LPAREN_STAR] = ACTIONS(6801),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6801),
    [anon_sym_DOLLARunit] = ACTIONS(6801),
  },
  [1257] = {
    [ts_builtin_sym_end] = ACTIONS(6803),
    [sym_simple_identifier] = ACTIONS(6805),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6803),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6803),
    [anon_sym_BQUOTE] = ACTIONS(6805),
    [aux_sym_id_directive_token1] = ACTIONS(6803),
    [aux_sym_id_directive_token2] = ACTIONS(6803),
    [aux_sym_id_directive_token3] = ACTIONS(6803),
    [aux_sym_id_directive_token4] = ACTIONS(6805),
    [aux_sym_zero_directive_token1] = ACTIONS(6803),
    [aux_sym_zero_directive_token2] = ACTIONS(6803),
    [aux_sym_zero_directive_token3] = ACTIONS(6803),
    [aux_sym_zero_directive_token4] = ACTIONS(6803),
    [aux_sym_zero_directive_token5] = ACTIONS(6803),
    [aux_sym_zero_directive_token6] = ACTIONS(6803),
    [aux_sym_zero_directive_token7] = ACTIONS(6803),
    [aux_sym_zero_directive_token8] = ACTIONS(6803),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6803),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6803),
    [anon_sym_wire] = ACTIONS(6805),
    [anon_sym_tri] = ACTIONS(6805),
    [anon_sym_tri0] = ACTIONS(6805),
    [anon_sym_tri1] = ACTIONS(6805),
    [anon_sym_wand] = ACTIONS(6805),
    [anon_sym_triand] = ACTIONS(6805),
    [anon_sym_wor] = ACTIONS(6805),
    [anon_sym_trior] = ACTIONS(6805),
    [anon_sym_trireg] = ACTIONS(6805),
    [anon_sym_uwire] = ACTIONS(6805),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6803),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6803),
    [aux_sym_begin_keywords_token1] = ACTIONS(6803),
    [anon_sym_SEMI] = ACTIONS(6803),
    [anon_sym_endmodule] = ACTIONS(6805),
    [anon_sym_extern] = ACTIONS(6805),
    [anon_sym_module] = ACTIONS(6805),
    [anon_sym_macromodule] = ACTIONS(6805),
    [anon_sym_interface] = ACTIONS(6805),
    [anon_sym_program] = ACTIONS(6805),
    [anon_sym_checker] = ACTIONS(6805),
    [anon_sym_virtual] = ACTIONS(6805),
    [anon_sym_class] = ACTIONS(6805),
    [anon_sym_package] = ACTIONS(6805),
    [anon_sym_timeunit] = ACTIONS(6805),
    [anon_sym_timeprecision] = ACTIONS(6805),
    [anon_sym_type] = ACTIONS(6805),
    [anon_sym_input] = ACTIONS(6805),
    [anon_sym_output] = ACTIONS(6805),
    [anon_sym_inout] = ACTIONS(6805),
    [anon_sym_ref] = ACTIONS(6805),
    [anon_sym_DOLLARfatal] = ACTIONS(6803),
    [anon_sym_DOLLARerror] = ACTIONS(6803),
    [anon_sym_DOLLARwarning] = ACTIONS(6803),
    [anon_sym_DOLLARinfo] = ACTIONS(6803),
    [anon_sym_default] = ACTIONS(6805),
    [anon_sym_clocking] = ACTIONS(6805),
    [anon_sym_defparam] = ACTIONS(6805),
    [anon_sym_bind] = ACTIONS(6805),
    [anon_sym_const] = ACTIONS(6805),
    [anon_sym_function] = ACTIONS(6805),
    [anon_sym_static] = ACTIONS(6805),
    [anon_sym_constraint] = ACTIONS(6805),
    [anon_sym_if] = ACTIONS(6805),
    [anon_sym_LBRACK] = ACTIONS(6803),
    [anon_sym_localparam] = ACTIONS(6805),
    [anon_sym_parameter] = ACTIONS(6805),
    [anon_sym_specparam] = ACTIONS(6805),
    [anon_sym_var] = ACTIONS(6805),
    [anon_sym_import] = ACTIONS(6805),
    [anon_sym_export] = ACTIONS(6805),
    [anon_sym_genvar] = ACTIONS(6805),
    [anon_sym_interconnect] = ACTIONS(6805),
    [anon_sym_typedef] = ACTIONS(6805),
    [anon_sym_enum] = ACTIONS(6805),
    [anon_sym_struct] = ACTIONS(6805),
    [anon_sym_union] = ACTIONS(6805),
    [anon_sym_nettype] = ACTIONS(6805),
    [anon_sym_automatic] = ACTIONS(6805),
    [anon_sym_string] = ACTIONS(6805),
    [anon_sym_chandle] = ACTIONS(6805),
    [anon_sym_event] = ACTIONS(6805),
    [anon_sym_byte] = ACTIONS(6805),
    [anon_sym_shortint] = ACTIONS(6805),
    [anon_sym_int] = ACTIONS(6805),
    [anon_sym_longint] = ACTIONS(6805),
    [anon_sym_integer] = ACTIONS(6805),
    [anon_sym_time] = ACTIONS(6805),
    [anon_sym_bit] = ACTIONS(6805),
    [anon_sym_logic] = ACTIONS(6805),
    [anon_sym_reg] = ACTIONS(6805),
    [anon_sym_shortreal] = ACTIONS(6805),
    [anon_sym_real] = ACTIONS(6805),
    [anon_sym_realtime] = ACTIONS(6805),
    [anon_sym_supply0] = ACTIONS(6805),
    [anon_sym_supply1] = ACTIONS(6805),
    [anon_sym_signed] = ACTIONS(6805),
    [anon_sym_unsigned] = ACTIONS(6805),
    [anon_sym_task] = ACTIONS(6805),
    [anon_sym_assert] = ACTIONS(6805),
    [anon_sym_property] = ACTIONS(6805),
    [anon_sym_assume] = ACTIONS(6805),
    [anon_sym_cover] = ACTIONS(6805),
    [anon_sym_sequence] = ACTIONS(6805),
    [anon_sym_restrict] = ACTIONS(6805),
    [anon_sym_not] = ACTIONS(6805),
    [anon_sym_or] = ACTIONS(6805),
    [anon_sym_and] = ACTIONS(6805),
    [anon_sym_case] = ACTIONS(6805),
    [anon_sym_always] = ACTIONS(6805),
    [anon_sym_covergroup] = ACTIONS(6805),
    [anon_sym_let] = ACTIONS(6805),
    [anon_sym_pulldown] = ACTIONS(6805),
    [anon_sym_pullup] = ACTIONS(6805),
    [anon_sym_cmos] = ACTIONS(6805),
    [anon_sym_rcmos] = ACTIONS(6805),
    [anon_sym_bufif0] = ACTIONS(6805),
    [anon_sym_bufif1] = ACTIONS(6805),
    [anon_sym_notif0] = ACTIONS(6805),
    [anon_sym_notif1] = ACTIONS(6805),
    [anon_sym_nmos] = ACTIONS(6805),
    [anon_sym_pmos] = ACTIONS(6805),
    [anon_sym_rnmos] = ACTIONS(6805),
    [anon_sym_rpmos] = ACTIONS(6805),
    [anon_sym_nand] = ACTIONS(6805),
    [anon_sym_nor] = ACTIONS(6805),
    [anon_sym_xor] = ACTIONS(6805),
    [anon_sym_xnor] = ACTIONS(6805),
    [anon_sym_buf] = ACTIONS(6805),
    [anon_sym_tranif0] = ACTIONS(6805),
    [anon_sym_tranif1] = ACTIONS(6805),
    [anon_sym_rtranif1] = ACTIONS(6805),
    [anon_sym_rtranif0] = ACTIONS(6805),
    [anon_sym_tran] = ACTIONS(6805),
    [anon_sym_rtran] = ACTIONS(6805),
    [anon_sym_generate] = ACTIONS(6805),
    [anon_sym_for] = ACTIONS(6805),
    [anon_sym_primitive] = ACTIONS(6805),
    [anon_sym_initial] = ACTIONS(6805),
    [anon_sym_assign] = ACTIONS(6805),
    [anon_sym_alias] = ACTIONS(6805),
    [anon_sym_always_comb] = ACTIONS(6805),
    [anon_sym_always_latch] = ACTIONS(6805),
    [anon_sym_always_ff] = ACTIONS(6805),
    [anon_sym_final] = ACTIONS(6805),
    [anon_sym_global] = ACTIONS(6805),
    [anon_sym_specify] = ACTIONS(6805),
    [anon_sym_LPAREN_STAR] = ACTIONS(6803),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6803),
    [anon_sym_DOLLARunit] = ACTIONS(6803),
  },
  [1258] = {
    [ts_builtin_sym_end] = ACTIONS(6807),
    [sym_simple_identifier] = ACTIONS(6809),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6807),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6807),
    [anon_sym_BQUOTE] = ACTIONS(6809),
    [aux_sym_id_directive_token1] = ACTIONS(6807),
    [aux_sym_id_directive_token2] = ACTIONS(6807),
    [aux_sym_id_directive_token3] = ACTIONS(6807),
    [aux_sym_id_directive_token4] = ACTIONS(6809),
    [aux_sym_zero_directive_token1] = ACTIONS(6807),
    [aux_sym_zero_directive_token2] = ACTIONS(6807),
    [aux_sym_zero_directive_token3] = ACTIONS(6807),
    [aux_sym_zero_directive_token4] = ACTIONS(6807),
    [aux_sym_zero_directive_token5] = ACTIONS(6807),
    [aux_sym_zero_directive_token6] = ACTIONS(6807),
    [aux_sym_zero_directive_token7] = ACTIONS(6807),
    [aux_sym_zero_directive_token8] = ACTIONS(6807),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6807),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6807),
    [anon_sym_wire] = ACTIONS(6809),
    [anon_sym_tri] = ACTIONS(6809),
    [anon_sym_tri0] = ACTIONS(6809),
    [anon_sym_tri1] = ACTIONS(6809),
    [anon_sym_wand] = ACTIONS(6809),
    [anon_sym_triand] = ACTIONS(6809),
    [anon_sym_wor] = ACTIONS(6809),
    [anon_sym_trior] = ACTIONS(6809),
    [anon_sym_trireg] = ACTIONS(6809),
    [anon_sym_uwire] = ACTIONS(6809),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6807),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6807),
    [aux_sym_begin_keywords_token1] = ACTIONS(6807),
    [anon_sym_SEMI] = ACTIONS(6807),
    [anon_sym_endmodule] = ACTIONS(6809),
    [anon_sym_extern] = ACTIONS(6809),
    [anon_sym_module] = ACTIONS(6809),
    [anon_sym_macromodule] = ACTIONS(6809),
    [anon_sym_interface] = ACTIONS(6809),
    [anon_sym_program] = ACTIONS(6809),
    [anon_sym_checker] = ACTIONS(6809),
    [anon_sym_virtual] = ACTIONS(6809),
    [anon_sym_class] = ACTIONS(6809),
    [anon_sym_package] = ACTIONS(6809),
    [anon_sym_timeunit] = ACTIONS(6809),
    [anon_sym_timeprecision] = ACTIONS(6809),
    [anon_sym_type] = ACTIONS(6809),
    [anon_sym_input] = ACTIONS(6809),
    [anon_sym_output] = ACTIONS(6809),
    [anon_sym_inout] = ACTIONS(6809),
    [anon_sym_ref] = ACTIONS(6809),
    [anon_sym_DOLLARfatal] = ACTIONS(6807),
    [anon_sym_DOLLARerror] = ACTIONS(6807),
    [anon_sym_DOLLARwarning] = ACTIONS(6807),
    [anon_sym_DOLLARinfo] = ACTIONS(6807),
    [anon_sym_default] = ACTIONS(6809),
    [anon_sym_clocking] = ACTIONS(6809),
    [anon_sym_defparam] = ACTIONS(6809),
    [anon_sym_bind] = ACTIONS(6809),
    [anon_sym_const] = ACTIONS(6809),
    [anon_sym_function] = ACTIONS(6809),
    [anon_sym_static] = ACTIONS(6809),
    [anon_sym_constraint] = ACTIONS(6809),
    [anon_sym_if] = ACTIONS(6809),
    [anon_sym_LBRACK] = ACTIONS(6807),
    [anon_sym_localparam] = ACTIONS(6809),
    [anon_sym_parameter] = ACTIONS(6809),
    [anon_sym_specparam] = ACTIONS(6809),
    [anon_sym_var] = ACTIONS(6809),
    [anon_sym_import] = ACTIONS(6809),
    [anon_sym_export] = ACTIONS(6809),
    [anon_sym_genvar] = ACTIONS(6809),
    [anon_sym_interconnect] = ACTIONS(6809),
    [anon_sym_typedef] = ACTIONS(6809),
    [anon_sym_enum] = ACTIONS(6809),
    [anon_sym_struct] = ACTIONS(6809),
    [anon_sym_union] = ACTIONS(6809),
    [anon_sym_nettype] = ACTIONS(6809),
    [anon_sym_automatic] = ACTIONS(6809),
    [anon_sym_string] = ACTIONS(6809),
    [anon_sym_chandle] = ACTIONS(6809),
    [anon_sym_event] = ACTIONS(6809),
    [anon_sym_byte] = ACTIONS(6809),
    [anon_sym_shortint] = ACTIONS(6809),
    [anon_sym_int] = ACTIONS(6809),
    [anon_sym_longint] = ACTIONS(6809),
    [anon_sym_integer] = ACTIONS(6809),
    [anon_sym_time] = ACTIONS(6809),
    [anon_sym_bit] = ACTIONS(6809),
    [anon_sym_logic] = ACTIONS(6809),
    [anon_sym_reg] = ACTIONS(6809),
    [anon_sym_shortreal] = ACTIONS(6809),
    [anon_sym_real] = ACTIONS(6809),
    [anon_sym_realtime] = ACTIONS(6809),
    [anon_sym_supply0] = ACTIONS(6809),
    [anon_sym_supply1] = ACTIONS(6809),
    [anon_sym_signed] = ACTIONS(6809),
    [anon_sym_unsigned] = ACTIONS(6809),
    [anon_sym_task] = ACTIONS(6809),
    [anon_sym_assert] = ACTIONS(6809),
    [anon_sym_property] = ACTIONS(6809),
    [anon_sym_assume] = ACTIONS(6809),
    [anon_sym_cover] = ACTIONS(6809),
    [anon_sym_sequence] = ACTIONS(6809),
    [anon_sym_restrict] = ACTIONS(6809),
    [anon_sym_not] = ACTIONS(6809),
    [anon_sym_or] = ACTIONS(6809),
    [anon_sym_and] = ACTIONS(6809),
    [anon_sym_case] = ACTIONS(6809),
    [anon_sym_always] = ACTIONS(6809),
    [anon_sym_covergroup] = ACTIONS(6809),
    [anon_sym_let] = ACTIONS(6809),
    [anon_sym_pulldown] = ACTIONS(6809),
    [anon_sym_pullup] = ACTIONS(6809),
    [anon_sym_cmos] = ACTIONS(6809),
    [anon_sym_rcmos] = ACTIONS(6809),
    [anon_sym_bufif0] = ACTIONS(6809),
    [anon_sym_bufif1] = ACTIONS(6809),
    [anon_sym_notif0] = ACTIONS(6809),
    [anon_sym_notif1] = ACTIONS(6809),
    [anon_sym_nmos] = ACTIONS(6809),
    [anon_sym_pmos] = ACTIONS(6809),
    [anon_sym_rnmos] = ACTIONS(6809),
    [anon_sym_rpmos] = ACTIONS(6809),
    [anon_sym_nand] = ACTIONS(6809),
    [anon_sym_nor] = ACTIONS(6809),
    [anon_sym_xor] = ACTIONS(6809),
    [anon_sym_xnor] = ACTIONS(6809),
    [anon_sym_buf] = ACTIONS(6809),
    [anon_sym_tranif0] = ACTIONS(6809),
    [anon_sym_tranif1] = ACTIONS(6809),
    [anon_sym_rtranif1] = ACTIONS(6809),
    [anon_sym_rtranif0] = ACTIONS(6809),
    [anon_sym_tran] = ACTIONS(6809),
    [anon_sym_rtran] = ACTIONS(6809),
    [anon_sym_generate] = ACTIONS(6809),
    [anon_sym_for] = ACTIONS(6809),
    [anon_sym_primitive] = ACTIONS(6809),
    [anon_sym_initial] = ACTIONS(6809),
    [anon_sym_assign] = ACTIONS(6809),
    [anon_sym_alias] = ACTIONS(6809),
    [anon_sym_always_comb] = ACTIONS(6809),
    [anon_sym_always_latch] = ACTIONS(6809),
    [anon_sym_always_ff] = ACTIONS(6809),
    [anon_sym_final] = ACTIONS(6809),
    [anon_sym_global] = ACTIONS(6809),
    [anon_sym_specify] = ACTIONS(6809),
    [anon_sym_LPAREN_STAR] = ACTIONS(6807),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6807),
    [anon_sym_DOLLARunit] = ACTIONS(6807),
  },
  [1259] = {
    [ts_builtin_sym_end] = ACTIONS(6811),
    [sym_simple_identifier] = ACTIONS(6813),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6811),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6811),
    [anon_sym_BQUOTE] = ACTIONS(6813),
    [aux_sym_id_directive_token1] = ACTIONS(6811),
    [aux_sym_id_directive_token2] = ACTIONS(6811),
    [aux_sym_id_directive_token3] = ACTIONS(6811),
    [aux_sym_id_directive_token4] = ACTIONS(6813),
    [aux_sym_zero_directive_token1] = ACTIONS(6811),
    [aux_sym_zero_directive_token2] = ACTIONS(6811),
    [aux_sym_zero_directive_token3] = ACTIONS(6811),
    [aux_sym_zero_directive_token4] = ACTIONS(6811),
    [aux_sym_zero_directive_token5] = ACTIONS(6811),
    [aux_sym_zero_directive_token6] = ACTIONS(6811),
    [aux_sym_zero_directive_token7] = ACTIONS(6811),
    [aux_sym_zero_directive_token8] = ACTIONS(6811),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6811),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6811),
    [anon_sym_wire] = ACTIONS(6813),
    [anon_sym_tri] = ACTIONS(6813),
    [anon_sym_tri0] = ACTIONS(6813),
    [anon_sym_tri1] = ACTIONS(6813),
    [anon_sym_wand] = ACTIONS(6813),
    [anon_sym_triand] = ACTIONS(6813),
    [anon_sym_wor] = ACTIONS(6813),
    [anon_sym_trior] = ACTIONS(6813),
    [anon_sym_trireg] = ACTIONS(6813),
    [anon_sym_uwire] = ACTIONS(6813),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6811),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6811),
    [aux_sym_begin_keywords_token1] = ACTIONS(6811),
    [anon_sym_SEMI] = ACTIONS(6811),
    [anon_sym_endmodule] = ACTIONS(6813),
    [anon_sym_extern] = ACTIONS(6813),
    [anon_sym_module] = ACTIONS(6813),
    [anon_sym_macromodule] = ACTIONS(6813),
    [anon_sym_interface] = ACTIONS(6813),
    [anon_sym_program] = ACTIONS(6813),
    [anon_sym_checker] = ACTIONS(6813),
    [anon_sym_virtual] = ACTIONS(6813),
    [anon_sym_class] = ACTIONS(6813),
    [anon_sym_package] = ACTIONS(6813),
    [anon_sym_timeunit] = ACTIONS(6813),
    [anon_sym_timeprecision] = ACTIONS(6813),
    [anon_sym_type] = ACTIONS(6813),
    [anon_sym_input] = ACTIONS(6813),
    [anon_sym_output] = ACTIONS(6813),
    [anon_sym_inout] = ACTIONS(6813),
    [anon_sym_ref] = ACTIONS(6813),
    [anon_sym_DOLLARfatal] = ACTIONS(6811),
    [anon_sym_DOLLARerror] = ACTIONS(6811),
    [anon_sym_DOLLARwarning] = ACTIONS(6811),
    [anon_sym_DOLLARinfo] = ACTIONS(6811),
    [anon_sym_default] = ACTIONS(6813),
    [anon_sym_clocking] = ACTIONS(6813),
    [anon_sym_defparam] = ACTIONS(6813),
    [anon_sym_bind] = ACTIONS(6813),
    [anon_sym_const] = ACTIONS(6813),
    [anon_sym_function] = ACTIONS(6813),
    [anon_sym_static] = ACTIONS(6813),
    [anon_sym_constraint] = ACTIONS(6813),
    [anon_sym_if] = ACTIONS(6813),
    [anon_sym_LBRACK] = ACTIONS(6811),
    [anon_sym_localparam] = ACTIONS(6813),
    [anon_sym_parameter] = ACTIONS(6813),
    [anon_sym_specparam] = ACTIONS(6813),
    [anon_sym_var] = ACTIONS(6813),
    [anon_sym_import] = ACTIONS(6813),
    [anon_sym_export] = ACTIONS(6813),
    [anon_sym_genvar] = ACTIONS(6813),
    [anon_sym_interconnect] = ACTIONS(6813),
    [anon_sym_typedef] = ACTIONS(6813),
    [anon_sym_enum] = ACTIONS(6813),
    [anon_sym_struct] = ACTIONS(6813),
    [anon_sym_union] = ACTIONS(6813),
    [anon_sym_nettype] = ACTIONS(6813),
    [anon_sym_automatic] = ACTIONS(6813),
    [anon_sym_string] = ACTIONS(6813),
    [anon_sym_chandle] = ACTIONS(6813),
    [anon_sym_event] = ACTIONS(6813),
    [anon_sym_byte] = ACTIONS(6813),
    [anon_sym_shortint] = ACTIONS(6813),
    [anon_sym_int] = ACTIONS(6813),
    [anon_sym_longint] = ACTIONS(6813),
    [anon_sym_integer] = ACTIONS(6813),
    [anon_sym_time] = ACTIONS(6813),
    [anon_sym_bit] = ACTIONS(6813),
    [anon_sym_logic] = ACTIONS(6813),
    [anon_sym_reg] = ACTIONS(6813),
    [anon_sym_shortreal] = ACTIONS(6813),
    [anon_sym_real] = ACTIONS(6813),
    [anon_sym_realtime] = ACTIONS(6813),
    [anon_sym_supply0] = ACTIONS(6813),
    [anon_sym_supply1] = ACTIONS(6813),
    [anon_sym_signed] = ACTIONS(6813),
    [anon_sym_unsigned] = ACTIONS(6813),
    [anon_sym_task] = ACTIONS(6813),
    [anon_sym_assert] = ACTIONS(6813),
    [anon_sym_property] = ACTIONS(6813),
    [anon_sym_assume] = ACTIONS(6813),
    [anon_sym_cover] = ACTIONS(6813),
    [anon_sym_sequence] = ACTIONS(6813),
    [anon_sym_restrict] = ACTIONS(6813),
    [anon_sym_not] = ACTIONS(6813),
    [anon_sym_or] = ACTIONS(6813),
    [anon_sym_and] = ACTIONS(6813),
    [anon_sym_case] = ACTIONS(6813),
    [anon_sym_always] = ACTIONS(6813),
    [anon_sym_covergroup] = ACTIONS(6813),
    [anon_sym_let] = ACTIONS(6813),
    [anon_sym_pulldown] = ACTIONS(6813),
    [anon_sym_pullup] = ACTIONS(6813),
    [anon_sym_cmos] = ACTIONS(6813),
    [anon_sym_rcmos] = ACTIONS(6813),
    [anon_sym_bufif0] = ACTIONS(6813),
    [anon_sym_bufif1] = ACTIONS(6813),
    [anon_sym_notif0] = ACTIONS(6813),
    [anon_sym_notif1] = ACTIONS(6813),
    [anon_sym_nmos] = ACTIONS(6813),
    [anon_sym_pmos] = ACTIONS(6813),
    [anon_sym_rnmos] = ACTIONS(6813),
    [anon_sym_rpmos] = ACTIONS(6813),
    [anon_sym_nand] = ACTIONS(6813),
    [anon_sym_nor] = ACTIONS(6813),
    [anon_sym_xor] = ACTIONS(6813),
    [anon_sym_xnor] = ACTIONS(6813),
    [anon_sym_buf] = ACTIONS(6813),
    [anon_sym_tranif0] = ACTIONS(6813),
    [anon_sym_tranif1] = ACTIONS(6813),
    [anon_sym_rtranif1] = ACTIONS(6813),
    [anon_sym_rtranif0] = ACTIONS(6813),
    [anon_sym_tran] = ACTIONS(6813),
    [anon_sym_rtran] = ACTIONS(6813),
    [anon_sym_generate] = ACTIONS(6813),
    [anon_sym_for] = ACTIONS(6813),
    [anon_sym_primitive] = ACTIONS(6813),
    [anon_sym_initial] = ACTIONS(6813),
    [anon_sym_assign] = ACTIONS(6813),
    [anon_sym_alias] = ACTIONS(6813),
    [anon_sym_always_comb] = ACTIONS(6813),
    [anon_sym_always_latch] = ACTIONS(6813),
    [anon_sym_always_ff] = ACTIONS(6813),
    [anon_sym_final] = ACTIONS(6813),
    [anon_sym_global] = ACTIONS(6813),
    [anon_sym_specify] = ACTIONS(6813),
    [anon_sym_LPAREN_STAR] = ACTIONS(6811),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6811),
    [anon_sym_DOLLARunit] = ACTIONS(6811),
  },
  [1260] = {
    [ts_builtin_sym_end] = ACTIONS(6815),
    [sym_simple_identifier] = ACTIONS(6817),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6815),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6815),
    [anon_sym_BQUOTE] = ACTIONS(6817),
    [aux_sym_id_directive_token1] = ACTIONS(6815),
    [aux_sym_id_directive_token2] = ACTIONS(6815),
    [aux_sym_id_directive_token3] = ACTIONS(6815),
    [aux_sym_id_directive_token4] = ACTIONS(6817),
    [aux_sym_zero_directive_token1] = ACTIONS(6815),
    [aux_sym_zero_directive_token2] = ACTIONS(6815),
    [aux_sym_zero_directive_token3] = ACTIONS(6815),
    [aux_sym_zero_directive_token4] = ACTIONS(6815),
    [aux_sym_zero_directive_token5] = ACTIONS(6815),
    [aux_sym_zero_directive_token6] = ACTIONS(6815),
    [aux_sym_zero_directive_token7] = ACTIONS(6815),
    [aux_sym_zero_directive_token8] = ACTIONS(6815),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6815),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6815),
    [anon_sym_wire] = ACTIONS(6817),
    [anon_sym_tri] = ACTIONS(6817),
    [anon_sym_tri0] = ACTIONS(6817),
    [anon_sym_tri1] = ACTIONS(6817),
    [anon_sym_wand] = ACTIONS(6817),
    [anon_sym_triand] = ACTIONS(6817),
    [anon_sym_wor] = ACTIONS(6817),
    [anon_sym_trior] = ACTIONS(6817),
    [anon_sym_trireg] = ACTIONS(6817),
    [anon_sym_uwire] = ACTIONS(6817),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6815),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6815),
    [aux_sym_begin_keywords_token1] = ACTIONS(6815),
    [anon_sym_SEMI] = ACTIONS(6815),
    [anon_sym_endmodule] = ACTIONS(6817),
    [anon_sym_extern] = ACTIONS(6817),
    [anon_sym_module] = ACTIONS(6817),
    [anon_sym_macromodule] = ACTIONS(6817),
    [anon_sym_interface] = ACTIONS(6817),
    [anon_sym_program] = ACTIONS(6817),
    [anon_sym_checker] = ACTIONS(6817),
    [anon_sym_virtual] = ACTIONS(6817),
    [anon_sym_class] = ACTIONS(6817),
    [anon_sym_package] = ACTIONS(6817),
    [anon_sym_timeunit] = ACTIONS(6817),
    [anon_sym_timeprecision] = ACTIONS(6817),
    [anon_sym_type] = ACTIONS(6817),
    [anon_sym_input] = ACTIONS(6817),
    [anon_sym_output] = ACTIONS(6817),
    [anon_sym_inout] = ACTIONS(6817),
    [anon_sym_ref] = ACTIONS(6817),
    [anon_sym_DOLLARfatal] = ACTIONS(6815),
    [anon_sym_DOLLARerror] = ACTIONS(6815),
    [anon_sym_DOLLARwarning] = ACTIONS(6815),
    [anon_sym_DOLLARinfo] = ACTIONS(6815),
    [anon_sym_default] = ACTIONS(6817),
    [anon_sym_clocking] = ACTIONS(6817),
    [anon_sym_defparam] = ACTIONS(6817),
    [anon_sym_bind] = ACTIONS(6817),
    [anon_sym_const] = ACTIONS(6817),
    [anon_sym_function] = ACTIONS(6817),
    [anon_sym_static] = ACTIONS(6817),
    [anon_sym_constraint] = ACTIONS(6817),
    [anon_sym_if] = ACTIONS(6817),
    [anon_sym_LBRACK] = ACTIONS(6815),
    [anon_sym_localparam] = ACTIONS(6817),
    [anon_sym_parameter] = ACTIONS(6817),
    [anon_sym_specparam] = ACTIONS(6817),
    [anon_sym_var] = ACTIONS(6817),
    [anon_sym_import] = ACTIONS(6817),
    [anon_sym_export] = ACTIONS(6817),
    [anon_sym_genvar] = ACTIONS(6817),
    [anon_sym_interconnect] = ACTIONS(6817),
    [anon_sym_typedef] = ACTIONS(6817),
    [anon_sym_enum] = ACTIONS(6817),
    [anon_sym_struct] = ACTIONS(6817),
    [anon_sym_union] = ACTIONS(6817),
    [anon_sym_nettype] = ACTIONS(6817),
    [anon_sym_automatic] = ACTIONS(6817),
    [anon_sym_string] = ACTIONS(6817),
    [anon_sym_chandle] = ACTIONS(6817),
    [anon_sym_event] = ACTIONS(6817),
    [anon_sym_byte] = ACTIONS(6817),
    [anon_sym_shortint] = ACTIONS(6817),
    [anon_sym_int] = ACTIONS(6817),
    [anon_sym_longint] = ACTIONS(6817),
    [anon_sym_integer] = ACTIONS(6817),
    [anon_sym_time] = ACTIONS(6817),
    [anon_sym_bit] = ACTIONS(6817),
    [anon_sym_logic] = ACTIONS(6817),
    [anon_sym_reg] = ACTIONS(6817),
    [anon_sym_shortreal] = ACTIONS(6817),
    [anon_sym_real] = ACTIONS(6817),
    [anon_sym_realtime] = ACTIONS(6817),
    [anon_sym_supply0] = ACTIONS(6817),
    [anon_sym_supply1] = ACTIONS(6817),
    [anon_sym_signed] = ACTIONS(6817),
    [anon_sym_unsigned] = ACTIONS(6817),
    [anon_sym_task] = ACTIONS(6817),
    [anon_sym_assert] = ACTIONS(6817),
    [anon_sym_property] = ACTIONS(6817),
    [anon_sym_assume] = ACTIONS(6817),
    [anon_sym_cover] = ACTIONS(6817),
    [anon_sym_sequence] = ACTIONS(6817),
    [anon_sym_restrict] = ACTIONS(6817),
    [anon_sym_not] = ACTIONS(6817),
    [anon_sym_or] = ACTIONS(6817),
    [anon_sym_and] = ACTIONS(6817),
    [anon_sym_case] = ACTIONS(6817),
    [anon_sym_always] = ACTIONS(6817),
    [anon_sym_covergroup] = ACTIONS(6817),
    [anon_sym_let] = ACTIONS(6817),
    [anon_sym_pulldown] = ACTIONS(6817),
    [anon_sym_pullup] = ACTIONS(6817),
    [anon_sym_cmos] = ACTIONS(6817),
    [anon_sym_rcmos] = ACTIONS(6817),
    [anon_sym_bufif0] = ACTIONS(6817),
    [anon_sym_bufif1] = ACTIONS(6817),
    [anon_sym_notif0] = ACTIONS(6817),
    [anon_sym_notif1] = ACTIONS(6817),
    [anon_sym_nmos] = ACTIONS(6817),
    [anon_sym_pmos] = ACTIONS(6817),
    [anon_sym_rnmos] = ACTIONS(6817),
    [anon_sym_rpmos] = ACTIONS(6817),
    [anon_sym_nand] = ACTIONS(6817),
    [anon_sym_nor] = ACTIONS(6817),
    [anon_sym_xor] = ACTIONS(6817),
    [anon_sym_xnor] = ACTIONS(6817),
    [anon_sym_buf] = ACTIONS(6817),
    [anon_sym_tranif0] = ACTIONS(6817),
    [anon_sym_tranif1] = ACTIONS(6817),
    [anon_sym_rtranif1] = ACTIONS(6817),
    [anon_sym_rtranif0] = ACTIONS(6817),
    [anon_sym_tran] = ACTIONS(6817),
    [anon_sym_rtran] = ACTIONS(6817),
    [anon_sym_generate] = ACTIONS(6817),
    [anon_sym_for] = ACTIONS(6817),
    [anon_sym_primitive] = ACTIONS(6817),
    [anon_sym_initial] = ACTIONS(6817),
    [anon_sym_assign] = ACTIONS(6817),
    [anon_sym_alias] = ACTIONS(6817),
    [anon_sym_always_comb] = ACTIONS(6817),
    [anon_sym_always_latch] = ACTIONS(6817),
    [anon_sym_always_ff] = ACTIONS(6817),
    [anon_sym_final] = ACTIONS(6817),
    [anon_sym_global] = ACTIONS(6817),
    [anon_sym_specify] = ACTIONS(6817),
    [anon_sym_LPAREN_STAR] = ACTIONS(6815),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6815),
    [anon_sym_DOLLARunit] = ACTIONS(6815),
  },
  [1261] = {
    [ts_builtin_sym_end] = ACTIONS(6819),
    [sym_simple_identifier] = ACTIONS(6821),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6819),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6819),
    [anon_sym_BQUOTE] = ACTIONS(6821),
    [aux_sym_id_directive_token1] = ACTIONS(6819),
    [aux_sym_id_directive_token2] = ACTIONS(6819),
    [aux_sym_id_directive_token3] = ACTIONS(6819),
    [aux_sym_id_directive_token4] = ACTIONS(6821),
    [aux_sym_zero_directive_token1] = ACTIONS(6819),
    [aux_sym_zero_directive_token2] = ACTIONS(6819),
    [aux_sym_zero_directive_token3] = ACTIONS(6819),
    [aux_sym_zero_directive_token4] = ACTIONS(6819),
    [aux_sym_zero_directive_token5] = ACTIONS(6819),
    [aux_sym_zero_directive_token6] = ACTIONS(6819),
    [aux_sym_zero_directive_token7] = ACTIONS(6819),
    [aux_sym_zero_directive_token8] = ACTIONS(6819),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6819),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6819),
    [anon_sym_wire] = ACTIONS(6821),
    [anon_sym_tri] = ACTIONS(6821),
    [anon_sym_tri0] = ACTIONS(6821),
    [anon_sym_tri1] = ACTIONS(6821),
    [anon_sym_wand] = ACTIONS(6821),
    [anon_sym_triand] = ACTIONS(6821),
    [anon_sym_wor] = ACTIONS(6821),
    [anon_sym_trior] = ACTIONS(6821),
    [anon_sym_trireg] = ACTIONS(6821),
    [anon_sym_uwire] = ACTIONS(6821),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6819),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6819),
    [aux_sym_begin_keywords_token1] = ACTIONS(6819),
    [anon_sym_SEMI] = ACTIONS(6819),
    [anon_sym_endmodule] = ACTIONS(6821),
    [anon_sym_extern] = ACTIONS(6821),
    [anon_sym_module] = ACTIONS(6821),
    [anon_sym_macromodule] = ACTIONS(6821),
    [anon_sym_interface] = ACTIONS(6821),
    [anon_sym_program] = ACTIONS(6821),
    [anon_sym_checker] = ACTIONS(6821),
    [anon_sym_virtual] = ACTIONS(6821),
    [anon_sym_class] = ACTIONS(6821),
    [anon_sym_package] = ACTIONS(6821),
    [anon_sym_timeunit] = ACTIONS(6821),
    [anon_sym_timeprecision] = ACTIONS(6821),
    [anon_sym_type] = ACTIONS(6821),
    [anon_sym_input] = ACTIONS(6821),
    [anon_sym_output] = ACTIONS(6821),
    [anon_sym_inout] = ACTIONS(6821),
    [anon_sym_ref] = ACTIONS(6821),
    [anon_sym_DOLLARfatal] = ACTIONS(6819),
    [anon_sym_DOLLARerror] = ACTIONS(6819),
    [anon_sym_DOLLARwarning] = ACTIONS(6819),
    [anon_sym_DOLLARinfo] = ACTIONS(6819),
    [anon_sym_default] = ACTIONS(6821),
    [anon_sym_clocking] = ACTIONS(6821),
    [anon_sym_defparam] = ACTIONS(6821),
    [anon_sym_bind] = ACTIONS(6821),
    [anon_sym_const] = ACTIONS(6821),
    [anon_sym_function] = ACTIONS(6821),
    [anon_sym_static] = ACTIONS(6821),
    [anon_sym_constraint] = ACTIONS(6821),
    [anon_sym_if] = ACTIONS(6821),
    [anon_sym_LBRACK] = ACTIONS(6819),
    [anon_sym_localparam] = ACTIONS(6821),
    [anon_sym_parameter] = ACTIONS(6821),
    [anon_sym_specparam] = ACTIONS(6821),
    [anon_sym_var] = ACTIONS(6821),
    [anon_sym_import] = ACTIONS(6821),
    [anon_sym_export] = ACTIONS(6821),
    [anon_sym_genvar] = ACTIONS(6821),
    [anon_sym_interconnect] = ACTIONS(6821),
    [anon_sym_typedef] = ACTIONS(6821),
    [anon_sym_enum] = ACTIONS(6821),
    [anon_sym_struct] = ACTIONS(6821),
    [anon_sym_union] = ACTIONS(6821),
    [anon_sym_nettype] = ACTIONS(6821),
    [anon_sym_automatic] = ACTIONS(6821),
    [anon_sym_string] = ACTIONS(6821),
    [anon_sym_chandle] = ACTIONS(6821),
    [anon_sym_event] = ACTIONS(6821),
    [anon_sym_byte] = ACTIONS(6821),
    [anon_sym_shortint] = ACTIONS(6821),
    [anon_sym_int] = ACTIONS(6821),
    [anon_sym_longint] = ACTIONS(6821),
    [anon_sym_integer] = ACTIONS(6821),
    [anon_sym_time] = ACTIONS(6821),
    [anon_sym_bit] = ACTIONS(6821),
    [anon_sym_logic] = ACTIONS(6821),
    [anon_sym_reg] = ACTIONS(6821),
    [anon_sym_shortreal] = ACTIONS(6821),
    [anon_sym_real] = ACTIONS(6821),
    [anon_sym_realtime] = ACTIONS(6821),
    [anon_sym_supply0] = ACTIONS(6821),
    [anon_sym_supply1] = ACTIONS(6821),
    [anon_sym_signed] = ACTIONS(6821),
    [anon_sym_unsigned] = ACTIONS(6821),
    [anon_sym_task] = ACTIONS(6821),
    [anon_sym_assert] = ACTIONS(6821),
    [anon_sym_property] = ACTIONS(6821),
    [anon_sym_assume] = ACTIONS(6821),
    [anon_sym_cover] = ACTIONS(6821),
    [anon_sym_sequence] = ACTIONS(6821),
    [anon_sym_restrict] = ACTIONS(6821),
    [anon_sym_not] = ACTIONS(6821),
    [anon_sym_or] = ACTIONS(6821),
    [anon_sym_and] = ACTIONS(6821),
    [anon_sym_case] = ACTIONS(6821),
    [anon_sym_always] = ACTIONS(6821),
    [anon_sym_covergroup] = ACTIONS(6821),
    [anon_sym_let] = ACTIONS(6821),
    [anon_sym_pulldown] = ACTIONS(6821),
    [anon_sym_pullup] = ACTIONS(6821),
    [anon_sym_cmos] = ACTIONS(6821),
    [anon_sym_rcmos] = ACTIONS(6821),
    [anon_sym_bufif0] = ACTIONS(6821),
    [anon_sym_bufif1] = ACTIONS(6821),
    [anon_sym_notif0] = ACTIONS(6821),
    [anon_sym_notif1] = ACTIONS(6821),
    [anon_sym_nmos] = ACTIONS(6821),
    [anon_sym_pmos] = ACTIONS(6821),
    [anon_sym_rnmos] = ACTIONS(6821),
    [anon_sym_rpmos] = ACTIONS(6821),
    [anon_sym_nand] = ACTIONS(6821),
    [anon_sym_nor] = ACTIONS(6821),
    [anon_sym_xor] = ACTIONS(6821),
    [anon_sym_xnor] = ACTIONS(6821),
    [anon_sym_buf] = ACTIONS(6821),
    [anon_sym_tranif0] = ACTIONS(6821),
    [anon_sym_tranif1] = ACTIONS(6821),
    [anon_sym_rtranif1] = ACTIONS(6821),
    [anon_sym_rtranif0] = ACTIONS(6821),
    [anon_sym_tran] = ACTIONS(6821),
    [anon_sym_rtran] = ACTIONS(6821),
    [anon_sym_generate] = ACTIONS(6821),
    [anon_sym_for] = ACTIONS(6821),
    [anon_sym_primitive] = ACTIONS(6821),
    [anon_sym_initial] = ACTIONS(6821),
    [anon_sym_assign] = ACTIONS(6821),
    [anon_sym_alias] = ACTIONS(6821),
    [anon_sym_always_comb] = ACTIONS(6821),
    [anon_sym_always_latch] = ACTIONS(6821),
    [anon_sym_always_ff] = ACTIONS(6821),
    [anon_sym_final] = ACTIONS(6821),
    [anon_sym_global] = ACTIONS(6821),
    [anon_sym_specify] = ACTIONS(6821),
    [anon_sym_LPAREN_STAR] = ACTIONS(6819),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6819),
    [anon_sym_DOLLARunit] = ACTIONS(6819),
  },
  [1262] = {
    [ts_builtin_sym_end] = ACTIONS(6823),
    [sym_simple_identifier] = ACTIONS(6825),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6823),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6823),
    [anon_sym_BQUOTE] = ACTIONS(6825),
    [aux_sym_id_directive_token1] = ACTIONS(6823),
    [aux_sym_id_directive_token2] = ACTIONS(6823),
    [aux_sym_id_directive_token3] = ACTIONS(6823),
    [aux_sym_id_directive_token4] = ACTIONS(6825),
    [aux_sym_zero_directive_token1] = ACTIONS(6823),
    [aux_sym_zero_directive_token2] = ACTIONS(6823),
    [aux_sym_zero_directive_token3] = ACTIONS(6823),
    [aux_sym_zero_directive_token4] = ACTIONS(6823),
    [aux_sym_zero_directive_token5] = ACTIONS(6823),
    [aux_sym_zero_directive_token6] = ACTIONS(6823),
    [aux_sym_zero_directive_token7] = ACTIONS(6823),
    [aux_sym_zero_directive_token8] = ACTIONS(6823),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6823),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6823),
    [anon_sym_wire] = ACTIONS(6825),
    [anon_sym_tri] = ACTIONS(6825),
    [anon_sym_tri0] = ACTIONS(6825),
    [anon_sym_tri1] = ACTIONS(6825),
    [anon_sym_wand] = ACTIONS(6825),
    [anon_sym_triand] = ACTIONS(6825),
    [anon_sym_wor] = ACTIONS(6825),
    [anon_sym_trior] = ACTIONS(6825),
    [anon_sym_trireg] = ACTIONS(6825),
    [anon_sym_uwire] = ACTIONS(6825),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6823),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6823),
    [aux_sym_begin_keywords_token1] = ACTIONS(6823),
    [anon_sym_SEMI] = ACTIONS(6823),
    [anon_sym_endmodule] = ACTIONS(6825),
    [anon_sym_extern] = ACTIONS(6825),
    [anon_sym_module] = ACTIONS(6825),
    [anon_sym_macromodule] = ACTIONS(6825),
    [anon_sym_interface] = ACTIONS(6825),
    [anon_sym_program] = ACTIONS(6825),
    [anon_sym_checker] = ACTIONS(6825),
    [anon_sym_virtual] = ACTIONS(6825),
    [anon_sym_class] = ACTIONS(6825),
    [anon_sym_package] = ACTIONS(6825),
    [anon_sym_timeunit] = ACTIONS(6825),
    [anon_sym_timeprecision] = ACTIONS(6825),
    [anon_sym_type] = ACTIONS(6825),
    [anon_sym_input] = ACTIONS(6825),
    [anon_sym_output] = ACTIONS(6825),
    [anon_sym_inout] = ACTIONS(6825),
    [anon_sym_ref] = ACTIONS(6825),
    [anon_sym_DOLLARfatal] = ACTIONS(6823),
    [anon_sym_DOLLARerror] = ACTIONS(6823),
    [anon_sym_DOLLARwarning] = ACTIONS(6823),
    [anon_sym_DOLLARinfo] = ACTIONS(6823),
    [anon_sym_default] = ACTIONS(6825),
    [anon_sym_clocking] = ACTIONS(6825),
    [anon_sym_defparam] = ACTIONS(6825),
    [anon_sym_bind] = ACTIONS(6825),
    [anon_sym_const] = ACTIONS(6825),
    [anon_sym_function] = ACTIONS(6825),
    [anon_sym_static] = ACTIONS(6825),
    [anon_sym_constraint] = ACTIONS(6825),
    [anon_sym_if] = ACTIONS(6825),
    [anon_sym_LBRACK] = ACTIONS(6823),
    [anon_sym_localparam] = ACTIONS(6825),
    [anon_sym_parameter] = ACTIONS(6825),
    [anon_sym_specparam] = ACTIONS(6825),
    [anon_sym_var] = ACTIONS(6825),
    [anon_sym_import] = ACTIONS(6825),
    [anon_sym_export] = ACTIONS(6825),
    [anon_sym_genvar] = ACTIONS(6825),
    [anon_sym_interconnect] = ACTIONS(6825),
    [anon_sym_typedef] = ACTIONS(6825),
    [anon_sym_enum] = ACTIONS(6825),
    [anon_sym_struct] = ACTIONS(6825),
    [anon_sym_union] = ACTIONS(6825),
    [anon_sym_nettype] = ACTIONS(6825),
    [anon_sym_automatic] = ACTIONS(6825),
    [anon_sym_string] = ACTIONS(6825),
    [anon_sym_chandle] = ACTIONS(6825),
    [anon_sym_event] = ACTIONS(6825),
    [anon_sym_byte] = ACTIONS(6825),
    [anon_sym_shortint] = ACTIONS(6825),
    [anon_sym_int] = ACTIONS(6825),
    [anon_sym_longint] = ACTIONS(6825),
    [anon_sym_integer] = ACTIONS(6825),
    [anon_sym_time] = ACTIONS(6825),
    [anon_sym_bit] = ACTIONS(6825),
    [anon_sym_logic] = ACTIONS(6825),
    [anon_sym_reg] = ACTIONS(6825),
    [anon_sym_shortreal] = ACTIONS(6825),
    [anon_sym_real] = ACTIONS(6825),
    [anon_sym_realtime] = ACTIONS(6825),
    [anon_sym_supply0] = ACTIONS(6825),
    [anon_sym_supply1] = ACTIONS(6825),
    [anon_sym_signed] = ACTIONS(6825),
    [anon_sym_unsigned] = ACTIONS(6825),
    [anon_sym_task] = ACTIONS(6825),
    [anon_sym_assert] = ACTIONS(6825),
    [anon_sym_property] = ACTIONS(6825),
    [anon_sym_assume] = ACTIONS(6825),
    [anon_sym_cover] = ACTIONS(6825),
    [anon_sym_sequence] = ACTIONS(6825),
    [anon_sym_restrict] = ACTIONS(6825),
    [anon_sym_not] = ACTIONS(6825),
    [anon_sym_or] = ACTIONS(6825),
    [anon_sym_and] = ACTIONS(6825),
    [anon_sym_case] = ACTIONS(6825),
    [anon_sym_always] = ACTIONS(6825),
    [anon_sym_covergroup] = ACTIONS(6825),
    [anon_sym_let] = ACTIONS(6825),
    [anon_sym_pulldown] = ACTIONS(6825),
    [anon_sym_pullup] = ACTIONS(6825),
    [anon_sym_cmos] = ACTIONS(6825),
    [anon_sym_rcmos] = ACTIONS(6825),
    [anon_sym_bufif0] = ACTIONS(6825),
    [anon_sym_bufif1] = ACTIONS(6825),
    [anon_sym_notif0] = ACTIONS(6825),
    [anon_sym_notif1] = ACTIONS(6825),
    [anon_sym_nmos] = ACTIONS(6825),
    [anon_sym_pmos] = ACTIONS(6825),
    [anon_sym_rnmos] = ACTIONS(6825),
    [anon_sym_rpmos] = ACTIONS(6825),
    [anon_sym_nand] = ACTIONS(6825),
    [anon_sym_nor] = ACTIONS(6825),
    [anon_sym_xor] = ACTIONS(6825),
    [anon_sym_xnor] = ACTIONS(6825),
    [anon_sym_buf] = ACTIONS(6825),
    [anon_sym_tranif0] = ACTIONS(6825),
    [anon_sym_tranif1] = ACTIONS(6825),
    [anon_sym_rtranif1] = ACTIONS(6825),
    [anon_sym_rtranif0] = ACTIONS(6825),
    [anon_sym_tran] = ACTIONS(6825),
    [anon_sym_rtran] = ACTIONS(6825),
    [anon_sym_generate] = ACTIONS(6825),
    [anon_sym_for] = ACTIONS(6825),
    [anon_sym_primitive] = ACTIONS(6825),
    [anon_sym_initial] = ACTIONS(6825),
    [anon_sym_assign] = ACTIONS(6825),
    [anon_sym_alias] = ACTIONS(6825),
    [anon_sym_always_comb] = ACTIONS(6825),
    [anon_sym_always_latch] = ACTIONS(6825),
    [anon_sym_always_ff] = ACTIONS(6825),
    [anon_sym_final] = ACTIONS(6825),
    [anon_sym_global] = ACTIONS(6825),
    [anon_sym_specify] = ACTIONS(6825),
    [anon_sym_LPAREN_STAR] = ACTIONS(6823),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6823),
    [anon_sym_DOLLARunit] = ACTIONS(6823),
  },
  [1263] = {
    [ts_builtin_sym_end] = ACTIONS(6631),
    [sym_simple_identifier] = ACTIONS(6633),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6631),
    [anon_sym_BQUOTE] = ACTIONS(6633),
    [aux_sym_id_directive_token1] = ACTIONS(6631),
    [aux_sym_id_directive_token2] = ACTIONS(6631),
    [aux_sym_id_directive_token3] = ACTIONS(6631),
    [aux_sym_id_directive_token4] = ACTIONS(6633),
    [aux_sym_zero_directive_token1] = ACTIONS(6631),
    [aux_sym_zero_directive_token2] = ACTIONS(6631),
    [aux_sym_zero_directive_token3] = ACTIONS(6631),
    [aux_sym_zero_directive_token4] = ACTIONS(6631),
    [aux_sym_zero_directive_token5] = ACTIONS(6631),
    [aux_sym_zero_directive_token6] = ACTIONS(6631),
    [aux_sym_zero_directive_token7] = ACTIONS(6631),
    [aux_sym_zero_directive_token8] = ACTIONS(6631),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6631),
    [anon_sym_wire] = ACTIONS(6633),
    [anon_sym_tri] = ACTIONS(6633),
    [anon_sym_tri0] = ACTIONS(6633),
    [anon_sym_tri1] = ACTIONS(6633),
    [anon_sym_wand] = ACTIONS(6633),
    [anon_sym_triand] = ACTIONS(6633),
    [anon_sym_wor] = ACTIONS(6633),
    [anon_sym_trior] = ACTIONS(6633),
    [anon_sym_trireg] = ACTIONS(6633),
    [anon_sym_uwire] = ACTIONS(6633),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6631),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6631),
    [aux_sym_begin_keywords_token1] = ACTIONS(6631),
    [anon_sym_SEMI] = ACTIONS(6631),
    [anon_sym_endmodule] = ACTIONS(6633),
    [anon_sym_extern] = ACTIONS(6633),
    [anon_sym_module] = ACTIONS(6633),
    [anon_sym_macromodule] = ACTIONS(6633),
    [anon_sym_interface] = ACTIONS(6633),
    [anon_sym_program] = ACTIONS(6633),
    [anon_sym_checker] = ACTIONS(6633),
    [anon_sym_virtual] = ACTIONS(6633),
    [anon_sym_class] = ACTIONS(6633),
    [anon_sym_package] = ACTIONS(6633),
    [anon_sym_timeunit] = ACTIONS(6633),
    [anon_sym_timeprecision] = ACTIONS(6633),
    [anon_sym_type] = ACTIONS(6633),
    [anon_sym_input] = ACTIONS(6633),
    [anon_sym_output] = ACTIONS(6633),
    [anon_sym_inout] = ACTIONS(6633),
    [anon_sym_ref] = ACTIONS(6633),
    [anon_sym_DOLLARfatal] = ACTIONS(6631),
    [anon_sym_DOLLARerror] = ACTIONS(6631),
    [anon_sym_DOLLARwarning] = ACTIONS(6631),
    [anon_sym_DOLLARinfo] = ACTIONS(6631),
    [anon_sym_default] = ACTIONS(6633),
    [anon_sym_clocking] = ACTIONS(6633),
    [anon_sym_defparam] = ACTIONS(6633),
    [anon_sym_bind] = ACTIONS(6633),
    [anon_sym_const] = ACTIONS(6633),
    [anon_sym_function] = ACTIONS(6633),
    [anon_sym_static] = ACTIONS(6633),
    [anon_sym_constraint] = ACTIONS(6633),
    [anon_sym_if] = ACTIONS(6633),
    [anon_sym_LBRACK] = ACTIONS(6631),
    [anon_sym_localparam] = ACTIONS(6633),
    [anon_sym_parameter] = ACTIONS(6633),
    [anon_sym_specparam] = ACTIONS(6633),
    [anon_sym_var] = ACTIONS(6633),
    [anon_sym_import] = ACTIONS(6633),
    [anon_sym_export] = ACTIONS(6633),
    [anon_sym_genvar] = ACTIONS(6633),
    [anon_sym_interconnect] = ACTIONS(6633),
    [anon_sym_typedef] = ACTIONS(6633),
    [anon_sym_enum] = ACTIONS(6633),
    [anon_sym_struct] = ACTIONS(6633),
    [anon_sym_union] = ACTIONS(6633),
    [anon_sym_nettype] = ACTIONS(6633),
    [anon_sym_automatic] = ACTIONS(6633),
    [anon_sym_string] = ACTIONS(6633),
    [anon_sym_chandle] = ACTIONS(6633),
    [anon_sym_event] = ACTIONS(6633),
    [anon_sym_byte] = ACTIONS(6633),
    [anon_sym_shortint] = ACTIONS(6633),
    [anon_sym_int] = ACTIONS(6633),
    [anon_sym_longint] = ACTIONS(6633),
    [anon_sym_integer] = ACTIONS(6633),
    [anon_sym_time] = ACTIONS(6633),
    [anon_sym_bit] = ACTIONS(6633),
    [anon_sym_logic] = ACTIONS(6633),
    [anon_sym_reg] = ACTIONS(6633),
    [anon_sym_shortreal] = ACTIONS(6633),
    [anon_sym_real] = ACTIONS(6633),
    [anon_sym_realtime] = ACTIONS(6633),
    [anon_sym_supply0] = ACTIONS(6633),
    [anon_sym_supply1] = ACTIONS(6633),
    [anon_sym_signed] = ACTIONS(6633),
    [anon_sym_unsigned] = ACTIONS(6633),
    [anon_sym_task] = ACTIONS(6633),
    [anon_sym_assert] = ACTIONS(6633),
    [anon_sym_property] = ACTIONS(6633),
    [anon_sym_assume] = ACTIONS(6633),
    [anon_sym_cover] = ACTIONS(6633),
    [anon_sym_sequence] = ACTIONS(6633),
    [anon_sym_restrict] = ACTIONS(6633),
    [anon_sym_not] = ACTIONS(6633),
    [anon_sym_or] = ACTIONS(6633),
    [anon_sym_and] = ACTIONS(6633),
    [anon_sym_case] = ACTIONS(6633),
    [anon_sym_always] = ACTIONS(6633),
    [anon_sym_covergroup] = ACTIONS(6633),
    [anon_sym_let] = ACTIONS(6633),
    [anon_sym_pulldown] = ACTIONS(6633),
    [anon_sym_pullup] = ACTIONS(6633),
    [anon_sym_cmos] = ACTIONS(6633),
    [anon_sym_rcmos] = ACTIONS(6633),
    [anon_sym_bufif0] = ACTIONS(6633),
    [anon_sym_bufif1] = ACTIONS(6633),
    [anon_sym_notif0] = ACTIONS(6633),
    [anon_sym_notif1] = ACTIONS(6633),
    [anon_sym_nmos] = ACTIONS(6633),
    [anon_sym_pmos] = ACTIONS(6633),
    [anon_sym_rnmos] = ACTIONS(6633),
    [anon_sym_rpmos] = ACTIONS(6633),
    [anon_sym_nand] = ACTIONS(6633),
    [anon_sym_nor] = ACTIONS(6633),
    [anon_sym_xor] = ACTIONS(6633),
    [anon_sym_xnor] = ACTIONS(6633),
    [anon_sym_buf] = ACTIONS(6633),
    [anon_sym_tranif0] = ACTIONS(6633),
    [anon_sym_tranif1] = ACTIONS(6633),
    [anon_sym_rtranif1] = ACTIONS(6633),
    [anon_sym_rtranif0] = ACTIONS(6633),
    [anon_sym_tran] = ACTIONS(6633),
    [anon_sym_rtran] = ACTIONS(6633),
    [anon_sym_generate] = ACTIONS(6633),
    [anon_sym_for] = ACTIONS(6633),
    [anon_sym_primitive] = ACTIONS(6633),
    [anon_sym_initial] = ACTIONS(6633),
    [anon_sym_assign] = ACTIONS(6633),
    [anon_sym_alias] = ACTIONS(6633),
    [anon_sym_always_comb] = ACTIONS(6633),
    [anon_sym_always_latch] = ACTIONS(6633),
    [anon_sym_always_ff] = ACTIONS(6633),
    [anon_sym_final] = ACTIONS(6633),
    [anon_sym_global] = ACTIONS(6633),
    [anon_sym_specify] = ACTIONS(6633),
    [anon_sym_LPAREN_STAR] = ACTIONS(6631),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6631),
    [anon_sym_DOLLARunit] = ACTIONS(6631),
  },
  [1264] = {
    [ts_builtin_sym_end] = ACTIONS(6827),
    [sym_simple_identifier] = ACTIONS(6829),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6827),
    [anon_sym_BQUOTE] = ACTIONS(6829),
    [aux_sym_id_directive_token1] = ACTIONS(6827),
    [aux_sym_id_directive_token2] = ACTIONS(6827),
    [aux_sym_id_directive_token3] = ACTIONS(6827),
    [aux_sym_id_directive_token4] = ACTIONS(6829),
    [aux_sym_zero_directive_token1] = ACTIONS(6827),
    [aux_sym_zero_directive_token2] = ACTIONS(6827),
    [aux_sym_zero_directive_token3] = ACTIONS(6827),
    [aux_sym_zero_directive_token4] = ACTIONS(6827),
    [aux_sym_zero_directive_token5] = ACTIONS(6827),
    [aux_sym_zero_directive_token6] = ACTIONS(6827),
    [aux_sym_zero_directive_token7] = ACTIONS(6827),
    [aux_sym_zero_directive_token8] = ACTIONS(6827),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6827),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6827),
    [anon_sym_wire] = ACTIONS(6829),
    [anon_sym_tri] = ACTIONS(6829),
    [anon_sym_tri0] = ACTIONS(6829),
    [anon_sym_tri1] = ACTIONS(6829),
    [anon_sym_wand] = ACTIONS(6829),
    [anon_sym_triand] = ACTIONS(6829),
    [anon_sym_wor] = ACTIONS(6829),
    [anon_sym_trior] = ACTIONS(6829),
    [anon_sym_trireg] = ACTIONS(6829),
    [anon_sym_uwire] = ACTIONS(6829),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6827),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6827),
    [aux_sym_begin_keywords_token1] = ACTIONS(6827),
    [anon_sym_SEMI] = ACTIONS(6827),
    [anon_sym_endmodule] = ACTIONS(6829),
    [anon_sym_extern] = ACTIONS(6829),
    [anon_sym_module] = ACTIONS(6829),
    [anon_sym_macromodule] = ACTIONS(6829),
    [anon_sym_interface] = ACTIONS(6829),
    [anon_sym_program] = ACTIONS(6829),
    [anon_sym_checker] = ACTIONS(6829),
    [anon_sym_virtual] = ACTIONS(6829),
    [anon_sym_class] = ACTIONS(6829),
    [anon_sym_package] = ACTIONS(6829),
    [anon_sym_timeunit] = ACTIONS(6829),
    [anon_sym_timeprecision] = ACTIONS(6829),
    [anon_sym_type] = ACTIONS(6829),
    [anon_sym_input] = ACTIONS(6829),
    [anon_sym_output] = ACTIONS(6829),
    [anon_sym_inout] = ACTIONS(6829),
    [anon_sym_ref] = ACTIONS(6829),
    [anon_sym_DOLLARfatal] = ACTIONS(6827),
    [anon_sym_DOLLARerror] = ACTIONS(6827),
    [anon_sym_DOLLARwarning] = ACTIONS(6827),
    [anon_sym_DOLLARinfo] = ACTIONS(6827),
    [anon_sym_default] = ACTIONS(6829),
    [anon_sym_clocking] = ACTIONS(6829),
    [anon_sym_defparam] = ACTIONS(6829),
    [anon_sym_bind] = ACTIONS(6829),
    [anon_sym_const] = ACTIONS(6829),
    [anon_sym_function] = ACTIONS(6829),
    [anon_sym_static] = ACTIONS(6829),
    [anon_sym_constraint] = ACTIONS(6829),
    [anon_sym_if] = ACTIONS(6829),
    [anon_sym_LBRACK] = ACTIONS(6827),
    [anon_sym_localparam] = ACTIONS(6829),
    [anon_sym_parameter] = ACTIONS(6829),
    [anon_sym_specparam] = ACTIONS(6829),
    [anon_sym_var] = ACTIONS(6829),
    [anon_sym_import] = ACTIONS(6829),
    [anon_sym_export] = ACTIONS(6829),
    [anon_sym_genvar] = ACTIONS(6829),
    [anon_sym_interconnect] = ACTIONS(6829),
    [anon_sym_typedef] = ACTIONS(6829),
    [anon_sym_enum] = ACTIONS(6829),
    [anon_sym_struct] = ACTIONS(6829),
    [anon_sym_union] = ACTIONS(6829),
    [anon_sym_nettype] = ACTIONS(6829),
    [anon_sym_automatic] = ACTIONS(6829),
    [anon_sym_string] = ACTIONS(6829),
    [anon_sym_chandle] = ACTIONS(6829),
    [anon_sym_event] = ACTIONS(6829),
    [anon_sym_byte] = ACTIONS(6829),
    [anon_sym_shortint] = ACTIONS(6829),
    [anon_sym_int] = ACTIONS(6829),
    [anon_sym_longint] = ACTIONS(6829),
    [anon_sym_integer] = ACTIONS(6829),
    [anon_sym_time] = ACTIONS(6829),
    [anon_sym_bit] = ACTIONS(6829),
    [anon_sym_logic] = ACTIONS(6829),
    [anon_sym_reg] = ACTIONS(6829),
    [anon_sym_shortreal] = ACTIONS(6829),
    [anon_sym_real] = ACTIONS(6829),
    [anon_sym_realtime] = ACTIONS(6829),
    [anon_sym_supply0] = ACTIONS(6829),
    [anon_sym_supply1] = ACTIONS(6829),
    [anon_sym_signed] = ACTIONS(6829),
    [anon_sym_unsigned] = ACTIONS(6829),
    [anon_sym_task] = ACTIONS(6829),
    [anon_sym_assert] = ACTIONS(6829),
    [anon_sym_property] = ACTIONS(6829),
    [anon_sym_assume] = ACTIONS(6829),
    [anon_sym_cover] = ACTIONS(6829),
    [anon_sym_sequence] = ACTIONS(6829),
    [anon_sym_restrict] = ACTIONS(6829),
    [anon_sym_not] = ACTIONS(6829),
    [anon_sym_or] = ACTIONS(6829),
    [anon_sym_and] = ACTIONS(6829),
    [anon_sym_case] = ACTIONS(6829),
    [anon_sym_always] = ACTIONS(6829),
    [anon_sym_covergroup] = ACTIONS(6829),
    [anon_sym_let] = ACTIONS(6829),
    [anon_sym_pulldown] = ACTIONS(6829),
    [anon_sym_pullup] = ACTIONS(6829),
    [anon_sym_cmos] = ACTIONS(6829),
    [anon_sym_rcmos] = ACTIONS(6829),
    [anon_sym_bufif0] = ACTIONS(6829),
    [anon_sym_bufif1] = ACTIONS(6829),
    [anon_sym_notif0] = ACTIONS(6829),
    [anon_sym_notif1] = ACTIONS(6829),
    [anon_sym_nmos] = ACTIONS(6829),
    [anon_sym_pmos] = ACTIONS(6829),
    [anon_sym_rnmos] = ACTIONS(6829),
    [anon_sym_rpmos] = ACTIONS(6829),
    [anon_sym_nand] = ACTIONS(6829),
    [anon_sym_nor] = ACTIONS(6829),
    [anon_sym_xor] = ACTIONS(6829),
    [anon_sym_xnor] = ACTIONS(6829),
    [anon_sym_buf] = ACTIONS(6829),
    [anon_sym_tranif0] = ACTIONS(6829),
    [anon_sym_tranif1] = ACTIONS(6829),
    [anon_sym_rtranif1] = ACTIONS(6829),
    [anon_sym_rtranif0] = ACTIONS(6829),
    [anon_sym_tran] = ACTIONS(6829),
    [anon_sym_rtran] = ACTIONS(6829),
    [anon_sym_generate] = ACTIONS(6829),
    [anon_sym_for] = ACTIONS(6829),
    [anon_sym_primitive] = ACTIONS(6829),
    [anon_sym_initial] = ACTIONS(6829),
    [anon_sym_assign] = ACTIONS(6829),
    [anon_sym_alias] = ACTIONS(6829),
    [anon_sym_always_comb] = ACTIONS(6829),
    [anon_sym_always_latch] = ACTIONS(6829),
    [anon_sym_always_ff] = ACTIONS(6829),
    [anon_sym_final] = ACTIONS(6829),
    [anon_sym_global] = ACTIONS(6829),
    [anon_sym_specify] = ACTIONS(6829),
    [anon_sym_LPAREN_STAR] = ACTIONS(6827),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6827),
    [anon_sym_DOLLARunit] = ACTIONS(6827),
  },
  [1265] = {
    [ts_builtin_sym_end] = ACTIONS(6831),
    [sym_simple_identifier] = ACTIONS(6833),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6831),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6831),
    [anon_sym_BQUOTE] = ACTIONS(6833),
    [aux_sym_id_directive_token1] = ACTIONS(6831),
    [aux_sym_id_directive_token2] = ACTIONS(6831),
    [aux_sym_id_directive_token3] = ACTIONS(6831),
    [aux_sym_id_directive_token4] = ACTIONS(6833),
    [aux_sym_zero_directive_token1] = ACTIONS(6831),
    [aux_sym_zero_directive_token2] = ACTIONS(6831),
    [aux_sym_zero_directive_token3] = ACTIONS(6831),
    [aux_sym_zero_directive_token4] = ACTIONS(6831),
    [aux_sym_zero_directive_token5] = ACTIONS(6831),
    [aux_sym_zero_directive_token6] = ACTIONS(6831),
    [aux_sym_zero_directive_token7] = ACTIONS(6831),
    [aux_sym_zero_directive_token8] = ACTIONS(6831),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6831),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6831),
    [anon_sym_wire] = ACTIONS(6833),
    [anon_sym_tri] = ACTIONS(6833),
    [anon_sym_tri0] = ACTIONS(6833),
    [anon_sym_tri1] = ACTIONS(6833),
    [anon_sym_wand] = ACTIONS(6833),
    [anon_sym_triand] = ACTIONS(6833),
    [anon_sym_wor] = ACTIONS(6833),
    [anon_sym_trior] = ACTIONS(6833),
    [anon_sym_trireg] = ACTIONS(6833),
    [anon_sym_uwire] = ACTIONS(6833),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6831),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6831),
    [aux_sym_begin_keywords_token1] = ACTIONS(6831),
    [anon_sym_SEMI] = ACTIONS(6831),
    [anon_sym_endmodule] = ACTIONS(6833),
    [anon_sym_extern] = ACTIONS(6833),
    [anon_sym_module] = ACTIONS(6833),
    [anon_sym_macromodule] = ACTIONS(6833),
    [anon_sym_interface] = ACTIONS(6833),
    [anon_sym_program] = ACTIONS(6833),
    [anon_sym_checker] = ACTIONS(6833),
    [anon_sym_virtual] = ACTIONS(6833),
    [anon_sym_class] = ACTIONS(6833),
    [anon_sym_package] = ACTIONS(6833),
    [anon_sym_timeunit] = ACTIONS(6833),
    [anon_sym_timeprecision] = ACTIONS(6833),
    [anon_sym_type] = ACTIONS(6833),
    [anon_sym_input] = ACTIONS(6833),
    [anon_sym_output] = ACTIONS(6833),
    [anon_sym_inout] = ACTIONS(6833),
    [anon_sym_ref] = ACTIONS(6833),
    [anon_sym_DOLLARfatal] = ACTIONS(6831),
    [anon_sym_DOLLARerror] = ACTIONS(6831),
    [anon_sym_DOLLARwarning] = ACTIONS(6831),
    [anon_sym_DOLLARinfo] = ACTIONS(6831),
    [anon_sym_default] = ACTIONS(6833),
    [anon_sym_clocking] = ACTIONS(6833),
    [anon_sym_defparam] = ACTIONS(6833),
    [anon_sym_bind] = ACTIONS(6833),
    [anon_sym_const] = ACTIONS(6833),
    [anon_sym_function] = ACTIONS(6833),
    [anon_sym_static] = ACTIONS(6833),
    [anon_sym_constraint] = ACTIONS(6833),
    [anon_sym_if] = ACTIONS(6833),
    [anon_sym_LBRACK] = ACTIONS(6831),
    [anon_sym_localparam] = ACTIONS(6833),
    [anon_sym_parameter] = ACTIONS(6833),
    [anon_sym_specparam] = ACTIONS(6833),
    [anon_sym_var] = ACTIONS(6833),
    [anon_sym_import] = ACTIONS(6833),
    [anon_sym_export] = ACTIONS(6833),
    [anon_sym_genvar] = ACTIONS(6833),
    [anon_sym_interconnect] = ACTIONS(6833),
    [anon_sym_typedef] = ACTIONS(6833),
    [anon_sym_enum] = ACTIONS(6833),
    [anon_sym_struct] = ACTIONS(6833),
    [anon_sym_union] = ACTIONS(6833),
    [anon_sym_nettype] = ACTIONS(6833),
    [anon_sym_automatic] = ACTIONS(6833),
    [anon_sym_string] = ACTIONS(6833),
    [anon_sym_chandle] = ACTIONS(6833),
    [anon_sym_event] = ACTIONS(6833),
    [anon_sym_byte] = ACTIONS(6833),
    [anon_sym_shortint] = ACTIONS(6833),
    [anon_sym_int] = ACTIONS(6833),
    [anon_sym_longint] = ACTIONS(6833),
    [anon_sym_integer] = ACTIONS(6833),
    [anon_sym_time] = ACTIONS(6833),
    [anon_sym_bit] = ACTIONS(6833),
    [anon_sym_logic] = ACTIONS(6833),
    [anon_sym_reg] = ACTIONS(6833),
    [anon_sym_shortreal] = ACTIONS(6833),
    [anon_sym_real] = ACTIONS(6833),
    [anon_sym_realtime] = ACTIONS(6833),
    [anon_sym_supply0] = ACTIONS(6833),
    [anon_sym_supply1] = ACTIONS(6833),
    [anon_sym_signed] = ACTIONS(6833),
    [anon_sym_unsigned] = ACTIONS(6833),
    [anon_sym_task] = ACTIONS(6833),
    [anon_sym_assert] = ACTIONS(6833),
    [anon_sym_property] = ACTIONS(6833),
    [anon_sym_assume] = ACTIONS(6833),
    [anon_sym_cover] = ACTIONS(6833),
    [anon_sym_sequence] = ACTIONS(6833),
    [anon_sym_restrict] = ACTIONS(6833),
    [anon_sym_not] = ACTIONS(6833),
    [anon_sym_or] = ACTIONS(6833),
    [anon_sym_and] = ACTIONS(6833),
    [anon_sym_case] = ACTIONS(6833),
    [anon_sym_always] = ACTIONS(6833),
    [anon_sym_covergroup] = ACTIONS(6833),
    [anon_sym_let] = ACTIONS(6833),
    [anon_sym_pulldown] = ACTIONS(6833),
    [anon_sym_pullup] = ACTIONS(6833),
    [anon_sym_cmos] = ACTIONS(6833),
    [anon_sym_rcmos] = ACTIONS(6833),
    [anon_sym_bufif0] = ACTIONS(6833),
    [anon_sym_bufif1] = ACTIONS(6833),
    [anon_sym_notif0] = ACTIONS(6833),
    [anon_sym_notif1] = ACTIONS(6833),
    [anon_sym_nmos] = ACTIONS(6833),
    [anon_sym_pmos] = ACTIONS(6833),
    [anon_sym_rnmos] = ACTIONS(6833),
    [anon_sym_rpmos] = ACTIONS(6833),
    [anon_sym_nand] = ACTIONS(6833),
    [anon_sym_nor] = ACTIONS(6833),
    [anon_sym_xor] = ACTIONS(6833),
    [anon_sym_xnor] = ACTIONS(6833),
    [anon_sym_buf] = ACTIONS(6833),
    [anon_sym_tranif0] = ACTIONS(6833),
    [anon_sym_tranif1] = ACTIONS(6833),
    [anon_sym_rtranif1] = ACTIONS(6833),
    [anon_sym_rtranif0] = ACTIONS(6833),
    [anon_sym_tran] = ACTIONS(6833),
    [anon_sym_rtran] = ACTIONS(6833),
    [anon_sym_generate] = ACTIONS(6833),
    [anon_sym_for] = ACTIONS(6833),
    [anon_sym_primitive] = ACTIONS(6833),
    [anon_sym_initial] = ACTIONS(6833),
    [anon_sym_assign] = ACTIONS(6833),
    [anon_sym_alias] = ACTIONS(6833),
    [anon_sym_always_comb] = ACTIONS(6833),
    [anon_sym_always_latch] = ACTIONS(6833),
    [anon_sym_always_ff] = ACTIONS(6833),
    [anon_sym_final] = ACTIONS(6833),
    [anon_sym_global] = ACTIONS(6833),
    [anon_sym_specify] = ACTIONS(6833),
    [anon_sym_LPAREN_STAR] = ACTIONS(6831),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6831),
    [anon_sym_DOLLARunit] = ACTIONS(6831),
  },
  [1266] = {
    [ts_builtin_sym_end] = ACTIONS(6835),
    [sym_simple_identifier] = ACTIONS(6837),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6835),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6835),
    [anon_sym_BQUOTE] = ACTIONS(6837),
    [aux_sym_id_directive_token1] = ACTIONS(6835),
    [aux_sym_id_directive_token2] = ACTIONS(6835),
    [aux_sym_id_directive_token3] = ACTIONS(6835),
    [aux_sym_id_directive_token4] = ACTIONS(6837),
    [aux_sym_zero_directive_token1] = ACTIONS(6835),
    [aux_sym_zero_directive_token2] = ACTIONS(6835),
    [aux_sym_zero_directive_token3] = ACTIONS(6835),
    [aux_sym_zero_directive_token4] = ACTIONS(6835),
    [aux_sym_zero_directive_token5] = ACTIONS(6835),
    [aux_sym_zero_directive_token6] = ACTIONS(6835),
    [aux_sym_zero_directive_token7] = ACTIONS(6835),
    [aux_sym_zero_directive_token8] = ACTIONS(6835),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6835),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6835),
    [anon_sym_wire] = ACTIONS(6837),
    [anon_sym_tri] = ACTIONS(6837),
    [anon_sym_tri0] = ACTIONS(6837),
    [anon_sym_tri1] = ACTIONS(6837),
    [anon_sym_wand] = ACTIONS(6837),
    [anon_sym_triand] = ACTIONS(6837),
    [anon_sym_wor] = ACTIONS(6837),
    [anon_sym_trior] = ACTIONS(6837),
    [anon_sym_trireg] = ACTIONS(6837),
    [anon_sym_uwire] = ACTIONS(6837),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6835),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6835),
    [aux_sym_begin_keywords_token1] = ACTIONS(6835),
    [anon_sym_SEMI] = ACTIONS(6835),
    [anon_sym_endmodule] = ACTIONS(6837),
    [anon_sym_extern] = ACTIONS(6837),
    [anon_sym_module] = ACTIONS(6837),
    [anon_sym_macromodule] = ACTIONS(6837),
    [anon_sym_interface] = ACTIONS(6837),
    [anon_sym_program] = ACTIONS(6837),
    [anon_sym_checker] = ACTIONS(6837),
    [anon_sym_virtual] = ACTIONS(6837),
    [anon_sym_class] = ACTIONS(6837),
    [anon_sym_package] = ACTIONS(6837),
    [anon_sym_timeunit] = ACTIONS(6837),
    [anon_sym_timeprecision] = ACTIONS(6837),
    [anon_sym_type] = ACTIONS(6837),
    [anon_sym_input] = ACTIONS(6837),
    [anon_sym_output] = ACTIONS(6837),
    [anon_sym_inout] = ACTIONS(6837),
    [anon_sym_ref] = ACTIONS(6837),
    [anon_sym_DOLLARfatal] = ACTIONS(6835),
    [anon_sym_DOLLARerror] = ACTIONS(6835),
    [anon_sym_DOLLARwarning] = ACTIONS(6835),
    [anon_sym_DOLLARinfo] = ACTIONS(6835),
    [anon_sym_default] = ACTIONS(6837),
    [anon_sym_clocking] = ACTIONS(6837),
    [anon_sym_defparam] = ACTIONS(6837),
    [anon_sym_bind] = ACTIONS(6837),
    [anon_sym_const] = ACTIONS(6837),
    [anon_sym_function] = ACTIONS(6837),
    [anon_sym_static] = ACTIONS(6837),
    [anon_sym_constraint] = ACTIONS(6837),
    [anon_sym_if] = ACTIONS(6837),
    [anon_sym_LBRACK] = ACTIONS(6835),
    [anon_sym_localparam] = ACTIONS(6837),
    [anon_sym_parameter] = ACTIONS(6837),
    [anon_sym_specparam] = ACTIONS(6837),
    [anon_sym_var] = ACTIONS(6837),
    [anon_sym_import] = ACTIONS(6837),
    [anon_sym_export] = ACTIONS(6837),
    [anon_sym_genvar] = ACTIONS(6837),
    [anon_sym_interconnect] = ACTIONS(6837),
    [anon_sym_typedef] = ACTIONS(6837),
    [anon_sym_enum] = ACTIONS(6837),
    [anon_sym_struct] = ACTIONS(6837),
    [anon_sym_union] = ACTIONS(6837),
    [anon_sym_nettype] = ACTIONS(6837),
    [anon_sym_automatic] = ACTIONS(6837),
    [anon_sym_string] = ACTIONS(6837),
    [anon_sym_chandle] = ACTIONS(6837),
    [anon_sym_event] = ACTIONS(6837),
    [anon_sym_byte] = ACTIONS(6837),
    [anon_sym_shortint] = ACTIONS(6837),
    [anon_sym_int] = ACTIONS(6837),
    [anon_sym_longint] = ACTIONS(6837),
    [anon_sym_integer] = ACTIONS(6837),
    [anon_sym_time] = ACTIONS(6837),
    [anon_sym_bit] = ACTIONS(6837),
    [anon_sym_logic] = ACTIONS(6837),
    [anon_sym_reg] = ACTIONS(6837),
    [anon_sym_shortreal] = ACTIONS(6837),
    [anon_sym_real] = ACTIONS(6837),
    [anon_sym_realtime] = ACTIONS(6837),
    [anon_sym_supply0] = ACTIONS(6837),
    [anon_sym_supply1] = ACTIONS(6837),
    [anon_sym_signed] = ACTIONS(6837),
    [anon_sym_unsigned] = ACTIONS(6837),
    [anon_sym_task] = ACTIONS(6837),
    [anon_sym_assert] = ACTIONS(6837),
    [anon_sym_property] = ACTIONS(6837),
    [anon_sym_assume] = ACTIONS(6837),
    [anon_sym_cover] = ACTIONS(6837),
    [anon_sym_sequence] = ACTIONS(6837),
    [anon_sym_restrict] = ACTIONS(6837),
    [anon_sym_not] = ACTIONS(6837),
    [anon_sym_or] = ACTIONS(6837),
    [anon_sym_and] = ACTIONS(6837),
    [anon_sym_case] = ACTIONS(6837),
    [anon_sym_always] = ACTIONS(6837),
    [anon_sym_covergroup] = ACTIONS(6837),
    [anon_sym_let] = ACTIONS(6837),
    [anon_sym_pulldown] = ACTIONS(6837),
    [anon_sym_pullup] = ACTIONS(6837),
    [anon_sym_cmos] = ACTIONS(6837),
    [anon_sym_rcmos] = ACTIONS(6837),
    [anon_sym_bufif0] = ACTIONS(6837),
    [anon_sym_bufif1] = ACTIONS(6837),
    [anon_sym_notif0] = ACTIONS(6837),
    [anon_sym_notif1] = ACTIONS(6837),
    [anon_sym_nmos] = ACTIONS(6837),
    [anon_sym_pmos] = ACTIONS(6837),
    [anon_sym_rnmos] = ACTIONS(6837),
    [anon_sym_rpmos] = ACTIONS(6837),
    [anon_sym_nand] = ACTIONS(6837),
    [anon_sym_nor] = ACTIONS(6837),
    [anon_sym_xor] = ACTIONS(6837),
    [anon_sym_xnor] = ACTIONS(6837),
    [anon_sym_buf] = ACTIONS(6837),
    [anon_sym_tranif0] = ACTIONS(6837),
    [anon_sym_tranif1] = ACTIONS(6837),
    [anon_sym_rtranif1] = ACTIONS(6837),
    [anon_sym_rtranif0] = ACTIONS(6837),
    [anon_sym_tran] = ACTIONS(6837),
    [anon_sym_rtran] = ACTIONS(6837),
    [anon_sym_generate] = ACTIONS(6837),
    [anon_sym_for] = ACTIONS(6837),
    [anon_sym_primitive] = ACTIONS(6837),
    [anon_sym_initial] = ACTIONS(6837),
    [anon_sym_assign] = ACTIONS(6837),
    [anon_sym_alias] = ACTIONS(6837),
    [anon_sym_always_comb] = ACTIONS(6837),
    [anon_sym_always_latch] = ACTIONS(6837),
    [anon_sym_always_ff] = ACTIONS(6837),
    [anon_sym_final] = ACTIONS(6837),
    [anon_sym_global] = ACTIONS(6837),
    [anon_sym_specify] = ACTIONS(6837),
    [anon_sym_LPAREN_STAR] = ACTIONS(6835),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6835),
    [anon_sym_DOLLARunit] = ACTIONS(6835),
  },
  [1267] = {
    [ts_builtin_sym_end] = ACTIONS(6771),
    [sym_simple_identifier] = ACTIONS(6773),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6771),
    [anon_sym_BQUOTE] = ACTIONS(6773),
    [aux_sym_id_directive_token1] = ACTIONS(6771),
    [aux_sym_id_directive_token2] = ACTIONS(6771),
    [aux_sym_id_directive_token3] = ACTIONS(6771),
    [aux_sym_id_directive_token4] = ACTIONS(6773),
    [aux_sym_zero_directive_token1] = ACTIONS(6771),
    [aux_sym_zero_directive_token2] = ACTIONS(6771),
    [aux_sym_zero_directive_token3] = ACTIONS(6771),
    [aux_sym_zero_directive_token4] = ACTIONS(6771),
    [aux_sym_zero_directive_token5] = ACTIONS(6771),
    [aux_sym_zero_directive_token6] = ACTIONS(6771),
    [aux_sym_zero_directive_token7] = ACTIONS(6771),
    [aux_sym_zero_directive_token8] = ACTIONS(6771),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6771),
    [anon_sym_wire] = ACTIONS(6773),
    [anon_sym_tri] = ACTIONS(6773),
    [anon_sym_tri0] = ACTIONS(6773),
    [anon_sym_tri1] = ACTIONS(6773),
    [anon_sym_wand] = ACTIONS(6773),
    [anon_sym_triand] = ACTIONS(6773),
    [anon_sym_wor] = ACTIONS(6773),
    [anon_sym_trior] = ACTIONS(6773),
    [anon_sym_trireg] = ACTIONS(6773),
    [anon_sym_uwire] = ACTIONS(6773),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6771),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6771),
    [aux_sym_begin_keywords_token1] = ACTIONS(6771),
    [anon_sym_SEMI] = ACTIONS(6771),
    [anon_sym_endmodule] = ACTIONS(6773),
    [anon_sym_extern] = ACTIONS(6773),
    [anon_sym_module] = ACTIONS(6773),
    [anon_sym_macromodule] = ACTIONS(6773),
    [anon_sym_interface] = ACTIONS(6773),
    [anon_sym_program] = ACTIONS(6773),
    [anon_sym_checker] = ACTIONS(6773),
    [anon_sym_virtual] = ACTIONS(6773),
    [anon_sym_class] = ACTIONS(6773),
    [anon_sym_package] = ACTIONS(6773),
    [anon_sym_timeunit] = ACTIONS(6773),
    [anon_sym_timeprecision] = ACTIONS(6773),
    [anon_sym_type] = ACTIONS(6773),
    [anon_sym_input] = ACTIONS(6773),
    [anon_sym_output] = ACTIONS(6773),
    [anon_sym_inout] = ACTIONS(6773),
    [anon_sym_ref] = ACTIONS(6773),
    [anon_sym_DOLLARfatal] = ACTIONS(6771),
    [anon_sym_DOLLARerror] = ACTIONS(6771),
    [anon_sym_DOLLARwarning] = ACTIONS(6771),
    [anon_sym_DOLLARinfo] = ACTIONS(6771),
    [anon_sym_default] = ACTIONS(6773),
    [anon_sym_clocking] = ACTIONS(6773),
    [anon_sym_defparam] = ACTIONS(6773),
    [anon_sym_bind] = ACTIONS(6773),
    [anon_sym_const] = ACTIONS(6773),
    [anon_sym_function] = ACTIONS(6773),
    [anon_sym_static] = ACTIONS(6773),
    [anon_sym_constraint] = ACTIONS(6773),
    [anon_sym_if] = ACTIONS(6773),
    [anon_sym_LBRACK] = ACTIONS(6771),
    [anon_sym_localparam] = ACTIONS(6773),
    [anon_sym_parameter] = ACTIONS(6773),
    [anon_sym_specparam] = ACTIONS(6773),
    [anon_sym_var] = ACTIONS(6773),
    [anon_sym_import] = ACTIONS(6773),
    [anon_sym_export] = ACTIONS(6773),
    [anon_sym_genvar] = ACTIONS(6773),
    [anon_sym_interconnect] = ACTIONS(6773),
    [anon_sym_typedef] = ACTIONS(6773),
    [anon_sym_enum] = ACTIONS(6773),
    [anon_sym_struct] = ACTIONS(6773),
    [anon_sym_union] = ACTIONS(6773),
    [anon_sym_nettype] = ACTIONS(6773),
    [anon_sym_automatic] = ACTIONS(6773),
    [anon_sym_string] = ACTIONS(6773),
    [anon_sym_chandle] = ACTIONS(6773),
    [anon_sym_event] = ACTIONS(6773),
    [anon_sym_byte] = ACTIONS(6773),
    [anon_sym_shortint] = ACTIONS(6773),
    [anon_sym_int] = ACTIONS(6773),
    [anon_sym_longint] = ACTIONS(6773),
    [anon_sym_integer] = ACTIONS(6773),
    [anon_sym_time] = ACTIONS(6773),
    [anon_sym_bit] = ACTIONS(6773),
    [anon_sym_logic] = ACTIONS(6773),
    [anon_sym_reg] = ACTIONS(6773),
    [anon_sym_shortreal] = ACTIONS(6773),
    [anon_sym_real] = ACTIONS(6773),
    [anon_sym_realtime] = ACTIONS(6773),
    [anon_sym_supply0] = ACTIONS(6773),
    [anon_sym_supply1] = ACTIONS(6773),
    [anon_sym_signed] = ACTIONS(6773),
    [anon_sym_unsigned] = ACTIONS(6773),
    [anon_sym_task] = ACTIONS(6773),
    [anon_sym_assert] = ACTIONS(6773),
    [anon_sym_property] = ACTIONS(6773),
    [anon_sym_assume] = ACTIONS(6773),
    [anon_sym_cover] = ACTIONS(6773),
    [anon_sym_sequence] = ACTIONS(6773),
    [anon_sym_restrict] = ACTIONS(6773),
    [anon_sym_not] = ACTIONS(6773),
    [anon_sym_or] = ACTIONS(6773),
    [anon_sym_and] = ACTIONS(6773),
    [anon_sym_case] = ACTIONS(6773),
    [anon_sym_always] = ACTIONS(6773),
    [anon_sym_covergroup] = ACTIONS(6773),
    [anon_sym_let] = ACTIONS(6773),
    [anon_sym_pulldown] = ACTIONS(6773),
    [anon_sym_pullup] = ACTIONS(6773),
    [anon_sym_cmos] = ACTIONS(6773),
    [anon_sym_rcmos] = ACTIONS(6773),
    [anon_sym_bufif0] = ACTIONS(6773),
    [anon_sym_bufif1] = ACTIONS(6773),
    [anon_sym_notif0] = ACTIONS(6773),
    [anon_sym_notif1] = ACTIONS(6773),
    [anon_sym_nmos] = ACTIONS(6773),
    [anon_sym_pmos] = ACTIONS(6773),
    [anon_sym_rnmos] = ACTIONS(6773),
    [anon_sym_rpmos] = ACTIONS(6773),
    [anon_sym_nand] = ACTIONS(6773),
    [anon_sym_nor] = ACTIONS(6773),
    [anon_sym_xor] = ACTIONS(6773),
    [anon_sym_xnor] = ACTIONS(6773),
    [anon_sym_buf] = ACTIONS(6773),
    [anon_sym_tranif0] = ACTIONS(6773),
    [anon_sym_tranif1] = ACTIONS(6773),
    [anon_sym_rtranif1] = ACTIONS(6773),
    [anon_sym_rtranif0] = ACTIONS(6773),
    [anon_sym_tran] = ACTIONS(6773),
    [anon_sym_rtran] = ACTIONS(6773),
    [anon_sym_generate] = ACTIONS(6773),
    [anon_sym_for] = ACTIONS(6773),
    [anon_sym_primitive] = ACTIONS(6773),
    [anon_sym_initial] = ACTIONS(6773),
    [anon_sym_assign] = ACTIONS(6773),
    [anon_sym_alias] = ACTIONS(6773),
    [anon_sym_always_comb] = ACTIONS(6773),
    [anon_sym_always_latch] = ACTIONS(6773),
    [anon_sym_always_ff] = ACTIONS(6773),
    [anon_sym_final] = ACTIONS(6773),
    [anon_sym_global] = ACTIONS(6773),
    [anon_sym_specify] = ACTIONS(6773),
    [anon_sym_LPAREN_STAR] = ACTIONS(6771),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6771),
    [anon_sym_DOLLARunit] = ACTIONS(6771),
  },
  [1268] = {
    [ts_builtin_sym_end] = ACTIONS(6839),
    [sym_simple_identifier] = ACTIONS(6841),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6839),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6839),
    [anon_sym_BQUOTE] = ACTIONS(6841),
    [aux_sym_id_directive_token1] = ACTIONS(6839),
    [aux_sym_id_directive_token2] = ACTIONS(6839),
    [aux_sym_id_directive_token3] = ACTIONS(6839),
    [aux_sym_id_directive_token4] = ACTIONS(6841),
    [aux_sym_zero_directive_token1] = ACTIONS(6839),
    [aux_sym_zero_directive_token2] = ACTIONS(6839),
    [aux_sym_zero_directive_token3] = ACTIONS(6839),
    [aux_sym_zero_directive_token4] = ACTIONS(6839),
    [aux_sym_zero_directive_token5] = ACTIONS(6839),
    [aux_sym_zero_directive_token6] = ACTIONS(6839),
    [aux_sym_zero_directive_token7] = ACTIONS(6839),
    [aux_sym_zero_directive_token8] = ACTIONS(6839),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6839),
    [anon_sym_wire] = ACTIONS(6841),
    [anon_sym_tri] = ACTIONS(6841),
    [anon_sym_tri0] = ACTIONS(6841),
    [anon_sym_tri1] = ACTIONS(6841),
    [anon_sym_wand] = ACTIONS(6841),
    [anon_sym_triand] = ACTIONS(6841),
    [anon_sym_wor] = ACTIONS(6841),
    [anon_sym_trior] = ACTIONS(6841),
    [anon_sym_trireg] = ACTIONS(6841),
    [anon_sym_uwire] = ACTIONS(6841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6839),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6839),
    [aux_sym_begin_keywords_token1] = ACTIONS(6839),
    [anon_sym_SEMI] = ACTIONS(6839),
    [anon_sym_endmodule] = ACTIONS(6841),
    [anon_sym_extern] = ACTIONS(6841),
    [anon_sym_module] = ACTIONS(6841),
    [anon_sym_macromodule] = ACTIONS(6841),
    [anon_sym_interface] = ACTIONS(6841),
    [anon_sym_program] = ACTIONS(6841),
    [anon_sym_checker] = ACTIONS(6841),
    [anon_sym_virtual] = ACTIONS(6841),
    [anon_sym_class] = ACTIONS(6841),
    [anon_sym_package] = ACTIONS(6841),
    [anon_sym_timeunit] = ACTIONS(6841),
    [anon_sym_timeprecision] = ACTIONS(6841),
    [anon_sym_type] = ACTIONS(6841),
    [anon_sym_input] = ACTIONS(6841),
    [anon_sym_output] = ACTIONS(6841),
    [anon_sym_inout] = ACTIONS(6841),
    [anon_sym_ref] = ACTIONS(6841),
    [anon_sym_DOLLARfatal] = ACTIONS(6839),
    [anon_sym_DOLLARerror] = ACTIONS(6839),
    [anon_sym_DOLLARwarning] = ACTIONS(6839),
    [anon_sym_DOLLARinfo] = ACTIONS(6839),
    [anon_sym_default] = ACTIONS(6841),
    [anon_sym_clocking] = ACTIONS(6841),
    [anon_sym_defparam] = ACTIONS(6841),
    [anon_sym_bind] = ACTIONS(6841),
    [anon_sym_const] = ACTIONS(6841),
    [anon_sym_function] = ACTIONS(6841),
    [anon_sym_static] = ACTIONS(6841),
    [anon_sym_constraint] = ACTIONS(6841),
    [anon_sym_if] = ACTIONS(6841),
    [anon_sym_LBRACK] = ACTIONS(6839),
    [anon_sym_localparam] = ACTIONS(6841),
    [anon_sym_parameter] = ACTIONS(6841),
    [anon_sym_specparam] = ACTIONS(6841),
    [anon_sym_var] = ACTIONS(6841),
    [anon_sym_import] = ACTIONS(6841),
    [anon_sym_export] = ACTIONS(6841),
    [anon_sym_genvar] = ACTIONS(6841),
    [anon_sym_interconnect] = ACTIONS(6841),
    [anon_sym_typedef] = ACTIONS(6841),
    [anon_sym_enum] = ACTIONS(6841),
    [anon_sym_struct] = ACTIONS(6841),
    [anon_sym_union] = ACTIONS(6841),
    [anon_sym_nettype] = ACTIONS(6841),
    [anon_sym_automatic] = ACTIONS(6841),
    [anon_sym_string] = ACTIONS(6841),
    [anon_sym_chandle] = ACTIONS(6841),
    [anon_sym_event] = ACTIONS(6841),
    [anon_sym_byte] = ACTIONS(6841),
    [anon_sym_shortint] = ACTIONS(6841),
    [anon_sym_int] = ACTIONS(6841),
    [anon_sym_longint] = ACTIONS(6841),
    [anon_sym_integer] = ACTIONS(6841),
    [anon_sym_time] = ACTIONS(6841),
    [anon_sym_bit] = ACTIONS(6841),
    [anon_sym_logic] = ACTIONS(6841),
    [anon_sym_reg] = ACTIONS(6841),
    [anon_sym_shortreal] = ACTIONS(6841),
    [anon_sym_real] = ACTIONS(6841),
    [anon_sym_realtime] = ACTIONS(6841),
    [anon_sym_supply0] = ACTIONS(6841),
    [anon_sym_supply1] = ACTIONS(6841),
    [anon_sym_signed] = ACTIONS(6841),
    [anon_sym_unsigned] = ACTIONS(6841),
    [anon_sym_task] = ACTIONS(6841),
    [anon_sym_assert] = ACTIONS(6841),
    [anon_sym_property] = ACTIONS(6841),
    [anon_sym_assume] = ACTIONS(6841),
    [anon_sym_cover] = ACTIONS(6841),
    [anon_sym_sequence] = ACTIONS(6841),
    [anon_sym_restrict] = ACTIONS(6841),
    [anon_sym_not] = ACTIONS(6841),
    [anon_sym_or] = ACTIONS(6841),
    [anon_sym_and] = ACTIONS(6841),
    [anon_sym_case] = ACTIONS(6841),
    [anon_sym_always] = ACTIONS(6841),
    [anon_sym_covergroup] = ACTIONS(6841),
    [anon_sym_let] = ACTIONS(6841),
    [anon_sym_pulldown] = ACTIONS(6841),
    [anon_sym_pullup] = ACTIONS(6841),
    [anon_sym_cmos] = ACTIONS(6841),
    [anon_sym_rcmos] = ACTIONS(6841),
    [anon_sym_bufif0] = ACTIONS(6841),
    [anon_sym_bufif1] = ACTIONS(6841),
    [anon_sym_notif0] = ACTIONS(6841),
    [anon_sym_notif1] = ACTIONS(6841),
    [anon_sym_nmos] = ACTIONS(6841),
    [anon_sym_pmos] = ACTIONS(6841),
    [anon_sym_rnmos] = ACTIONS(6841),
    [anon_sym_rpmos] = ACTIONS(6841),
    [anon_sym_nand] = ACTIONS(6841),
    [anon_sym_nor] = ACTIONS(6841),
    [anon_sym_xor] = ACTIONS(6841),
    [anon_sym_xnor] = ACTIONS(6841),
    [anon_sym_buf] = ACTIONS(6841),
    [anon_sym_tranif0] = ACTIONS(6841),
    [anon_sym_tranif1] = ACTIONS(6841),
    [anon_sym_rtranif1] = ACTIONS(6841),
    [anon_sym_rtranif0] = ACTIONS(6841),
    [anon_sym_tran] = ACTIONS(6841),
    [anon_sym_rtran] = ACTIONS(6841),
    [anon_sym_generate] = ACTIONS(6841),
    [anon_sym_for] = ACTIONS(6841),
    [anon_sym_primitive] = ACTIONS(6841),
    [anon_sym_initial] = ACTIONS(6841),
    [anon_sym_assign] = ACTIONS(6841),
    [anon_sym_alias] = ACTIONS(6841),
    [anon_sym_always_comb] = ACTIONS(6841),
    [anon_sym_always_latch] = ACTIONS(6841),
    [anon_sym_always_ff] = ACTIONS(6841),
    [anon_sym_final] = ACTIONS(6841),
    [anon_sym_global] = ACTIONS(6841),
    [anon_sym_specify] = ACTIONS(6841),
    [anon_sym_LPAREN_STAR] = ACTIONS(6839),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6839),
    [anon_sym_DOLLARunit] = ACTIONS(6839),
  },
  [1269] = {
    [ts_builtin_sym_end] = ACTIONS(6843),
    [sym_simple_identifier] = ACTIONS(6845),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6843),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6843),
    [anon_sym_BQUOTE] = ACTIONS(6845),
    [aux_sym_id_directive_token1] = ACTIONS(6843),
    [aux_sym_id_directive_token2] = ACTIONS(6843),
    [aux_sym_id_directive_token3] = ACTIONS(6843),
    [aux_sym_id_directive_token4] = ACTIONS(6845),
    [aux_sym_zero_directive_token1] = ACTIONS(6843),
    [aux_sym_zero_directive_token2] = ACTIONS(6843),
    [aux_sym_zero_directive_token3] = ACTIONS(6843),
    [aux_sym_zero_directive_token4] = ACTIONS(6843),
    [aux_sym_zero_directive_token5] = ACTIONS(6843),
    [aux_sym_zero_directive_token6] = ACTIONS(6843),
    [aux_sym_zero_directive_token7] = ACTIONS(6843),
    [aux_sym_zero_directive_token8] = ACTIONS(6843),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6843),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6843),
    [anon_sym_wire] = ACTIONS(6845),
    [anon_sym_tri] = ACTIONS(6845),
    [anon_sym_tri0] = ACTIONS(6845),
    [anon_sym_tri1] = ACTIONS(6845),
    [anon_sym_wand] = ACTIONS(6845),
    [anon_sym_triand] = ACTIONS(6845),
    [anon_sym_wor] = ACTIONS(6845),
    [anon_sym_trior] = ACTIONS(6845),
    [anon_sym_trireg] = ACTIONS(6845),
    [anon_sym_uwire] = ACTIONS(6845),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6843),
    [aux_sym_begin_keywords_token1] = ACTIONS(6843),
    [anon_sym_SEMI] = ACTIONS(6843),
    [anon_sym_endmodule] = ACTIONS(6845),
    [anon_sym_extern] = ACTIONS(6845),
    [anon_sym_module] = ACTIONS(6845),
    [anon_sym_macromodule] = ACTIONS(6845),
    [anon_sym_interface] = ACTIONS(6845),
    [anon_sym_program] = ACTIONS(6845),
    [anon_sym_checker] = ACTIONS(6845),
    [anon_sym_virtual] = ACTIONS(6845),
    [anon_sym_class] = ACTIONS(6845),
    [anon_sym_package] = ACTIONS(6845),
    [anon_sym_timeunit] = ACTIONS(6845),
    [anon_sym_timeprecision] = ACTIONS(6845),
    [anon_sym_type] = ACTIONS(6845),
    [anon_sym_input] = ACTIONS(6845),
    [anon_sym_output] = ACTIONS(6845),
    [anon_sym_inout] = ACTIONS(6845),
    [anon_sym_ref] = ACTIONS(6845),
    [anon_sym_DOLLARfatal] = ACTIONS(6843),
    [anon_sym_DOLLARerror] = ACTIONS(6843),
    [anon_sym_DOLLARwarning] = ACTIONS(6843),
    [anon_sym_DOLLARinfo] = ACTIONS(6843),
    [anon_sym_default] = ACTIONS(6845),
    [anon_sym_clocking] = ACTIONS(6845),
    [anon_sym_defparam] = ACTIONS(6845),
    [anon_sym_bind] = ACTIONS(6845),
    [anon_sym_const] = ACTIONS(6845),
    [anon_sym_function] = ACTIONS(6845),
    [anon_sym_static] = ACTIONS(6845),
    [anon_sym_constraint] = ACTIONS(6845),
    [anon_sym_if] = ACTIONS(6845),
    [anon_sym_LBRACK] = ACTIONS(6843),
    [anon_sym_localparam] = ACTIONS(6845),
    [anon_sym_parameter] = ACTIONS(6845),
    [anon_sym_specparam] = ACTIONS(6845),
    [anon_sym_var] = ACTIONS(6845),
    [anon_sym_import] = ACTIONS(6845),
    [anon_sym_export] = ACTIONS(6845),
    [anon_sym_genvar] = ACTIONS(6845),
    [anon_sym_interconnect] = ACTIONS(6845),
    [anon_sym_typedef] = ACTIONS(6845),
    [anon_sym_enum] = ACTIONS(6845),
    [anon_sym_struct] = ACTIONS(6845),
    [anon_sym_union] = ACTIONS(6845),
    [anon_sym_nettype] = ACTIONS(6845),
    [anon_sym_automatic] = ACTIONS(6845),
    [anon_sym_string] = ACTIONS(6845),
    [anon_sym_chandle] = ACTIONS(6845),
    [anon_sym_event] = ACTIONS(6845),
    [anon_sym_byte] = ACTIONS(6845),
    [anon_sym_shortint] = ACTIONS(6845),
    [anon_sym_int] = ACTIONS(6845),
    [anon_sym_longint] = ACTIONS(6845),
    [anon_sym_integer] = ACTIONS(6845),
    [anon_sym_time] = ACTIONS(6845),
    [anon_sym_bit] = ACTIONS(6845),
    [anon_sym_logic] = ACTIONS(6845),
    [anon_sym_reg] = ACTIONS(6845),
    [anon_sym_shortreal] = ACTIONS(6845),
    [anon_sym_real] = ACTIONS(6845),
    [anon_sym_realtime] = ACTIONS(6845),
    [anon_sym_supply0] = ACTIONS(6845),
    [anon_sym_supply1] = ACTIONS(6845),
    [anon_sym_signed] = ACTIONS(6845),
    [anon_sym_unsigned] = ACTIONS(6845),
    [anon_sym_task] = ACTIONS(6845),
    [anon_sym_assert] = ACTIONS(6845),
    [anon_sym_property] = ACTIONS(6845),
    [anon_sym_assume] = ACTIONS(6845),
    [anon_sym_cover] = ACTIONS(6845),
    [anon_sym_sequence] = ACTIONS(6845),
    [anon_sym_restrict] = ACTIONS(6845),
    [anon_sym_not] = ACTIONS(6845),
    [anon_sym_or] = ACTIONS(6845),
    [anon_sym_and] = ACTIONS(6845),
    [anon_sym_case] = ACTIONS(6845),
    [anon_sym_always] = ACTIONS(6845),
    [anon_sym_covergroup] = ACTIONS(6845),
    [anon_sym_let] = ACTIONS(6845),
    [anon_sym_pulldown] = ACTIONS(6845),
    [anon_sym_pullup] = ACTIONS(6845),
    [anon_sym_cmos] = ACTIONS(6845),
    [anon_sym_rcmos] = ACTIONS(6845),
    [anon_sym_bufif0] = ACTIONS(6845),
    [anon_sym_bufif1] = ACTIONS(6845),
    [anon_sym_notif0] = ACTIONS(6845),
    [anon_sym_notif1] = ACTIONS(6845),
    [anon_sym_nmos] = ACTIONS(6845),
    [anon_sym_pmos] = ACTIONS(6845),
    [anon_sym_rnmos] = ACTIONS(6845),
    [anon_sym_rpmos] = ACTIONS(6845),
    [anon_sym_nand] = ACTIONS(6845),
    [anon_sym_nor] = ACTIONS(6845),
    [anon_sym_xor] = ACTIONS(6845),
    [anon_sym_xnor] = ACTIONS(6845),
    [anon_sym_buf] = ACTIONS(6845),
    [anon_sym_tranif0] = ACTIONS(6845),
    [anon_sym_tranif1] = ACTIONS(6845),
    [anon_sym_rtranif1] = ACTIONS(6845),
    [anon_sym_rtranif0] = ACTIONS(6845),
    [anon_sym_tran] = ACTIONS(6845),
    [anon_sym_rtran] = ACTIONS(6845),
    [anon_sym_generate] = ACTIONS(6845),
    [anon_sym_for] = ACTIONS(6845),
    [anon_sym_primitive] = ACTIONS(6845),
    [anon_sym_initial] = ACTIONS(6845),
    [anon_sym_assign] = ACTIONS(6845),
    [anon_sym_alias] = ACTIONS(6845),
    [anon_sym_always_comb] = ACTIONS(6845),
    [anon_sym_always_latch] = ACTIONS(6845),
    [anon_sym_always_ff] = ACTIONS(6845),
    [anon_sym_final] = ACTIONS(6845),
    [anon_sym_global] = ACTIONS(6845),
    [anon_sym_specify] = ACTIONS(6845),
    [anon_sym_LPAREN_STAR] = ACTIONS(6843),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6843),
    [anon_sym_DOLLARunit] = ACTIONS(6843),
  },
  [1270] = {
    [ts_builtin_sym_end] = ACTIONS(6847),
    [sym_simple_identifier] = ACTIONS(6849),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6847),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6847),
    [anon_sym_BQUOTE] = ACTIONS(6849),
    [aux_sym_id_directive_token1] = ACTIONS(6847),
    [aux_sym_id_directive_token2] = ACTIONS(6847),
    [aux_sym_id_directive_token3] = ACTIONS(6847),
    [aux_sym_id_directive_token4] = ACTIONS(6849),
    [aux_sym_zero_directive_token1] = ACTIONS(6847),
    [aux_sym_zero_directive_token2] = ACTIONS(6847),
    [aux_sym_zero_directive_token3] = ACTIONS(6847),
    [aux_sym_zero_directive_token4] = ACTIONS(6847),
    [aux_sym_zero_directive_token5] = ACTIONS(6847),
    [aux_sym_zero_directive_token6] = ACTIONS(6847),
    [aux_sym_zero_directive_token7] = ACTIONS(6847),
    [aux_sym_zero_directive_token8] = ACTIONS(6847),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6847),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6847),
    [anon_sym_wire] = ACTIONS(6849),
    [anon_sym_tri] = ACTIONS(6849),
    [anon_sym_tri0] = ACTIONS(6849),
    [anon_sym_tri1] = ACTIONS(6849),
    [anon_sym_wand] = ACTIONS(6849),
    [anon_sym_triand] = ACTIONS(6849),
    [anon_sym_wor] = ACTIONS(6849),
    [anon_sym_trior] = ACTIONS(6849),
    [anon_sym_trireg] = ACTIONS(6849),
    [anon_sym_uwire] = ACTIONS(6849),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6847),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6847),
    [aux_sym_begin_keywords_token1] = ACTIONS(6847),
    [anon_sym_SEMI] = ACTIONS(6847),
    [anon_sym_endmodule] = ACTIONS(6849),
    [anon_sym_extern] = ACTIONS(6849),
    [anon_sym_module] = ACTIONS(6849),
    [anon_sym_macromodule] = ACTIONS(6849),
    [anon_sym_interface] = ACTIONS(6849),
    [anon_sym_program] = ACTIONS(6849),
    [anon_sym_checker] = ACTIONS(6849),
    [anon_sym_virtual] = ACTIONS(6849),
    [anon_sym_class] = ACTIONS(6849),
    [anon_sym_package] = ACTIONS(6849),
    [anon_sym_timeunit] = ACTIONS(6849),
    [anon_sym_timeprecision] = ACTIONS(6849),
    [anon_sym_type] = ACTIONS(6849),
    [anon_sym_input] = ACTIONS(6849),
    [anon_sym_output] = ACTIONS(6849),
    [anon_sym_inout] = ACTIONS(6849),
    [anon_sym_ref] = ACTIONS(6849),
    [anon_sym_DOLLARfatal] = ACTIONS(6847),
    [anon_sym_DOLLARerror] = ACTIONS(6847),
    [anon_sym_DOLLARwarning] = ACTIONS(6847),
    [anon_sym_DOLLARinfo] = ACTIONS(6847),
    [anon_sym_default] = ACTIONS(6849),
    [anon_sym_clocking] = ACTIONS(6849),
    [anon_sym_defparam] = ACTIONS(6849),
    [anon_sym_bind] = ACTIONS(6849),
    [anon_sym_const] = ACTIONS(6849),
    [anon_sym_function] = ACTIONS(6849),
    [anon_sym_static] = ACTIONS(6849),
    [anon_sym_constraint] = ACTIONS(6849),
    [anon_sym_if] = ACTIONS(6849),
    [anon_sym_LBRACK] = ACTIONS(6847),
    [anon_sym_localparam] = ACTIONS(6849),
    [anon_sym_parameter] = ACTIONS(6849),
    [anon_sym_specparam] = ACTIONS(6849),
    [anon_sym_var] = ACTIONS(6849),
    [anon_sym_import] = ACTIONS(6849),
    [anon_sym_export] = ACTIONS(6849),
    [anon_sym_genvar] = ACTIONS(6849),
    [anon_sym_interconnect] = ACTIONS(6849),
    [anon_sym_typedef] = ACTIONS(6849),
    [anon_sym_enum] = ACTIONS(6849),
    [anon_sym_struct] = ACTIONS(6849),
    [anon_sym_union] = ACTIONS(6849),
    [anon_sym_nettype] = ACTIONS(6849),
    [anon_sym_automatic] = ACTIONS(6849),
    [anon_sym_string] = ACTIONS(6849),
    [anon_sym_chandle] = ACTIONS(6849),
    [anon_sym_event] = ACTIONS(6849),
    [anon_sym_byte] = ACTIONS(6849),
    [anon_sym_shortint] = ACTIONS(6849),
    [anon_sym_int] = ACTIONS(6849),
    [anon_sym_longint] = ACTIONS(6849),
    [anon_sym_integer] = ACTIONS(6849),
    [anon_sym_time] = ACTIONS(6849),
    [anon_sym_bit] = ACTIONS(6849),
    [anon_sym_logic] = ACTIONS(6849),
    [anon_sym_reg] = ACTIONS(6849),
    [anon_sym_shortreal] = ACTIONS(6849),
    [anon_sym_real] = ACTIONS(6849),
    [anon_sym_realtime] = ACTIONS(6849),
    [anon_sym_supply0] = ACTIONS(6849),
    [anon_sym_supply1] = ACTIONS(6849),
    [anon_sym_signed] = ACTIONS(6849),
    [anon_sym_unsigned] = ACTIONS(6849),
    [anon_sym_task] = ACTIONS(6849),
    [anon_sym_assert] = ACTIONS(6849),
    [anon_sym_property] = ACTIONS(6849),
    [anon_sym_assume] = ACTIONS(6849),
    [anon_sym_cover] = ACTIONS(6849),
    [anon_sym_sequence] = ACTIONS(6849),
    [anon_sym_restrict] = ACTIONS(6849),
    [anon_sym_not] = ACTIONS(6849),
    [anon_sym_or] = ACTIONS(6849),
    [anon_sym_and] = ACTIONS(6849),
    [anon_sym_case] = ACTIONS(6849),
    [anon_sym_always] = ACTIONS(6849),
    [anon_sym_covergroup] = ACTIONS(6849),
    [anon_sym_let] = ACTIONS(6849),
    [anon_sym_pulldown] = ACTIONS(6849),
    [anon_sym_pullup] = ACTIONS(6849),
    [anon_sym_cmos] = ACTIONS(6849),
    [anon_sym_rcmos] = ACTIONS(6849),
    [anon_sym_bufif0] = ACTIONS(6849),
    [anon_sym_bufif1] = ACTIONS(6849),
    [anon_sym_notif0] = ACTIONS(6849),
    [anon_sym_notif1] = ACTIONS(6849),
    [anon_sym_nmos] = ACTIONS(6849),
    [anon_sym_pmos] = ACTIONS(6849),
    [anon_sym_rnmos] = ACTIONS(6849),
    [anon_sym_rpmos] = ACTIONS(6849),
    [anon_sym_nand] = ACTIONS(6849),
    [anon_sym_nor] = ACTIONS(6849),
    [anon_sym_xor] = ACTIONS(6849),
    [anon_sym_xnor] = ACTIONS(6849),
    [anon_sym_buf] = ACTIONS(6849),
    [anon_sym_tranif0] = ACTIONS(6849),
    [anon_sym_tranif1] = ACTIONS(6849),
    [anon_sym_rtranif1] = ACTIONS(6849),
    [anon_sym_rtranif0] = ACTIONS(6849),
    [anon_sym_tran] = ACTIONS(6849),
    [anon_sym_rtran] = ACTIONS(6849),
    [anon_sym_generate] = ACTIONS(6849),
    [anon_sym_for] = ACTIONS(6849),
    [anon_sym_primitive] = ACTIONS(6849),
    [anon_sym_initial] = ACTIONS(6849),
    [anon_sym_assign] = ACTIONS(6849),
    [anon_sym_alias] = ACTIONS(6849),
    [anon_sym_always_comb] = ACTIONS(6849),
    [anon_sym_always_latch] = ACTIONS(6849),
    [anon_sym_always_ff] = ACTIONS(6849),
    [anon_sym_final] = ACTIONS(6849),
    [anon_sym_global] = ACTIONS(6849),
    [anon_sym_specify] = ACTIONS(6849),
    [anon_sym_LPAREN_STAR] = ACTIONS(6847),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6847),
    [anon_sym_DOLLARunit] = ACTIONS(6847),
  },
  [1271] = {
    [ts_builtin_sym_end] = ACTIONS(6851),
    [sym_simple_identifier] = ACTIONS(6853),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6851),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6851),
    [anon_sym_BQUOTE] = ACTIONS(6853),
    [aux_sym_id_directive_token1] = ACTIONS(6851),
    [aux_sym_id_directive_token2] = ACTIONS(6851),
    [aux_sym_id_directive_token3] = ACTIONS(6851),
    [aux_sym_id_directive_token4] = ACTIONS(6853),
    [aux_sym_zero_directive_token1] = ACTIONS(6851),
    [aux_sym_zero_directive_token2] = ACTIONS(6851),
    [aux_sym_zero_directive_token3] = ACTIONS(6851),
    [aux_sym_zero_directive_token4] = ACTIONS(6851),
    [aux_sym_zero_directive_token5] = ACTIONS(6851),
    [aux_sym_zero_directive_token6] = ACTIONS(6851),
    [aux_sym_zero_directive_token7] = ACTIONS(6851),
    [aux_sym_zero_directive_token8] = ACTIONS(6851),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6851),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6851),
    [anon_sym_wire] = ACTIONS(6853),
    [anon_sym_tri] = ACTIONS(6853),
    [anon_sym_tri0] = ACTIONS(6853),
    [anon_sym_tri1] = ACTIONS(6853),
    [anon_sym_wand] = ACTIONS(6853),
    [anon_sym_triand] = ACTIONS(6853),
    [anon_sym_wor] = ACTIONS(6853),
    [anon_sym_trior] = ACTIONS(6853),
    [anon_sym_trireg] = ACTIONS(6853),
    [anon_sym_uwire] = ACTIONS(6853),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6851),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6851),
    [aux_sym_begin_keywords_token1] = ACTIONS(6851),
    [anon_sym_SEMI] = ACTIONS(6851),
    [anon_sym_endmodule] = ACTIONS(6853),
    [anon_sym_extern] = ACTIONS(6853),
    [anon_sym_module] = ACTIONS(6853),
    [anon_sym_macromodule] = ACTIONS(6853),
    [anon_sym_interface] = ACTIONS(6853),
    [anon_sym_program] = ACTIONS(6853),
    [anon_sym_checker] = ACTIONS(6853),
    [anon_sym_virtual] = ACTIONS(6853),
    [anon_sym_class] = ACTIONS(6853),
    [anon_sym_package] = ACTIONS(6853),
    [anon_sym_timeunit] = ACTIONS(6853),
    [anon_sym_timeprecision] = ACTIONS(6853),
    [anon_sym_type] = ACTIONS(6853),
    [anon_sym_input] = ACTIONS(6853),
    [anon_sym_output] = ACTIONS(6853),
    [anon_sym_inout] = ACTIONS(6853),
    [anon_sym_ref] = ACTIONS(6853),
    [anon_sym_DOLLARfatal] = ACTIONS(6851),
    [anon_sym_DOLLARerror] = ACTIONS(6851),
    [anon_sym_DOLLARwarning] = ACTIONS(6851),
    [anon_sym_DOLLARinfo] = ACTIONS(6851),
    [anon_sym_default] = ACTIONS(6853),
    [anon_sym_clocking] = ACTIONS(6853),
    [anon_sym_defparam] = ACTIONS(6853),
    [anon_sym_bind] = ACTIONS(6853),
    [anon_sym_const] = ACTIONS(6853),
    [anon_sym_function] = ACTIONS(6853),
    [anon_sym_static] = ACTIONS(6853),
    [anon_sym_constraint] = ACTIONS(6853),
    [anon_sym_if] = ACTIONS(6853),
    [anon_sym_LBRACK] = ACTIONS(6851),
    [anon_sym_localparam] = ACTIONS(6853),
    [anon_sym_parameter] = ACTIONS(6853),
    [anon_sym_specparam] = ACTIONS(6853),
    [anon_sym_var] = ACTIONS(6853),
    [anon_sym_import] = ACTIONS(6853),
    [anon_sym_export] = ACTIONS(6853),
    [anon_sym_genvar] = ACTIONS(6853),
    [anon_sym_interconnect] = ACTIONS(6853),
    [anon_sym_typedef] = ACTIONS(6853),
    [anon_sym_enum] = ACTIONS(6853),
    [anon_sym_struct] = ACTIONS(6853),
    [anon_sym_union] = ACTIONS(6853),
    [anon_sym_nettype] = ACTIONS(6853),
    [anon_sym_automatic] = ACTIONS(6853),
    [anon_sym_string] = ACTIONS(6853),
    [anon_sym_chandle] = ACTIONS(6853),
    [anon_sym_event] = ACTIONS(6853),
    [anon_sym_byte] = ACTIONS(6853),
    [anon_sym_shortint] = ACTIONS(6853),
    [anon_sym_int] = ACTIONS(6853),
    [anon_sym_longint] = ACTIONS(6853),
    [anon_sym_integer] = ACTIONS(6853),
    [anon_sym_time] = ACTIONS(6853),
    [anon_sym_bit] = ACTIONS(6853),
    [anon_sym_logic] = ACTIONS(6853),
    [anon_sym_reg] = ACTIONS(6853),
    [anon_sym_shortreal] = ACTIONS(6853),
    [anon_sym_real] = ACTIONS(6853),
    [anon_sym_realtime] = ACTIONS(6853),
    [anon_sym_supply0] = ACTIONS(6853),
    [anon_sym_supply1] = ACTIONS(6853),
    [anon_sym_signed] = ACTIONS(6853),
    [anon_sym_unsigned] = ACTIONS(6853),
    [anon_sym_task] = ACTIONS(6853),
    [anon_sym_assert] = ACTIONS(6853),
    [anon_sym_property] = ACTIONS(6853),
    [anon_sym_assume] = ACTIONS(6853),
    [anon_sym_cover] = ACTIONS(6853),
    [anon_sym_sequence] = ACTIONS(6853),
    [anon_sym_restrict] = ACTIONS(6853),
    [anon_sym_not] = ACTIONS(6853),
    [anon_sym_or] = ACTIONS(6853),
    [anon_sym_and] = ACTIONS(6853),
    [anon_sym_case] = ACTIONS(6853),
    [anon_sym_always] = ACTIONS(6853),
    [anon_sym_covergroup] = ACTIONS(6853),
    [anon_sym_let] = ACTIONS(6853),
    [anon_sym_pulldown] = ACTIONS(6853),
    [anon_sym_pullup] = ACTIONS(6853),
    [anon_sym_cmos] = ACTIONS(6853),
    [anon_sym_rcmos] = ACTIONS(6853),
    [anon_sym_bufif0] = ACTIONS(6853),
    [anon_sym_bufif1] = ACTIONS(6853),
    [anon_sym_notif0] = ACTIONS(6853),
    [anon_sym_notif1] = ACTIONS(6853),
    [anon_sym_nmos] = ACTIONS(6853),
    [anon_sym_pmos] = ACTIONS(6853),
    [anon_sym_rnmos] = ACTIONS(6853),
    [anon_sym_rpmos] = ACTIONS(6853),
    [anon_sym_nand] = ACTIONS(6853),
    [anon_sym_nor] = ACTIONS(6853),
    [anon_sym_xor] = ACTIONS(6853),
    [anon_sym_xnor] = ACTIONS(6853),
    [anon_sym_buf] = ACTIONS(6853),
    [anon_sym_tranif0] = ACTIONS(6853),
    [anon_sym_tranif1] = ACTIONS(6853),
    [anon_sym_rtranif1] = ACTIONS(6853),
    [anon_sym_rtranif0] = ACTIONS(6853),
    [anon_sym_tran] = ACTIONS(6853),
    [anon_sym_rtran] = ACTIONS(6853),
    [anon_sym_generate] = ACTIONS(6853),
    [anon_sym_for] = ACTIONS(6853),
    [anon_sym_primitive] = ACTIONS(6853),
    [anon_sym_initial] = ACTIONS(6853),
    [anon_sym_assign] = ACTIONS(6853),
    [anon_sym_alias] = ACTIONS(6853),
    [anon_sym_always_comb] = ACTIONS(6853),
    [anon_sym_always_latch] = ACTIONS(6853),
    [anon_sym_always_ff] = ACTIONS(6853),
    [anon_sym_final] = ACTIONS(6853),
    [anon_sym_global] = ACTIONS(6853),
    [anon_sym_specify] = ACTIONS(6853),
    [anon_sym_LPAREN_STAR] = ACTIONS(6851),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6851),
    [anon_sym_DOLLARunit] = ACTIONS(6851),
  },
  [1272] = {
    [ts_builtin_sym_end] = ACTIONS(6855),
    [sym_simple_identifier] = ACTIONS(6857),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6855),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6855),
    [anon_sym_BQUOTE] = ACTIONS(6857),
    [aux_sym_id_directive_token1] = ACTIONS(6855),
    [aux_sym_id_directive_token2] = ACTIONS(6855),
    [aux_sym_id_directive_token3] = ACTIONS(6855),
    [aux_sym_id_directive_token4] = ACTIONS(6857),
    [aux_sym_zero_directive_token1] = ACTIONS(6855),
    [aux_sym_zero_directive_token2] = ACTIONS(6855),
    [aux_sym_zero_directive_token3] = ACTIONS(6855),
    [aux_sym_zero_directive_token4] = ACTIONS(6855),
    [aux_sym_zero_directive_token5] = ACTIONS(6855),
    [aux_sym_zero_directive_token6] = ACTIONS(6855),
    [aux_sym_zero_directive_token7] = ACTIONS(6855),
    [aux_sym_zero_directive_token8] = ACTIONS(6855),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6855),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6855),
    [anon_sym_wire] = ACTIONS(6857),
    [anon_sym_tri] = ACTIONS(6857),
    [anon_sym_tri0] = ACTIONS(6857),
    [anon_sym_tri1] = ACTIONS(6857),
    [anon_sym_wand] = ACTIONS(6857),
    [anon_sym_triand] = ACTIONS(6857),
    [anon_sym_wor] = ACTIONS(6857),
    [anon_sym_trior] = ACTIONS(6857),
    [anon_sym_trireg] = ACTIONS(6857),
    [anon_sym_uwire] = ACTIONS(6857),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6855),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6855),
    [aux_sym_begin_keywords_token1] = ACTIONS(6855),
    [anon_sym_SEMI] = ACTIONS(6855),
    [anon_sym_endmodule] = ACTIONS(6857),
    [anon_sym_extern] = ACTIONS(6857),
    [anon_sym_module] = ACTIONS(6857),
    [anon_sym_macromodule] = ACTIONS(6857),
    [anon_sym_interface] = ACTIONS(6857),
    [anon_sym_program] = ACTIONS(6857),
    [anon_sym_checker] = ACTIONS(6857),
    [anon_sym_virtual] = ACTIONS(6857),
    [anon_sym_class] = ACTIONS(6857),
    [anon_sym_package] = ACTIONS(6857),
    [anon_sym_timeunit] = ACTIONS(6857),
    [anon_sym_timeprecision] = ACTIONS(6857),
    [anon_sym_type] = ACTIONS(6857),
    [anon_sym_input] = ACTIONS(6857),
    [anon_sym_output] = ACTIONS(6857),
    [anon_sym_inout] = ACTIONS(6857),
    [anon_sym_ref] = ACTIONS(6857),
    [anon_sym_DOLLARfatal] = ACTIONS(6855),
    [anon_sym_DOLLARerror] = ACTIONS(6855),
    [anon_sym_DOLLARwarning] = ACTIONS(6855),
    [anon_sym_DOLLARinfo] = ACTIONS(6855),
    [anon_sym_default] = ACTIONS(6857),
    [anon_sym_clocking] = ACTIONS(6857),
    [anon_sym_defparam] = ACTIONS(6857),
    [anon_sym_bind] = ACTIONS(6857),
    [anon_sym_const] = ACTIONS(6857),
    [anon_sym_function] = ACTIONS(6857),
    [anon_sym_static] = ACTIONS(6857),
    [anon_sym_constraint] = ACTIONS(6857),
    [anon_sym_if] = ACTIONS(6857),
    [anon_sym_LBRACK] = ACTIONS(6855),
    [anon_sym_localparam] = ACTIONS(6857),
    [anon_sym_parameter] = ACTIONS(6857),
    [anon_sym_specparam] = ACTIONS(6857),
    [anon_sym_var] = ACTIONS(6857),
    [anon_sym_import] = ACTIONS(6857),
    [anon_sym_export] = ACTIONS(6857),
    [anon_sym_genvar] = ACTIONS(6857),
    [anon_sym_interconnect] = ACTIONS(6857),
    [anon_sym_typedef] = ACTIONS(6857),
    [anon_sym_enum] = ACTIONS(6857),
    [anon_sym_struct] = ACTIONS(6857),
    [anon_sym_union] = ACTIONS(6857),
    [anon_sym_nettype] = ACTIONS(6857),
    [anon_sym_automatic] = ACTIONS(6857),
    [anon_sym_string] = ACTIONS(6857),
    [anon_sym_chandle] = ACTIONS(6857),
    [anon_sym_event] = ACTIONS(6857),
    [anon_sym_byte] = ACTIONS(6857),
    [anon_sym_shortint] = ACTIONS(6857),
    [anon_sym_int] = ACTIONS(6857),
    [anon_sym_longint] = ACTIONS(6857),
    [anon_sym_integer] = ACTIONS(6857),
    [anon_sym_time] = ACTIONS(6857),
    [anon_sym_bit] = ACTIONS(6857),
    [anon_sym_logic] = ACTIONS(6857),
    [anon_sym_reg] = ACTIONS(6857),
    [anon_sym_shortreal] = ACTIONS(6857),
    [anon_sym_real] = ACTIONS(6857),
    [anon_sym_realtime] = ACTIONS(6857),
    [anon_sym_supply0] = ACTIONS(6857),
    [anon_sym_supply1] = ACTIONS(6857),
    [anon_sym_signed] = ACTIONS(6857),
    [anon_sym_unsigned] = ACTIONS(6857),
    [anon_sym_task] = ACTIONS(6857),
    [anon_sym_assert] = ACTIONS(6857),
    [anon_sym_property] = ACTIONS(6857),
    [anon_sym_assume] = ACTIONS(6857),
    [anon_sym_cover] = ACTIONS(6857),
    [anon_sym_sequence] = ACTIONS(6857),
    [anon_sym_restrict] = ACTIONS(6857),
    [anon_sym_not] = ACTIONS(6857),
    [anon_sym_or] = ACTIONS(6857),
    [anon_sym_and] = ACTIONS(6857),
    [anon_sym_case] = ACTIONS(6857),
    [anon_sym_always] = ACTIONS(6857),
    [anon_sym_covergroup] = ACTIONS(6857),
    [anon_sym_let] = ACTIONS(6857),
    [anon_sym_pulldown] = ACTIONS(6857),
    [anon_sym_pullup] = ACTIONS(6857),
    [anon_sym_cmos] = ACTIONS(6857),
    [anon_sym_rcmos] = ACTIONS(6857),
    [anon_sym_bufif0] = ACTIONS(6857),
    [anon_sym_bufif1] = ACTIONS(6857),
    [anon_sym_notif0] = ACTIONS(6857),
    [anon_sym_notif1] = ACTIONS(6857),
    [anon_sym_nmos] = ACTIONS(6857),
    [anon_sym_pmos] = ACTIONS(6857),
    [anon_sym_rnmos] = ACTIONS(6857),
    [anon_sym_rpmos] = ACTIONS(6857),
    [anon_sym_nand] = ACTIONS(6857),
    [anon_sym_nor] = ACTIONS(6857),
    [anon_sym_xor] = ACTIONS(6857),
    [anon_sym_xnor] = ACTIONS(6857),
    [anon_sym_buf] = ACTIONS(6857),
    [anon_sym_tranif0] = ACTIONS(6857),
    [anon_sym_tranif1] = ACTIONS(6857),
    [anon_sym_rtranif1] = ACTIONS(6857),
    [anon_sym_rtranif0] = ACTIONS(6857),
    [anon_sym_tran] = ACTIONS(6857),
    [anon_sym_rtran] = ACTIONS(6857),
    [anon_sym_generate] = ACTIONS(6857),
    [anon_sym_for] = ACTIONS(6857),
    [anon_sym_primitive] = ACTIONS(6857),
    [anon_sym_initial] = ACTIONS(6857),
    [anon_sym_assign] = ACTIONS(6857),
    [anon_sym_alias] = ACTIONS(6857),
    [anon_sym_always_comb] = ACTIONS(6857),
    [anon_sym_always_latch] = ACTIONS(6857),
    [anon_sym_always_ff] = ACTIONS(6857),
    [anon_sym_final] = ACTIONS(6857),
    [anon_sym_global] = ACTIONS(6857),
    [anon_sym_specify] = ACTIONS(6857),
    [anon_sym_LPAREN_STAR] = ACTIONS(6855),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6855),
    [anon_sym_DOLLARunit] = ACTIONS(6855),
  },
  [1273] = {
    [ts_builtin_sym_end] = ACTIONS(6859),
    [sym_simple_identifier] = ACTIONS(6861),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6859),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6859),
    [anon_sym_BQUOTE] = ACTIONS(6861),
    [aux_sym_id_directive_token1] = ACTIONS(6859),
    [aux_sym_id_directive_token2] = ACTIONS(6859),
    [aux_sym_id_directive_token3] = ACTIONS(6859),
    [aux_sym_id_directive_token4] = ACTIONS(6861),
    [aux_sym_zero_directive_token1] = ACTIONS(6859),
    [aux_sym_zero_directive_token2] = ACTIONS(6859),
    [aux_sym_zero_directive_token3] = ACTIONS(6859),
    [aux_sym_zero_directive_token4] = ACTIONS(6859),
    [aux_sym_zero_directive_token5] = ACTIONS(6859),
    [aux_sym_zero_directive_token6] = ACTIONS(6859),
    [aux_sym_zero_directive_token7] = ACTIONS(6859),
    [aux_sym_zero_directive_token8] = ACTIONS(6859),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6859),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6859),
    [anon_sym_wire] = ACTIONS(6861),
    [anon_sym_tri] = ACTIONS(6861),
    [anon_sym_tri0] = ACTIONS(6861),
    [anon_sym_tri1] = ACTIONS(6861),
    [anon_sym_wand] = ACTIONS(6861),
    [anon_sym_triand] = ACTIONS(6861),
    [anon_sym_wor] = ACTIONS(6861),
    [anon_sym_trior] = ACTIONS(6861),
    [anon_sym_trireg] = ACTIONS(6861),
    [anon_sym_uwire] = ACTIONS(6861),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6859),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6859),
    [aux_sym_begin_keywords_token1] = ACTIONS(6859),
    [anon_sym_SEMI] = ACTIONS(6859),
    [anon_sym_endmodule] = ACTIONS(6861),
    [anon_sym_extern] = ACTIONS(6861),
    [anon_sym_module] = ACTIONS(6861),
    [anon_sym_macromodule] = ACTIONS(6861),
    [anon_sym_interface] = ACTIONS(6861),
    [anon_sym_program] = ACTIONS(6861),
    [anon_sym_checker] = ACTIONS(6861),
    [anon_sym_virtual] = ACTIONS(6861),
    [anon_sym_class] = ACTIONS(6861),
    [anon_sym_package] = ACTIONS(6861),
    [anon_sym_timeunit] = ACTIONS(6861),
    [anon_sym_timeprecision] = ACTIONS(6861),
    [anon_sym_type] = ACTIONS(6861),
    [anon_sym_input] = ACTIONS(6861),
    [anon_sym_output] = ACTIONS(6861),
    [anon_sym_inout] = ACTIONS(6861),
    [anon_sym_ref] = ACTIONS(6861),
    [anon_sym_DOLLARfatal] = ACTIONS(6859),
    [anon_sym_DOLLARerror] = ACTIONS(6859),
    [anon_sym_DOLLARwarning] = ACTIONS(6859),
    [anon_sym_DOLLARinfo] = ACTIONS(6859),
    [anon_sym_default] = ACTIONS(6861),
    [anon_sym_clocking] = ACTIONS(6861),
    [anon_sym_defparam] = ACTIONS(6861),
    [anon_sym_bind] = ACTIONS(6861),
    [anon_sym_const] = ACTIONS(6861),
    [anon_sym_function] = ACTIONS(6861),
    [anon_sym_static] = ACTIONS(6861),
    [anon_sym_constraint] = ACTIONS(6861),
    [anon_sym_if] = ACTIONS(6861),
    [anon_sym_LBRACK] = ACTIONS(6859),
    [anon_sym_localparam] = ACTIONS(6861),
    [anon_sym_parameter] = ACTIONS(6861),
    [anon_sym_specparam] = ACTIONS(6861),
    [anon_sym_var] = ACTIONS(6861),
    [anon_sym_import] = ACTIONS(6861),
    [anon_sym_export] = ACTIONS(6861),
    [anon_sym_genvar] = ACTIONS(6861),
    [anon_sym_interconnect] = ACTIONS(6861),
    [anon_sym_typedef] = ACTIONS(6861),
    [anon_sym_enum] = ACTIONS(6861),
    [anon_sym_struct] = ACTIONS(6861),
    [anon_sym_union] = ACTIONS(6861),
    [anon_sym_nettype] = ACTIONS(6861),
    [anon_sym_automatic] = ACTIONS(6861),
    [anon_sym_string] = ACTIONS(6861),
    [anon_sym_chandle] = ACTIONS(6861),
    [anon_sym_event] = ACTIONS(6861),
    [anon_sym_byte] = ACTIONS(6861),
    [anon_sym_shortint] = ACTIONS(6861),
    [anon_sym_int] = ACTIONS(6861),
    [anon_sym_longint] = ACTIONS(6861),
    [anon_sym_integer] = ACTIONS(6861),
    [anon_sym_time] = ACTIONS(6861),
    [anon_sym_bit] = ACTIONS(6861),
    [anon_sym_logic] = ACTIONS(6861),
    [anon_sym_reg] = ACTIONS(6861),
    [anon_sym_shortreal] = ACTIONS(6861),
    [anon_sym_real] = ACTIONS(6861),
    [anon_sym_realtime] = ACTIONS(6861),
    [anon_sym_supply0] = ACTIONS(6861),
    [anon_sym_supply1] = ACTIONS(6861),
    [anon_sym_signed] = ACTIONS(6861),
    [anon_sym_unsigned] = ACTIONS(6861),
    [anon_sym_task] = ACTIONS(6861),
    [anon_sym_assert] = ACTIONS(6861),
    [anon_sym_property] = ACTIONS(6861),
    [anon_sym_assume] = ACTIONS(6861),
    [anon_sym_cover] = ACTIONS(6861),
    [anon_sym_sequence] = ACTIONS(6861),
    [anon_sym_restrict] = ACTIONS(6861),
    [anon_sym_not] = ACTIONS(6861),
    [anon_sym_or] = ACTIONS(6861),
    [anon_sym_and] = ACTIONS(6861),
    [anon_sym_case] = ACTIONS(6861),
    [anon_sym_always] = ACTIONS(6861),
    [anon_sym_covergroup] = ACTIONS(6861),
    [anon_sym_let] = ACTIONS(6861),
    [anon_sym_pulldown] = ACTIONS(6861),
    [anon_sym_pullup] = ACTIONS(6861),
    [anon_sym_cmos] = ACTIONS(6861),
    [anon_sym_rcmos] = ACTIONS(6861),
    [anon_sym_bufif0] = ACTIONS(6861),
    [anon_sym_bufif1] = ACTIONS(6861),
    [anon_sym_notif0] = ACTIONS(6861),
    [anon_sym_notif1] = ACTIONS(6861),
    [anon_sym_nmos] = ACTIONS(6861),
    [anon_sym_pmos] = ACTIONS(6861),
    [anon_sym_rnmos] = ACTIONS(6861),
    [anon_sym_rpmos] = ACTIONS(6861),
    [anon_sym_nand] = ACTIONS(6861),
    [anon_sym_nor] = ACTIONS(6861),
    [anon_sym_xor] = ACTIONS(6861),
    [anon_sym_xnor] = ACTIONS(6861),
    [anon_sym_buf] = ACTIONS(6861),
    [anon_sym_tranif0] = ACTIONS(6861),
    [anon_sym_tranif1] = ACTIONS(6861),
    [anon_sym_rtranif1] = ACTIONS(6861),
    [anon_sym_rtranif0] = ACTIONS(6861),
    [anon_sym_tran] = ACTIONS(6861),
    [anon_sym_rtran] = ACTIONS(6861),
    [anon_sym_generate] = ACTIONS(6861),
    [anon_sym_for] = ACTIONS(6861),
    [anon_sym_primitive] = ACTIONS(6861),
    [anon_sym_initial] = ACTIONS(6861),
    [anon_sym_assign] = ACTIONS(6861),
    [anon_sym_alias] = ACTIONS(6861),
    [anon_sym_always_comb] = ACTIONS(6861),
    [anon_sym_always_latch] = ACTIONS(6861),
    [anon_sym_always_ff] = ACTIONS(6861),
    [anon_sym_final] = ACTIONS(6861),
    [anon_sym_global] = ACTIONS(6861),
    [anon_sym_specify] = ACTIONS(6861),
    [anon_sym_LPAREN_STAR] = ACTIONS(6859),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6859),
    [anon_sym_DOLLARunit] = ACTIONS(6859),
  },
  [1274] = {
    [ts_builtin_sym_end] = ACTIONS(6863),
    [sym_simple_identifier] = ACTIONS(6865),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6863),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6863),
    [anon_sym_BQUOTE] = ACTIONS(6865),
    [aux_sym_id_directive_token1] = ACTIONS(6863),
    [aux_sym_id_directive_token2] = ACTIONS(6863),
    [aux_sym_id_directive_token3] = ACTIONS(6863),
    [aux_sym_id_directive_token4] = ACTIONS(6865),
    [aux_sym_zero_directive_token1] = ACTIONS(6863),
    [aux_sym_zero_directive_token2] = ACTIONS(6863),
    [aux_sym_zero_directive_token3] = ACTIONS(6863),
    [aux_sym_zero_directive_token4] = ACTIONS(6863),
    [aux_sym_zero_directive_token5] = ACTIONS(6863),
    [aux_sym_zero_directive_token6] = ACTIONS(6863),
    [aux_sym_zero_directive_token7] = ACTIONS(6863),
    [aux_sym_zero_directive_token8] = ACTIONS(6863),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6863),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6863),
    [anon_sym_wire] = ACTIONS(6865),
    [anon_sym_tri] = ACTIONS(6865),
    [anon_sym_tri0] = ACTIONS(6865),
    [anon_sym_tri1] = ACTIONS(6865),
    [anon_sym_wand] = ACTIONS(6865),
    [anon_sym_triand] = ACTIONS(6865),
    [anon_sym_wor] = ACTIONS(6865),
    [anon_sym_trior] = ACTIONS(6865),
    [anon_sym_trireg] = ACTIONS(6865),
    [anon_sym_uwire] = ACTIONS(6865),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6863),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6863),
    [aux_sym_begin_keywords_token1] = ACTIONS(6863),
    [anon_sym_SEMI] = ACTIONS(6863),
    [anon_sym_endmodule] = ACTIONS(6865),
    [anon_sym_extern] = ACTIONS(6865),
    [anon_sym_module] = ACTIONS(6865),
    [anon_sym_macromodule] = ACTIONS(6865),
    [anon_sym_interface] = ACTIONS(6865),
    [anon_sym_program] = ACTIONS(6865),
    [anon_sym_checker] = ACTIONS(6865),
    [anon_sym_virtual] = ACTIONS(6865),
    [anon_sym_class] = ACTIONS(6865),
    [anon_sym_package] = ACTIONS(6865),
    [anon_sym_timeunit] = ACTIONS(6865),
    [anon_sym_timeprecision] = ACTIONS(6865),
    [anon_sym_type] = ACTIONS(6865),
    [anon_sym_input] = ACTIONS(6865),
    [anon_sym_output] = ACTIONS(6865),
    [anon_sym_inout] = ACTIONS(6865),
    [anon_sym_ref] = ACTIONS(6865),
    [anon_sym_DOLLARfatal] = ACTIONS(6863),
    [anon_sym_DOLLARerror] = ACTIONS(6863),
    [anon_sym_DOLLARwarning] = ACTIONS(6863),
    [anon_sym_DOLLARinfo] = ACTIONS(6863),
    [anon_sym_default] = ACTIONS(6865),
    [anon_sym_clocking] = ACTIONS(6865),
    [anon_sym_defparam] = ACTIONS(6865),
    [anon_sym_bind] = ACTIONS(6865),
    [anon_sym_const] = ACTIONS(6865),
    [anon_sym_function] = ACTIONS(6865),
    [anon_sym_static] = ACTIONS(6865),
    [anon_sym_constraint] = ACTIONS(6865),
    [anon_sym_if] = ACTIONS(6865),
    [anon_sym_LBRACK] = ACTIONS(6863),
    [anon_sym_localparam] = ACTIONS(6865),
    [anon_sym_parameter] = ACTIONS(6865),
    [anon_sym_specparam] = ACTIONS(6865),
    [anon_sym_var] = ACTIONS(6865),
    [anon_sym_import] = ACTIONS(6865),
    [anon_sym_export] = ACTIONS(6865),
    [anon_sym_genvar] = ACTIONS(6865),
    [anon_sym_interconnect] = ACTIONS(6865),
    [anon_sym_typedef] = ACTIONS(6865),
    [anon_sym_enum] = ACTIONS(6865),
    [anon_sym_struct] = ACTIONS(6865),
    [anon_sym_union] = ACTIONS(6865),
    [anon_sym_nettype] = ACTIONS(6865),
    [anon_sym_automatic] = ACTIONS(6865),
    [anon_sym_string] = ACTIONS(6865),
    [anon_sym_chandle] = ACTIONS(6865),
    [anon_sym_event] = ACTIONS(6865),
    [anon_sym_byte] = ACTIONS(6865),
    [anon_sym_shortint] = ACTIONS(6865),
    [anon_sym_int] = ACTIONS(6865),
    [anon_sym_longint] = ACTIONS(6865),
    [anon_sym_integer] = ACTIONS(6865),
    [anon_sym_time] = ACTIONS(6865),
    [anon_sym_bit] = ACTIONS(6865),
    [anon_sym_logic] = ACTIONS(6865),
    [anon_sym_reg] = ACTIONS(6865),
    [anon_sym_shortreal] = ACTIONS(6865),
    [anon_sym_real] = ACTIONS(6865),
    [anon_sym_realtime] = ACTIONS(6865),
    [anon_sym_supply0] = ACTIONS(6865),
    [anon_sym_supply1] = ACTIONS(6865),
    [anon_sym_signed] = ACTIONS(6865),
    [anon_sym_unsigned] = ACTIONS(6865),
    [anon_sym_task] = ACTIONS(6865),
    [anon_sym_assert] = ACTIONS(6865),
    [anon_sym_property] = ACTIONS(6865),
    [anon_sym_assume] = ACTIONS(6865),
    [anon_sym_cover] = ACTIONS(6865),
    [anon_sym_sequence] = ACTIONS(6865),
    [anon_sym_restrict] = ACTIONS(6865),
    [anon_sym_not] = ACTIONS(6865),
    [anon_sym_or] = ACTIONS(6865),
    [anon_sym_and] = ACTIONS(6865),
    [anon_sym_case] = ACTIONS(6865),
    [anon_sym_always] = ACTIONS(6865),
    [anon_sym_covergroup] = ACTIONS(6865),
    [anon_sym_let] = ACTIONS(6865),
    [anon_sym_pulldown] = ACTIONS(6865),
    [anon_sym_pullup] = ACTIONS(6865),
    [anon_sym_cmos] = ACTIONS(6865),
    [anon_sym_rcmos] = ACTIONS(6865),
    [anon_sym_bufif0] = ACTIONS(6865),
    [anon_sym_bufif1] = ACTIONS(6865),
    [anon_sym_notif0] = ACTIONS(6865),
    [anon_sym_notif1] = ACTIONS(6865),
    [anon_sym_nmos] = ACTIONS(6865),
    [anon_sym_pmos] = ACTIONS(6865),
    [anon_sym_rnmos] = ACTIONS(6865),
    [anon_sym_rpmos] = ACTIONS(6865),
    [anon_sym_nand] = ACTIONS(6865),
    [anon_sym_nor] = ACTIONS(6865),
    [anon_sym_xor] = ACTIONS(6865),
    [anon_sym_xnor] = ACTIONS(6865),
    [anon_sym_buf] = ACTIONS(6865),
    [anon_sym_tranif0] = ACTIONS(6865),
    [anon_sym_tranif1] = ACTIONS(6865),
    [anon_sym_rtranif1] = ACTIONS(6865),
    [anon_sym_rtranif0] = ACTIONS(6865),
    [anon_sym_tran] = ACTIONS(6865),
    [anon_sym_rtran] = ACTIONS(6865),
    [anon_sym_generate] = ACTIONS(6865),
    [anon_sym_for] = ACTIONS(6865),
    [anon_sym_primitive] = ACTIONS(6865),
    [anon_sym_initial] = ACTIONS(6865),
    [anon_sym_assign] = ACTIONS(6865),
    [anon_sym_alias] = ACTIONS(6865),
    [anon_sym_always_comb] = ACTIONS(6865),
    [anon_sym_always_latch] = ACTIONS(6865),
    [anon_sym_always_ff] = ACTIONS(6865),
    [anon_sym_final] = ACTIONS(6865),
    [anon_sym_global] = ACTIONS(6865),
    [anon_sym_specify] = ACTIONS(6865),
    [anon_sym_LPAREN_STAR] = ACTIONS(6863),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6863),
    [anon_sym_DOLLARunit] = ACTIONS(6863),
  },
  [1275] = {
    [ts_builtin_sym_end] = ACTIONS(6867),
    [sym_simple_identifier] = ACTIONS(6869),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6867),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6867),
    [anon_sym_BQUOTE] = ACTIONS(6869),
    [aux_sym_id_directive_token1] = ACTIONS(6867),
    [aux_sym_id_directive_token2] = ACTIONS(6867),
    [aux_sym_id_directive_token3] = ACTIONS(6867),
    [aux_sym_id_directive_token4] = ACTIONS(6869),
    [aux_sym_zero_directive_token1] = ACTIONS(6867),
    [aux_sym_zero_directive_token2] = ACTIONS(6867),
    [aux_sym_zero_directive_token3] = ACTIONS(6867),
    [aux_sym_zero_directive_token4] = ACTIONS(6867),
    [aux_sym_zero_directive_token5] = ACTIONS(6867),
    [aux_sym_zero_directive_token6] = ACTIONS(6867),
    [aux_sym_zero_directive_token7] = ACTIONS(6867),
    [aux_sym_zero_directive_token8] = ACTIONS(6867),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6867),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6867),
    [anon_sym_wire] = ACTIONS(6869),
    [anon_sym_tri] = ACTIONS(6869),
    [anon_sym_tri0] = ACTIONS(6869),
    [anon_sym_tri1] = ACTIONS(6869),
    [anon_sym_wand] = ACTIONS(6869),
    [anon_sym_triand] = ACTIONS(6869),
    [anon_sym_wor] = ACTIONS(6869),
    [anon_sym_trior] = ACTIONS(6869),
    [anon_sym_trireg] = ACTIONS(6869),
    [anon_sym_uwire] = ACTIONS(6869),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6867),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6867),
    [aux_sym_begin_keywords_token1] = ACTIONS(6867),
    [anon_sym_SEMI] = ACTIONS(6867),
    [anon_sym_endmodule] = ACTIONS(6869),
    [anon_sym_extern] = ACTIONS(6869),
    [anon_sym_module] = ACTIONS(6869),
    [anon_sym_macromodule] = ACTIONS(6869),
    [anon_sym_interface] = ACTIONS(6869),
    [anon_sym_program] = ACTIONS(6869),
    [anon_sym_checker] = ACTIONS(6869),
    [anon_sym_virtual] = ACTIONS(6869),
    [anon_sym_class] = ACTIONS(6869),
    [anon_sym_package] = ACTIONS(6869),
    [anon_sym_timeunit] = ACTIONS(6869),
    [anon_sym_timeprecision] = ACTIONS(6869),
    [anon_sym_type] = ACTIONS(6869),
    [anon_sym_input] = ACTIONS(6869),
    [anon_sym_output] = ACTIONS(6869),
    [anon_sym_inout] = ACTIONS(6869),
    [anon_sym_ref] = ACTIONS(6869),
    [anon_sym_DOLLARfatal] = ACTIONS(6867),
    [anon_sym_DOLLARerror] = ACTIONS(6867),
    [anon_sym_DOLLARwarning] = ACTIONS(6867),
    [anon_sym_DOLLARinfo] = ACTIONS(6867),
    [anon_sym_default] = ACTIONS(6869),
    [anon_sym_clocking] = ACTIONS(6869),
    [anon_sym_defparam] = ACTIONS(6869),
    [anon_sym_bind] = ACTIONS(6869),
    [anon_sym_const] = ACTIONS(6869),
    [anon_sym_function] = ACTIONS(6869),
    [anon_sym_static] = ACTIONS(6869),
    [anon_sym_constraint] = ACTIONS(6869),
    [anon_sym_if] = ACTIONS(6869),
    [anon_sym_LBRACK] = ACTIONS(6867),
    [anon_sym_localparam] = ACTIONS(6869),
    [anon_sym_parameter] = ACTIONS(6869),
    [anon_sym_specparam] = ACTIONS(6869),
    [anon_sym_var] = ACTIONS(6869),
    [anon_sym_import] = ACTIONS(6869),
    [anon_sym_export] = ACTIONS(6869),
    [anon_sym_genvar] = ACTIONS(6869),
    [anon_sym_interconnect] = ACTIONS(6869),
    [anon_sym_typedef] = ACTIONS(6869),
    [anon_sym_enum] = ACTIONS(6869),
    [anon_sym_struct] = ACTIONS(6869),
    [anon_sym_union] = ACTIONS(6869),
    [anon_sym_nettype] = ACTIONS(6869),
    [anon_sym_automatic] = ACTIONS(6869),
    [anon_sym_string] = ACTIONS(6869),
    [anon_sym_chandle] = ACTIONS(6869),
    [anon_sym_event] = ACTIONS(6869),
    [anon_sym_byte] = ACTIONS(6869),
    [anon_sym_shortint] = ACTIONS(6869),
    [anon_sym_int] = ACTIONS(6869),
    [anon_sym_longint] = ACTIONS(6869),
    [anon_sym_integer] = ACTIONS(6869),
    [anon_sym_time] = ACTIONS(6869),
    [anon_sym_bit] = ACTIONS(6869),
    [anon_sym_logic] = ACTIONS(6869),
    [anon_sym_reg] = ACTIONS(6869),
    [anon_sym_shortreal] = ACTIONS(6869),
    [anon_sym_real] = ACTIONS(6869),
    [anon_sym_realtime] = ACTIONS(6869),
    [anon_sym_supply0] = ACTIONS(6869),
    [anon_sym_supply1] = ACTIONS(6869),
    [anon_sym_signed] = ACTIONS(6869),
    [anon_sym_unsigned] = ACTIONS(6869),
    [anon_sym_task] = ACTIONS(6869),
    [anon_sym_assert] = ACTIONS(6869),
    [anon_sym_property] = ACTIONS(6869),
    [anon_sym_assume] = ACTIONS(6869),
    [anon_sym_cover] = ACTIONS(6869),
    [anon_sym_sequence] = ACTIONS(6869),
    [anon_sym_restrict] = ACTIONS(6869),
    [anon_sym_not] = ACTIONS(6869),
    [anon_sym_or] = ACTIONS(6869),
    [anon_sym_and] = ACTIONS(6869),
    [anon_sym_case] = ACTIONS(6869),
    [anon_sym_always] = ACTIONS(6869),
    [anon_sym_covergroup] = ACTIONS(6869),
    [anon_sym_let] = ACTIONS(6869),
    [anon_sym_pulldown] = ACTIONS(6869),
    [anon_sym_pullup] = ACTIONS(6869),
    [anon_sym_cmos] = ACTIONS(6869),
    [anon_sym_rcmos] = ACTIONS(6869),
    [anon_sym_bufif0] = ACTIONS(6869),
    [anon_sym_bufif1] = ACTIONS(6869),
    [anon_sym_notif0] = ACTIONS(6869),
    [anon_sym_notif1] = ACTIONS(6869),
    [anon_sym_nmos] = ACTIONS(6869),
    [anon_sym_pmos] = ACTIONS(6869),
    [anon_sym_rnmos] = ACTIONS(6869),
    [anon_sym_rpmos] = ACTIONS(6869),
    [anon_sym_nand] = ACTIONS(6869),
    [anon_sym_nor] = ACTIONS(6869),
    [anon_sym_xor] = ACTIONS(6869),
    [anon_sym_xnor] = ACTIONS(6869),
    [anon_sym_buf] = ACTIONS(6869),
    [anon_sym_tranif0] = ACTIONS(6869),
    [anon_sym_tranif1] = ACTIONS(6869),
    [anon_sym_rtranif1] = ACTIONS(6869),
    [anon_sym_rtranif0] = ACTIONS(6869),
    [anon_sym_tran] = ACTIONS(6869),
    [anon_sym_rtran] = ACTIONS(6869),
    [anon_sym_generate] = ACTIONS(6869),
    [anon_sym_for] = ACTIONS(6869),
    [anon_sym_primitive] = ACTIONS(6869),
    [anon_sym_initial] = ACTIONS(6869),
    [anon_sym_assign] = ACTIONS(6869),
    [anon_sym_alias] = ACTIONS(6869),
    [anon_sym_always_comb] = ACTIONS(6869),
    [anon_sym_always_latch] = ACTIONS(6869),
    [anon_sym_always_ff] = ACTIONS(6869),
    [anon_sym_final] = ACTIONS(6869),
    [anon_sym_global] = ACTIONS(6869),
    [anon_sym_specify] = ACTIONS(6869),
    [anon_sym_LPAREN_STAR] = ACTIONS(6867),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6867),
    [anon_sym_DOLLARunit] = ACTIONS(6867),
  },
  [1276] = {
    [ts_builtin_sym_end] = ACTIONS(6871),
    [sym_simple_identifier] = ACTIONS(6873),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6871),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6871),
    [anon_sym_BQUOTE] = ACTIONS(6873),
    [aux_sym_id_directive_token1] = ACTIONS(6871),
    [aux_sym_id_directive_token2] = ACTIONS(6871),
    [aux_sym_id_directive_token3] = ACTIONS(6871),
    [aux_sym_id_directive_token4] = ACTIONS(6873),
    [aux_sym_zero_directive_token1] = ACTIONS(6871),
    [aux_sym_zero_directive_token2] = ACTIONS(6871),
    [aux_sym_zero_directive_token3] = ACTIONS(6871),
    [aux_sym_zero_directive_token4] = ACTIONS(6871),
    [aux_sym_zero_directive_token5] = ACTIONS(6871),
    [aux_sym_zero_directive_token6] = ACTIONS(6871),
    [aux_sym_zero_directive_token7] = ACTIONS(6871),
    [aux_sym_zero_directive_token8] = ACTIONS(6871),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6871),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6871),
    [anon_sym_wire] = ACTIONS(6873),
    [anon_sym_tri] = ACTIONS(6873),
    [anon_sym_tri0] = ACTIONS(6873),
    [anon_sym_tri1] = ACTIONS(6873),
    [anon_sym_wand] = ACTIONS(6873),
    [anon_sym_triand] = ACTIONS(6873),
    [anon_sym_wor] = ACTIONS(6873),
    [anon_sym_trior] = ACTIONS(6873),
    [anon_sym_trireg] = ACTIONS(6873),
    [anon_sym_uwire] = ACTIONS(6873),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6871),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6871),
    [aux_sym_begin_keywords_token1] = ACTIONS(6871),
    [anon_sym_SEMI] = ACTIONS(6871),
    [anon_sym_endmodule] = ACTIONS(6873),
    [anon_sym_extern] = ACTIONS(6873),
    [anon_sym_module] = ACTIONS(6873),
    [anon_sym_macromodule] = ACTIONS(6873),
    [anon_sym_interface] = ACTIONS(6873),
    [anon_sym_program] = ACTIONS(6873),
    [anon_sym_checker] = ACTIONS(6873),
    [anon_sym_virtual] = ACTIONS(6873),
    [anon_sym_class] = ACTIONS(6873),
    [anon_sym_package] = ACTIONS(6873),
    [anon_sym_timeunit] = ACTIONS(6873),
    [anon_sym_timeprecision] = ACTIONS(6873),
    [anon_sym_type] = ACTIONS(6873),
    [anon_sym_input] = ACTIONS(6873),
    [anon_sym_output] = ACTIONS(6873),
    [anon_sym_inout] = ACTIONS(6873),
    [anon_sym_ref] = ACTIONS(6873),
    [anon_sym_DOLLARfatal] = ACTIONS(6871),
    [anon_sym_DOLLARerror] = ACTIONS(6871),
    [anon_sym_DOLLARwarning] = ACTIONS(6871),
    [anon_sym_DOLLARinfo] = ACTIONS(6871),
    [anon_sym_default] = ACTIONS(6873),
    [anon_sym_clocking] = ACTIONS(6873),
    [anon_sym_defparam] = ACTIONS(6873),
    [anon_sym_bind] = ACTIONS(6873),
    [anon_sym_const] = ACTIONS(6873),
    [anon_sym_function] = ACTIONS(6873),
    [anon_sym_static] = ACTIONS(6873),
    [anon_sym_constraint] = ACTIONS(6873),
    [anon_sym_if] = ACTIONS(6873),
    [anon_sym_LBRACK] = ACTIONS(6871),
    [anon_sym_localparam] = ACTIONS(6873),
    [anon_sym_parameter] = ACTIONS(6873),
    [anon_sym_specparam] = ACTIONS(6873),
    [anon_sym_var] = ACTIONS(6873),
    [anon_sym_import] = ACTIONS(6873),
    [anon_sym_export] = ACTIONS(6873),
    [anon_sym_genvar] = ACTIONS(6873),
    [anon_sym_interconnect] = ACTIONS(6873),
    [anon_sym_typedef] = ACTIONS(6873),
    [anon_sym_enum] = ACTIONS(6873),
    [anon_sym_struct] = ACTIONS(6873),
    [anon_sym_union] = ACTIONS(6873),
    [anon_sym_nettype] = ACTIONS(6873),
    [anon_sym_automatic] = ACTIONS(6873),
    [anon_sym_string] = ACTIONS(6873),
    [anon_sym_chandle] = ACTIONS(6873),
    [anon_sym_event] = ACTIONS(6873),
    [anon_sym_byte] = ACTIONS(6873),
    [anon_sym_shortint] = ACTIONS(6873),
    [anon_sym_int] = ACTIONS(6873),
    [anon_sym_longint] = ACTIONS(6873),
    [anon_sym_integer] = ACTIONS(6873),
    [anon_sym_time] = ACTIONS(6873),
    [anon_sym_bit] = ACTIONS(6873),
    [anon_sym_logic] = ACTIONS(6873),
    [anon_sym_reg] = ACTIONS(6873),
    [anon_sym_shortreal] = ACTIONS(6873),
    [anon_sym_real] = ACTIONS(6873),
    [anon_sym_realtime] = ACTIONS(6873),
    [anon_sym_supply0] = ACTIONS(6873),
    [anon_sym_supply1] = ACTIONS(6873),
    [anon_sym_signed] = ACTIONS(6873),
    [anon_sym_unsigned] = ACTIONS(6873),
    [anon_sym_task] = ACTIONS(6873),
    [anon_sym_assert] = ACTIONS(6873),
    [anon_sym_property] = ACTIONS(6873),
    [anon_sym_assume] = ACTIONS(6873),
    [anon_sym_cover] = ACTIONS(6873),
    [anon_sym_sequence] = ACTIONS(6873),
    [anon_sym_restrict] = ACTIONS(6873),
    [anon_sym_not] = ACTIONS(6873),
    [anon_sym_or] = ACTIONS(6873),
    [anon_sym_and] = ACTIONS(6873),
    [anon_sym_case] = ACTIONS(6873),
    [anon_sym_always] = ACTIONS(6873),
    [anon_sym_covergroup] = ACTIONS(6873),
    [anon_sym_let] = ACTIONS(6873),
    [anon_sym_pulldown] = ACTIONS(6873),
    [anon_sym_pullup] = ACTIONS(6873),
    [anon_sym_cmos] = ACTIONS(6873),
    [anon_sym_rcmos] = ACTIONS(6873),
    [anon_sym_bufif0] = ACTIONS(6873),
    [anon_sym_bufif1] = ACTIONS(6873),
    [anon_sym_notif0] = ACTIONS(6873),
    [anon_sym_notif1] = ACTIONS(6873),
    [anon_sym_nmos] = ACTIONS(6873),
    [anon_sym_pmos] = ACTIONS(6873),
    [anon_sym_rnmos] = ACTIONS(6873),
    [anon_sym_rpmos] = ACTIONS(6873),
    [anon_sym_nand] = ACTIONS(6873),
    [anon_sym_nor] = ACTIONS(6873),
    [anon_sym_xor] = ACTIONS(6873),
    [anon_sym_xnor] = ACTIONS(6873),
    [anon_sym_buf] = ACTIONS(6873),
    [anon_sym_tranif0] = ACTIONS(6873),
    [anon_sym_tranif1] = ACTIONS(6873),
    [anon_sym_rtranif1] = ACTIONS(6873),
    [anon_sym_rtranif0] = ACTIONS(6873),
    [anon_sym_tran] = ACTIONS(6873),
    [anon_sym_rtran] = ACTIONS(6873),
    [anon_sym_generate] = ACTIONS(6873),
    [anon_sym_for] = ACTIONS(6873),
    [anon_sym_primitive] = ACTIONS(6873),
    [anon_sym_initial] = ACTIONS(6873),
    [anon_sym_assign] = ACTIONS(6873),
    [anon_sym_alias] = ACTIONS(6873),
    [anon_sym_always_comb] = ACTIONS(6873),
    [anon_sym_always_latch] = ACTIONS(6873),
    [anon_sym_always_ff] = ACTIONS(6873),
    [anon_sym_final] = ACTIONS(6873),
    [anon_sym_global] = ACTIONS(6873),
    [anon_sym_specify] = ACTIONS(6873),
    [anon_sym_LPAREN_STAR] = ACTIONS(6871),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6871),
    [anon_sym_DOLLARunit] = ACTIONS(6871),
  },
  [1277] = {
    [ts_builtin_sym_end] = ACTIONS(6875),
    [sym_simple_identifier] = ACTIONS(6877),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6875),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6875),
    [anon_sym_BQUOTE] = ACTIONS(6877),
    [aux_sym_id_directive_token1] = ACTIONS(6875),
    [aux_sym_id_directive_token2] = ACTIONS(6875),
    [aux_sym_id_directive_token3] = ACTIONS(6875),
    [aux_sym_id_directive_token4] = ACTIONS(6877),
    [aux_sym_zero_directive_token1] = ACTIONS(6875),
    [aux_sym_zero_directive_token2] = ACTIONS(6875),
    [aux_sym_zero_directive_token3] = ACTIONS(6875),
    [aux_sym_zero_directive_token4] = ACTIONS(6875),
    [aux_sym_zero_directive_token5] = ACTIONS(6875),
    [aux_sym_zero_directive_token6] = ACTIONS(6875),
    [aux_sym_zero_directive_token7] = ACTIONS(6875),
    [aux_sym_zero_directive_token8] = ACTIONS(6875),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6875),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6875),
    [anon_sym_wire] = ACTIONS(6877),
    [anon_sym_tri] = ACTIONS(6877),
    [anon_sym_tri0] = ACTIONS(6877),
    [anon_sym_tri1] = ACTIONS(6877),
    [anon_sym_wand] = ACTIONS(6877),
    [anon_sym_triand] = ACTIONS(6877),
    [anon_sym_wor] = ACTIONS(6877),
    [anon_sym_trior] = ACTIONS(6877),
    [anon_sym_trireg] = ACTIONS(6877),
    [anon_sym_uwire] = ACTIONS(6877),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6875),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6875),
    [aux_sym_begin_keywords_token1] = ACTIONS(6875),
    [anon_sym_SEMI] = ACTIONS(6875),
    [anon_sym_endmodule] = ACTIONS(6877),
    [anon_sym_extern] = ACTIONS(6877),
    [anon_sym_module] = ACTIONS(6877),
    [anon_sym_macromodule] = ACTIONS(6877),
    [anon_sym_interface] = ACTIONS(6877),
    [anon_sym_program] = ACTIONS(6877),
    [anon_sym_checker] = ACTIONS(6877),
    [anon_sym_virtual] = ACTIONS(6877),
    [anon_sym_class] = ACTIONS(6877),
    [anon_sym_package] = ACTIONS(6877),
    [anon_sym_timeunit] = ACTIONS(6877),
    [anon_sym_timeprecision] = ACTIONS(6877),
    [anon_sym_type] = ACTIONS(6877),
    [anon_sym_input] = ACTIONS(6877),
    [anon_sym_output] = ACTIONS(6877),
    [anon_sym_inout] = ACTIONS(6877),
    [anon_sym_ref] = ACTIONS(6877),
    [anon_sym_DOLLARfatal] = ACTIONS(6875),
    [anon_sym_DOLLARerror] = ACTIONS(6875),
    [anon_sym_DOLLARwarning] = ACTIONS(6875),
    [anon_sym_DOLLARinfo] = ACTIONS(6875),
    [anon_sym_default] = ACTIONS(6877),
    [anon_sym_clocking] = ACTIONS(6877),
    [anon_sym_defparam] = ACTIONS(6877),
    [anon_sym_bind] = ACTIONS(6877),
    [anon_sym_const] = ACTIONS(6877),
    [anon_sym_function] = ACTIONS(6877),
    [anon_sym_static] = ACTIONS(6877),
    [anon_sym_constraint] = ACTIONS(6877),
    [anon_sym_if] = ACTIONS(6877),
    [anon_sym_LBRACK] = ACTIONS(6875),
    [anon_sym_localparam] = ACTIONS(6877),
    [anon_sym_parameter] = ACTIONS(6877),
    [anon_sym_specparam] = ACTIONS(6877),
    [anon_sym_var] = ACTIONS(6877),
    [anon_sym_import] = ACTIONS(6877),
    [anon_sym_export] = ACTIONS(6877),
    [anon_sym_genvar] = ACTIONS(6877),
    [anon_sym_interconnect] = ACTIONS(6877),
    [anon_sym_typedef] = ACTIONS(6877),
    [anon_sym_enum] = ACTIONS(6877),
    [anon_sym_struct] = ACTIONS(6877),
    [anon_sym_union] = ACTIONS(6877),
    [anon_sym_nettype] = ACTIONS(6877),
    [anon_sym_automatic] = ACTIONS(6877),
    [anon_sym_string] = ACTIONS(6877),
    [anon_sym_chandle] = ACTIONS(6877),
    [anon_sym_event] = ACTIONS(6877),
    [anon_sym_byte] = ACTIONS(6877),
    [anon_sym_shortint] = ACTIONS(6877),
    [anon_sym_int] = ACTIONS(6877),
    [anon_sym_longint] = ACTIONS(6877),
    [anon_sym_integer] = ACTIONS(6877),
    [anon_sym_time] = ACTIONS(6877),
    [anon_sym_bit] = ACTIONS(6877),
    [anon_sym_logic] = ACTIONS(6877),
    [anon_sym_reg] = ACTIONS(6877),
    [anon_sym_shortreal] = ACTIONS(6877),
    [anon_sym_real] = ACTIONS(6877),
    [anon_sym_realtime] = ACTIONS(6877),
    [anon_sym_supply0] = ACTIONS(6877),
    [anon_sym_supply1] = ACTIONS(6877),
    [anon_sym_signed] = ACTIONS(6877),
    [anon_sym_unsigned] = ACTIONS(6877),
    [anon_sym_task] = ACTIONS(6877),
    [anon_sym_assert] = ACTIONS(6877),
    [anon_sym_property] = ACTIONS(6877),
    [anon_sym_assume] = ACTIONS(6877),
    [anon_sym_cover] = ACTIONS(6877),
    [anon_sym_sequence] = ACTIONS(6877),
    [anon_sym_restrict] = ACTIONS(6877),
    [anon_sym_not] = ACTIONS(6877),
    [anon_sym_or] = ACTIONS(6877),
    [anon_sym_and] = ACTIONS(6877),
    [anon_sym_case] = ACTIONS(6877),
    [anon_sym_always] = ACTIONS(6877),
    [anon_sym_covergroup] = ACTIONS(6877),
    [anon_sym_let] = ACTIONS(6877),
    [anon_sym_pulldown] = ACTIONS(6877),
    [anon_sym_pullup] = ACTIONS(6877),
    [anon_sym_cmos] = ACTIONS(6877),
    [anon_sym_rcmos] = ACTIONS(6877),
    [anon_sym_bufif0] = ACTIONS(6877),
    [anon_sym_bufif1] = ACTIONS(6877),
    [anon_sym_notif0] = ACTIONS(6877),
    [anon_sym_notif1] = ACTIONS(6877),
    [anon_sym_nmos] = ACTIONS(6877),
    [anon_sym_pmos] = ACTIONS(6877),
    [anon_sym_rnmos] = ACTIONS(6877),
    [anon_sym_rpmos] = ACTIONS(6877),
    [anon_sym_nand] = ACTIONS(6877),
    [anon_sym_nor] = ACTIONS(6877),
    [anon_sym_xor] = ACTIONS(6877),
    [anon_sym_xnor] = ACTIONS(6877),
    [anon_sym_buf] = ACTIONS(6877),
    [anon_sym_tranif0] = ACTIONS(6877),
    [anon_sym_tranif1] = ACTIONS(6877),
    [anon_sym_rtranif1] = ACTIONS(6877),
    [anon_sym_rtranif0] = ACTIONS(6877),
    [anon_sym_tran] = ACTIONS(6877),
    [anon_sym_rtran] = ACTIONS(6877),
    [anon_sym_generate] = ACTIONS(6877),
    [anon_sym_for] = ACTIONS(6877),
    [anon_sym_primitive] = ACTIONS(6877),
    [anon_sym_initial] = ACTIONS(6877),
    [anon_sym_assign] = ACTIONS(6877),
    [anon_sym_alias] = ACTIONS(6877),
    [anon_sym_always_comb] = ACTIONS(6877),
    [anon_sym_always_latch] = ACTIONS(6877),
    [anon_sym_always_ff] = ACTIONS(6877),
    [anon_sym_final] = ACTIONS(6877),
    [anon_sym_global] = ACTIONS(6877),
    [anon_sym_specify] = ACTIONS(6877),
    [anon_sym_LPAREN_STAR] = ACTIONS(6875),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6875),
    [anon_sym_DOLLARunit] = ACTIONS(6875),
  },
  [1278] = {
    [ts_builtin_sym_end] = ACTIONS(6879),
    [sym_simple_identifier] = ACTIONS(6881),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6879),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6879),
    [anon_sym_BQUOTE] = ACTIONS(6881),
    [aux_sym_id_directive_token1] = ACTIONS(6879),
    [aux_sym_id_directive_token2] = ACTIONS(6879),
    [aux_sym_id_directive_token3] = ACTIONS(6879),
    [aux_sym_id_directive_token4] = ACTIONS(6881),
    [aux_sym_zero_directive_token1] = ACTIONS(6879),
    [aux_sym_zero_directive_token2] = ACTIONS(6879),
    [aux_sym_zero_directive_token3] = ACTIONS(6879),
    [aux_sym_zero_directive_token4] = ACTIONS(6879),
    [aux_sym_zero_directive_token5] = ACTIONS(6879),
    [aux_sym_zero_directive_token6] = ACTIONS(6879),
    [aux_sym_zero_directive_token7] = ACTIONS(6879),
    [aux_sym_zero_directive_token8] = ACTIONS(6879),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6879),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6879),
    [anon_sym_wire] = ACTIONS(6881),
    [anon_sym_tri] = ACTIONS(6881),
    [anon_sym_tri0] = ACTIONS(6881),
    [anon_sym_tri1] = ACTIONS(6881),
    [anon_sym_wand] = ACTIONS(6881),
    [anon_sym_triand] = ACTIONS(6881),
    [anon_sym_wor] = ACTIONS(6881),
    [anon_sym_trior] = ACTIONS(6881),
    [anon_sym_trireg] = ACTIONS(6881),
    [anon_sym_uwire] = ACTIONS(6881),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6879),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6879),
    [aux_sym_begin_keywords_token1] = ACTIONS(6879),
    [anon_sym_SEMI] = ACTIONS(6879),
    [anon_sym_endmodule] = ACTIONS(6881),
    [anon_sym_extern] = ACTIONS(6881),
    [anon_sym_module] = ACTIONS(6881),
    [anon_sym_macromodule] = ACTIONS(6881),
    [anon_sym_interface] = ACTIONS(6881),
    [anon_sym_program] = ACTIONS(6881),
    [anon_sym_checker] = ACTIONS(6881),
    [anon_sym_virtual] = ACTIONS(6881),
    [anon_sym_class] = ACTIONS(6881),
    [anon_sym_package] = ACTIONS(6881),
    [anon_sym_timeunit] = ACTIONS(6881),
    [anon_sym_timeprecision] = ACTIONS(6881),
    [anon_sym_type] = ACTIONS(6881),
    [anon_sym_input] = ACTIONS(6881),
    [anon_sym_output] = ACTIONS(6881),
    [anon_sym_inout] = ACTIONS(6881),
    [anon_sym_ref] = ACTIONS(6881),
    [anon_sym_DOLLARfatal] = ACTIONS(6879),
    [anon_sym_DOLLARerror] = ACTIONS(6879),
    [anon_sym_DOLLARwarning] = ACTIONS(6879),
    [anon_sym_DOLLARinfo] = ACTIONS(6879),
    [anon_sym_default] = ACTIONS(6881),
    [anon_sym_clocking] = ACTIONS(6881),
    [anon_sym_defparam] = ACTIONS(6881),
    [anon_sym_bind] = ACTIONS(6881),
    [anon_sym_const] = ACTIONS(6881),
    [anon_sym_function] = ACTIONS(6881),
    [anon_sym_static] = ACTIONS(6881),
    [anon_sym_constraint] = ACTIONS(6881),
    [anon_sym_if] = ACTIONS(6881),
    [anon_sym_LBRACK] = ACTIONS(6879),
    [anon_sym_localparam] = ACTIONS(6881),
    [anon_sym_parameter] = ACTIONS(6881),
    [anon_sym_specparam] = ACTIONS(6881),
    [anon_sym_var] = ACTIONS(6881),
    [anon_sym_import] = ACTIONS(6881),
    [anon_sym_export] = ACTIONS(6881),
    [anon_sym_genvar] = ACTIONS(6881),
    [anon_sym_interconnect] = ACTIONS(6881),
    [anon_sym_typedef] = ACTIONS(6881),
    [anon_sym_enum] = ACTIONS(6881),
    [anon_sym_struct] = ACTIONS(6881),
    [anon_sym_union] = ACTIONS(6881),
    [anon_sym_nettype] = ACTIONS(6881),
    [anon_sym_automatic] = ACTIONS(6881),
    [anon_sym_string] = ACTIONS(6881),
    [anon_sym_chandle] = ACTIONS(6881),
    [anon_sym_event] = ACTIONS(6881),
    [anon_sym_byte] = ACTIONS(6881),
    [anon_sym_shortint] = ACTIONS(6881),
    [anon_sym_int] = ACTIONS(6881),
    [anon_sym_longint] = ACTIONS(6881),
    [anon_sym_integer] = ACTIONS(6881),
    [anon_sym_time] = ACTIONS(6881),
    [anon_sym_bit] = ACTIONS(6881),
    [anon_sym_logic] = ACTIONS(6881),
    [anon_sym_reg] = ACTIONS(6881),
    [anon_sym_shortreal] = ACTIONS(6881),
    [anon_sym_real] = ACTIONS(6881),
    [anon_sym_realtime] = ACTIONS(6881),
    [anon_sym_supply0] = ACTIONS(6881),
    [anon_sym_supply1] = ACTIONS(6881),
    [anon_sym_signed] = ACTIONS(6881),
    [anon_sym_unsigned] = ACTIONS(6881),
    [anon_sym_task] = ACTIONS(6881),
    [anon_sym_assert] = ACTIONS(6881),
    [anon_sym_property] = ACTIONS(6881),
    [anon_sym_assume] = ACTIONS(6881),
    [anon_sym_cover] = ACTIONS(6881),
    [anon_sym_sequence] = ACTIONS(6881),
    [anon_sym_restrict] = ACTIONS(6881),
    [anon_sym_not] = ACTIONS(6881),
    [anon_sym_or] = ACTIONS(6881),
    [anon_sym_and] = ACTIONS(6881),
    [anon_sym_case] = ACTIONS(6881),
    [anon_sym_always] = ACTIONS(6881),
    [anon_sym_covergroup] = ACTIONS(6881),
    [anon_sym_let] = ACTIONS(6881),
    [anon_sym_pulldown] = ACTIONS(6881),
    [anon_sym_pullup] = ACTIONS(6881),
    [anon_sym_cmos] = ACTIONS(6881),
    [anon_sym_rcmos] = ACTIONS(6881),
    [anon_sym_bufif0] = ACTIONS(6881),
    [anon_sym_bufif1] = ACTIONS(6881),
    [anon_sym_notif0] = ACTIONS(6881),
    [anon_sym_notif1] = ACTIONS(6881),
    [anon_sym_nmos] = ACTIONS(6881),
    [anon_sym_pmos] = ACTIONS(6881),
    [anon_sym_rnmos] = ACTIONS(6881),
    [anon_sym_rpmos] = ACTIONS(6881),
    [anon_sym_nand] = ACTIONS(6881),
    [anon_sym_nor] = ACTIONS(6881),
    [anon_sym_xor] = ACTIONS(6881),
    [anon_sym_xnor] = ACTIONS(6881),
    [anon_sym_buf] = ACTIONS(6881),
    [anon_sym_tranif0] = ACTIONS(6881),
    [anon_sym_tranif1] = ACTIONS(6881),
    [anon_sym_rtranif1] = ACTIONS(6881),
    [anon_sym_rtranif0] = ACTIONS(6881),
    [anon_sym_tran] = ACTIONS(6881),
    [anon_sym_rtran] = ACTIONS(6881),
    [anon_sym_generate] = ACTIONS(6881),
    [anon_sym_for] = ACTIONS(6881),
    [anon_sym_primitive] = ACTIONS(6881),
    [anon_sym_initial] = ACTIONS(6881),
    [anon_sym_assign] = ACTIONS(6881),
    [anon_sym_alias] = ACTIONS(6881),
    [anon_sym_always_comb] = ACTIONS(6881),
    [anon_sym_always_latch] = ACTIONS(6881),
    [anon_sym_always_ff] = ACTIONS(6881),
    [anon_sym_final] = ACTIONS(6881),
    [anon_sym_global] = ACTIONS(6881),
    [anon_sym_specify] = ACTIONS(6881),
    [anon_sym_LPAREN_STAR] = ACTIONS(6879),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6879),
    [anon_sym_DOLLARunit] = ACTIONS(6879),
  },
  [1279] = {
    [ts_builtin_sym_end] = ACTIONS(6883),
    [sym_simple_identifier] = ACTIONS(6885),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6883),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6883),
    [anon_sym_BQUOTE] = ACTIONS(6885),
    [aux_sym_id_directive_token1] = ACTIONS(6883),
    [aux_sym_id_directive_token2] = ACTIONS(6883),
    [aux_sym_id_directive_token3] = ACTIONS(6883),
    [aux_sym_id_directive_token4] = ACTIONS(6885),
    [aux_sym_zero_directive_token1] = ACTIONS(6883),
    [aux_sym_zero_directive_token2] = ACTIONS(6883),
    [aux_sym_zero_directive_token3] = ACTIONS(6883),
    [aux_sym_zero_directive_token4] = ACTIONS(6883),
    [aux_sym_zero_directive_token5] = ACTIONS(6883),
    [aux_sym_zero_directive_token6] = ACTIONS(6883),
    [aux_sym_zero_directive_token7] = ACTIONS(6883),
    [aux_sym_zero_directive_token8] = ACTIONS(6883),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6883),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6883),
    [anon_sym_wire] = ACTIONS(6885),
    [anon_sym_tri] = ACTIONS(6885),
    [anon_sym_tri0] = ACTIONS(6885),
    [anon_sym_tri1] = ACTIONS(6885),
    [anon_sym_wand] = ACTIONS(6885),
    [anon_sym_triand] = ACTIONS(6885),
    [anon_sym_wor] = ACTIONS(6885),
    [anon_sym_trior] = ACTIONS(6885),
    [anon_sym_trireg] = ACTIONS(6885),
    [anon_sym_uwire] = ACTIONS(6885),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6883),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6883),
    [aux_sym_begin_keywords_token1] = ACTIONS(6883),
    [anon_sym_SEMI] = ACTIONS(6883),
    [anon_sym_endmodule] = ACTIONS(6885),
    [anon_sym_extern] = ACTIONS(6885),
    [anon_sym_module] = ACTIONS(6885),
    [anon_sym_macromodule] = ACTIONS(6885),
    [anon_sym_interface] = ACTIONS(6885),
    [anon_sym_program] = ACTIONS(6885),
    [anon_sym_checker] = ACTIONS(6885),
    [anon_sym_virtual] = ACTIONS(6885),
    [anon_sym_class] = ACTIONS(6885),
    [anon_sym_package] = ACTIONS(6885),
    [anon_sym_timeunit] = ACTIONS(6885),
    [anon_sym_timeprecision] = ACTIONS(6885),
    [anon_sym_type] = ACTIONS(6885),
    [anon_sym_input] = ACTIONS(6885),
    [anon_sym_output] = ACTIONS(6885),
    [anon_sym_inout] = ACTIONS(6885),
    [anon_sym_ref] = ACTIONS(6885),
    [anon_sym_DOLLARfatal] = ACTIONS(6883),
    [anon_sym_DOLLARerror] = ACTIONS(6883),
    [anon_sym_DOLLARwarning] = ACTIONS(6883),
    [anon_sym_DOLLARinfo] = ACTIONS(6883),
    [anon_sym_default] = ACTIONS(6885),
    [anon_sym_clocking] = ACTIONS(6885),
    [anon_sym_defparam] = ACTIONS(6885),
    [anon_sym_bind] = ACTIONS(6885),
    [anon_sym_const] = ACTIONS(6885),
    [anon_sym_function] = ACTIONS(6885),
    [anon_sym_static] = ACTIONS(6885),
    [anon_sym_constraint] = ACTIONS(6885),
    [anon_sym_if] = ACTIONS(6885),
    [anon_sym_LBRACK] = ACTIONS(6883),
    [anon_sym_localparam] = ACTIONS(6885),
    [anon_sym_parameter] = ACTIONS(6885),
    [anon_sym_specparam] = ACTIONS(6885),
    [anon_sym_var] = ACTIONS(6885),
    [anon_sym_import] = ACTIONS(6885),
    [anon_sym_export] = ACTIONS(6885),
    [anon_sym_genvar] = ACTIONS(6885),
    [anon_sym_interconnect] = ACTIONS(6885),
    [anon_sym_typedef] = ACTIONS(6885),
    [anon_sym_enum] = ACTIONS(6885),
    [anon_sym_struct] = ACTIONS(6885),
    [anon_sym_union] = ACTIONS(6885),
    [anon_sym_nettype] = ACTIONS(6885),
    [anon_sym_automatic] = ACTIONS(6885),
    [anon_sym_string] = ACTIONS(6885),
    [anon_sym_chandle] = ACTIONS(6885),
    [anon_sym_event] = ACTIONS(6885),
    [anon_sym_byte] = ACTIONS(6885),
    [anon_sym_shortint] = ACTIONS(6885),
    [anon_sym_int] = ACTIONS(6885),
    [anon_sym_longint] = ACTIONS(6885),
    [anon_sym_integer] = ACTIONS(6885),
    [anon_sym_time] = ACTIONS(6885),
    [anon_sym_bit] = ACTIONS(6885),
    [anon_sym_logic] = ACTIONS(6885),
    [anon_sym_reg] = ACTIONS(6885),
    [anon_sym_shortreal] = ACTIONS(6885),
    [anon_sym_real] = ACTIONS(6885),
    [anon_sym_realtime] = ACTIONS(6885),
    [anon_sym_supply0] = ACTIONS(6885),
    [anon_sym_supply1] = ACTIONS(6885),
    [anon_sym_signed] = ACTIONS(6885),
    [anon_sym_unsigned] = ACTIONS(6885),
    [anon_sym_task] = ACTIONS(6885),
    [anon_sym_assert] = ACTIONS(6885),
    [anon_sym_property] = ACTIONS(6885),
    [anon_sym_assume] = ACTIONS(6885),
    [anon_sym_cover] = ACTIONS(6885),
    [anon_sym_sequence] = ACTIONS(6885),
    [anon_sym_restrict] = ACTIONS(6885),
    [anon_sym_not] = ACTIONS(6885),
    [anon_sym_or] = ACTIONS(6885),
    [anon_sym_and] = ACTIONS(6885),
    [anon_sym_case] = ACTIONS(6885),
    [anon_sym_always] = ACTIONS(6885),
    [anon_sym_covergroup] = ACTIONS(6885),
    [anon_sym_let] = ACTIONS(6885),
    [anon_sym_pulldown] = ACTIONS(6885),
    [anon_sym_pullup] = ACTIONS(6885),
    [anon_sym_cmos] = ACTIONS(6885),
    [anon_sym_rcmos] = ACTIONS(6885),
    [anon_sym_bufif0] = ACTIONS(6885),
    [anon_sym_bufif1] = ACTIONS(6885),
    [anon_sym_notif0] = ACTIONS(6885),
    [anon_sym_notif1] = ACTIONS(6885),
    [anon_sym_nmos] = ACTIONS(6885),
    [anon_sym_pmos] = ACTIONS(6885),
    [anon_sym_rnmos] = ACTIONS(6885),
    [anon_sym_rpmos] = ACTIONS(6885),
    [anon_sym_nand] = ACTIONS(6885),
    [anon_sym_nor] = ACTIONS(6885),
    [anon_sym_xor] = ACTIONS(6885),
    [anon_sym_xnor] = ACTIONS(6885),
    [anon_sym_buf] = ACTIONS(6885),
    [anon_sym_tranif0] = ACTIONS(6885),
    [anon_sym_tranif1] = ACTIONS(6885),
    [anon_sym_rtranif1] = ACTIONS(6885),
    [anon_sym_rtranif0] = ACTIONS(6885),
    [anon_sym_tran] = ACTIONS(6885),
    [anon_sym_rtran] = ACTIONS(6885),
    [anon_sym_generate] = ACTIONS(6885),
    [anon_sym_for] = ACTIONS(6885),
    [anon_sym_primitive] = ACTIONS(6885),
    [anon_sym_initial] = ACTIONS(6885),
    [anon_sym_assign] = ACTIONS(6885),
    [anon_sym_alias] = ACTIONS(6885),
    [anon_sym_always_comb] = ACTIONS(6885),
    [anon_sym_always_latch] = ACTIONS(6885),
    [anon_sym_always_ff] = ACTIONS(6885),
    [anon_sym_final] = ACTIONS(6885),
    [anon_sym_global] = ACTIONS(6885),
    [anon_sym_specify] = ACTIONS(6885),
    [anon_sym_LPAREN_STAR] = ACTIONS(6883),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6883),
    [anon_sym_DOLLARunit] = ACTIONS(6883),
  },
  [1280] = {
    [ts_builtin_sym_end] = ACTIONS(6677),
    [sym_simple_identifier] = ACTIONS(6679),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6677),
    [anon_sym_BQUOTE] = ACTIONS(6679),
    [aux_sym_id_directive_token1] = ACTIONS(6677),
    [aux_sym_id_directive_token2] = ACTIONS(6677),
    [aux_sym_id_directive_token3] = ACTIONS(6677),
    [aux_sym_id_directive_token4] = ACTIONS(6679),
    [aux_sym_zero_directive_token1] = ACTIONS(6677),
    [aux_sym_zero_directive_token2] = ACTIONS(6677),
    [aux_sym_zero_directive_token3] = ACTIONS(6677),
    [aux_sym_zero_directive_token4] = ACTIONS(6677),
    [aux_sym_zero_directive_token5] = ACTIONS(6677),
    [aux_sym_zero_directive_token6] = ACTIONS(6677),
    [aux_sym_zero_directive_token7] = ACTIONS(6677),
    [aux_sym_zero_directive_token8] = ACTIONS(6677),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6677),
    [anon_sym_wire] = ACTIONS(6679),
    [anon_sym_tri] = ACTIONS(6679),
    [anon_sym_tri0] = ACTIONS(6679),
    [anon_sym_tri1] = ACTIONS(6679),
    [anon_sym_wand] = ACTIONS(6679),
    [anon_sym_triand] = ACTIONS(6679),
    [anon_sym_wor] = ACTIONS(6679),
    [anon_sym_trior] = ACTIONS(6679),
    [anon_sym_trireg] = ACTIONS(6679),
    [anon_sym_uwire] = ACTIONS(6679),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6677),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6677),
    [aux_sym_begin_keywords_token1] = ACTIONS(6677),
    [anon_sym_SEMI] = ACTIONS(6677),
    [anon_sym_endmodule] = ACTIONS(6679),
    [anon_sym_extern] = ACTIONS(6679),
    [anon_sym_module] = ACTIONS(6679),
    [anon_sym_macromodule] = ACTIONS(6679),
    [anon_sym_interface] = ACTIONS(6679),
    [anon_sym_program] = ACTIONS(6679),
    [anon_sym_checker] = ACTIONS(6679),
    [anon_sym_virtual] = ACTIONS(6679),
    [anon_sym_class] = ACTIONS(6679),
    [anon_sym_package] = ACTIONS(6679),
    [anon_sym_timeunit] = ACTIONS(6679),
    [anon_sym_timeprecision] = ACTIONS(6679),
    [anon_sym_type] = ACTIONS(6679),
    [anon_sym_input] = ACTIONS(6679),
    [anon_sym_output] = ACTIONS(6679),
    [anon_sym_inout] = ACTIONS(6679),
    [anon_sym_ref] = ACTIONS(6679),
    [anon_sym_DOLLARfatal] = ACTIONS(6677),
    [anon_sym_DOLLARerror] = ACTIONS(6677),
    [anon_sym_DOLLARwarning] = ACTIONS(6677),
    [anon_sym_DOLLARinfo] = ACTIONS(6677),
    [anon_sym_default] = ACTIONS(6679),
    [anon_sym_clocking] = ACTIONS(6679),
    [anon_sym_defparam] = ACTIONS(6679),
    [anon_sym_bind] = ACTIONS(6679),
    [anon_sym_const] = ACTIONS(6679),
    [anon_sym_function] = ACTIONS(6679),
    [anon_sym_static] = ACTIONS(6679),
    [anon_sym_constraint] = ACTIONS(6679),
    [anon_sym_if] = ACTIONS(6679),
    [anon_sym_LBRACK] = ACTIONS(6677),
    [anon_sym_localparam] = ACTIONS(6679),
    [anon_sym_parameter] = ACTIONS(6679),
    [anon_sym_specparam] = ACTIONS(6679),
    [anon_sym_var] = ACTIONS(6679),
    [anon_sym_import] = ACTIONS(6679),
    [anon_sym_export] = ACTIONS(6679),
    [anon_sym_genvar] = ACTIONS(6679),
    [anon_sym_interconnect] = ACTIONS(6679),
    [anon_sym_typedef] = ACTIONS(6679),
    [anon_sym_enum] = ACTIONS(6679),
    [anon_sym_struct] = ACTIONS(6679),
    [anon_sym_union] = ACTIONS(6679),
    [anon_sym_nettype] = ACTIONS(6679),
    [anon_sym_automatic] = ACTIONS(6679),
    [anon_sym_string] = ACTIONS(6679),
    [anon_sym_chandle] = ACTIONS(6679),
    [anon_sym_event] = ACTIONS(6679),
    [anon_sym_byte] = ACTIONS(6679),
    [anon_sym_shortint] = ACTIONS(6679),
    [anon_sym_int] = ACTIONS(6679),
    [anon_sym_longint] = ACTIONS(6679),
    [anon_sym_integer] = ACTIONS(6679),
    [anon_sym_time] = ACTIONS(6679),
    [anon_sym_bit] = ACTIONS(6679),
    [anon_sym_logic] = ACTIONS(6679),
    [anon_sym_reg] = ACTIONS(6679),
    [anon_sym_shortreal] = ACTIONS(6679),
    [anon_sym_real] = ACTIONS(6679),
    [anon_sym_realtime] = ACTIONS(6679),
    [anon_sym_supply0] = ACTIONS(6679),
    [anon_sym_supply1] = ACTIONS(6679),
    [anon_sym_signed] = ACTIONS(6679),
    [anon_sym_unsigned] = ACTIONS(6679),
    [anon_sym_task] = ACTIONS(6679),
    [anon_sym_assert] = ACTIONS(6679),
    [anon_sym_property] = ACTIONS(6679),
    [anon_sym_assume] = ACTIONS(6679),
    [anon_sym_cover] = ACTIONS(6679),
    [anon_sym_sequence] = ACTIONS(6679),
    [anon_sym_restrict] = ACTIONS(6679),
    [anon_sym_not] = ACTIONS(6679),
    [anon_sym_or] = ACTIONS(6679),
    [anon_sym_and] = ACTIONS(6679),
    [anon_sym_case] = ACTIONS(6679),
    [anon_sym_always] = ACTIONS(6679),
    [anon_sym_covergroup] = ACTIONS(6679),
    [anon_sym_let] = ACTIONS(6679),
    [anon_sym_pulldown] = ACTIONS(6679),
    [anon_sym_pullup] = ACTIONS(6679),
    [anon_sym_cmos] = ACTIONS(6679),
    [anon_sym_rcmos] = ACTIONS(6679),
    [anon_sym_bufif0] = ACTIONS(6679),
    [anon_sym_bufif1] = ACTIONS(6679),
    [anon_sym_notif0] = ACTIONS(6679),
    [anon_sym_notif1] = ACTIONS(6679),
    [anon_sym_nmos] = ACTIONS(6679),
    [anon_sym_pmos] = ACTIONS(6679),
    [anon_sym_rnmos] = ACTIONS(6679),
    [anon_sym_rpmos] = ACTIONS(6679),
    [anon_sym_nand] = ACTIONS(6679),
    [anon_sym_nor] = ACTIONS(6679),
    [anon_sym_xor] = ACTIONS(6679),
    [anon_sym_xnor] = ACTIONS(6679),
    [anon_sym_buf] = ACTIONS(6679),
    [anon_sym_tranif0] = ACTIONS(6679),
    [anon_sym_tranif1] = ACTIONS(6679),
    [anon_sym_rtranif1] = ACTIONS(6679),
    [anon_sym_rtranif0] = ACTIONS(6679),
    [anon_sym_tran] = ACTIONS(6679),
    [anon_sym_rtran] = ACTIONS(6679),
    [anon_sym_generate] = ACTIONS(6679),
    [anon_sym_for] = ACTIONS(6679),
    [anon_sym_primitive] = ACTIONS(6679),
    [anon_sym_initial] = ACTIONS(6679),
    [anon_sym_assign] = ACTIONS(6679),
    [anon_sym_alias] = ACTIONS(6679),
    [anon_sym_always_comb] = ACTIONS(6679),
    [anon_sym_always_latch] = ACTIONS(6679),
    [anon_sym_always_ff] = ACTIONS(6679),
    [anon_sym_final] = ACTIONS(6679),
    [anon_sym_global] = ACTIONS(6679),
    [anon_sym_specify] = ACTIONS(6679),
    [anon_sym_LPAREN_STAR] = ACTIONS(6677),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6677),
    [anon_sym_DOLLARunit] = ACTIONS(6677),
  },
  [1281] = {
    [ts_builtin_sym_end] = ACTIONS(6621),
    [sym_simple_identifier] = ACTIONS(6623),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6621),
    [anon_sym_BQUOTE] = ACTIONS(6623),
    [aux_sym_id_directive_token1] = ACTIONS(6621),
    [aux_sym_id_directive_token2] = ACTIONS(6621),
    [aux_sym_id_directive_token3] = ACTIONS(6621),
    [aux_sym_id_directive_token4] = ACTIONS(6623),
    [aux_sym_zero_directive_token1] = ACTIONS(6621),
    [aux_sym_zero_directive_token2] = ACTIONS(6621),
    [aux_sym_zero_directive_token3] = ACTIONS(6621),
    [aux_sym_zero_directive_token4] = ACTIONS(6621),
    [aux_sym_zero_directive_token5] = ACTIONS(6621),
    [aux_sym_zero_directive_token6] = ACTIONS(6621),
    [aux_sym_zero_directive_token7] = ACTIONS(6621),
    [aux_sym_zero_directive_token8] = ACTIONS(6621),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6621),
    [anon_sym_wire] = ACTIONS(6623),
    [anon_sym_tri] = ACTIONS(6623),
    [anon_sym_tri0] = ACTIONS(6623),
    [anon_sym_tri1] = ACTIONS(6623),
    [anon_sym_wand] = ACTIONS(6623),
    [anon_sym_triand] = ACTIONS(6623),
    [anon_sym_wor] = ACTIONS(6623),
    [anon_sym_trior] = ACTIONS(6623),
    [anon_sym_trireg] = ACTIONS(6623),
    [anon_sym_uwire] = ACTIONS(6623),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6621),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6621),
    [aux_sym_begin_keywords_token1] = ACTIONS(6621),
    [anon_sym_SEMI] = ACTIONS(6621),
    [anon_sym_endmodule] = ACTIONS(6623),
    [anon_sym_extern] = ACTIONS(6623),
    [anon_sym_module] = ACTIONS(6623),
    [anon_sym_macromodule] = ACTIONS(6623),
    [anon_sym_interface] = ACTIONS(6623),
    [anon_sym_program] = ACTIONS(6623),
    [anon_sym_checker] = ACTIONS(6623),
    [anon_sym_virtual] = ACTIONS(6623),
    [anon_sym_class] = ACTIONS(6623),
    [anon_sym_package] = ACTIONS(6623),
    [anon_sym_timeunit] = ACTIONS(6623),
    [anon_sym_timeprecision] = ACTIONS(6623),
    [anon_sym_type] = ACTIONS(6623),
    [anon_sym_input] = ACTIONS(6623),
    [anon_sym_output] = ACTIONS(6623),
    [anon_sym_inout] = ACTIONS(6623),
    [anon_sym_ref] = ACTIONS(6623),
    [anon_sym_DOLLARfatal] = ACTIONS(6621),
    [anon_sym_DOLLARerror] = ACTIONS(6621),
    [anon_sym_DOLLARwarning] = ACTIONS(6621),
    [anon_sym_DOLLARinfo] = ACTIONS(6621),
    [anon_sym_default] = ACTIONS(6623),
    [anon_sym_clocking] = ACTIONS(6623),
    [anon_sym_defparam] = ACTIONS(6623),
    [anon_sym_bind] = ACTIONS(6623),
    [anon_sym_const] = ACTIONS(6623),
    [anon_sym_function] = ACTIONS(6623),
    [anon_sym_static] = ACTIONS(6623),
    [anon_sym_constraint] = ACTIONS(6623),
    [anon_sym_if] = ACTIONS(6623),
    [anon_sym_LBRACK] = ACTIONS(6621),
    [anon_sym_localparam] = ACTIONS(6623),
    [anon_sym_parameter] = ACTIONS(6623),
    [anon_sym_specparam] = ACTIONS(6623),
    [anon_sym_var] = ACTIONS(6623),
    [anon_sym_import] = ACTIONS(6623),
    [anon_sym_export] = ACTIONS(6623),
    [anon_sym_genvar] = ACTIONS(6623),
    [anon_sym_interconnect] = ACTIONS(6623),
    [anon_sym_typedef] = ACTIONS(6623),
    [anon_sym_enum] = ACTIONS(6623),
    [anon_sym_struct] = ACTIONS(6623),
    [anon_sym_union] = ACTIONS(6623),
    [anon_sym_nettype] = ACTIONS(6623),
    [anon_sym_automatic] = ACTIONS(6623),
    [anon_sym_string] = ACTIONS(6623),
    [anon_sym_chandle] = ACTIONS(6623),
    [anon_sym_event] = ACTIONS(6623),
    [anon_sym_byte] = ACTIONS(6623),
    [anon_sym_shortint] = ACTIONS(6623),
    [anon_sym_int] = ACTIONS(6623),
    [anon_sym_longint] = ACTIONS(6623),
    [anon_sym_integer] = ACTIONS(6623),
    [anon_sym_time] = ACTIONS(6623),
    [anon_sym_bit] = ACTIONS(6623),
    [anon_sym_logic] = ACTIONS(6623),
    [anon_sym_reg] = ACTIONS(6623),
    [anon_sym_shortreal] = ACTIONS(6623),
    [anon_sym_real] = ACTIONS(6623),
    [anon_sym_realtime] = ACTIONS(6623),
    [anon_sym_supply0] = ACTIONS(6623),
    [anon_sym_supply1] = ACTIONS(6623),
    [anon_sym_signed] = ACTIONS(6623),
    [anon_sym_unsigned] = ACTIONS(6623),
    [anon_sym_task] = ACTIONS(6623),
    [anon_sym_assert] = ACTIONS(6623),
    [anon_sym_property] = ACTIONS(6623),
    [anon_sym_assume] = ACTIONS(6623),
    [anon_sym_cover] = ACTIONS(6623),
    [anon_sym_sequence] = ACTIONS(6623),
    [anon_sym_restrict] = ACTIONS(6623),
    [anon_sym_not] = ACTIONS(6623),
    [anon_sym_or] = ACTIONS(6623),
    [anon_sym_and] = ACTIONS(6623),
    [anon_sym_case] = ACTIONS(6623),
    [anon_sym_always] = ACTIONS(6623),
    [anon_sym_covergroup] = ACTIONS(6623),
    [anon_sym_let] = ACTIONS(6623),
    [anon_sym_pulldown] = ACTIONS(6623),
    [anon_sym_pullup] = ACTIONS(6623),
    [anon_sym_cmos] = ACTIONS(6623),
    [anon_sym_rcmos] = ACTIONS(6623),
    [anon_sym_bufif0] = ACTIONS(6623),
    [anon_sym_bufif1] = ACTIONS(6623),
    [anon_sym_notif0] = ACTIONS(6623),
    [anon_sym_notif1] = ACTIONS(6623),
    [anon_sym_nmos] = ACTIONS(6623),
    [anon_sym_pmos] = ACTIONS(6623),
    [anon_sym_rnmos] = ACTIONS(6623),
    [anon_sym_rpmos] = ACTIONS(6623),
    [anon_sym_nand] = ACTIONS(6623),
    [anon_sym_nor] = ACTIONS(6623),
    [anon_sym_xor] = ACTIONS(6623),
    [anon_sym_xnor] = ACTIONS(6623),
    [anon_sym_buf] = ACTIONS(6623),
    [anon_sym_tranif0] = ACTIONS(6623),
    [anon_sym_tranif1] = ACTIONS(6623),
    [anon_sym_rtranif1] = ACTIONS(6623),
    [anon_sym_rtranif0] = ACTIONS(6623),
    [anon_sym_tran] = ACTIONS(6623),
    [anon_sym_rtran] = ACTIONS(6623),
    [anon_sym_generate] = ACTIONS(6623),
    [anon_sym_for] = ACTIONS(6623),
    [anon_sym_primitive] = ACTIONS(6623),
    [anon_sym_initial] = ACTIONS(6623),
    [anon_sym_assign] = ACTIONS(6623),
    [anon_sym_alias] = ACTIONS(6623),
    [anon_sym_always_comb] = ACTIONS(6623),
    [anon_sym_always_latch] = ACTIONS(6623),
    [anon_sym_always_ff] = ACTIONS(6623),
    [anon_sym_final] = ACTIONS(6623),
    [anon_sym_global] = ACTIONS(6623),
    [anon_sym_specify] = ACTIONS(6623),
    [anon_sym_LPAREN_STAR] = ACTIONS(6621),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6621),
    [anon_sym_DOLLARunit] = ACTIONS(6621),
  },
  [1282] = {
    [ts_builtin_sym_end] = ACTIONS(6887),
    [sym_simple_identifier] = ACTIONS(6890),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6887),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6887),
    [anon_sym_BQUOTE] = ACTIONS(6890),
    [aux_sym_id_directive_token1] = ACTIONS(6887),
    [aux_sym_id_directive_token2] = ACTIONS(6887),
    [aux_sym_id_directive_token3] = ACTIONS(6887),
    [aux_sym_id_directive_token4] = ACTIONS(6890),
    [aux_sym_zero_directive_token1] = ACTIONS(6887),
    [aux_sym_zero_directive_token2] = ACTIONS(6887),
    [aux_sym_zero_directive_token3] = ACTIONS(6887),
    [aux_sym_zero_directive_token4] = ACTIONS(6887),
    [aux_sym_zero_directive_token5] = ACTIONS(6887),
    [aux_sym_zero_directive_token6] = ACTIONS(6887),
    [aux_sym_zero_directive_token7] = ACTIONS(6887),
    [aux_sym_zero_directive_token8] = ACTIONS(6887),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6887),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6887),
    [anon_sym_wire] = ACTIONS(6890),
    [anon_sym_tri] = ACTIONS(6890),
    [anon_sym_tri0] = ACTIONS(6890),
    [anon_sym_tri1] = ACTIONS(6890),
    [anon_sym_wand] = ACTIONS(6890),
    [anon_sym_triand] = ACTIONS(6890),
    [anon_sym_wor] = ACTIONS(6890),
    [anon_sym_trior] = ACTIONS(6890),
    [anon_sym_trireg] = ACTIONS(6890),
    [anon_sym_uwire] = ACTIONS(6890),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6887),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6887),
    [aux_sym_begin_keywords_token1] = ACTIONS(6887),
    [anon_sym_SEMI] = ACTIONS(6887),
    [anon_sym_endmodule] = ACTIONS(6890),
    [anon_sym_extern] = ACTIONS(6890),
    [anon_sym_module] = ACTIONS(6890),
    [anon_sym_macromodule] = ACTIONS(6890),
    [anon_sym_interface] = ACTIONS(6890),
    [anon_sym_program] = ACTIONS(6890),
    [anon_sym_checker] = ACTIONS(6890),
    [anon_sym_virtual] = ACTIONS(6890),
    [anon_sym_class] = ACTIONS(6890),
    [anon_sym_package] = ACTIONS(6890),
    [anon_sym_timeunit] = ACTIONS(6890),
    [anon_sym_timeprecision] = ACTIONS(6890),
    [anon_sym_type] = ACTIONS(6890),
    [anon_sym_input] = ACTIONS(6890),
    [anon_sym_output] = ACTIONS(6890),
    [anon_sym_inout] = ACTIONS(6890),
    [anon_sym_ref] = ACTIONS(6890),
    [anon_sym_DOLLARfatal] = ACTIONS(6887),
    [anon_sym_DOLLARerror] = ACTIONS(6887),
    [anon_sym_DOLLARwarning] = ACTIONS(6887),
    [anon_sym_DOLLARinfo] = ACTIONS(6887),
    [anon_sym_default] = ACTIONS(6890),
    [anon_sym_clocking] = ACTIONS(6890),
    [anon_sym_defparam] = ACTIONS(6890),
    [anon_sym_bind] = ACTIONS(6890),
    [anon_sym_const] = ACTIONS(6890),
    [anon_sym_function] = ACTIONS(6890),
    [anon_sym_static] = ACTIONS(6890),
    [anon_sym_constraint] = ACTIONS(6890),
    [anon_sym_if] = ACTIONS(6890),
    [anon_sym_LBRACK] = ACTIONS(6887),
    [anon_sym_localparam] = ACTIONS(6890),
    [anon_sym_parameter] = ACTIONS(6890),
    [anon_sym_specparam] = ACTIONS(6890),
    [anon_sym_var] = ACTIONS(6890),
    [anon_sym_import] = ACTIONS(6890),
    [anon_sym_export] = ACTIONS(6890),
    [anon_sym_genvar] = ACTIONS(6890),
    [anon_sym_interconnect] = ACTIONS(6890),
    [anon_sym_typedef] = ACTIONS(6890),
    [anon_sym_enum] = ACTIONS(6890),
    [anon_sym_struct] = ACTIONS(6890),
    [anon_sym_union] = ACTIONS(6890),
    [anon_sym_nettype] = ACTIONS(6890),
    [anon_sym_automatic] = ACTIONS(6890),
    [anon_sym_string] = ACTIONS(6890),
    [anon_sym_chandle] = ACTIONS(6890),
    [anon_sym_event] = ACTIONS(6890),
    [anon_sym_byte] = ACTIONS(6890),
    [anon_sym_shortint] = ACTIONS(6890),
    [anon_sym_int] = ACTIONS(6890),
    [anon_sym_longint] = ACTIONS(6890),
    [anon_sym_integer] = ACTIONS(6890),
    [anon_sym_time] = ACTIONS(6890),
    [anon_sym_bit] = ACTIONS(6890),
    [anon_sym_logic] = ACTIONS(6890),
    [anon_sym_reg] = ACTIONS(6890),
    [anon_sym_shortreal] = ACTIONS(6890),
    [anon_sym_real] = ACTIONS(6890),
    [anon_sym_realtime] = ACTIONS(6890),
    [anon_sym_supply0] = ACTIONS(6890),
    [anon_sym_supply1] = ACTIONS(6890),
    [anon_sym_signed] = ACTIONS(6890),
    [anon_sym_unsigned] = ACTIONS(6890),
    [anon_sym_task] = ACTIONS(6890),
    [anon_sym_assert] = ACTIONS(6890),
    [anon_sym_property] = ACTIONS(6890),
    [anon_sym_assume] = ACTIONS(6890),
    [anon_sym_cover] = ACTIONS(6890),
    [anon_sym_sequence] = ACTIONS(6890),
    [anon_sym_restrict] = ACTIONS(6890),
    [anon_sym_not] = ACTIONS(6890),
    [anon_sym_or] = ACTIONS(6890),
    [anon_sym_and] = ACTIONS(6890),
    [anon_sym_case] = ACTIONS(6890),
    [anon_sym_always] = ACTIONS(6890),
    [anon_sym_covergroup] = ACTIONS(6890),
    [anon_sym_let] = ACTIONS(6890),
    [anon_sym_pulldown] = ACTIONS(6890),
    [anon_sym_pullup] = ACTIONS(6890),
    [anon_sym_cmos] = ACTIONS(6890),
    [anon_sym_rcmos] = ACTIONS(6890),
    [anon_sym_bufif0] = ACTIONS(6890),
    [anon_sym_bufif1] = ACTIONS(6890),
    [anon_sym_notif0] = ACTIONS(6890),
    [anon_sym_notif1] = ACTIONS(6890),
    [anon_sym_nmos] = ACTIONS(6890),
    [anon_sym_pmos] = ACTIONS(6890),
    [anon_sym_rnmos] = ACTIONS(6890),
    [anon_sym_rpmos] = ACTIONS(6890),
    [anon_sym_nand] = ACTIONS(6890),
    [anon_sym_nor] = ACTIONS(6890),
    [anon_sym_xor] = ACTIONS(6890),
    [anon_sym_xnor] = ACTIONS(6890),
    [anon_sym_buf] = ACTIONS(6890),
    [anon_sym_tranif0] = ACTIONS(6890),
    [anon_sym_tranif1] = ACTIONS(6890),
    [anon_sym_rtranif1] = ACTIONS(6890),
    [anon_sym_rtranif0] = ACTIONS(6890),
    [anon_sym_tran] = ACTIONS(6890),
    [anon_sym_rtran] = ACTIONS(6890),
    [anon_sym_generate] = ACTIONS(6890),
    [anon_sym_for] = ACTIONS(6890),
    [anon_sym_primitive] = ACTIONS(6890),
    [anon_sym_initial] = ACTIONS(6890),
    [anon_sym_assign] = ACTIONS(6890),
    [anon_sym_alias] = ACTIONS(6890),
    [anon_sym_always_comb] = ACTIONS(6890),
    [anon_sym_always_latch] = ACTIONS(6890),
    [anon_sym_always_ff] = ACTIONS(6890),
    [anon_sym_final] = ACTIONS(6890),
    [anon_sym_global] = ACTIONS(6890),
    [anon_sym_specify] = ACTIONS(6890),
    [anon_sym_LPAREN_STAR] = ACTIONS(6887),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6887),
    [anon_sym_DOLLARunit] = ACTIONS(6887),
  },
  [1283] = {
    [ts_builtin_sym_end] = ACTIONS(6461),
    [sym_simple_identifier] = ACTIONS(6463),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6461),
    [anon_sym_BQUOTE] = ACTIONS(6463),
    [aux_sym_id_directive_token1] = ACTIONS(6461),
    [aux_sym_id_directive_token2] = ACTIONS(6461),
    [aux_sym_id_directive_token3] = ACTIONS(6461),
    [aux_sym_id_directive_token4] = ACTIONS(6463),
    [aux_sym_zero_directive_token1] = ACTIONS(6461),
    [aux_sym_zero_directive_token2] = ACTIONS(6461),
    [aux_sym_zero_directive_token3] = ACTIONS(6461),
    [aux_sym_zero_directive_token4] = ACTIONS(6461),
    [aux_sym_zero_directive_token5] = ACTIONS(6461),
    [aux_sym_zero_directive_token6] = ACTIONS(6461),
    [aux_sym_zero_directive_token7] = ACTIONS(6461),
    [aux_sym_zero_directive_token8] = ACTIONS(6461),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6461),
    [anon_sym_wire] = ACTIONS(6463),
    [anon_sym_tri] = ACTIONS(6463),
    [anon_sym_tri0] = ACTIONS(6463),
    [anon_sym_tri1] = ACTIONS(6463),
    [anon_sym_wand] = ACTIONS(6463),
    [anon_sym_triand] = ACTIONS(6463),
    [anon_sym_wor] = ACTIONS(6463),
    [anon_sym_trior] = ACTIONS(6463),
    [anon_sym_trireg] = ACTIONS(6463),
    [anon_sym_uwire] = ACTIONS(6463),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6461),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6461),
    [aux_sym_begin_keywords_token1] = ACTIONS(6461),
    [anon_sym_SEMI] = ACTIONS(6461),
    [anon_sym_endmodule] = ACTIONS(6463),
    [anon_sym_extern] = ACTIONS(6463),
    [anon_sym_module] = ACTIONS(6463),
    [anon_sym_macromodule] = ACTIONS(6463),
    [anon_sym_interface] = ACTIONS(6463),
    [anon_sym_program] = ACTIONS(6463),
    [anon_sym_checker] = ACTIONS(6463),
    [anon_sym_virtual] = ACTIONS(6463),
    [anon_sym_class] = ACTIONS(6463),
    [anon_sym_package] = ACTIONS(6463),
    [anon_sym_timeunit] = ACTIONS(6463),
    [anon_sym_timeprecision] = ACTIONS(6463),
    [anon_sym_type] = ACTIONS(6463),
    [anon_sym_input] = ACTIONS(6463),
    [anon_sym_output] = ACTIONS(6463),
    [anon_sym_inout] = ACTIONS(6463),
    [anon_sym_ref] = ACTIONS(6463),
    [anon_sym_DOLLARfatal] = ACTIONS(6461),
    [anon_sym_DOLLARerror] = ACTIONS(6461),
    [anon_sym_DOLLARwarning] = ACTIONS(6461),
    [anon_sym_DOLLARinfo] = ACTIONS(6461),
    [anon_sym_default] = ACTIONS(6463),
    [anon_sym_clocking] = ACTIONS(6463),
    [anon_sym_defparam] = ACTIONS(6463),
    [anon_sym_bind] = ACTIONS(6463),
    [anon_sym_const] = ACTIONS(6463),
    [anon_sym_function] = ACTIONS(6463),
    [anon_sym_static] = ACTIONS(6463),
    [anon_sym_constraint] = ACTIONS(6463),
    [anon_sym_if] = ACTIONS(6463),
    [anon_sym_LBRACK] = ACTIONS(6461),
    [anon_sym_localparam] = ACTIONS(6463),
    [anon_sym_parameter] = ACTIONS(6463),
    [anon_sym_specparam] = ACTIONS(6463),
    [anon_sym_var] = ACTIONS(6463),
    [anon_sym_import] = ACTIONS(6463),
    [anon_sym_export] = ACTIONS(6463),
    [anon_sym_genvar] = ACTIONS(6463),
    [anon_sym_interconnect] = ACTIONS(6463),
    [anon_sym_typedef] = ACTIONS(6463),
    [anon_sym_enum] = ACTIONS(6463),
    [anon_sym_struct] = ACTIONS(6463),
    [anon_sym_union] = ACTIONS(6463),
    [anon_sym_nettype] = ACTIONS(6463),
    [anon_sym_automatic] = ACTIONS(6463),
    [anon_sym_string] = ACTIONS(6463),
    [anon_sym_chandle] = ACTIONS(6463),
    [anon_sym_event] = ACTIONS(6463),
    [anon_sym_byte] = ACTIONS(6463),
    [anon_sym_shortint] = ACTIONS(6463),
    [anon_sym_int] = ACTIONS(6463),
    [anon_sym_longint] = ACTIONS(6463),
    [anon_sym_integer] = ACTIONS(6463),
    [anon_sym_time] = ACTIONS(6463),
    [anon_sym_bit] = ACTIONS(6463),
    [anon_sym_logic] = ACTIONS(6463),
    [anon_sym_reg] = ACTIONS(6463),
    [anon_sym_shortreal] = ACTIONS(6463),
    [anon_sym_real] = ACTIONS(6463),
    [anon_sym_realtime] = ACTIONS(6463),
    [anon_sym_supply0] = ACTIONS(6463),
    [anon_sym_supply1] = ACTIONS(6463),
    [anon_sym_signed] = ACTIONS(6463),
    [anon_sym_unsigned] = ACTIONS(6463),
    [anon_sym_task] = ACTIONS(6463),
    [anon_sym_assert] = ACTIONS(6463),
    [anon_sym_property] = ACTIONS(6463),
    [anon_sym_assume] = ACTIONS(6463),
    [anon_sym_cover] = ACTIONS(6463),
    [anon_sym_sequence] = ACTIONS(6463),
    [anon_sym_restrict] = ACTIONS(6463),
    [anon_sym_not] = ACTIONS(6463),
    [anon_sym_or] = ACTIONS(6463),
    [anon_sym_and] = ACTIONS(6463),
    [anon_sym_case] = ACTIONS(6463),
    [anon_sym_always] = ACTIONS(6463),
    [anon_sym_covergroup] = ACTIONS(6463),
    [anon_sym_let] = ACTIONS(6463),
    [anon_sym_pulldown] = ACTIONS(6463),
    [anon_sym_pullup] = ACTIONS(6463),
    [anon_sym_cmos] = ACTIONS(6463),
    [anon_sym_rcmos] = ACTIONS(6463),
    [anon_sym_bufif0] = ACTIONS(6463),
    [anon_sym_bufif1] = ACTIONS(6463),
    [anon_sym_notif0] = ACTIONS(6463),
    [anon_sym_notif1] = ACTIONS(6463),
    [anon_sym_nmos] = ACTIONS(6463),
    [anon_sym_pmos] = ACTIONS(6463),
    [anon_sym_rnmos] = ACTIONS(6463),
    [anon_sym_rpmos] = ACTIONS(6463),
    [anon_sym_nand] = ACTIONS(6463),
    [anon_sym_nor] = ACTIONS(6463),
    [anon_sym_xor] = ACTIONS(6463),
    [anon_sym_xnor] = ACTIONS(6463),
    [anon_sym_buf] = ACTIONS(6463),
    [anon_sym_tranif0] = ACTIONS(6463),
    [anon_sym_tranif1] = ACTIONS(6463),
    [anon_sym_rtranif1] = ACTIONS(6463),
    [anon_sym_rtranif0] = ACTIONS(6463),
    [anon_sym_tran] = ACTIONS(6463),
    [anon_sym_rtran] = ACTIONS(6463),
    [anon_sym_generate] = ACTIONS(6463),
    [anon_sym_for] = ACTIONS(6463),
    [anon_sym_primitive] = ACTIONS(6463),
    [anon_sym_initial] = ACTIONS(6463),
    [anon_sym_assign] = ACTIONS(6463),
    [anon_sym_alias] = ACTIONS(6463),
    [anon_sym_always_comb] = ACTIONS(6463),
    [anon_sym_always_latch] = ACTIONS(6463),
    [anon_sym_always_ff] = ACTIONS(6463),
    [anon_sym_final] = ACTIONS(6463),
    [anon_sym_global] = ACTIONS(6463),
    [anon_sym_specify] = ACTIONS(6463),
    [anon_sym_LPAREN_STAR] = ACTIONS(6461),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6461),
    [anon_sym_DOLLARunit] = ACTIONS(6461),
  },
  [1284] = {
    [ts_builtin_sym_end] = ACTIONS(5670),
    [sym_simple_identifier] = ACTIONS(5672),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5670),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5670),
    [anon_sym_BQUOTE] = ACTIONS(5672),
    [aux_sym_id_directive_token1] = ACTIONS(5670),
    [aux_sym_id_directive_token2] = ACTIONS(5670),
    [aux_sym_id_directive_token3] = ACTIONS(5670),
    [aux_sym_id_directive_token4] = ACTIONS(5672),
    [aux_sym_zero_directive_token1] = ACTIONS(5670),
    [aux_sym_zero_directive_token2] = ACTIONS(5670),
    [aux_sym_zero_directive_token3] = ACTIONS(5670),
    [aux_sym_zero_directive_token4] = ACTIONS(5670),
    [aux_sym_zero_directive_token5] = ACTIONS(5670),
    [aux_sym_zero_directive_token6] = ACTIONS(5670),
    [aux_sym_zero_directive_token7] = ACTIONS(5670),
    [aux_sym_zero_directive_token8] = ACTIONS(5670),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5670),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5670),
    [anon_sym_wire] = ACTIONS(5672),
    [anon_sym_tri] = ACTIONS(5672),
    [anon_sym_tri0] = ACTIONS(5672),
    [anon_sym_tri1] = ACTIONS(5672),
    [anon_sym_wand] = ACTIONS(5672),
    [anon_sym_triand] = ACTIONS(5672),
    [anon_sym_wor] = ACTIONS(5672),
    [anon_sym_trior] = ACTIONS(5672),
    [anon_sym_trireg] = ACTIONS(5672),
    [anon_sym_uwire] = ACTIONS(5672),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5670),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5670),
    [aux_sym_begin_keywords_token1] = ACTIONS(5670),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_endmodule] = ACTIONS(5672),
    [anon_sym_extern] = ACTIONS(5672),
    [anon_sym_module] = ACTIONS(5672),
    [anon_sym_macromodule] = ACTIONS(5672),
    [anon_sym_interface] = ACTIONS(5672),
    [anon_sym_program] = ACTIONS(5672),
    [anon_sym_checker] = ACTIONS(5672),
    [anon_sym_virtual] = ACTIONS(5672),
    [anon_sym_class] = ACTIONS(5672),
    [anon_sym_package] = ACTIONS(5672),
    [anon_sym_timeunit] = ACTIONS(5672),
    [anon_sym_timeprecision] = ACTIONS(5672),
    [anon_sym_type] = ACTIONS(5672),
    [anon_sym_input] = ACTIONS(5672),
    [anon_sym_output] = ACTIONS(5672),
    [anon_sym_inout] = ACTIONS(5672),
    [anon_sym_ref] = ACTIONS(5672),
    [anon_sym_DOLLARfatal] = ACTIONS(5670),
    [anon_sym_DOLLARerror] = ACTIONS(5670),
    [anon_sym_DOLLARwarning] = ACTIONS(5670),
    [anon_sym_DOLLARinfo] = ACTIONS(5670),
    [anon_sym_default] = ACTIONS(5672),
    [anon_sym_clocking] = ACTIONS(5672),
    [anon_sym_defparam] = ACTIONS(5672),
    [anon_sym_bind] = ACTIONS(5672),
    [anon_sym_const] = ACTIONS(5672),
    [anon_sym_function] = ACTIONS(5672),
    [anon_sym_static] = ACTIONS(5672),
    [anon_sym_constraint] = ACTIONS(5672),
    [anon_sym_if] = ACTIONS(5672),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_localparam] = ACTIONS(5672),
    [anon_sym_parameter] = ACTIONS(5672),
    [anon_sym_specparam] = ACTIONS(5672),
    [anon_sym_var] = ACTIONS(5672),
    [anon_sym_import] = ACTIONS(5672),
    [anon_sym_export] = ACTIONS(5672),
    [anon_sym_genvar] = ACTIONS(5672),
    [anon_sym_interconnect] = ACTIONS(5672),
    [anon_sym_typedef] = ACTIONS(5672),
    [anon_sym_enum] = ACTIONS(5672),
    [anon_sym_struct] = ACTIONS(5672),
    [anon_sym_union] = ACTIONS(5672),
    [anon_sym_nettype] = ACTIONS(5672),
    [anon_sym_automatic] = ACTIONS(5672),
    [anon_sym_string] = ACTIONS(5672),
    [anon_sym_chandle] = ACTIONS(5672),
    [anon_sym_event] = ACTIONS(5672),
    [anon_sym_byte] = ACTIONS(5672),
    [anon_sym_shortint] = ACTIONS(5672),
    [anon_sym_int] = ACTIONS(5672),
    [anon_sym_longint] = ACTIONS(5672),
    [anon_sym_integer] = ACTIONS(5672),
    [anon_sym_time] = ACTIONS(5672),
    [anon_sym_bit] = ACTIONS(5672),
    [anon_sym_logic] = ACTIONS(5672),
    [anon_sym_reg] = ACTIONS(5672),
    [anon_sym_shortreal] = ACTIONS(5672),
    [anon_sym_real] = ACTIONS(5672),
    [anon_sym_realtime] = ACTIONS(5672),
    [anon_sym_supply0] = ACTIONS(5672),
    [anon_sym_supply1] = ACTIONS(5672),
    [anon_sym_signed] = ACTIONS(5672),
    [anon_sym_unsigned] = ACTIONS(5672),
    [anon_sym_task] = ACTIONS(5672),
    [anon_sym_assert] = ACTIONS(5672),
    [anon_sym_property] = ACTIONS(5672),
    [anon_sym_assume] = ACTIONS(5672),
    [anon_sym_cover] = ACTIONS(5672),
    [anon_sym_sequence] = ACTIONS(5672),
    [anon_sym_restrict] = ACTIONS(5672),
    [anon_sym_not] = ACTIONS(5672),
    [anon_sym_or] = ACTIONS(5672),
    [anon_sym_and] = ACTIONS(5672),
    [anon_sym_case] = ACTIONS(5672),
    [anon_sym_always] = ACTIONS(5672),
    [anon_sym_covergroup] = ACTIONS(5672),
    [anon_sym_let] = ACTIONS(5672),
    [anon_sym_pulldown] = ACTIONS(5672),
    [anon_sym_pullup] = ACTIONS(5672),
    [anon_sym_cmos] = ACTIONS(5672),
    [anon_sym_rcmos] = ACTIONS(5672),
    [anon_sym_bufif0] = ACTIONS(5672),
    [anon_sym_bufif1] = ACTIONS(5672),
    [anon_sym_notif0] = ACTIONS(5672),
    [anon_sym_notif1] = ACTIONS(5672),
    [anon_sym_nmos] = ACTIONS(5672),
    [anon_sym_pmos] = ACTIONS(5672),
    [anon_sym_rnmos] = ACTIONS(5672),
    [anon_sym_rpmos] = ACTIONS(5672),
    [anon_sym_nand] = ACTIONS(5672),
    [anon_sym_nor] = ACTIONS(5672),
    [anon_sym_xor] = ACTIONS(5672),
    [anon_sym_xnor] = ACTIONS(5672),
    [anon_sym_buf] = ACTIONS(5672),
    [anon_sym_tranif0] = ACTIONS(5672),
    [anon_sym_tranif1] = ACTIONS(5672),
    [anon_sym_rtranif1] = ACTIONS(5672),
    [anon_sym_rtranif0] = ACTIONS(5672),
    [anon_sym_tran] = ACTIONS(5672),
    [anon_sym_rtran] = ACTIONS(5672),
    [anon_sym_generate] = ACTIONS(5672),
    [anon_sym_for] = ACTIONS(5672),
    [anon_sym_primitive] = ACTIONS(5672),
    [anon_sym_initial] = ACTIONS(5672),
    [anon_sym_assign] = ACTIONS(5672),
    [anon_sym_alias] = ACTIONS(5672),
    [anon_sym_always_comb] = ACTIONS(5672),
    [anon_sym_always_latch] = ACTIONS(5672),
    [anon_sym_always_ff] = ACTIONS(5672),
    [anon_sym_final] = ACTIONS(5672),
    [anon_sym_global] = ACTIONS(5672),
    [anon_sym_specify] = ACTIONS(5672),
    [anon_sym_LPAREN_STAR] = ACTIONS(5670),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5670),
    [anon_sym_DOLLARunit] = ACTIONS(5670),
  },
  [1285] = {
    [ts_builtin_sym_end] = ACTIONS(6893),
    [sym_simple_identifier] = ACTIONS(6895),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6893),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6893),
    [anon_sym_BQUOTE] = ACTIONS(6895),
    [aux_sym_id_directive_token1] = ACTIONS(6893),
    [aux_sym_id_directive_token2] = ACTIONS(6893),
    [aux_sym_id_directive_token3] = ACTIONS(6893),
    [aux_sym_id_directive_token4] = ACTIONS(6895),
    [aux_sym_zero_directive_token1] = ACTIONS(6893),
    [aux_sym_zero_directive_token2] = ACTIONS(6893),
    [aux_sym_zero_directive_token3] = ACTIONS(6893),
    [aux_sym_zero_directive_token4] = ACTIONS(6893),
    [aux_sym_zero_directive_token5] = ACTIONS(6893),
    [aux_sym_zero_directive_token6] = ACTIONS(6893),
    [aux_sym_zero_directive_token7] = ACTIONS(6893),
    [aux_sym_zero_directive_token8] = ACTIONS(6893),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6893),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6893),
    [anon_sym_wire] = ACTIONS(6895),
    [anon_sym_tri] = ACTIONS(6895),
    [anon_sym_tri0] = ACTIONS(6895),
    [anon_sym_tri1] = ACTIONS(6895),
    [anon_sym_wand] = ACTIONS(6895),
    [anon_sym_triand] = ACTIONS(6895),
    [anon_sym_wor] = ACTIONS(6895),
    [anon_sym_trior] = ACTIONS(6895),
    [anon_sym_trireg] = ACTIONS(6895),
    [anon_sym_uwire] = ACTIONS(6895),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6893),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6893),
    [aux_sym_begin_keywords_token1] = ACTIONS(6893),
    [anon_sym_SEMI] = ACTIONS(6893),
    [anon_sym_endmodule] = ACTIONS(6895),
    [anon_sym_extern] = ACTIONS(6895),
    [anon_sym_module] = ACTIONS(6895),
    [anon_sym_macromodule] = ACTIONS(6895),
    [anon_sym_interface] = ACTIONS(6895),
    [anon_sym_program] = ACTIONS(6895),
    [anon_sym_checker] = ACTIONS(6895),
    [anon_sym_virtual] = ACTIONS(6895),
    [anon_sym_class] = ACTIONS(6895),
    [anon_sym_package] = ACTIONS(6895),
    [anon_sym_timeunit] = ACTIONS(6895),
    [anon_sym_timeprecision] = ACTIONS(6895),
    [anon_sym_type] = ACTIONS(6895),
    [anon_sym_input] = ACTIONS(6895),
    [anon_sym_output] = ACTIONS(6895),
    [anon_sym_inout] = ACTIONS(6895),
    [anon_sym_ref] = ACTIONS(6895),
    [anon_sym_DOLLARfatal] = ACTIONS(6893),
    [anon_sym_DOLLARerror] = ACTIONS(6893),
    [anon_sym_DOLLARwarning] = ACTIONS(6893),
    [anon_sym_DOLLARinfo] = ACTIONS(6893),
    [anon_sym_default] = ACTIONS(6895),
    [anon_sym_clocking] = ACTIONS(6895),
    [anon_sym_defparam] = ACTIONS(6895),
    [anon_sym_bind] = ACTIONS(6895),
    [anon_sym_const] = ACTIONS(6895),
    [anon_sym_function] = ACTIONS(6895),
    [anon_sym_static] = ACTIONS(6895),
    [anon_sym_constraint] = ACTIONS(6895),
    [anon_sym_if] = ACTIONS(6895),
    [anon_sym_LBRACK] = ACTIONS(6893),
    [anon_sym_localparam] = ACTIONS(6895),
    [anon_sym_parameter] = ACTIONS(6895),
    [anon_sym_specparam] = ACTIONS(6895),
    [anon_sym_var] = ACTIONS(6895),
    [anon_sym_import] = ACTIONS(6895),
    [anon_sym_export] = ACTIONS(6895),
    [anon_sym_genvar] = ACTIONS(6895),
    [anon_sym_interconnect] = ACTIONS(6895),
    [anon_sym_typedef] = ACTIONS(6895),
    [anon_sym_enum] = ACTIONS(6895),
    [anon_sym_struct] = ACTIONS(6895),
    [anon_sym_union] = ACTIONS(6895),
    [anon_sym_nettype] = ACTIONS(6895),
    [anon_sym_automatic] = ACTIONS(6895),
    [anon_sym_string] = ACTIONS(6895),
    [anon_sym_chandle] = ACTIONS(6895),
    [anon_sym_event] = ACTIONS(6895),
    [anon_sym_byte] = ACTIONS(6895),
    [anon_sym_shortint] = ACTIONS(6895),
    [anon_sym_int] = ACTIONS(6895),
    [anon_sym_longint] = ACTIONS(6895),
    [anon_sym_integer] = ACTIONS(6895),
    [anon_sym_time] = ACTIONS(6895),
    [anon_sym_bit] = ACTIONS(6895),
    [anon_sym_logic] = ACTIONS(6895),
    [anon_sym_reg] = ACTIONS(6895),
    [anon_sym_shortreal] = ACTIONS(6895),
    [anon_sym_real] = ACTIONS(6895),
    [anon_sym_realtime] = ACTIONS(6895),
    [anon_sym_supply0] = ACTIONS(6895),
    [anon_sym_supply1] = ACTIONS(6895),
    [anon_sym_signed] = ACTIONS(6895),
    [anon_sym_unsigned] = ACTIONS(6895),
    [anon_sym_task] = ACTIONS(6895),
    [anon_sym_assert] = ACTIONS(6895),
    [anon_sym_property] = ACTIONS(6895),
    [anon_sym_assume] = ACTIONS(6895),
    [anon_sym_cover] = ACTIONS(6895),
    [anon_sym_sequence] = ACTIONS(6895),
    [anon_sym_restrict] = ACTIONS(6895),
    [anon_sym_not] = ACTIONS(6895),
    [anon_sym_or] = ACTIONS(6895),
    [anon_sym_and] = ACTIONS(6895),
    [anon_sym_case] = ACTIONS(6895),
    [anon_sym_always] = ACTIONS(6895),
    [anon_sym_covergroup] = ACTIONS(6895),
    [anon_sym_let] = ACTIONS(6895),
    [anon_sym_pulldown] = ACTIONS(6895),
    [anon_sym_pullup] = ACTIONS(6895),
    [anon_sym_cmos] = ACTIONS(6895),
    [anon_sym_rcmos] = ACTIONS(6895),
    [anon_sym_bufif0] = ACTIONS(6895),
    [anon_sym_bufif1] = ACTIONS(6895),
    [anon_sym_notif0] = ACTIONS(6895),
    [anon_sym_notif1] = ACTIONS(6895),
    [anon_sym_nmos] = ACTIONS(6895),
    [anon_sym_pmos] = ACTIONS(6895),
    [anon_sym_rnmos] = ACTIONS(6895),
    [anon_sym_rpmos] = ACTIONS(6895),
    [anon_sym_nand] = ACTIONS(6895),
    [anon_sym_nor] = ACTIONS(6895),
    [anon_sym_xor] = ACTIONS(6895),
    [anon_sym_xnor] = ACTIONS(6895),
    [anon_sym_buf] = ACTIONS(6895),
    [anon_sym_tranif0] = ACTIONS(6895),
    [anon_sym_tranif1] = ACTIONS(6895),
    [anon_sym_rtranif1] = ACTIONS(6895),
    [anon_sym_rtranif0] = ACTIONS(6895),
    [anon_sym_tran] = ACTIONS(6895),
    [anon_sym_rtran] = ACTIONS(6895),
    [anon_sym_generate] = ACTIONS(6895),
    [anon_sym_for] = ACTIONS(6895),
    [anon_sym_primitive] = ACTIONS(6895),
    [anon_sym_initial] = ACTIONS(6895),
    [anon_sym_assign] = ACTIONS(6895),
    [anon_sym_alias] = ACTIONS(6895),
    [anon_sym_always_comb] = ACTIONS(6895),
    [anon_sym_always_latch] = ACTIONS(6895),
    [anon_sym_always_ff] = ACTIONS(6895),
    [anon_sym_final] = ACTIONS(6895),
    [anon_sym_global] = ACTIONS(6895),
    [anon_sym_specify] = ACTIONS(6895),
    [anon_sym_LPAREN_STAR] = ACTIONS(6893),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6893),
    [anon_sym_DOLLARunit] = ACTIONS(6893),
  },
  [1286] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5675),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2644),
    [anon_sym_DQUOTE] = ACTIONS(2648),
    [anon_sym_LT] = ACTIONS(2644),
    [anon_sym_GT] = ACTIONS(2644),
    [anon_sym_LPAREN] = ACTIONS(2648),
    [anon_sym_RPAREN] = ACTIONS(2648),
    [anon_sym_BQUOTE] = ACTIONS(2648),
    [anon_sym_SLASH] = ACTIONS(2644),
    [anon_sym_COLON] = ACTIONS(2648),
    [anon_sym_type] = ACTIONS(2644),
    [anon_sym_LBRACE] = ACTIONS(2648),
    [anon_sym_const] = ACTIONS(2644),
    [anon_sym_local] = ACTIONS(2644),
    [anon_sym_super] = ACTIONS(2644),
    [anon_sym_STAR] = ACTIONS(2644),
    [anon_sym_string] = ACTIONS(2644),
    [anon_sym_byte] = ACTIONS(2644),
    [anon_sym_shortint] = ACTIONS(2644),
    [anon_sym_int] = ACTIONS(2644),
    [anon_sym_longint] = ACTIONS(2644),
    [anon_sym_integer] = ACTIONS(2644),
    [anon_sym_time] = ACTIONS(2644),
    [anon_sym_bit] = ACTIONS(2644),
    [anon_sym_logic] = ACTIONS(2644),
    [anon_sym_reg] = ACTIONS(2644),
    [anon_sym_shortreal] = ACTIONS(2644),
    [anon_sym_real] = ACTIONS(2644),
    [anon_sym_realtime] = ACTIONS(2644),
    [anon_sym_signed] = ACTIONS(2644),
    [anon_sym_unsigned] = ACTIONS(2644),
    [anon_sym_tagged] = ACTIONS(2644),
    [anon_sym_DOLLAR] = ACTIONS(2644),
    [anon_sym_PLUS] = ACTIONS(2644),
    [anon_sym_PLUS_PLUS] = ACTIONS(2648),
    [anon_sym_STAR_STAR] = ACTIONS(2648),
    [anon_sym_PERCENT] = ACTIONS(2648),
    [anon_sym_EQ_EQ] = ACTIONS(2644),
    [anon_sym_BANG_EQ] = ACTIONS(2644),
    [anon_sym_LT_EQ] = ACTIONS(2648),
    [anon_sym_GT_EQ] = ACTIONS(2648),
    [anon_sym_BANG] = ACTIONS(2644),
    [anon_sym_AMP_AMP] = ACTIONS(2644),
    [anon_sym_PIPE_PIPE] = ACTIONS(2648),
    [anon_sym_matches] = ACTIONS(2644),
    [anon_sym_DASH] = ACTIONS(2644),
    [anon_sym_DASH_GT] = ACTIONS(2648),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2648),
    [anon_sym_inside] = ACTIONS(2644),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2648),
    [anon_sym_TILDE] = ACTIONS(2644),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2648),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2648),
    [anon_sym_GT_GT] = ACTIONS(2644),
    [anon_sym_LT_LT] = ACTIONS(2644),
    [anon_sym_std] = ACTIONS(2644),
    [anon_sym_randomize] = ACTIONS(2644),
    [anon_sym_null] = ACTIONS(2644),
    [anon_sym_QMARK] = ACTIONS(2648),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2648),
    [anon_sym_AMP] = ACTIONS(2644),
    [anon_sym_PIPE] = ACTIONS(2644),
    [anon_sym_CARET] = ACTIONS(2644),
    [anon_sym_CARET_TILDE] = ACTIONS(2648),
    [anon_sym_TILDE_CARET] = ACTIONS(2648),
    [anon_sym_GT_GT_GT] = ACTIONS(2648),
    [anon_sym_LT_LT_LT] = ACTIONS(2648),
    [anon_sym_LT_DASH_GT] = ACTIONS(2648),
    [anon_sym_this] = ACTIONS(2644),
    [anon_sym_TILDE_AMP] = ACTIONS(2648),
    [anon_sym_TILDE_PIPE] = ACTIONS(2648),
    [anon_sym_DASH_DASH] = ACTIONS(2648),
    [aux_sym_decimal_number_token1] = ACTIONS(2648),
    [aux_sym_decimal_number_token2] = ACTIONS(2648),
    [sym_binary_number] = ACTIONS(2648),
    [sym_octal_number] = ACTIONS(2648),
    [sym_hex_number] = ACTIONS(2648),
    [aux_sym_real_number_token1] = ACTIONS(2648),
    [sym_fixed_point_number] = ACTIONS(2644),
    [sym_unsigned_number] = ACTIONS(2644),
    [anon_sym_SQUOTE0] = ACTIONS(2648),
    [anon_sym_SQUOTE1] = ACTIONS(2648),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2648),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2648),
    [anon_sym_DOLLARroot] = ACTIONS(2644),
    [anon_sym_DOLLARunit] = ACTIONS(2644),
    [sym_system_tf_identifier] = ACTIONS(2644),
  },
  [1287] = {
    [ts_builtin_sym_end] = ACTIONS(6897),
    [sym_simple_identifier] = ACTIONS(6899),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6897),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6897),
    [anon_sym_BQUOTE] = ACTIONS(6899),
    [aux_sym_id_directive_token1] = ACTIONS(6897),
    [aux_sym_id_directive_token2] = ACTIONS(6897),
    [aux_sym_id_directive_token3] = ACTIONS(6897),
    [aux_sym_id_directive_token4] = ACTIONS(6899),
    [aux_sym_zero_directive_token1] = ACTIONS(6897),
    [aux_sym_zero_directive_token2] = ACTIONS(6897),
    [aux_sym_zero_directive_token3] = ACTIONS(6897),
    [aux_sym_zero_directive_token4] = ACTIONS(6897),
    [aux_sym_zero_directive_token5] = ACTIONS(6897),
    [aux_sym_zero_directive_token6] = ACTIONS(6897),
    [aux_sym_zero_directive_token7] = ACTIONS(6897),
    [aux_sym_zero_directive_token8] = ACTIONS(6897),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6897),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6897),
    [anon_sym_wire] = ACTIONS(6899),
    [anon_sym_tri] = ACTIONS(6899),
    [anon_sym_tri0] = ACTIONS(6899),
    [anon_sym_tri1] = ACTIONS(6899),
    [anon_sym_wand] = ACTIONS(6899),
    [anon_sym_triand] = ACTIONS(6899),
    [anon_sym_wor] = ACTIONS(6899),
    [anon_sym_trior] = ACTIONS(6899),
    [anon_sym_trireg] = ACTIONS(6899),
    [anon_sym_uwire] = ACTIONS(6899),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6897),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6897),
    [aux_sym_begin_keywords_token1] = ACTIONS(6897),
    [anon_sym_SEMI] = ACTIONS(6897),
    [anon_sym_endmodule] = ACTIONS(6899),
    [anon_sym_extern] = ACTIONS(6899),
    [anon_sym_module] = ACTIONS(6899),
    [anon_sym_macromodule] = ACTIONS(6899),
    [anon_sym_interface] = ACTIONS(6899),
    [anon_sym_program] = ACTIONS(6899),
    [anon_sym_checker] = ACTIONS(6899),
    [anon_sym_virtual] = ACTIONS(6899),
    [anon_sym_class] = ACTIONS(6899),
    [anon_sym_package] = ACTIONS(6899),
    [anon_sym_timeunit] = ACTIONS(6899),
    [anon_sym_timeprecision] = ACTIONS(6899),
    [anon_sym_type] = ACTIONS(6899),
    [anon_sym_input] = ACTIONS(6899),
    [anon_sym_output] = ACTIONS(6899),
    [anon_sym_inout] = ACTIONS(6899),
    [anon_sym_ref] = ACTIONS(6899),
    [anon_sym_DOLLARfatal] = ACTIONS(6897),
    [anon_sym_DOLLARerror] = ACTIONS(6897),
    [anon_sym_DOLLARwarning] = ACTIONS(6897),
    [anon_sym_DOLLARinfo] = ACTIONS(6897),
    [anon_sym_default] = ACTIONS(6899),
    [anon_sym_clocking] = ACTIONS(6899),
    [anon_sym_defparam] = ACTIONS(6899),
    [anon_sym_bind] = ACTIONS(6899),
    [anon_sym_const] = ACTIONS(6899),
    [anon_sym_function] = ACTIONS(6899),
    [anon_sym_static] = ACTIONS(6899),
    [anon_sym_constraint] = ACTIONS(6899),
    [anon_sym_if] = ACTIONS(6899),
    [anon_sym_LBRACK] = ACTIONS(6897),
    [anon_sym_localparam] = ACTIONS(6899),
    [anon_sym_parameter] = ACTIONS(6899),
    [anon_sym_specparam] = ACTIONS(6899),
    [anon_sym_var] = ACTIONS(6899),
    [anon_sym_import] = ACTIONS(6899),
    [anon_sym_export] = ACTIONS(6899),
    [anon_sym_genvar] = ACTIONS(6899),
    [anon_sym_interconnect] = ACTIONS(6899),
    [anon_sym_typedef] = ACTIONS(6899),
    [anon_sym_enum] = ACTIONS(6899),
    [anon_sym_struct] = ACTIONS(6899),
    [anon_sym_union] = ACTIONS(6899),
    [anon_sym_nettype] = ACTIONS(6899),
    [anon_sym_automatic] = ACTIONS(6899),
    [anon_sym_string] = ACTIONS(6899),
    [anon_sym_chandle] = ACTIONS(6899),
    [anon_sym_event] = ACTIONS(6899),
    [anon_sym_byte] = ACTIONS(6899),
    [anon_sym_shortint] = ACTIONS(6899),
    [anon_sym_int] = ACTIONS(6899),
    [anon_sym_longint] = ACTIONS(6899),
    [anon_sym_integer] = ACTIONS(6899),
    [anon_sym_time] = ACTIONS(6899),
    [anon_sym_bit] = ACTIONS(6899),
    [anon_sym_logic] = ACTIONS(6899),
    [anon_sym_reg] = ACTIONS(6899),
    [anon_sym_shortreal] = ACTIONS(6899),
    [anon_sym_real] = ACTIONS(6899),
    [anon_sym_realtime] = ACTIONS(6899),
    [anon_sym_supply0] = ACTIONS(6899),
    [anon_sym_supply1] = ACTIONS(6899),
    [anon_sym_signed] = ACTIONS(6899),
    [anon_sym_unsigned] = ACTIONS(6899),
    [anon_sym_task] = ACTIONS(6899),
    [anon_sym_assert] = ACTIONS(6899),
    [anon_sym_property] = ACTIONS(6899),
    [anon_sym_assume] = ACTIONS(6899),
    [anon_sym_cover] = ACTIONS(6899),
    [anon_sym_sequence] = ACTIONS(6899),
    [anon_sym_restrict] = ACTIONS(6899),
    [anon_sym_not] = ACTIONS(6899),
    [anon_sym_or] = ACTIONS(6899),
    [anon_sym_and] = ACTIONS(6899),
    [anon_sym_case] = ACTIONS(6899),
    [anon_sym_always] = ACTIONS(6899),
    [anon_sym_covergroup] = ACTIONS(6899),
    [anon_sym_let] = ACTIONS(6899),
    [anon_sym_pulldown] = ACTIONS(6899),
    [anon_sym_pullup] = ACTIONS(6899),
    [anon_sym_cmos] = ACTIONS(6899),
    [anon_sym_rcmos] = ACTIONS(6899),
    [anon_sym_bufif0] = ACTIONS(6899),
    [anon_sym_bufif1] = ACTIONS(6899),
    [anon_sym_notif0] = ACTIONS(6899),
    [anon_sym_notif1] = ACTIONS(6899),
    [anon_sym_nmos] = ACTIONS(6899),
    [anon_sym_pmos] = ACTIONS(6899),
    [anon_sym_rnmos] = ACTIONS(6899),
    [anon_sym_rpmos] = ACTIONS(6899),
    [anon_sym_nand] = ACTIONS(6899),
    [anon_sym_nor] = ACTIONS(6899),
    [anon_sym_xor] = ACTIONS(6899),
    [anon_sym_xnor] = ACTIONS(6899),
    [anon_sym_buf] = ACTIONS(6899),
    [anon_sym_tranif0] = ACTIONS(6899),
    [anon_sym_tranif1] = ACTIONS(6899),
    [anon_sym_rtranif1] = ACTIONS(6899),
    [anon_sym_rtranif0] = ACTIONS(6899),
    [anon_sym_tran] = ACTIONS(6899),
    [anon_sym_rtran] = ACTIONS(6899),
    [anon_sym_generate] = ACTIONS(6899),
    [anon_sym_for] = ACTIONS(6899),
    [anon_sym_primitive] = ACTIONS(6899),
    [anon_sym_initial] = ACTIONS(6899),
    [anon_sym_assign] = ACTIONS(6899),
    [anon_sym_alias] = ACTIONS(6899),
    [anon_sym_always_comb] = ACTIONS(6899),
    [anon_sym_always_latch] = ACTIONS(6899),
    [anon_sym_always_ff] = ACTIONS(6899),
    [anon_sym_final] = ACTIONS(6899),
    [anon_sym_global] = ACTIONS(6899),
    [anon_sym_specify] = ACTIONS(6899),
    [anon_sym_LPAREN_STAR] = ACTIONS(6897),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6897),
    [anon_sym_DOLLARunit] = ACTIONS(6897),
  },
  [1288] = {
    [ts_builtin_sym_end] = ACTIONS(5700),
    [sym_simple_identifier] = ACTIONS(5702),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(5700),
    [aux_sym_text_macro_definition_token1] = ACTIONS(5700),
    [anon_sym_BQUOTE] = ACTIONS(5702),
    [aux_sym_id_directive_token1] = ACTIONS(5700),
    [aux_sym_id_directive_token2] = ACTIONS(5700),
    [aux_sym_id_directive_token3] = ACTIONS(5700),
    [aux_sym_id_directive_token4] = ACTIONS(5702),
    [aux_sym_zero_directive_token1] = ACTIONS(5700),
    [aux_sym_zero_directive_token2] = ACTIONS(5700),
    [aux_sym_zero_directive_token3] = ACTIONS(5700),
    [aux_sym_zero_directive_token4] = ACTIONS(5700),
    [aux_sym_zero_directive_token5] = ACTIONS(5700),
    [aux_sym_zero_directive_token6] = ACTIONS(5700),
    [aux_sym_zero_directive_token7] = ACTIONS(5700),
    [aux_sym_zero_directive_token8] = ACTIONS(5700),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(5700),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(5700),
    [anon_sym_wire] = ACTIONS(5702),
    [anon_sym_tri] = ACTIONS(5702),
    [anon_sym_tri0] = ACTIONS(5702),
    [anon_sym_tri1] = ACTIONS(5702),
    [anon_sym_wand] = ACTIONS(5702),
    [anon_sym_triand] = ACTIONS(5702),
    [anon_sym_wor] = ACTIONS(5702),
    [anon_sym_trior] = ACTIONS(5702),
    [anon_sym_trireg] = ACTIONS(5702),
    [anon_sym_uwire] = ACTIONS(5702),
    [aux_sym_unconnected_drive_token1] = ACTIONS(5700),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(5700),
    [aux_sym_begin_keywords_token1] = ACTIONS(5700),
    [anon_sym_SEMI] = ACTIONS(5700),
    [anon_sym_endmodule] = ACTIONS(5702),
    [anon_sym_extern] = ACTIONS(5702),
    [anon_sym_module] = ACTIONS(5702),
    [anon_sym_macromodule] = ACTIONS(5702),
    [anon_sym_interface] = ACTIONS(5702),
    [anon_sym_program] = ACTIONS(5702),
    [anon_sym_checker] = ACTIONS(5702),
    [anon_sym_virtual] = ACTIONS(5702),
    [anon_sym_class] = ACTIONS(5702),
    [anon_sym_package] = ACTIONS(5702),
    [anon_sym_timeunit] = ACTIONS(5702),
    [anon_sym_timeprecision] = ACTIONS(5702),
    [anon_sym_type] = ACTIONS(5702),
    [anon_sym_input] = ACTIONS(5702),
    [anon_sym_output] = ACTIONS(5702),
    [anon_sym_inout] = ACTIONS(5702),
    [anon_sym_ref] = ACTIONS(5702),
    [anon_sym_DOLLARfatal] = ACTIONS(5700),
    [anon_sym_DOLLARerror] = ACTIONS(5700),
    [anon_sym_DOLLARwarning] = ACTIONS(5700),
    [anon_sym_DOLLARinfo] = ACTIONS(5700),
    [anon_sym_default] = ACTIONS(5702),
    [anon_sym_clocking] = ACTIONS(5702),
    [anon_sym_defparam] = ACTIONS(5702),
    [anon_sym_bind] = ACTIONS(5702),
    [anon_sym_const] = ACTIONS(5702),
    [anon_sym_function] = ACTIONS(5702),
    [anon_sym_static] = ACTIONS(5702),
    [anon_sym_constraint] = ACTIONS(5702),
    [anon_sym_if] = ACTIONS(5702),
    [anon_sym_LBRACK] = ACTIONS(5700),
    [anon_sym_localparam] = ACTIONS(5702),
    [anon_sym_parameter] = ACTIONS(5702),
    [anon_sym_specparam] = ACTIONS(5702),
    [anon_sym_var] = ACTIONS(5702),
    [anon_sym_import] = ACTIONS(5702),
    [anon_sym_export] = ACTIONS(5702),
    [anon_sym_genvar] = ACTIONS(5702),
    [anon_sym_interconnect] = ACTIONS(5702),
    [anon_sym_typedef] = ACTIONS(5702),
    [anon_sym_enum] = ACTIONS(5702),
    [anon_sym_struct] = ACTIONS(5702),
    [anon_sym_union] = ACTIONS(5702),
    [anon_sym_nettype] = ACTIONS(5702),
    [anon_sym_automatic] = ACTIONS(5702),
    [anon_sym_string] = ACTIONS(5702),
    [anon_sym_chandle] = ACTIONS(5702),
    [anon_sym_event] = ACTIONS(5702),
    [anon_sym_byte] = ACTIONS(5702),
    [anon_sym_shortint] = ACTIONS(5702),
    [anon_sym_int] = ACTIONS(5702),
    [anon_sym_longint] = ACTIONS(5702),
    [anon_sym_integer] = ACTIONS(5702),
    [anon_sym_time] = ACTIONS(5702),
    [anon_sym_bit] = ACTIONS(5702),
    [anon_sym_logic] = ACTIONS(5702),
    [anon_sym_reg] = ACTIONS(5702),
    [anon_sym_shortreal] = ACTIONS(5702),
    [anon_sym_real] = ACTIONS(5702),
    [anon_sym_realtime] = ACTIONS(5702),
    [anon_sym_supply0] = ACTIONS(5702),
    [anon_sym_supply1] = ACTIONS(5702),
    [anon_sym_signed] = ACTIONS(5702),
    [anon_sym_unsigned] = ACTIONS(5702),
    [anon_sym_task] = ACTIONS(5702),
    [anon_sym_assert] = ACTIONS(5702),
    [anon_sym_property] = ACTIONS(5702),
    [anon_sym_assume] = ACTIONS(5702),
    [anon_sym_cover] = ACTIONS(5702),
    [anon_sym_sequence] = ACTIONS(5702),
    [anon_sym_restrict] = ACTIONS(5702),
    [anon_sym_not] = ACTIONS(5702),
    [anon_sym_or] = ACTIONS(5702),
    [anon_sym_and] = ACTIONS(5702),
    [anon_sym_case] = ACTIONS(5702),
    [anon_sym_always] = ACTIONS(5702),
    [anon_sym_covergroup] = ACTIONS(5702),
    [anon_sym_let] = ACTIONS(5702),
    [anon_sym_pulldown] = ACTIONS(5702),
    [anon_sym_pullup] = ACTIONS(5702),
    [anon_sym_cmos] = ACTIONS(5702),
    [anon_sym_rcmos] = ACTIONS(5702),
    [anon_sym_bufif0] = ACTIONS(5702),
    [anon_sym_bufif1] = ACTIONS(5702),
    [anon_sym_notif0] = ACTIONS(5702),
    [anon_sym_notif1] = ACTIONS(5702),
    [anon_sym_nmos] = ACTIONS(5702),
    [anon_sym_pmos] = ACTIONS(5702),
    [anon_sym_rnmos] = ACTIONS(5702),
    [anon_sym_rpmos] = ACTIONS(5702),
    [anon_sym_nand] = ACTIONS(5702),
    [anon_sym_nor] = ACTIONS(5702),
    [anon_sym_xor] = ACTIONS(5702),
    [anon_sym_xnor] = ACTIONS(5702),
    [anon_sym_buf] = ACTIONS(5702),
    [anon_sym_tranif0] = ACTIONS(5702),
    [anon_sym_tranif1] = ACTIONS(5702),
    [anon_sym_rtranif1] = ACTIONS(5702),
    [anon_sym_rtranif0] = ACTIONS(5702),
    [anon_sym_tran] = ACTIONS(5702),
    [anon_sym_rtran] = ACTIONS(5702),
    [anon_sym_generate] = ACTIONS(5702),
    [anon_sym_for] = ACTIONS(5702),
    [anon_sym_primitive] = ACTIONS(5702),
    [anon_sym_initial] = ACTIONS(5702),
    [anon_sym_assign] = ACTIONS(5702),
    [anon_sym_alias] = ACTIONS(5702),
    [anon_sym_always_comb] = ACTIONS(5702),
    [anon_sym_always_latch] = ACTIONS(5702),
    [anon_sym_always_ff] = ACTIONS(5702),
    [anon_sym_final] = ACTIONS(5702),
    [anon_sym_global] = ACTIONS(5702),
    [anon_sym_specify] = ACTIONS(5702),
    [anon_sym_LPAREN_STAR] = ACTIONS(5700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5700),
    [anon_sym_DOLLARunit] = ACTIONS(5700),
  },
  [1289] = {
    [ts_builtin_sym_end] = ACTIONS(6901),
    [sym_simple_identifier] = ACTIONS(6903),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6901),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6901),
    [anon_sym_BQUOTE] = ACTIONS(6903),
    [aux_sym_id_directive_token1] = ACTIONS(6901),
    [aux_sym_id_directive_token2] = ACTIONS(6901),
    [aux_sym_id_directive_token3] = ACTIONS(6901),
    [aux_sym_id_directive_token4] = ACTIONS(6903),
    [aux_sym_zero_directive_token1] = ACTIONS(6901),
    [aux_sym_zero_directive_token2] = ACTIONS(6901),
    [aux_sym_zero_directive_token3] = ACTIONS(6901),
    [aux_sym_zero_directive_token4] = ACTIONS(6901),
    [aux_sym_zero_directive_token5] = ACTIONS(6901),
    [aux_sym_zero_directive_token6] = ACTIONS(6901),
    [aux_sym_zero_directive_token7] = ACTIONS(6901),
    [aux_sym_zero_directive_token8] = ACTIONS(6901),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6901),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6901),
    [anon_sym_wire] = ACTIONS(6903),
    [anon_sym_tri] = ACTIONS(6903),
    [anon_sym_tri0] = ACTIONS(6903),
    [anon_sym_tri1] = ACTIONS(6903),
    [anon_sym_wand] = ACTIONS(6903),
    [anon_sym_triand] = ACTIONS(6903),
    [anon_sym_wor] = ACTIONS(6903),
    [anon_sym_trior] = ACTIONS(6903),
    [anon_sym_trireg] = ACTIONS(6903),
    [anon_sym_uwire] = ACTIONS(6903),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6901),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6901),
    [aux_sym_begin_keywords_token1] = ACTIONS(6901),
    [anon_sym_SEMI] = ACTIONS(6901),
    [anon_sym_endmodule] = ACTIONS(6903),
    [anon_sym_extern] = ACTIONS(6903),
    [anon_sym_module] = ACTIONS(6903),
    [anon_sym_macromodule] = ACTIONS(6903),
    [anon_sym_interface] = ACTIONS(6903),
    [anon_sym_program] = ACTIONS(6903),
    [anon_sym_checker] = ACTIONS(6903),
    [anon_sym_virtual] = ACTIONS(6903),
    [anon_sym_class] = ACTIONS(6903),
    [anon_sym_package] = ACTIONS(6903),
    [anon_sym_timeunit] = ACTIONS(6903),
    [anon_sym_timeprecision] = ACTIONS(6903),
    [anon_sym_type] = ACTIONS(6903),
    [anon_sym_input] = ACTIONS(6903),
    [anon_sym_output] = ACTIONS(6903),
    [anon_sym_inout] = ACTIONS(6903),
    [anon_sym_ref] = ACTIONS(6903),
    [anon_sym_DOLLARfatal] = ACTIONS(6901),
    [anon_sym_DOLLARerror] = ACTIONS(6901),
    [anon_sym_DOLLARwarning] = ACTIONS(6901),
    [anon_sym_DOLLARinfo] = ACTIONS(6901),
    [anon_sym_default] = ACTIONS(6903),
    [anon_sym_clocking] = ACTIONS(6903),
    [anon_sym_defparam] = ACTIONS(6903),
    [anon_sym_bind] = ACTIONS(6903),
    [anon_sym_const] = ACTIONS(6903),
    [anon_sym_function] = ACTIONS(6903),
    [anon_sym_static] = ACTIONS(6903),
    [anon_sym_constraint] = ACTIONS(6903),
    [anon_sym_if] = ACTIONS(6903),
    [anon_sym_LBRACK] = ACTIONS(6901),
    [anon_sym_localparam] = ACTIONS(6903),
    [anon_sym_parameter] = ACTIONS(6903),
    [anon_sym_specparam] = ACTIONS(6903),
    [anon_sym_var] = ACTIONS(6903),
    [anon_sym_import] = ACTIONS(6903),
    [anon_sym_export] = ACTIONS(6903),
    [anon_sym_genvar] = ACTIONS(6903),
    [anon_sym_interconnect] = ACTIONS(6903),
    [anon_sym_typedef] = ACTIONS(6903),
    [anon_sym_enum] = ACTIONS(6903),
    [anon_sym_struct] = ACTIONS(6903),
    [anon_sym_union] = ACTIONS(6903),
    [anon_sym_nettype] = ACTIONS(6903),
    [anon_sym_automatic] = ACTIONS(6903),
    [anon_sym_string] = ACTIONS(6903),
    [anon_sym_chandle] = ACTIONS(6903),
    [anon_sym_event] = ACTIONS(6903),
    [anon_sym_byte] = ACTIONS(6903),
    [anon_sym_shortint] = ACTIONS(6903),
    [anon_sym_int] = ACTIONS(6903),
    [anon_sym_longint] = ACTIONS(6903),
    [anon_sym_integer] = ACTIONS(6903),
    [anon_sym_time] = ACTIONS(6903),
    [anon_sym_bit] = ACTIONS(6903),
    [anon_sym_logic] = ACTIONS(6903),
    [anon_sym_reg] = ACTIONS(6903),
    [anon_sym_shortreal] = ACTIONS(6903),
    [anon_sym_real] = ACTIONS(6903),
    [anon_sym_realtime] = ACTIONS(6903),
    [anon_sym_supply0] = ACTIONS(6903),
    [anon_sym_supply1] = ACTIONS(6903),
    [anon_sym_signed] = ACTIONS(6903),
    [anon_sym_unsigned] = ACTIONS(6903),
    [anon_sym_task] = ACTIONS(6903),
    [anon_sym_assert] = ACTIONS(6903),
    [anon_sym_property] = ACTIONS(6903),
    [anon_sym_assume] = ACTIONS(6903),
    [anon_sym_cover] = ACTIONS(6903),
    [anon_sym_sequence] = ACTIONS(6903),
    [anon_sym_restrict] = ACTIONS(6903),
    [anon_sym_not] = ACTIONS(6903),
    [anon_sym_or] = ACTIONS(6903),
    [anon_sym_and] = ACTIONS(6903),
    [anon_sym_case] = ACTIONS(6903),
    [anon_sym_always] = ACTIONS(6903),
    [anon_sym_covergroup] = ACTIONS(6903),
    [anon_sym_let] = ACTIONS(6903),
    [anon_sym_pulldown] = ACTIONS(6903),
    [anon_sym_pullup] = ACTIONS(6903),
    [anon_sym_cmos] = ACTIONS(6903),
    [anon_sym_rcmos] = ACTIONS(6903),
    [anon_sym_bufif0] = ACTIONS(6903),
    [anon_sym_bufif1] = ACTIONS(6903),
    [anon_sym_notif0] = ACTIONS(6903),
    [anon_sym_notif1] = ACTIONS(6903),
    [anon_sym_nmos] = ACTIONS(6903),
    [anon_sym_pmos] = ACTIONS(6903),
    [anon_sym_rnmos] = ACTIONS(6903),
    [anon_sym_rpmos] = ACTIONS(6903),
    [anon_sym_nand] = ACTIONS(6903),
    [anon_sym_nor] = ACTIONS(6903),
    [anon_sym_xor] = ACTIONS(6903),
    [anon_sym_xnor] = ACTIONS(6903),
    [anon_sym_buf] = ACTIONS(6903),
    [anon_sym_tranif0] = ACTIONS(6903),
    [anon_sym_tranif1] = ACTIONS(6903),
    [anon_sym_rtranif1] = ACTIONS(6903),
    [anon_sym_rtranif0] = ACTIONS(6903),
    [anon_sym_tran] = ACTIONS(6903),
    [anon_sym_rtran] = ACTIONS(6903),
    [anon_sym_generate] = ACTIONS(6903),
    [anon_sym_for] = ACTIONS(6903),
    [anon_sym_primitive] = ACTIONS(6903),
    [anon_sym_initial] = ACTIONS(6903),
    [anon_sym_assign] = ACTIONS(6903),
    [anon_sym_alias] = ACTIONS(6903),
    [anon_sym_always_comb] = ACTIONS(6903),
    [anon_sym_always_latch] = ACTIONS(6903),
    [anon_sym_always_ff] = ACTIONS(6903),
    [anon_sym_final] = ACTIONS(6903),
    [anon_sym_global] = ACTIONS(6903),
    [anon_sym_specify] = ACTIONS(6903),
    [anon_sym_LPAREN_STAR] = ACTIONS(6901),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6901),
    [anon_sym_DOLLARunit] = ACTIONS(6901),
  },
  [1290] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19903),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1291] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18483),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1292] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17826),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1293] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17867),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1294] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17870),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1295] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18725),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1296] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17875),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1297] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17928),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1298] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17930),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1299] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18506),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1300] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19820),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1301] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17940),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1302] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17704),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1303] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17954),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1304] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17957),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1305] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18742),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1306] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17976),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1307] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18752),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1308] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18758),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1309] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17755),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1310] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18622),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1311] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18625),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1312] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17696),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1313] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18627),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1314] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18648),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1315] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18780),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1316] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20533),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1317] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19667),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1318] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17759),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1319] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19938),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1320] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19849),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1321] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19305),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1322] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17765),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1323] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19886),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1324] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17441),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1325] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17819),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1326] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20385),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1327] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17699),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1328] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20394),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1329] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17659),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1330] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20415),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1331] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18832),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1332] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18848),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1333] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17803),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1334] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18854),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1335] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18930),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1336] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18297),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1337] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18314),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1338] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18340),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1339] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17374),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1340] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17376),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1341] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18384),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1342] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17385),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1343] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17399),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1344] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19551),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1345] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19579),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1346] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19607),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1347] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19634),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1348] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19658),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1349] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19682),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1350] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(19699),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1351] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20191),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1352] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(18460),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1353] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17947),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1354] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17559),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1355] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17561),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1356] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17566),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1357] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17630),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1358] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17634),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1359] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17640),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1360] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(17821),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1361] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_spec] = STATE(20390),
    [sym_property_expr] = STATE(11391),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1371),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(4100),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1362] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_LBRACK] = ACTIONS(6905),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1363] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_LBRACK] = ACTIONS(6907),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1364] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_LBRACK] = ACTIONS(6911),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1365] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11349),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_LBRACK] = ACTIONS(6923),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1366] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_LBRACK] = ACTIONS(6927),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1367] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11469),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_LBRACK] = ACTIONS(6939),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1368] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11441),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_LBRACK] = ACTIONS(6941),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1369] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11770),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_COLON] = ACTIONS(6943),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1370] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11559),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_LBRACK] = ACTIONS(6945),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1371] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11387),
    [sym_sequence_expr] = STATE(10821),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_disable] = ACTIONS(6947),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1372] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11484),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1373] = {
    [sym_simple_identifier] = ACTIONS(6949),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6951),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6951),
    [anon_sym_BQUOTE] = ACTIONS(6949),
    [aux_sym_id_directive_token1] = ACTIONS(6951),
    [aux_sym_id_directive_token2] = ACTIONS(6951),
    [aux_sym_id_directive_token3] = ACTIONS(6951),
    [aux_sym_id_directive_token4] = ACTIONS(6949),
    [aux_sym_zero_directive_token1] = ACTIONS(6951),
    [aux_sym_zero_directive_token2] = ACTIONS(6951),
    [aux_sym_zero_directive_token3] = ACTIONS(6951),
    [aux_sym_zero_directive_token4] = ACTIONS(6951),
    [aux_sym_zero_directive_token5] = ACTIONS(6951),
    [aux_sym_zero_directive_token6] = ACTIONS(6951),
    [aux_sym_zero_directive_token7] = ACTIONS(6951),
    [aux_sym_zero_directive_token8] = ACTIONS(6951),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6951),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6951),
    [anon_sym_wire] = ACTIONS(6949),
    [anon_sym_tri] = ACTIONS(6949),
    [anon_sym_tri0] = ACTIONS(6949),
    [anon_sym_tri1] = ACTIONS(6949),
    [anon_sym_wand] = ACTIONS(6949),
    [anon_sym_triand] = ACTIONS(6949),
    [anon_sym_wor] = ACTIONS(6949),
    [anon_sym_trior] = ACTIONS(6949),
    [anon_sym_trireg] = ACTIONS(6949),
    [anon_sym_uwire] = ACTIONS(6949),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6951),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6951),
    [aux_sym_begin_keywords_token1] = ACTIONS(6951),
    [anon_sym_SEMI] = ACTIONS(6951),
    [anon_sym_endmodule] = ACTIONS(6949),
    [anon_sym_extern] = ACTIONS(6949),
    [anon_sym_module] = ACTIONS(6949),
    [anon_sym_macromodule] = ACTIONS(6949),
    [anon_sym_interface] = ACTIONS(6949),
    [anon_sym_program] = ACTIONS(6949),
    [anon_sym_checker] = ACTIONS(6949),
    [anon_sym_virtual] = ACTIONS(6949),
    [anon_sym_class] = ACTIONS(6949),
    [anon_sym_timeunit] = ACTIONS(6949),
    [anon_sym_timeprecision] = ACTIONS(6949),
    [anon_sym_type] = ACTIONS(6949),
    [anon_sym_input] = ACTIONS(6949),
    [anon_sym_output] = ACTIONS(6949),
    [anon_sym_inout] = ACTIONS(6949),
    [anon_sym_ref] = ACTIONS(6949),
    [anon_sym_DOLLARfatal] = ACTIONS(6951),
    [anon_sym_DOLLARerror] = ACTIONS(6951),
    [anon_sym_DOLLARwarning] = ACTIONS(6951),
    [anon_sym_DOLLARinfo] = ACTIONS(6951),
    [anon_sym_default] = ACTIONS(6949),
    [anon_sym_clocking] = ACTIONS(6949),
    [anon_sym_defparam] = ACTIONS(6949),
    [anon_sym_bind] = ACTIONS(6949),
    [anon_sym_const] = ACTIONS(6949),
    [anon_sym_function] = ACTIONS(6949),
    [anon_sym_static] = ACTIONS(6949),
    [anon_sym_constraint] = ACTIONS(6949),
    [anon_sym_if] = ACTIONS(6949),
    [anon_sym_LBRACK] = ACTIONS(6951),
    [anon_sym_localparam] = ACTIONS(6949),
    [anon_sym_parameter] = ACTIONS(6949),
    [anon_sym_specparam] = ACTIONS(6949),
    [anon_sym_var] = ACTIONS(6949),
    [anon_sym_import] = ACTIONS(6949),
    [anon_sym_export] = ACTIONS(6949),
    [anon_sym_genvar] = ACTIONS(6949),
    [anon_sym_interconnect] = ACTIONS(6949),
    [anon_sym_typedef] = ACTIONS(6949),
    [anon_sym_enum] = ACTIONS(6949),
    [anon_sym_struct] = ACTIONS(6949),
    [anon_sym_union] = ACTIONS(6949),
    [anon_sym_nettype] = ACTIONS(6949),
    [anon_sym_automatic] = ACTIONS(6949),
    [anon_sym_string] = ACTIONS(6949),
    [anon_sym_chandle] = ACTIONS(6949),
    [anon_sym_event] = ACTIONS(6949),
    [anon_sym_byte] = ACTIONS(6949),
    [anon_sym_shortint] = ACTIONS(6949),
    [anon_sym_int] = ACTIONS(6949),
    [anon_sym_longint] = ACTIONS(6949),
    [anon_sym_integer] = ACTIONS(6949),
    [anon_sym_time] = ACTIONS(6949),
    [anon_sym_bit] = ACTIONS(6949),
    [anon_sym_logic] = ACTIONS(6949),
    [anon_sym_reg] = ACTIONS(6949),
    [anon_sym_shortreal] = ACTIONS(6949),
    [anon_sym_real] = ACTIONS(6949),
    [anon_sym_realtime] = ACTIONS(6949),
    [anon_sym_supply0] = ACTIONS(6949),
    [anon_sym_supply1] = ACTIONS(6949),
    [anon_sym_signed] = ACTIONS(6949),
    [anon_sym_unsigned] = ACTIONS(6949),
    [anon_sym_task] = ACTIONS(6949),
    [anon_sym_assert] = ACTIONS(6949),
    [anon_sym_property] = ACTIONS(6949),
    [anon_sym_assume] = ACTIONS(6949),
    [anon_sym_cover] = ACTIONS(6949),
    [anon_sym_sequence] = ACTIONS(6949),
    [anon_sym_restrict] = ACTIONS(6949),
    [anon_sym_not] = ACTIONS(6949),
    [anon_sym_or] = ACTIONS(6949),
    [anon_sym_and] = ACTIONS(6949),
    [anon_sym_case] = ACTIONS(6949),
    [anon_sym_always] = ACTIONS(6949),
    [anon_sym_covergroup] = ACTIONS(6949),
    [anon_sym_let] = ACTIONS(6949),
    [anon_sym_pulldown] = ACTIONS(6949),
    [anon_sym_pullup] = ACTIONS(6949),
    [anon_sym_cmos] = ACTIONS(6949),
    [anon_sym_rcmos] = ACTIONS(6949),
    [anon_sym_bufif0] = ACTIONS(6949),
    [anon_sym_bufif1] = ACTIONS(6949),
    [anon_sym_notif0] = ACTIONS(6949),
    [anon_sym_notif1] = ACTIONS(6949),
    [anon_sym_nmos] = ACTIONS(6949),
    [anon_sym_pmos] = ACTIONS(6949),
    [anon_sym_rnmos] = ACTIONS(6949),
    [anon_sym_rpmos] = ACTIONS(6949),
    [anon_sym_nand] = ACTIONS(6949),
    [anon_sym_nor] = ACTIONS(6949),
    [anon_sym_xor] = ACTIONS(6949),
    [anon_sym_xnor] = ACTIONS(6949),
    [anon_sym_buf] = ACTIONS(6949),
    [anon_sym_tranif0] = ACTIONS(6949),
    [anon_sym_tranif1] = ACTIONS(6949),
    [anon_sym_rtranif1] = ACTIONS(6949),
    [anon_sym_rtranif0] = ACTIONS(6949),
    [anon_sym_tran] = ACTIONS(6949),
    [anon_sym_rtran] = ACTIONS(6949),
    [anon_sym_generate] = ACTIONS(6949),
    [anon_sym_for] = ACTIONS(6949),
    [anon_sym_initial] = ACTIONS(6949),
    [anon_sym_assign] = ACTIONS(6949),
    [anon_sym_alias] = ACTIONS(6949),
    [anon_sym_always_comb] = ACTIONS(6949),
    [anon_sym_always_latch] = ACTIONS(6949),
    [anon_sym_always_ff] = ACTIONS(6949),
    [anon_sym_final] = ACTIONS(6949),
    [anon_sym_global] = ACTIONS(6949),
    [anon_sym_specify] = ACTIONS(6949),
    [anon_sym_LPAREN_STAR] = ACTIONS(6951),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6951),
    [anon_sym_DOLLARunit] = ACTIONS(6951),
  },
  [1374] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1375] = {
    [sym_simple_identifier] = ACTIONS(6953),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6955),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6955),
    [anon_sym_BQUOTE] = ACTIONS(6953),
    [aux_sym_id_directive_token1] = ACTIONS(6955),
    [aux_sym_id_directive_token2] = ACTIONS(6955),
    [aux_sym_id_directive_token3] = ACTIONS(6955),
    [aux_sym_id_directive_token4] = ACTIONS(6953),
    [aux_sym_zero_directive_token1] = ACTIONS(6955),
    [aux_sym_zero_directive_token2] = ACTIONS(6955),
    [aux_sym_zero_directive_token3] = ACTIONS(6955),
    [aux_sym_zero_directive_token4] = ACTIONS(6955),
    [aux_sym_zero_directive_token5] = ACTIONS(6955),
    [aux_sym_zero_directive_token6] = ACTIONS(6955),
    [aux_sym_zero_directive_token7] = ACTIONS(6955),
    [aux_sym_zero_directive_token8] = ACTIONS(6955),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6955),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6955),
    [anon_sym_wire] = ACTIONS(6953),
    [anon_sym_tri] = ACTIONS(6953),
    [anon_sym_tri0] = ACTIONS(6953),
    [anon_sym_tri1] = ACTIONS(6953),
    [anon_sym_wand] = ACTIONS(6953),
    [anon_sym_triand] = ACTIONS(6953),
    [anon_sym_wor] = ACTIONS(6953),
    [anon_sym_trior] = ACTIONS(6953),
    [anon_sym_trireg] = ACTIONS(6953),
    [anon_sym_uwire] = ACTIONS(6953),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6955),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6955),
    [aux_sym_begin_keywords_token1] = ACTIONS(6955),
    [anon_sym_SEMI] = ACTIONS(6955),
    [anon_sym_endmodule] = ACTIONS(6953),
    [anon_sym_extern] = ACTIONS(6953),
    [anon_sym_module] = ACTIONS(6953),
    [anon_sym_macromodule] = ACTIONS(6953),
    [anon_sym_interface] = ACTIONS(6953),
    [anon_sym_program] = ACTIONS(6953),
    [anon_sym_checker] = ACTIONS(6953),
    [anon_sym_virtual] = ACTIONS(6953),
    [anon_sym_class] = ACTIONS(6953),
    [anon_sym_timeunit] = ACTIONS(6953),
    [anon_sym_timeprecision] = ACTIONS(6953),
    [anon_sym_type] = ACTIONS(6953),
    [anon_sym_input] = ACTIONS(6953),
    [anon_sym_output] = ACTIONS(6953),
    [anon_sym_inout] = ACTIONS(6953),
    [anon_sym_ref] = ACTIONS(6953),
    [anon_sym_DOLLARfatal] = ACTIONS(6955),
    [anon_sym_DOLLARerror] = ACTIONS(6955),
    [anon_sym_DOLLARwarning] = ACTIONS(6955),
    [anon_sym_DOLLARinfo] = ACTIONS(6955),
    [anon_sym_default] = ACTIONS(6953),
    [anon_sym_clocking] = ACTIONS(6953),
    [anon_sym_defparam] = ACTIONS(6953),
    [anon_sym_bind] = ACTIONS(6953),
    [anon_sym_const] = ACTIONS(6953),
    [anon_sym_function] = ACTIONS(6953),
    [anon_sym_static] = ACTIONS(6953),
    [anon_sym_constraint] = ACTIONS(6953),
    [anon_sym_if] = ACTIONS(6953),
    [anon_sym_LBRACK] = ACTIONS(6955),
    [anon_sym_localparam] = ACTIONS(6953),
    [anon_sym_parameter] = ACTIONS(6953),
    [anon_sym_specparam] = ACTIONS(6953),
    [anon_sym_var] = ACTIONS(6953),
    [anon_sym_import] = ACTIONS(6953),
    [anon_sym_export] = ACTIONS(6953),
    [anon_sym_genvar] = ACTIONS(6953),
    [anon_sym_interconnect] = ACTIONS(6953),
    [anon_sym_typedef] = ACTIONS(6953),
    [anon_sym_enum] = ACTIONS(6953),
    [anon_sym_struct] = ACTIONS(6953),
    [anon_sym_union] = ACTIONS(6953),
    [anon_sym_nettype] = ACTIONS(6953),
    [anon_sym_automatic] = ACTIONS(6953),
    [anon_sym_string] = ACTIONS(6953),
    [anon_sym_chandle] = ACTIONS(6953),
    [anon_sym_event] = ACTIONS(6953),
    [anon_sym_byte] = ACTIONS(6953),
    [anon_sym_shortint] = ACTIONS(6953),
    [anon_sym_int] = ACTIONS(6953),
    [anon_sym_longint] = ACTIONS(6953),
    [anon_sym_integer] = ACTIONS(6953),
    [anon_sym_time] = ACTIONS(6953),
    [anon_sym_bit] = ACTIONS(6953),
    [anon_sym_logic] = ACTIONS(6953),
    [anon_sym_reg] = ACTIONS(6953),
    [anon_sym_shortreal] = ACTIONS(6953),
    [anon_sym_real] = ACTIONS(6953),
    [anon_sym_realtime] = ACTIONS(6953),
    [anon_sym_supply0] = ACTIONS(6953),
    [anon_sym_supply1] = ACTIONS(6953),
    [anon_sym_signed] = ACTIONS(6953),
    [anon_sym_unsigned] = ACTIONS(6953),
    [anon_sym_task] = ACTIONS(6953),
    [anon_sym_assert] = ACTIONS(6953),
    [anon_sym_property] = ACTIONS(6953),
    [anon_sym_assume] = ACTIONS(6953),
    [anon_sym_cover] = ACTIONS(6953),
    [anon_sym_sequence] = ACTIONS(6953),
    [anon_sym_restrict] = ACTIONS(6953),
    [anon_sym_not] = ACTIONS(6953),
    [anon_sym_or] = ACTIONS(6953),
    [anon_sym_and] = ACTIONS(6953),
    [anon_sym_case] = ACTIONS(6953),
    [anon_sym_always] = ACTIONS(6953),
    [anon_sym_covergroup] = ACTIONS(6953),
    [anon_sym_let] = ACTIONS(6953),
    [anon_sym_pulldown] = ACTIONS(6953),
    [anon_sym_pullup] = ACTIONS(6953),
    [anon_sym_cmos] = ACTIONS(6953),
    [anon_sym_rcmos] = ACTIONS(6953),
    [anon_sym_bufif0] = ACTIONS(6953),
    [anon_sym_bufif1] = ACTIONS(6953),
    [anon_sym_notif0] = ACTIONS(6953),
    [anon_sym_notif1] = ACTIONS(6953),
    [anon_sym_nmos] = ACTIONS(6953),
    [anon_sym_pmos] = ACTIONS(6953),
    [anon_sym_rnmos] = ACTIONS(6953),
    [anon_sym_rpmos] = ACTIONS(6953),
    [anon_sym_nand] = ACTIONS(6953),
    [anon_sym_nor] = ACTIONS(6953),
    [anon_sym_xor] = ACTIONS(6953),
    [anon_sym_xnor] = ACTIONS(6953),
    [anon_sym_buf] = ACTIONS(6953),
    [anon_sym_tranif0] = ACTIONS(6953),
    [anon_sym_tranif1] = ACTIONS(6953),
    [anon_sym_rtranif1] = ACTIONS(6953),
    [anon_sym_rtranif0] = ACTIONS(6953),
    [anon_sym_tran] = ACTIONS(6953),
    [anon_sym_rtran] = ACTIONS(6953),
    [anon_sym_generate] = ACTIONS(6953),
    [anon_sym_for] = ACTIONS(6953),
    [anon_sym_initial] = ACTIONS(6953),
    [anon_sym_assign] = ACTIONS(6953),
    [anon_sym_alias] = ACTIONS(6953),
    [anon_sym_always_comb] = ACTIONS(6953),
    [anon_sym_always_latch] = ACTIONS(6953),
    [anon_sym_always_ff] = ACTIONS(6953),
    [anon_sym_final] = ACTIONS(6953),
    [anon_sym_global] = ACTIONS(6953),
    [anon_sym_specify] = ACTIONS(6953),
    [anon_sym_LPAREN_STAR] = ACTIONS(6955),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6955),
    [anon_sym_DOLLARunit] = ACTIONS(6955),
  },
  [1376] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11320),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1377] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11281),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1378] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11465),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1379] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11472),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1380] = {
    [sym_simple_identifier] = ACTIONS(6957),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6959),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6959),
    [anon_sym_BQUOTE] = ACTIONS(6957),
    [aux_sym_id_directive_token1] = ACTIONS(6959),
    [aux_sym_id_directive_token2] = ACTIONS(6959),
    [aux_sym_id_directive_token3] = ACTIONS(6959),
    [aux_sym_id_directive_token4] = ACTIONS(6957),
    [aux_sym_zero_directive_token1] = ACTIONS(6959),
    [aux_sym_zero_directive_token2] = ACTIONS(6959),
    [aux_sym_zero_directive_token3] = ACTIONS(6959),
    [aux_sym_zero_directive_token4] = ACTIONS(6959),
    [aux_sym_zero_directive_token5] = ACTIONS(6959),
    [aux_sym_zero_directive_token6] = ACTIONS(6959),
    [aux_sym_zero_directive_token7] = ACTIONS(6959),
    [aux_sym_zero_directive_token8] = ACTIONS(6959),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6959),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6959),
    [anon_sym_wire] = ACTIONS(6957),
    [anon_sym_tri] = ACTIONS(6957),
    [anon_sym_tri0] = ACTIONS(6957),
    [anon_sym_tri1] = ACTIONS(6957),
    [anon_sym_wand] = ACTIONS(6957),
    [anon_sym_triand] = ACTIONS(6957),
    [anon_sym_wor] = ACTIONS(6957),
    [anon_sym_trior] = ACTIONS(6957),
    [anon_sym_trireg] = ACTIONS(6957),
    [anon_sym_uwire] = ACTIONS(6957),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6959),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6959),
    [aux_sym_begin_keywords_token1] = ACTIONS(6959),
    [anon_sym_SEMI] = ACTIONS(6959),
    [anon_sym_endmodule] = ACTIONS(6957),
    [anon_sym_extern] = ACTIONS(6957),
    [anon_sym_module] = ACTIONS(6957),
    [anon_sym_macromodule] = ACTIONS(6957),
    [anon_sym_interface] = ACTIONS(6957),
    [anon_sym_program] = ACTIONS(6957),
    [anon_sym_checker] = ACTIONS(6957),
    [anon_sym_virtual] = ACTIONS(6957),
    [anon_sym_class] = ACTIONS(6957),
    [anon_sym_timeunit] = ACTIONS(6957),
    [anon_sym_timeprecision] = ACTIONS(6957),
    [anon_sym_type] = ACTIONS(6957),
    [anon_sym_input] = ACTIONS(6957),
    [anon_sym_output] = ACTIONS(6957),
    [anon_sym_inout] = ACTIONS(6957),
    [anon_sym_ref] = ACTIONS(6957),
    [anon_sym_DOLLARfatal] = ACTIONS(6959),
    [anon_sym_DOLLARerror] = ACTIONS(6959),
    [anon_sym_DOLLARwarning] = ACTIONS(6959),
    [anon_sym_DOLLARinfo] = ACTIONS(6959),
    [anon_sym_default] = ACTIONS(6957),
    [anon_sym_clocking] = ACTIONS(6957),
    [anon_sym_defparam] = ACTIONS(6957),
    [anon_sym_bind] = ACTIONS(6957),
    [anon_sym_const] = ACTIONS(6957),
    [anon_sym_function] = ACTIONS(6957),
    [anon_sym_static] = ACTIONS(6957),
    [anon_sym_constraint] = ACTIONS(6957),
    [anon_sym_if] = ACTIONS(6957),
    [anon_sym_LBRACK] = ACTIONS(6959),
    [anon_sym_localparam] = ACTIONS(6957),
    [anon_sym_parameter] = ACTIONS(6957),
    [anon_sym_specparam] = ACTIONS(6957),
    [anon_sym_var] = ACTIONS(6957),
    [anon_sym_import] = ACTIONS(6957),
    [anon_sym_export] = ACTIONS(6957),
    [anon_sym_genvar] = ACTIONS(6957),
    [anon_sym_interconnect] = ACTIONS(6957),
    [anon_sym_typedef] = ACTIONS(6957),
    [anon_sym_enum] = ACTIONS(6957),
    [anon_sym_struct] = ACTIONS(6957),
    [anon_sym_union] = ACTIONS(6957),
    [anon_sym_nettype] = ACTIONS(6957),
    [anon_sym_automatic] = ACTIONS(6957),
    [anon_sym_string] = ACTIONS(6957),
    [anon_sym_chandle] = ACTIONS(6957),
    [anon_sym_event] = ACTIONS(6957),
    [anon_sym_byte] = ACTIONS(6957),
    [anon_sym_shortint] = ACTIONS(6957),
    [anon_sym_int] = ACTIONS(6957),
    [anon_sym_longint] = ACTIONS(6957),
    [anon_sym_integer] = ACTIONS(6957),
    [anon_sym_time] = ACTIONS(6957),
    [anon_sym_bit] = ACTIONS(6957),
    [anon_sym_logic] = ACTIONS(6957),
    [anon_sym_reg] = ACTIONS(6957),
    [anon_sym_shortreal] = ACTIONS(6957),
    [anon_sym_real] = ACTIONS(6957),
    [anon_sym_realtime] = ACTIONS(6957),
    [anon_sym_supply0] = ACTIONS(6957),
    [anon_sym_supply1] = ACTIONS(6957),
    [anon_sym_signed] = ACTIONS(6957),
    [anon_sym_unsigned] = ACTIONS(6957),
    [anon_sym_task] = ACTIONS(6957),
    [anon_sym_assert] = ACTIONS(6957),
    [anon_sym_property] = ACTIONS(6957),
    [anon_sym_assume] = ACTIONS(6957),
    [anon_sym_cover] = ACTIONS(6957),
    [anon_sym_sequence] = ACTIONS(6957),
    [anon_sym_restrict] = ACTIONS(6957),
    [anon_sym_not] = ACTIONS(6957),
    [anon_sym_or] = ACTIONS(6957),
    [anon_sym_and] = ACTIONS(6957),
    [anon_sym_case] = ACTIONS(6957),
    [anon_sym_always] = ACTIONS(6957),
    [anon_sym_covergroup] = ACTIONS(6957),
    [anon_sym_let] = ACTIONS(6957),
    [anon_sym_pulldown] = ACTIONS(6957),
    [anon_sym_pullup] = ACTIONS(6957),
    [anon_sym_cmos] = ACTIONS(6957),
    [anon_sym_rcmos] = ACTIONS(6957),
    [anon_sym_bufif0] = ACTIONS(6957),
    [anon_sym_bufif1] = ACTIONS(6957),
    [anon_sym_notif0] = ACTIONS(6957),
    [anon_sym_notif1] = ACTIONS(6957),
    [anon_sym_nmos] = ACTIONS(6957),
    [anon_sym_pmos] = ACTIONS(6957),
    [anon_sym_rnmos] = ACTIONS(6957),
    [anon_sym_rpmos] = ACTIONS(6957),
    [anon_sym_nand] = ACTIONS(6957),
    [anon_sym_nor] = ACTIONS(6957),
    [anon_sym_xor] = ACTIONS(6957),
    [anon_sym_xnor] = ACTIONS(6957),
    [anon_sym_buf] = ACTIONS(6957),
    [anon_sym_tranif0] = ACTIONS(6957),
    [anon_sym_tranif1] = ACTIONS(6957),
    [anon_sym_rtranif1] = ACTIONS(6957),
    [anon_sym_rtranif0] = ACTIONS(6957),
    [anon_sym_tran] = ACTIONS(6957),
    [anon_sym_rtran] = ACTIONS(6957),
    [anon_sym_generate] = ACTIONS(6957),
    [anon_sym_for] = ACTIONS(6957),
    [anon_sym_initial] = ACTIONS(6957),
    [anon_sym_assign] = ACTIONS(6957),
    [anon_sym_alias] = ACTIONS(6957),
    [anon_sym_always_comb] = ACTIONS(6957),
    [anon_sym_always_latch] = ACTIONS(6957),
    [anon_sym_always_ff] = ACTIONS(6957),
    [anon_sym_final] = ACTIONS(6957),
    [anon_sym_global] = ACTIONS(6957),
    [anon_sym_specify] = ACTIONS(6957),
    [anon_sym_LPAREN_STAR] = ACTIONS(6959),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6959),
    [anon_sym_DOLLARunit] = ACTIONS(6959),
  },
  [1381] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11290),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1382] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11432),
    [sym_sequence_expr] = STATE(10821),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1383] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11563),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1384] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11564),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1385] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11290),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1386] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11565),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1387] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11575),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1388] = {
    [sym_simple_identifier] = ACTIONS(6961),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6963),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6963),
    [anon_sym_BQUOTE] = ACTIONS(6961),
    [aux_sym_id_directive_token1] = ACTIONS(6963),
    [aux_sym_id_directive_token2] = ACTIONS(6963),
    [aux_sym_id_directive_token3] = ACTIONS(6963),
    [aux_sym_id_directive_token4] = ACTIONS(6961),
    [aux_sym_zero_directive_token1] = ACTIONS(6963),
    [aux_sym_zero_directive_token2] = ACTIONS(6963),
    [aux_sym_zero_directive_token3] = ACTIONS(6963),
    [aux_sym_zero_directive_token4] = ACTIONS(6963),
    [aux_sym_zero_directive_token5] = ACTIONS(6963),
    [aux_sym_zero_directive_token6] = ACTIONS(6963),
    [aux_sym_zero_directive_token7] = ACTIONS(6963),
    [aux_sym_zero_directive_token8] = ACTIONS(6963),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6963),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6963),
    [anon_sym_wire] = ACTIONS(6961),
    [anon_sym_tri] = ACTIONS(6961),
    [anon_sym_tri0] = ACTIONS(6961),
    [anon_sym_tri1] = ACTIONS(6961),
    [anon_sym_wand] = ACTIONS(6961),
    [anon_sym_triand] = ACTIONS(6961),
    [anon_sym_wor] = ACTIONS(6961),
    [anon_sym_trior] = ACTIONS(6961),
    [anon_sym_trireg] = ACTIONS(6961),
    [anon_sym_uwire] = ACTIONS(6961),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6963),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6963),
    [aux_sym_begin_keywords_token1] = ACTIONS(6963),
    [anon_sym_SEMI] = ACTIONS(6963),
    [anon_sym_endmodule] = ACTIONS(6961),
    [anon_sym_extern] = ACTIONS(6961),
    [anon_sym_module] = ACTIONS(6961),
    [anon_sym_macromodule] = ACTIONS(6961),
    [anon_sym_interface] = ACTIONS(6961),
    [anon_sym_program] = ACTIONS(6961),
    [anon_sym_checker] = ACTIONS(6961),
    [anon_sym_virtual] = ACTIONS(6961),
    [anon_sym_class] = ACTIONS(6961),
    [anon_sym_timeunit] = ACTIONS(6961),
    [anon_sym_timeprecision] = ACTIONS(6961),
    [anon_sym_type] = ACTIONS(6961),
    [anon_sym_input] = ACTIONS(6961),
    [anon_sym_output] = ACTIONS(6961),
    [anon_sym_inout] = ACTIONS(6961),
    [anon_sym_ref] = ACTIONS(6961),
    [anon_sym_DOLLARfatal] = ACTIONS(6963),
    [anon_sym_DOLLARerror] = ACTIONS(6963),
    [anon_sym_DOLLARwarning] = ACTIONS(6963),
    [anon_sym_DOLLARinfo] = ACTIONS(6963),
    [anon_sym_default] = ACTIONS(6961),
    [anon_sym_clocking] = ACTIONS(6961),
    [anon_sym_defparam] = ACTIONS(6961),
    [anon_sym_bind] = ACTIONS(6961),
    [anon_sym_const] = ACTIONS(6961),
    [anon_sym_function] = ACTIONS(6961),
    [anon_sym_static] = ACTIONS(6961),
    [anon_sym_constraint] = ACTIONS(6961),
    [anon_sym_if] = ACTIONS(6961),
    [anon_sym_LBRACK] = ACTIONS(6963),
    [anon_sym_localparam] = ACTIONS(6961),
    [anon_sym_parameter] = ACTIONS(6961),
    [anon_sym_specparam] = ACTIONS(6961),
    [anon_sym_var] = ACTIONS(6961),
    [anon_sym_import] = ACTIONS(6961),
    [anon_sym_export] = ACTIONS(6961),
    [anon_sym_genvar] = ACTIONS(6961),
    [anon_sym_interconnect] = ACTIONS(6961),
    [anon_sym_typedef] = ACTIONS(6961),
    [anon_sym_enum] = ACTIONS(6961),
    [anon_sym_struct] = ACTIONS(6961),
    [anon_sym_union] = ACTIONS(6961),
    [anon_sym_nettype] = ACTIONS(6961),
    [anon_sym_automatic] = ACTIONS(6961),
    [anon_sym_string] = ACTIONS(6961),
    [anon_sym_chandle] = ACTIONS(6961),
    [anon_sym_event] = ACTIONS(6961),
    [anon_sym_byte] = ACTIONS(6961),
    [anon_sym_shortint] = ACTIONS(6961),
    [anon_sym_int] = ACTIONS(6961),
    [anon_sym_longint] = ACTIONS(6961),
    [anon_sym_integer] = ACTIONS(6961),
    [anon_sym_time] = ACTIONS(6961),
    [anon_sym_bit] = ACTIONS(6961),
    [anon_sym_logic] = ACTIONS(6961),
    [anon_sym_reg] = ACTIONS(6961),
    [anon_sym_shortreal] = ACTIONS(6961),
    [anon_sym_real] = ACTIONS(6961),
    [anon_sym_realtime] = ACTIONS(6961),
    [anon_sym_supply0] = ACTIONS(6961),
    [anon_sym_supply1] = ACTIONS(6961),
    [anon_sym_signed] = ACTIONS(6961),
    [anon_sym_unsigned] = ACTIONS(6961),
    [anon_sym_task] = ACTIONS(6961),
    [anon_sym_assert] = ACTIONS(6961),
    [anon_sym_property] = ACTIONS(6961),
    [anon_sym_assume] = ACTIONS(6961),
    [anon_sym_cover] = ACTIONS(6961),
    [anon_sym_sequence] = ACTIONS(6961),
    [anon_sym_restrict] = ACTIONS(6961),
    [anon_sym_not] = ACTIONS(6961),
    [anon_sym_or] = ACTIONS(6961),
    [anon_sym_and] = ACTIONS(6961),
    [anon_sym_case] = ACTIONS(6961),
    [anon_sym_always] = ACTIONS(6961),
    [anon_sym_covergroup] = ACTIONS(6961),
    [anon_sym_let] = ACTIONS(6961),
    [anon_sym_pulldown] = ACTIONS(6961),
    [anon_sym_pullup] = ACTIONS(6961),
    [anon_sym_cmos] = ACTIONS(6961),
    [anon_sym_rcmos] = ACTIONS(6961),
    [anon_sym_bufif0] = ACTIONS(6961),
    [anon_sym_bufif1] = ACTIONS(6961),
    [anon_sym_notif0] = ACTIONS(6961),
    [anon_sym_notif1] = ACTIONS(6961),
    [anon_sym_nmos] = ACTIONS(6961),
    [anon_sym_pmos] = ACTIONS(6961),
    [anon_sym_rnmos] = ACTIONS(6961),
    [anon_sym_rpmos] = ACTIONS(6961),
    [anon_sym_nand] = ACTIONS(6961),
    [anon_sym_nor] = ACTIONS(6961),
    [anon_sym_xor] = ACTIONS(6961),
    [anon_sym_xnor] = ACTIONS(6961),
    [anon_sym_buf] = ACTIONS(6961),
    [anon_sym_tranif0] = ACTIONS(6961),
    [anon_sym_tranif1] = ACTIONS(6961),
    [anon_sym_rtranif1] = ACTIONS(6961),
    [anon_sym_rtranif0] = ACTIONS(6961),
    [anon_sym_tran] = ACTIONS(6961),
    [anon_sym_rtran] = ACTIONS(6961),
    [anon_sym_generate] = ACTIONS(6961),
    [anon_sym_for] = ACTIONS(6961),
    [anon_sym_initial] = ACTIONS(6961),
    [anon_sym_assign] = ACTIONS(6961),
    [anon_sym_alias] = ACTIONS(6961),
    [anon_sym_always_comb] = ACTIONS(6961),
    [anon_sym_always_latch] = ACTIONS(6961),
    [anon_sym_always_ff] = ACTIONS(6961),
    [anon_sym_final] = ACTIONS(6961),
    [anon_sym_global] = ACTIONS(6961),
    [anon_sym_specify] = ACTIONS(6961),
    [anon_sym_LPAREN_STAR] = ACTIONS(6963),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6963),
    [anon_sym_DOLLARunit] = ACTIONS(6963),
  },
  [1389] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11449),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1390] = {
    [sym_simple_identifier] = ACTIONS(6965),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6967),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6967),
    [anon_sym_BQUOTE] = ACTIONS(6965),
    [aux_sym_id_directive_token1] = ACTIONS(6967),
    [aux_sym_id_directive_token2] = ACTIONS(6967),
    [aux_sym_id_directive_token3] = ACTIONS(6967),
    [aux_sym_id_directive_token4] = ACTIONS(6965),
    [aux_sym_zero_directive_token1] = ACTIONS(6967),
    [aux_sym_zero_directive_token2] = ACTIONS(6967),
    [aux_sym_zero_directive_token3] = ACTIONS(6967),
    [aux_sym_zero_directive_token4] = ACTIONS(6967),
    [aux_sym_zero_directive_token5] = ACTIONS(6967),
    [aux_sym_zero_directive_token6] = ACTIONS(6967),
    [aux_sym_zero_directive_token7] = ACTIONS(6967),
    [aux_sym_zero_directive_token8] = ACTIONS(6967),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6967),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6967),
    [anon_sym_wire] = ACTIONS(6965),
    [anon_sym_tri] = ACTIONS(6965),
    [anon_sym_tri0] = ACTIONS(6965),
    [anon_sym_tri1] = ACTIONS(6965),
    [anon_sym_wand] = ACTIONS(6965),
    [anon_sym_triand] = ACTIONS(6965),
    [anon_sym_wor] = ACTIONS(6965),
    [anon_sym_trior] = ACTIONS(6965),
    [anon_sym_trireg] = ACTIONS(6965),
    [anon_sym_uwire] = ACTIONS(6965),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6967),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6967),
    [aux_sym_begin_keywords_token1] = ACTIONS(6967),
    [anon_sym_SEMI] = ACTIONS(6967),
    [anon_sym_endmodule] = ACTIONS(6965),
    [anon_sym_extern] = ACTIONS(6965),
    [anon_sym_module] = ACTIONS(6965),
    [anon_sym_macromodule] = ACTIONS(6965),
    [anon_sym_interface] = ACTIONS(6965),
    [anon_sym_program] = ACTIONS(6965),
    [anon_sym_checker] = ACTIONS(6965),
    [anon_sym_virtual] = ACTIONS(6965),
    [anon_sym_class] = ACTIONS(6965),
    [anon_sym_timeunit] = ACTIONS(6965),
    [anon_sym_timeprecision] = ACTIONS(6965),
    [anon_sym_type] = ACTIONS(6965),
    [anon_sym_input] = ACTIONS(6965),
    [anon_sym_output] = ACTIONS(6965),
    [anon_sym_inout] = ACTIONS(6965),
    [anon_sym_ref] = ACTIONS(6965),
    [anon_sym_DOLLARfatal] = ACTIONS(6967),
    [anon_sym_DOLLARerror] = ACTIONS(6967),
    [anon_sym_DOLLARwarning] = ACTIONS(6967),
    [anon_sym_DOLLARinfo] = ACTIONS(6967),
    [anon_sym_default] = ACTIONS(6965),
    [anon_sym_clocking] = ACTIONS(6965),
    [anon_sym_defparam] = ACTIONS(6965),
    [anon_sym_bind] = ACTIONS(6965),
    [anon_sym_const] = ACTIONS(6965),
    [anon_sym_function] = ACTIONS(6965),
    [anon_sym_static] = ACTIONS(6965),
    [anon_sym_constraint] = ACTIONS(6965),
    [anon_sym_if] = ACTIONS(6965),
    [anon_sym_LBRACK] = ACTIONS(6967),
    [anon_sym_localparam] = ACTIONS(6965),
    [anon_sym_parameter] = ACTIONS(6965),
    [anon_sym_specparam] = ACTIONS(6965),
    [anon_sym_var] = ACTIONS(6965),
    [anon_sym_import] = ACTIONS(6965),
    [anon_sym_export] = ACTIONS(6965),
    [anon_sym_genvar] = ACTIONS(6965),
    [anon_sym_interconnect] = ACTIONS(6965),
    [anon_sym_typedef] = ACTIONS(6965),
    [anon_sym_enum] = ACTIONS(6965),
    [anon_sym_struct] = ACTIONS(6965),
    [anon_sym_union] = ACTIONS(6965),
    [anon_sym_nettype] = ACTIONS(6965),
    [anon_sym_automatic] = ACTIONS(6965),
    [anon_sym_string] = ACTIONS(6965),
    [anon_sym_chandle] = ACTIONS(6965),
    [anon_sym_event] = ACTIONS(6965),
    [anon_sym_byte] = ACTIONS(6965),
    [anon_sym_shortint] = ACTIONS(6965),
    [anon_sym_int] = ACTIONS(6965),
    [anon_sym_longint] = ACTIONS(6965),
    [anon_sym_integer] = ACTIONS(6965),
    [anon_sym_time] = ACTIONS(6965),
    [anon_sym_bit] = ACTIONS(6965),
    [anon_sym_logic] = ACTIONS(6965),
    [anon_sym_reg] = ACTIONS(6965),
    [anon_sym_shortreal] = ACTIONS(6965),
    [anon_sym_real] = ACTIONS(6965),
    [anon_sym_realtime] = ACTIONS(6965),
    [anon_sym_supply0] = ACTIONS(6965),
    [anon_sym_supply1] = ACTIONS(6965),
    [anon_sym_signed] = ACTIONS(6965),
    [anon_sym_unsigned] = ACTIONS(6965),
    [anon_sym_task] = ACTIONS(6965),
    [anon_sym_assert] = ACTIONS(6965),
    [anon_sym_property] = ACTIONS(6965),
    [anon_sym_assume] = ACTIONS(6965),
    [anon_sym_cover] = ACTIONS(6965),
    [anon_sym_sequence] = ACTIONS(6965),
    [anon_sym_restrict] = ACTIONS(6965),
    [anon_sym_not] = ACTIONS(6965),
    [anon_sym_or] = ACTIONS(6965),
    [anon_sym_and] = ACTIONS(6965),
    [anon_sym_case] = ACTIONS(6965),
    [anon_sym_always] = ACTIONS(6965),
    [anon_sym_covergroup] = ACTIONS(6965),
    [anon_sym_let] = ACTIONS(6965),
    [anon_sym_pulldown] = ACTIONS(6965),
    [anon_sym_pullup] = ACTIONS(6965),
    [anon_sym_cmos] = ACTIONS(6965),
    [anon_sym_rcmos] = ACTIONS(6965),
    [anon_sym_bufif0] = ACTIONS(6965),
    [anon_sym_bufif1] = ACTIONS(6965),
    [anon_sym_notif0] = ACTIONS(6965),
    [anon_sym_notif1] = ACTIONS(6965),
    [anon_sym_nmos] = ACTIONS(6965),
    [anon_sym_pmos] = ACTIONS(6965),
    [anon_sym_rnmos] = ACTIONS(6965),
    [anon_sym_rpmos] = ACTIONS(6965),
    [anon_sym_nand] = ACTIONS(6965),
    [anon_sym_nor] = ACTIONS(6965),
    [anon_sym_xor] = ACTIONS(6965),
    [anon_sym_xnor] = ACTIONS(6965),
    [anon_sym_buf] = ACTIONS(6965),
    [anon_sym_tranif0] = ACTIONS(6965),
    [anon_sym_tranif1] = ACTIONS(6965),
    [anon_sym_rtranif1] = ACTIONS(6965),
    [anon_sym_rtranif0] = ACTIONS(6965),
    [anon_sym_tran] = ACTIONS(6965),
    [anon_sym_rtran] = ACTIONS(6965),
    [anon_sym_generate] = ACTIONS(6965),
    [anon_sym_for] = ACTIONS(6965),
    [anon_sym_initial] = ACTIONS(6965),
    [anon_sym_assign] = ACTIONS(6965),
    [anon_sym_alias] = ACTIONS(6965),
    [anon_sym_always_comb] = ACTIONS(6965),
    [anon_sym_always_latch] = ACTIONS(6965),
    [anon_sym_always_ff] = ACTIONS(6965),
    [anon_sym_final] = ACTIONS(6965),
    [anon_sym_global] = ACTIONS(6965),
    [anon_sym_specify] = ACTIONS(6965),
    [anon_sym_LPAREN_STAR] = ACTIONS(6967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6967),
    [anon_sym_DOLLARunit] = ACTIONS(6967),
  },
  [1391] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11434),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1392] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11281),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1393] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11627),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1394] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11443),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1395] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11649),
    [sym_sequence_expr] = STATE(10883),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1396] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11467),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1397] = {
    [sym_simple_identifier] = ACTIONS(6969),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(6971),
    [aux_sym_text_macro_definition_token1] = ACTIONS(6971),
    [anon_sym_BQUOTE] = ACTIONS(6969),
    [aux_sym_id_directive_token1] = ACTIONS(6971),
    [aux_sym_id_directive_token2] = ACTIONS(6971),
    [aux_sym_id_directive_token3] = ACTIONS(6971),
    [aux_sym_id_directive_token4] = ACTIONS(6969),
    [aux_sym_zero_directive_token1] = ACTIONS(6971),
    [aux_sym_zero_directive_token2] = ACTIONS(6971),
    [aux_sym_zero_directive_token3] = ACTIONS(6971),
    [aux_sym_zero_directive_token4] = ACTIONS(6971),
    [aux_sym_zero_directive_token5] = ACTIONS(6971),
    [aux_sym_zero_directive_token6] = ACTIONS(6971),
    [aux_sym_zero_directive_token7] = ACTIONS(6971),
    [aux_sym_zero_directive_token8] = ACTIONS(6971),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(6971),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(6971),
    [anon_sym_wire] = ACTIONS(6969),
    [anon_sym_tri] = ACTIONS(6969),
    [anon_sym_tri0] = ACTIONS(6969),
    [anon_sym_tri1] = ACTIONS(6969),
    [anon_sym_wand] = ACTIONS(6969),
    [anon_sym_triand] = ACTIONS(6969),
    [anon_sym_wor] = ACTIONS(6969),
    [anon_sym_trior] = ACTIONS(6969),
    [anon_sym_trireg] = ACTIONS(6969),
    [anon_sym_uwire] = ACTIONS(6969),
    [aux_sym_unconnected_drive_token1] = ACTIONS(6971),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(6971),
    [aux_sym_begin_keywords_token1] = ACTIONS(6971),
    [anon_sym_SEMI] = ACTIONS(6971),
    [anon_sym_endmodule] = ACTIONS(6969),
    [anon_sym_extern] = ACTIONS(6969),
    [anon_sym_module] = ACTIONS(6969),
    [anon_sym_macromodule] = ACTIONS(6969),
    [anon_sym_interface] = ACTIONS(6969),
    [anon_sym_program] = ACTIONS(6969),
    [anon_sym_checker] = ACTIONS(6969),
    [anon_sym_virtual] = ACTIONS(6969),
    [anon_sym_class] = ACTIONS(6969),
    [anon_sym_timeunit] = ACTIONS(6969),
    [anon_sym_timeprecision] = ACTIONS(6969),
    [anon_sym_type] = ACTIONS(6969),
    [anon_sym_input] = ACTIONS(6969),
    [anon_sym_output] = ACTIONS(6969),
    [anon_sym_inout] = ACTIONS(6969),
    [anon_sym_ref] = ACTIONS(6969),
    [anon_sym_DOLLARfatal] = ACTIONS(6971),
    [anon_sym_DOLLARerror] = ACTIONS(6971),
    [anon_sym_DOLLARwarning] = ACTIONS(6971),
    [anon_sym_DOLLARinfo] = ACTIONS(6971),
    [anon_sym_default] = ACTIONS(6969),
    [anon_sym_clocking] = ACTIONS(6969),
    [anon_sym_defparam] = ACTIONS(6969),
    [anon_sym_bind] = ACTIONS(6969),
    [anon_sym_const] = ACTIONS(6969),
    [anon_sym_function] = ACTIONS(6969),
    [anon_sym_static] = ACTIONS(6969),
    [anon_sym_constraint] = ACTIONS(6969),
    [anon_sym_if] = ACTIONS(6969),
    [anon_sym_LBRACK] = ACTIONS(6971),
    [anon_sym_localparam] = ACTIONS(6969),
    [anon_sym_parameter] = ACTIONS(6969),
    [anon_sym_specparam] = ACTIONS(6969),
    [anon_sym_var] = ACTIONS(6969),
    [anon_sym_import] = ACTIONS(6969),
    [anon_sym_export] = ACTIONS(6969),
    [anon_sym_genvar] = ACTIONS(6969),
    [anon_sym_interconnect] = ACTIONS(6969),
    [anon_sym_typedef] = ACTIONS(6969),
    [anon_sym_enum] = ACTIONS(6969),
    [anon_sym_struct] = ACTIONS(6969),
    [anon_sym_union] = ACTIONS(6969),
    [anon_sym_nettype] = ACTIONS(6969),
    [anon_sym_automatic] = ACTIONS(6969),
    [anon_sym_string] = ACTIONS(6969),
    [anon_sym_chandle] = ACTIONS(6969),
    [anon_sym_event] = ACTIONS(6969),
    [anon_sym_byte] = ACTIONS(6969),
    [anon_sym_shortint] = ACTIONS(6969),
    [anon_sym_int] = ACTIONS(6969),
    [anon_sym_longint] = ACTIONS(6969),
    [anon_sym_integer] = ACTIONS(6969),
    [anon_sym_time] = ACTIONS(6969),
    [anon_sym_bit] = ACTIONS(6969),
    [anon_sym_logic] = ACTIONS(6969),
    [anon_sym_reg] = ACTIONS(6969),
    [anon_sym_shortreal] = ACTIONS(6969),
    [anon_sym_real] = ACTIONS(6969),
    [anon_sym_realtime] = ACTIONS(6969),
    [anon_sym_supply0] = ACTIONS(6969),
    [anon_sym_supply1] = ACTIONS(6969),
    [anon_sym_signed] = ACTIONS(6969),
    [anon_sym_unsigned] = ACTIONS(6969),
    [anon_sym_task] = ACTIONS(6969),
    [anon_sym_assert] = ACTIONS(6969),
    [anon_sym_property] = ACTIONS(6969),
    [anon_sym_assume] = ACTIONS(6969),
    [anon_sym_cover] = ACTIONS(6969),
    [anon_sym_sequence] = ACTIONS(6969),
    [anon_sym_restrict] = ACTIONS(6969),
    [anon_sym_not] = ACTIONS(6969),
    [anon_sym_or] = ACTIONS(6969),
    [anon_sym_and] = ACTIONS(6969),
    [anon_sym_case] = ACTIONS(6969),
    [anon_sym_always] = ACTIONS(6969),
    [anon_sym_covergroup] = ACTIONS(6969),
    [anon_sym_let] = ACTIONS(6969),
    [anon_sym_pulldown] = ACTIONS(6969),
    [anon_sym_pullup] = ACTIONS(6969),
    [anon_sym_cmos] = ACTIONS(6969),
    [anon_sym_rcmos] = ACTIONS(6969),
    [anon_sym_bufif0] = ACTIONS(6969),
    [anon_sym_bufif1] = ACTIONS(6969),
    [anon_sym_notif0] = ACTIONS(6969),
    [anon_sym_notif1] = ACTIONS(6969),
    [anon_sym_nmos] = ACTIONS(6969),
    [anon_sym_pmos] = ACTIONS(6969),
    [anon_sym_rnmos] = ACTIONS(6969),
    [anon_sym_rpmos] = ACTIONS(6969),
    [anon_sym_nand] = ACTIONS(6969),
    [anon_sym_nor] = ACTIONS(6969),
    [anon_sym_xor] = ACTIONS(6969),
    [anon_sym_xnor] = ACTIONS(6969),
    [anon_sym_buf] = ACTIONS(6969),
    [anon_sym_tranif0] = ACTIONS(6969),
    [anon_sym_tranif1] = ACTIONS(6969),
    [anon_sym_rtranif1] = ACTIONS(6969),
    [anon_sym_rtranif0] = ACTIONS(6969),
    [anon_sym_tran] = ACTIONS(6969),
    [anon_sym_rtran] = ACTIONS(6969),
    [anon_sym_generate] = ACTIONS(6969),
    [anon_sym_for] = ACTIONS(6969),
    [anon_sym_initial] = ACTIONS(6969),
    [anon_sym_assign] = ACTIONS(6969),
    [anon_sym_alias] = ACTIONS(6969),
    [anon_sym_always_comb] = ACTIONS(6969),
    [anon_sym_always_latch] = ACTIONS(6969),
    [anon_sym_always_ff] = ACTIONS(6969),
    [anon_sym_final] = ACTIONS(6969),
    [anon_sym_global] = ACTIONS(6969),
    [anon_sym_specify] = ACTIONS(6969),
    [anon_sym_LPAREN_STAR] = ACTIONS(6971),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6971),
    [anon_sym_DOLLARunit] = ACTIONS(6971),
  },
  [1398] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11428),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1399] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11707),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1400] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11561),
    [sym_sequence_expr] = STATE(10913),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1400),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(3379),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(3383),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(3387),
    [anon_sym_s_nexttime] = ACTIONS(3387),
    [anon_sym_always] = ACTIONS(3389),
    [anon_sym_s_always] = ACTIONS(3391),
    [anon_sym_s_eventually] = ACTIONS(3389),
    [anon_sym_eventually] = ACTIONS(3391),
    [anon_sym_accept_on] = ACTIONS(3393),
    [anon_sym_reject_on] = ACTIONS(3393),
    [anon_sym_sync_accept_on] = ACTIONS(3393),
    [anon_sym_sync_reject_on] = ACTIONS(3393),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1401] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11430),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1402] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11723),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1403] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11339),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1404] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11432),
    [sym_sequence_expr] = STATE(10869),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1404),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1405] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11480),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1406] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1407] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11328),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1408] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11329),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1409] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11290),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1410] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11330),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1411] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11334),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1412] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10824),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1382),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(4108),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(4110),
    [anon_sym_s_nexttime] = ACTIONS(4110),
    [anon_sym_always] = ACTIONS(4112),
    [anon_sym_s_always] = ACTIONS(4114),
    [anon_sym_s_eventually] = ACTIONS(4112),
    [anon_sym_eventually] = ACTIONS(4114),
    [anon_sym_accept_on] = ACTIONS(4116),
    [anon_sym_reject_on] = ACTIONS(4116),
    [anon_sym_sync_accept_on] = ACTIONS(4116),
    [anon_sym_sync_reject_on] = ACTIONS(4116),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1413] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11281),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1414] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11335),
    [sym_sequence_expr] = STATE(10807),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1415] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11327),
    [sym_sequence_expr] = STATE(10815),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1415),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6909),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6913),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6915),
    [anon_sym_s_nexttime] = ACTIONS(6915),
    [anon_sym_always] = ACTIONS(6917),
    [anon_sym_s_always] = ACTIONS(6919),
    [anon_sym_s_eventually] = ACTIONS(6917),
    [anon_sym_eventually] = ACTIONS(6919),
    [anon_sym_accept_on] = ACTIONS(6921),
    [anon_sym_reject_on] = ACTIONS(6921),
    [anon_sym_sync_accept_on] = ACTIONS(6921),
    [anon_sym_sync_reject_on] = ACTIONS(6921),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1416] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11299),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1417] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11458),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1418] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11459),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1419] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11290),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1420] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11460),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1421] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11461),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1422] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11281),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1423] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11463),
    [sym_sequence_expr] = STATE(10828),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1424] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_expr] = STATE(11457),
    [sym_sequence_expr] = STATE(10838),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1424),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(4098),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(6925),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_strong] = ACTIONS(3381),
    [anon_sym_weak] = ACTIONS(3381),
    [anon_sym_not] = ACTIONS(6929),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_nexttime] = ACTIONS(6931),
    [anon_sym_s_nexttime] = ACTIONS(6931),
    [anon_sym_always] = ACTIONS(6933),
    [anon_sym_s_always] = ACTIONS(6935),
    [anon_sym_s_eventually] = ACTIONS(6933),
    [anon_sym_eventually] = ACTIONS(6935),
    [anon_sym_accept_on] = ACTIONS(6937),
    [anon_sym_reject_on] = ACTIONS(6937),
    [anon_sym_sync_accept_on] = ACTIONS(6937),
    [anon_sym_sync_reject_on] = ACTIONS(6937),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1425] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_DQUOTE] = ACTIONS(1682),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1684),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_RBRACE] = ACTIONS(1682),
    [anon_sym_disable] = ACTIONS(1684),
    [anon_sym_iff] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_endfunction] = ACTIONS(1684),
    [anon_sym_u2013_GT] = ACTIONS(1682),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_foreach] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_unique] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_tagged] = ACTIONS(1684),
    [anon_sym_DOLLAR] = ACTIONS(1684),
    [anon_sym_endtask] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_expect] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_POUND_POUND] = ACTIONS(1682),
    [anon_sym_dist] = ACTIONS(1684),
    [anon_sym_begin] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_deassign] = ACTIONS(1684),
    [anon_sym_force] = ACTIONS(1684),
    [anon_sym_release] = ACTIONS(1684),
    [anon_sym_fork] = ACTIONS(1684),
    [anon_sym_join] = ACTIONS(1684),
    [anon_sym_join_any] = ACTIONS(1684),
    [anon_sym_join_none] = ACTIONS(1684),
    [anon_sym_repeat] = ACTIONS(1684),
    [anon_sym_AT] = ACTIONS(1684),
    [anon_sym_AT_STAR] = ACTIONS(1682),
    [anon_sym_return] = ACTIONS(1684),
    [anon_sym_break] = ACTIONS(1684),
    [anon_sym_continue] = ACTIONS(1684),
    [anon_sym_wait] = ACTIONS(1684),
    [anon_sym_wait_order] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1684),
    [anon_sym_DASH_GT_GT] = ACTIONS(1682),
    [anon_sym_unique0] = ACTIONS(1684),
    [anon_sym_priority] = ACTIONS(1684),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_casez] = ACTIONS(1684),
    [anon_sym_casex] = ACTIONS(1684),
    [anon_sym_randcase] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_forever] = ACTIONS(1684),
    [anon_sym_while] = ACTIONS(1684),
    [anon_sym_do] = ACTIONS(1684),
    [anon_sym_TILDE] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_std] = ACTIONS(1684),
    [anon_sym_randomize] = ACTIONS(1684),
    [anon_sym_null] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_TILDE_AMP] = ACTIONS(1682),
    [anon_sym_TILDE_PIPE] = ACTIONS(1682),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [aux_sym_decimal_number_token1] = ACTIONS(1682),
    [aux_sym_decimal_number_token2] = ACTIONS(1682),
    [sym_binary_number] = ACTIONS(1682),
    [sym_octal_number] = ACTIONS(1682),
    [sym_hex_number] = ACTIONS(1682),
    [aux_sym_real_number_token1] = ACTIONS(1682),
    [sym_fixed_point_number] = ACTIONS(1684),
    [sym_unsigned_number] = ACTIONS(1684),
    [anon_sym_SQUOTE0] = ACTIONS(1682),
    [anon_sym_SQUOTE1] = ACTIONS(1682),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [1426] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_DQUOTE] = ACTIONS(1686),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1688),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_RBRACE] = ACTIONS(1686),
    [anon_sym_disable] = ACTIONS(1688),
    [anon_sym_iff] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_endfunction] = ACTIONS(1688),
    [anon_sym_u2013_GT] = ACTIONS(1686),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_foreach] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_unique] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_tagged] = ACTIONS(1688),
    [anon_sym_DOLLAR] = ACTIONS(1688),
    [anon_sym_endtask] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_expect] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_POUND_POUND] = ACTIONS(1686),
    [anon_sym_dist] = ACTIONS(1688),
    [anon_sym_begin] = ACTIONS(1688),
    [anon_sym_BANG] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_deassign] = ACTIONS(1688),
    [anon_sym_force] = ACTIONS(1688),
    [anon_sym_release] = ACTIONS(1688),
    [anon_sym_fork] = ACTIONS(1688),
    [anon_sym_join] = ACTIONS(1688),
    [anon_sym_join_any] = ACTIONS(1688),
    [anon_sym_join_none] = ACTIONS(1688),
    [anon_sym_repeat] = ACTIONS(1688),
    [anon_sym_AT] = ACTIONS(1688),
    [anon_sym_AT_STAR] = ACTIONS(1686),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_break] = ACTIONS(1688),
    [anon_sym_continue] = ACTIONS(1688),
    [anon_sym_wait] = ACTIONS(1688),
    [anon_sym_wait_order] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1688),
    [anon_sym_DASH_GT_GT] = ACTIONS(1686),
    [anon_sym_unique0] = ACTIONS(1688),
    [anon_sym_priority] = ACTIONS(1688),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_casez] = ACTIONS(1688),
    [anon_sym_casex] = ACTIONS(1688),
    [anon_sym_randcase] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_forever] = ACTIONS(1688),
    [anon_sym_while] = ACTIONS(1688),
    [anon_sym_do] = ACTIONS(1688),
    [anon_sym_TILDE] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_std] = ACTIONS(1688),
    [anon_sym_randomize] = ACTIONS(1688),
    [anon_sym_null] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_TILDE_AMP] = ACTIONS(1686),
    [anon_sym_TILDE_PIPE] = ACTIONS(1686),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [aux_sym_decimal_number_token1] = ACTIONS(1686),
    [aux_sym_decimal_number_token2] = ACTIONS(1686),
    [sym_binary_number] = ACTIONS(1686),
    [sym_octal_number] = ACTIONS(1686),
    [sym_hex_number] = ACTIONS(1686),
    [aux_sym_real_number_token1] = ACTIONS(1686),
    [sym_fixed_point_number] = ACTIONS(1688),
    [sym_unsigned_number] = ACTIONS(1688),
    [anon_sym_SQUOTE0] = ACTIONS(1686),
    [anon_sym_SQUOTE1] = ACTIONS(1686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [1427] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11446),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1455),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1455),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1428] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11486),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1429),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1429),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1429] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11401),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1430] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11380),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1431),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1431),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1431] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11448),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1432] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11390),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1433),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1433),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1433] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11412),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1434] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11412),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1435),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1435),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1435] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11445),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1436] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11399),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1437),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1437),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1437] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11423),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1438] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11479),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1439),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1439),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1439] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11382),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1440] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11382),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1441),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1441),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1441] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11397),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1442] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11468),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1443] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11486),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1444] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11393),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1445] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11405),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1446),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1446),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1446] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11418),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1447] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11410),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1442),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1442),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1448] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11398),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1462),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1462),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1449] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11427),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1452),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1452),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1450] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11431),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1451),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1451),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1451] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11446),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1452] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11482),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1453] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11379),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1454),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1454),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1454] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11414),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1455] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11456),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1456] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11414),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1457),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1457),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1457] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11447),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1458] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11404),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1459),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1459),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1459] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11388),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1460] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_EQ] = ACTIONS(1688),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1688),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_disable] = ACTIONS(1688),
    [anon_sym_bind] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_foreach] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_unique] = ACTIONS(1688),
    [anon_sym_localparam] = ACTIONS(1688),
    [anon_sym_parameter] = ACTIONS(1688),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1688),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_expect] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_POUND_POUND] = ACTIONS(1686),
    [anon_sym_begin] = ACTIONS(1688),
    [anon_sym_end] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_let] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_PLUS_EQ] = ACTIONS(1686),
    [anon_sym_DASH_EQ] = ACTIONS(1686),
    [anon_sym_STAR_EQ] = ACTIONS(1686),
    [anon_sym_SLASH_EQ] = ACTIONS(1686),
    [anon_sym_PERCENT_EQ] = ACTIONS(1686),
    [anon_sym_AMP_EQ] = ACTIONS(1686),
    [anon_sym_PIPE_EQ] = ACTIONS(1686),
    [anon_sym_CARET_EQ] = ACTIONS(1686),
    [anon_sym_LT_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT_EQ] = ACTIONS(1686),
    [anon_sym_LT_LT_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1686),
    [anon_sym_deassign] = ACTIONS(1688),
    [anon_sym_force] = ACTIONS(1688),
    [anon_sym_release] = ACTIONS(1688),
    [anon_sym_fork] = ACTIONS(1688),
    [anon_sym_join] = ACTIONS(1688),
    [anon_sym_join_any] = ACTIONS(1688),
    [anon_sym_join_none] = ACTIONS(1688),
    [anon_sym_repeat] = ACTIONS(1688),
    [anon_sym_AT] = ACTIONS(1688),
    [anon_sym_AT_STAR] = ACTIONS(1686),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_break] = ACTIONS(1688),
    [anon_sym_continue] = ACTIONS(1688),
    [anon_sym_wait] = ACTIONS(1688),
    [anon_sym_wait_order] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1688),
    [anon_sym_DASH_GT_GT] = ACTIONS(1686),
    [anon_sym_unique0] = ACTIONS(1688),
    [anon_sym_priority] = ACTIONS(1688),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_casez] = ACTIONS(1688),
    [anon_sym_casex] = ACTIONS(1688),
    [anon_sym_randcase] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_forever] = ACTIONS(1688),
    [anon_sym_while] = ACTIONS(1688),
    [anon_sym_do] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT_LT] = ACTIONS(1688),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [1461] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_EQ] = ACTIONS(1684),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1684),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_disable] = ACTIONS(1684),
    [anon_sym_bind] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_foreach] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_unique] = ACTIONS(1684),
    [anon_sym_localparam] = ACTIONS(1684),
    [anon_sym_parameter] = ACTIONS(1684),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1684),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_expect] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_POUND_POUND] = ACTIONS(1682),
    [anon_sym_begin] = ACTIONS(1684),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_let] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_PLUS_EQ] = ACTIONS(1682),
    [anon_sym_DASH_EQ] = ACTIONS(1682),
    [anon_sym_STAR_EQ] = ACTIONS(1682),
    [anon_sym_SLASH_EQ] = ACTIONS(1682),
    [anon_sym_PERCENT_EQ] = ACTIONS(1682),
    [anon_sym_AMP_EQ] = ACTIONS(1682),
    [anon_sym_PIPE_EQ] = ACTIONS(1682),
    [anon_sym_CARET_EQ] = ACTIONS(1682),
    [anon_sym_LT_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT_EQ] = ACTIONS(1682),
    [anon_sym_LT_LT_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1682),
    [anon_sym_deassign] = ACTIONS(1684),
    [anon_sym_force] = ACTIONS(1684),
    [anon_sym_release] = ACTIONS(1684),
    [anon_sym_fork] = ACTIONS(1684),
    [anon_sym_join] = ACTIONS(1684),
    [anon_sym_join_any] = ACTIONS(1684),
    [anon_sym_join_none] = ACTIONS(1684),
    [anon_sym_repeat] = ACTIONS(1684),
    [anon_sym_AT] = ACTIONS(1684),
    [anon_sym_AT_STAR] = ACTIONS(1682),
    [anon_sym_return] = ACTIONS(1684),
    [anon_sym_break] = ACTIONS(1684),
    [anon_sym_continue] = ACTIONS(1684),
    [anon_sym_wait] = ACTIONS(1684),
    [anon_sym_wait_order] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1684),
    [anon_sym_DASH_GT_GT] = ACTIONS(1682),
    [anon_sym_unique0] = ACTIONS(1684),
    [anon_sym_priority] = ACTIONS(1684),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_casez] = ACTIONS(1684),
    [anon_sym_casex] = ACTIONS(1684),
    [anon_sym_randcase] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_forever] = ACTIONS(1684),
    [anon_sym_while] = ACTIONS(1684),
    [anon_sym_do] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT_LT] = ACTIONS(1684),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [1462] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11429),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(5731),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(5731),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1463] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11406),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1443),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1443),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1464] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(12566),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__var_data_type] = STATE(12566),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_expr] = STATE(11429),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_assertion_variable_declaration] = STATE(1444),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5800),
    [sym_package_scope] = STATE(12469),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_declaration_repeat1] = STATE(1444),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_var] = ACTIONS(4104),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1465] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym__module_or_generate_item_declaration] = STATE(5648),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5648),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_inout_declaration] = STATE(18782),
    [sym_input_declaration] = STATE(18782),
    [sym_output_declaration] = STATE(18782),
    [sym_interface_port_declaration] = STATE(18782),
    [sym_ref_declaration] = STATE(18782),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5648),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5648),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_continuous_assign] = STATE(5648),
    [sym_initial_construct] = STATE(5648),
    [sym_final_construct] = STATE(5648),
    [sym_clocking_declaration] = STATE(5648),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10697),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_input] = ACTIONS(129),
    [anon_sym_output] = ACTIONS(131),
    [anon_sym_inout] = ACTIONS(133),
    [anon_sym_ref] = ACTIONS(135),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1466] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11579),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(19232),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_let_actual_arg] = STATE(19237),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8220),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5858),
    [sym_package_scope] = STATE(12297),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13048),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_RPAREN] = ACTIONS(6979),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6981),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1467] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11579),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(20233),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_let_actual_arg] = STATE(20234),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8220),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5858),
    [sym_package_scope] = STATE(12297),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13048),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_RPAREN] = ACTIONS(6983),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6981),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1468] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11579),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(20233),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8209),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5858),
    [sym_package_scope] = STATE(12297),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13048),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_RPAREN] = ACTIONS(6985),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6981),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1469] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11579),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(19232),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(16037),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8209),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5858),
    [sym_package_scope] = STATE(12297),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13048),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_RPAREN] = ACTIONS(6987),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6981),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1470] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17219),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1471] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(16744),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1472] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17152),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1473] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17235),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1474] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17151),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1475] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17222),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1476] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_data_type] = STATE(16947),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_list_of_parameter_assignments] = STATE(18047),
    [sym_ordered_parameter_assignment] = STATE(15441),
    [sym_named_parameter_assignment] = STATE(15442),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_param_expression] = STATE(16951),
    [sym_expression] = STATE(5656),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3007),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5232),
    [sym_package_scope] = STATE(12065),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_RPAREN] = ACTIONS(6993),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(6997),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(7003),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [1477] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(16913),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1478] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17231),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1479] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(16910),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1480] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(16947),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_list_of_parameter_assignments] = STATE(18047),
    [sym_ordered_parameter_assignment] = STATE(15441),
    [sym_named_parameter_assignment] = STATE(15442),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_param_expression] = STATE(16951),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16947),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(6993),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(6997),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(7031),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1481] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(16947),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_list_of_parameter_assignments] = STATE(18047),
    [sym_ordered_parameter_assignment] = STATE(15441),
    [sym_named_parameter_assignment] = STATE(15442),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_param_expression] = STATE(16951),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16953),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(6993),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(6997),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(7031),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1482] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11436),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym__sequence_actual_arg] = STATE(17216),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15666),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8232),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1483] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_scalar_constant] = STATE(17168),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8625),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3251),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_0] = ACTIONS(7035),
    [anon_sym_1] = ACTIONS(7035),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_1_SQUOTEb0] = ACTIONS(7035),
    [anon_sym_1_SQUOTEb1] = ACTIONS(7035),
    [anon_sym_1_SQUOTEB0] = ACTIONS(7035),
    [anon_sym_1_SQUOTEB1] = ACTIONS(7035),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_SQUOTEb0] = ACTIONS(7035),
    [anon_sym_SQUOTEb1] = ACTIONS(7035),
    [anon_sym_SQUOTEB0] = ACTIONS(7035),
    [anon_sym_SQUOTEB1] = ACTIONS(7035),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(7037),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1484] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_scalar_constant] = STATE(17168),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9013),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3283),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_0] = ACTIONS(7035),
    [anon_sym_1] = ACTIONS(7035),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_1_SQUOTEb0] = ACTIONS(7035),
    [anon_sym_1_SQUOTEb1] = ACTIONS(7035),
    [anon_sym_1_SQUOTEB0] = ACTIONS(7035),
    [anon_sym_1_SQUOTEB1] = ACTIONS(7035),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_SQUOTEb0] = ACTIONS(7035),
    [anon_sym_SQUOTEb1] = ACTIONS(7035),
    [anon_sym_SQUOTEB0] = ACTIONS(7035),
    [anon_sym_SQUOTEB1] = ACTIONS(7035),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(7037),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1485] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(1522),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(8685),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_set_repeat1] = STATE(1522),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7041),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1486] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11332),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(17798),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(8197),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17799),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10934),
    [sym_unary_operator] = STATE(5324),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(5848),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5735),
    [sym_package_scope] = STATE(11977),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12971),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7059),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7061),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7065),
    [anon_sym_DOLLARroot] = ACTIONS(7067),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1487] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11332),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(8197),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10934),
    [sym_unary_operator] = STATE(5324),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(5848),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5735),
    [sym_package_scope] = STATE(11977),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12971),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7059),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7061),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7065),
    [anon_sym_DOLLARroot] = ACTIONS(7067),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1488] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1506),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1506),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7069),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1489] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7073),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1490] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7075),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1491] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7077),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1492] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1490),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1490),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7079),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1493] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7081),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1494] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1493),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1493),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7083),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1495] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1500),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1500),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7085),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1496] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1498),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1498),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7087),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1497] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1503),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1503),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7089),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1498] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7091),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1499] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7093),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1500] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7095),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1501] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym__module_or_generate_item_declaration] = STATE(5648),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym_package_or_generate_item_declaration] = STATE(5648),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_genvar_declaration] = STATE(5648),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym_concurrent_assertion_item] = STATE(5648),
    [sym__concurrent_assertion_statement] = STATE(1224),
    [sym_assert_property_statement] = STATE(1224),
    [sym_assume_property_statement] = STATE(1224),
    [sym_cover_property_statement] = STATE(1224),
    [sym_cover_sequence_statement] = STATE(1224),
    [sym_restrict_property_statement] = STATE(1224),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_checker_instantiation] = STATE(1224),
    [sym_continuous_assign] = STATE(5648),
    [sym_initial_construct] = STATE(5648),
    [sym_final_construct] = STATE(5648),
    [sym_clocking_declaration] = STATE(5648),
    [sym_attribute_instance] = STATE(2328),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10755),
    [sym_package_scope] = STATE(14321),
    [aux_sym__description_repeat1] = STATE(2328),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_clocking] = ACTIONS(143),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(151),
    [anon_sym_genvar] = ACTIONS(153),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_assert] = ACTIONS(3668),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_assume] = ACTIONS(3670),
    [anon_sym_cover] = ACTIONS(3672),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_initial] = ACTIONS(189),
    [anon_sym_assign] = ACTIONS(191),
    [anon_sym_final] = ACTIONS(195),
    [anon_sym_global] = ACTIONS(197),
    [anon_sym_LPAREN_STAR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1502] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1491),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1491),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7097),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1503] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7099),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1504] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1499),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1499),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7101),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1505] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7103),
    [anon_sym_DQUOTE] = ACTIONS(7106),
    [anon_sym_LPAREN] = ACTIONS(7109),
    [anon_sym_BQUOTE] = ACTIONS(7112),
    [anon_sym_type] = ACTIONS(7115),
    [anon_sym_LBRACE] = ACTIONS(7118),
    [anon_sym_RBRACE] = ACTIONS(7121),
    [anon_sym_disable] = ACTIONS(7123),
    [anon_sym_const] = ACTIONS(7126),
    [anon_sym_local] = ACTIONS(7129),
    [anon_sym_super] = ACTIONS(7132),
    [anon_sym_solve] = ACTIONS(7135),
    [anon_sym_soft] = ACTIONS(7138),
    [anon_sym_if] = ACTIONS(7141),
    [anon_sym_foreach] = ACTIONS(7144),
    [anon_sym_unique] = ACTIONS(7147),
    [anon_sym_string] = ACTIONS(7126),
    [anon_sym_byte] = ACTIONS(7150),
    [anon_sym_shortint] = ACTIONS(7150),
    [anon_sym_int] = ACTIONS(7150),
    [anon_sym_longint] = ACTIONS(7150),
    [anon_sym_integer] = ACTIONS(7150),
    [anon_sym_time] = ACTIONS(7150),
    [anon_sym_bit] = ACTIONS(7153),
    [anon_sym_logic] = ACTIONS(7153),
    [anon_sym_reg] = ACTIONS(7153),
    [anon_sym_shortreal] = ACTIONS(7156),
    [anon_sym_real] = ACTIONS(7156),
    [anon_sym_realtime] = ACTIONS(7156),
    [anon_sym_signed] = ACTIONS(7126),
    [anon_sym_unsigned] = ACTIONS(7126),
    [anon_sym_tagged] = ACTIONS(7159),
    [anon_sym_DOLLAR] = ACTIONS(7162),
    [anon_sym_PLUS] = ACTIONS(7165),
    [anon_sym_PLUS_PLUS] = ACTIONS(7168),
    [anon_sym_BANG] = ACTIONS(7171),
    [anon_sym_DASH] = ACTIONS(7165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7174),
    [anon_sym_TILDE] = ACTIONS(7165),
    [anon_sym_std] = ACTIONS(7177),
    [anon_sym_randomize] = ACTIONS(7180),
    [anon_sym_null] = ACTIONS(7183),
    [anon_sym_AMP] = ACTIONS(7171),
    [anon_sym_PIPE] = ACTIONS(7171),
    [anon_sym_CARET] = ACTIONS(7165),
    [anon_sym_CARET_TILDE] = ACTIONS(7171),
    [anon_sym_TILDE_CARET] = ACTIONS(7171),
    [anon_sym_this] = ACTIONS(7186),
    [anon_sym_TILDE_AMP] = ACTIONS(7171),
    [anon_sym_TILDE_PIPE] = ACTIONS(7171),
    [anon_sym_DASH_DASH] = ACTIONS(7168),
    [aux_sym_decimal_number_token1] = ACTIONS(7189),
    [aux_sym_decimal_number_token2] = ACTIONS(7189),
    [sym_binary_number] = ACTIONS(7192),
    [sym_octal_number] = ACTIONS(7192),
    [sym_hex_number] = ACTIONS(7192),
    [aux_sym_real_number_token1] = ACTIONS(7195),
    [sym_fixed_point_number] = ACTIONS(7198),
    [sym_unsigned_number] = ACTIONS(7201),
    [anon_sym_SQUOTE0] = ACTIONS(7204),
    [anon_sym_SQUOTE1] = ACTIONS(7204),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7207),
    [anon_sym_DOLLARroot] = ACTIONS(7210),
    [anon_sym_DOLLARunit] = ACTIONS(7213),
    [sym_system_tf_identifier] = ACTIONS(7216),
  },
  [1506] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1505),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1505),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7219),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1507] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_block_item] = STATE(1489),
    [sym_constraint_expression] = STATE(6627),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_block_repeat1] = STATE(1489),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7221),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_solve] = ACTIONS(7071),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1508] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(16947),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_param_expression] = STATE(18024),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16947),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7223),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(7031),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1509] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(17328),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9556),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7225),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1510] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(16947),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_ordered_parameter_assignment] = STATE(16829),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_param_expression] = STATE(16951),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16947),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(7031),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1511] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(16687),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9417),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7229),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1512] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_trans_set] = STATE(19806),
    [sym_trans_range_list] = STATE(16339),
    [sym_trans_item] = STATE(13915),
    [sym_covergroup_range_list] = STATE(13916),
    [sym_covergroup_value_range] = STATE(12333),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(8751),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5319),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(7025),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5813),
    [sym_package_scope] = STATE(12316),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13068),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7233),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7235),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7239),
    [anon_sym_DOLLARroot] = ACTIONS(7241),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1513] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(17127),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9424),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7243),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1514] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(17055),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9451),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7247),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1515] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(17211),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9411),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7251),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1516] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7255),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1517] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11596),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1546),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7257),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1518] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(1518),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_set_repeat1] = STATE(1518),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7259),
    [anon_sym_DQUOTE] = ACTIONS(7262),
    [anon_sym_LPAREN] = ACTIONS(7265),
    [anon_sym_BQUOTE] = ACTIONS(7268),
    [anon_sym_type] = ACTIONS(7271),
    [anon_sym_LBRACE] = ACTIONS(7274),
    [anon_sym_RBRACE] = ACTIONS(7277),
    [anon_sym_disable] = ACTIONS(7279),
    [anon_sym_const] = ACTIONS(7282),
    [anon_sym_local] = ACTIONS(7285),
    [anon_sym_super] = ACTIONS(7288),
    [anon_sym_soft] = ACTIONS(7291),
    [anon_sym_if] = ACTIONS(7294),
    [anon_sym_foreach] = ACTIONS(7297),
    [anon_sym_unique] = ACTIONS(7300),
    [anon_sym_string] = ACTIONS(7282),
    [anon_sym_byte] = ACTIONS(7303),
    [anon_sym_shortint] = ACTIONS(7303),
    [anon_sym_int] = ACTIONS(7303),
    [anon_sym_longint] = ACTIONS(7303),
    [anon_sym_integer] = ACTIONS(7303),
    [anon_sym_time] = ACTIONS(7303),
    [anon_sym_bit] = ACTIONS(7306),
    [anon_sym_logic] = ACTIONS(7306),
    [anon_sym_reg] = ACTIONS(7306),
    [anon_sym_shortreal] = ACTIONS(7309),
    [anon_sym_real] = ACTIONS(7309),
    [anon_sym_realtime] = ACTIONS(7309),
    [anon_sym_signed] = ACTIONS(7282),
    [anon_sym_unsigned] = ACTIONS(7282),
    [anon_sym_tagged] = ACTIONS(7312),
    [anon_sym_DOLLAR] = ACTIONS(7315),
    [anon_sym_PLUS] = ACTIONS(7318),
    [anon_sym_PLUS_PLUS] = ACTIONS(7321),
    [anon_sym_BANG] = ACTIONS(7324),
    [anon_sym_DASH] = ACTIONS(7318),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7327),
    [anon_sym_TILDE] = ACTIONS(7318),
    [anon_sym_std] = ACTIONS(7330),
    [anon_sym_randomize] = ACTIONS(7333),
    [anon_sym_null] = ACTIONS(7336),
    [anon_sym_AMP] = ACTIONS(7324),
    [anon_sym_PIPE] = ACTIONS(7324),
    [anon_sym_CARET] = ACTIONS(7318),
    [anon_sym_CARET_TILDE] = ACTIONS(7324),
    [anon_sym_TILDE_CARET] = ACTIONS(7324),
    [anon_sym_this] = ACTIONS(7339),
    [anon_sym_TILDE_AMP] = ACTIONS(7324),
    [anon_sym_TILDE_PIPE] = ACTIONS(7324),
    [anon_sym_DASH_DASH] = ACTIONS(7321),
    [aux_sym_decimal_number_token1] = ACTIONS(7342),
    [aux_sym_decimal_number_token2] = ACTIONS(7342),
    [sym_binary_number] = ACTIONS(7345),
    [sym_octal_number] = ACTIONS(7345),
    [sym_hex_number] = ACTIONS(7345),
    [aux_sym_real_number_token1] = ACTIONS(7348),
    [sym_fixed_point_number] = ACTIONS(7351),
    [sym_unsigned_number] = ACTIONS(7354),
    [anon_sym_SQUOTE0] = ACTIONS(7357),
    [anon_sym_SQUOTE1] = ACTIONS(7357),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7357),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7360),
    [anon_sym_DOLLARroot] = ACTIONS(7363),
    [anon_sym_DOLLARunit] = ACTIONS(7366),
    [sym_system_tf_identifier] = ACTIONS(7369),
  },
  [1519] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11599),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1547),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7372),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1520] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11603),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1548),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7374),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1521] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11533),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1535),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7376),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1522] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(1518),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constraint_set_repeat1] = STATE(1518),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7378),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1523] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11656),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1539),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7380),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1524] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11525),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1516),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7382),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1525] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11595),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1536),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7384),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1526] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7386),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1527] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11531),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1540),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7388),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1528] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7390),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1529] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11560),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1538),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7392),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1530] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11500),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1526),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7394),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1531] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11576),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1542),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7396),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1532] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11591),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1545),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7398),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1533] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11634),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1528),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7400),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1534] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11585),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1543),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7402),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1535] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7404),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1536] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7406),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1537] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11588),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1544),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7408),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1538] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7410),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1539] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7412),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1540] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7414),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1541] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7416),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1542] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7418),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1543] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7420),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1544] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7422),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1545] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7424),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1546] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7426),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1547] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7428),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1548] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11516),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7430),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1549] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11637),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1541),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_disable] = ACTIONS(7432),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1550] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11638),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1551] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11543),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1552] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11323),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1553] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7434),
    [anon_sym_SEMI] = ACTIONS(7437),
    [anon_sym_checker] = ACTIONS(7440),
    [anon_sym_endchecker] = ACTIONS(7443),
    [anon_sym_virtual] = ACTIONS(7445),
    [anon_sym_type] = ACTIONS(7448),
    [anon_sym_DOLLARfatal] = ACTIONS(7451),
    [anon_sym_DOLLARerror] = ACTIONS(7454),
    [anon_sym_DOLLARwarning] = ACTIONS(7454),
    [anon_sym_DOLLARinfo] = ACTIONS(7454),
    [anon_sym_default] = ACTIONS(7457),
    [anon_sym_clocking] = ACTIONS(7460),
    [anon_sym_rand] = ACTIONS(7463),
    [anon_sym_const] = ACTIONS(7466),
    [anon_sym_function] = ACTIONS(7469),
    [anon_sym_static] = ACTIONS(7472),
    [anon_sym_if] = ACTIONS(7475),
    [anon_sym_LBRACK] = ACTIONS(7478),
    [anon_sym_var] = ACTIONS(7481),
    [anon_sym_import] = ACTIONS(7484),
    [anon_sym_genvar] = ACTIONS(7487),
    [anon_sym_typedef] = ACTIONS(7490),
    [anon_sym_enum] = ACTIONS(7493),
    [anon_sym_struct] = ACTIONS(7496),
    [anon_sym_union] = ACTIONS(7499),
    [anon_sym_nettype] = ACTIONS(7502),
    [anon_sym_automatic] = ACTIONS(7472),
    [anon_sym_string] = ACTIONS(7505),
    [anon_sym_chandle] = ACTIONS(7505),
    [anon_sym_event] = ACTIONS(7505),
    [anon_sym_byte] = ACTIONS(7508),
    [anon_sym_shortint] = ACTIONS(7508),
    [anon_sym_int] = ACTIONS(7508),
    [anon_sym_longint] = ACTIONS(7508),
    [anon_sym_integer] = ACTIONS(7508),
    [anon_sym_time] = ACTIONS(7508),
    [anon_sym_bit] = ACTIONS(7511),
    [anon_sym_logic] = ACTIONS(7511),
    [anon_sym_reg] = ACTIONS(7511),
    [anon_sym_shortreal] = ACTIONS(7514),
    [anon_sym_real] = ACTIONS(7514),
    [anon_sym_realtime] = ACTIONS(7514),
    [anon_sym_signed] = ACTIONS(7517),
    [anon_sym_unsigned] = ACTIONS(7517),
    [anon_sym_assert] = ACTIONS(7520),
    [anon_sym_property] = ACTIONS(7523),
    [anon_sym_assume] = ACTIONS(7526),
    [anon_sym_cover] = ACTIONS(7529),
    [anon_sym_sequence] = ACTIONS(7532),
    [anon_sym_restrict] = ACTIONS(7535),
    [anon_sym_case] = ACTIONS(7538),
    [anon_sym_always] = ACTIONS(7541),
    [anon_sym_covergroup] = ACTIONS(7544),
    [anon_sym_let] = ACTIONS(7547),
    [anon_sym_generate] = ACTIONS(7550),
    [anon_sym_for] = ACTIONS(7553),
    [anon_sym_initial] = ACTIONS(7556),
    [anon_sym_assign] = ACTIONS(7559),
    [anon_sym_always_comb] = ACTIONS(7541),
    [anon_sym_always_latch] = ACTIONS(7541),
    [anon_sym_always_ff] = ACTIONS(7541),
    [anon_sym_final] = ACTIONS(7562),
    [anon_sym_global] = ACTIONS(7565),
    [anon_sym_LPAREN_STAR] = ACTIONS(7568),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7571),
    [anon_sym_DOLLARunit] = ACTIONS(7574),
  },
  [1554] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10834),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1555] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1573),
    [sym__checker_or_generate_item] = STATE(1573),
    [sym_checker_or_generate_item_declaration] = STATE(1573),
    [sym__checker_generate_item] = STATE(1573),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1573),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1573),
    [sym_loop_generate_construct] = STATE(1573),
    [sym__conditional_generate_construct] = STATE(1573),
    [sym_if_generate_construct] = STATE(1573),
    [sym_case_generate_construct] = STATE(1573),
    [sym_continuous_assign] = STATE(1573),
    [sym_initial_construct] = STATE(1573),
    [sym_always_construct] = STATE(1573),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1573),
    [sym__assertion_item] = STATE(1573),
    [sym_deferred_immediate_assertion_item] = STATE(1573),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1573),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7581),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1556] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10836),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1557] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6376),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9535),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7593),
    [anon_sym_foreach] = ACTIONS(7595),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1558] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6381),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1559] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11305),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1560] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10806),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1561] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11313),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1562] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10837),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1563] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11616),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1564] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11619),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1565] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9394),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_module_path_expression] = STATE(15780),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7292),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7597),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7599),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1566] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11493),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1567] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11498),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1568] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10832),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1569] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10840),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1570] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11578),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1571] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11584),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1572] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1595),
    [sym__checker_or_generate_item] = STATE(1595),
    [sym_checker_or_generate_item_declaration] = STATE(1595),
    [sym__checker_generate_item] = STATE(1595),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1595),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1595),
    [sym_loop_generate_construct] = STATE(1595),
    [sym__conditional_generate_construct] = STATE(1595),
    [sym_if_generate_construct] = STATE(1595),
    [sym_case_generate_construct] = STATE(1595),
    [sym_continuous_assign] = STATE(1595),
    [sym_initial_construct] = STATE(1595),
    [sym_always_construct] = STATE(1595),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1595),
    [sym__assertion_item] = STATE(1595),
    [sym_deferred_immediate_assertion_item] = STATE(1595),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1595),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7603),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1573] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7605),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1574] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1581),
    [sym__checker_or_generate_item] = STATE(1581),
    [sym_checker_or_generate_item_declaration] = STATE(1581),
    [sym__checker_generate_item] = STATE(1581),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1581),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1581),
    [sym_loop_generate_construct] = STATE(1581),
    [sym__conditional_generate_construct] = STATE(1581),
    [sym_if_generate_construct] = STATE(1581),
    [sym_case_generate_construct] = STATE(1581),
    [sym_continuous_assign] = STATE(1581),
    [sym_initial_construct] = STATE(1581),
    [sym_always_construct] = STATE(1581),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1581),
    [sym__assertion_item] = STATE(1581),
    [sym_deferred_immediate_assertion_item] = STATE(1581),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1581),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7605),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1575] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10819),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1576] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11491),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1577] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11492),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1578] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7607),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1579] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_select_expression] = STATE(14775),
    [sym_select_condition] = STATE(12808),
    [sym__cross_set_expression] = STATE(12186),
    [sym__covergroup_expression] = STATE(12186),
    [sym_let_expression] = STATE(9317),
    [sym_operator_assignment] = STATE(18323),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(7947),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9489),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_mintypmax_expression] = STATE(18324),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(10938),
    [sym_unary_operator] = STATE(5338),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5866),
    [sym_package_scope] = STATE(12313),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13063),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(7611),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7613),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(7615),
    [anon_sym_binsof] = ACTIONS(7617),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7621),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [1580] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1656),
    [sym__checker_or_generate_item] = STATE(1656),
    [sym_checker_or_generate_item_declaration] = STATE(1656),
    [sym__checker_generate_item] = STATE(1656),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1656),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1656),
    [sym_loop_generate_construct] = STATE(1656),
    [sym__conditional_generate_construct] = STATE(1656),
    [sym_if_generate_construct] = STATE(1656),
    [sym_case_generate_construct] = STATE(1656),
    [sym_continuous_assign] = STATE(1656),
    [sym_initial_construct] = STATE(1656),
    [sym_always_construct] = STATE(1656),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1656),
    [sym__assertion_item] = STATE(1656),
    [sym_deferred_immediate_assertion_item] = STATE(1656),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1656),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7623),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1581] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7625),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1582] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11566),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1583] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7627),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1584] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1636),
    [sym__checker_or_generate_item] = STATE(1636),
    [sym_checker_or_generate_item_declaration] = STATE(1636),
    [sym__checker_generate_item] = STATE(1636),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1636),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1636),
    [sym_loop_generate_construct] = STATE(1636),
    [sym__conditional_generate_construct] = STATE(1636),
    [sym_if_generate_construct] = STATE(1636),
    [sym_case_generate_construct] = STATE(1636),
    [sym_continuous_assign] = STATE(1636),
    [sym_initial_construct] = STATE(1636),
    [sym_always_construct] = STATE(1636),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1636),
    [sym__assertion_item] = STATE(1636),
    [sym_deferred_immediate_assertion_item] = STATE(1636),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1636),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7627),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1585] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6598),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1586] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6324),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1587] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11605),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1588] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10809),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1589] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11538),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1590] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10811),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1591] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1606),
    [sym__checker_or_generate_item] = STATE(1606),
    [sym_checker_or_generate_item_declaration] = STATE(1606),
    [sym__checker_generate_item] = STATE(1606),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1606),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1606),
    [sym_loop_generate_construct] = STATE(1606),
    [sym__conditional_generate_construct] = STATE(1606),
    [sym_if_generate_construct] = STATE(1606),
    [sym_case_generate_construct] = STATE(1606),
    [sym_continuous_assign] = STATE(1606),
    [sym_initial_construct] = STATE(1606),
    [sym_always_construct] = STATE(1606),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1606),
    [sym__assertion_item] = STATE(1606),
    [sym_deferred_immediate_assertion_item] = STATE(1606),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1606),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7629),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1592] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7631),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1593] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_list_of_port_connections] = STATE(18305),
    [sym_ordered_port_connection] = STATE(15407),
    [sym_named_port_connection] = STATE(15660),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9566),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2188),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2188),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_RPAREN] = ACTIONS(7633),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_DOT_STAR] = ACTIONS(7635),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(7637),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1594] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1619),
    [sym__checker_or_generate_item] = STATE(1619),
    [sym_checker_or_generate_item_declaration] = STATE(1619),
    [sym__checker_generate_item] = STATE(1619),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1619),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1619),
    [sym_loop_generate_construct] = STATE(1619),
    [sym__conditional_generate_construct] = STATE(1619),
    [sym_if_generate_construct] = STATE(1619),
    [sym_case_generate_construct] = STATE(1619),
    [sym_continuous_assign] = STATE(1619),
    [sym_initial_construct] = STATE(1619),
    [sym_always_construct] = STATE(1619),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1619),
    [sym__assertion_item] = STATE(1619),
    [sym_deferred_immediate_assertion_item] = STATE(1619),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1619),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7639),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1595] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7641),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1596] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1610),
    [sym__checker_or_generate_item] = STATE(1610),
    [sym_checker_or_generate_item_declaration] = STATE(1610),
    [sym__checker_generate_item] = STATE(1610),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1610),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1610),
    [sym_loop_generate_construct] = STATE(1610),
    [sym__conditional_generate_construct] = STATE(1610),
    [sym_if_generate_construct] = STATE(1610),
    [sym_case_generate_construct] = STATE(1610),
    [sym_continuous_assign] = STATE(1610),
    [sym_initial_construct] = STATE(1610),
    [sym_always_construct] = STATE(1610),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1610),
    [sym__assertion_item] = STATE(1610),
    [sym_deferred_immediate_assertion_item] = STATE(1610),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1610),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7641),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1597] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10812),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1598] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10835),
    [sym_cycle_delay_range] = STATE(10898),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10635),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1598),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1599] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11309),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1600] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11408),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1601] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11433),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1602] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11419),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1603] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11384),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1604] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11422),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1605] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6381),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9535),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7593),
    [anon_sym_foreach] = ACTIONS(7595),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1606] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7643),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1607] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11303),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1608] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1583),
    [sym__checker_or_generate_item] = STATE(1583),
    [sym_checker_or_generate_item_declaration] = STATE(1583),
    [sym__checker_generate_item] = STATE(1583),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1583),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1583),
    [sym_loop_generate_construct] = STATE(1583),
    [sym__conditional_generate_construct] = STATE(1583),
    [sym_if_generate_construct] = STATE(1583),
    [sym_case_generate_construct] = STATE(1583),
    [sym_continuous_assign] = STATE(1583),
    [sym_initial_construct] = STATE(1583),
    [sym_always_construct] = STATE(1583),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1583),
    [sym__assertion_item] = STATE(1583),
    [sym_deferred_immediate_assertion_item] = STATE(1583),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1583),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7645),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1609] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_covergroup_range_list] = STATE(17608),
    [sym_covergroup_value_range] = STATE(16255),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9047),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1610] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7647),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1611] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5844),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9394),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_module_path_expression] = STATE(15780),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7453),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7597),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7599),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1612] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6598),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9535),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7593),
    [anon_sym_foreach] = ACTIONS(7595),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1613] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6324),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9535),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7593),
    [anon_sym_foreach] = ACTIONS(7595),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1614] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10816),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1615] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11650),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1616] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_select_expression] = STATE(14775),
    [sym_select_condition] = STATE(12808),
    [sym__cross_set_expression] = STATE(12186),
    [sym__covergroup_expression] = STATE(12186),
    [sym_let_expression] = STATE(9317),
    [sym_operator_assignment] = STATE(20075),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(7947),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9489),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_mintypmax_expression] = STATE(20077),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(10938),
    [sym_unary_operator] = STATE(5338),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5866),
    [sym_package_scope] = STATE(12313),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13063),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(7611),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7613),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(7615),
    [anon_sym_binsof] = ACTIONS(7617),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7621),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [1617] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11581),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1618] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11582),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1619] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7649),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1620] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11653),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1621] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11586),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1622] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11587),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1623] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11589),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1624] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11590),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1625] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11593),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1626] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11594),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1627] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11597),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1628] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11598),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1629] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8957),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_module_path_expression] = STATE(16656),
    [sym_module_path_mintypmax_expression] = STATE(18152),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(8930),
    [sym_integral_number] = STATE(8930),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(8930),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5891),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7597),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7651),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1630] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9394),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_module_path_expression] = STATE(15780),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7453),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7597),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7599),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1631] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11601),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1632] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11602),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1633] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1650),
    [sym__checker_or_generate_item] = STATE(1650),
    [sym_checker_or_generate_item_declaration] = STATE(1650),
    [sym__checker_generate_item] = STATE(1650),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1650),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1650),
    [sym_loop_generate_construct] = STATE(1650),
    [sym__conditional_generate_construct] = STATE(1650),
    [sym_if_generate_construct] = STATE(1650),
    [sym_case_generate_construct] = STATE(1650),
    [sym_continuous_assign] = STATE(1650),
    [sym_initial_construct] = STATE(1650),
    [sym_always_construct] = STATE(1650),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1650),
    [sym__assertion_item] = STATE(1650),
    [sym_deferred_immediate_assertion_item] = STATE(1650),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1650),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7655),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1634] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11606),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1635] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11607),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1636] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7657),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1637] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10797),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1638] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_covergroup_range_list] = STATE(17811),
    [sym_covergroup_value_range] = STATE(16255),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9047),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1639] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1641),
    [sym__checker_or_generate_item] = STATE(1641),
    [sym_checker_or_generate_item_declaration] = STATE(1641),
    [sym__checker_generate_item] = STATE(1641),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1641),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1641),
    [sym_loop_generate_construct] = STATE(1641),
    [sym__conditional_generate_construct] = STATE(1641),
    [sym_if_generate_construct] = STATE(1641),
    [sym_case_generate_construct] = STATE(1641),
    [sym_continuous_assign] = STATE(1641),
    [sym_initial_construct] = STATE(1641),
    [sym_always_construct] = STATE(1641),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1641),
    [sym__assertion_item] = STATE(1641),
    [sym_deferred_immediate_assertion_item] = STATE(1641),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1641),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7659),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1640] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_covergroup_range_list] = STATE(19831),
    [sym_covergroup_value_range] = STATE(16255),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9047),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1641] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7661),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1642] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11357),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1643] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1658),
    [sym__checker_or_generate_item] = STATE(1658),
    [sym_checker_or_generate_item_declaration] = STATE(1658),
    [sym__checker_generate_item] = STATE(1658),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1658),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1658),
    [sym_loop_generate_construct] = STATE(1658),
    [sym__conditional_generate_construct] = STATE(1658),
    [sym_if_generate_construct] = STATE(1658),
    [sym_case_generate_construct] = STATE(1658),
    [sym_continuous_assign] = STATE(1658),
    [sym_initial_construct] = STATE(1658),
    [sym_always_construct] = STATE(1658),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1658),
    [sym__assertion_item] = STATE(1658),
    [sym_deferred_immediate_assertion_item] = STATE(1658),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1658),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7663),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1644] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7665),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1645] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11510),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1646] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11511),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1647] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11639),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1648] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6385),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9535),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7593),
    [anon_sym_foreach] = ACTIONS(7595),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1649] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1592),
    [sym__checker_or_generate_item] = STATE(1592),
    [sym_checker_or_generate_item_declaration] = STATE(1592),
    [sym__checker_generate_item] = STATE(1592),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1592),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1592),
    [sym_loop_generate_construct] = STATE(1592),
    [sym__conditional_generate_construct] = STATE(1592),
    [sym_if_generate_construct] = STATE(1592),
    [sym_case_generate_construct] = STATE(1592),
    [sym_continuous_assign] = STATE(1592),
    [sym_initial_construct] = STATE(1592),
    [sym_always_construct] = STATE(1592),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1592),
    [sym__assertion_item] = STATE(1592),
    [sym_deferred_immediate_assertion_item] = STATE(1592),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1592),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7665),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1650] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7667),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1651] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_constraint_expression] = STATE(6380),
    [sym_uniqueness_constraint] = STATE(19467),
    [sym_constraint_set] = STATE(6597),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19467),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7591),
    [anon_sym_disable] = ACTIONS(7043),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_soft] = ACTIONS(7045),
    [anon_sym_if] = ACTIONS(7047),
    [anon_sym_foreach] = ACTIONS(7049),
    [anon_sym_unique] = ACTIONS(7051),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1652] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11409),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1653] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(10808),
    [sym_cycle_delay_range] = STATE(10799),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(10682),
    [sym_expression_or_dist] = STATE(10621),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1614),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7113),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5737),
    [sym_package_scope] = STATE(12396),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13652),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(7577),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(3397),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(3884),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [1654] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1578),
    [sym__checker_or_generate_item] = STATE(1578),
    [sym_checker_or_generate_item_declaration] = STATE(1578),
    [sym__checker_generate_item] = STATE(1578),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1578),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1578),
    [sym_loop_generate_construct] = STATE(1578),
    [sym__conditional_generate_construct] = STATE(1578),
    [sym_if_generate_construct] = STATE(1578),
    [sym_case_generate_construct] = STATE(1578),
    [sym_continuous_assign] = STATE(1578),
    [sym_initial_construct] = STATE(1578),
    [sym_always_construct] = STATE(1578),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1578),
    [sym__assertion_item] = STATE(1578),
    [sym_deferred_immediate_assertion_item] = STATE(1578),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1578),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7661),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1655] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1644),
    [sym__checker_or_generate_item] = STATE(1644),
    [sym_checker_or_generate_item_declaration] = STATE(1644),
    [sym__checker_generate_item] = STATE(1644),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1644),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1644),
    [sym_loop_generate_construct] = STATE(1644),
    [sym__conditional_generate_construct] = STATE(1644),
    [sym_if_generate_construct] = STATE(1644),
    [sym_case_generate_construct] = STATE(1644),
    [sym_continuous_assign] = STATE(1644),
    [sym_initial_construct] = STATE(1644),
    [sym_always_construct] = STATE(1644),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1644),
    [sym__assertion_item] = STATE(1644),
    [sym_deferred_immediate_assertion_item] = STATE(1644),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1644),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7669),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1656] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7671),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1657] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11354),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1658] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(1553),
    [sym__checker_or_generate_item] = STATE(1553),
    [sym_checker_or_generate_item_declaration] = STATE(1553),
    [sym__checker_generate_item] = STATE(1553),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(1553),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(1553),
    [sym_loop_generate_construct] = STATE(1553),
    [sym__conditional_generate_construct] = STATE(1553),
    [sym_if_generate_construct] = STATE(1553),
    [sym_case_generate_construct] = STATE(1553),
    [sym_continuous_assign] = STATE(1553),
    [sym_initial_construct] = STATE(1553),
    [sym_always_construct] = STATE(1553),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(1553),
    [sym__assertion_item] = STATE(1553),
    [sym_deferred_immediate_assertion_item] = STATE(1553),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(1985),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(1985),
    [aux_sym_checker_declaration_repeat1] = STATE(1553),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_endchecker] = ACTIONS(7673),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1659] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11362),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1660] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11541),
    [sym_cycle_delay_range] = STATE(11331),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10936),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1657),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1661] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_expr] = STATE(11389),
    [sym_cycle_delay_range] = STATE(11615),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(11047),
    [sym_expression_or_dist] = STATE(10959),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(1652),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5842),
    [sym_package_scope] = STATE(12163),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13949),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(6973),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_first_match] = ACTIONS(3395),
    [anon_sym_POUND_POUND] = ACTIONS(6975),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(3399),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(3399),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(3401),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(6977),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1662] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(18197),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9955),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1663] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(19787),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1664] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7685),
    [anon_sym_DQUOTE] = ACTIONS(7688),
    [anon_sym_LPAREN] = ACTIONS(7691),
    [anon_sym_BQUOTE] = ACTIONS(7694),
    [anon_sym_type] = ACTIONS(7697),
    [anon_sym_LBRACE] = ACTIONS(7700),
    [anon_sym_default] = ACTIONS(7703),
    [anon_sym_const] = ACTIONS(7706),
    [anon_sym_local] = ACTIONS(7709),
    [anon_sym_super] = ACTIONS(7712),
    [anon_sym_LBRACK] = ACTIONS(7715),
    [anon_sym_string] = ACTIONS(7706),
    [anon_sym_byte] = ACTIONS(7718),
    [anon_sym_shortint] = ACTIONS(7718),
    [anon_sym_int] = ACTIONS(7718),
    [anon_sym_longint] = ACTIONS(7718),
    [anon_sym_integer] = ACTIONS(7718),
    [anon_sym_time] = ACTIONS(7718),
    [anon_sym_bit] = ACTIONS(7721),
    [anon_sym_logic] = ACTIONS(7721),
    [anon_sym_reg] = ACTIONS(7721),
    [anon_sym_shortreal] = ACTIONS(7724),
    [anon_sym_real] = ACTIONS(7724),
    [anon_sym_realtime] = ACTIONS(7724),
    [anon_sym_signed] = ACTIONS(7706),
    [anon_sym_unsigned] = ACTIONS(7706),
    [anon_sym_tagged] = ACTIONS(7727),
    [anon_sym_DOLLAR] = ACTIONS(7730),
    [anon_sym_PLUS] = ACTIONS(7733),
    [anon_sym_PLUS_PLUS] = ACTIONS(7736),
    [anon_sym_endcase] = ACTIONS(7739),
    [anon_sym_BANG] = ACTIONS(7741),
    [anon_sym_DASH] = ACTIONS(7733),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7744),
    [anon_sym_TILDE] = ACTIONS(7733),
    [anon_sym_std] = ACTIONS(7747),
    [anon_sym_randomize] = ACTIONS(7750),
    [anon_sym_null] = ACTIONS(7753),
    [anon_sym_AMP] = ACTIONS(7741),
    [anon_sym_PIPE] = ACTIONS(7741),
    [anon_sym_CARET] = ACTIONS(7733),
    [anon_sym_CARET_TILDE] = ACTIONS(7741),
    [anon_sym_TILDE_CARET] = ACTIONS(7741),
    [anon_sym_this] = ACTIONS(7756),
    [anon_sym_TILDE_AMP] = ACTIONS(7741),
    [anon_sym_TILDE_PIPE] = ACTIONS(7741),
    [anon_sym_DASH_DASH] = ACTIONS(7736),
    [aux_sym_decimal_number_token1] = ACTIONS(7759),
    [aux_sym_decimal_number_token2] = ACTIONS(7759),
    [sym_binary_number] = ACTIONS(7762),
    [sym_octal_number] = ACTIONS(7762),
    [sym_hex_number] = ACTIONS(7762),
    [aux_sym_real_number_token1] = ACTIONS(7765),
    [sym_fixed_point_number] = ACTIONS(7768),
    [sym_unsigned_number] = ACTIONS(7771),
    [anon_sym_SQUOTE0] = ACTIONS(7774),
    [anon_sym_SQUOTE1] = ACTIONS(7774),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7774),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7777),
    [anon_sym_DOLLARroot] = ACTIONS(7780),
    [anon_sym_DOLLARunit] = ACTIONS(7783),
    [sym_system_tf_identifier] = ACTIONS(7786),
  },
  [1665] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(19787),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20261),
    [sym_indexed_range] = STATE(20261),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1666] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7793),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1667] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7795),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1668] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(19945),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9995),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1669] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8957),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_module_path_expression] = STATE(16656),
    [sym_module_path_mintypmax_expression] = STATE(18152),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(8930),
    [sym_integral_number] = STATE(8930),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(8930),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7292),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7597),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7599),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1670] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(18054),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9892),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1671] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(18642),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9842),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1672] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(18074),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9977),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1673] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7797),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1674] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_data_type] = STATE(20138),
    [sym_class_scope] = STATE(13944),
    [sym_class_type] = STATE(11768),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(11549),
    [sym_integer_vector_type] = STATE(11266),
    [sym_non_integer_type] = STATE(12849),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(9118),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7129),
    [sym_package_scope] = STATE(12329),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_string] = ACTIONS(4106),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1675] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7799),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1676] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7801),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1677] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(19787),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18773),
    [sym_indexed_range] = STATE(18773),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1678] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(19787),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9390),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1679] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7803),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1680] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7805),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1681] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(19787),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9452),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18592),
    [sym_indexed_range] = STATE(18592),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1682] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7807),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1683] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7809),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1684] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7811),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1685] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7813),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1686] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7815),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1687] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7817),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1688] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7819),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1689] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7821),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1690] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1664),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7823),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1691] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17923),
    [sym_indexed_range] = STATE(17923),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1692] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9235),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5359),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7251),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1693] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1781),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1781),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7857),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1694] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7887),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1695] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1730),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1730),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7889),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1696] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1704),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1704),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7891),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1697] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7891),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1698] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7893),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1699] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1706),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1706),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7893),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1700] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7895),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1701] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1708),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1708),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7895),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1702] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1690),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1690),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1703] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1753),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1753),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7887),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1704] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7897),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1705] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1711),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1711),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7897),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1706] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7899),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1707] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1713),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1713),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7899),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1708] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7901),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1709] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1715),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1715),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7901),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1710] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7903),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1711] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7905),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1712] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1716),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1716),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7905),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1713] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7907),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1714] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1718),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1718),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7907),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1715] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7909),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1716] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7911),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1717] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1719),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1719),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7911),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1718] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7913),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1719] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7915),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1720] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1732),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1732),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7903),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1721] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1760),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1760),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7917),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1722] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7919),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1723] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9452),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18592),
    [sym_indexed_range] = STATE(18592),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1724] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7917),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1725] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1736),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1736),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7919),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1726] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7921),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1727] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1750),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1750),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7921),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1728] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7923),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1729] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1762),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1762),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7925),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1730] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7927),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1731] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1765),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1765),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7927),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1732] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7929),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1733] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9385),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17551),
    [sym_indexed_range] = STATE(17551),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1734] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7931),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1735] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1754),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1754),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7929),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1736] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7933),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1737] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1756),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1756),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7933),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1738] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1810),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1810),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7931),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1739] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1822),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1822),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7935),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1740] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9390),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1741] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7935),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1742] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9450),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1743] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20261),
    [sym_indexed_range] = STATE(20261),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1744] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18773),
    [sym_indexed_range] = STATE(18773),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1745] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19555),
    [sym_indexed_range] = STATE(19555),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1746] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17751),
    [sym_indexed_range] = STATE(17751),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1747] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9389),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1748] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7937),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1749] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1828),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1828),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7937),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1750] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7939),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1751] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1864),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1864),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7923),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1752] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1734),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1734),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7941),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1753] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7941),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1754] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7943),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1755] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1758),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1758),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7943),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1756] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7945),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1757] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1758] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7947),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1759] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9900),
    [sym__constant_part_select_range] = STATE(20296),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(20296),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18773),
    [sym_indexed_range] = STATE(18773),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7658),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1760] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7949),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1761] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1782),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1782),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7951),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1762] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7953),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1763] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1787),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1787),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7953),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1764] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1788),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1788),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7955),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1765] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7955),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1766] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1767] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1741),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1741),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7949),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1768] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1770),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1770),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7957),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1769] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7959),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1770] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7961),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1771] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1675),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1675),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1772] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1684),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1684),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1773] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1779),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1779),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7959),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1774] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1833),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1833),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7961),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1775] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1776] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9488),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17620),
    [sym_indexed_range] = STATE(17620),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1777] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9387),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1778] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1849),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1849),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7963),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1779] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7963),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1780] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1795),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1795),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7965),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1781] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7965),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1782] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7967),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1783] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1811),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1811),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7969),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1784] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1815),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1815),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7967),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1785] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9900),
    [sym__constant_part_select_range] = STATE(20296),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(20296),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17689),
    [sym_indexed_range] = STATE(17689),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7658),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1786] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1816),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1816),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7971),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1787] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7971),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1788] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7973),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1789] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1921),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1921),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7975),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1790] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7975),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1791] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1819),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1819),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7973),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1792] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7977),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1793] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1926),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1926),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7977),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1794] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1686),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1686),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1795] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7979),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1796] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1857),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1857),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7979),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1797] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1676),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1676),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1798] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1683),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1683),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1799] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1748),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1748),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7981),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1800] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18773),
    [sym_indexed_range] = STATE(18773),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1801] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9549),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17815),
    [sym_indexed_range] = STATE(17815),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1802] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7983),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1803] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7985),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1804] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1969),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1969),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7983),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1805] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1954),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1954),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7987),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1806] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1971),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1971),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7985),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1807] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1976),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1976),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7989),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1808] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7989),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1809] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1834),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1834),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7991),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1810] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7987),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1811] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7993),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1812] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1839),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1839),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7993),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1813] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1836),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1836),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7995),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1814] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7997),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1815] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7995),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1816] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7999),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1817] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1844),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1844),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7999),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1818] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1845),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1845),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8001),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1819] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8001),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1820] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1673),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1673),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1821] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1667),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1667),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1822] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8003),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1823] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8005),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1824] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9428),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20418),
    [sym_indexed_range] = STATE(20418),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1825] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17689),
    [sym_indexed_range] = STATE(17689),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1826] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1961),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1961),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8003),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1827] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2006),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2006),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8005),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1828] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8007),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1829] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1963),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1963),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8007),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1830] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1831] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1965),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1965),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8009),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1832] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1878),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1878),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8011),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1833] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8009),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1834] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8013),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1835] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1885),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1885),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8013),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1836] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8015),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1837] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1887),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1887),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8017),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1838] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1802),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1802),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8019),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1839] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8017),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1840] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8021),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1841] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1808),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1808),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8021),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1842] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1868),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1868),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8015),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1843] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1871),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1871),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8023),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1844] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8023),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1845] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8025),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1846] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1874),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1874),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8025),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1847] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1689),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1848] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1666),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1666),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1849] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8027),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1850] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1979),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1979),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8027),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1851] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9408),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1852] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9557),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17751),
    [sym_indexed_range] = STATE(17751),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1853] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1980),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1980),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8029),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1854] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1957),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1957),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7997),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1855] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8031),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1856] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1790),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1790),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8031),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1857] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8029),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1858] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1792),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1792),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8033),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1859] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8033),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1860] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1682),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1682),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1861] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1688),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1688),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1862] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17689),
    [sym_indexed_range] = STATE(17689),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1863] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5846),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9050),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(16412),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7454),
    [sym_package_scope] = STATE(12472),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13372),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_RBRACE] = ACTIONS(8037),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(8041),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1864] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7981),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1865] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1895),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1895),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8043),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1866] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(8045),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(8048),
    [aux_sym_text_macro_definition_token1] = ACTIONS(8051),
    [anon_sym_BQUOTE] = ACTIONS(8054),
    [aux_sym_id_directive_token1] = ACTIONS(8057),
    [aux_sym_id_directive_token2] = ACTIONS(8057),
    [aux_sym_id_directive_token3] = ACTIONS(8057),
    [aux_sym_id_directive_token4] = ACTIONS(8060),
    [aux_sym_zero_directive_token1] = ACTIONS(8063),
    [aux_sym_zero_directive_token2] = ACTIONS(8063),
    [aux_sym_zero_directive_token3] = ACTIONS(8063),
    [aux_sym_zero_directive_token4] = ACTIONS(8063),
    [aux_sym_zero_directive_token5] = ACTIONS(8063),
    [aux_sym_zero_directive_token6] = ACTIONS(8063),
    [aux_sym_zero_directive_token7] = ACTIONS(8063),
    [aux_sym_zero_directive_token8] = ACTIONS(8063),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(8066),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(8069),
    [aux_sym_unconnected_drive_token1] = ACTIONS(8072),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(8075),
    [aux_sym_begin_keywords_token1] = ACTIONS(8078),
    [anon_sym_SEMI] = ACTIONS(8081),
    [anon_sym_extern] = ACTIONS(8084),
    [anon_sym_virtual] = ACTIONS(8087),
    [anon_sym_class] = ACTIONS(8090),
    [anon_sym_endclass] = ACTIONS(8093),
    [anon_sym_pure] = ACTIONS(8095),
    [anon_sym_type] = ACTIONS(8098),
    [anon_sym_rand] = ACTIONS(8101),
    [anon_sym_const] = ACTIONS(8104),
    [anon_sym_function] = ACTIONS(8107),
    [anon_sym_static] = ACTIONS(8110),
    [anon_sym_protected] = ACTIONS(8113),
    [anon_sym_local] = ACTIONS(8113),
    [anon_sym_randc] = ACTIONS(8101),
    [anon_sym_constraint] = ACTIONS(8116),
    [anon_sym_LBRACK] = ACTIONS(8119),
    [anon_sym_localparam] = ACTIONS(8122),
    [anon_sym_parameter] = ACTIONS(8125),
    [anon_sym_var] = ACTIONS(8128),
    [anon_sym_import] = ACTIONS(8131),
    [anon_sym_typedef] = ACTIONS(8134),
    [anon_sym_enum] = ACTIONS(8137),
    [anon_sym_struct] = ACTIONS(8140),
    [anon_sym_union] = ACTIONS(8143),
    [anon_sym_nettype] = ACTIONS(8146),
    [anon_sym_automatic] = ACTIONS(8149),
    [anon_sym_string] = ACTIONS(8152),
    [anon_sym_chandle] = ACTIONS(8152),
    [anon_sym_event] = ACTIONS(8152),
    [anon_sym_byte] = ACTIONS(8155),
    [anon_sym_shortint] = ACTIONS(8155),
    [anon_sym_int] = ACTIONS(8155),
    [anon_sym_longint] = ACTIONS(8155),
    [anon_sym_integer] = ACTIONS(8155),
    [anon_sym_time] = ACTIONS(8155),
    [anon_sym_bit] = ACTIONS(8158),
    [anon_sym_logic] = ACTIONS(8158),
    [anon_sym_reg] = ACTIONS(8158),
    [anon_sym_shortreal] = ACTIONS(8161),
    [anon_sym_real] = ACTIONS(8161),
    [anon_sym_realtime] = ACTIONS(8161),
    [anon_sym_signed] = ACTIONS(8164),
    [anon_sym_unsigned] = ACTIONS(8164),
    [anon_sym_task] = ACTIONS(8167),
    [anon_sym_covergroup] = ACTIONS(8170),
    [anon_sym_LPAREN_STAR] = ACTIONS(8173),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8176),
    [anon_sym_DOLLARunit] = ACTIONS(8179),
  },
  [1867] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1823),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1823),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8182),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1868] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8043),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1869] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1679),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1679),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1870] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1680),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1680),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1871] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8184),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1872] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1900),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1900),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8184),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1873] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9385),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17551),
    [sym_indexed_range] = STATE(17551),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1874] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8186),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1875] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1905),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1905),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8186),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1876] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8188),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1877] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1803),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1803),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8188),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1878] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8190),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1879] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8182),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1880] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1685),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1685),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1881] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_inside_item] = STATE(1687),
    [sym_open_range_list] = STATE(19448),
    [sym_open_value_range] = STATE(16506),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat3] = STATE(1687),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(7789),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1882] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9450),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1883] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1898),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1898),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8190),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1884] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1899),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1899),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8192),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1885] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8192),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1886] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17751),
    [sym_indexed_range] = STATE(17751),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1887] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8194),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1888] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1903),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1903),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8194),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1889] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17863),
    [sym_indexed_range] = STATE(17863),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1890] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8196),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1891] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_trans_set] = STATE(19373),
    [sym_trans_range_list] = STATE(16339),
    [sym_trans_item] = STATE(13915),
    [sym_covergroup_range_list] = STATE(13916),
    [sym_covergroup_value_range] = STATE(12333),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8900),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1892] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9480),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1893] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17923),
    [sym_indexed_range] = STATE(17923),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1894] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9387),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1895] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8198),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1896] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1907),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1907),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8198),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1897] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1909),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1909),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8200),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1898] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8200),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1899] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8202),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1900] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8204),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1901] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1912),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1912),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8202),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1902] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1913),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1913),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8206),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1903] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8206),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1904] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1917),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1917),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8204),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1905] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8208),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1906] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1919),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1919),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8208),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1907] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8210),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1908] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8212),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1909] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8214),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1910] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1925),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1925),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8214),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1911] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1928),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1928),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8216),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1912] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8216),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1913] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8218),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1914] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1930),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1930),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8218),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1915] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1890),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1890),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8212),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1916] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1920),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1920),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8210),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1917] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8220),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1918] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1933),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1933),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8220),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1919] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8222),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1920] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8224),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1921] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8226),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1922] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1934),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1934),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8224),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1923] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1814),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1814),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8226),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1924] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1938),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1938),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8228),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1925] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8228),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1926] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8230),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1927] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1908),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1908),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8230),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1928] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8232),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1929] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1940),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1940),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8232),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1930] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8234),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1931] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1942),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1942),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8234),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1932] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8236),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1933] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8238),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1934] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8240),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1935] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1958),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1958),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8242),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1936] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2010),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2010),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8244),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1937] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2005),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2005),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8246),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1938] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8248),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1939] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1944),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1944),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8248),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1940] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8250),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1941] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1946),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1946),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8250),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1942] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8252),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1943] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1948),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1948),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8252),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1944] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8254),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1945] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1949),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1949),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8254),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1946] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8256),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1947] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1951),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1951),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8256),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1948] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8258),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1949] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8260),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1950] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1952),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1952),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8260),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1951] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8262),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1952] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8264),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1953] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1769),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1769),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8266),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1954] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8268),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1955] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1988),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1988),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8270),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1956] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1970),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1970),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8272),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1957] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8274),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1958] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8276),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1959] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1975),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1975),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8276),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1960] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1997),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1997),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8268),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1961] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8278),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1962] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1999),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1999),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8278),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1963] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8280),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1964] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_delay_or_event_control] = STATE(4180),
    [sym_delay_control] = STATE(7394),
    [sym_event_control] = STATE(7394),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9840),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_POUND] = ACTIONS(8282),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_repeat] = ACTIONS(8284),
    [anon_sym_AT] = ACTIONS(8286),
    [anon_sym_AT_STAR] = ACTIONS(8288),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1965] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8290),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1966] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20261),
    [sym_indexed_range] = STATE(20261),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1967] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1990),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1990),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8292),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1968] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1855),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1855),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8294),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1969] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8294),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1970] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8296),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1971] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8298),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1972] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1994),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1994),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8296),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1973] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1995),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1995),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8300),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1974] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1987),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1987),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8298),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1975] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8300),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1976] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8302),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1977] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2026),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2026),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8290),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1978] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2027),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2027),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8304),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1979] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8304),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1980] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8306),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1981] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10354),
    [sym__constant_part_select_range] = STATE(18289),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(18289),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19555),
    [sym_indexed_range] = STATE(19555),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7617),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [1982] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2029),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2029),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8306),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1983] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2003),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2003),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8280),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1984] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2020),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2020),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8308),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1985] = {
    [sym_checker_declaration] = STATE(6632),
    [sym_elaboration_system_task] = STATE(6625),
    [sym__checker_or_generate_item] = STATE(6625),
    [sym_checker_or_generate_item_declaration] = STATE(6625),
    [sym__checker_generate_item] = STATE(6625),
    [sym_data_declaration] = STATE(6632),
    [sym_package_import_declaration] = STATE(6392),
    [sym_genvar_declaration] = STATE(6632),
    [sym_type_declaration] = STATE(6392),
    [sym_net_type_declaration] = STATE(6392),
    [sym_lifetime] = STATE(8377),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12618),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17764),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6632),
    [sym_concurrent_assertion_item] = STATE(6625),
    [sym__concurrent_assertion_statement] = STATE(6394),
    [sym_assert_property_statement] = STATE(6394),
    [sym_assume_property_statement] = STATE(6394),
    [sym_cover_property_statement] = STATE(6394),
    [sym_cover_sequence_statement] = STATE(6394),
    [sym_restrict_property_statement] = STATE(6394),
    [sym__assertion_item_declaration] = STATE(6632),
    [sym_property_declaration] = STATE(6632),
    [sym_sequence_declaration] = STATE(6632),
    [sym_covergroup_declaration] = STATE(6632),
    [sym_let_declaration] = STATE(6632),
    [sym_checker_instantiation] = STATE(6394),
    [sym_generate_region] = STATE(6625),
    [sym_loop_generate_construct] = STATE(6625),
    [sym__conditional_generate_construct] = STATE(6625),
    [sym_if_generate_construct] = STATE(6625),
    [sym_case_generate_construct] = STATE(6625),
    [sym_continuous_assign] = STATE(6625),
    [sym_initial_construct] = STATE(6625),
    [sym_always_construct] = STATE(6625),
    [sym_always_keyword] = STATE(4262),
    [sym_final_construct] = STATE(6625),
    [sym__assertion_item] = STATE(6625),
    [sym_deferred_immediate_assertion_item] = STATE(6625),
    [sym__deferred_immediate_assertion_statement] = STATE(6395),
    [sym_deferred_immediate_assert_statement] = STATE(6395),
    [sym_deferred_immediate_assume_statement] = STATE(6395),
    [sym_deferred_immediate_cover_statement] = STATE(6395),
    [sym_clocking_declaration] = STATE(6632),
    [sym_attribute_instance] = STATE(5226),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10818),
    [sym_package_scope] = STATE(15051),
    [aux_sym__description_repeat1] = STATE(5226),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(7579),
    [anon_sym_checker] = ACTIONS(1098),
    [anon_sym_virtual] = ACTIONS(2131),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOLLARfatal] = ACTIONS(1104),
    [anon_sym_DOLLARerror] = ACTIONS(1106),
    [anon_sym_DOLLARwarning] = ACTIONS(1106),
    [anon_sym_DOLLARinfo] = ACTIONS(1106),
    [anon_sym_default] = ACTIONS(7583),
    [anon_sym_clocking] = ACTIONS(1110),
    [anon_sym_rand] = ACTIONS(1116),
    [anon_sym_const] = ACTIONS(1118),
    [anon_sym_function] = ACTIONS(7585),
    [anon_sym_static] = ACTIONS(91),
    [anon_sym_if] = ACTIONS(1186),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_var] = ACTIONS(1128),
    [anon_sym_import] = ACTIONS(7587),
    [anon_sym_genvar] = ACTIONS(1134),
    [anon_sym_typedef] = ACTIONS(1138),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(1140),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_assert] = ACTIONS(1188),
    [anon_sym_property] = ACTIONS(1146),
    [anon_sym_assume] = ACTIONS(1190),
    [anon_sym_cover] = ACTIONS(1192),
    [anon_sym_sequence] = ACTIONS(1152),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym_always] = ACTIONS(169),
    [anon_sym_covergroup] = ACTIONS(1158),
    [anon_sym_let] = ACTIONS(1162),
    [anon_sym_generate] = ACTIONS(1168),
    [anon_sym_for] = ACTIONS(1194),
    [anon_sym_initial] = ACTIONS(1196),
    [anon_sym_assign] = ACTIONS(1174),
    [anon_sym_always_comb] = ACTIONS(169),
    [anon_sym_always_latch] = ACTIONS(169),
    [anon_sym_always_ff] = ACTIONS(169),
    [anon_sym_final] = ACTIONS(1198),
    [anon_sym_global] = ACTIONS(1180),
    [anon_sym_LPAREN_STAR] = ACTIONS(7589),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1986] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(16412),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7454),
    [sym_package_scope] = STATE(12472),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13372),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(8041),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [1987] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8310),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1988] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8312),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1989] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1840),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1840),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8314),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1990] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8316),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1991] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2023),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2023),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8312),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1992] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2013),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2013),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8316),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1993] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2014),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2014),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8318),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1994] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8318),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1995] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8320),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1996] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2019),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2019),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8320),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1997] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8322),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1998] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2007),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2007),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8322),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [1999] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8324),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2000] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2011),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2011),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8324),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2001] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1859),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1859),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8302),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2002] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1932),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1932),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8274),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2003] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8326),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2004] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1876),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1876),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8328),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2005] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(7857),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2006] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8328),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2007] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8330),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2008] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2024),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2024),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8330),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2009] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(9849),
    [sym__constant_part_select_range] = STATE(17749),
    [sym_constant_range] = STATE(20098),
    [sym_constant_indexed_range] = STATE(17749),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9698),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5342),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7381),
    [sym_package_scope] = STATE(12336),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_constant_select1_repeat1] = STATE(7526),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(7675),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(7679),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2010] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8332),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2011] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8334),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2012] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2030),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2030),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8336),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2013] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8336),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2014] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8338),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2015] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2033),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2033),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8338),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2016] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(2034),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(2034),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8340),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2017] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1694),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1694),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8342),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2018] = {
    [sym_port_direction] = STATE(10696),
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_tf_item_declaration] = STATE(2018),
    [sym_tf_port_direction] = STATE(8444),
    [sym_tf_port_declaration] = STATE(5504),
    [sym_block_item_declaration] = STATE(5504),
    [sym_overload_declaration] = STATE(5428),
    [sym_let_declaration] = STATE(5428),
    [sym_attribute_instance] = STATE(5807),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5807),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [aux_sym_function_body_declaration_repeat1] = STATE(2018),
    [sym_simple_identifier] = ACTIONS(8344),
    [anon_sym_SEMI] = ACTIONS(8347),
    [anon_sym_virtual] = ACTIONS(8349),
    [anon_sym_POUND] = ACTIONS(8352),
    [anon_sym_type] = ACTIONS(8354),
    [anon_sym_LBRACE] = ACTIONS(8347),
    [anon_sym_input] = ACTIONS(8357),
    [anon_sym_output] = ACTIONS(8357),
    [anon_sym_inout] = ACTIONS(8357),
    [anon_sym_ref] = ACTIONS(8357),
    [anon_sym_disable] = ACTIONS(8352),
    [anon_sym_bind] = ACTIONS(8360),
    [anon_sym_const] = ACTIONS(8363),
    [anon_sym_static] = ACTIONS(8366),
    [anon_sym_local] = ACTIONS(8352),
    [anon_sym_super] = ACTIONS(8352),
    [anon_sym_endfunction] = ACTIONS(8352),
    [anon_sym_if] = ACTIONS(8352),
    [anon_sym_foreach] = ACTIONS(8352),
    [anon_sym_LBRACK] = ACTIONS(8369),
    [anon_sym_unique] = ACTIONS(8352),
    [anon_sym_localparam] = ACTIONS(8372),
    [anon_sym_parameter] = ACTIONS(8375),
    [anon_sym_var] = ACTIONS(8378),
    [anon_sym_import] = ACTIONS(8381),
    [anon_sym_typedef] = ACTIONS(8384),
    [anon_sym_enum] = ACTIONS(8387),
    [anon_sym_struct] = ACTIONS(8390),
    [anon_sym_union] = ACTIONS(8393),
    [anon_sym_nettype] = ACTIONS(8396),
    [anon_sym_automatic] = ACTIONS(8366),
    [anon_sym_string] = ACTIONS(8399),
    [anon_sym_chandle] = ACTIONS(8399),
    [anon_sym_event] = ACTIONS(8399),
    [anon_sym_byte] = ACTIONS(8402),
    [anon_sym_shortint] = ACTIONS(8402),
    [anon_sym_int] = ACTIONS(8402),
    [anon_sym_longint] = ACTIONS(8402),
    [anon_sym_integer] = ACTIONS(8402),
    [anon_sym_time] = ACTIONS(8402),
    [anon_sym_bit] = ACTIONS(8405),
    [anon_sym_logic] = ACTIONS(8405),
    [anon_sym_reg] = ACTIONS(8405),
    [anon_sym_shortreal] = ACTIONS(8408),
    [anon_sym_real] = ACTIONS(8408),
    [anon_sym_realtime] = ACTIONS(8408),
    [anon_sym_signed] = ACTIONS(8411),
    [anon_sym_unsigned] = ACTIONS(8411),
    [anon_sym_endtask] = ACTIONS(8352),
    [anon_sym_PLUS_PLUS] = ACTIONS(8347),
    [anon_sym_assert] = ACTIONS(8352),
    [anon_sym_assume] = ACTIONS(8352),
    [anon_sym_cover] = ACTIONS(8352),
    [anon_sym_expect] = ACTIONS(8352),
    [anon_sym_restrict] = ACTIONS(8352),
    [anon_sym_case] = ACTIONS(8352),
    [anon_sym_POUND_POUND] = ACTIONS(8347),
    [anon_sym_begin] = ACTIONS(8352),
    [anon_sym_let] = ACTIONS(8414),
    [anon_sym_for] = ACTIONS(8352),
    [anon_sym_assign] = ACTIONS(8352),
    [anon_sym_deassign] = ACTIONS(8352),
    [anon_sym_force] = ACTIONS(8352),
    [anon_sym_release] = ACTIONS(8352),
    [anon_sym_fork] = ACTIONS(8352),
    [anon_sym_repeat] = ACTIONS(8352),
    [anon_sym_AT] = ACTIONS(8352),
    [anon_sym_AT_STAR] = ACTIONS(8347),
    [anon_sym_return] = ACTIONS(8352),
    [anon_sym_break] = ACTIONS(8352),
    [anon_sym_continue] = ACTIONS(8352),
    [anon_sym_wait] = ACTIONS(8352),
    [anon_sym_wait_order] = ACTIONS(8352),
    [anon_sym_DASH_GT] = ACTIONS(8352),
    [anon_sym_DASH_GT_GT] = ACTIONS(8347),
    [anon_sym_unique0] = ACTIONS(8352),
    [anon_sym_priority] = ACTIONS(8352),
    [anon_sym_casez] = ACTIONS(8352),
    [anon_sym_casex] = ACTIONS(8352),
    [anon_sym_randcase] = ACTIONS(8352),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8347),
    [anon_sym_forever] = ACTIONS(8352),
    [anon_sym_while] = ACTIONS(8352),
    [anon_sym_do] = ACTIONS(8352),
    [anon_sym_this] = ACTIONS(8352),
    [anon_sym_DASH_DASH] = ACTIONS(8347),
    [anon_sym_LPAREN_STAR] = ACTIONS(8417),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8420),
    [anon_sym_DOLLARroot] = ACTIONS(8352),
    [anon_sym_DOLLARunit] = ACTIONS(8423),
    [sym_system_tf_identifier] = ACTIONS(8352),
  },
  [2019] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8340),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2020] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8426),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2021] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1724),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1724),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8426),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2022] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1728),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1728),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8428),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2023] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8428),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2024] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8430),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2025] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1710),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1710),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8432),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2026] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8432),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2027] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8434),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2028] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1722),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1722),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8434),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2029] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8436),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2030] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8438),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2031] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1697),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1697),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8438),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2032] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1698),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1698),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8440),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2033] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8440),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2034] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1866),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1866),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8442),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2035] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1700),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1700),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8442),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2036] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1726),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1726),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8436),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2037] = {
    [sym_include_compiler_directive] = STATE(6024),
    [sym_text_macro_definition] = STATE(6024),
    [sym_text_macro_usage] = STATE(6024),
    [sym_id_directive] = STATE(6024),
    [sym_zero_directive] = STATE(6024),
    [sym_timescale_compiler_directive] = STATE(6024),
    [sym_default_nettype_compiler_directive] = STATE(6024),
    [sym_unconnected_drive] = STATE(6024),
    [sym_line_compiler_directive] = STATE(6024),
    [sym_begin_keywords] = STATE(6024),
    [sym__directives] = STATE(6024),
    [sym_class_declaration] = STATE(6024),
    [sym_class_item] = STATE(1879),
    [sym_class_property] = STATE(6024),
    [sym_class_method] = STATE(6024),
    [sym__class_constraint] = STATE(6024),
    [sym_class_item_qualifier] = STATE(8808),
    [sym__property_qualifier] = STATE(6643),
    [sym_random_qualifier] = STATE(6643),
    [sym_method_qualifier] = STATE(11298),
    [sym_class_constructor_declaration] = STATE(6025),
    [sym_constraint_declaration] = STATE(6024),
    [sym_constraint_prototype] = STATE(6024),
    [sym_constraint_prototype_qualifier] = STATE(17053),
    [sym_local_parameter_declaration] = STATE(18593),
    [sym_parameter_declaration] = STATE(18593),
    [sym__any_parameter_declaration] = STATE(18593),
    [sym_data_declaration] = STATE(6026),
    [sym_package_import_declaration] = STATE(6062),
    [sym_type_declaration] = STATE(6062),
    [sym_net_type_declaration] = STATE(6062),
    [sym_lifetime] = STATE(8402),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12650),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(20009),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(6025),
    [sym_task_declaration] = STATE(6025),
    [sym_covergroup_declaration] = STATE(6024),
    [sym_attribute_instance] = STATE(5650),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5650),
    [aux_sym_class_declaration_repeat2] = STATE(1879),
    [aux_sym_class_property_repeat1] = STATE(6643),
    [aux_sym_class_method_repeat1] = STATE(11298),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(7827),
    [aux_sym_text_macro_definition_token1] = ACTIONS(7829),
    [anon_sym_BQUOTE] = ACTIONS(7831),
    [aux_sym_id_directive_token1] = ACTIONS(7833),
    [aux_sym_id_directive_token2] = ACTIONS(7833),
    [aux_sym_id_directive_token3] = ACTIONS(7833),
    [aux_sym_id_directive_token4] = ACTIONS(7835),
    [aux_sym_zero_directive_token1] = ACTIONS(7837),
    [aux_sym_zero_directive_token2] = ACTIONS(7837),
    [aux_sym_zero_directive_token3] = ACTIONS(7837),
    [aux_sym_zero_directive_token4] = ACTIONS(7837),
    [aux_sym_zero_directive_token5] = ACTIONS(7837),
    [aux_sym_zero_directive_token6] = ACTIONS(7837),
    [aux_sym_zero_directive_token7] = ACTIONS(7837),
    [aux_sym_zero_directive_token8] = ACTIONS(7837),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(7839),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(7841),
    [aux_sym_unconnected_drive_token1] = ACTIONS(7843),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(7845),
    [aux_sym_begin_keywords_token1] = ACTIONS(7847),
    [anon_sym_SEMI] = ACTIONS(7849),
    [anon_sym_extern] = ACTIONS(7851),
    [anon_sym_virtual] = ACTIONS(7853),
    [anon_sym_class] = ACTIONS(7855),
    [anon_sym_endclass] = ACTIONS(8332),
    [anon_sym_pure] = ACTIONS(7859),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_rand] = ACTIONS(7861),
    [anon_sym_const] = ACTIONS(7863),
    [anon_sym_function] = ACTIONS(7865),
    [anon_sym_static] = ACTIONS(7867),
    [anon_sym_protected] = ACTIONS(7869),
    [anon_sym_local] = ACTIONS(7869),
    [anon_sym_randc] = ACTIONS(7861),
    [anon_sym_constraint] = ACTIONS(7871),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(7873),
    [anon_sym_import] = ACTIONS(7875),
    [anon_sym_typedef] = ACTIONS(7877),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(7879),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(7881),
    [anon_sym_covergroup] = ACTIONS(7883),
    [anon_sym_LPAREN_STAR] = ACTIONS(7885),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [2038] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19776),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8444),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2039] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8874),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2040] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7148),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2041] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8918),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2042] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8831),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2043] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(8921),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2614),
    [anon_sym_join_any] = ACTIONS(2614),
    [anon_sym_join_none] = ACTIONS(2614),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2044] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19776),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8448),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2045] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(20255),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9563),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8450),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2046] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2137),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2137),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8454),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8456),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2047] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2183),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2183),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8458),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8460),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2048] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19776),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8462),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2049] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6690),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2050] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(994),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2051] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(18588),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8450),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2052] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2196),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2196),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8464),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8466),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2053] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7135),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2054] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6156),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2055] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(16380),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9512),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(8468),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2056] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2189),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2189),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8470),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8472),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2057] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6671),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2058] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2172),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2172),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8474),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8476),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2059] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2150),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2150),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8478),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8480),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2060] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6168),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2061] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18151),
    [sym_assignment_pattern_key] = STATE(18151),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10534),
    [sym_expression] = STATE(9537),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(16417),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7428),
    [sym_package_scope] = STATE(12398),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13372),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(8041),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2062] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19552),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8486),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2063] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4357),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2064] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15930),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9512),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_STAR] = ACTIONS(8488),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2065] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4368),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2066] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2149),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2149),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8490),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8492),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2067] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2197),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2197),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8494),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8496),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2068] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(17809),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9391),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8462),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2069] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19776),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8498),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2070] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(18588),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8500),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2071] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2118),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2118),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8502),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8504),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2072] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2119),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2119),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8506),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8508),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2073] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19552),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8448),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2074] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2175),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2175),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8510),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8512),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2075] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6675),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2076] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6233),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2077] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2111),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2111),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8514),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8516),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2078] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7168),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2079] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6885),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2080] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2178),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2178),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8518),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8520),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2081] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(17800),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9423),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16282),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8522),
    [anon_sym_COMMA] = ACTIONS(8524),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2082] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6903),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2083] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(17254),
    [sym_delayed_reference] = STATE(17256),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5756),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [sym_terminal_identifier] = STATE(7722),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8526),
    [anon_sym_COMMA] = ACTIONS(8528),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2084] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6710),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2085] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_port_reference] = STATE(16302),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7469),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2086] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6759),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2618),
    [anon_sym_join_any] = ACTIONS(2618),
    [anon_sym_join_none] = ACTIONS(2618),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2087] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(8530),
    [anon_sym_SEMI] = ACTIONS(8533),
    [anon_sym_POUND] = ACTIONS(8536),
    [anon_sym_type] = ACTIONS(8539),
    [anon_sym_LBRACE] = ACTIONS(8542),
    [anon_sym_disable] = ACTIONS(8545),
    [anon_sym_local] = ACTIONS(8548),
    [anon_sym_super] = ACTIONS(8551),
    [anon_sym_if] = ACTIONS(8554),
    [anon_sym_foreach] = ACTIONS(8557),
    [anon_sym_unique] = ACTIONS(8560),
    [anon_sym_byte] = ACTIONS(8563),
    [anon_sym_shortint] = ACTIONS(8563),
    [anon_sym_int] = ACTIONS(8563),
    [anon_sym_longint] = ACTIONS(8563),
    [anon_sym_integer] = ACTIONS(8563),
    [anon_sym_time] = ACTIONS(8563),
    [anon_sym_endtask] = ACTIONS(8566),
    [anon_sym_PLUS_PLUS] = ACTIONS(8568),
    [anon_sym_assert] = ACTIONS(8571),
    [anon_sym_assume] = ACTIONS(8574),
    [anon_sym_cover] = ACTIONS(8577),
    [anon_sym_expect] = ACTIONS(8580),
    [anon_sym_restrict] = ACTIONS(8583),
    [anon_sym_case] = ACTIONS(8586),
    [anon_sym_POUND_POUND] = ACTIONS(8589),
    [anon_sym_begin] = ACTIONS(8592),
    [anon_sym_for] = ACTIONS(8595),
    [anon_sym_assign] = ACTIONS(8598),
    [anon_sym_deassign] = ACTIONS(8601),
    [anon_sym_force] = ACTIONS(8604),
    [anon_sym_release] = ACTIONS(8607),
    [anon_sym_fork] = ACTIONS(8610),
    [anon_sym_join] = ACTIONS(8566),
    [anon_sym_join_any] = ACTIONS(8566),
    [anon_sym_join_none] = ACTIONS(8566),
    [anon_sym_repeat] = ACTIONS(8613),
    [anon_sym_AT] = ACTIONS(8616),
    [anon_sym_AT_STAR] = ACTIONS(8619),
    [anon_sym_return] = ACTIONS(8622),
    [anon_sym_break] = ACTIONS(8625),
    [anon_sym_continue] = ACTIONS(8625),
    [anon_sym_wait] = ACTIONS(8628),
    [anon_sym_wait_order] = ACTIONS(8631),
    [anon_sym_DASH_GT] = ACTIONS(8634),
    [anon_sym_DASH_GT_GT] = ACTIONS(8637),
    [anon_sym_unique0] = ACTIONS(8560),
    [anon_sym_priority] = ACTIONS(8560),
    [anon_sym_casez] = ACTIONS(8586),
    [anon_sym_casex] = ACTIONS(8586),
    [anon_sym_randcase] = ACTIONS(8640),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8643),
    [anon_sym_forever] = ACTIONS(8646),
    [anon_sym_while] = ACTIONS(8613),
    [anon_sym_do] = ACTIONS(8649),
    [anon_sym_this] = ACTIONS(8652),
    [anon_sym_DASH_DASH] = ACTIONS(8568),
    [anon_sym_LPAREN_STAR] = ACTIONS(8655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8658),
    [anon_sym_DOLLARroot] = ACTIONS(8661),
    [anon_sym_DOLLARunit] = ACTIONS(8664),
    [sym_system_tf_identifier] = ACTIONS(8667),
  },
  [2088] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_trans_range_list] = STATE(16652),
    [sym_trans_item] = STATE(13915),
    [sym_covergroup_range_list] = STATE(13916),
    [sym_covergroup_value_range] = STATE(12333),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8900),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2089] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6641),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2610),
    [anon_sym_join_any] = ACTIONS(2610),
    [anon_sym_join_none] = ACTIONS(2610),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2090] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4349),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2091] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2177),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2177),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8670),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8672),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2092] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(992),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2093] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2182),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2182),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8676),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2094] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19776),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8500),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2095] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(1013),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2096] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(20147),
    [sym_assignment_pattern_key] = STATE(20147),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10517),
    [sym_expression] = STATE(9432),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(16417),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7428),
    [sym_package_scope] = STATE(12398),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13372),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(8041),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2097] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(1017),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2634),
    [anon_sym_join_any] = ACTIONS(2634),
    [anon_sym_join_none] = ACTIONS(2634),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2098] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4378),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2099] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(16651),
    [sym_delayed_reference] = STATE(17359),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5756),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [sym_terminal_identifier] = STATE(7722),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8678),
    [anon_sym_COMMA] = ACTIONS(8680),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2100] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2145),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2145),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_matches] = ACTIONS(8682),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_inside] = ACTIONS(8684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2101] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4443),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2102] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(6134),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2622),
    [anon_sym_join_any] = ACTIONS(2622),
    [anon_sym_join_none] = ACTIONS(2622),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2103] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(7171),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2630),
    [anon_sym_join_any] = ACTIONS(2630),
    [anon_sym_join_none] = ACTIONS(2630),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2104] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(16775),
    [sym_delayed_reference] = STATE(16750),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5756),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [sym_terminal_identifier] = STATE(7722),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8686),
    [anon_sym_COMMA] = ACTIONS(8688),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2105] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4470),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2638),
    [anon_sym_join_any] = ACTIONS(2638),
    [anon_sym_join_none] = ACTIONS(2638),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2106] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4344),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2107] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(19775),
    [sym_let_expression] = STATE(7174),
    [sym_let_list_of_arguments] = STATE(19552),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8690),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8446),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2108] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_join_keyword] = STATE(4527),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_join] = ACTIONS(2626),
    [anon_sym_join_any] = ACTIONS(2626),
    [anon_sym_join_none] = ACTIONS(2626),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2109] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(18578),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2110] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9563),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8694),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2111] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8698),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2112] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5844),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(8974),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2113] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5838),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9078),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8700),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2114] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(19528),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2115] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_select_expression] = STATE(12829),
    [sym_select_condition] = STATE(12808),
    [sym__cross_set_expression] = STATE(12186),
    [sym__covergroup_expression] = STATE(12186),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9255),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7418),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(8702),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(7615),
    [anon_sym_binsof] = ACTIONS(7617),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2116] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(17758),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2117] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8704),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2118] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8706),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2119] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7813),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2120] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5840),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8708),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2121] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5837),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8700),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2122] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(8710),
    [anon_sym_DQUOTE] = ACTIONS(8713),
    [anon_sym_LPAREN] = ACTIONS(8716),
    [anon_sym_BQUOTE] = ACTIONS(8719),
    [anon_sym_type] = ACTIONS(8722),
    [anon_sym_LBRACE] = ACTIONS(8725),
    [anon_sym_default] = ACTIONS(8728),
    [anon_sym_const] = ACTIONS(8731),
    [anon_sym_local] = ACTIONS(8734),
    [anon_sym_super] = ACTIONS(8737),
    [anon_sym_string] = ACTIONS(8731),
    [anon_sym_byte] = ACTIONS(8740),
    [anon_sym_shortint] = ACTIONS(8740),
    [anon_sym_int] = ACTIONS(8740),
    [anon_sym_longint] = ACTIONS(8740),
    [anon_sym_integer] = ACTIONS(8740),
    [anon_sym_time] = ACTIONS(8740),
    [anon_sym_bit] = ACTIONS(8743),
    [anon_sym_logic] = ACTIONS(8743),
    [anon_sym_reg] = ACTIONS(8743),
    [anon_sym_shortreal] = ACTIONS(8746),
    [anon_sym_real] = ACTIONS(8746),
    [anon_sym_realtime] = ACTIONS(8746),
    [anon_sym_signed] = ACTIONS(8731),
    [anon_sym_unsigned] = ACTIONS(8731),
    [anon_sym_tagged] = ACTIONS(8749),
    [anon_sym_DOLLAR] = ACTIONS(8752),
    [anon_sym_PLUS] = ACTIONS(8755),
    [anon_sym_PLUS_PLUS] = ACTIONS(8758),
    [anon_sym_endcase] = ACTIONS(8761),
    [anon_sym_BANG] = ACTIONS(8763),
    [anon_sym_DASH] = ACTIONS(8755),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8766),
    [anon_sym_TILDE] = ACTIONS(8755),
    [anon_sym_std] = ACTIONS(8769),
    [anon_sym_randomize] = ACTIONS(8772),
    [anon_sym_null] = ACTIONS(8775),
    [anon_sym_AMP] = ACTIONS(8763),
    [anon_sym_PIPE] = ACTIONS(8763),
    [anon_sym_CARET] = ACTIONS(8755),
    [anon_sym_CARET_TILDE] = ACTIONS(8763),
    [anon_sym_TILDE_CARET] = ACTIONS(8763),
    [anon_sym_this] = ACTIONS(8778),
    [anon_sym_TILDE_AMP] = ACTIONS(8763),
    [anon_sym_TILDE_PIPE] = ACTIONS(8763),
    [anon_sym_DASH_DASH] = ACTIONS(8758),
    [aux_sym_decimal_number_token1] = ACTIONS(8781),
    [aux_sym_decimal_number_token2] = ACTIONS(8781),
    [sym_binary_number] = ACTIONS(8784),
    [sym_octal_number] = ACTIONS(8784),
    [sym_hex_number] = ACTIONS(8784),
    [aux_sym_real_number_token1] = ACTIONS(8787),
    [sym_fixed_point_number] = ACTIONS(8790),
    [sym_unsigned_number] = ACTIONS(8793),
    [anon_sym_SQUOTE0] = ACTIONS(8796),
    [anon_sym_SQUOTE1] = ACTIONS(8796),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(8796),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8799),
    [anon_sym_DOLLARroot] = ACTIONS(8802),
    [anon_sym_DOLLARunit] = ACTIONS(8805),
    [sym_system_tf_identifier] = ACTIONS(8808),
  },
  [2123] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9024),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2124] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8811),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2125] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2126] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5843),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9024),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2127] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9563),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8813),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2128] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9391),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8815),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2129] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9391),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8817),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2130] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_select_expression] = STATE(13818),
    [sym_select_condition] = STATE(12808),
    [sym__cross_set_expression] = STATE(12186),
    [sym__covergroup_expression] = STATE(12186),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9255),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7418),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(8702),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(7615),
    [anon_sym_binsof] = ACTIONS(7617),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2131] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5847),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8700),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2132] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15894),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9512),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2133] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(17674),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2134] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8819),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2135] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(19227),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2136] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8813),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2137] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8821),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2138] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_event_expression] = STATE(15147),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_edge_identifier] = STATE(4218),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9512),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_posedge] = ACTIONS(3405),
    [anon_sym_negedge] = ACTIONS(3405),
    [anon_sym_edge] = ACTIONS(3405),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2139] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_case_item] = STATE(2158),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(16485),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9543),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_expr_repeat1] = STATE(2158),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8823),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8825),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2140] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19525),
    [sym_expression] = STATE(9493),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19525),
    [sym_indexed_range] = STATE(19525),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_range_expression] = STATE(20246),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2141] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(18900),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19555),
    [sym_indexed_range] = STATE(19555),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(7681),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2142] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8829),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2143] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5836),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9604),
    [sym_expression] = STATE(9075),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8831),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2144] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8833),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2145] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8835),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2146] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8837),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2147] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9563),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8839),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2148] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8841),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2149] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8843),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2150] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7801),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2151] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9391),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8845),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2152] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5846),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9050),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8037),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2153] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8847),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2154] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8849),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2155] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5843),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2156] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8851),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2157] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5845),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2158] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_case_item] = STATE(2158),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(16485),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9543),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_expr_repeat1] = STATE(2158),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(8853),
    [anon_sym_DQUOTE] = ACTIONS(8856),
    [anon_sym_LPAREN] = ACTIONS(8859),
    [anon_sym_BQUOTE] = ACTIONS(8862),
    [anon_sym_type] = ACTIONS(8865),
    [anon_sym_LBRACE] = ACTIONS(8868),
    [anon_sym_default] = ACTIONS(8871),
    [anon_sym_const] = ACTIONS(8874),
    [anon_sym_local] = ACTIONS(8877),
    [anon_sym_super] = ACTIONS(8880),
    [anon_sym_string] = ACTIONS(8874),
    [anon_sym_byte] = ACTIONS(8883),
    [anon_sym_shortint] = ACTIONS(8883),
    [anon_sym_int] = ACTIONS(8883),
    [anon_sym_longint] = ACTIONS(8883),
    [anon_sym_integer] = ACTIONS(8883),
    [anon_sym_time] = ACTIONS(8883),
    [anon_sym_bit] = ACTIONS(8886),
    [anon_sym_logic] = ACTIONS(8886),
    [anon_sym_reg] = ACTIONS(8886),
    [anon_sym_shortreal] = ACTIONS(8889),
    [anon_sym_real] = ACTIONS(8889),
    [anon_sym_realtime] = ACTIONS(8889),
    [anon_sym_signed] = ACTIONS(8874),
    [anon_sym_unsigned] = ACTIONS(8874),
    [anon_sym_tagged] = ACTIONS(8892),
    [anon_sym_DOLLAR] = ACTIONS(8895),
    [anon_sym_PLUS] = ACTIONS(8898),
    [anon_sym_PLUS_PLUS] = ACTIONS(8901),
    [anon_sym_endcase] = ACTIONS(8904),
    [anon_sym_BANG] = ACTIONS(8906),
    [anon_sym_DASH] = ACTIONS(8898),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8909),
    [anon_sym_TILDE] = ACTIONS(8898),
    [anon_sym_std] = ACTIONS(8912),
    [anon_sym_randomize] = ACTIONS(8915),
    [anon_sym_null] = ACTIONS(8918),
    [anon_sym_AMP] = ACTIONS(8906),
    [anon_sym_PIPE] = ACTIONS(8906),
    [anon_sym_CARET] = ACTIONS(8898),
    [anon_sym_CARET_TILDE] = ACTIONS(8906),
    [anon_sym_TILDE_CARET] = ACTIONS(8906),
    [anon_sym_this] = ACTIONS(8921),
    [anon_sym_TILDE_AMP] = ACTIONS(8906),
    [anon_sym_TILDE_PIPE] = ACTIONS(8906),
    [anon_sym_DASH_DASH] = ACTIONS(8901),
    [aux_sym_decimal_number_token1] = ACTIONS(8924),
    [aux_sym_decimal_number_token2] = ACTIONS(8924),
    [sym_binary_number] = ACTIONS(8927),
    [sym_octal_number] = ACTIONS(8927),
    [sym_hex_number] = ACTIONS(8927),
    [aux_sym_real_number_token1] = ACTIONS(8930),
    [sym_fixed_point_number] = ACTIONS(8933),
    [sym_unsigned_number] = ACTIONS(8936),
    [anon_sym_SQUOTE0] = ACTIONS(8939),
    [anon_sym_SQUOTE1] = ACTIONS(8939),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(8939),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8942),
    [anon_sym_DOLLARroot] = ACTIONS(8945),
    [anon_sym_DOLLARunit] = ACTIONS(8948),
    [sym_system_tf_identifier] = ACTIONS(8951),
  },
  [2159] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5844),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9024),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2160] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8954),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2161] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5847),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9138),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8956),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2162] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5837),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9078),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8700),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2163] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8829),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2164] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8958),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2165] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_scalar_timing_check_condition] = STATE(18043),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9680),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(8960),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2166] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8704),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2167] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5834),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9050),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8037),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2168] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5844),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2169] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8839),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2170] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5835),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9138),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8956),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2171] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8962),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2172] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7807),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2173] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5831),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(8974),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2174] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8964),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2175] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7815),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2176] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5830),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9075),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8831),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2177] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7797),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2178] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8966),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2179] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8968),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2180] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_select_expression] = STATE(12828),
    [sym_select_condition] = STATE(12808),
    [sym__cross_set_expression] = STATE(12186),
    [sym__covergroup_expression] = STATE(12186),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9255),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7418),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(8702),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(7615),
    [anon_sym_binsof] = ACTIONS(7617),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2181] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5836),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9075),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8831),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2182] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7799),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2183] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7821),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2184] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5830),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9604),
    [sym_expression] = STATE(9075),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8831),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2185] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8970),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2186] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18387),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8694),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2187] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5839),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8708),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2188] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9639),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_DOT_STAR] = ACTIONS(8972),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8974),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2189] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8976),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2190] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5832),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9050),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8037),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2191] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18915),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8978),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2192] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8837),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2193] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_stream_operator] = STATE(5847),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11663),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7169),
    [sym_package_scope] = STATE(12244),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(8708),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2194] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_stream_operator] = STATE(5843),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(8974),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5349),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7479),
    [sym_package_scope] = STATE(12376),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_RBRACE] = ACTIONS(7601),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_GT_GT] = ACTIONS(7053),
    [anon_sym_LT_LT] = ACTIONS(7053),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2195] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_sequence_list_of_arguments] = STATE(18321),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8980),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_DOT] = ACTIONS(8696),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2196] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(8982),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2197] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item] = STATE(2122),
    [sym_case_item_expression] = STATE(15381),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_case_statement_repeat1] = STATE(2122),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8452),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(7803),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2198] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(8984),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2199] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2966),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2200] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2295),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2201] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2974),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2202] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(17934),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2203] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2838),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2204] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2982),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2205] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18300),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18300),
    [sym_indexed_range] = STATE(18300),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2206] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_property_case_item] = STATE(2139),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(16485),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9543),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_property_expr_repeat1] = STATE(2139),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8823),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2207] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18597),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18597),
    [sym_indexed_range] = STATE(18597),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2208] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2998),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2209] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(8988),
    [anon_sym_SEMI] = ACTIONS(8991),
    [anon_sym_POUND] = ACTIONS(8994),
    [anon_sym_type] = ACTIONS(8997),
    [anon_sym_LBRACE] = ACTIONS(9000),
    [anon_sym_disable] = ACTIONS(9003),
    [anon_sym_local] = ACTIONS(9006),
    [anon_sym_super] = ACTIONS(9009),
    [anon_sym_endfunction] = ACTIONS(9012),
    [anon_sym_if] = ACTIONS(9014),
    [anon_sym_foreach] = ACTIONS(9017),
    [anon_sym_unique] = ACTIONS(9020),
    [anon_sym_byte] = ACTIONS(9023),
    [anon_sym_shortint] = ACTIONS(9023),
    [anon_sym_int] = ACTIONS(9023),
    [anon_sym_longint] = ACTIONS(9023),
    [anon_sym_integer] = ACTIONS(9023),
    [anon_sym_time] = ACTIONS(9023),
    [anon_sym_PLUS_PLUS] = ACTIONS(9026),
    [anon_sym_assert] = ACTIONS(9029),
    [anon_sym_assume] = ACTIONS(9032),
    [anon_sym_cover] = ACTIONS(9035),
    [anon_sym_expect] = ACTIONS(9038),
    [anon_sym_restrict] = ACTIONS(9041),
    [anon_sym_case] = ACTIONS(9044),
    [anon_sym_POUND_POUND] = ACTIONS(9047),
    [anon_sym_begin] = ACTIONS(9050),
    [anon_sym_for] = ACTIONS(9053),
    [anon_sym_assign] = ACTIONS(9056),
    [anon_sym_deassign] = ACTIONS(9059),
    [anon_sym_force] = ACTIONS(9062),
    [anon_sym_release] = ACTIONS(9065),
    [anon_sym_fork] = ACTIONS(9068),
    [anon_sym_repeat] = ACTIONS(9071),
    [anon_sym_AT] = ACTIONS(9074),
    [anon_sym_AT_STAR] = ACTIONS(9077),
    [anon_sym_return] = ACTIONS(9080),
    [anon_sym_break] = ACTIONS(9083),
    [anon_sym_continue] = ACTIONS(9083),
    [anon_sym_wait] = ACTIONS(9086),
    [anon_sym_wait_order] = ACTIONS(9089),
    [anon_sym_DASH_GT] = ACTIONS(9092),
    [anon_sym_DASH_GT_GT] = ACTIONS(9095),
    [anon_sym_unique0] = ACTIONS(9020),
    [anon_sym_priority] = ACTIONS(9020),
    [anon_sym_casez] = ACTIONS(9044),
    [anon_sym_casex] = ACTIONS(9044),
    [anon_sym_randcase] = ACTIONS(9098),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9101),
    [anon_sym_forever] = ACTIONS(9104),
    [anon_sym_while] = ACTIONS(9071),
    [anon_sym_do] = ACTIONS(9107),
    [anon_sym_this] = ACTIONS(9110),
    [anon_sym_DASH_DASH] = ACTIONS(9026),
    [anon_sym_LPAREN_STAR] = ACTIONS(9113),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9116),
    [anon_sym_DOLLARroot] = ACTIONS(9119),
    [anon_sym_DOLLARunit] = ACTIONS(9122),
    [sym_system_tf_identifier] = ACTIONS(9125),
  },
  [2210] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2768),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2211] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18151),
    [sym_assignment_pattern_key] = STATE(18151),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10534),
    [sym_expression] = STATE(9537),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2212] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2772),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2213] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2315),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2214] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2305),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2215] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2698),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2216] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2237),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2217] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2776),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2218] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2331),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2219] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(19484),
    [sym_output_terminal] = STATE(17492),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7573),
    [sym_package_scope] = STATE(12266),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13962),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9128),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2220] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2243),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2221] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(19128),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2222] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9130),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2223] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2254),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2254),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9130),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2224] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9132),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2225] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3038),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2226] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(20417),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20417),
    [sym_indexed_range] = STATE(20417),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2227] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2235),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2228] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2780),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2229] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2335),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2230] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9134),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2231] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(19793),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2232] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2339),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2233] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17806),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17806),
    [sym_indexed_range] = STATE(17806),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2234] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2784),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2235] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2242),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2242),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2784),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2236] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_dist_list] = STATE(19556),
    [sym_dist_item] = STATE(16023),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9316),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_value_range] = STATE(13150),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2237] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2786),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2238] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2233),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2239] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2788),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2240] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(20147),
    [sym_assignment_pattern_key] = STATE(20147),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10517),
    [sym_expression] = STATE(9432),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2241] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19791),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2242] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2792),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2243] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2249),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2249),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2792),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2244] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2794),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2245] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2796),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2246] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2798),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2247] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(19555),
    [sym_expression] = STATE(9467),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19555),
    [sym_indexed_range] = STATE(19555),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2248] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2258),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9136),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2249] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9136),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2250] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2800),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2251] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2802),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2252] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(17487),
    [sym_output_terminal] = STATE(17492),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7573),
    [sym_package_scope] = STATE(12266),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13962),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9128),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2253] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2804),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2254] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9138),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2255] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2278),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2278),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9138),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2256] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9140),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2257] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17697),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17697),
    [sym_indexed_range] = STATE(17697),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2258] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9142),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2259] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2265),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2265),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9142),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2260] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9144),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2261] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2806),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2262] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9146),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2263] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2892),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2264] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2577),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2577),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2892),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2265] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9148),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2266] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2269),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2269),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9148),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2267] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9150),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2268] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2900),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2269] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9152),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2270] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2198),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2198),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9152),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2271] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2272),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(8984),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2272] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9154),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2273] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2904),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2274] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2924),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2275] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18467),
    [sym_assignment_pattern_key] = STATE(18467),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10562),
    [sym_expression] = STATE(9487),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2276] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2818),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2277] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2245),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2278] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9156),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2279] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2285),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2285),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9156),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2280] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2822),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2281] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2282] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18550),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18550),
    [sym_indexed_range] = STATE(18550),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2283] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2830),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2284] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2251),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2285] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9158),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2286] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2296),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9158),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2287] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2255),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2288] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(18194),
    [sym_output_terminal] = STATE(17492),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(14789),
    [sym_assignment_pattern_net_lvalue] = STATE(13056),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_net_lvalue] = STATE(17260),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7573),
    [sym_package_scope] = STATE(12266),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13962),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(8035),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8039),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9128),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2289] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18815),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18815),
    [sym_indexed_range] = STATE(18815),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2290] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2842),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2291] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2299),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2299),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2842),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2292] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_ordered_port_connection] = STATE(16876),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9566),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2965),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2965),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2293] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2844),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2294] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2257),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2295] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2846),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2296] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9160),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2297] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timestamp_condition] = STATE(16921),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16961),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9162),
    [anon_sym_COMMA] = ACTIONS(9164),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2298] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timestamp_condition] = STATE(17038),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16961),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9166),
    [anon_sym_COMMA] = ACTIONS(9168),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2299] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2850),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2300] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2309),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2309),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2850),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2301] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2852),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2302] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2854),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2303] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2856),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2304] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_covergroup_range_list] = STATE(19535),
    [sym_covergroup_value_range] = STATE(16255),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2305] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(17240),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9170),
    [anon_sym_COMMA] = ACTIONS(9172),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2306] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timestamp_condition] = STATE(17244),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16961),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9170),
    [anon_sym_COMMA] = ACTIONS(9174),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2307] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timestamp_condition] = STATE(17262),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(16961),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(8526),
    [anon_sym_COMMA] = ACTIONS(9176),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2308] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2315),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2315),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9178),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2309] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9178),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2310] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2858),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2311] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(17323),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9180),
    [anon_sym_COMMA] = ACTIONS(9182),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2312] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2860),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2313] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2862),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2314] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timecheck_condition] = STATE(16725),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17241),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9184),
    [anon_sym_COMMA] = ACTIONS(9186),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2315] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9188),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2316] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2320),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2320),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9188),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2317] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9190),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2318] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2864),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2319] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9192),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2320] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9194),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2321] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2323),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2323),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9194),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2322] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9196),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2323] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9198),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2324] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2325),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2325),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9198),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2325] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9200),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2326] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2327),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2327),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9200),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2327] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9202),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2328] = {
    [sym_attribute_instance] = STATE(2328),
    [aux_sym__description_repeat1] = STATE(2328),
    [sym_simple_identifier] = ACTIONS(9204),
    [anon_sym_wire] = ACTIONS(9204),
    [anon_sym_tri] = ACTIONS(9204),
    [anon_sym_tri0] = ACTIONS(9204),
    [anon_sym_tri1] = ACTIONS(9204),
    [anon_sym_wand] = ACTIONS(9204),
    [anon_sym_triand] = ACTIONS(9204),
    [anon_sym_wor] = ACTIONS(9204),
    [anon_sym_trior] = ACTIONS(9204),
    [anon_sym_trireg] = ACTIONS(9204),
    [anon_sym_uwire] = ACTIONS(9204),
    [anon_sym_SEMI] = ACTIONS(9206),
    [anon_sym_extern] = ACTIONS(9204),
    [anon_sym_module] = ACTIONS(9204),
    [anon_sym_macromodule] = ACTIONS(9204),
    [anon_sym_interface] = ACTIONS(9204),
    [anon_sym_program] = ACTIONS(9204),
    [anon_sym_checker] = ACTIONS(9204),
    [anon_sym_virtual] = ACTIONS(9204),
    [anon_sym_class] = ACTIONS(9204),
    [anon_sym_type] = ACTIONS(9204),
    [anon_sym_input] = ACTIONS(9204),
    [anon_sym_output] = ACTIONS(9204),
    [anon_sym_inout] = ACTIONS(9204),
    [anon_sym_ref] = ACTIONS(9204),
    [anon_sym_DOLLARfatal] = ACTIONS(9206),
    [anon_sym_DOLLARerror] = ACTIONS(9206),
    [anon_sym_DOLLARwarning] = ACTIONS(9206),
    [anon_sym_DOLLARinfo] = ACTIONS(9206),
    [anon_sym_default] = ACTIONS(9204),
    [anon_sym_clocking] = ACTIONS(9204),
    [anon_sym_defparam] = ACTIONS(9204),
    [anon_sym_bind] = ACTIONS(9204),
    [anon_sym_const] = ACTIONS(9204),
    [anon_sym_function] = ACTIONS(9204),
    [anon_sym_static] = ACTIONS(9204),
    [anon_sym_constraint] = ACTIONS(9204),
    [anon_sym_if] = ACTIONS(9204),
    [anon_sym_LBRACK] = ACTIONS(9206),
    [anon_sym_localparam] = ACTIONS(9204),
    [anon_sym_parameter] = ACTIONS(9204),
    [anon_sym_specparam] = ACTIONS(9204),
    [anon_sym_var] = ACTIONS(9204),
    [anon_sym_import] = ACTIONS(9204),
    [anon_sym_export] = ACTIONS(9204),
    [anon_sym_genvar] = ACTIONS(9204),
    [anon_sym_interconnect] = ACTIONS(9204),
    [anon_sym_typedef] = ACTIONS(9204),
    [anon_sym_enum] = ACTIONS(9204),
    [anon_sym_struct] = ACTIONS(9204),
    [anon_sym_union] = ACTIONS(9204),
    [anon_sym_nettype] = ACTIONS(9204),
    [anon_sym_automatic] = ACTIONS(9204),
    [anon_sym_string] = ACTIONS(9204),
    [anon_sym_chandle] = ACTIONS(9204),
    [anon_sym_event] = ACTIONS(9204),
    [anon_sym_byte] = ACTIONS(9204),
    [anon_sym_shortint] = ACTIONS(9204),
    [anon_sym_int] = ACTIONS(9204),
    [anon_sym_longint] = ACTIONS(9204),
    [anon_sym_integer] = ACTIONS(9204),
    [anon_sym_time] = ACTIONS(9204),
    [anon_sym_bit] = ACTIONS(9204),
    [anon_sym_logic] = ACTIONS(9204),
    [anon_sym_reg] = ACTIONS(9204),
    [anon_sym_shortreal] = ACTIONS(9204),
    [anon_sym_real] = ACTIONS(9204),
    [anon_sym_realtime] = ACTIONS(9204),
    [anon_sym_supply0] = ACTIONS(9204),
    [anon_sym_supply1] = ACTIONS(9204),
    [anon_sym_signed] = ACTIONS(9204),
    [anon_sym_unsigned] = ACTIONS(9204),
    [anon_sym_task] = ACTIONS(9204),
    [anon_sym_PLUS_PLUS] = ACTIONS(9206),
    [anon_sym_assert] = ACTIONS(9204),
    [anon_sym_property] = ACTIONS(9204),
    [anon_sym_assume] = ACTIONS(9204),
    [anon_sym_cover] = ACTIONS(9204),
    [anon_sym_sequence] = ACTIONS(9204),
    [anon_sym_restrict] = ACTIONS(9204),
    [anon_sym_not] = ACTIONS(9204),
    [anon_sym_or] = ACTIONS(9204),
    [anon_sym_and] = ACTIONS(9204),
    [anon_sym_case] = ACTIONS(9204),
    [anon_sym_always] = ACTIONS(9204),
    [anon_sym_covergroup] = ACTIONS(9204),
    [anon_sym_let] = ACTIONS(9204),
    [anon_sym_pulldown] = ACTIONS(9204),
    [anon_sym_pullup] = ACTIONS(9204),
    [anon_sym_cmos] = ACTIONS(9204),
    [anon_sym_rcmos] = ACTIONS(9204),
    [anon_sym_bufif0] = ACTIONS(9204),
    [anon_sym_bufif1] = ACTIONS(9204),
    [anon_sym_notif0] = ACTIONS(9204),
    [anon_sym_notif1] = ACTIONS(9204),
    [anon_sym_nmos] = ACTIONS(9204),
    [anon_sym_pmos] = ACTIONS(9204),
    [anon_sym_rnmos] = ACTIONS(9204),
    [anon_sym_rpmos] = ACTIONS(9204),
    [anon_sym_nand] = ACTIONS(9204),
    [anon_sym_nor] = ACTIONS(9204),
    [anon_sym_xor] = ACTIONS(9204),
    [anon_sym_xnor] = ACTIONS(9204),
    [anon_sym_buf] = ACTIONS(9204),
    [anon_sym_tranif0] = ACTIONS(9204),
    [anon_sym_tranif1] = ACTIONS(9204),
    [anon_sym_rtranif1] = ACTIONS(9204),
    [anon_sym_rtranif0] = ACTIONS(9204),
    [anon_sym_tran] = ACTIONS(9204),
    [anon_sym_rtran] = ACTIONS(9204),
    [anon_sym_for] = ACTIONS(9204),
    [anon_sym_initial] = ACTIONS(9204),
    [anon_sym_assign] = ACTIONS(9204),
    [anon_sym_alias] = ACTIONS(9204),
    [anon_sym_always_comb] = ACTIONS(9204),
    [anon_sym_always_latch] = ACTIONS(9204),
    [anon_sym_always_ff] = ACTIONS(9204),
    [anon_sym_final] = ACTIONS(9204),
    [anon_sym_global] = ACTIONS(9204),
    [anon_sym_DASH_DASH] = ACTIONS(9206),
    [anon_sym_LPAREN_STAR] = ACTIONS(9208),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9206),
    [anon_sym_DOLLARunit] = ACTIONS(9206),
  },
  [2329] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18655),
    [sym_assignment_pattern_key] = STATE(18655),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10566),
    [sym_expression] = STATE(9525),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2330] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2880),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2331] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2263),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2332] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2884),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2333] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2265),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2334] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(20237),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20237),
    [sym_indexed_range] = STATE(20237),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2335] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2888),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2336] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2269),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2337] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(20147),
    [sym_assignment_pattern_key] = STATE(20147),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10517),
    [sym_expression] = STATE(9432),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2338] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2273),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2339] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17532),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17532),
    [sym_indexed_range] = STATE(17532),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2340] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2896),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2341] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2345),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2345),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2896),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2342] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2898),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2343] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2275),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2344] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2902),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2345] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2908),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2346] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2351),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2351),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2908),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2347] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2910),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2348] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2912),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2349] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2914),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2350] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2355),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2355),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9211),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2351] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9211),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2352] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2916),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2353] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2920),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2354] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2922),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2355] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9213),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2356] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2360),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2360),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9213),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2357] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9215),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2358] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2926),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2359] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9217),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2360] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9219),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2361] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2363),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2363),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9219),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2362] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9221),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2363] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9223),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2364] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2365),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2365),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9223),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2365] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9225),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2366] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2578),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2578),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9225),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2367] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18822),
    [sym_assignment_pattern_key] = STATE(18822),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10567),
    [sym_expression] = STATE(9409),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2368] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2938),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2369] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2279),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2370] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2942),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2371] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2281),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2372] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19085),
    [sym_expression] = STATE(9452),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19085),
    [sym_indexed_range] = STATE(19085),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2373] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2946),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2374] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2285),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2375] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2289),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2376] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19302),
    [sym_expression] = STATE(9452),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19302),
    [sym_indexed_range] = STATE(19302),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2377] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2950),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2378] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2382),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2382),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2950),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2379] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2952),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2380] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2291),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2381] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2954),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2382] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2958),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2383] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2389),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2389),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2958),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2384] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2960),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2385] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2962),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2386] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2964),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2387] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19244),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19244),
    [sym_indexed_range] = STATE(19244),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2388] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2393),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2393),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9227),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2389] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9227),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2390] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2968),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2391] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2970),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2392] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2972),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2393] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9229),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2394] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2398),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2398),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9229),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2395] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9231),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2396] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2976),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2397] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9233),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2398] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9235),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2399] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2401),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2401),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9235),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2400] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9237),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2401] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9239),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2402] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2403),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2403),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9239),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2403] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9241),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2404] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2405),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2405),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9241),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2405] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9243),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2406] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18964),
    [sym_assignment_pattern_key] = STATE(18964),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10568),
    [sym_expression] = STATE(9426),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7393),
    [sym_package_scope] = STATE(12426),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2407] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2990),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2408] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2299),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2409] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2994),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2410] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2301),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2411] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19245),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19245),
    [sym_indexed_range] = STATE(19245),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2412] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18597),
    [sym_expression] = STATE(9390),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18597),
    [sym_indexed_range] = STATE(18597),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2413] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3002),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2414] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2307),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2415] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2311),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2416] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19245),
    [sym_expression] = STATE(9390),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19245),
    [sym_indexed_range] = STATE(19245),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2417] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3006),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2418] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2422),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2422),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3006),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2419] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3008),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2420] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2313),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2421] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3010),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2422] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3014),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2423] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2428),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2428),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3014),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2424] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3016),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2425] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3018),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2426] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3020),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2427] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2432),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2432),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9245),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2428] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9245),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2429] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3022),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2430] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3024),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2431] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3026),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2432] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2433] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2437),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2437),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9247),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2434] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9249),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2435] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3028),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2436] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9251),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2437] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9253),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2438] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2440),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2440),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9253),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2439] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9255),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2440] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9257),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2441] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2442),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2442),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9257),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2442] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9259),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2443] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2444),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2444),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9259),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2444] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9261),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2445] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19346),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19346),
    [sym_indexed_range] = STATE(19346),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2446] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19417),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19417),
    [sym_indexed_range] = STATE(19417),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2447] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17439),
    [sym_expression] = STATE(9428),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17439),
    [sym_indexed_range] = STATE(17439),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2448] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17456),
    [sym_expression] = STATE(9428),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17456),
    [sym_indexed_range] = STATE(17456),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2449] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17581),
    [sym_expression] = STATE(9385),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17581),
    [sym_indexed_range] = STATE(17581),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2450] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17587),
    [sym_expression] = STATE(9385),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17587),
    [sym_indexed_range] = STATE(17587),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2451] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18550),
    [sym_expression] = STATE(9408),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18550),
    [sym_indexed_range] = STATE(18550),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2452] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18815),
    [sym_expression] = STATE(9408),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18815),
    [sym_indexed_range] = STATE(18815),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2453] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(20237),
    [sym_expression] = STATE(9450),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20237),
    [sym_indexed_range] = STATE(20237),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2454] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17532),
    [sym_expression] = STATE(9450),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17532),
    [sym_indexed_range] = STATE(17532),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2455] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17655),
    [sym_expression] = STATE(9488),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17655),
    [sym_indexed_range] = STATE(17655),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2456] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17661),
    [sym_expression] = STATE(9488),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17661),
    [sym_indexed_range] = STATE(17661),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2457] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17717),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17717),
    [sym_indexed_range] = STATE(17717),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2458] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17724),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17724),
    [sym_indexed_range] = STATE(17724),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2459] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17838),
    [sym_expression] = STATE(9549),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17838),
    [sym_indexed_range] = STATE(17838),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2460] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17844),
    [sym_expression] = STATE(9549),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17844),
    [sym_indexed_range] = STATE(17844),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2461] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17779),
    [sym_expression] = STATE(9557),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17779),
    [sym_indexed_range] = STATE(17779),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2462] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17785),
    [sym_expression] = STATE(9557),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17785),
    [sym_indexed_range] = STATE(17785),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2463] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18550),
    [sym_expression] = STATE(9480),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18550),
    [sym_indexed_range] = STATE(18550),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2464] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18815),
    [sym_expression] = STATE(9480),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18815),
    [sym_indexed_range] = STATE(18815),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2465] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(20237),
    [sym_expression] = STATE(9387),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20237),
    [sym_indexed_range] = STATE(20237),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2466] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17532),
    [sym_expression] = STATE(9387),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17532),
    [sym_indexed_range] = STATE(17532),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2467] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18597),
    [sym_expression] = STATE(9389),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18597),
    [sym_indexed_range] = STATE(18597),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2468] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19245),
    [sym_expression] = STATE(9389),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19245),
    [sym_indexed_range] = STATE(19245),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2469] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(18939),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(18970),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2470] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18151),
    [sym_assignment_pattern_key] = STATE(18151),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10534),
    [sym_expression] = STATE(9537),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2471] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17817),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2472] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(20516),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2473] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17993),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17993),
    [sym_indexed_range] = STATE(17993),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2474] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18061),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18061),
    [sym_indexed_range] = STATE(18061),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2475] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17801),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17801),
    [sym_indexed_range] = STATE(17801),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2476] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19529),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19529),
    [sym_indexed_range] = STATE(19529),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2477] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18008),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18008),
    [sym_indexed_range] = STATE(18008),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2478] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2826),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2479] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17890),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17890),
    [sym_indexed_range] = STATE(17890),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2480] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17895),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17895),
    [sym_indexed_range] = STATE(17895),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2481] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17779),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17779),
    [sym_indexed_range] = STATE(17779),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2482] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17785),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17785),
    [sym_indexed_range] = STATE(17785),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2483] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(20380),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20381),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2484] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18467),
    [sym_assignment_pattern_key] = STATE(18467),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10562),
    [sym_expression] = STATE(9487),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2485] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(19791),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2486] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(18111),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2487] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18173),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18173),
    [sym_indexed_range] = STATE(18173),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2488] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18791),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18791),
    [sym_indexed_range] = STATE(18791),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2489] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19030),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19030),
    [sym_indexed_range] = STATE(19030),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2490] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17952),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17952),
    [sym_indexed_range] = STATE(17952),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2491] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17959),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17959),
    [sym_indexed_range] = STATE(17959),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2492] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(20380),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19718),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20381),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2493] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18655),
    [sym_assignment_pattern_key] = STATE(18655),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10566),
    [sym_expression] = STATE(9525),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2494] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17804),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2495] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(18873),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2496] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18962),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18962),
    [sym_indexed_range] = STATE(18962),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2497] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17530),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17530),
    [sym_indexed_range] = STATE(17530),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2498] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2263),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2263),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2826),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2499] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17612),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17612),
    [sym_indexed_range] = STATE(17612),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2500] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(18323),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(18324),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2501] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18822),
    [sym_assignment_pattern_key] = STATE(18822),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10567),
    [sym_expression] = STATE(9409),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2502] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17551),
    [sym_expression] = STATE(9385),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17551),
    [sym_indexed_range] = STATE(17551),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2503] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(18887),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2504] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(18892),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18892),
    [sym_indexed_range] = STATE(18892),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2505] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19300),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19300),
    [sym_indexed_range] = STATE(19300),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2506] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19460),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19460),
    [sym_indexed_range] = STATE(19460),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2507] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(17798),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17799),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2508] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13852),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17311),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17311),
    [sym_non_integer_type] = STATE(17311),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17311),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym__array_pattern_key] = STATE(18964),
    [sym_assignment_pattern_key] = STATE(18964),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10568),
    [sym_expression] = STATE(9426),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(11767),
    [sym_unary_operator] = STATE(5329),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7375),
    [sym_package_scope] = STATE(12093),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13157),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12523),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_default] = ACTIONS(8482),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7057),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2509] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(18592),
    [sym_expression] = STATE(9452),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18592),
    [sym_indexed_range] = STATE(18592),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2510] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_range_list] = STATE(18847),
    [sym_open_value_range] = STATE(16569),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2511] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17548),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17548),
    [sym_indexed_range] = STATE(17548),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2512] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19523),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19523),
    [sym_indexed_range] = STATE(19523),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2513] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17524),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17524),
    [sym_indexed_range] = STATE(17524),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2514] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(20075),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(5968),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20077),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1460),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5860),
    [sym_package_scope] = STATE(12075),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13207),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(7609),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(7825),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(7619),
    [anon_sym_DOLLARroot] = ACTIONS(7653),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2515] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17817),
    [sym_expression] = STATE(9450),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2516] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19238),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19238),
    [sym_indexed_range] = STATE(19238),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2517] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19411),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19411),
    [sym_indexed_range] = STATE(19411),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2518] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(19518),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19518),
    [sym_indexed_range] = STATE(19518),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2519] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(19791),
    [sym_expression] = STATE(9390),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2520] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17413),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17413),
    [sym_indexed_range] = STATE(17413),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2521] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17455),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17455),
    [sym_indexed_range] = STATE(17455),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2522] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17482),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17482),
    [sym_indexed_range] = STATE(17482),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2523] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17620),
    [sym_expression] = STATE(9488),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17620),
    [sym_indexed_range] = STATE(17620),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2524] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17574),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17574),
    [sym_indexed_range] = STATE(17574),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2525] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17586),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17586),
    [sym_indexed_range] = STATE(17586),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2526] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17590),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17590),
    [sym_indexed_range] = STATE(17590),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2527] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(20261),
    [sym_expression] = STATE(9458),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20261),
    [sym_indexed_range] = STATE(20261),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2528] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17647),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17647),
    [sym_indexed_range] = STATE(17647),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2529] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17660),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17660),
    [sym_indexed_range] = STATE(17660),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2530] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17664),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17664),
    [sym_indexed_range] = STATE(17664),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2531] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17689),
    [sym_expression] = STATE(9530),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17689),
    [sym_indexed_range] = STATE(17689),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2532] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17710),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17710),
    [sym_indexed_range] = STATE(17710),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2533] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17723),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17723),
    [sym_indexed_range] = STATE(17723),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2534] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17728),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17728),
    [sym_indexed_range] = STATE(17728),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2535] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(18773),
    [sym_expression] = STATE(9481),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(18773),
    [sym_indexed_range] = STATE(18773),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2536] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17773),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17773),
    [sym_indexed_range] = STATE(17773),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2537] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17783),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17783),
    [sym_indexed_range] = STATE(17783),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2538] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17788),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17788),
    [sym_indexed_range] = STATE(17788),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2539] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(20418),
    [sym_expression] = STATE(9428),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(20418),
    [sym_indexed_range] = STATE(20418),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2540] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17830),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17830),
    [sym_indexed_range] = STATE(17830),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2541] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17843),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17843),
    [sym_indexed_range] = STATE(17843),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2542] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17847),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17847),
    [sym_indexed_range] = STATE(17847),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2543] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17804),
    [sym_expression] = STATE(9408),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2544] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17879),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17879),
    [sym_indexed_range] = STATE(17879),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2545] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17894),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17894),
    [sym_indexed_range] = STATE(17894),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2546] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17898),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17898),
    [sym_indexed_range] = STATE(17898),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2547] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17751),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17751),
    [sym_indexed_range] = STATE(17751),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2548] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17945),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17945),
    [sym_indexed_range] = STATE(17945),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2549] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17958),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17958),
    [sym_indexed_range] = STATE(17958),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2550] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10582),
    [sym_constant_range] = STATE(17965),
    [sym_expression] = STATE(9652),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17965),
    [sym_indexed_range] = STATE(17965),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5335),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7389),
    [sym_package_scope] = STATE(12408),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2551] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17751),
    [sym_expression] = STATE(9557),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17751),
    [sym_indexed_range] = STATE(17751),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2552] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17815),
    [sym_expression] = STATE(9549),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17815),
    [sym_indexed_range] = STATE(17815),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2553] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17923),
    [sym_expression] = STATE(9455),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17923),
    [sym_indexed_range] = STATE(17923),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2554] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17863),
    [sym_expression] = STATE(9400),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17863),
    [sym_indexed_range] = STATE(17863),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2555] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17817),
    [sym_expression] = STATE(9387),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17817),
    [sym_indexed_range] = STATE(17817),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2556] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(17804),
    [sym_expression] = STATE(9480),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(17804),
    [sym_indexed_range] = STATE(17804),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2557] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_constant_expression] = STATE(10525),
    [sym_constant_range] = STATE(19791),
    [sym_expression] = STATE(9389),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym__part_select_range] = STATE(19791),
    [sym_indexed_range] = STATE(19791),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5337),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7419),
    [sym_package_scope] = STATE(12206),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2558] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2319),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2559] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2321),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2560] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2323),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2561] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2327),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2562] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2222),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2222),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9263),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2563] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2832),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2564] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3040),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2565] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2329),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2566] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3042),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2567] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2694),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2568] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3044),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2569] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3046),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2570] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3048),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2571] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3050),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2572] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(3052),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2573] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9265),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2574] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(2918),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2575] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9267),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2576] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9269),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2577] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9263),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2578] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(7411),
    [sym_statement_item] = STATE(6696),
    [sym_function_statement] = STATE(7390),
    [sym_function_statement_or_null] = STATE(2209),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4263),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4263),
    [aux_sym_class_constructor_declaration_repeat2] = STATE(2209),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2129),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_endfunction] = ACTIONS(9271),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2579] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1173),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2580] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(5190),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2581] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9072),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2582] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9087),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2583] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9102),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2584] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9074),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2585] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8973),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2586] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9048),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2587] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9081),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2588] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8962),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2589] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6985),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2590] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1039),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2591] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6968),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2592] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9398),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15691),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7243),
    [anon_sym_COMMA] = ACTIONS(7245),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2593] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3094),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2594] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1046),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2595] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1047),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2596] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8758),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2622),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2622),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2597] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8759),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2623),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2623),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2598] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8764),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2624),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2624),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2599] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2625),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2625),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2600] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8766),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2626),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2626),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2601] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8767),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2627),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2627),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2602] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8768),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2628),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2628),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2603] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8769),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2629),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2629),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2604] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8770),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2630),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2630),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2605] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8773),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2631),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2631),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2606] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8774),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2632),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2632),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2607] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8775),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2633),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2633),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2608] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(18970),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2609] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7049),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2610] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1049),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2611] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6924),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2612] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2613] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6958),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2614] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3100),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2615] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_list_of_arguments_parent] = STATE(16925),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9624),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9451),
    [anon_sym_COMMA] = ACTIONS(9453),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(9453),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2616] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2375),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2617] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9368),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2663),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2663),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2618] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3114),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2619] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2642),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2642),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9457),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2620] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10305),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3102),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3102),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2621] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_dist_item] = STATE(16908),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9316),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_value_range] = STATE(13150),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2622] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8780),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2623] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8781),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2624] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8782),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2625] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2626] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8783),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2627] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8787),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2628] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8788),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2629] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8823),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2630] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8790),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2631] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8791),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2632] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8792),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2633] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8794),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2634] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9173),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2664),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2664),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2635] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_trans_list] = STATE(17352),
    [sym__set_covergroup_expression] = STATE(17352),
    [sym__covergroup_expression] = STATE(17352),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7474),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9459),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(9461),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2636] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9276),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2666),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2666),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2637] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2586),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2638] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1055),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2639] = {
    [sym_attribute_instance] = STATE(2639),
    [aux_sym__description_repeat1] = STATE(2639),
    [sym_simple_identifier] = ACTIONS(9204),
    [anon_sym_LT] = ACTIONS(9204),
    [anon_sym_GT] = ACTIONS(9204),
    [anon_sym_LPAREN] = ACTIONS(9204),
    [anon_sym_RPAREN] = ACTIONS(9206),
    [anon_sym_COMMA] = ACTIONS(9206),
    [anon_sym_SLASH] = ACTIONS(9204),
    [anon_sym_wire] = ACTIONS(9204),
    [anon_sym_tri] = ACTIONS(9204),
    [anon_sym_tri0] = ACTIONS(9204),
    [anon_sym_tri1] = ACTIONS(9204),
    [anon_sym_wand] = ACTIONS(9204),
    [anon_sym_triand] = ACTIONS(9204),
    [anon_sym_wor] = ACTIONS(9204),
    [anon_sym_trior] = ACTIONS(9204),
    [anon_sym_trireg] = ACTIONS(9204),
    [anon_sym_uwire] = ACTIONS(9204),
    [anon_sym_DOT_STAR] = ACTIONS(9206),
    [anon_sym_SEMI] = ACTIONS(9206),
    [anon_sym_COLON] = ACTIONS(9206),
    [anon_sym_module] = ACTIONS(9204),
    [anon_sym_macromodule] = ACTIONS(9204),
    [anon_sym_interface] = ACTIONS(9204),
    [anon_sym_program] = ACTIONS(9204),
    [anon_sym_checker] = ACTIONS(9204),
    [anon_sym_virtual] = ACTIONS(9204),
    [anon_sym_class] = ACTIONS(9204),
    [anon_sym_pure] = ACTIONS(9204),
    [anon_sym_package] = ACTIONS(9204),
    [anon_sym_timeunit] = ACTIONS(9204),
    [anon_sym_timeprecision] = ACTIONS(9204),
    [anon_sym_type] = ACTIONS(9204),
    [anon_sym_DOT] = ACTIONS(9204),
    [anon_sym_LBRACE] = ACTIONS(9206),
    [anon_sym_RBRACE] = ACTIONS(9206),
    [anon_sym_input] = ACTIONS(9204),
    [anon_sym_output] = ACTIONS(9204),
    [anon_sym_inout] = ACTIONS(9204),
    [anon_sym_ref] = ACTIONS(9204),
    [anon_sym_clocking] = ACTIONS(9204),
    [anon_sym_iff] = ACTIONS(9204),
    [anon_sym_bind] = ACTIONS(9204),
    [anon_sym_const] = ACTIONS(9204),
    [anon_sym_function] = ACTIONS(9204),
    [anon_sym_static] = ACTIONS(9204),
    [anon_sym_constraint] = ACTIONS(9204),
    [anon_sym_u2013_GT] = ACTIONS(9206),
    [anon_sym_LBRACK] = ACTIONS(9206),
    [anon_sym_RBRACK] = ACTIONS(9206),
    [anon_sym_localparam] = ACTIONS(9204),
    [anon_sym_parameter] = ACTIONS(9204),
    [anon_sym_var] = ACTIONS(9204),
    [anon_sym_import] = ACTIONS(9204),
    [anon_sym_STAR] = ACTIONS(9204),
    [anon_sym_export] = ACTIONS(9204),
    [anon_sym_interconnect] = ACTIONS(9204),
    [anon_sym_typedef] = ACTIONS(9204),
    [anon_sym_enum] = ACTIONS(9204),
    [anon_sym_struct] = ACTIONS(9204),
    [anon_sym_union] = ACTIONS(9204),
    [anon_sym_nettype] = ACTIONS(9204),
    [anon_sym_with] = ACTIONS(9204),
    [anon_sym_automatic] = ACTIONS(9204),
    [anon_sym_string] = ACTIONS(9204),
    [anon_sym_chandle] = ACTIONS(9204),
    [anon_sym_event] = ACTIONS(9204),
    [anon_sym_byte] = ACTIONS(9204),
    [anon_sym_shortint] = ACTIONS(9204),
    [anon_sym_int] = ACTIONS(9204),
    [anon_sym_longint] = ACTIONS(9204),
    [anon_sym_integer] = ACTIONS(9204),
    [anon_sym_time] = ACTIONS(9204),
    [anon_sym_bit] = ACTIONS(9204),
    [anon_sym_logic] = ACTIONS(9204),
    [anon_sym_reg] = ACTIONS(9204),
    [anon_sym_shortreal] = ACTIONS(9204),
    [anon_sym_real] = ACTIONS(9204),
    [anon_sym_realtime] = ACTIONS(9204),
    [anon_sym_supply0] = ACTIONS(9204),
    [anon_sym_supply1] = ACTIONS(9204),
    [anon_sym_signed] = ACTIONS(9204),
    [anon_sym_unsigned] = ACTIONS(9204),
    [anon_sym_task] = ACTIONS(9204),
    [anon_sym_PLUS] = ACTIONS(9206),
    [anon_sym_STAR_STAR] = ACTIONS(9206),
    [anon_sym_PERCENT] = ACTIONS(9206),
    [anon_sym_EQ_EQ] = ACTIONS(9204),
    [anon_sym_BANG_EQ] = ACTIONS(9204),
    [anon_sym_LT_EQ] = ACTIONS(9206),
    [anon_sym_GT_EQ] = ACTIONS(9206),
    [anon_sym_property] = ACTIONS(9204),
    [anon_sym_sequence] = ACTIONS(9204),
    [anon_sym_or] = ACTIONS(9204),
    [anon_sym_dist] = ACTIONS(9204),
    [anon_sym_covergroup] = ACTIONS(9204),
    [anon_sym_AMP_AMP] = ACTIONS(9204),
    [anon_sym_PIPE_PIPE] = ACTIONS(9206),
    [anon_sym_matches] = ACTIONS(9204),
    [anon_sym_let] = ACTIONS(9204),
    [anon_sym_primitive] = ACTIONS(9204),
    [anon_sym_DASH] = ACTIONS(9204),
    [anon_sym_DASH_GT] = ACTIONS(9206),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9206),
    [anon_sym_inside] = ACTIONS(9204),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9206),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9206),
    [anon_sym_GT_GT] = ACTIONS(9204),
    [anon_sym_LT_LT] = ACTIONS(9204),
    [anon_sym_QMARK] = ACTIONS(9206),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9206),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9206),
    [anon_sym_AMP] = ACTIONS(9204),
    [anon_sym_PIPE] = ACTIONS(9204),
    [anon_sym_CARET] = ACTIONS(9204),
    [anon_sym_CARET_TILDE] = ACTIONS(9206),
    [anon_sym_TILDE_CARET] = ACTIONS(9206),
    [anon_sym_GT_GT_GT] = ACTIONS(9206),
    [anon_sym_LT_LT_LT] = ACTIONS(9206),
    [anon_sym_LT_DASH_GT] = ACTIONS(9206),
    [anon_sym_LPAREN_STAR] = ACTIONS(9463),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9206),
    [anon_sym_DOLLARunit] = ACTIONS(9206),
  },
  [2640] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(9466),
    [anon_sym_DQUOTE] = ACTIONS(9469),
    [anon_sym_LPAREN] = ACTIONS(9472),
    [anon_sym_BQUOTE] = ACTIONS(9475),
    [anon_sym_type] = ACTIONS(9478),
    [anon_sym_LBRACE] = ACTIONS(9481),
    [anon_sym_const] = ACTIONS(9484),
    [anon_sym_local] = ACTIONS(9487),
    [anon_sym_super] = ACTIONS(9490),
    [anon_sym_string] = ACTIONS(9484),
    [anon_sym_byte] = ACTIONS(9493),
    [anon_sym_shortint] = ACTIONS(9493),
    [anon_sym_int] = ACTIONS(9493),
    [anon_sym_longint] = ACTIONS(9493),
    [anon_sym_integer] = ACTIONS(9493),
    [anon_sym_time] = ACTIONS(9493),
    [anon_sym_bit] = ACTIONS(9496),
    [anon_sym_logic] = ACTIONS(9496),
    [anon_sym_reg] = ACTIONS(9496),
    [anon_sym_shortreal] = ACTIONS(9499),
    [anon_sym_real] = ACTIONS(9499),
    [anon_sym_realtime] = ACTIONS(9499),
    [anon_sym_signed] = ACTIONS(9484),
    [anon_sym_unsigned] = ACTIONS(9484),
    [anon_sym_tagged] = ACTIONS(9502),
    [anon_sym_DOLLAR] = ACTIONS(9505),
    [anon_sym_PLUS] = ACTIONS(9508),
    [anon_sym_PLUS_PLUS] = ACTIONS(9511),
    [anon_sym_endcase] = ACTIONS(9514),
    [anon_sym_BANG] = ACTIONS(9516),
    [anon_sym_DASH] = ACTIONS(9508),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9519),
    [anon_sym_TILDE] = ACTIONS(9508),
    [anon_sym_std] = ACTIONS(9522),
    [anon_sym_randomize] = ACTIONS(9525),
    [anon_sym_null] = ACTIONS(9528),
    [anon_sym_AMP] = ACTIONS(9516),
    [anon_sym_PIPE] = ACTIONS(9516),
    [anon_sym_CARET] = ACTIONS(9508),
    [anon_sym_CARET_TILDE] = ACTIONS(9516),
    [anon_sym_TILDE_CARET] = ACTIONS(9516),
    [anon_sym_this] = ACTIONS(9531),
    [anon_sym_TILDE_AMP] = ACTIONS(9516),
    [anon_sym_TILDE_PIPE] = ACTIONS(9516),
    [anon_sym_DASH_DASH] = ACTIONS(9511),
    [aux_sym_decimal_number_token1] = ACTIONS(9534),
    [aux_sym_decimal_number_token2] = ACTIONS(9534),
    [sym_binary_number] = ACTIONS(9537),
    [sym_octal_number] = ACTIONS(9537),
    [sym_hex_number] = ACTIONS(9537),
    [aux_sym_real_number_token1] = ACTIONS(9540),
    [sym_fixed_point_number] = ACTIONS(9543),
    [sym_unsigned_number] = ACTIONS(9546),
    [anon_sym_SQUOTE0] = ACTIONS(9549),
    [anon_sym_SQUOTE1] = ACTIONS(9549),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(9549),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9552),
    [anon_sym_DOLLARroot] = ACTIONS(9555),
    [anon_sym_DOLLARunit] = ACTIONS(9558),
    [sym_system_tf_identifier] = ACTIONS(9561),
  },
  [2641] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3122),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2642] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9564),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2643] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8610),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3121),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2644] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(18527),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9566),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2645] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8692),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2669),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2669),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2646] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9234),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2674),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2674),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2647] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9347),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2677),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2677),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2648] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8615),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3131),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3131),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2649] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9322),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2678),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2678),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2650] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9244),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2679),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2679),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2651] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9339),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2680),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2680),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2652] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3130),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2653] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9372),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2681),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2681),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2654] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2353),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2655] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8617),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3171),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3171),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2656] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3134),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2657] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_covergroup_value_range] = STATE(12281),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8900),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2658] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3068),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2659] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(18784),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9570),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2660] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9374),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2683),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2683),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2661] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9203),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(2685),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2685),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2662] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3182),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2663] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9277),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2664] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9288),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2665] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3216),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3216),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2666] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9293),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2667] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8625),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3251),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2668] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8552),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3265),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3265),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2669] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8717),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2670] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8564),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3292),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3292),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2671] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2672] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8573),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2833),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2833),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2673] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3146),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2674] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9309),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2675] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9572),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2676] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8614),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2928),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2928),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2677] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9310),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2678] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9313),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2679] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9315),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2680] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9356),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2681] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9365),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2682] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8546),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2929),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2929),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2683] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9169),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2684] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9574),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2685] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9174),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2686] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3158),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2687] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3166),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2688] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4683),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2689] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4706),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2690] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4725),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2691] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4773),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2692] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(18347),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9578),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2693] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9312),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2867),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2867),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2694] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4832),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2695] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4912),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2696] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(5016),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2697] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(5190),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2698] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9582),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2699] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2700] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9412),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2719),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2719),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2701] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1143),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2702] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9414),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2723),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2723),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2703] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9421),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2724),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2724),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2704] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9431),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2725),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2725),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2705] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9438),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2732),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2732),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2706] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9482),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2734),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2734),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2707] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9586),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2708] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9490),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2749),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2749),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2709] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9501),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2750),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2750),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2710] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9507),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2751),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2751),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2711] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9515),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2752),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2752),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2712] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9517),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2753),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2753),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2713] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9527),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(2758),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2758),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2714] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9314),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2868),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2868),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2715] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7208),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2716] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7211),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2717] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7212),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2718] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7213),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2719] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9397),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2720] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9423),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16282),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9612),
    [anon_sym_COMMA] = ACTIONS(8524),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2721] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8570),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2933),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2933),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2722] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20381),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2723] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9399),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2724] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9401),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2725] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9494),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2726] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2379),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2727] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3064),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2728] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2747),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2747),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9614),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2729] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8629),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2955),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2955),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2730] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7005),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2763),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2763),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2731] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7006),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2765),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2765),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2732] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9402),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2733] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7007),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2766),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2766),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2734] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9404),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2735] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7008),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2768),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2768),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2736] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7009),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2769),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2769),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2737] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7012),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2770),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2770),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2738] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7013),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2772),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2772),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2739] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7014),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2773),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2773),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2740] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7015),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2774),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2774),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2741] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2578),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2742] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7016),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2775),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2775),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2743] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7018),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2776),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2776),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2744] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7020),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(2777),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2777),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2745] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19841),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2746] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2747] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9618),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2748] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(20185),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9620),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2749] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9405),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2750] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9406),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2751] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9407),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2752] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9419),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2753] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9434),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2754] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3072),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2755] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2594),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2756] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3074),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2757] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(17527),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9622),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2758] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9439),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(9584),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [2759] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9072),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2760] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9087),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2761] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9102),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2762] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9074),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2763] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6949),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2764] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3078),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2765] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6964),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2766] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6971),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2767] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3080),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2768] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6972),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2769] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6975),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2770] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7086),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2771] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9626),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2772] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6920),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2773] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6999),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2774] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7002),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2775] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7071),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2776] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7078),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2777] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6922),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(9616),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [2778] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8973),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2779] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9048),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2780] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9081),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2781] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8962),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2782] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9319),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2872),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2872),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2783] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3086),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2784] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3088),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2785] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(8530),
    [anon_sym_SEMI] = ACTIONS(9628),
    [anon_sym_POUND] = ACTIONS(8536),
    [anon_sym_type] = ACTIONS(8539),
    [anon_sym_LBRACE] = ACTIONS(8542),
    [anon_sym_disable] = ACTIONS(9631),
    [anon_sym_local] = ACTIONS(8548),
    [anon_sym_super] = ACTIONS(8551),
    [anon_sym_if] = ACTIONS(9634),
    [anon_sym_foreach] = ACTIONS(9637),
    [anon_sym_unique] = ACTIONS(8560),
    [anon_sym_byte] = ACTIONS(8563),
    [anon_sym_shortint] = ACTIONS(8563),
    [anon_sym_int] = ACTIONS(8563),
    [anon_sym_longint] = ACTIONS(8563),
    [anon_sym_integer] = ACTIONS(8563),
    [anon_sym_time] = ACTIONS(8563),
    [anon_sym_PLUS_PLUS] = ACTIONS(8568),
    [anon_sym_assert] = ACTIONS(9640),
    [anon_sym_assume] = ACTIONS(9643),
    [anon_sym_cover] = ACTIONS(9646),
    [anon_sym_expect] = ACTIONS(9649),
    [anon_sym_restrict] = ACTIONS(9652),
    [anon_sym_case] = ACTIONS(8586),
    [anon_sym_POUND_POUND] = ACTIONS(8589),
    [anon_sym_begin] = ACTIONS(9655),
    [anon_sym_end] = ACTIONS(8566),
    [anon_sym_for] = ACTIONS(9658),
    [anon_sym_assign] = ACTIONS(8598),
    [anon_sym_deassign] = ACTIONS(8601),
    [anon_sym_force] = ACTIONS(8604),
    [anon_sym_release] = ACTIONS(8607),
    [anon_sym_fork] = ACTIONS(9661),
    [anon_sym_repeat] = ACTIONS(9664),
    [anon_sym_AT] = ACTIONS(8616),
    [anon_sym_AT_STAR] = ACTIONS(8619),
    [anon_sym_return] = ACTIONS(9667),
    [anon_sym_break] = ACTIONS(9670),
    [anon_sym_continue] = ACTIONS(9670),
    [anon_sym_wait] = ACTIONS(9673),
    [anon_sym_wait_order] = ACTIONS(9676),
    [anon_sym_DASH_GT] = ACTIONS(9679),
    [anon_sym_DASH_GT_GT] = ACTIONS(9682),
    [anon_sym_unique0] = ACTIONS(8560),
    [anon_sym_priority] = ACTIONS(8560),
    [anon_sym_casez] = ACTIONS(8586),
    [anon_sym_casex] = ACTIONS(8586),
    [anon_sym_randcase] = ACTIONS(9685),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(8643),
    [anon_sym_forever] = ACTIONS(9688),
    [anon_sym_while] = ACTIONS(9664),
    [anon_sym_do] = ACTIONS(9691),
    [anon_sym_this] = ACTIONS(8652),
    [anon_sym_DASH_DASH] = ACTIONS(8568),
    [anon_sym_LPAREN_STAR] = ACTIONS(8655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(8658),
    [anon_sym_DOLLARroot] = ACTIONS(8661),
    [anon_sym_DOLLARunit] = ACTIONS(8664),
    [sym_system_tf_identifier] = ACTIONS(8667),
  },
  [2786] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9436),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16546),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7247),
    [anon_sym_COMMA] = ACTIONS(7249),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2787] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9321),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2873),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2873),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2788] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9324),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2875),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2875),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2789] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8795),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2842),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2842),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2790] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9694),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2791] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3090),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2792] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8796),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2843),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2843),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2793] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8797),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2844),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2844),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2794] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2845),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2845),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2795] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8798),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2850),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2850),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2796] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8799),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2851),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2851),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2797] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9696),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2798] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8800),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2852),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2852),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2799] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8801),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2853),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2853),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2800] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8802),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2854),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2854),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2801] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8804),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2855),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2855),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2802] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8805),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2859),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2859),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2803] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8806),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(2860),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2860),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2804] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17799),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2805] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7182),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2806] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7082),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2807] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7085),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2808] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6921),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2809] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7004),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2810] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9563),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15121),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7225),
    [anon_sym_COMMA] = ACTIONS(7227),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2811] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19718),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20381),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2812] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9325),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2877),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2877),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2813] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9328),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2879),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2879),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2814] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9330),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2887),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2887),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2815] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2355),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2816] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3102),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2817] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2831),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2831),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9698),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2818] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4899),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2819] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4902),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2820] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4903),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2821] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4904),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2822] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1145),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2823] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(18943),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9744),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2824] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2596),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2825] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6796),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2826] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6806),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2827] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6809),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2828] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2357),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2829] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6869),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2830] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3104),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2831] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9770),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2832] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(19079),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9772),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2833] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8640),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2834] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3128),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2835] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2870),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2870),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9774),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2836] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9298),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2841),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2841),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2837] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3106),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2838] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2361),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2839] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3108),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2840] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(19282),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9776),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2841] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9165),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2842] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8816),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2843] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8817),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2844] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8818),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2845] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2846] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3110),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2847] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2848] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_value_range] = STATE(16344),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9695),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(8986),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2849] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9778),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2850] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8819),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2851] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8820),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2852] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8821),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2853] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8822),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2854] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8811),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2855] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8749),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2856] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2857] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6739),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2858] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3118),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2859] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8809),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2860] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8776),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2861] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9180),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2862] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9187),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2863] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9354),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2864] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9780),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2865] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2866] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2600),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2867] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9193),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2868] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9196),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2869] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3154),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2870] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9782),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2871] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9784),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2872] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9199),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2873] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9216),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2874] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3062),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2875] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9220),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2876] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2369),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2877] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9222),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2878] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(20107),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9786),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2879] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9245),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2880] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4650),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2881] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4657),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2882] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4659),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2883] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4662),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4735),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9576),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2884] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9391),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(15584),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7229),
    [anon_sym_COMMA] = ACTIONS(7231),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2885] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6867),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2886] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(18324),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2887] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9249),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2888] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9301),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2861),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2861),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2889] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9306),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2862),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2862),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [2890] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2367),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2891] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3126),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2892] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2897),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2897),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9788),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2893] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3058),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2894] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6525),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2895] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2371),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2896] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3132),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2897] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9834),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2898] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6526),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2899] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6795),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2900] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(18051),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9836),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2901] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6528),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2902] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2590),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2903] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3056),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2904] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2905] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2906] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3138),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2907] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(19481),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9838),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2908] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2347),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2909] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9840),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2910] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1034),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2911] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1037),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2912] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1038),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2913] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1039),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2914] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2915] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3142),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2916] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9844),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2917] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1046),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2918] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1047),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2919] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1049),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2920] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6870),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2921] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9846),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2922] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3060),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2923] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3150),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2924] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2925] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1055),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2926] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_trans_list] = STATE(17225),
    [sym__set_covergroup_expression] = STATE(17225),
    [sym__covergroup_expression] = STATE(17225),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7442),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9459),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(9848),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2927] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_clocking_event] = STATE(17791),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9850),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_AT] = ACTIONS(9568),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2928] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8656),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2929] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8549),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2930] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9852),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2931] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2932] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6533),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2933] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8555),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2934] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6549),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2935] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1099),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2936] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9854),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2937] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6562),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2938] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6569),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2939] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3070),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2940] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2684),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2684),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9856),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2941] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3076),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2942] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6574),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2943] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9858),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2944] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9147),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2945] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8978),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2946] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9026),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2947] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9041),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9006),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9624),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2948] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_constant_expression] = STATE(10135),
    [sym_constant_mintypmax_expression] = STATE(19430),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(20077),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5361),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7486),
    [sym_package_scope] = STATE(12179),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2949] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3160),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2950] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2952),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2952),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9860),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2951] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3162),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2952] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9862),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2953] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1099),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2954] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3164),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2955] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8556),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2956] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9864),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2957] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4899),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2958] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4902),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2959] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4903),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2960] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4904),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2961] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3168),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2962] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2964),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2964),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9868),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2963] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3170),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2964] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2640),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_randcase_statement_repeat1] = STATE(2640),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_endcase] = ACTIONS(9870),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2965] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9639),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2966] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(3172),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2967] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(2785),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_task_body_declaration_repeat1] = STATE(2785),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_end] = ACTIONS(9872),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2968] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6281),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2969] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6282),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2970] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6283),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2971] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6284),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2972] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4912),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2973] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(5016),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2974] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7208),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2975] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7211),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2976] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7212),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2977] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7213),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2978] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9429),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3027),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3027),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2979] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9430),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3028),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3028),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2980] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7082),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2981] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7085),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2982] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6921),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2983] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7004),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2984] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8692),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3029),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3029),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2985] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9433),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3054),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3054),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2986] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4650),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2987] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4657),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2988] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4659),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2989] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4662),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2990] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9435),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3079),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3079),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [2991] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3082),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2992] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9147),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2993] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(8978),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2994] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9026),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2995] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_action_block] = STATE(9041),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9071),
    [sym_statement] = STATE(9110),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_else] = ACTIONS(9367),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2996] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9477),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_list_of_arguments_parent_repeat1] = STATE(16445),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(7251),
    [anon_sym_COMMA] = ACTIONS(7253),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2997] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3084),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2998] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1143),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [2999] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9437),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3080),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3080),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3000] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9442),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3093),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3093),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3001] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9443),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3097),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3097),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3002] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9444),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3098),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3098),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3003] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9446),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3101),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3101),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3004] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9454),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3103),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3103),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3005] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9880),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3006] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3007] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17447),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9882),
    [anon_sym_COMMA] = ACTIONS(9885),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3008] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9229),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(2863),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(2863),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(9580),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [3009] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9848),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3016),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3016),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3010] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8079),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3085),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3085),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3011] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8083),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3086),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3086),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3012] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8086),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3087),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3013] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9887),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3014] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3088),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3088),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3015] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8089),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3089),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3089),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3016] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9863),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3017] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1145),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3018] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym__port_expression] = STATE(17802),
    [sym_port_reference] = STATE(17802),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9901),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7731),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9889),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(9891),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3019] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8093),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3090),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3090),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3020] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8095),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3091),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3091),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3021] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8096),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3092),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3092),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3022] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8097),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3094),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3094),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3023] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8101),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3095),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3095),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3024] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8102),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3099),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3099),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3025] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9483),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3026] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8104),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3100),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3100),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3027] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9484),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3028] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9491),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3029] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8717),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3030] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5617),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3042),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3042),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3031] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5618),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3043),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3043),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3032] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5619),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3044),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3044),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3033] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5657),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3045),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3045),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3034] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5620),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3046),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3046),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3035] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5621),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3047),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3047),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3036] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5622),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3048),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3048),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3037] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5623),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3049),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3049),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3038] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5671),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3050),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3050),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3039] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5625),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3051),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3051),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3040] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5627),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3052),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3052),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3041] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5628),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3053),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3053),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3042] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5629),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3043] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5630),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3044] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5631),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3045] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5642),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3046] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5632),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3047] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5633),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3048] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5634),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3049] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5635),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3050] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5636),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3051] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5637),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3052] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5638),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3053] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5639),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3054] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9495),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3055] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8837),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3067),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3067),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3056] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8839),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3068),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3068),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3057] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8845),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3069),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3069),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3058] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3070),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3070),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3059] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8848),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3071),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3071),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3060] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8853),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3072),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3072),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3061] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8865),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3073),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3073),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3062] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8868),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3074),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3074),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3063] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8869),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3075),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3075),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3064] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8876),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3076),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3076),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3065] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8877),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3077),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3077),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3066] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8878),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3078),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3078),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3067] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8879),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3068] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8932),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3069] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8884),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3070] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3071] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8885),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3072] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8886),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3073] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8887),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3074] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8889),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3075] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8890),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3076] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8891),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3077] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8892),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3078] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8893),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3079] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9496),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3080] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9497),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3081] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9897),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3082] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2351),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3083] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1173),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1065),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9842),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3084] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9898),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3096),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3096),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3085] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8048),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3086] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8049),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3087] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8052),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3088] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3089] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8054),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3090] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8055),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3091] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8056),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3092] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8057),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3093] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9498),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3094] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8058),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3095] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8059),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3096] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9912),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3097] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9502),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3098] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9504),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3099] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8060),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3100] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8061),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3101] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9505),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3102] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9872),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3103] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9506),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3104] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3105] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6976),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3106] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6982),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3107] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9927),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3111),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3111),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3108] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6714),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3109] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7077),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(7084),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9411),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3110] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6718),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3111] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9942),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3112] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_covergroup_value_range] = STATE(12281),
    [sym__covergroup_expression] = STATE(12334),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7237),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3113] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3174),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3114] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6719),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3115] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6720),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6786),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9748),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3116] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4661),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3117] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4664),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3118] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4672),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3119] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1034),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3120] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6281),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3121] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8566),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3122] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4726),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3123] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6282),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3124] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6283),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3125] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9961),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3127),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3127),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3126] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6284),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6521),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9796),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3127] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9972),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3128] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6796),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3129] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6806),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3130] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6809),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3131] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8580),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3132] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6869),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3133] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4877),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3134] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6739),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3135] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6867),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3136] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10004),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3138),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3138),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3137] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6795),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3138] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10019),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3139] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6870),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3140] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6714),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3141] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6718),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3142] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6719),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3143] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5029),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3144] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_action_block] = STATE(6720),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6785),
    [sym_statement] = STATE(6776),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_else] = ACTIONS(9899),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3145] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10137),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3147),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3147),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3146] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4661),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3147] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10138),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3148] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4664),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3149] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4672),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3150] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4726),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3151] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5140),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3152] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10043),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3154),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3154),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3153] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(4877),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3154] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10052),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3155] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5029),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3156] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5140),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3157] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5192),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4628),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9706),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3158] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_action_block] = STATE(5192),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4608),
    [sym_statement] = STATE(4743),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_else] = ACTIONS(9866),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3159] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10058),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3161),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3161),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3160] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1037),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3161] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10068),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3162] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7301),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3163] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7303),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3164] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7305),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3165] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10075),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3167),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3167),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3166] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7310),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3167] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10081),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3168] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7346),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3169] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7237),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3170] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7354),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3171] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8598),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3172] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7182),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7330),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9876),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3173] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6525),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3174] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6526),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3175] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6528),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3176] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6533),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3177] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6549),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3178] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6562),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3179] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6569),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3180] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_action_block] = STATE(6574),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6520),
    [sym_statement] = STATE(6314),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_else] = ACTIONS(9874),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3181] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9253),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3193),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3193),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3182] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9260),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3194),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3194),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3183] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9268),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3195),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3195),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3184] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8692),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3196),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3196),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3185] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9275),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3197),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3197),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3186] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9279),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3198),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3198),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3187] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9286),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3202),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3202),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3188] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9291),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3212),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3212),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3189] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9333),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3218),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3218),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3190] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9340),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3219),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3219),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3191] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9344),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3220),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3220),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3192] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9349),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3222),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3222),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3193] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9358),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3194] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9360),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3195] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9361),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3196] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(8717),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3197] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9362),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3198] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9363),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3199] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5677),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3228),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3228),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3200] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10116),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3211),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3211),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3201] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5678),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3230),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3230),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3202] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9357),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3203] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5679),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3232),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3204] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5657),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3233),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3233),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3205] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5680),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3234),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3234),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3206] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2576),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3207] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5681),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3236),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3236),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3208] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5682),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3238),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3238),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3209] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5683),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3240),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3240),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3210] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5684),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3241),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3241),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3211] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10124),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3212] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9373),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3213] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5685),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3243),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3214] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5686),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3244),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3244),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3215] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5672),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(3245),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3216] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3217] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2582),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3218] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9256),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3219] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9224),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3220] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9327),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3221] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3054),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3222] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9302),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3223] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(2592),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3224] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6976),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3225] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6982),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3226] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7077),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3227] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3178),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3228] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5690),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3229] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3230] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5691),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3231] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6985),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3232] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5692),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3233] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5642),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3234] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5693),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3235] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6968),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3236] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5694),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3237] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(7049),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3238] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5695),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3239] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3240] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5696),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3241] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5697),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3242] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3186),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3243] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5698),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3244] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5699),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3245] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5700),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(9893),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3246] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6924),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3247] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_action_block] = STATE(6958),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7083),
    [sym_statement] = STATE(6952),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_else] = ACTIONS(9878),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3248] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_action_block] = STATE(1038),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1035),
    [sym_statement] = STATE(1036),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_else] = ACTIONS(9279),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3249] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9905),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3250] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(3188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3251] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8616),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3252] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4683),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3253] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4706),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3254] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4725),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3255] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(2087),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_task_body_declaration_repeat1] = STATE(2087),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_endtask] = ACTIONS(9907),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3256] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4773),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3257] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10143),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3258),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3258] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10144),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3259] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10159),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3260),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3260] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10160),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3261] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7301),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3262] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7303),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3263] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7305),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3264] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_action_block] = STATE(4832),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4651),
    [sym_statement] = STATE(4752),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_else] = ACTIONS(9323),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3265] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8620),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3266] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7310),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3267] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9009),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3279),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3279),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3268] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9010),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3280),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3280),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3269] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9011),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3281),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3281),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3270] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7395),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3282),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3282),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3271] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9013),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3283),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3272] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9014),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3284),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3273] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9015),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3285),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3285),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3274] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9017),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3286),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3286),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3275] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9019),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3287),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3287),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3276] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9020),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3288),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3288),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3277] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9022),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3289),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3289),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3278] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9023),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3290),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3290),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3279] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9028),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3280] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9029),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3281] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9030),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3282] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(7374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3283] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9031),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3284] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9032),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3285] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9033),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3286] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9034),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3287] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9035),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3288] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9036),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3289] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9037),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3290] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9038),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3291] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_open_value_range] = STATE(16344),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9571),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_value_range] = STATE(15120),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_LBRACK] = ACTIONS(7791),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3292] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8623),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3293] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7346),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3294] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7237),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3295] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_action_block] = STATE(7354),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7294),
    [sym_statement] = STATE(7295),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_else] = ACTIONS(9590),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3296] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10370),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(3297),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3297),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3297] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10375),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(7033),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3298] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9427),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(3025),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(3025),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(9455),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3299] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_let_actual_arg] = STATE(20234),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10191),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9909),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3300] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__set_covergroup_expression] = STATE(16891),
    [sym__covergroup_expression] = STATE(16891),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7468),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(9911),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3301] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(20437),
    [sym__covergroup_expression] = STATE(20437),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3302] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7123),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_COLON] = ACTIONS(9913),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3303] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__covergroup_expression] = STATE(19315),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(9937),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3304] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17447),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9939),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3305] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(17601),
    [sym__covergroup_expression] = STATE(17601),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3306] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_condition] = STATE(18039),
    [sym_scalar_timing_check_condition] = STATE(20411),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10151),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9941),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(8960),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3307] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_stream_expression] = STATE(16002),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_constant_expression] = STATE(9621),
    [sym_expression] = STATE(9521),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(9258),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8827),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5321),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7415),
    [sym_package_scope] = STATE(12237),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(9943),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3308] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_condition] = STATE(20408),
    [sym_scalar_timing_check_condition] = STATE(20411),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10151),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9941),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(8960),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3309] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(20042),
    [sym__covergroup_expression] = STATE(20042),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3310] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_list_of_actual_arguments] = STATE(17677),
    [sym__actual_argument] = STATE(15677),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9583),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3311] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5674),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3331),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_RPAREN] = ACTIONS(9945),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3312] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_repeat_range] = STATE(17899),
    [sym__covergroup_expression] = STATE(16723),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9636),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3313] = {
    [sym_simple_identifier] = ACTIONS(9947),
    [anon_sym_wire] = ACTIONS(9947),
    [anon_sym_tri] = ACTIONS(9947),
    [anon_sym_tri0] = ACTIONS(9947),
    [anon_sym_tri1] = ACTIONS(9947),
    [anon_sym_wand] = ACTIONS(9947),
    [anon_sym_triand] = ACTIONS(9947),
    [anon_sym_wor] = ACTIONS(9947),
    [anon_sym_trior] = ACTIONS(9947),
    [anon_sym_trireg] = ACTIONS(9947),
    [anon_sym_uwire] = ACTIONS(9947),
    [anon_sym_SEMI] = ACTIONS(9949),
    [anon_sym_extern] = ACTIONS(9947),
    [anon_sym_module] = ACTIONS(9947),
    [anon_sym_macromodule] = ACTIONS(9947),
    [anon_sym_interface] = ACTIONS(9947),
    [anon_sym_program] = ACTIONS(9947),
    [anon_sym_checker] = ACTIONS(9947),
    [anon_sym_virtual] = ACTIONS(9947),
    [anon_sym_class] = ACTIONS(9947),
    [anon_sym_type] = ACTIONS(9947),
    [anon_sym_input] = ACTIONS(9947),
    [anon_sym_output] = ACTIONS(9947),
    [anon_sym_inout] = ACTIONS(9947),
    [anon_sym_ref] = ACTIONS(9947),
    [anon_sym_DOLLARfatal] = ACTIONS(9949),
    [anon_sym_DOLLARerror] = ACTIONS(9949),
    [anon_sym_DOLLARwarning] = ACTIONS(9949),
    [anon_sym_DOLLARinfo] = ACTIONS(9949),
    [anon_sym_default] = ACTIONS(9947),
    [anon_sym_clocking] = ACTIONS(9947),
    [anon_sym_defparam] = ACTIONS(9947),
    [anon_sym_bind] = ACTIONS(9947),
    [anon_sym_const] = ACTIONS(9947),
    [anon_sym_function] = ACTIONS(9947),
    [anon_sym_static] = ACTIONS(9947),
    [anon_sym_constraint] = ACTIONS(9947),
    [anon_sym_if] = ACTIONS(9947),
    [anon_sym_LBRACK] = ACTIONS(9949),
    [anon_sym_localparam] = ACTIONS(9947),
    [anon_sym_parameter] = ACTIONS(9947),
    [anon_sym_specparam] = ACTIONS(9947),
    [anon_sym_var] = ACTIONS(9947),
    [anon_sym_import] = ACTIONS(9947),
    [anon_sym_export] = ACTIONS(9947),
    [anon_sym_genvar] = ACTIONS(9947),
    [anon_sym_interconnect] = ACTIONS(9947),
    [anon_sym_typedef] = ACTIONS(9947),
    [anon_sym_enum] = ACTIONS(9947),
    [anon_sym_struct] = ACTIONS(9947),
    [anon_sym_union] = ACTIONS(9947),
    [anon_sym_nettype] = ACTIONS(9947),
    [anon_sym_automatic] = ACTIONS(9947),
    [anon_sym_string] = ACTIONS(9947),
    [anon_sym_chandle] = ACTIONS(9947),
    [anon_sym_event] = ACTIONS(9947),
    [anon_sym_byte] = ACTIONS(9947),
    [anon_sym_shortint] = ACTIONS(9947),
    [anon_sym_int] = ACTIONS(9947),
    [anon_sym_longint] = ACTIONS(9947),
    [anon_sym_integer] = ACTIONS(9947),
    [anon_sym_time] = ACTIONS(9947),
    [anon_sym_bit] = ACTIONS(9947),
    [anon_sym_logic] = ACTIONS(9947),
    [anon_sym_reg] = ACTIONS(9947),
    [anon_sym_shortreal] = ACTIONS(9947),
    [anon_sym_real] = ACTIONS(9947),
    [anon_sym_realtime] = ACTIONS(9947),
    [anon_sym_supply0] = ACTIONS(9947),
    [anon_sym_supply1] = ACTIONS(9947),
    [anon_sym_signed] = ACTIONS(9947),
    [anon_sym_unsigned] = ACTIONS(9947),
    [anon_sym_task] = ACTIONS(9947),
    [anon_sym_PLUS_PLUS] = ACTIONS(9949),
    [anon_sym_assert] = ACTIONS(9947),
    [anon_sym_property] = ACTIONS(9947),
    [anon_sym_assume] = ACTIONS(9947),
    [anon_sym_cover] = ACTIONS(9947),
    [anon_sym_sequence] = ACTIONS(9947),
    [anon_sym_restrict] = ACTIONS(9947),
    [anon_sym_not] = ACTIONS(9947),
    [anon_sym_or] = ACTIONS(9947),
    [anon_sym_and] = ACTIONS(9947),
    [anon_sym_case] = ACTIONS(9947),
    [anon_sym_always] = ACTIONS(9947),
    [anon_sym_covergroup] = ACTIONS(9947),
    [anon_sym_let] = ACTIONS(9947),
    [anon_sym_pulldown] = ACTIONS(9947),
    [anon_sym_pullup] = ACTIONS(9947),
    [anon_sym_cmos] = ACTIONS(9947),
    [anon_sym_rcmos] = ACTIONS(9947),
    [anon_sym_bufif0] = ACTIONS(9947),
    [anon_sym_bufif1] = ACTIONS(9947),
    [anon_sym_notif0] = ACTIONS(9947),
    [anon_sym_notif1] = ACTIONS(9947),
    [anon_sym_nmos] = ACTIONS(9947),
    [anon_sym_pmos] = ACTIONS(9947),
    [anon_sym_rnmos] = ACTIONS(9947),
    [anon_sym_rpmos] = ACTIONS(9947),
    [anon_sym_nand] = ACTIONS(9947),
    [anon_sym_nor] = ACTIONS(9947),
    [anon_sym_xor] = ACTIONS(9947),
    [anon_sym_xnor] = ACTIONS(9947),
    [anon_sym_buf] = ACTIONS(9947),
    [anon_sym_tranif0] = ACTIONS(9947),
    [anon_sym_tranif1] = ACTIONS(9947),
    [anon_sym_rtranif1] = ACTIONS(9947),
    [anon_sym_rtranif0] = ACTIONS(9947),
    [anon_sym_tran] = ACTIONS(9947),
    [anon_sym_rtran] = ACTIONS(9947),
    [anon_sym_for] = ACTIONS(9947),
    [anon_sym_initial] = ACTIONS(9947),
    [anon_sym_assign] = ACTIONS(9947),
    [anon_sym_alias] = ACTIONS(9947),
    [anon_sym_always_comb] = ACTIONS(9947),
    [anon_sym_always_latch] = ACTIONS(9947),
    [anon_sym_always_ff] = ACTIONS(9947),
    [anon_sym_final] = ACTIONS(9947),
    [anon_sym_global] = ACTIONS(9947),
    [anon_sym_DASH_DASH] = ACTIONS(9949),
    [anon_sym_LPAREN_STAR] = ACTIONS(9949),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9949),
    [anon_sym_DOLLARunit] = ACTIONS(9949),
  },
  [3314] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_cycle_delay] = STATE(4160),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9839),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_POUND_POUND] = ACTIONS(9951),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3315] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(17904),
    [sym__covergroup_expression] = STATE(17904),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3316] = {
    [sym_simple_identifier] = ACTIONS(9953),
    [anon_sym_wire] = ACTIONS(9953),
    [anon_sym_tri] = ACTIONS(9953),
    [anon_sym_tri0] = ACTIONS(9953),
    [anon_sym_tri1] = ACTIONS(9953),
    [anon_sym_wand] = ACTIONS(9953),
    [anon_sym_triand] = ACTIONS(9953),
    [anon_sym_wor] = ACTIONS(9953),
    [anon_sym_trior] = ACTIONS(9953),
    [anon_sym_trireg] = ACTIONS(9953),
    [anon_sym_uwire] = ACTIONS(9953),
    [anon_sym_SEMI] = ACTIONS(9955),
    [anon_sym_extern] = ACTIONS(9953),
    [anon_sym_module] = ACTIONS(9953),
    [anon_sym_macromodule] = ACTIONS(9953),
    [anon_sym_interface] = ACTIONS(9953),
    [anon_sym_program] = ACTIONS(9953),
    [anon_sym_checker] = ACTIONS(9953),
    [anon_sym_virtual] = ACTIONS(9953),
    [anon_sym_class] = ACTIONS(9953),
    [anon_sym_type] = ACTIONS(9953),
    [anon_sym_input] = ACTIONS(9953),
    [anon_sym_output] = ACTIONS(9953),
    [anon_sym_inout] = ACTIONS(9953),
    [anon_sym_ref] = ACTIONS(9953),
    [anon_sym_DOLLARfatal] = ACTIONS(9955),
    [anon_sym_DOLLARerror] = ACTIONS(9955),
    [anon_sym_DOLLARwarning] = ACTIONS(9955),
    [anon_sym_DOLLARinfo] = ACTIONS(9955),
    [anon_sym_default] = ACTIONS(9953),
    [anon_sym_clocking] = ACTIONS(9953),
    [anon_sym_defparam] = ACTIONS(9953),
    [anon_sym_bind] = ACTIONS(9953),
    [anon_sym_const] = ACTIONS(9953),
    [anon_sym_function] = ACTIONS(9953),
    [anon_sym_static] = ACTIONS(9953),
    [anon_sym_constraint] = ACTIONS(9953),
    [anon_sym_if] = ACTIONS(9953),
    [anon_sym_LBRACK] = ACTIONS(9955),
    [anon_sym_localparam] = ACTIONS(9953),
    [anon_sym_parameter] = ACTIONS(9953),
    [anon_sym_specparam] = ACTIONS(9953),
    [anon_sym_var] = ACTIONS(9953),
    [anon_sym_import] = ACTIONS(9953),
    [anon_sym_export] = ACTIONS(9953),
    [anon_sym_genvar] = ACTIONS(9953),
    [anon_sym_interconnect] = ACTIONS(9953),
    [anon_sym_typedef] = ACTIONS(9953),
    [anon_sym_enum] = ACTIONS(9953),
    [anon_sym_struct] = ACTIONS(9953),
    [anon_sym_union] = ACTIONS(9953),
    [anon_sym_nettype] = ACTIONS(9953),
    [anon_sym_automatic] = ACTIONS(9953),
    [anon_sym_string] = ACTIONS(9953),
    [anon_sym_chandle] = ACTIONS(9953),
    [anon_sym_event] = ACTIONS(9953),
    [anon_sym_byte] = ACTIONS(9953),
    [anon_sym_shortint] = ACTIONS(9953),
    [anon_sym_int] = ACTIONS(9953),
    [anon_sym_longint] = ACTIONS(9953),
    [anon_sym_integer] = ACTIONS(9953),
    [anon_sym_time] = ACTIONS(9953),
    [anon_sym_bit] = ACTIONS(9953),
    [anon_sym_logic] = ACTIONS(9953),
    [anon_sym_reg] = ACTIONS(9953),
    [anon_sym_shortreal] = ACTIONS(9953),
    [anon_sym_real] = ACTIONS(9953),
    [anon_sym_realtime] = ACTIONS(9953),
    [anon_sym_supply0] = ACTIONS(9953),
    [anon_sym_supply1] = ACTIONS(9953),
    [anon_sym_signed] = ACTIONS(9953),
    [anon_sym_unsigned] = ACTIONS(9953),
    [anon_sym_task] = ACTIONS(9953),
    [anon_sym_PLUS_PLUS] = ACTIONS(9955),
    [anon_sym_assert] = ACTIONS(9953),
    [anon_sym_property] = ACTIONS(9953),
    [anon_sym_assume] = ACTIONS(9953),
    [anon_sym_cover] = ACTIONS(9953),
    [anon_sym_sequence] = ACTIONS(9953),
    [anon_sym_restrict] = ACTIONS(9953),
    [anon_sym_not] = ACTIONS(9953),
    [anon_sym_or] = ACTIONS(9953),
    [anon_sym_and] = ACTIONS(9953),
    [anon_sym_case] = ACTIONS(9953),
    [anon_sym_always] = ACTIONS(9953),
    [anon_sym_covergroup] = ACTIONS(9953),
    [anon_sym_let] = ACTIONS(9953),
    [anon_sym_pulldown] = ACTIONS(9953),
    [anon_sym_pullup] = ACTIONS(9953),
    [anon_sym_cmos] = ACTIONS(9953),
    [anon_sym_rcmos] = ACTIONS(9953),
    [anon_sym_bufif0] = ACTIONS(9953),
    [anon_sym_bufif1] = ACTIONS(9953),
    [anon_sym_notif0] = ACTIONS(9953),
    [anon_sym_notif1] = ACTIONS(9953),
    [anon_sym_nmos] = ACTIONS(9953),
    [anon_sym_pmos] = ACTIONS(9953),
    [anon_sym_rnmos] = ACTIONS(9953),
    [anon_sym_rpmos] = ACTIONS(9953),
    [anon_sym_nand] = ACTIONS(9953),
    [anon_sym_nor] = ACTIONS(9953),
    [anon_sym_xor] = ACTIONS(9953),
    [anon_sym_xnor] = ACTIONS(9953),
    [anon_sym_buf] = ACTIONS(9953),
    [anon_sym_tranif0] = ACTIONS(9953),
    [anon_sym_tranif1] = ACTIONS(9953),
    [anon_sym_rtranif1] = ACTIONS(9953),
    [anon_sym_rtranif0] = ACTIONS(9953),
    [anon_sym_tran] = ACTIONS(9953),
    [anon_sym_rtran] = ACTIONS(9953),
    [anon_sym_for] = ACTIONS(9953),
    [anon_sym_initial] = ACTIONS(9953),
    [anon_sym_assign] = ACTIONS(9953),
    [anon_sym_alias] = ACTIONS(9953),
    [anon_sym_always_comb] = ACTIONS(9953),
    [anon_sym_always_latch] = ACTIONS(9953),
    [anon_sym_always_ff] = ACTIONS(9953),
    [anon_sym_final] = ACTIONS(9953),
    [anon_sym_global] = ACTIONS(9953),
    [anon_sym_DASH_DASH] = ACTIONS(9955),
    [anon_sym_LPAREN_STAR] = ACTIONS(9955),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9955),
    [anon_sym_DOLLARunit] = ACTIONS(9955),
  },
  [3317] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(19419),
    [sym__covergroup_expression] = STATE(19419),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3318] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_list_of_actual_arguments] = STATE(19703),
    [sym__actual_argument] = STATE(15677),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9583),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3319] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(12560),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_class_new] = STATE(16709),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9657),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_new] = ACTIONS(9957),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3320] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9278),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_COLON] = ACTIONS(9959),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3321] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_let_actual_arg] = STATE(19237),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10191),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(9983),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3322] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7105),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_COLON] = ACTIONS(9985),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3323] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_condition] = STATE(18109),
    [sym_scalar_timing_check_condition] = STATE(20411),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10151),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(9941),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(8960),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3324] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__covergroup_expression] = STATE(19560),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_RBRACK] = ACTIONS(9987),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3325] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(19515),
    [sym__covergroup_expression] = STATE(19515),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3326] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__with_covergroup_expression] = STATE(17692),
    [sym__covergroup_expression] = STATE(17692),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3327] = {
    [sym_local_parameter_declaration] = STATE(19407),
    [sym_parameter_declaration] = STATE(19407),
    [sym__any_parameter_declaration] = STATE(19407),
    [sym_data_declaration] = STATE(5428),
    [sym_package_import_declaration] = STATE(5400),
    [sym_type_declaration] = STATE(5400),
    [sym_net_type_declaration] = STATE(5400),
    [sym_lifetime] = STATE(8380),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12676),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(18100),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(3327),
    [sym_overload_declaration] = STATE(5428),
    [sym_let_declaration] = STATE(5428),
    [sym_attribute_instance] = STATE(6044),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(6044),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(3327),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(9989),
    [anon_sym_SEMI] = ACTIONS(9992),
    [anon_sym_virtual] = ACTIONS(9994),
    [anon_sym_POUND] = ACTIONS(9997),
    [anon_sym_type] = ACTIONS(9999),
    [anon_sym_LBRACE] = ACTIONS(9992),
    [anon_sym_disable] = ACTIONS(9997),
    [anon_sym_bind] = ACTIONS(10002),
    [anon_sym_const] = ACTIONS(10005),
    [anon_sym_static] = ACTIONS(10008),
    [anon_sym_local] = ACTIONS(9997),
    [anon_sym_super] = ACTIONS(9997),
    [anon_sym_endfunction] = ACTIONS(9997),
    [anon_sym_if] = ACTIONS(9997),
    [anon_sym_foreach] = ACTIONS(9997),
    [anon_sym_LBRACK] = ACTIONS(10011),
    [anon_sym_unique] = ACTIONS(9997),
    [anon_sym_localparam] = ACTIONS(10014),
    [anon_sym_parameter] = ACTIONS(10017),
    [anon_sym_var] = ACTIONS(10020),
    [anon_sym_import] = ACTIONS(10023),
    [anon_sym_typedef] = ACTIONS(10026),
    [anon_sym_enum] = ACTIONS(10029),
    [anon_sym_struct] = ACTIONS(10032),
    [anon_sym_union] = ACTIONS(10035),
    [anon_sym_nettype] = ACTIONS(10038),
    [anon_sym_automatic] = ACTIONS(10008),
    [anon_sym_string] = ACTIONS(10041),
    [anon_sym_chandle] = ACTIONS(10041),
    [anon_sym_event] = ACTIONS(10041),
    [anon_sym_byte] = ACTIONS(10044),
    [anon_sym_shortint] = ACTIONS(10044),
    [anon_sym_int] = ACTIONS(10044),
    [anon_sym_longint] = ACTIONS(10044),
    [anon_sym_integer] = ACTIONS(10044),
    [anon_sym_time] = ACTIONS(10044),
    [anon_sym_bit] = ACTIONS(10047),
    [anon_sym_logic] = ACTIONS(10047),
    [anon_sym_reg] = ACTIONS(10047),
    [anon_sym_shortreal] = ACTIONS(10050),
    [anon_sym_real] = ACTIONS(10050),
    [anon_sym_realtime] = ACTIONS(10050),
    [anon_sym_signed] = ACTIONS(10053),
    [anon_sym_unsigned] = ACTIONS(10053),
    [anon_sym_endtask] = ACTIONS(9997),
    [anon_sym_PLUS_PLUS] = ACTIONS(9992),
    [anon_sym_assert] = ACTIONS(9997),
    [anon_sym_assume] = ACTIONS(9997),
    [anon_sym_cover] = ACTIONS(9997),
    [anon_sym_expect] = ACTIONS(9997),
    [anon_sym_restrict] = ACTIONS(9997),
    [anon_sym_case] = ACTIONS(9997),
    [anon_sym_POUND_POUND] = ACTIONS(9992),
    [anon_sym_begin] = ACTIONS(9997),
    [anon_sym_let] = ACTIONS(10056),
    [anon_sym_for] = ACTIONS(9997),
    [anon_sym_assign] = ACTIONS(9997),
    [anon_sym_deassign] = ACTIONS(9997),
    [anon_sym_force] = ACTIONS(9997),
    [anon_sym_release] = ACTIONS(9997),
    [anon_sym_fork] = ACTIONS(9997),
    [anon_sym_join] = ACTIONS(9997),
    [anon_sym_join_any] = ACTIONS(9997),
    [anon_sym_join_none] = ACTIONS(9997),
    [anon_sym_repeat] = ACTIONS(9997),
    [anon_sym_AT] = ACTIONS(9997),
    [anon_sym_AT_STAR] = ACTIONS(9992),
    [anon_sym_return] = ACTIONS(9997),
    [anon_sym_break] = ACTIONS(9997),
    [anon_sym_continue] = ACTIONS(9997),
    [anon_sym_wait] = ACTIONS(9997),
    [anon_sym_wait_order] = ACTIONS(9997),
    [anon_sym_DASH_GT] = ACTIONS(9997),
    [anon_sym_DASH_GT_GT] = ACTIONS(9992),
    [anon_sym_unique0] = ACTIONS(9997),
    [anon_sym_priority] = ACTIONS(9997),
    [anon_sym_casez] = ACTIONS(9997),
    [anon_sym_casex] = ACTIONS(9997),
    [anon_sym_randcase] = ACTIONS(9997),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9992),
    [anon_sym_forever] = ACTIONS(9997),
    [anon_sym_while] = ACTIONS(9997),
    [anon_sym_do] = ACTIONS(9997),
    [anon_sym_this] = ACTIONS(9997),
    [anon_sym_DASH_DASH] = ACTIONS(9992),
    [anon_sym_LPAREN_STAR] = ACTIONS(10059),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(10062),
    [anon_sym_DOLLARroot] = ACTIONS(9997),
    [anon_sym_DOLLARunit] = ACTIONS(10065),
    [sym_system_tf_identifier] = ACTIONS(9997),
  },
  [3328] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_end_edge_offset] = STATE(17304),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17307),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3329] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5674),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3331),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_RPAREN] = ACTIONS(10068),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3330] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym__integer_covergroup_expression] = STATE(12855),
    [sym__covergroup_expression] = STATE(12855),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9255),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3331] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(17391),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10070),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3332] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_start_edge_offset] = STATE(19395),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19396),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3333] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym__integer_covergroup_expression] = STATE(12830),
    [sym__covergroup_expression] = STATE(12830),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9255),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3334] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4771),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3335] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6573),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3336] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1195),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3337] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7214),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3338] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7215),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3339] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7216),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3340] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7280),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3341] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7287),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3342] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4635),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3343] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9926),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10138),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3344] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7132),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3345] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_item_expression] = STATE(17017),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9668),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3346] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6711),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3347] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6715),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3348] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1133),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3349] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1153),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3350] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9292),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3351] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10245),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10140),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3352] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7091),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3353] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7124),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3354] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10303),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10142),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3355] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18028),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3356] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7041),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3357] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(16647),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3358] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7043),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3359] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6459),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3360] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6461),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3361] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(18090),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3362] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(18891),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3363] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(18279),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3364] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(18337),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3365] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(18898),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3366] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(15763),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3367] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(15824),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3368] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10163),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10144),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3369] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20087),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3370] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1091),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3371] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10166),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3372] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2940),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3373] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1076),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3374] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18214),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3375] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(19213),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3376] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6969),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3377] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6995),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3378] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7056),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3379] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6986),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3380] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7029),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3381] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(10156),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3382] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9959),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10148),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3383] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_stream_expression] = STATE(17076),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9521),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3384] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5674),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3311),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3385] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6970),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3386] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4905),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3387] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4906),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3388] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4913),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3389] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19327),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3390] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6793),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3391] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7044),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3392] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6807),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3393] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6852),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3394] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6869),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3395] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1066),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3396] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6981),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3397] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6985),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3398] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7003),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3399] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1079),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3400] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1096),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3401] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19354),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3402] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20051),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3403] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19475),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3404] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7080),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3405] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6980),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3406] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6974),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3407] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6977),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3408] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6802),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3409] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6979),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3410] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6887),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3411] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19600),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3412] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19603),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3413] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_pcontrol_terminal] = STATE(19655),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10328),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3414] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6740),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3415] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7057),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3416] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1100),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3417] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6928),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3418] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6957),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3419] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19741),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3420] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1067),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3421] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1172),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3422] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4623),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3423] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4636),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3424] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4663),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3425] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4667),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3426] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4676),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3427] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4665),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3428] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4615),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3429] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6915),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3430] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(17675),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3431] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6916),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3432] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10002),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10172),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3433] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6917),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3434] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10021),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10174),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3435] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9901),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10176),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3436] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5674),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3329),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3437] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6886),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3438] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6810),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3439] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(20157),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3440] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(20352),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3441] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(20471),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3442] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(16266),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3443] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(16459),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3444] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6868),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3445] = {
    [sym_simple_identifier] = ACTIONS(9953),
    [anon_sym_LT] = ACTIONS(9953),
    [anon_sym_GT] = ACTIONS(9953),
    [anon_sym_LPAREN] = ACTIONS(9953),
    [anon_sym_RPAREN] = ACTIONS(9955),
    [anon_sym_COMMA] = ACTIONS(9955),
    [anon_sym_SLASH] = ACTIONS(9953),
    [anon_sym_wire] = ACTIONS(9953),
    [anon_sym_tri] = ACTIONS(9953),
    [anon_sym_tri0] = ACTIONS(9953),
    [anon_sym_tri1] = ACTIONS(9953),
    [anon_sym_wand] = ACTIONS(9953),
    [anon_sym_triand] = ACTIONS(9953),
    [anon_sym_wor] = ACTIONS(9953),
    [anon_sym_trior] = ACTIONS(9953),
    [anon_sym_trireg] = ACTIONS(9953),
    [anon_sym_uwire] = ACTIONS(9953),
    [anon_sym_DOT_STAR] = ACTIONS(9955),
    [anon_sym_SEMI] = ACTIONS(9955),
    [anon_sym_COLON] = ACTIONS(9955),
    [anon_sym_module] = ACTIONS(9953),
    [anon_sym_macromodule] = ACTIONS(9953),
    [anon_sym_interface] = ACTIONS(9953),
    [anon_sym_program] = ACTIONS(9953),
    [anon_sym_checker] = ACTIONS(9953),
    [anon_sym_virtual] = ACTIONS(9953),
    [anon_sym_class] = ACTIONS(9953),
    [anon_sym_pure] = ACTIONS(9953),
    [anon_sym_package] = ACTIONS(9953),
    [anon_sym_timeunit] = ACTIONS(9953),
    [anon_sym_timeprecision] = ACTIONS(9953),
    [anon_sym_type] = ACTIONS(9953),
    [anon_sym_DOT] = ACTIONS(9953),
    [anon_sym_LBRACE] = ACTIONS(9955),
    [anon_sym_RBRACE] = ACTIONS(9955),
    [anon_sym_input] = ACTIONS(9953),
    [anon_sym_output] = ACTIONS(9953),
    [anon_sym_inout] = ACTIONS(9953),
    [anon_sym_ref] = ACTIONS(9953),
    [anon_sym_clocking] = ACTIONS(9953),
    [anon_sym_iff] = ACTIONS(9953),
    [anon_sym_bind] = ACTIONS(9953),
    [anon_sym_const] = ACTIONS(9953),
    [anon_sym_function] = ACTIONS(9953),
    [anon_sym_static] = ACTIONS(9953),
    [anon_sym_constraint] = ACTIONS(9953),
    [anon_sym_u2013_GT] = ACTIONS(9955),
    [anon_sym_LBRACK] = ACTIONS(9955),
    [anon_sym_RBRACK] = ACTIONS(9955),
    [anon_sym_localparam] = ACTIONS(9953),
    [anon_sym_parameter] = ACTIONS(9953),
    [anon_sym_var] = ACTIONS(9953),
    [anon_sym_import] = ACTIONS(9953),
    [anon_sym_STAR] = ACTIONS(9953),
    [anon_sym_export] = ACTIONS(9953),
    [anon_sym_interconnect] = ACTIONS(9953),
    [anon_sym_typedef] = ACTIONS(9953),
    [anon_sym_enum] = ACTIONS(9953),
    [anon_sym_struct] = ACTIONS(9953),
    [anon_sym_union] = ACTIONS(9953),
    [anon_sym_nettype] = ACTIONS(9953),
    [anon_sym_with] = ACTIONS(9953),
    [anon_sym_automatic] = ACTIONS(9953),
    [anon_sym_string] = ACTIONS(9953),
    [anon_sym_chandle] = ACTIONS(9953),
    [anon_sym_event] = ACTIONS(9953),
    [anon_sym_byte] = ACTIONS(9953),
    [anon_sym_shortint] = ACTIONS(9953),
    [anon_sym_int] = ACTIONS(9953),
    [anon_sym_longint] = ACTIONS(9953),
    [anon_sym_integer] = ACTIONS(9953),
    [anon_sym_time] = ACTIONS(9953),
    [anon_sym_bit] = ACTIONS(9953),
    [anon_sym_logic] = ACTIONS(9953),
    [anon_sym_reg] = ACTIONS(9953),
    [anon_sym_shortreal] = ACTIONS(9953),
    [anon_sym_real] = ACTIONS(9953),
    [anon_sym_realtime] = ACTIONS(9953),
    [anon_sym_supply0] = ACTIONS(9953),
    [anon_sym_supply1] = ACTIONS(9953),
    [anon_sym_signed] = ACTIONS(9953),
    [anon_sym_unsigned] = ACTIONS(9953),
    [anon_sym_task] = ACTIONS(9953),
    [anon_sym_PLUS] = ACTIONS(9955),
    [anon_sym_STAR_STAR] = ACTIONS(9955),
    [anon_sym_PERCENT] = ACTIONS(9955),
    [anon_sym_EQ_EQ] = ACTIONS(9953),
    [anon_sym_BANG_EQ] = ACTIONS(9953),
    [anon_sym_LT_EQ] = ACTIONS(9955),
    [anon_sym_GT_EQ] = ACTIONS(9955),
    [anon_sym_property] = ACTIONS(9953),
    [anon_sym_sequence] = ACTIONS(9953),
    [anon_sym_or] = ACTIONS(9953),
    [anon_sym_dist] = ACTIONS(9953),
    [anon_sym_covergroup] = ACTIONS(9953),
    [anon_sym_AMP_AMP] = ACTIONS(9953),
    [anon_sym_PIPE_PIPE] = ACTIONS(9955),
    [anon_sym_matches] = ACTIONS(9953),
    [anon_sym_let] = ACTIONS(9953),
    [anon_sym_primitive] = ACTIONS(9953),
    [anon_sym_DASH] = ACTIONS(9953),
    [anon_sym_DASH_GT] = ACTIONS(9955),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9955),
    [anon_sym_inside] = ACTIONS(9953),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9955),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9955),
    [anon_sym_GT_GT] = ACTIONS(9953),
    [anon_sym_LT_LT] = ACTIONS(9953),
    [anon_sym_QMARK] = ACTIONS(9955),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9955),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9955),
    [anon_sym_AMP] = ACTIONS(9953),
    [anon_sym_PIPE] = ACTIONS(9953),
    [anon_sym_CARET] = ACTIONS(9953),
    [anon_sym_CARET_TILDE] = ACTIONS(9955),
    [anon_sym_TILDE_CARET] = ACTIONS(9955),
    [anon_sym_GT_GT_GT] = ACTIONS(9955),
    [anon_sym_LT_LT_LT] = ACTIONS(9955),
    [anon_sym_LT_DASH_GT] = ACTIONS(9955),
    [anon_sym_LPAREN_STAR] = ACTIONS(9955),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9955),
    [anon_sym_DOLLARunit] = ACTIONS(9955),
  },
  [3446] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_array_range_expression] = STATE(17635),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9300),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [3447] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5082),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3448] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6524),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3449] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6527),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3450] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6532),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3451] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6533),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3452] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8982),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3453] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8994),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3454] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8997),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3455] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8938),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3456] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8990),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3457] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10042),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10178),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3458] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19980),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3459] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5019),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3460] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19984),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3461] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17294),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3462] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17297),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3463] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17300),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3464] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_pcontrol_terminal] = STATE(20116),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10328),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3465] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10056),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10180),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3466] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(17144),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9543),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3467] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6285),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3468] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6286),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3469] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6287),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3470] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6777),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3471] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6791),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3472] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6362),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3473] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6370),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3474] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4749),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3475] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4736),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3476] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4708),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3477] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4750),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3478] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_stream_expression] = STATE(16002),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9521),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3479] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7339),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3480] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4773),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3481] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7349),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3482] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1086),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3483] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6315),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3484] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4917),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3485] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2835),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3486] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4923),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3487] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19808),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3488] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9460),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_mintypmax_expression] = STATE(19909),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3489] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4792),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3490] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6317),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3491] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18859),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3492] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10125),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10182),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3493] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10127),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10184),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3494] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4817),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3495] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6542),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3496] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4737),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3497] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6953),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3498] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4870),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3499] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6956),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3500] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4875),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3501] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4757),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3502] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4881),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3503] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6546),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3504] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4768),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3505] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9112),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3506] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9119),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3507] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(5012),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3508] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6409),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3509] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9190),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3510] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1040),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3511] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1041),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3512] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2619),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3513] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1042),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3514] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(5055),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3515] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(17935),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3516] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9896),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10186),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3517] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1045),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3518] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4583),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4245),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4245),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3519] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18407),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3520] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10145),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10188),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3521] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10146),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10190),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3522] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1048),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3523] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2728),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3524] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18277),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3525] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5674),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_mintypmax_expression] = STATE(3304),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3526] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6722),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3527] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19759),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3528] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10161),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10192),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3529] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6723),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3530] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6724),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3531] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4654),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3532] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10164),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10194),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3533] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4666),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3534] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10071),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10196),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3535] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym__actual_argument] = STATE(17120),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9583),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3536] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4720),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3537] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4726),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3538] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2817),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3539] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18734),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3540] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4775),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3541] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19002),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3542] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10175),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10198),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3543] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10176),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10200),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3544] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4843),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3545] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4882),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3546] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8984),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3547] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2892),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3548] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8986),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3549] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4986),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3550] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4990),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3551] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1054),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3552] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__covergroup_expression] = STATE(20325),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9636),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3553] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10179),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10202),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3554] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10180),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10204),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3555] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6550),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3556] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4999),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3557] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2950),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3558] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(20491),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3559] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(20494),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3560] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10187),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10206),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3561] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10188),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10208),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3562] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1055),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3563] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5118),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3564] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5146),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3565] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_randcase_item] = STATE(2962),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10174),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3566] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1129),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3567] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10196),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10210),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3568] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5181),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3569] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10197),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10212),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3570] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6557),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3571] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6860),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3572] = {
    [sym_simple_identifier] = ACTIONS(9947),
    [anon_sym_LT] = ACTIONS(9947),
    [anon_sym_GT] = ACTIONS(9947),
    [anon_sym_LPAREN] = ACTIONS(9947),
    [anon_sym_RPAREN] = ACTIONS(9949),
    [anon_sym_COMMA] = ACTIONS(9949),
    [anon_sym_SLASH] = ACTIONS(9947),
    [anon_sym_wire] = ACTIONS(9947),
    [anon_sym_tri] = ACTIONS(9947),
    [anon_sym_tri0] = ACTIONS(9947),
    [anon_sym_tri1] = ACTIONS(9947),
    [anon_sym_wand] = ACTIONS(9947),
    [anon_sym_triand] = ACTIONS(9947),
    [anon_sym_wor] = ACTIONS(9947),
    [anon_sym_trior] = ACTIONS(9947),
    [anon_sym_trireg] = ACTIONS(9947),
    [anon_sym_uwire] = ACTIONS(9947),
    [anon_sym_DOT_STAR] = ACTIONS(9949),
    [anon_sym_SEMI] = ACTIONS(9949),
    [anon_sym_COLON] = ACTIONS(9949),
    [anon_sym_module] = ACTIONS(9947),
    [anon_sym_macromodule] = ACTIONS(9947),
    [anon_sym_interface] = ACTIONS(9947),
    [anon_sym_program] = ACTIONS(9947),
    [anon_sym_checker] = ACTIONS(9947),
    [anon_sym_virtual] = ACTIONS(9947),
    [anon_sym_class] = ACTIONS(9947),
    [anon_sym_pure] = ACTIONS(9947),
    [anon_sym_package] = ACTIONS(9947),
    [anon_sym_timeunit] = ACTIONS(9947),
    [anon_sym_timeprecision] = ACTIONS(9947),
    [anon_sym_type] = ACTIONS(9947),
    [anon_sym_DOT] = ACTIONS(9947),
    [anon_sym_LBRACE] = ACTIONS(9949),
    [anon_sym_RBRACE] = ACTIONS(9949),
    [anon_sym_input] = ACTIONS(9947),
    [anon_sym_output] = ACTIONS(9947),
    [anon_sym_inout] = ACTIONS(9947),
    [anon_sym_ref] = ACTIONS(9947),
    [anon_sym_clocking] = ACTIONS(9947),
    [anon_sym_iff] = ACTIONS(9947),
    [anon_sym_bind] = ACTIONS(9947),
    [anon_sym_const] = ACTIONS(9947),
    [anon_sym_function] = ACTIONS(9947),
    [anon_sym_static] = ACTIONS(9947),
    [anon_sym_constraint] = ACTIONS(9947),
    [anon_sym_u2013_GT] = ACTIONS(9949),
    [anon_sym_LBRACK] = ACTIONS(9949),
    [anon_sym_RBRACK] = ACTIONS(9949),
    [anon_sym_localparam] = ACTIONS(9947),
    [anon_sym_parameter] = ACTIONS(9947),
    [anon_sym_var] = ACTIONS(9947),
    [anon_sym_import] = ACTIONS(9947),
    [anon_sym_STAR] = ACTIONS(9947),
    [anon_sym_export] = ACTIONS(9947),
    [anon_sym_interconnect] = ACTIONS(9947),
    [anon_sym_typedef] = ACTIONS(9947),
    [anon_sym_enum] = ACTIONS(9947),
    [anon_sym_struct] = ACTIONS(9947),
    [anon_sym_union] = ACTIONS(9947),
    [anon_sym_nettype] = ACTIONS(9947),
    [anon_sym_with] = ACTIONS(9947),
    [anon_sym_automatic] = ACTIONS(9947),
    [anon_sym_string] = ACTIONS(9947),
    [anon_sym_chandle] = ACTIONS(9947),
    [anon_sym_event] = ACTIONS(9947),
    [anon_sym_byte] = ACTIONS(9947),
    [anon_sym_shortint] = ACTIONS(9947),
    [anon_sym_int] = ACTIONS(9947),
    [anon_sym_longint] = ACTIONS(9947),
    [anon_sym_integer] = ACTIONS(9947),
    [anon_sym_time] = ACTIONS(9947),
    [anon_sym_bit] = ACTIONS(9947),
    [anon_sym_logic] = ACTIONS(9947),
    [anon_sym_reg] = ACTIONS(9947),
    [anon_sym_shortreal] = ACTIONS(9947),
    [anon_sym_real] = ACTIONS(9947),
    [anon_sym_realtime] = ACTIONS(9947),
    [anon_sym_supply0] = ACTIONS(9947),
    [anon_sym_supply1] = ACTIONS(9947),
    [anon_sym_signed] = ACTIONS(9947),
    [anon_sym_unsigned] = ACTIONS(9947),
    [anon_sym_task] = ACTIONS(9947),
    [anon_sym_PLUS] = ACTIONS(9949),
    [anon_sym_STAR_STAR] = ACTIONS(9949),
    [anon_sym_PERCENT] = ACTIONS(9949),
    [anon_sym_EQ_EQ] = ACTIONS(9947),
    [anon_sym_BANG_EQ] = ACTIONS(9947),
    [anon_sym_LT_EQ] = ACTIONS(9949),
    [anon_sym_GT_EQ] = ACTIONS(9949),
    [anon_sym_property] = ACTIONS(9947),
    [anon_sym_sequence] = ACTIONS(9947),
    [anon_sym_or] = ACTIONS(9947),
    [anon_sym_dist] = ACTIONS(9947),
    [anon_sym_covergroup] = ACTIONS(9947),
    [anon_sym_AMP_AMP] = ACTIONS(9947),
    [anon_sym_PIPE_PIPE] = ACTIONS(9949),
    [anon_sym_matches] = ACTIONS(9947),
    [anon_sym_let] = ACTIONS(9947),
    [anon_sym_primitive] = ACTIONS(9947),
    [anon_sym_DASH] = ACTIONS(9947),
    [anon_sym_DASH_GT] = ACTIONS(9949),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9949),
    [anon_sym_inside] = ACTIONS(9947),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9949),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9949),
    [anon_sym_GT_GT] = ACTIONS(9947),
    [anon_sym_LT_LT] = ACTIONS(9947),
    [anon_sym_QMARK] = ACTIONS(9949),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9949),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9949),
    [anon_sym_AMP] = ACTIONS(9947),
    [anon_sym_PIPE] = ACTIONS(9947),
    [anon_sym_CARET] = ACTIONS(9947),
    [anon_sym_CARET_TILDE] = ACTIONS(9949),
    [anon_sym_TILDE_CARET] = ACTIONS(9949),
    [anon_sym_GT_GT_GT] = ACTIONS(9949),
    [anon_sym_LT_LT_LT] = ACTIONS(9949),
    [anon_sym_LT_DASH_GT] = ACTIONS(9949),
    [anon_sym_LPAREN_STAR] = ACTIONS(9949),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9949),
    [anon_sym_DOLLARunit] = ACTIONS(9949),
  },
  [3573] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20273),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3574] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6558),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3575] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9684),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(10214),
    [anon_sym_DQUOTE] = ACTIONS(10217),
    [anon_sym_LPAREN] = ACTIONS(10220),
    [anon_sym_BQUOTE] = ACTIONS(10223),
    [anon_sym_type] = ACTIONS(10226),
    [anon_sym_LBRACE] = ACTIONS(10229),
    [anon_sym_const] = ACTIONS(10232),
    [anon_sym_local] = ACTIONS(10235),
    [anon_sym_super] = ACTIONS(10238),
    [anon_sym_string] = ACTIONS(10232),
    [anon_sym_byte] = ACTIONS(10241),
    [anon_sym_shortint] = ACTIONS(10241),
    [anon_sym_int] = ACTIONS(10241),
    [anon_sym_longint] = ACTIONS(10241),
    [anon_sym_integer] = ACTIONS(10241),
    [anon_sym_time] = ACTIONS(10241),
    [anon_sym_bit] = ACTIONS(10244),
    [anon_sym_logic] = ACTIONS(10244),
    [anon_sym_reg] = ACTIONS(10244),
    [anon_sym_shortreal] = ACTIONS(10247),
    [anon_sym_real] = ACTIONS(10247),
    [anon_sym_realtime] = ACTIONS(10247),
    [anon_sym_signed] = ACTIONS(10232),
    [anon_sym_unsigned] = ACTIONS(10232),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(10250),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(10253),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(10256),
    [anon_sym_randomize] = ACTIONS(10259),
    [anon_sym_null] = ACTIONS(10262),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(10265),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(10268),
    [aux_sym_decimal_number_token2] = ACTIONS(10268),
    [sym_binary_number] = ACTIONS(10271),
    [sym_octal_number] = ACTIONS(10271),
    [sym_hex_number] = ACTIONS(10271),
    [aux_sym_real_number_token1] = ACTIONS(10274),
    [sym_fixed_point_number] = ACTIONS(10277),
    [sym_unsigned_number] = ACTIONS(10280),
    [anon_sym_SQUOTE0] = ACTIONS(10283),
    [anon_sym_SQUOTE1] = ACTIONS(10283),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(10283),
    [anon_sym_LPAREN_STAR] = ACTIONS(10286),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(10288),
    [anon_sym_DOLLARroot] = ACTIONS(10291),
    [anon_sym_DOLLARunit] = ACTIONS(10294),
    [sym_system_tf_identifier] = ACTIONS(10297),
  },
  [3576] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6872),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4248),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4248),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3577] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6559),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3578] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_ncontrol_terminal] = STATE(18117),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10215),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3579] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(18160),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3580] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(18174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3581] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_input_terminal] = STATE(16980),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9672),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3582] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7351),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3583] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7360),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3584] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(18195),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3585] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19479),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3586] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10226),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10300),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3587] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9749),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10302),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3588] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9750),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10304),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3589] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9049),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3590] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6566),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3591] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10227),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10306),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3592] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9924),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10308),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3593] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9091),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3594] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6570),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4251),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4251),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3595] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9051),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3596] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9074),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3597] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8955),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3598] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10231),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10310),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3599] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9152),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3600] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19342),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3601] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1138),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3602] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18265),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3603] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18760),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3604] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18763),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3605] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9085),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3606] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__covergroup_expression] = STATE(18293),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3607] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9004),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3608] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9007),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3609] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9018),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3610] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10240),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10312),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3611] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1139),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3612] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9077),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3613] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9084),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3614] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8949),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4258),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4258),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3615] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym__covergroup_expression] = STATE(19374),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8922),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3616] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_data_source_expression] = STATE(19350),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10301),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3617] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17166),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3618] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7308),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4272),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4272),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3619] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1140),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3620] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18394),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3621] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20005),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3622] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10259),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10314),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3623] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(17436),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3624] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10273),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10316),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3625] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10281),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10318),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3626] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10294),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_RPAREN] = ACTIONS(10320),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3627] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7300),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3628] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7304),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3629] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17169),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3630] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20484),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3631] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7309),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3632] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7310),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3633] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17170),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3634] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1076),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3635] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1079),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3636] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5171),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4260),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4260),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3637] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17171),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3638] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(19377),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3639] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17172),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3640] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18249),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3641] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(17173),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3642] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(19381),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3643] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18285),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3644] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1040),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3645] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1041),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3646] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1042),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3647] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1048),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3648] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1054),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3649] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1055),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3650] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7338),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3651] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7344),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3652] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1091),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3653] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18336),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3654] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1096),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3655] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1138),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3656] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18354),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3657] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1140),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3658] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_ncontrol_terminal] = STATE(19398),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10215),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3659] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7347),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3660] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1133),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3661] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1172),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3662] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1086),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3663] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1129),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3664] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6711),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3665] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6715),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3666] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4905),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3667] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4906),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3668] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4913),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3669] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6807),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3670] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6852),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3671] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6869),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3672] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6802),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3673] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6887),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3674] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6915),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3675] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6917),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3676] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6886),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3677] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6868),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3678] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5082),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3679] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5019),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3680] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4917),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3681] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4923),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3682] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6722),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3683] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6723),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3684] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6724),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3685] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4666),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3686] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4720),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3687] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4726),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3688] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4775),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3689] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4843),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3690] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4986),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3691] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(4999),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3692] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5118),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3693] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5181),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3694] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6860),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3695] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_or_null] = STATE(6872),
    [sym_statement] = STATE(6783),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4283),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4283),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2343),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3696] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7351),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3697] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7360),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3698] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7304),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3699] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7309),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3700] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7310),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3701] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7338),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3702] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7344),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3703] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7277),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3704] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7177),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3705] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7337),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3706] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7181),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3707] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6459),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3708] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6461),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3709] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6527),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3710] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6532),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3711] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6533),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3712] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6542),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3713] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6546),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3714] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6557),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3715] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6559),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3716] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6566),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3717] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6573),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3718] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7041),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3719] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7043),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3720] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7044),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3721] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6981),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3722] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6985),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3723] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7003),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3724] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7080),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3725] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6974),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3726] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6979),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3727] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7057),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3728] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6957),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3729] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4623),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3730] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4636),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3731] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4708),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3732] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4771),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3733] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4773),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3734] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4792),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3735] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4817),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3736] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4870),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3737] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4881),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3738] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(5012),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3739] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4583),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3740] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8984),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3741] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8986),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3742] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9091),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3743] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9051),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3744] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9074),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3745] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8955),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3746] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9152),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3747] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9004),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3748] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9018),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3749] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(9077),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3750] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8949),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3751] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_or_null] = STATE(5171),
    [sym_statement] = STATE(5218),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4277),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4277),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9700),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3752] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6285),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3753] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6286),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3754] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6287),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3755] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6362),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3756] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6370),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3757] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_or_null] = STATE(6409),
    [sym_statement] = STATE(6442),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4243),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4243),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9790),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3758] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7214),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3759] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7215),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3760] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7216),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3761] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7280),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3762] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7287),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4247),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4247),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3763] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4635),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3764] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6969),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3765] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6995),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3766] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7056),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3767] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(6986),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3768] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_or_null] = STATE(7029),
    [sym_statement] = STATE(7032),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4250),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4250),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9405),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3769] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(10156),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3770] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4663),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3771] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4667),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3772] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4676),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3773] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4665),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3774] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_or_null] = STATE(4615),
    [sym_statement] = STATE(4988),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4284),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4284),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9317),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3775] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8982),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3776] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8994),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3777] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8997),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3778] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8938),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3779] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_or_null] = STATE(8990),
    [sym_statement] = STATE(9076),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4256),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4256),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9361),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3780] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10343),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10322),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3781] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10344),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10324),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3782] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10345),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10326),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3783] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10346),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10328),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3784] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10347),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10330),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3785] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10348),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10332),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3786] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10349),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10334),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3787] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10350),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3788] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7277),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3789] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7176),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3790] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10352),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10338),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3791] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10353),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10340),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3792] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7177),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3793] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(19400),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3794] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10357),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10342),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3795] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10358),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10344),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3796] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10359),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10346),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3797] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10360),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10348),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3798] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18523),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3799] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18539),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3800] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18558),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3801] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18565),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3802] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18706),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3803] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18722),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3804] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18741),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3805] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18748),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3806] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18870),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3807] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18886),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3808] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18904),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3809] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(18911),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3810] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(18999),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3811] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19012),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3812] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19027),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3813] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19033),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3814] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19073),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3815] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19077),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3816] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19082),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3817] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19086),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3818] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19122),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3819] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_case_expression] = STATE(19125),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9838),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3820] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19130),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3821] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19134),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3822] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19824),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3823] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19825),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3824] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19834),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3825] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19835),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3826] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19844),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3827] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19845),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3828] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19854),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3829] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19855),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3830] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19864),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3831] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19865),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3832] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19874),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3833] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19875),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3834] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3835] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(19885),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3836] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(1195),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4259),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4259),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3837] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7337),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3838] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7355),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3839] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20259),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3840] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20179),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3841] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(19402),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3842] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_enable_terminal] = STATE(19410),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10219),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3843] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20206),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3844] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10384),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10350),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3845] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10385),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10352),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3846] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20294),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3847] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20308),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3848] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20322),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3849] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20333),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3850] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20344),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3851] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_or_null] = STATE(20353),
    [sym_statement] = STATE(1124),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4232),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4232),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9273),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3852] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_or_null] = STATE(7181),
    [sym_statement] = STATE(7261),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4253),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4253),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(2704),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3853] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9847),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_SEMI] = ACTIONS(10354),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3854] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_expression_or_dist] = STATE(20483),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9392),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3855] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_timing_check_limit] = STATE(19364),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9643),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3856] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10140),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3857] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10373),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3858] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9720),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3859] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10185),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3860] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10186),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3861] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9724),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3862] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9594),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3863] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9381),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [3864] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9754),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3865] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9834),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3866] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9783),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3867] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9669),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3868] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9805),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3869] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17113),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3870] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9280),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3871] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9806),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3872] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9809),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3873] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9822),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3874] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9823),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3875] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9827),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3876] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9826),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3877] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9891),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3878] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9828),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3879] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9830),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3880] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9921),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3881] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9954),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3882] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9829),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3883] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9595),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3884] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9846),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3885] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9598),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3886] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19095),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9369),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12806),
    [sym_unary_operator] = STATE(5355),
    [sym_inc_or_dec_operator] = STATE(10556),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(572),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7386),
    [sym_package_scope] = STATE(12291),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13036),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5969),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5977),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5979),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6005),
    [anon_sym_DOLLARroot] = ACTIONS(6007),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3887] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9852),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3888] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9853),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3889] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9459),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3890] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9854),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3891] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17283),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3892] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9855),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3893] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9856),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3894] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9857),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3895] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9858),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3896] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9859),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3897] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9522),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3898] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9860),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3899] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9861),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3900] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9538),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3901] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9862),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3902] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9956),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3903] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9865),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3904] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9867),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3905] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16760),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3906] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9868),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3907] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9471),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3908] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9870),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3909] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9948),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3910] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9873),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3911] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9871),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3912] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9875),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3913] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9876),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3914] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9877),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3915] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5687),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3916] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9273),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3917] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(19139),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9188),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7435),
    [sym_package_scope] = STATE(12220),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13270),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6335),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6343),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [3918] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9831),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3919] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5640),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3920] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(19044),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5641),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5236),
    [sym_package_scope] = STATE(12298),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13023),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(7001),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(7027),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [3921] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9616),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3922] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9976),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3923] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8596),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3924] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9832),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3925] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6378),
    [sym_statement_item] = STATE(6444),
    [sym_function_statement] = STATE(6410),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4289),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4289),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3926] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8894),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3927] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9710),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3928] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19950),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8896),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5346),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5464),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3929] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9824),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3930] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9895),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3931] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9864),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3932] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9721),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3933] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9903),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3934] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9904),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3935] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9905),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3936] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16916),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3937] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9906),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3938] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9907),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3939] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9908),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3940] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9909),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3941] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9910),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3942] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10134),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3943] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9529),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3944] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9911),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3945] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10304),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3946] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9913),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3947] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9878),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3948] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17039),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3949] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9914),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3950] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9915),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3951] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9916),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3952] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9674),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3953] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9917),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3954] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9919),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3955] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8067),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3956] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9925),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3957] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9930),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3958] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9931),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3959] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9932),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3960] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16724),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3961] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9933),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3962] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9934),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3963] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9935),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3964] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9936),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3965] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9937),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3966] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9511),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3967] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9941),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3968] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9665),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3969] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9943),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3970] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16780),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3971] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9944),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3972] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9946),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3973] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9744),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3974] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4722),
    [sym_statement_item] = STATE(5002),
    [sym_function_statement] = STATE(4646),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4332),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4332),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3975] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9947),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3976] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9950),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3977] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9951),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3978] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(7019),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(2646),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [3979] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(14743),
    [sym_cond_pattern] = STATE(14743),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3980] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9958),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3981] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9541),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3982] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9645),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3983] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18427),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8080),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12555),
    [sym_unary_operator] = STATE(5341),
    [sym_inc_or_dec_operator] = STATE(10551),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(6897),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5817),
    [sym_package_scope] = STATE(12271),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13007),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(3445),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(3471),
    [anon_sym_DOLLARroot] = ACTIONS(3473),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3984] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9963),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3985] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9964),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3986] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9965),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3987] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17079),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3988] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9966),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3989] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9967),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3990] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9968),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3991] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9969),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3992] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9970),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3993] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9474),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3994] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9971),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3995] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9973),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3996] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17119),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3997] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9974),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3998] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9978),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [3999] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9981),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4000] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9985),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4001] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9987),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4002] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8803),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4003] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10000),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4004] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10007),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4005] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10008),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4006] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10009),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4007] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17355),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4008] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10010),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4009] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10011),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4010] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10012),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4011] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10015),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4012] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10016),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4013] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9960),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4014] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9448),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4015] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10018),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4016] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9918),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4017] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10023),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4018] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16650),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4019] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10024),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4020] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10025),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4021] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10026),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4022] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10028),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4023] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10032),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4024] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10383),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4025] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10041),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4026] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(10298),
    [sym_statement_item] = STATE(9088),
    [sym_function_statement] = STATE(10157),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4326),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4326),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4027] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10386),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4028] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10044),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4029] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10045),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4030] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10046),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4031] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16741),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4032] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10047),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4033] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10048),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4034] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10049),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4035] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10050),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4036] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10051),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4037] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10053),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4038] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16752),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4039] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10054),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4040] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1245),
    [sym_statement_item] = STATE(1137),
    [sym_function_statement] = STATE(1239),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4330),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4330),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4041] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9383),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4042] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10060),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4043] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10061),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4044] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10062),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4045] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16803),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4046] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10063),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4047] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10064),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4048] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10065),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4049] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10066),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4050] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10067),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4051] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16810),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4052] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10082),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4053] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9666),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4054] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10077),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4055] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10078),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4056] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16835),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4057] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10079),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4058] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10080),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4059] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16837),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4060] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10083),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4061] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10084),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4062] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16844),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4063] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10085),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4064] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10086),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4065] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8810),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4066] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16848),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4067] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10088),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4068] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10089),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4069] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16857),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4070] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10090),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4071] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10091),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4072] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16858),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4073] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9575),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4074] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10092),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4075] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10093),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4076] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16870),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4077] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10094),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4078] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10095),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4079] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16873),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4080] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10096),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4081] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10097),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4082] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16883),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4083] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10098),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4084] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10099),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4085] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16885),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4086] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10101),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4087] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10102),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4088] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16892),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4089] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10103),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4090] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10104),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4091] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10374),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4092] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10105),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4093] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10106),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4094] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16906),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4095] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10107),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4096] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10108),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4097] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9748),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4098] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16912),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4099] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9533),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4100] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10299),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4101] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9532),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(6485),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [4102] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19899),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8750),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5328),
    [sym_inc_or_dec_operator] = STATE(10521),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(8200),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7090),
    [sym_package_scope] = STATE(12317),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13075),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5154),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5156),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5158),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5164),
    [anon_sym_DOLLARroot] = ACTIONS(5166),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4103] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10277),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4104] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9550),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [4105] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10300),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4106] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9835),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4107] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10118),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4108] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10119),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4109] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17068),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4110] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10120),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4111] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10121),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4112] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_cond_predicate] = STATE(19151),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(16047),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(8297),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_inc_or_dec_expression] = STATE(9552),
    [sym_conditional_expression] = STATE(9553),
    [sym_expression] = STATE(9509),
    [sym_tagged_union_expression] = STATE(9553),
    [sym_inside_expression] = STATE(9553),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9336),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9317),
    [sym_variable_lvalue] = STATE(12575),
    [sym_unary_operator] = STATE(5331),
    [sym_inc_or_dec_operator] = STATE(10487),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7450),
    [sym_package_scope] = STATE(12078),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13367),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(6485),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6489),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6491),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(6495),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(6499),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6513),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [4113] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9531),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4114] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10190),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4115] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10142),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4116] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10055),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4117] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(17085),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4118] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9307),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4119] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10126),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4120] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9678),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4121] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9751),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4122] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10128),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4123] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9928),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4124] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8577),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4125] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9825),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4126] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10130),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4127] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9753),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4128] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9393),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4129] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9755),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4130] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9654),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4131] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16717),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4132] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9463),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4133] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10147),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4134] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5701),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [4135] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9479),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4136] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9758),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4137] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10165),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4138] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9447),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4139] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10177),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4140] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9655),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4141] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9524),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4142] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10181),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4143] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_cond_predicate] = STATE(18934),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(16425),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8649),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_inc_or_dec_expression] = STATE(8741),
    [sym_conditional_expression] = STATE(8686),
    [sym_expression] = STATE(9526),
    [sym_tagged_union_expression] = STATE(8686),
    [sym_inside_expression] = STATE(8686),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8595),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(8619),
    [sym_variable_lvalue] = STATE(12595),
    [sym_unary_operator] = STATE(5362),
    [sym_inc_or_dec_operator] = STATE(10545),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7475),
    [sym_package_scope] = STATE(11966),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13103),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(5973),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6333),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(6453),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5983),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5991),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(6455),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [4144] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9759),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4145] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10189),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4146] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5711),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [4147] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9717),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4148] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_cond_predicate] = STATE(18102),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16016),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6400),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_inc_or_dec_expression] = STATE(7053),
    [sym_conditional_expression] = STATE(7054),
    [sym_expression] = STATE(6962),
    [sym_tagged_union_expression] = STATE(7054),
    [sym_inside_expression] = STATE(7054),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6741),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(6727),
    [sym_variable_lvalue] = STATE(12863),
    [sym_unary_operator] = STATE(5317),
    [sym_inc_or_dec_operator] = STATE(10539),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_escaped_identifier] = STATE(5808),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5732),
    [sym_package_scope] = STATE(12260),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12991),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(2640),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(2646),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(2658),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2664),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(2672),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2688),
    [anon_sym_DOLLARroot] = ACTIONS(2690),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [4149] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10198),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4150] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9761),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4151] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9727),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4152] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9762),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4153] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9763),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4154] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9764),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4155] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9767),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4156] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(4606),
    [sym_statement_item] = STATE(4596),
    [sym_function_statement] = STATE(4813),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4307),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4307),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4157] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9769),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4158] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_cond_predicate] = STATE(18616),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(15466),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5521),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_inc_or_dec_expression] = STATE(5664),
    [sym_conditional_expression] = STATE(5665),
    [sym_expression] = STATE(5703),
    [sym_tagged_union_expression] = STATE(5665),
    [sym_inside_expression] = STATE(5665),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5569),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(5543),
    [sym_variable_lvalue] = STATE(12499),
    [sym_unary_operator] = STATE(5323),
    [sym_inc_or_dec_operator] = STATE(10508),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5266),
    [sym_package_scope] = STATE(12073),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13436),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(6991),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(6999),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(9901),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(7005),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(7013),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(9903),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [4159] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9534),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4160] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9938),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4161] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9939),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4162] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9043),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4163] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10234),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4164] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9045),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4165] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9653),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4166] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9836),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4167] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9670),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4168] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(8772),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4169] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(20467),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10302),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5348),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5686),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4170] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10319),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4171] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9540),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4172] = {
    [sym_module_keyword] = STATE(12139),
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5491),
    [sym_bind_directive] = STATE(5491),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(5491),
    [sym_package_or_generate_item_declaration] = STATE(5491),
    [sym_anonymous_program] = STATE(5491),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(5491),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(2639),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(2639),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_module] = ACTIONS(37),
    [anon_sym_macromodule] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(766),
    [anon_sym_program] = ACTIONS(10356),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_package] = ACTIONS(10358),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(57),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_primitive] = ACTIONS(10360),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4173] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(19235),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9228),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5462),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4174] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(4606),
    [sym_statement_item] = STATE(4596),
    [sym_function_statement] = STATE(4813),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4321),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4321),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4175] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10003),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4176] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9707),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4177] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9632),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4178] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6378),
    [sym_statement_item] = STATE(6444),
    [sym_function_statement] = STATE(6410),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4292),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4292),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4179] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9425),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4180] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9940),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4181] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9703),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4182] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4722),
    [sym_statement_item] = STATE(5002),
    [sym_function_statement] = STATE(4646),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4308),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4308),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4183] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10141),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4184] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(10298),
    [sym_statement_item] = STATE(9088),
    [sym_function_statement] = STATE(10157),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4317),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4317),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4185] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10309),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4186] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10310),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4187] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10311),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4188] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10312),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4189] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9691),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4190] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10315),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4191] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10316),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4192] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10317),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4193] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10318),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4194] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10320),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4195] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10321),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4196] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10322),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4197] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10323),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4198] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10324),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4199] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10325),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4200] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10326),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4201] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10327),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4202] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10329),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4203] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10330),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4204] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10331),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4205] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10332),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4206] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10022),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4207] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_cond_predicate] = STATE(18783),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(15452),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(8712),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_inc_or_dec_expression] = STATE(9375),
    [sym_conditional_expression] = STATE(9377),
    [sym_expression] = STATE(9296),
    [sym_tagged_union_expression] = STATE(9377),
    [sym_inside_expression] = STATE(9377),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9154),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(9136),
    [sym_variable_lvalue] = STATE(12655),
    [sym_unary_operator] = STATE(5352),
    [sym_inc_or_dec_operator] = STATE(10522),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_escaped_identifier] = STATE(5300),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7368),
    [sym_package_scope] = STATE(12274),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(14019),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(5900),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(5904),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(5908),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(5910),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(5914),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(5922),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5936),
    [anon_sym_DOLLARroot] = ACTIONS(5938),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [4208] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10334),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4209] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10335),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4210] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10336),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4211] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10337),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4212] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10339),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4213] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10340),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4214] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10341),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4215] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10342),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4216] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10307),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4217] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9714),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4218] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9440),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4219] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9899),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4220] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(9681),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4221] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10254),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4222] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1245),
    [sym_statement_item] = STATE(1137),
    [sym_function_statement] = STATE(1239),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4293),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4293),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4223] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10371),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4224] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(18617),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10372),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4225] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_cond_predicate] = STATE(16896),
    [sym__expression_or_cond_pattern] = STATE(15070),
    [sym_cond_pattern] = STATE(15070),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(6983),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_inc_or_dec_expression] = STATE(7405),
    [sym_conditional_expression] = STATE(7407),
    [sym_expression] = STATE(10306),
    [sym_tagged_union_expression] = STATE(7407),
    [sym_inside_expression] = STATE(7407),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7228),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(19341),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(12498),
    [sym_unary_operator] = STATE(5333),
    [sym_inc_or_dec_operator] = STATE(10533),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6628),
    [sym_package_scope] = STATE(12415),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13142),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_tagged] = ACTIONS(4150),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2662),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2662),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(4158),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4226] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(10158),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4317),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4317),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4227] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(4999),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4321),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4321),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4228] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(5118),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4321),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4321),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4229] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement] = STATE(7057),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4303),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4303),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4230] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement] = STATE(7177),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4331),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4331),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4231] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement] = STATE(7337),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4331),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9214),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4331),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4232] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1082),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10362),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4233] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6559),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4292),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4292),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4234] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6566),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4292),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4292),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4235] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1238),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4330),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4330),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4236] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement] = STATE(6979),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4287),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4287),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4237] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement] = STATE(7057),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4287),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9219),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4287),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4238] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4881),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4308),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4308),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4239] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(5012),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4308),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4308),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4240] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(9018),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4317),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4317),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4241] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(9077),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4317),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9227),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4317),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4242] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(5134),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4321),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9185),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4321),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4243] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6463),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10364),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4244] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4881),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4332),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4332),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4245] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4652),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10366),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4246] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6411),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4292),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9195),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4292),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4247] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7252),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3190),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4248] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3098),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4249] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4648),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4308),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9225),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4308),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4250] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7046),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10368),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4251] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6463),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10364),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4252] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(5012),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4332),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4332),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4253] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7252),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3190),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4254] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement] = STATE(6979),
    [sym_statement_item] = STATE(7034),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4303),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9177),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4303),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4255] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(6917),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4314),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4314),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4256] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(8993),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10370),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4257] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6559),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4289),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4289),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4258] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(8993),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10370),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4259] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1082),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10362),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4260] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4937),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10372),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4261] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(10158),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4326),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4326),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4262] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6411),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4289),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4289),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4263] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3148),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4264] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(9018),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4326),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4326),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4265] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(5134),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4307),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4307),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4266] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(5118),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4307),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4307),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4267] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement] = STATE(9077),
    [sym_statement_item] = STATE(9088),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4326),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9238),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4326),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4268] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement] = STATE(6566),
    [sym_statement_item] = STATE(6444),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4289),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9186),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4289),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4269] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1140),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4330),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4330),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4270] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement] = STATE(7177),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4296),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4271] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1133),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4330),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9201),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4330),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4272] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7046),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10368),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4273] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement] = STATE(4648),
    [sym_statement_item] = STATE(5002),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4332),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9236),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4332),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4274] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement] = STATE(4999),
    [sym_statement_item] = STATE(4596),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4307),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9287),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4307),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4275] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1140),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4293),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4293),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4276] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1133),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4293),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4293),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4277] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4937),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10372),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4278] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(6886),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4314),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9305),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4314),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4279] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(6917),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4333),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4333),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4280] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement] = STATE(6886),
    [sym_statement_item] = STATE(6696),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4333),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9208),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4333),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4281] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement] = STATE(1238),
    [sym_statement_item] = STATE(1137),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4293),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9323),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4293),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4282] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement] = STATE(7337),
    [sym_statement_item] = STATE(7264),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4296),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9184),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4296),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4283] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(3098),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4284] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4652),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(10366),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4285] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6803),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4286] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7075),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4287] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7046),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4288] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4965),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4289] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6463),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4290] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7062),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4291),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4291),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4291] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7075),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3719),
    [sym_event_control] = STATE(3719),
    [sym__procedural_timing_control] = STATE(3719),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13961),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3719),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9409),
    [anon_sym_foreach] = ACTIONS(9413),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9415),
    [anon_sym_assume] = ACTIONS(9417),
    [anon_sym_cover] = ACTIONS(9419),
    [anon_sym_expect] = ACTIONS(9421),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9427),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9431),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9437),
    [anon_sym_wait_order] = ACTIONS(9439),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9447),
    [anon_sym_while] = ACTIONS(9431),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4292] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6463),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4293] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1082),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4294] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6481),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4295),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4295),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4295] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6508),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3708),
    [sym_event_control] = STATE(3708),
    [sym__procedural_timing_control] = STATE(3708),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13958),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3708),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9794),
    [anon_sym_foreach] = ACTIONS(9798),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9800),
    [anon_sym_assume] = ACTIONS(9802),
    [anon_sym_cover] = ACTIONS(9804),
    [anon_sym_expect] = ACTIONS(9806),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(9810),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(9814),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(9820),
    [anon_sym_wait_order] = ACTIONS(9822),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9830),
    [anon_sym_while] = ACTIONS(9814),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4296] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7252),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4297] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4782),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4301),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4301),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4298] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6481),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4305),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4305),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4299] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7203),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4329),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4329),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4300] = {
    [sym_local_parameter_declaration] = STATE(18070),
    [sym_parameter_declaration] = STATE(18070),
    [sym__any_parameter_declaration] = STATE(18070),
    [sym_data_declaration] = STATE(5719),
    [sym_package_import_declaration] = STATE(5708),
    [sym_type_declaration] = STATE(5708),
    [sym_net_type_declaration] = STATE(5708),
    [sym_lifetime] = STATE(8426),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12703),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(19894),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_block_item_declaration] = STATE(4300),
    [sym_overload_declaration] = STATE(5719),
    [sym_let_declaration] = STATE(5719),
    [sym_attribute_instance] = STATE(6075),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10992),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(6075),
    [aux_sym_class_constructor_declaration_repeat1] = STATE(4300),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(9989),
    [anon_sym_SEMI] = ACTIONS(9992),
    [anon_sym_virtual] = ACTIONS(9994),
    [anon_sym_POUND] = ACTIONS(9997),
    [anon_sym_type] = ACTIONS(9999),
    [anon_sym_LBRACE] = ACTIONS(9992),
    [anon_sym_disable] = ACTIONS(9997),
    [anon_sym_bind] = ACTIONS(10374),
    [anon_sym_const] = ACTIONS(10377),
    [anon_sym_static] = ACTIONS(10008),
    [anon_sym_local] = ACTIONS(9997),
    [anon_sym_super] = ACTIONS(9997),
    [anon_sym_if] = ACTIONS(9997),
    [anon_sym_foreach] = ACTIONS(9997),
    [anon_sym_LBRACK] = ACTIONS(10011),
    [anon_sym_unique] = ACTIONS(9997),
    [anon_sym_localparam] = ACTIONS(10014),
    [anon_sym_parameter] = ACTIONS(10017),
    [anon_sym_var] = ACTIONS(10380),
    [anon_sym_import] = ACTIONS(10383),
    [anon_sym_typedef] = ACTIONS(10386),
    [anon_sym_enum] = ACTIONS(10029),
    [anon_sym_struct] = ACTIONS(10032),
    [anon_sym_union] = ACTIONS(10035),
    [anon_sym_nettype] = ACTIONS(10389),
    [anon_sym_automatic] = ACTIONS(10008),
    [anon_sym_string] = ACTIONS(10041),
    [anon_sym_chandle] = ACTIONS(10041),
    [anon_sym_event] = ACTIONS(10041),
    [anon_sym_byte] = ACTIONS(10044),
    [anon_sym_shortint] = ACTIONS(10044),
    [anon_sym_int] = ACTIONS(10044),
    [anon_sym_longint] = ACTIONS(10044),
    [anon_sym_integer] = ACTIONS(10044),
    [anon_sym_time] = ACTIONS(10044),
    [anon_sym_bit] = ACTIONS(10047),
    [anon_sym_logic] = ACTIONS(10047),
    [anon_sym_reg] = ACTIONS(10047),
    [anon_sym_shortreal] = ACTIONS(10050),
    [anon_sym_real] = ACTIONS(10050),
    [anon_sym_realtime] = ACTIONS(10050),
    [anon_sym_signed] = ACTIONS(10053),
    [anon_sym_unsigned] = ACTIONS(10053),
    [anon_sym_PLUS_PLUS] = ACTIONS(9992),
    [anon_sym_assert] = ACTIONS(9997),
    [anon_sym_assume] = ACTIONS(9997),
    [anon_sym_cover] = ACTIONS(9997),
    [anon_sym_expect] = ACTIONS(9997),
    [anon_sym_restrict] = ACTIONS(9997),
    [anon_sym_case] = ACTIONS(9997),
    [anon_sym_POUND_POUND] = ACTIONS(9992),
    [anon_sym_begin] = ACTIONS(9997),
    [anon_sym_end] = ACTIONS(9997),
    [anon_sym_let] = ACTIONS(10392),
    [anon_sym_for] = ACTIONS(9997),
    [anon_sym_assign] = ACTIONS(9997),
    [anon_sym_deassign] = ACTIONS(9997),
    [anon_sym_force] = ACTIONS(9997),
    [anon_sym_release] = ACTIONS(9997),
    [anon_sym_fork] = ACTIONS(9997),
    [anon_sym_repeat] = ACTIONS(9997),
    [anon_sym_AT] = ACTIONS(9997),
    [anon_sym_AT_STAR] = ACTIONS(9992),
    [anon_sym_return] = ACTIONS(9997),
    [anon_sym_break] = ACTIONS(9997),
    [anon_sym_continue] = ACTIONS(9997),
    [anon_sym_wait] = ACTIONS(9997),
    [anon_sym_wait_order] = ACTIONS(9997),
    [anon_sym_DASH_GT] = ACTIONS(9997),
    [anon_sym_DASH_GT_GT] = ACTIONS(9992),
    [anon_sym_unique0] = ACTIONS(9997),
    [anon_sym_priority] = ACTIONS(9997),
    [anon_sym_casez] = ACTIONS(9997),
    [anon_sym_casex] = ACTIONS(9997),
    [anon_sym_randcase] = ACTIONS(9997),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9992),
    [anon_sym_forever] = ACTIONS(9997),
    [anon_sym_while] = ACTIONS(9997),
    [anon_sym_do] = ACTIONS(9997),
    [anon_sym_this] = ACTIONS(9997),
    [anon_sym_DASH_DASH] = ACTIONS(9992),
    [anon_sym_LPAREN_STAR] = ACTIONS(10059),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(10062),
    [anon_sym_DOLLARroot] = ACTIONS(9997),
    [anon_sym_DOLLARunit] = ACTIONS(10065),
    [sym_system_tf_identifier] = ACTIONS(9997),
  },
  [4301] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(5199),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4302] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4782),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4306),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4306),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4303] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7046),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4304] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1073),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4335),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4335),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4305] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6443),
    [sym_assert_property_statement] = STATE(6443),
    [sym_assume_property_statement] = STATE(6443),
    [sym_cover_property_statement] = STATE(6443),
    [sym_expect_property_statement] = STATE(6443),
    [sym_cover_sequence_statement] = STATE(6443),
    [sym_restrict_property_statement] = STATE(6443),
    [sym_checker_instantiation] = STATE(6443),
    [sym_blocking_assignment] = STATE(18302),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18302),
    [sym_procedural_continuous_assignment] = STATE(18302),
    [sym_seq_block] = STATE(6443),
    [sym_par_block] = STATE(6443),
    [sym_statement_item] = STATE(6508),
    [sym_procedural_timing_control_statement] = STATE(6443),
    [sym_delay_control] = STATE(3360),
    [sym_event_control] = STATE(3360),
    [sym__procedural_timing_control] = STATE(3360),
    [sym_jump_statement] = STATE(6443),
    [sym_wait_statement] = STATE(6443),
    [sym_event_trigger] = STATE(6443),
    [sym_disable_statement] = STATE(6443),
    [sym_conditional_statement] = STATE(6443),
    [sym_unique_priority] = STATE(13943),
    [sym_case_statement] = STATE(6443),
    [sym_case_keyword] = STATE(20319),
    [sym_randcase_statement] = STATE(6443),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6443),
    [sym__procedural_assertion_statement] = STATE(6443),
    [sym__immediate_assertion_statement] = STATE(6443),
    [sym__simple_immediate_assertion_statement] = STATE(6443),
    [sym_simple_immediate_assert_statement] = STATE(6443),
    [sym_simple_immediate_assume_statement] = STATE(6443),
    [sym_simple_immediate_cover_statement] = STATE(6443),
    [sym__deferred_immediate_assertion_statement] = STATE(6443),
    [sym_deferred_immediate_assert_statement] = STATE(6443),
    [sym_deferred_immediate_assume_statement] = STATE(6443),
    [sym_deferred_immediate_cover_statement] = STATE(6443),
    [sym_clocking_drive] = STATE(18302),
    [sym_cycle_delay] = STATE(3360),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18302),
    [sym_inc_or_dec_expression] = STATE(18302),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9464),
    [sym_package_scope] = STATE(12858),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9792),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10094),
    [anon_sym_foreach] = ACTIONS(10096),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10098),
    [anon_sym_assume] = ACTIONS(10100),
    [anon_sym_cover] = ACTIONS(10102),
    [anon_sym_expect] = ACTIONS(10104),
    [anon_sym_restrict] = ACTIONS(1154),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9808),
    [anon_sym_for] = ACTIONS(10106),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9812),
    [anon_sym_repeat] = ACTIONS(10108),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9816),
    [anon_sym_break] = ACTIONS(9818),
    [anon_sym_continue] = ACTIONS(9818),
    [anon_sym_wait] = ACTIONS(10110),
    [anon_sym_wait_order] = ACTIONS(10112),
    [anon_sym_DASH_GT] = ACTIONS(9824),
    [anon_sym_DASH_GT_GT] = ACTIONS(9826),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9828),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10114),
    [anon_sym_while] = ACTIONS(10108),
    [anon_sym_do] = ACTIONS(9832),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4306] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(5199),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4307] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4937),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4308] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4652),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3730),
    [sym_event_control] = STATE(3730),
    [sym__procedural_timing_control] = STATE(3730),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13965),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3730),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9321),
    [anon_sym_foreach] = ACTIONS(9325),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9327),
    [anon_sym_assume] = ACTIONS(9329),
    [anon_sym_cover] = ACTIONS(9331),
    [anon_sym_expect] = ACTIONS(9333),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(9337),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(9341),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(9347),
    [anon_sym_wait_order] = ACTIONS(9349),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9357),
    [anon_sym_while] = ACTIONS(9341),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4309] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1073),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4318),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4318),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4310] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6803),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4311] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7033),
    [sym_assert_property_statement] = STATE(7033),
    [sym_assume_property_statement] = STATE(7033),
    [sym_cover_property_statement] = STATE(7033),
    [sym_expect_property_statement] = STATE(7033),
    [sym_cover_sequence_statement] = STATE(7033),
    [sym_restrict_property_statement] = STATE(7033),
    [sym_checker_instantiation] = STATE(7033),
    [sym_blocking_assignment] = STATE(20048),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20048),
    [sym_procedural_continuous_assignment] = STATE(20048),
    [sym_seq_block] = STATE(7033),
    [sym_par_block] = STATE(7033),
    [sym_statement_item] = STATE(7062),
    [sym_procedural_timing_control_statement] = STATE(7033),
    [sym_delay_control] = STATE(3358),
    [sym_event_control] = STATE(3358),
    [sym__procedural_timing_control] = STATE(3358),
    [sym_jump_statement] = STATE(7033),
    [sym_wait_statement] = STATE(7033),
    [sym_event_trigger] = STATE(7033),
    [sym_disable_statement] = STATE(7033),
    [sym_conditional_statement] = STATE(7033),
    [sym_unique_priority] = STATE(13945),
    [sym_case_statement] = STATE(7033),
    [sym_case_keyword] = STATE(20330),
    [sym_randcase_statement] = STATE(7033),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7033),
    [sym__procedural_assertion_statement] = STATE(7033),
    [sym__immediate_assertion_statement] = STATE(7033),
    [sym__simple_immediate_assertion_statement] = STATE(7033),
    [sym_simple_immediate_assert_statement] = STATE(7033),
    [sym_simple_immediate_assume_statement] = STATE(7033),
    [sym_simple_immediate_cover_statement] = STATE(7033),
    [sym__deferred_immediate_assertion_statement] = STATE(7033),
    [sym_deferred_immediate_assert_statement] = STATE(7033),
    [sym_deferred_immediate_assume_statement] = STATE(7033),
    [sym_deferred_immediate_cover_statement] = STATE(7033),
    [sym_clocking_drive] = STATE(20048),
    [sym_cycle_delay] = STATE(3358),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20048),
    [sym_inc_or_dec_expression] = STATE(20048),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4286),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9508),
    [sym_package_scope] = STATE(12861),
    [aux_sym__description_repeat1] = STATE(4286),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9407),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9915),
    [anon_sym_foreach] = ACTIONS(9917),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9919),
    [anon_sym_assume] = ACTIONS(9921),
    [anon_sym_cover] = ACTIONS(9923),
    [anon_sym_expect] = ACTIONS(9925),
    [anon_sym_restrict] = ACTIONS(9423),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9425),
    [anon_sym_for] = ACTIONS(9927),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9429),
    [anon_sym_repeat] = ACTIONS(9929),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9433),
    [anon_sym_break] = ACTIONS(9435),
    [anon_sym_continue] = ACTIONS(9435),
    [anon_sym_wait] = ACTIONS(9931),
    [anon_sym_wait_order] = ACTIONS(9933),
    [anon_sym_DASH_GT] = ACTIONS(9441),
    [anon_sym_DASH_GT_GT] = ACTIONS(9443),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9445),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9935),
    [anon_sym_while] = ACTIONS(9929),
    [anon_sym_do] = ACTIONS(9449),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4312] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7203),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4315),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4315),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4313] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1686),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1688),
    [aux_sym_id_directive_token1] = ACTIONS(1686),
    [aux_sym_id_directive_token2] = ACTIONS(1686),
    [aux_sym_id_directive_token3] = ACTIONS(1686),
    [aux_sym_id_directive_token4] = ACTIONS(1688),
    [aux_sym_zero_directive_token1] = ACTIONS(1686),
    [aux_sym_zero_directive_token2] = ACTIONS(1686),
    [aux_sym_zero_directive_token3] = ACTIONS(1686),
    [aux_sym_zero_directive_token4] = ACTIONS(1686),
    [aux_sym_zero_directive_token5] = ACTIONS(1686),
    [aux_sym_zero_directive_token6] = ACTIONS(1686),
    [aux_sym_zero_directive_token7] = ACTIONS(1686),
    [aux_sym_zero_directive_token8] = ACTIONS(1686),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1686),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1686),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1686),
    [aux_sym_begin_keywords_token1] = ACTIONS(1686),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_extern] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_class] = ACTIONS(1688),
    [anon_sym_endclass] = ACTIONS(1688),
    [anon_sym_pure] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_RBRACE] = ACTIONS(1686),
    [anon_sym_iff] = ACTIONS(1688),
    [anon_sym_rand] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_function] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_protected] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_randc] = ACTIONS(1688),
    [anon_sym_constraint] = ACTIONS(1688),
    [anon_sym_u2013_GT] = ACTIONS(1686),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_localparam] = ACTIONS(1688),
    [anon_sym_parameter] = ACTIONS(1688),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_task] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_dist] = ACTIONS(1688),
    [anon_sym_covergroup] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARunit] = ACTIONS(1686),
  },
  [4314] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4315] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7245),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4316] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(9066),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4320),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4320),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4317] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(8993),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4318] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1166),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4319] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(9066),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4325),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4325),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4320] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(9128),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3741),
    [sym_event_control] = STATE(3741),
    [sym__procedural_timing_control] = STATE(3741),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13966),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3741),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9365),
    [anon_sym_foreach] = ACTIONS(9369),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9371),
    [anon_sym_assume] = ACTIONS(9373),
    [anon_sym_cover] = ACTIONS(9375),
    [anon_sym_expect] = ACTIONS(9377),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9381),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9385),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9391),
    [anon_sym_wait_order] = ACTIONS(9393),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9401),
    [anon_sym_while] = ACTIONS(9385),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4321] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4937),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4322] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6905),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4285),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4285),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4323] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1682),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1684),
    [aux_sym_id_directive_token1] = ACTIONS(1682),
    [aux_sym_id_directive_token2] = ACTIONS(1682),
    [aux_sym_id_directive_token3] = ACTIONS(1682),
    [aux_sym_id_directive_token4] = ACTIONS(1684),
    [aux_sym_zero_directive_token1] = ACTIONS(1682),
    [aux_sym_zero_directive_token2] = ACTIONS(1682),
    [aux_sym_zero_directive_token3] = ACTIONS(1682),
    [aux_sym_zero_directive_token4] = ACTIONS(1682),
    [aux_sym_zero_directive_token5] = ACTIONS(1682),
    [aux_sym_zero_directive_token6] = ACTIONS(1682),
    [aux_sym_zero_directive_token7] = ACTIONS(1682),
    [aux_sym_zero_directive_token8] = ACTIONS(1682),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1682),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1682),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1682),
    [aux_sym_begin_keywords_token1] = ACTIONS(1682),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_extern] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_class] = ACTIONS(1684),
    [anon_sym_endclass] = ACTIONS(1684),
    [anon_sym_pure] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_RBRACE] = ACTIONS(1682),
    [anon_sym_iff] = ACTIONS(1684),
    [anon_sym_rand] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_function] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_protected] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_randc] = ACTIONS(1684),
    [anon_sym_constraint] = ACTIONS(1684),
    [anon_sym_u2013_GT] = ACTIONS(1682),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_localparam] = ACTIONS(1684),
    [anon_sym_parameter] = ACTIONS(1684),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_task] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_dist] = ACTIONS(1684),
    [anon_sym_covergroup] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARunit] = ACTIONS(1682),
  },
  [4324] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(4965),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4325] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(9128),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4326] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(9082),
    [sym_assert_property_statement] = STATE(9082),
    [sym_assume_property_statement] = STATE(9082),
    [sym_cover_property_statement] = STATE(9082),
    [sym_expect_property_statement] = STATE(9082),
    [sym_cover_sequence_statement] = STATE(9082),
    [sym_restrict_property_statement] = STATE(9082),
    [sym_checker_instantiation] = STATE(9082),
    [sym_blocking_assignment] = STATE(20125),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20125),
    [sym_procedural_continuous_assignment] = STATE(20125),
    [sym_seq_block] = STATE(9082),
    [sym_par_block] = STATE(9082),
    [sym_statement_item] = STATE(8993),
    [sym_procedural_timing_control_statement] = STATE(9082),
    [sym_delay_control] = STATE(3548),
    [sym_event_control] = STATE(3548),
    [sym__procedural_timing_control] = STATE(3548),
    [sym_jump_statement] = STATE(9082),
    [sym_wait_statement] = STATE(9082),
    [sym_event_trigger] = STATE(9082),
    [sym_disable_statement] = STATE(9082),
    [sym_conditional_statement] = STATE(9082),
    [sym_unique_priority] = STATE(13952),
    [sym_case_statement] = STATE(9082),
    [sym_case_keyword] = STATE(20351),
    [sym_randcase_statement] = STATE(9082),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(9082),
    [sym__procedural_assertion_statement] = STATE(9082),
    [sym__immediate_assertion_statement] = STATE(9082),
    [sym__simple_immediate_assertion_statement] = STATE(9082),
    [sym_simple_immediate_assert_statement] = STATE(9082),
    [sym_simple_immediate_assume_statement] = STATE(9082),
    [sym_simple_immediate_cover_statement] = STATE(9082),
    [sym__deferred_immediate_assertion_statement] = STATE(9082),
    [sym_deferred_immediate_assert_statement] = STATE(9082),
    [sym_deferred_immediate_assume_statement] = STATE(9082),
    [sym_deferred_immediate_cover_statement] = STATE(9082),
    [sym_clocking_drive] = STATE(20125),
    [sym_cycle_delay] = STATE(3548),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20125),
    [sym_inc_or_dec_expression] = STATE(20125),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9516),
    [sym_package_scope] = STATE(12864),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9363),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9961),
    [anon_sym_foreach] = ACTIONS(9963),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9965),
    [anon_sym_assume] = ACTIONS(9967),
    [anon_sym_cover] = ACTIONS(9969),
    [anon_sym_expect] = ACTIONS(9971),
    [anon_sym_restrict] = ACTIONS(834),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9379),
    [anon_sym_for] = ACTIONS(9973),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9383),
    [anon_sym_repeat] = ACTIONS(9975),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9387),
    [anon_sym_break] = ACTIONS(9389),
    [anon_sym_continue] = ACTIONS(9389),
    [anon_sym_wait] = ACTIONS(9977),
    [anon_sym_wait_order] = ACTIONS(9979),
    [anon_sym_DASH_GT] = ACTIONS(9395),
    [anon_sym_DASH_GT_GT] = ACTIONS(9397),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9399),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9981),
    [anon_sym_while] = ACTIONS(9975),
    [anon_sym_do] = ACTIONS(9403),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4327] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(5081),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3486),
    [sym_event_control] = STATE(3486),
    [sym__procedural_timing_control] = STATE(3486),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13928),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3486),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4288),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4288),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10150),
    [anon_sym_foreach] = ACTIONS(10152),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10154),
    [anon_sym_assume] = ACTIONS(10156),
    [anon_sym_cover] = ACTIONS(10158),
    [anon_sym_expect] = ACTIONS(10160),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(10162),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(10164),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(10166),
    [anon_sym_wait_order] = ACTIONS(10168),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10170),
    [anon_sym_while] = ACTIONS(10164),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4328] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6905),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3347),
    [sym_event_control] = STATE(3347),
    [sym__procedural_timing_control] = STATE(3347),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13811),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3347),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4310),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4310),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2151),
    [anon_sym_foreach] = ACTIONS(2153),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2167),
    [anon_sym_assume] = ACTIONS(2169),
    [anon_sym_cover] = ACTIONS(2171),
    [anon_sym_expect] = ACTIONS(2173),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(2185),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(2197),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(2207),
    [anon_sym_wait_order] = ACTIONS(2209),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2219),
    [anon_sym_while] = ACTIONS(2197),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4329] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7245),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3583),
    [sym_event_control] = STATE(3583),
    [sym__procedural_timing_control] = STATE(3583),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13936),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3583),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(2714),
    [anon_sym_foreach] = ACTIONS(2716),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(2726),
    [anon_sym_assume] = ACTIONS(2728),
    [anon_sym_cover] = ACTIONS(2730),
    [anon_sym_expect] = ACTIONS(2732),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(2742),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(2746),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(2752),
    [anon_sym_wait_order] = ACTIONS(2754),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(2762),
    [anon_sym_while] = ACTIONS(2746),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4330] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1082),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3399),
    [sym_event_control] = STATE(3399),
    [sym__procedural_timing_control] = STATE(3399),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13389),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3399),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10116),
    [anon_sym_foreach] = ACTIONS(10118),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10120),
    [anon_sym_assume] = ACTIONS(10122),
    [anon_sym_cover] = ACTIONS(10124),
    [anon_sym_expect] = ACTIONS(10126),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(10128),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(10130),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(10132),
    [anon_sym_wait_order] = ACTIONS(10134),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10136),
    [anon_sym_while] = ACTIONS(10130),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4331] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(7263),
    [sym_assert_property_statement] = STATE(7263),
    [sym_assume_property_statement] = STATE(7263),
    [sym_cover_property_statement] = STATE(7263),
    [sym_expect_property_statement] = STATE(7263),
    [sym_cover_sequence_statement] = STATE(7263),
    [sym_restrict_property_statement] = STATE(7263),
    [sym_checker_instantiation] = STATE(7263),
    [sym_blocking_assignment] = STATE(20265),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(20265),
    [sym_procedural_continuous_assignment] = STATE(20265),
    [sym_seq_block] = STATE(7263),
    [sym_par_block] = STATE(7263),
    [sym_statement_item] = STATE(7252),
    [sym_procedural_timing_control_statement] = STATE(7263),
    [sym_delay_control] = STATE(3697),
    [sym_event_control] = STATE(3697),
    [sym__procedural_timing_control] = STATE(3697),
    [sym_jump_statement] = STATE(7263),
    [sym_wait_statement] = STATE(7263),
    [sym_event_trigger] = STATE(7263),
    [sym_disable_statement] = STATE(7263),
    [sym_conditional_statement] = STATE(7263),
    [sym_unique_priority] = STATE(13956),
    [sym_case_statement] = STATE(7263),
    [sym_case_keyword] = STATE(20305),
    [sym_randcase_statement] = STATE(7263),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(7263),
    [sym__procedural_assertion_statement] = STATE(7263),
    [sym__immediate_assertion_statement] = STATE(7263),
    [sym__simple_immediate_assertion_statement] = STATE(7263),
    [sym_simple_immediate_assert_statement] = STATE(7263),
    [sym_simple_immediate_assume_statement] = STATE(7263),
    [sym_simple_immediate_cover_statement] = STATE(7263),
    [sym__deferred_immediate_assertion_statement] = STATE(7263),
    [sym_deferred_immediate_assert_statement] = STATE(7263),
    [sym_deferred_immediate_assume_statement] = STATE(7263),
    [sym_deferred_immediate_cover_statement] = STATE(7263),
    [sym_clocking_drive] = STATE(20265),
    [sym_cycle_delay] = STATE(3697),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(20265),
    [sym_inc_or_dec_expression] = STATE(20265),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9499),
    [sym_package_scope] = STATE(12860),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2708),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9588),
    [anon_sym_foreach] = ACTIONS(9592),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9594),
    [anon_sym_assume] = ACTIONS(9596),
    [anon_sym_cover] = ACTIONS(9598),
    [anon_sym_expect] = ACTIONS(9600),
    [anon_sym_restrict] = ACTIONS(2734),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2736),
    [anon_sym_for] = ACTIONS(9602),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2744),
    [anon_sym_repeat] = ACTIONS(9604),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2748),
    [anon_sym_break] = ACTIONS(2750),
    [anon_sym_continue] = ACTIONS(2750),
    [anon_sym_wait] = ACTIONS(9606),
    [anon_sym_wait_order] = ACTIONS(9608),
    [anon_sym_DASH_GT] = ACTIONS(2756),
    [anon_sym_DASH_GT_GT] = ACTIONS(2758),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2760),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9610),
    [anon_sym_while] = ACTIONS(9604),
    [anon_sym_do] = ACTIONS(2764),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4332] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(5001),
    [sym_assert_property_statement] = STATE(5001),
    [sym_assume_property_statement] = STATE(5001),
    [sym_cover_property_statement] = STATE(5001),
    [sym_expect_property_statement] = STATE(5001),
    [sym_cover_sequence_statement] = STATE(5001),
    [sym_restrict_property_statement] = STATE(5001),
    [sym_checker_instantiation] = STATE(5001),
    [sym_blocking_assignment] = STATE(18304),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18304),
    [sym_procedural_continuous_assignment] = STATE(18304),
    [sym_seq_block] = STATE(5001),
    [sym_par_block] = STATE(5001),
    [sym_statement_item] = STATE(4652),
    [sym_procedural_timing_control_statement] = STATE(5001),
    [sym_delay_control] = STATE(3423),
    [sym_event_control] = STATE(3423),
    [sym__procedural_timing_control] = STATE(3423),
    [sym_jump_statement] = STATE(5001),
    [sym_wait_statement] = STATE(5001),
    [sym_event_trigger] = STATE(5001),
    [sym_disable_statement] = STATE(5001),
    [sym_conditional_statement] = STATE(5001),
    [sym_unique_priority] = STATE(13950),
    [sym_case_statement] = STATE(5001),
    [sym_case_keyword] = STATE(20341),
    [sym_randcase_statement] = STATE(5001),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(5001),
    [sym__procedural_assertion_statement] = STATE(5001),
    [sym__immediate_assertion_statement] = STATE(5001),
    [sym__simple_immediate_assertion_statement] = STATE(5001),
    [sym_simple_immediate_assert_statement] = STATE(5001),
    [sym_simple_immediate_assume_statement] = STATE(5001),
    [sym_simple_immediate_cover_statement] = STATE(5001),
    [sym__deferred_immediate_assertion_statement] = STATE(5001),
    [sym_deferred_immediate_assert_statement] = STATE(5001),
    [sym_deferred_immediate_assume_statement] = STATE(5001),
    [sym_deferred_immediate_cover_statement] = STATE(5001),
    [sym_clocking_drive] = STATE(18304),
    [sym_cycle_delay] = STATE(3423),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18304),
    [sym_inc_or_dec_expression] = STATE(18304),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9384),
    [sym_package_scope] = STATE(12862),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9319),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(10072),
    [anon_sym_foreach] = ACTIONS(10074),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(10076),
    [anon_sym_assume] = ACTIONS(10078),
    [anon_sym_cover] = ACTIONS(10080),
    [anon_sym_expect] = ACTIONS(10082),
    [anon_sym_restrict] = ACTIONS(926),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9335),
    [anon_sym_for] = ACTIONS(10084),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9339),
    [anon_sym_repeat] = ACTIONS(10086),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9343),
    [anon_sym_break] = ACTIONS(9345),
    [anon_sym_continue] = ACTIONS(9345),
    [anon_sym_wait] = ACTIONS(10088),
    [anon_sym_wait_order] = ACTIONS(10090),
    [anon_sym_DASH_GT] = ACTIONS(9351),
    [anon_sym_DASH_GT_GT] = ACTIONS(9353),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9355),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(10092),
    [anon_sym_while] = ACTIONS(10086),
    [anon_sym_do] = ACTIONS(9359),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4333] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(6794),
    [sym_assert_property_statement] = STATE(6794),
    [sym_assume_property_statement] = STATE(6794),
    [sym_cover_property_statement] = STATE(6794),
    [sym_expect_property_statement] = STATE(6794),
    [sym_cover_sequence_statement] = STATE(6794),
    [sym_restrict_property_statement] = STATE(6794),
    [sym_checker_instantiation] = STATE(6794),
    [sym_blocking_assignment] = STATE(17521),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17521),
    [sym_procedural_continuous_assignment] = STATE(17521),
    [sym_seq_block] = STATE(6794),
    [sym_par_block] = STATE(6794),
    [sym_statement_item] = STATE(6717),
    [sym_procedural_timing_control_statement] = STATE(6794),
    [sym_delay_control] = STATE(3665),
    [sym_event_control] = STATE(3665),
    [sym__procedural_timing_control] = STATE(3665),
    [sym_jump_statement] = STATE(6794),
    [sym_wait_statement] = STATE(6794),
    [sym_event_trigger] = STATE(6794),
    [sym_disable_statement] = STATE(6794),
    [sym_conditional_statement] = STATE(6794),
    [sym_unique_priority] = STATE(13948),
    [sym_case_statement] = STATE(6794),
    [sym_case_keyword] = STATE(20164),
    [sym_randcase_statement] = STATE(6794),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(6794),
    [sym__procedural_assertion_statement] = STATE(6794),
    [sym__immediate_assertion_statement] = STATE(6794),
    [sym__simple_immediate_assertion_statement] = STATE(6794),
    [sym_simple_immediate_assert_statement] = STATE(6794),
    [sym_simple_immediate_assume_statement] = STATE(6794),
    [sym_simple_immediate_cover_statement] = STATE(6794),
    [sym__deferred_immediate_assertion_statement] = STATE(6794),
    [sym_deferred_immediate_assert_statement] = STATE(6794),
    [sym_deferred_immediate_assume_statement] = STATE(6794),
    [sym_deferred_immediate_cover_statement] = STATE(6794),
    [sym_clocking_drive] = STATE(17521),
    [sym_cycle_delay] = STATE(3665),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17521),
    [sym_inc_or_dec_expression] = STATE(17521),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9486),
    [sym_package_scope] = STATE(12859),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(2139),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9746),
    [anon_sym_foreach] = ACTIONS(9750),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9752),
    [anon_sym_assume] = ACTIONS(9754),
    [anon_sym_cover] = ACTIONS(9756),
    [anon_sym_expect] = ACTIONS(9758),
    [anon_sym_restrict] = ACTIONS(2175),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(2181),
    [anon_sym_for] = ACTIONS(9760),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(2195),
    [anon_sym_repeat] = ACTIONS(9762),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(2203),
    [anon_sym_break] = ACTIONS(2205),
    [anon_sym_continue] = ACTIONS(2205),
    [anon_sym_wait] = ACTIONS(9764),
    [anon_sym_wait_order] = ACTIONS(9766),
    [anon_sym_DASH_GT] = ACTIONS(2211),
    [anon_sym_DASH_GT_GT] = ACTIONS(2213),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(2215),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9768),
    [anon_sym_while] = ACTIONS(9762),
    [anon_sym_do] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4334] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(4594),
    [sym_assert_property_statement] = STATE(4594),
    [sym_assume_property_statement] = STATE(4594),
    [sym_cover_property_statement] = STATE(4594),
    [sym_expect_property_statement] = STATE(4594),
    [sym_cover_sequence_statement] = STATE(4594),
    [sym_restrict_property_statement] = STATE(4594),
    [sym_checker_instantiation] = STATE(4594),
    [sym_blocking_assignment] = STATE(18682),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(18682),
    [sym_procedural_continuous_assignment] = STATE(18682),
    [sym_seq_block] = STATE(4594),
    [sym_par_block] = STATE(4594),
    [sym_statement_item] = STATE(5081),
    [sym_procedural_timing_control_statement] = STATE(4594),
    [sym_delay_control] = STATE(3681),
    [sym_event_control] = STATE(3681),
    [sym__procedural_timing_control] = STATE(3681),
    [sym_jump_statement] = STATE(4594),
    [sym_wait_statement] = STATE(4594),
    [sym_event_trigger] = STATE(4594),
    [sym_disable_statement] = STATE(4594),
    [sym_conditional_statement] = STATE(4594),
    [sym_unique_priority] = STATE(13954),
    [sym_case_statement] = STATE(4594),
    [sym_case_keyword] = STATE(20290),
    [sym_randcase_statement] = STATE(4594),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(4594),
    [sym__procedural_assertion_statement] = STATE(4594),
    [sym__immediate_assertion_statement] = STATE(4594),
    [sym__simple_immediate_assertion_statement] = STATE(4594),
    [sym_simple_immediate_assert_statement] = STATE(4594),
    [sym_simple_immediate_assume_statement] = STATE(4594),
    [sym_simple_immediate_cover_statement] = STATE(4594),
    [sym__deferred_immediate_assertion_statement] = STATE(4594),
    [sym_deferred_immediate_assert_statement] = STATE(4594),
    [sym_deferred_immediate_assume_statement] = STATE(4594),
    [sym_deferred_immediate_cover_statement] = STATE(4594),
    [sym_clocking_drive] = STATE(18682),
    [sym_cycle_delay] = STATE(3681),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(18682),
    [sym_inc_or_dec_expression] = STATE(18682),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4324),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9449),
    [sym_package_scope] = STATE(12840),
    [aux_sym__description_repeat1] = STATE(4324),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9702),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9704),
    [anon_sym_foreach] = ACTIONS(9708),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9710),
    [anon_sym_assume] = ACTIONS(9712),
    [anon_sym_cover] = ACTIONS(9714),
    [anon_sym_expect] = ACTIONS(9716),
    [anon_sym_restrict] = ACTIONS(1050),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9718),
    [anon_sym_for] = ACTIONS(9720),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9722),
    [anon_sym_repeat] = ACTIONS(9724),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9726),
    [anon_sym_break] = ACTIONS(9728),
    [anon_sym_continue] = ACTIONS(9728),
    [anon_sym_wait] = ACTIONS(9730),
    [anon_sym_wait_order] = ACTIONS(9732),
    [anon_sym_DASH_GT] = ACTIONS(9734),
    [anon_sym_DASH_GT_GT] = ACTIONS(9736),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9738),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9740),
    [anon_sym_while] = ACTIONS(9724),
    [anon_sym_do] = ACTIONS(9742),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4335] = {
    [sym_class_scope] = STATE(14584),
    [sym_class_type] = STATE(19534),
    [sym_integer_atom_type] = STATE(17271),
    [sym_type_reference] = STATE(17271),
    [sym__concurrent_assertion_statement] = STATE(1128),
    [sym_assert_property_statement] = STATE(1128),
    [sym_assume_property_statement] = STATE(1128),
    [sym_cover_property_statement] = STATE(1128),
    [sym_expect_property_statement] = STATE(1128),
    [sym_cover_sequence_statement] = STATE(1128),
    [sym_restrict_property_statement] = STATE(1128),
    [sym_checker_instantiation] = STATE(1128),
    [sym_blocking_assignment] = STATE(17969),
    [sym_operator_assignment] = STATE(18270),
    [sym_nonblocking_assignment] = STATE(17969),
    [sym_procedural_continuous_assignment] = STATE(17969),
    [sym_seq_block] = STATE(1128),
    [sym_par_block] = STATE(1128),
    [sym_statement_item] = STATE(1166),
    [sym_procedural_timing_control_statement] = STATE(1128),
    [sym_delay_control] = STATE(3635),
    [sym_event_control] = STATE(3635),
    [sym__procedural_timing_control] = STATE(3635),
    [sym_jump_statement] = STATE(1128),
    [sym_wait_statement] = STATE(1128),
    [sym_event_trigger] = STATE(1128),
    [sym_disable_statement] = STATE(1128),
    [sym_conditional_statement] = STATE(1128),
    [sym_unique_priority] = STATE(13974),
    [sym_case_statement] = STATE(1128),
    [sym_case_keyword] = STATE(19763),
    [sym_randcase_statement] = STATE(1128),
    [sym__assignment_pattern_expression_type] = STATE(17271),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_loop_statement] = STATE(1128),
    [sym__procedural_assertion_statement] = STATE(1128),
    [sym__immediate_assertion_statement] = STATE(1128),
    [sym__simple_immediate_assertion_statement] = STATE(1128),
    [sym_simple_immediate_assert_statement] = STATE(1128),
    [sym_simple_immediate_assume_statement] = STATE(1128),
    [sym_simple_immediate_cover_statement] = STATE(1128),
    [sym__deferred_immediate_assertion_statement] = STATE(1128),
    [sym_deferred_immediate_assert_statement] = STATE(1128),
    [sym_deferred_immediate_assume_statement] = STATE(1128),
    [sym_deferred_immediate_cover_statement] = STATE(1128),
    [sym_clocking_drive] = STATE(17969),
    [sym_cycle_delay] = STATE(3635),
    [sym_clockvar] = STATE(12341),
    [sym_clockvar_expression] = STATE(19779),
    [sym_streaming_concatenation] = STATE(10857),
    [sym_system_tf_call] = STATE(17969),
    [sym_inc_or_dec_expression] = STATE(17969),
    [sym_implicit_class_handle] = STATE(19785),
    [sym_variable_lvalue] = STATE(10862),
    [sym_nonrange_variable_lvalue] = STATE(19794),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(9476),
    [sym_package_scope] = STATE(12804),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13087),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(2133),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(2135),
    [anon_sym_disable] = ACTIONS(9275),
    [anon_sym_local] = ACTIONS(2145),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_if] = ACTIONS(9277),
    [anon_sym_foreach] = ACTIONS(9281),
    [anon_sym_unique] = ACTIONS(2155),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_assert] = ACTIONS(9283),
    [anon_sym_assume] = ACTIONS(9285),
    [anon_sym_cover] = ACTIONS(9287),
    [anon_sym_expect] = ACTIONS(9289),
    [anon_sym_restrict] = ACTIONS(161),
    [anon_sym_case] = ACTIONS(2177),
    [anon_sym_POUND_POUND] = ACTIONS(2179),
    [anon_sym_begin] = ACTIONS(9291),
    [anon_sym_for] = ACTIONS(9293),
    [anon_sym_assign] = ACTIONS(2187),
    [anon_sym_deassign] = ACTIONS(2189),
    [anon_sym_force] = ACTIONS(2191),
    [anon_sym_release] = ACTIONS(2193),
    [anon_sym_fork] = ACTIONS(9295),
    [anon_sym_repeat] = ACTIONS(9297),
    [anon_sym_AT] = ACTIONS(2199),
    [anon_sym_AT_STAR] = ACTIONS(2201),
    [anon_sym_return] = ACTIONS(9299),
    [anon_sym_break] = ACTIONS(9301),
    [anon_sym_continue] = ACTIONS(9301),
    [anon_sym_wait] = ACTIONS(9303),
    [anon_sym_wait_order] = ACTIONS(9305),
    [anon_sym_DASH_GT] = ACTIONS(9307),
    [anon_sym_DASH_GT_GT] = ACTIONS(9309),
    [anon_sym_unique0] = ACTIONS(2155),
    [anon_sym_priority] = ACTIONS(2155),
    [anon_sym_casez] = ACTIONS(2177),
    [anon_sym_casex] = ACTIONS(2177),
    [anon_sym_randcase] = ACTIONS(9311),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(2217),
    [anon_sym_forever] = ACTIONS(9313),
    [anon_sym_while] = ACTIONS(9297),
    [anon_sym_do] = ACTIONS(9315),
    [anon_sym_this] = ACTIONS(2223),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(2227),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [4336] = {
    [sym_simple_identifier] = ACTIONS(5682),
    [anon_sym_wire] = ACTIONS(5682),
    [anon_sym_tri] = ACTIONS(5682),
    [anon_sym_tri0] = ACTIONS(5682),
    [anon_sym_tri1] = ACTIONS(5682),
    [anon_sym_wand] = ACTIONS(5682),
    [anon_sym_triand] = ACTIONS(5682),
    [anon_sym_wor] = ACTIONS(5682),
    [anon_sym_trior] = ACTIONS(5682),
    [anon_sym_trireg] = ACTIONS(5682),
    [anon_sym_uwire] = ACTIONS(5682),
    [anon_sym_SEMI] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5682),
    [anon_sym_interface] = ACTIONS(5682),
    [anon_sym_checker] = ACTIONS(5682),
    [anon_sym_virtual] = ACTIONS(5682),
    [anon_sym_class] = ACTIONS(5682),
    [anon_sym_type] = ACTIONS(5682),
    [anon_sym_DOLLARfatal] = ACTIONS(5684),
    [anon_sym_DOLLARerror] = ACTIONS(5684),
    [anon_sym_DOLLARwarning] = ACTIONS(5684),
    [anon_sym_DOLLARinfo] = ACTIONS(5684),
    [anon_sym_default] = ACTIONS(5682),
    [anon_sym_clocking] = ACTIONS(5682),
    [anon_sym_defparam] = ACTIONS(5682),
    [anon_sym_bind] = ACTIONS(5682),
    [anon_sym_rand] = ACTIONS(5682),
    [anon_sym_const] = ACTIONS(5682),
    [anon_sym_function] = ACTIONS(5682),
    [anon_sym_static] = ACTIONS(5682),
    [anon_sym_constraint] = ACTIONS(5682),
    [anon_sym_if] = ACTIONS(5682),
    [anon_sym_else] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_localparam] = ACTIONS(5682),
    [anon_sym_parameter] = ACTIONS(5682),
    [anon_sym_var] = ACTIONS(5682),
    [anon_sym_import] = ACTIONS(5682),
    [anon_sym_export] = ACTIONS(5682),
    [anon_sym_genvar] = ACTIONS(5682),
    [anon_sym_interconnect] = ACTIONS(5682),
    [anon_sym_typedef] = ACTIONS(5682),
    [anon_sym_enum] = ACTIONS(5682),
    [anon_sym_struct] = ACTIONS(5682),
    [anon_sym_union] = ACTIONS(5682),
    [anon_sym_nettype] = ACTIONS(5682),
    [anon_sym_automatic] = ACTIONS(5682),
    [anon_sym_string] = ACTIONS(5682),
    [anon_sym_chandle] = ACTIONS(5682),
    [anon_sym_event] = ACTIONS(5682),
    [anon_sym_byte] = ACTIONS(5682),
    [anon_sym_shortint] = ACTIONS(5682),
    [anon_sym_int] = ACTIONS(5682),
    [anon_sym_longint] = ACTIONS(5682),
    [anon_sym_integer] = ACTIONS(5682),
    [anon_sym_time] = ACTIONS(5682),
    [anon_sym_bit] = ACTIONS(5682),
    [anon_sym_logic] = ACTIONS(5682),
    [anon_sym_reg] = ACTIONS(5682),
    [anon_sym_shortreal] = ACTIONS(5682),
    [anon_sym_real] = ACTIONS(5682),
    [anon_sym_realtime] = ACTIONS(5682),
    [anon_sym_supply0] = ACTIONS(5682),
    [anon_sym_supply1] = ACTIONS(5682),
    [anon_sym_signed] = ACTIONS(5682),
    [anon_sym_unsigned] = ACTIONS(5682),
    [anon_sym_task] = ACTIONS(5682),
    [anon_sym_assert] = ACTIONS(5682),
    [anon_sym_property] = ACTIONS(5682),
    [anon_sym_assume] = ACTIONS(5682),
    [anon_sym_cover] = ACTIONS(5682),
    [anon_sym_sequence] = ACTIONS(5682),
    [anon_sym_restrict] = ACTIONS(5682),
    [anon_sym_not] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_case] = ACTIONS(5682),
    [anon_sym_always] = ACTIONS(5682),
    [anon_sym_covergroup] = ACTIONS(5682),
    [anon_sym_end] = ACTIONS(5682),
    [anon_sym_let] = ACTIONS(5682),
    [anon_sym_pulldown] = ACTIONS(5682),
    [anon_sym_pullup] = ACTIONS(5682),
    [anon_sym_cmos] = ACTIONS(5682),
    [anon_sym_rcmos] = ACTIONS(5682),
    [anon_sym_bufif0] = ACTIONS(5682),
    [anon_sym_bufif1] = ACTIONS(5682),
    [anon_sym_notif0] = ACTIONS(5682),
    [anon_sym_notif1] = ACTIONS(5682),
    [anon_sym_nmos] = ACTIONS(5682),
    [anon_sym_pmos] = ACTIONS(5682),
    [anon_sym_rnmos] = ACTIONS(5682),
    [anon_sym_rpmos] = ACTIONS(5682),
    [anon_sym_nand] = ACTIONS(5682),
    [anon_sym_nor] = ACTIONS(5682),
    [anon_sym_xor] = ACTIONS(5682),
    [anon_sym_xnor] = ACTIONS(5682),
    [anon_sym_buf] = ACTIONS(5682),
    [anon_sym_tranif0] = ACTIONS(5682),
    [anon_sym_tranif1] = ACTIONS(5682),
    [anon_sym_rtranif1] = ACTIONS(5682),
    [anon_sym_rtranif0] = ACTIONS(5682),
    [anon_sym_tran] = ACTIONS(5682),
    [anon_sym_rtran] = ACTIONS(5682),
    [anon_sym_generate] = ACTIONS(5682),
    [anon_sym_for] = ACTIONS(5682),
    [anon_sym_initial] = ACTIONS(5682),
    [anon_sym_assign] = ACTIONS(5682),
    [anon_sym_alias] = ACTIONS(5682),
    [anon_sym_always_comb] = ACTIONS(5682),
    [anon_sym_always_latch] = ACTIONS(5682),
    [anon_sym_always_ff] = ACTIONS(5682),
    [anon_sym_final] = ACTIONS(5682),
    [anon_sym_global] = ACTIONS(5682),
    [anon_sym_LPAREN_STAR] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5684),
    [anon_sym_DOLLARunit] = ACTIONS(5684),
  },
  [4337] = {
    [sym_simple_identifier] = ACTIONS(4788),
    [anon_sym_wire] = ACTIONS(4788),
    [anon_sym_tri] = ACTIONS(4788),
    [anon_sym_tri0] = ACTIONS(4788),
    [anon_sym_tri1] = ACTIONS(4788),
    [anon_sym_wand] = ACTIONS(4788),
    [anon_sym_triand] = ACTIONS(4788),
    [anon_sym_wor] = ACTIONS(4788),
    [anon_sym_trior] = ACTIONS(4788),
    [anon_sym_trireg] = ACTIONS(4788),
    [anon_sym_uwire] = ACTIONS(4788),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_COLON] = ACTIONS(10395),
    [anon_sym_extern] = ACTIONS(4788),
    [anon_sym_interface] = ACTIONS(4788),
    [anon_sym_checker] = ACTIONS(4788),
    [anon_sym_virtual] = ACTIONS(4788),
    [anon_sym_class] = ACTIONS(4788),
    [anon_sym_type] = ACTIONS(4788),
    [anon_sym_DOLLARfatal] = ACTIONS(4786),
    [anon_sym_DOLLARerror] = ACTIONS(4786),
    [anon_sym_DOLLARwarning] = ACTIONS(4786),
    [anon_sym_DOLLARinfo] = ACTIONS(4786),
    [anon_sym_default] = ACTIONS(4788),
    [anon_sym_clocking] = ACTIONS(4788),
    [anon_sym_defparam] = ACTIONS(4788),
    [anon_sym_bind] = ACTIONS(4788),
    [anon_sym_rand] = ACTIONS(4788),
    [anon_sym_const] = ACTIONS(4788),
    [anon_sym_function] = ACTIONS(4788),
    [anon_sym_static] = ACTIONS(4788),
    [anon_sym_constraint] = ACTIONS(4788),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [anon_sym_localparam] = ACTIONS(4788),
    [anon_sym_parameter] = ACTIONS(4788),
    [anon_sym_var] = ACTIONS(4788),
    [anon_sym_import] = ACTIONS(4788),
    [anon_sym_export] = ACTIONS(4788),
    [anon_sym_genvar] = ACTIONS(4788),
    [anon_sym_interconnect] = ACTIONS(4788),
    [anon_sym_typedef] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_struct] = ACTIONS(4788),
    [anon_sym_union] = ACTIONS(4788),
    [anon_sym_nettype] = ACTIONS(4788),
    [anon_sym_automatic] = ACTIONS(4788),
    [anon_sym_string] = ACTIONS(4788),
    [anon_sym_chandle] = ACTIONS(4788),
    [anon_sym_event] = ACTIONS(4788),
    [anon_sym_byte] = ACTIONS(4788),
    [anon_sym_shortint] = ACTIONS(4788),
    [anon_sym_int] = ACTIONS(4788),
    [anon_sym_longint] = ACTIONS(4788),
    [anon_sym_integer] = ACTIONS(4788),
    [anon_sym_time] = ACTIONS(4788),
    [anon_sym_bit] = ACTIONS(4788),
    [anon_sym_logic] = ACTIONS(4788),
    [anon_sym_reg] = ACTIONS(4788),
    [anon_sym_shortreal] = ACTIONS(4788),
    [anon_sym_real] = ACTIONS(4788),
    [anon_sym_realtime] = ACTIONS(4788),
    [anon_sym_supply0] = ACTIONS(4788),
    [anon_sym_supply1] = ACTIONS(4788),
    [anon_sym_signed] = ACTIONS(4788),
    [anon_sym_unsigned] = ACTIONS(4788),
    [anon_sym_task] = ACTIONS(4788),
    [anon_sym_assert] = ACTIONS(4788),
    [anon_sym_property] = ACTIONS(4788),
    [anon_sym_assume] = ACTIONS(4788),
    [anon_sym_cover] = ACTIONS(4788),
    [anon_sym_sequence] = ACTIONS(4788),
    [anon_sym_restrict] = ACTIONS(4788),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_or] = ACTIONS(4788),
    [anon_sym_and] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_always] = ACTIONS(4788),
    [anon_sym_covergroup] = ACTIONS(4788),
    [anon_sym_let] = ACTIONS(4788),
    [anon_sym_pulldown] = ACTIONS(4788),
    [anon_sym_pullup] = ACTIONS(4788),
    [anon_sym_cmos] = ACTIONS(4788),
    [anon_sym_rcmos] = ACTIONS(4788),
    [anon_sym_bufif0] = ACTIONS(4788),
    [anon_sym_bufif1] = ACTIONS(4788),
    [anon_sym_notif0] = ACTIONS(4788),
    [anon_sym_notif1] = ACTIONS(4788),
    [anon_sym_nmos] = ACTIONS(4788),
    [anon_sym_pmos] = ACTIONS(4788),
    [anon_sym_rnmos] = ACTIONS(4788),
    [anon_sym_rpmos] = ACTIONS(4788),
    [anon_sym_nand] = ACTIONS(4788),
    [anon_sym_nor] = ACTIONS(4788),
    [anon_sym_xor] = ACTIONS(4788),
    [anon_sym_xnor] = ACTIONS(4788),
    [anon_sym_buf] = ACTIONS(4788),
    [anon_sym_tranif0] = ACTIONS(4788),
    [anon_sym_tranif1] = ACTIONS(4788),
    [anon_sym_rtranif1] = ACTIONS(4788),
    [anon_sym_rtranif0] = ACTIONS(4788),
    [anon_sym_tran] = ACTIONS(4788),
    [anon_sym_rtran] = ACTIONS(4788),
    [anon_sym_generate] = ACTIONS(4788),
    [anon_sym_endgenerate] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_initial] = ACTIONS(4788),
    [anon_sym_assign] = ACTIONS(4788),
    [anon_sym_alias] = ACTIONS(4788),
    [anon_sym_always_comb] = ACTIONS(4788),
    [anon_sym_always_latch] = ACTIONS(4788),
    [anon_sym_always_ff] = ACTIONS(4788),
    [anon_sym_final] = ACTIONS(4788),
    [anon_sym_global] = ACTIONS(4788),
    [anon_sym_LPAREN_STAR] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4786),
    [anon_sym_DOLLARunit] = ACTIONS(4786),
  },
  [4338] = {
    [sym_simple_identifier] = ACTIONS(4388),
    [anon_sym_wire] = ACTIONS(4388),
    [anon_sym_tri] = ACTIONS(4388),
    [anon_sym_tri0] = ACTIONS(4388),
    [anon_sym_tri1] = ACTIONS(4388),
    [anon_sym_wand] = ACTIONS(4388),
    [anon_sym_triand] = ACTIONS(4388),
    [anon_sym_wor] = ACTIONS(4388),
    [anon_sym_trior] = ACTIONS(4388),
    [anon_sym_trireg] = ACTIONS(4388),
    [anon_sym_uwire] = ACTIONS(4388),
    [anon_sym_SEMI] = ACTIONS(4386),
    [anon_sym_COLON] = ACTIONS(10397),
    [anon_sym_extern] = ACTIONS(4388),
    [anon_sym_interface] = ACTIONS(4388),
    [anon_sym_checker] = ACTIONS(4388),
    [anon_sym_virtual] = ACTIONS(4388),
    [anon_sym_class] = ACTIONS(4388),
    [anon_sym_type] = ACTIONS(4388),
    [anon_sym_DOLLARfatal] = ACTIONS(4386),
    [anon_sym_DOLLARerror] = ACTIONS(4386),
    [anon_sym_DOLLARwarning] = ACTIONS(4386),
    [anon_sym_DOLLARinfo] = ACTIONS(4386),
    [anon_sym_default] = ACTIONS(4388),
    [anon_sym_clocking] = ACTIONS(4388),
    [anon_sym_defparam] = ACTIONS(4388),
    [anon_sym_bind] = ACTIONS(4388),
    [anon_sym_rand] = ACTIONS(4388),
    [anon_sym_const] = ACTIONS(4388),
    [anon_sym_function] = ACTIONS(4388),
    [anon_sym_static] = ACTIONS(4388),
    [anon_sym_constraint] = ACTIONS(4388),
    [anon_sym_if] = ACTIONS(4388),
    [anon_sym_else] = ACTIONS(4388),
    [anon_sym_LBRACK] = ACTIONS(4386),
    [anon_sym_localparam] = ACTIONS(4388),
    [anon_sym_parameter] = ACTIONS(4388),
    [anon_sym_var] = ACTIONS(4388),
    [anon_sym_import] = ACTIONS(4388),
    [anon_sym_export] = ACTIONS(4388),
    [anon_sym_genvar] = ACTIONS(4388),
    [anon_sym_interconnect] = ACTIONS(4388),
    [anon_sym_typedef] = ACTIONS(4388),
    [anon_sym_enum] = ACTIONS(4388),
    [anon_sym_struct] = ACTIONS(4388),
    [anon_sym_union] = ACTIONS(4388),
    [anon_sym_nettype] = ACTIONS(4388),
    [anon_sym_automatic] = ACTIONS(4388),
    [anon_sym_string] = ACTIONS(4388),
    [anon_sym_chandle] = ACTIONS(4388),
    [anon_sym_event] = ACTIONS(4388),
    [anon_sym_byte] = ACTIONS(4388),
    [anon_sym_shortint] = ACTIONS(4388),
    [anon_sym_int] = ACTIONS(4388),
    [anon_sym_longint] = ACTIONS(4388),
    [anon_sym_integer] = ACTIONS(4388),
    [anon_sym_time] = ACTIONS(4388),
    [anon_sym_bit] = ACTIONS(4388),
    [anon_sym_logic] = ACTIONS(4388),
    [anon_sym_reg] = ACTIONS(4388),
    [anon_sym_shortreal] = ACTIONS(4388),
    [anon_sym_real] = ACTIONS(4388),
    [anon_sym_realtime] = ACTIONS(4388),
    [anon_sym_supply0] = ACTIONS(4388),
    [anon_sym_supply1] = ACTIONS(4388),
    [anon_sym_signed] = ACTIONS(4388),
    [anon_sym_unsigned] = ACTIONS(4388),
    [anon_sym_task] = ACTIONS(4388),
    [anon_sym_assert] = ACTIONS(4388),
    [anon_sym_property] = ACTIONS(4388),
    [anon_sym_assume] = ACTIONS(4388),
    [anon_sym_cover] = ACTIONS(4388),
    [anon_sym_sequence] = ACTIONS(4388),
    [anon_sym_restrict] = ACTIONS(4388),
    [anon_sym_not] = ACTIONS(4388),
    [anon_sym_or] = ACTIONS(4388),
    [anon_sym_and] = ACTIONS(4388),
    [anon_sym_case] = ACTIONS(4388),
    [anon_sym_always] = ACTIONS(4388),
    [anon_sym_covergroup] = ACTIONS(4388),
    [anon_sym_let] = ACTIONS(4388),
    [anon_sym_pulldown] = ACTIONS(4388),
    [anon_sym_pullup] = ACTIONS(4388),
    [anon_sym_cmos] = ACTIONS(4388),
    [anon_sym_rcmos] = ACTIONS(4388),
    [anon_sym_bufif0] = ACTIONS(4388),
    [anon_sym_bufif1] = ACTIONS(4388),
    [anon_sym_notif0] = ACTIONS(4388),
    [anon_sym_notif1] = ACTIONS(4388),
    [anon_sym_nmos] = ACTIONS(4388),
    [anon_sym_pmos] = ACTIONS(4388),
    [anon_sym_rnmos] = ACTIONS(4388),
    [anon_sym_rpmos] = ACTIONS(4388),
    [anon_sym_nand] = ACTIONS(4388),
    [anon_sym_nor] = ACTIONS(4388),
    [anon_sym_xor] = ACTIONS(4388),
    [anon_sym_xnor] = ACTIONS(4388),
    [anon_sym_buf] = ACTIONS(4388),
    [anon_sym_tranif0] = ACTIONS(4388),
    [anon_sym_tranif1] = ACTIONS(4388),
    [anon_sym_rtranif1] = ACTIONS(4388),
    [anon_sym_rtranif0] = ACTIONS(4388),
    [anon_sym_tran] = ACTIONS(4388),
    [anon_sym_rtran] = ACTIONS(4388),
    [anon_sym_generate] = ACTIONS(4388),
    [anon_sym_endgenerate] = ACTIONS(4388),
    [anon_sym_for] = ACTIONS(4388),
    [anon_sym_initial] = ACTIONS(4388),
    [anon_sym_assign] = ACTIONS(4388),
    [anon_sym_alias] = ACTIONS(4388),
    [anon_sym_always_comb] = ACTIONS(4388),
    [anon_sym_always_latch] = ACTIONS(4388),
    [anon_sym_always_ff] = ACTIONS(4388),
    [anon_sym_final] = ACTIONS(4388),
    [anon_sym_global] = ACTIONS(4388),
    [anon_sym_LPAREN_STAR] = ACTIONS(4386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4386),
    [anon_sym_DOLLARunit] = ACTIONS(4386),
  },
  [4339] = {
    [sym_simple_identifier] = ACTIONS(4340),
    [anon_sym_wire] = ACTIONS(4340),
    [anon_sym_tri] = ACTIONS(4340),
    [anon_sym_tri0] = ACTIONS(4340),
    [anon_sym_tri1] = ACTIONS(4340),
    [anon_sym_wand] = ACTIONS(4340),
    [anon_sym_triand] = ACTIONS(4340),
    [anon_sym_wor] = ACTIONS(4340),
    [anon_sym_trior] = ACTIONS(4340),
    [anon_sym_trireg] = ACTIONS(4340),
    [anon_sym_uwire] = ACTIONS(4340),
    [anon_sym_SEMI] = ACTIONS(4338),
    [anon_sym_COLON] = ACTIONS(10399),
    [anon_sym_extern] = ACTIONS(4340),
    [anon_sym_interface] = ACTIONS(4340),
    [anon_sym_checker] = ACTIONS(4340),
    [anon_sym_virtual] = ACTIONS(4340),
    [anon_sym_class] = ACTIONS(4340),
    [anon_sym_type] = ACTIONS(4340),
    [anon_sym_DOLLARfatal] = ACTIONS(4338),
    [anon_sym_DOLLARerror] = ACTIONS(4338),
    [anon_sym_DOLLARwarning] = ACTIONS(4338),
    [anon_sym_DOLLARinfo] = ACTIONS(4338),
    [anon_sym_default] = ACTIONS(4340),
    [anon_sym_clocking] = ACTIONS(4340),
    [anon_sym_defparam] = ACTIONS(4340),
    [anon_sym_bind] = ACTIONS(4340),
    [anon_sym_rand] = ACTIONS(4340),
    [anon_sym_const] = ACTIONS(4340),
    [anon_sym_function] = ACTIONS(4340),
    [anon_sym_static] = ACTIONS(4340),
    [anon_sym_constraint] = ACTIONS(4340),
    [anon_sym_if] = ACTIONS(4340),
    [anon_sym_else] = ACTIONS(4340),
    [anon_sym_LBRACK] = ACTIONS(4338),
    [anon_sym_localparam] = ACTIONS(4340),
    [anon_sym_parameter] = ACTIONS(4340),
    [anon_sym_var] = ACTIONS(4340),
    [anon_sym_import] = ACTIONS(4340),
    [anon_sym_export] = ACTIONS(4340),
    [anon_sym_genvar] = ACTIONS(4340),
    [anon_sym_interconnect] = ACTIONS(4340),
    [anon_sym_typedef] = ACTIONS(4340),
    [anon_sym_enum] = ACTIONS(4340),
    [anon_sym_struct] = ACTIONS(4340),
    [anon_sym_union] = ACTIONS(4340),
    [anon_sym_nettype] = ACTIONS(4340),
    [anon_sym_automatic] = ACTIONS(4340),
    [anon_sym_string] = ACTIONS(4340),
    [anon_sym_chandle] = ACTIONS(4340),
    [anon_sym_event] = ACTIONS(4340),
    [anon_sym_byte] = ACTIONS(4340),
    [anon_sym_shortint] = ACTIONS(4340),
    [anon_sym_int] = ACTIONS(4340),
    [anon_sym_longint] = ACTIONS(4340),
    [anon_sym_integer] = ACTIONS(4340),
    [anon_sym_time] = ACTIONS(4340),
    [anon_sym_bit] = ACTIONS(4340),
    [anon_sym_logic] = ACTIONS(4340),
    [anon_sym_reg] = ACTIONS(4340),
    [anon_sym_shortreal] = ACTIONS(4340),
    [anon_sym_real] = ACTIONS(4340),
    [anon_sym_realtime] = ACTIONS(4340),
    [anon_sym_supply0] = ACTIONS(4340),
    [anon_sym_supply1] = ACTIONS(4340),
    [anon_sym_signed] = ACTIONS(4340),
    [anon_sym_unsigned] = ACTIONS(4340),
    [anon_sym_task] = ACTIONS(4340),
    [anon_sym_assert] = ACTIONS(4340),
    [anon_sym_property] = ACTIONS(4340),
    [anon_sym_assume] = ACTIONS(4340),
    [anon_sym_cover] = ACTIONS(4340),
    [anon_sym_sequence] = ACTIONS(4340),
    [anon_sym_restrict] = ACTIONS(4340),
    [anon_sym_not] = ACTIONS(4340),
    [anon_sym_or] = ACTIONS(4340),
    [anon_sym_and] = ACTIONS(4340),
    [anon_sym_case] = ACTIONS(4340),
    [anon_sym_always] = ACTIONS(4340),
    [anon_sym_covergroup] = ACTIONS(4340),
    [anon_sym_let] = ACTIONS(4340),
    [anon_sym_pulldown] = ACTIONS(4340),
    [anon_sym_pullup] = ACTIONS(4340),
    [anon_sym_cmos] = ACTIONS(4340),
    [anon_sym_rcmos] = ACTIONS(4340),
    [anon_sym_bufif0] = ACTIONS(4340),
    [anon_sym_bufif1] = ACTIONS(4340),
    [anon_sym_notif0] = ACTIONS(4340),
    [anon_sym_notif1] = ACTIONS(4340),
    [anon_sym_nmos] = ACTIONS(4340),
    [anon_sym_pmos] = ACTIONS(4340),
    [anon_sym_rnmos] = ACTIONS(4340),
    [anon_sym_rpmos] = ACTIONS(4340),
    [anon_sym_nand] = ACTIONS(4340),
    [anon_sym_nor] = ACTIONS(4340),
    [anon_sym_xor] = ACTIONS(4340),
    [anon_sym_xnor] = ACTIONS(4340),
    [anon_sym_buf] = ACTIONS(4340),
    [anon_sym_tranif0] = ACTIONS(4340),
    [anon_sym_tranif1] = ACTIONS(4340),
    [anon_sym_rtranif1] = ACTIONS(4340),
    [anon_sym_rtranif0] = ACTIONS(4340),
    [anon_sym_tran] = ACTIONS(4340),
    [anon_sym_rtran] = ACTIONS(4340),
    [anon_sym_generate] = ACTIONS(4340),
    [anon_sym_endgenerate] = ACTIONS(4340),
    [anon_sym_for] = ACTIONS(4340),
    [anon_sym_initial] = ACTIONS(4340),
    [anon_sym_assign] = ACTIONS(4340),
    [anon_sym_alias] = ACTIONS(4340),
    [anon_sym_always_comb] = ACTIONS(4340),
    [anon_sym_always_latch] = ACTIONS(4340),
    [anon_sym_always_ff] = ACTIONS(4340),
    [anon_sym_final] = ACTIONS(4340),
    [anon_sym_global] = ACTIONS(4340),
    [anon_sym_LPAREN_STAR] = ACTIONS(4338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4338),
    [anon_sym_DOLLARunit] = ACTIONS(4338),
  },
  [4340] = {
    [sym_simple_identifier] = ACTIONS(4442),
    [anon_sym_wire] = ACTIONS(4442),
    [anon_sym_tri] = ACTIONS(4442),
    [anon_sym_tri0] = ACTIONS(4442),
    [anon_sym_tri1] = ACTIONS(4442),
    [anon_sym_wand] = ACTIONS(4442),
    [anon_sym_triand] = ACTIONS(4442),
    [anon_sym_wor] = ACTIONS(4442),
    [anon_sym_trior] = ACTIONS(4442),
    [anon_sym_trireg] = ACTIONS(4442),
    [anon_sym_uwire] = ACTIONS(4442),
    [anon_sym_SEMI] = ACTIONS(4440),
    [anon_sym_COLON] = ACTIONS(10401),
    [anon_sym_extern] = ACTIONS(4442),
    [anon_sym_interface] = ACTIONS(4442),
    [anon_sym_checker] = ACTIONS(4442),
    [anon_sym_virtual] = ACTIONS(4442),
    [anon_sym_class] = ACTIONS(4442),
    [anon_sym_type] = ACTIONS(4442),
    [anon_sym_DOLLARfatal] = ACTIONS(4440),
    [anon_sym_DOLLARerror] = ACTIONS(4440),
    [anon_sym_DOLLARwarning] = ACTIONS(4440),
    [anon_sym_DOLLARinfo] = ACTIONS(4440),
    [anon_sym_default] = ACTIONS(4442),
    [anon_sym_clocking] = ACTIONS(4442),
    [anon_sym_defparam] = ACTIONS(4442),
    [anon_sym_bind] = ACTIONS(4442),
    [anon_sym_rand] = ACTIONS(4442),
    [anon_sym_const] = ACTIONS(4442),
    [anon_sym_function] = ACTIONS(4442),
    [anon_sym_static] = ACTIONS(4442),
    [anon_sym_constraint] = ACTIONS(4442),
    [anon_sym_if] = ACTIONS(4442),
    [anon_sym_else] = ACTIONS(4442),
    [anon_sym_LBRACK] = ACTIONS(4440),
    [anon_sym_localparam] = ACTIONS(4442),
    [anon_sym_parameter] = ACTIONS(4442),
    [anon_sym_var] = ACTIONS(4442),
    [anon_sym_import] = ACTIONS(4442),
    [anon_sym_export] = ACTIONS(4442),
    [anon_sym_genvar] = ACTIONS(4442),
    [anon_sym_interconnect] = ACTIONS(4442),
    [anon_sym_typedef] = ACTIONS(4442),
    [anon_sym_enum] = ACTIONS(4442),
    [anon_sym_struct] = ACTIONS(4442),
    [anon_sym_union] = ACTIONS(4442),
    [anon_sym_nettype] = ACTIONS(4442),
    [anon_sym_automatic] = ACTIONS(4442),
    [anon_sym_string] = ACTIONS(4442),
    [anon_sym_chandle] = ACTIONS(4442),
    [anon_sym_event] = ACTIONS(4442),
    [anon_sym_byte] = ACTIONS(4442),
    [anon_sym_shortint] = ACTIONS(4442),
    [anon_sym_int] = ACTIONS(4442),
    [anon_sym_longint] = ACTIONS(4442),
    [anon_sym_integer] = ACTIONS(4442),
    [anon_sym_time] = ACTIONS(4442),
    [anon_sym_bit] = ACTIONS(4442),
    [anon_sym_logic] = ACTIONS(4442),
    [anon_sym_reg] = ACTIONS(4442),
    [anon_sym_shortreal] = ACTIONS(4442),
    [anon_sym_real] = ACTIONS(4442),
    [anon_sym_realtime] = ACTIONS(4442),
    [anon_sym_supply0] = ACTIONS(4442),
    [anon_sym_supply1] = ACTIONS(4442),
    [anon_sym_signed] = ACTIONS(4442),
    [anon_sym_unsigned] = ACTIONS(4442),
    [anon_sym_task] = ACTIONS(4442),
    [anon_sym_assert] = ACTIONS(4442),
    [anon_sym_property] = ACTIONS(4442),
    [anon_sym_assume] = ACTIONS(4442),
    [anon_sym_cover] = ACTIONS(4442),
    [anon_sym_sequence] = ACTIONS(4442),
    [anon_sym_restrict] = ACTIONS(4442),
    [anon_sym_not] = ACTIONS(4442),
    [anon_sym_or] = ACTIONS(4442),
    [anon_sym_and] = ACTIONS(4442),
    [anon_sym_case] = ACTIONS(4442),
    [anon_sym_always] = ACTIONS(4442),
    [anon_sym_covergroup] = ACTIONS(4442),
    [anon_sym_let] = ACTIONS(4442),
    [anon_sym_pulldown] = ACTIONS(4442),
    [anon_sym_pullup] = ACTIONS(4442),
    [anon_sym_cmos] = ACTIONS(4442),
    [anon_sym_rcmos] = ACTIONS(4442),
    [anon_sym_bufif0] = ACTIONS(4442),
    [anon_sym_bufif1] = ACTIONS(4442),
    [anon_sym_notif0] = ACTIONS(4442),
    [anon_sym_notif1] = ACTIONS(4442),
    [anon_sym_nmos] = ACTIONS(4442),
    [anon_sym_pmos] = ACTIONS(4442),
    [anon_sym_rnmos] = ACTIONS(4442),
    [anon_sym_rpmos] = ACTIONS(4442),
    [anon_sym_nand] = ACTIONS(4442),
    [anon_sym_nor] = ACTIONS(4442),
    [anon_sym_xor] = ACTIONS(4442),
    [anon_sym_xnor] = ACTIONS(4442),
    [anon_sym_buf] = ACTIONS(4442),
    [anon_sym_tranif0] = ACTIONS(4442),
    [anon_sym_tranif1] = ACTIONS(4442),
    [anon_sym_rtranif1] = ACTIONS(4442),
    [anon_sym_rtranif0] = ACTIONS(4442),
    [anon_sym_tran] = ACTIONS(4442),
    [anon_sym_rtran] = ACTIONS(4442),
    [anon_sym_generate] = ACTIONS(4442),
    [anon_sym_endgenerate] = ACTIONS(4442),
    [anon_sym_for] = ACTIONS(4442),
    [anon_sym_initial] = ACTIONS(4442),
    [anon_sym_assign] = ACTIONS(4442),
    [anon_sym_alias] = ACTIONS(4442),
    [anon_sym_always_comb] = ACTIONS(4442),
    [anon_sym_always_latch] = ACTIONS(4442),
    [anon_sym_always_ff] = ACTIONS(4442),
    [anon_sym_final] = ACTIONS(4442),
    [anon_sym_global] = ACTIONS(4442),
    [anon_sym_LPAREN_STAR] = ACTIONS(4440),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4440),
    [anon_sym_DOLLARunit] = ACTIONS(4440),
  },
  [4341] = {
    [sym_simple_identifier] = ACTIONS(4794),
    [anon_sym_wire] = ACTIONS(4794),
    [anon_sym_tri] = ACTIONS(4794),
    [anon_sym_tri0] = ACTIONS(4794),
    [anon_sym_tri1] = ACTIONS(4794),
    [anon_sym_wand] = ACTIONS(4794),
    [anon_sym_triand] = ACTIONS(4794),
    [anon_sym_wor] = ACTIONS(4794),
    [anon_sym_trior] = ACTIONS(4794),
    [anon_sym_trireg] = ACTIONS(4794),
    [anon_sym_uwire] = ACTIONS(4794),
    [anon_sym_SEMI] = ACTIONS(4792),
    [anon_sym_COLON] = ACTIONS(10403),
    [anon_sym_extern] = ACTIONS(4794),
    [anon_sym_interface] = ACTIONS(4794),
    [anon_sym_checker] = ACTIONS(4794),
    [anon_sym_virtual] = ACTIONS(4794),
    [anon_sym_class] = ACTIONS(4794),
    [anon_sym_type] = ACTIONS(4794),
    [anon_sym_DOLLARfatal] = ACTIONS(4792),
    [anon_sym_DOLLARerror] = ACTIONS(4792),
    [anon_sym_DOLLARwarning] = ACTIONS(4792),
    [anon_sym_DOLLARinfo] = ACTIONS(4792),
    [anon_sym_default] = ACTIONS(4794),
    [anon_sym_clocking] = ACTIONS(4794),
    [anon_sym_defparam] = ACTIONS(4794),
    [anon_sym_bind] = ACTIONS(4794),
    [anon_sym_rand] = ACTIONS(4794),
    [anon_sym_const] = ACTIONS(4794),
    [anon_sym_function] = ACTIONS(4794),
    [anon_sym_static] = ACTIONS(4794),
    [anon_sym_constraint] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4794),
    [anon_sym_else] = ACTIONS(4794),
    [anon_sym_LBRACK] = ACTIONS(4792),
    [anon_sym_localparam] = ACTIONS(4794),
    [anon_sym_parameter] = ACTIONS(4794),
    [anon_sym_var] = ACTIONS(4794),
    [anon_sym_import] = ACTIONS(4794),
    [anon_sym_export] = ACTIONS(4794),
    [anon_sym_genvar] = ACTIONS(4794),
    [anon_sym_interconnect] = ACTIONS(4794),
    [anon_sym_typedef] = ACTIONS(4794),
    [anon_sym_enum] = ACTIONS(4794),
    [anon_sym_struct] = ACTIONS(4794),
    [anon_sym_union] = ACTIONS(4794),
    [anon_sym_nettype] = ACTIONS(4794),
    [anon_sym_automatic] = ACTIONS(4794),
    [anon_sym_string] = ACTIONS(4794),
    [anon_sym_chandle] = ACTIONS(4794),
    [anon_sym_event] = ACTIONS(4794),
    [anon_sym_byte] = ACTIONS(4794),
    [anon_sym_shortint] = ACTIONS(4794),
    [anon_sym_int] = ACTIONS(4794),
    [anon_sym_longint] = ACTIONS(4794),
    [anon_sym_integer] = ACTIONS(4794),
    [anon_sym_time] = ACTIONS(4794),
    [anon_sym_bit] = ACTIONS(4794),
    [anon_sym_logic] = ACTIONS(4794),
    [anon_sym_reg] = ACTIONS(4794),
    [anon_sym_shortreal] = ACTIONS(4794),
    [anon_sym_real] = ACTIONS(4794),
    [anon_sym_realtime] = ACTIONS(4794),
    [anon_sym_supply0] = ACTIONS(4794),
    [anon_sym_supply1] = ACTIONS(4794),
    [anon_sym_signed] = ACTIONS(4794),
    [anon_sym_unsigned] = ACTIONS(4794),
    [anon_sym_task] = ACTIONS(4794),
    [anon_sym_assert] = ACTIONS(4794),
    [anon_sym_property] = ACTIONS(4794),
    [anon_sym_assume] = ACTIONS(4794),
    [anon_sym_cover] = ACTIONS(4794),
    [anon_sym_sequence] = ACTIONS(4794),
    [anon_sym_restrict] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4794),
    [anon_sym_or] = ACTIONS(4794),
    [anon_sym_and] = ACTIONS(4794),
    [anon_sym_case] = ACTIONS(4794),
    [anon_sym_always] = ACTIONS(4794),
    [anon_sym_covergroup] = ACTIONS(4794),
    [anon_sym_let] = ACTIONS(4794),
    [anon_sym_pulldown] = ACTIONS(4794),
    [anon_sym_pullup] = ACTIONS(4794),
    [anon_sym_cmos] = ACTIONS(4794),
    [anon_sym_rcmos] = ACTIONS(4794),
    [anon_sym_bufif0] = ACTIONS(4794),
    [anon_sym_bufif1] = ACTIONS(4794),
    [anon_sym_notif0] = ACTIONS(4794),
    [anon_sym_notif1] = ACTIONS(4794),
    [anon_sym_nmos] = ACTIONS(4794),
    [anon_sym_pmos] = ACTIONS(4794),
    [anon_sym_rnmos] = ACTIONS(4794),
    [anon_sym_rpmos] = ACTIONS(4794),
    [anon_sym_nand] = ACTIONS(4794),
    [anon_sym_nor] = ACTIONS(4794),
    [anon_sym_xor] = ACTIONS(4794),
    [anon_sym_xnor] = ACTIONS(4794),
    [anon_sym_buf] = ACTIONS(4794),
    [anon_sym_tranif0] = ACTIONS(4794),
    [anon_sym_tranif1] = ACTIONS(4794),
    [anon_sym_rtranif1] = ACTIONS(4794),
    [anon_sym_rtranif0] = ACTIONS(4794),
    [anon_sym_tran] = ACTIONS(4794),
    [anon_sym_rtran] = ACTIONS(4794),
    [anon_sym_generate] = ACTIONS(4794),
    [anon_sym_endgenerate] = ACTIONS(4794),
    [anon_sym_for] = ACTIONS(4794),
    [anon_sym_initial] = ACTIONS(4794),
    [anon_sym_assign] = ACTIONS(4794),
    [anon_sym_alias] = ACTIONS(4794),
    [anon_sym_always_comb] = ACTIONS(4794),
    [anon_sym_always_latch] = ACTIONS(4794),
    [anon_sym_always_ff] = ACTIONS(4794),
    [anon_sym_final] = ACTIONS(4794),
    [anon_sym_global] = ACTIONS(4794),
    [anon_sym_LPAREN_STAR] = ACTIONS(4792),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4792),
    [anon_sym_DOLLARunit] = ACTIONS(4792),
  },
  [4342] = {
    [sym_simple_identifier] = ACTIONS(4800),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_COLON] = ACTIONS(10405),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_rand] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_endgenerate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [4343] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_COLON] = ACTIONS(10407),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_rand] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_endgenerate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [4344] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_COLON] = ACTIONS(10409),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_rand] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_endgenerate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [4345] = {
    [sym_simple_identifier] = ACTIONS(4448),
    [anon_sym_wire] = ACTIONS(4448),
    [anon_sym_tri] = ACTIONS(4448),
    [anon_sym_tri0] = ACTIONS(4448),
    [anon_sym_tri1] = ACTIONS(4448),
    [anon_sym_wand] = ACTIONS(4448),
    [anon_sym_triand] = ACTIONS(4448),
    [anon_sym_wor] = ACTIONS(4448),
    [anon_sym_trior] = ACTIONS(4448),
    [anon_sym_trireg] = ACTIONS(4448),
    [anon_sym_uwire] = ACTIONS(4448),
    [anon_sym_SEMI] = ACTIONS(4446),
    [anon_sym_COLON] = ACTIONS(10411),
    [anon_sym_extern] = ACTIONS(4448),
    [anon_sym_interface] = ACTIONS(4448),
    [anon_sym_checker] = ACTIONS(4448),
    [anon_sym_virtual] = ACTIONS(4448),
    [anon_sym_class] = ACTIONS(4448),
    [anon_sym_type] = ACTIONS(4448),
    [anon_sym_DOLLARfatal] = ACTIONS(4446),
    [anon_sym_DOLLARerror] = ACTIONS(4446),
    [anon_sym_DOLLARwarning] = ACTIONS(4446),
    [anon_sym_DOLLARinfo] = ACTIONS(4446),
    [anon_sym_default] = ACTIONS(4448),
    [anon_sym_clocking] = ACTIONS(4448),
    [anon_sym_defparam] = ACTIONS(4448),
    [anon_sym_bind] = ACTIONS(4448),
    [anon_sym_rand] = ACTIONS(4448),
    [anon_sym_const] = ACTIONS(4448),
    [anon_sym_function] = ACTIONS(4448),
    [anon_sym_static] = ACTIONS(4448),
    [anon_sym_constraint] = ACTIONS(4448),
    [anon_sym_if] = ACTIONS(4448),
    [anon_sym_else] = ACTIONS(4448),
    [anon_sym_LBRACK] = ACTIONS(4446),
    [anon_sym_localparam] = ACTIONS(4448),
    [anon_sym_parameter] = ACTIONS(4448),
    [anon_sym_var] = ACTIONS(4448),
    [anon_sym_import] = ACTIONS(4448),
    [anon_sym_export] = ACTIONS(4448),
    [anon_sym_genvar] = ACTIONS(4448),
    [anon_sym_interconnect] = ACTIONS(4448),
    [anon_sym_typedef] = ACTIONS(4448),
    [anon_sym_enum] = ACTIONS(4448),
    [anon_sym_struct] = ACTIONS(4448),
    [anon_sym_union] = ACTIONS(4448),
    [anon_sym_nettype] = ACTIONS(4448),
    [anon_sym_automatic] = ACTIONS(4448),
    [anon_sym_string] = ACTIONS(4448),
    [anon_sym_chandle] = ACTIONS(4448),
    [anon_sym_event] = ACTIONS(4448),
    [anon_sym_byte] = ACTIONS(4448),
    [anon_sym_shortint] = ACTIONS(4448),
    [anon_sym_int] = ACTIONS(4448),
    [anon_sym_longint] = ACTIONS(4448),
    [anon_sym_integer] = ACTIONS(4448),
    [anon_sym_time] = ACTIONS(4448),
    [anon_sym_bit] = ACTIONS(4448),
    [anon_sym_logic] = ACTIONS(4448),
    [anon_sym_reg] = ACTIONS(4448),
    [anon_sym_shortreal] = ACTIONS(4448),
    [anon_sym_real] = ACTIONS(4448),
    [anon_sym_realtime] = ACTIONS(4448),
    [anon_sym_supply0] = ACTIONS(4448),
    [anon_sym_supply1] = ACTIONS(4448),
    [anon_sym_signed] = ACTIONS(4448),
    [anon_sym_unsigned] = ACTIONS(4448),
    [anon_sym_task] = ACTIONS(4448),
    [anon_sym_assert] = ACTIONS(4448),
    [anon_sym_property] = ACTIONS(4448),
    [anon_sym_assume] = ACTIONS(4448),
    [anon_sym_cover] = ACTIONS(4448),
    [anon_sym_sequence] = ACTIONS(4448),
    [anon_sym_restrict] = ACTIONS(4448),
    [anon_sym_not] = ACTIONS(4448),
    [anon_sym_or] = ACTIONS(4448),
    [anon_sym_and] = ACTIONS(4448),
    [anon_sym_case] = ACTIONS(4448),
    [anon_sym_always] = ACTIONS(4448),
    [anon_sym_covergroup] = ACTIONS(4448),
    [anon_sym_let] = ACTIONS(4448),
    [anon_sym_pulldown] = ACTIONS(4448),
    [anon_sym_pullup] = ACTIONS(4448),
    [anon_sym_cmos] = ACTIONS(4448),
    [anon_sym_rcmos] = ACTIONS(4448),
    [anon_sym_bufif0] = ACTIONS(4448),
    [anon_sym_bufif1] = ACTIONS(4448),
    [anon_sym_notif0] = ACTIONS(4448),
    [anon_sym_notif1] = ACTIONS(4448),
    [anon_sym_nmos] = ACTIONS(4448),
    [anon_sym_pmos] = ACTIONS(4448),
    [anon_sym_rnmos] = ACTIONS(4448),
    [anon_sym_rpmos] = ACTIONS(4448),
    [anon_sym_nand] = ACTIONS(4448),
    [anon_sym_nor] = ACTIONS(4448),
    [anon_sym_xor] = ACTIONS(4448),
    [anon_sym_xnor] = ACTIONS(4448),
    [anon_sym_buf] = ACTIONS(4448),
    [anon_sym_tranif0] = ACTIONS(4448),
    [anon_sym_tranif1] = ACTIONS(4448),
    [anon_sym_rtranif1] = ACTIONS(4448),
    [anon_sym_rtranif0] = ACTIONS(4448),
    [anon_sym_tran] = ACTIONS(4448),
    [anon_sym_rtran] = ACTIONS(4448),
    [anon_sym_generate] = ACTIONS(4448),
    [anon_sym_endgenerate] = ACTIONS(4448),
    [anon_sym_for] = ACTIONS(4448),
    [anon_sym_initial] = ACTIONS(4448),
    [anon_sym_assign] = ACTIONS(4448),
    [anon_sym_alias] = ACTIONS(4448),
    [anon_sym_always_comb] = ACTIONS(4448),
    [anon_sym_always_latch] = ACTIONS(4448),
    [anon_sym_always_ff] = ACTIONS(4448),
    [anon_sym_final] = ACTIONS(4448),
    [anon_sym_global] = ACTIONS(4448),
    [anon_sym_LPAREN_STAR] = ACTIONS(4446),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4446),
    [anon_sym_DOLLARunit] = ACTIONS(4446),
  },
  [4346] = {
    [sym_simple_identifier] = ACTIONS(5588),
    [anon_sym_wire] = ACTIONS(5588),
    [anon_sym_tri] = ACTIONS(5588),
    [anon_sym_tri0] = ACTIONS(5588),
    [anon_sym_tri1] = ACTIONS(5588),
    [anon_sym_wand] = ACTIONS(5588),
    [anon_sym_triand] = ACTIONS(5588),
    [anon_sym_wor] = ACTIONS(5588),
    [anon_sym_trior] = ACTIONS(5588),
    [anon_sym_trireg] = ACTIONS(5588),
    [anon_sym_uwire] = ACTIONS(5588),
    [anon_sym_SEMI] = ACTIONS(5590),
    [anon_sym_COLON] = ACTIONS(10413),
    [anon_sym_extern] = ACTIONS(5588),
    [anon_sym_interface] = ACTIONS(5588),
    [anon_sym_checker] = ACTIONS(5588),
    [anon_sym_virtual] = ACTIONS(5588),
    [anon_sym_class] = ACTIONS(5588),
    [anon_sym_type] = ACTIONS(5588),
    [anon_sym_DOLLARfatal] = ACTIONS(5590),
    [anon_sym_DOLLARerror] = ACTIONS(5590),
    [anon_sym_DOLLARwarning] = ACTIONS(5590),
    [anon_sym_DOLLARinfo] = ACTIONS(5590),
    [anon_sym_default] = ACTIONS(5588),
    [anon_sym_clocking] = ACTIONS(5588),
    [anon_sym_defparam] = ACTIONS(5588),
    [anon_sym_bind] = ACTIONS(5588),
    [anon_sym_rand] = ACTIONS(5588),
    [anon_sym_const] = ACTIONS(5588),
    [anon_sym_function] = ACTIONS(5588),
    [anon_sym_static] = ACTIONS(5588),
    [anon_sym_constraint] = ACTIONS(5588),
    [anon_sym_if] = ACTIONS(5588),
    [anon_sym_else] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5590),
    [anon_sym_localparam] = ACTIONS(5588),
    [anon_sym_parameter] = ACTIONS(5588),
    [anon_sym_var] = ACTIONS(5588),
    [anon_sym_import] = ACTIONS(5588),
    [anon_sym_export] = ACTIONS(5588),
    [anon_sym_genvar] = ACTIONS(5588),
    [anon_sym_interconnect] = ACTIONS(5588),
    [anon_sym_typedef] = ACTIONS(5588),
    [anon_sym_enum] = ACTIONS(5588),
    [anon_sym_struct] = ACTIONS(5588),
    [anon_sym_union] = ACTIONS(5588),
    [anon_sym_nettype] = ACTIONS(5588),
    [anon_sym_automatic] = ACTIONS(5588),
    [anon_sym_string] = ACTIONS(5588),
    [anon_sym_chandle] = ACTIONS(5588),
    [anon_sym_event] = ACTIONS(5588),
    [anon_sym_byte] = ACTIONS(5588),
    [anon_sym_shortint] = ACTIONS(5588),
    [anon_sym_int] = ACTIONS(5588),
    [anon_sym_longint] = ACTIONS(5588),
    [anon_sym_integer] = ACTIONS(5588),
    [anon_sym_time] = ACTIONS(5588),
    [anon_sym_bit] = ACTIONS(5588),
    [anon_sym_logic] = ACTIONS(5588),
    [anon_sym_reg] = ACTIONS(5588),
    [anon_sym_shortreal] = ACTIONS(5588),
    [anon_sym_real] = ACTIONS(5588),
    [anon_sym_realtime] = ACTIONS(5588),
    [anon_sym_supply0] = ACTIONS(5588),
    [anon_sym_supply1] = ACTIONS(5588),
    [anon_sym_signed] = ACTIONS(5588),
    [anon_sym_unsigned] = ACTIONS(5588),
    [anon_sym_task] = ACTIONS(5588),
    [anon_sym_assert] = ACTIONS(5588),
    [anon_sym_property] = ACTIONS(5588),
    [anon_sym_assume] = ACTIONS(5588),
    [anon_sym_cover] = ACTIONS(5588),
    [anon_sym_sequence] = ACTIONS(5588),
    [anon_sym_restrict] = ACTIONS(5588),
    [anon_sym_not] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_case] = ACTIONS(5588),
    [anon_sym_always] = ACTIONS(5588),
    [anon_sym_covergroup] = ACTIONS(5588),
    [anon_sym_end] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_pulldown] = ACTIONS(5588),
    [anon_sym_pullup] = ACTIONS(5588),
    [anon_sym_cmos] = ACTIONS(5588),
    [anon_sym_rcmos] = ACTIONS(5588),
    [anon_sym_bufif0] = ACTIONS(5588),
    [anon_sym_bufif1] = ACTIONS(5588),
    [anon_sym_notif0] = ACTIONS(5588),
    [anon_sym_notif1] = ACTIONS(5588),
    [anon_sym_nmos] = ACTIONS(5588),
    [anon_sym_pmos] = ACTIONS(5588),
    [anon_sym_rnmos] = ACTIONS(5588),
    [anon_sym_rpmos] = ACTIONS(5588),
    [anon_sym_nand] = ACTIONS(5588),
    [anon_sym_nor] = ACTIONS(5588),
    [anon_sym_xor] = ACTIONS(5588),
    [anon_sym_xnor] = ACTIONS(5588),
    [anon_sym_buf] = ACTIONS(5588),
    [anon_sym_tranif0] = ACTIONS(5588),
    [anon_sym_tranif1] = ACTIONS(5588),
    [anon_sym_rtranif1] = ACTIONS(5588),
    [anon_sym_rtranif0] = ACTIONS(5588),
    [anon_sym_tran] = ACTIONS(5588),
    [anon_sym_rtran] = ACTIONS(5588),
    [anon_sym_generate] = ACTIONS(5588),
    [anon_sym_for] = ACTIONS(5588),
    [anon_sym_initial] = ACTIONS(5588),
    [anon_sym_assign] = ACTIONS(5588),
    [anon_sym_alias] = ACTIONS(5588),
    [anon_sym_always_comb] = ACTIONS(5588),
    [anon_sym_always_latch] = ACTIONS(5588),
    [anon_sym_always_ff] = ACTIONS(5588),
    [anon_sym_final] = ACTIONS(5588),
    [anon_sym_global] = ACTIONS(5588),
    [anon_sym_LPAREN_STAR] = ACTIONS(5590),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5590),
    [anon_sym_DOLLARunit] = ACTIONS(5590),
  },
  [4347] = {
    [sym_simple_identifier] = ACTIONS(4542),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_COLON] = ACTIONS(10415),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_rand] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_endgenerate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [4348] = {
    [sym_simple_identifier] = ACTIONS(4316),
    [anon_sym_wire] = ACTIONS(4316),
    [anon_sym_tri] = ACTIONS(4316),
    [anon_sym_tri0] = ACTIONS(4316),
    [anon_sym_tri1] = ACTIONS(4316),
    [anon_sym_wand] = ACTIONS(4316),
    [anon_sym_triand] = ACTIONS(4316),
    [anon_sym_wor] = ACTIONS(4316),
    [anon_sym_trior] = ACTIONS(4316),
    [anon_sym_trireg] = ACTIONS(4316),
    [anon_sym_uwire] = ACTIONS(4316),
    [anon_sym_SEMI] = ACTIONS(4314),
    [anon_sym_COLON] = ACTIONS(10417),
    [anon_sym_extern] = ACTIONS(4316),
    [anon_sym_interface] = ACTIONS(4316),
    [anon_sym_checker] = ACTIONS(4316),
    [anon_sym_virtual] = ACTIONS(4316),
    [anon_sym_class] = ACTIONS(4316),
    [anon_sym_type] = ACTIONS(4316),
    [anon_sym_DOLLARfatal] = ACTIONS(4314),
    [anon_sym_DOLLARerror] = ACTIONS(4314),
    [anon_sym_DOLLARwarning] = ACTIONS(4314),
    [anon_sym_DOLLARinfo] = ACTIONS(4314),
    [anon_sym_default] = ACTIONS(4316),
    [anon_sym_clocking] = ACTIONS(4316),
    [anon_sym_defparam] = ACTIONS(4316),
    [anon_sym_bind] = ACTIONS(4316),
    [anon_sym_rand] = ACTIONS(4316),
    [anon_sym_const] = ACTIONS(4316),
    [anon_sym_function] = ACTIONS(4316),
    [anon_sym_static] = ACTIONS(4316),
    [anon_sym_constraint] = ACTIONS(4316),
    [anon_sym_if] = ACTIONS(4316),
    [anon_sym_else] = ACTIONS(4316),
    [anon_sym_LBRACK] = ACTIONS(4314),
    [anon_sym_localparam] = ACTIONS(4316),
    [anon_sym_parameter] = ACTIONS(4316),
    [anon_sym_var] = ACTIONS(4316),
    [anon_sym_import] = ACTIONS(4316),
    [anon_sym_export] = ACTIONS(4316),
    [anon_sym_genvar] = ACTIONS(4316),
    [anon_sym_interconnect] = ACTIONS(4316),
    [anon_sym_typedef] = ACTIONS(4316),
    [anon_sym_enum] = ACTIONS(4316),
    [anon_sym_struct] = ACTIONS(4316),
    [anon_sym_union] = ACTIONS(4316),
    [anon_sym_nettype] = ACTIONS(4316),
    [anon_sym_automatic] = ACTIONS(4316),
    [anon_sym_string] = ACTIONS(4316),
    [anon_sym_chandle] = ACTIONS(4316),
    [anon_sym_event] = ACTIONS(4316),
    [anon_sym_byte] = ACTIONS(4316),
    [anon_sym_shortint] = ACTIONS(4316),
    [anon_sym_int] = ACTIONS(4316),
    [anon_sym_longint] = ACTIONS(4316),
    [anon_sym_integer] = ACTIONS(4316),
    [anon_sym_time] = ACTIONS(4316),
    [anon_sym_bit] = ACTIONS(4316),
    [anon_sym_logic] = ACTIONS(4316),
    [anon_sym_reg] = ACTIONS(4316),
    [anon_sym_shortreal] = ACTIONS(4316),
    [anon_sym_real] = ACTIONS(4316),
    [anon_sym_realtime] = ACTIONS(4316),
    [anon_sym_supply0] = ACTIONS(4316),
    [anon_sym_supply1] = ACTIONS(4316),
    [anon_sym_signed] = ACTIONS(4316),
    [anon_sym_unsigned] = ACTIONS(4316),
    [anon_sym_task] = ACTIONS(4316),
    [anon_sym_assert] = ACTIONS(4316),
    [anon_sym_property] = ACTIONS(4316),
    [anon_sym_assume] = ACTIONS(4316),
    [anon_sym_cover] = ACTIONS(4316),
    [anon_sym_sequence] = ACTIONS(4316),
    [anon_sym_restrict] = ACTIONS(4316),
    [anon_sym_not] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4316),
    [anon_sym_and] = ACTIONS(4316),
    [anon_sym_case] = ACTIONS(4316),
    [anon_sym_always] = ACTIONS(4316),
    [anon_sym_covergroup] = ACTIONS(4316),
    [anon_sym_end] = ACTIONS(4316),
    [anon_sym_let] = ACTIONS(4316),
    [anon_sym_pulldown] = ACTIONS(4316),
    [anon_sym_pullup] = ACTIONS(4316),
    [anon_sym_cmos] = ACTIONS(4316),
    [anon_sym_rcmos] = ACTIONS(4316),
    [anon_sym_bufif0] = ACTIONS(4316),
    [anon_sym_bufif1] = ACTIONS(4316),
    [anon_sym_notif0] = ACTIONS(4316),
    [anon_sym_notif1] = ACTIONS(4316),
    [anon_sym_nmos] = ACTIONS(4316),
    [anon_sym_pmos] = ACTIONS(4316),
    [anon_sym_rnmos] = ACTIONS(4316),
    [anon_sym_rpmos] = ACTIONS(4316),
    [anon_sym_nand] = ACTIONS(4316),
    [anon_sym_nor] = ACTIONS(4316),
    [anon_sym_xor] = ACTIONS(4316),
    [anon_sym_xnor] = ACTIONS(4316),
    [anon_sym_buf] = ACTIONS(4316),
    [anon_sym_tranif0] = ACTIONS(4316),
    [anon_sym_tranif1] = ACTIONS(4316),
    [anon_sym_rtranif1] = ACTIONS(4316),
    [anon_sym_rtranif0] = ACTIONS(4316),
    [anon_sym_tran] = ACTIONS(4316),
    [anon_sym_rtran] = ACTIONS(4316),
    [anon_sym_generate] = ACTIONS(4316),
    [anon_sym_for] = ACTIONS(4316),
    [anon_sym_initial] = ACTIONS(4316),
    [anon_sym_assign] = ACTIONS(4316),
    [anon_sym_alias] = ACTIONS(4316),
    [anon_sym_always_comb] = ACTIONS(4316),
    [anon_sym_always_latch] = ACTIONS(4316),
    [anon_sym_always_ff] = ACTIONS(4316),
    [anon_sym_final] = ACTIONS(4316),
    [anon_sym_global] = ACTIONS(4316),
    [anon_sym_LPAREN_STAR] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4314),
    [anon_sym_DOLLARunit] = ACTIONS(4314),
  },
  [4349] = {
    [sym_simple_identifier] = ACTIONS(5612),
    [anon_sym_wire] = ACTIONS(5612),
    [anon_sym_tri] = ACTIONS(5612),
    [anon_sym_tri0] = ACTIONS(5612),
    [anon_sym_tri1] = ACTIONS(5612),
    [anon_sym_wand] = ACTIONS(5612),
    [anon_sym_triand] = ACTIONS(5612),
    [anon_sym_wor] = ACTIONS(5612),
    [anon_sym_trior] = ACTIONS(5612),
    [anon_sym_trireg] = ACTIONS(5612),
    [anon_sym_uwire] = ACTIONS(5612),
    [anon_sym_SEMI] = ACTIONS(5614),
    [anon_sym_COLON] = ACTIONS(10419),
    [anon_sym_extern] = ACTIONS(5612),
    [anon_sym_interface] = ACTIONS(5612),
    [anon_sym_checker] = ACTIONS(5612),
    [anon_sym_virtual] = ACTIONS(5612),
    [anon_sym_class] = ACTIONS(5612),
    [anon_sym_type] = ACTIONS(5612),
    [anon_sym_DOLLARfatal] = ACTIONS(5614),
    [anon_sym_DOLLARerror] = ACTIONS(5614),
    [anon_sym_DOLLARwarning] = ACTIONS(5614),
    [anon_sym_DOLLARinfo] = ACTIONS(5614),
    [anon_sym_default] = ACTIONS(5612),
    [anon_sym_clocking] = ACTIONS(5612),
    [anon_sym_defparam] = ACTIONS(5612),
    [anon_sym_bind] = ACTIONS(5612),
    [anon_sym_rand] = ACTIONS(5612),
    [anon_sym_const] = ACTIONS(5612),
    [anon_sym_function] = ACTIONS(5612),
    [anon_sym_static] = ACTIONS(5612),
    [anon_sym_constraint] = ACTIONS(5612),
    [anon_sym_if] = ACTIONS(5612),
    [anon_sym_else] = ACTIONS(5612),
    [anon_sym_LBRACK] = ACTIONS(5614),
    [anon_sym_localparam] = ACTIONS(5612),
    [anon_sym_parameter] = ACTIONS(5612),
    [anon_sym_var] = ACTIONS(5612),
    [anon_sym_import] = ACTIONS(5612),
    [anon_sym_export] = ACTIONS(5612),
    [anon_sym_genvar] = ACTIONS(5612),
    [anon_sym_interconnect] = ACTIONS(5612),
    [anon_sym_typedef] = ACTIONS(5612),
    [anon_sym_enum] = ACTIONS(5612),
    [anon_sym_struct] = ACTIONS(5612),
    [anon_sym_union] = ACTIONS(5612),
    [anon_sym_nettype] = ACTIONS(5612),
    [anon_sym_automatic] = ACTIONS(5612),
    [anon_sym_string] = ACTIONS(5612),
    [anon_sym_chandle] = ACTIONS(5612),
    [anon_sym_event] = ACTIONS(5612),
    [anon_sym_byte] = ACTIONS(5612),
    [anon_sym_shortint] = ACTIONS(5612),
    [anon_sym_int] = ACTIONS(5612),
    [anon_sym_longint] = ACTIONS(5612),
    [anon_sym_integer] = ACTIONS(5612),
    [anon_sym_time] = ACTIONS(5612),
    [anon_sym_bit] = ACTIONS(5612),
    [anon_sym_logic] = ACTIONS(5612),
    [anon_sym_reg] = ACTIONS(5612),
    [anon_sym_shortreal] = ACTIONS(5612),
    [anon_sym_real] = ACTIONS(5612),
    [anon_sym_realtime] = ACTIONS(5612),
    [anon_sym_supply0] = ACTIONS(5612),
    [anon_sym_supply1] = ACTIONS(5612),
    [anon_sym_signed] = ACTIONS(5612),
    [anon_sym_unsigned] = ACTIONS(5612),
    [anon_sym_task] = ACTIONS(5612),
    [anon_sym_assert] = ACTIONS(5612),
    [anon_sym_property] = ACTIONS(5612),
    [anon_sym_assume] = ACTIONS(5612),
    [anon_sym_cover] = ACTIONS(5612),
    [anon_sym_sequence] = ACTIONS(5612),
    [anon_sym_restrict] = ACTIONS(5612),
    [anon_sym_not] = ACTIONS(5612),
    [anon_sym_or] = ACTIONS(5612),
    [anon_sym_and] = ACTIONS(5612),
    [anon_sym_case] = ACTIONS(5612),
    [anon_sym_always] = ACTIONS(5612),
    [anon_sym_covergroup] = ACTIONS(5612),
    [anon_sym_end] = ACTIONS(5612),
    [anon_sym_let] = ACTIONS(5612),
    [anon_sym_pulldown] = ACTIONS(5612),
    [anon_sym_pullup] = ACTIONS(5612),
    [anon_sym_cmos] = ACTIONS(5612),
    [anon_sym_rcmos] = ACTIONS(5612),
    [anon_sym_bufif0] = ACTIONS(5612),
    [anon_sym_bufif1] = ACTIONS(5612),
    [anon_sym_notif0] = ACTIONS(5612),
    [anon_sym_notif1] = ACTIONS(5612),
    [anon_sym_nmos] = ACTIONS(5612),
    [anon_sym_pmos] = ACTIONS(5612),
    [anon_sym_rnmos] = ACTIONS(5612),
    [anon_sym_rpmos] = ACTIONS(5612),
    [anon_sym_nand] = ACTIONS(5612),
    [anon_sym_nor] = ACTIONS(5612),
    [anon_sym_xor] = ACTIONS(5612),
    [anon_sym_xnor] = ACTIONS(5612),
    [anon_sym_buf] = ACTIONS(5612),
    [anon_sym_tranif0] = ACTIONS(5612),
    [anon_sym_tranif1] = ACTIONS(5612),
    [anon_sym_rtranif1] = ACTIONS(5612),
    [anon_sym_rtranif0] = ACTIONS(5612),
    [anon_sym_tran] = ACTIONS(5612),
    [anon_sym_rtran] = ACTIONS(5612),
    [anon_sym_generate] = ACTIONS(5612),
    [anon_sym_for] = ACTIONS(5612),
    [anon_sym_initial] = ACTIONS(5612),
    [anon_sym_assign] = ACTIONS(5612),
    [anon_sym_alias] = ACTIONS(5612),
    [anon_sym_always_comb] = ACTIONS(5612),
    [anon_sym_always_latch] = ACTIONS(5612),
    [anon_sym_always_ff] = ACTIONS(5612),
    [anon_sym_final] = ACTIONS(5612),
    [anon_sym_global] = ACTIONS(5612),
    [anon_sym_LPAREN_STAR] = ACTIONS(5614),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5614),
    [anon_sym_DOLLARunit] = ACTIONS(5614),
  },
  [4350] = {
    [sym_simple_identifier] = ACTIONS(5792),
    [anon_sym_wire] = ACTIONS(5792),
    [anon_sym_tri] = ACTIONS(5792),
    [anon_sym_tri0] = ACTIONS(5792),
    [anon_sym_tri1] = ACTIONS(5792),
    [anon_sym_wand] = ACTIONS(5792),
    [anon_sym_triand] = ACTIONS(5792),
    [anon_sym_wor] = ACTIONS(5792),
    [anon_sym_trior] = ACTIONS(5792),
    [anon_sym_trireg] = ACTIONS(5792),
    [anon_sym_uwire] = ACTIONS(5792),
    [anon_sym_SEMI] = ACTIONS(5794),
    [anon_sym_COLON] = ACTIONS(10421),
    [anon_sym_extern] = ACTIONS(5792),
    [anon_sym_interface] = ACTIONS(5792),
    [anon_sym_checker] = ACTIONS(5792),
    [anon_sym_virtual] = ACTIONS(5792),
    [anon_sym_class] = ACTIONS(5792),
    [anon_sym_type] = ACTIONS(5792),
    [anon_sym_DOLLARfatal] = ACTIONS(5794),
    [anon_sym_DOLLARerror] = ACTIONS(5794),
    [anon_sym_DOLLARwarning] = ACTIONS(5794),
    [anon_sym_DOLLARinfo] = ACTIONS(5794),
    [anon_sym_default] = ACTIONS(5792),
    [anon_sym_clocking] = ACTIONS(5792),
    [anon_sym_defparam] = ACTIONS(5792),
    [anon_sym_bind] = ACTIONS(5792),
    [anon_sym_rand] = ACTIONS(5792),
    [anon_sym_const] = ACTIONS(5792),
    [anon_sym_function] = ACTIONS(5792),
    [anon_sym_static] = ACTIONS(5792),
    [anon_sym_constraint] = ACTIONS(5792),
    [anon_sym_if] = ACTIONS(5792),
    [anon_sym_else] = ACTIONS(5792),
    [anon_sym_LBRACK] = ACTIONS(5794),
    [anon_sym_localparam] = ACTIONS(5792),
    [anon_sym_parameter] = ACTIONS(5792),
    [anon_sym_var] = ACTIONS(5792),
    [anon_sym_import] = ACTIONS(5792),
    [anon_sym_export] = ACTIONS(5792),
    [anon_sym_genvar] = ACTIONS(5792),
    [anon_sym_interconnect] = ACTIONS(5792),
    [anon_sym_typedef] = ACTIONS(5792),
    [anon_sym_enum] = ACTIONS(5792),
    [anon_sym_struct] = ACTIONS(5792),
    [anon_sym_union] = ACTIONS(5792),
    [anon_sym_nettype] = ACTIONS(5792),
    [anon_sym_automatic] = ACTIONS(5792),
    [anon_sym_string] = ACTIONS(5792),
    [anon_sym_chandle] = ACTIONS(5792),
    [anon_sym_event] = ACTIONS(5792),
    [anon_sym_byte] = ACTIONS(5792),
    [anon_sym_shortint] = ACTIONS(5792),
    [anon_sym_int] = ACTIONS(5792),
    [anon_sym_longint] = ACTIONS(5792),
    [anon_sym_integer] = ACTIONS(5792),
    [anon_sym_time] = ACTIONS(5792),
    [anon_sym_bit] = ACTIONS(5792),
    [anon_sym_logic] = ACTIONS(5792),
    [anon_sym_reg] = ACTIONS(5792),
    [anon_sym_shortreal] = ACTIONS(5792),
    [anon_sym_real] = ACTIONS(5792),
    [anon_sym_realtime] = ACTIONS(5792),
    [anon_sym_supply0] = ACTIONS(5792),
    [anon_sym_supply1] = ACTIONS(5792),
    [anon_sym_signed] = ACTIONS(5792),
    [anon_sym_unsigned] = ACTIONS(5792),
    [anon_sym_task] = ACTIONS(5792),
    [anon_sym_assert] = ACTIONS(5792),
    [anon_sym_property] = ACTIONS(5792),
    [anon_sym_assume] = ACTIONS(5792),
    [anon_sym_cover] = ACTIONS(5792),
    [anon_sym_sequence] = ACTIONS(5792),
    [anon_sym_restrict] = ACTIONS(5792),
    [anon_sym_not] = ACTIONS(5792),
    [anon_sym_or] = ACTIONS(5792),
    [anon_sym_and] = ACTIONS(5792),
    [anon_sym_case] = ACTIONS(5792),
    [anon_sym_always] = ACTIONS(5792),
    [anon_sym_covergroup] = ACTIONS(5792),
    [anon_sym_let] = ACTIONS(5792),
    [anon_sym_pulldown] = ACTIONS(5792),
    [anon_sym_pullup] = ACTIONS(5792),
    [anon_sym_cmos] = ACTIONS(5792),
    [anon_sym_rcmos] = ACTIONS(5792),
    [anon_sym_bufif0] = ACTIONS(5792),
    [anon_sym_bufif1] = ACTIONS(5792),
    [anon_sym_notif0] = ACTIONS(5792),
    [anon_sym_notif1] = ACTIONS(5792),
    [anon_sym_nmos] = ACTIONS(5792),
    [anon_sym_pmos] = ACTIONS(5792),
    [anon_sym_rnmos] = ACTIONS(5792),
    [anon_sym_rpmos] = ACTIONS(5792),
    [anon_sym_nand] = ACTIONS(5792),
    [anon_sym_nor] = ACTIONS(5792),
    [anon_sym_xor] = ACTIONS(5792),
    [anon_sym_xnor] = ACTIONS(5792),
    [anon_sym_buf] = ACTIONS(5792),
    [anon_sym_tranif0] = ACTIONS(5792),
    [anon_sym_tranif1] = ACTIONS(5792),
    [anon_sym_rtranif1] = ACTIONS(5792),
    [anon_sym_rtranif0] = ACTIONS(5792),
    [anon_sym_tran] = ACTIONS(5792),
    [anon_sym_rtran] = ACTIONS(5792),
    [anon_sym_generate] = ACTIONS(5792),
    [anon_sym_endgenerate] = ACTIONS(5792),
    [anon_sym_for] = ACTIONS(5792),
    [anon_sym_initial] = ACTIONS(5792),
    [anon_sym_assign] = ACTIONS(5792),
    [anon_sym_alias] = ACTIONS(5792),
    [anon_sym_always_comb] = ACTIONS(5792),
    [anon_sym_always_latch] = ACTIONS(5792),
    [anon_sym_always_ff] = ACTIONS(5792),
    [anon_sym_final] = ACTIONS(5792),
    [anon_sym_global] = ACTIONS(5792),
    [anon_sym_LPAREN_STAR] = ACTIONS(5794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5794),
    [anon_sym_DOLLARunit] = ACTIONS(5794),
  },
  [4351] = {
    [sym_simple_identifier] = ACTIONS(4600),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_COLON] = ACTIONS(10423),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_rand] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_end] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [4352] = {
    [sym_simple_identifier] = ACTIONS(4806),
    [anon_sym_wire] = ACTIONS(4806),
    [anon_sym_tri] = ACTIONS(4806),
    [anon_sym_tri0] = ACTIONS(4806),
    [anon_sym_tri1] = ACTIONS(4806),
    [anon_sym_wand] = ACTIONS(4806),
    [anon_sym_triand] = ACTIONS(4806),
    [anon_sym_wor] = ACTIONS(4806),
    [anon_sym_trior] = ACTIONS(4806),
    [anon_sym_trireg] = ACTIONS(4806),
    [anon_sym_uwire] = ACTIONS(4806),
    [anon_sym_SEMI] = ACTIONS(4804),
    [anon_sym_COLON] = ACTIONS(10425),
    [anon_sym_extern] = ACTIONS(4806),
    [anon_sym_interface] = ACTIONS(4806),
    [anon_sym_checker] = ACTIONS(4806),
    [anon_sym_virtual] = ACTIONS(4806),
    [anon_sym_class] = ACTIONS(4806),
    [anon_sym_type] = ACTIONS(4806),
    [anon_sym_DOLLARfatal] = ACTIONS(4804),
    [anon_sym_DOLLARerror] = ACTIONS(4804),
    [anon_sym_DOLLARwarning] = ACTIONS(4804),
    [anon_sym_DOLLARinfo] = ACTIONS(4804),
    [anon_sym_default] = ACTIONS(4806),
    [anon_sym_clocking] = ACTIONS(4806),
    [anon_sym_defparam] = ACTIONS(4806),
    [anon_sym_bind] = ACTIONS(4806),
    [anon_sym_rand] = ACTIONS(4806),
    [anon_sym_const] = ACTIONS(4806),
    [anon_sym_function] = ACTIONS(4806),
    [anon_sym_static] = ACTIONS(4806),
    [anon_sym_constraint] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4806),
    [anon_sym_else] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(4804),
    [anon_sym_localparam] = ACTIONS(4806),
    [anon_sym_parameter] = ACTIONS(4806),
    [anon_sym_var] = ACTIONS(4806),
    [anon_sym_import] = ACTIONS(4806),
    [anon_sym_export] = ACTIONS(4806),
    [anon_sym_genvar] = ACTIONS(4806),
    [anon_sym_interconnect] = ACTIONS(4806),
    [anon_sym_typedef] = ACTIONS(4806),
    [anon_sym_enum] = ACTIONS(4806),
    [anon_sym_struct] = ACTIONS(4806),
    [anon_sym_union] = ACTIONS(4806),
    [anon_sym_nettype] = ACTIONS(4806),
    [anon_sym_automatic] = ACTIONS(4806),
    [anon_sym_string] = ACTIONS(4806),
    [anon_sym_chandle] = ACTIONS(4806),
    [anon_sym_event] = ACTIONS(4806),
    [anon_sym_byte] = ACTIONS(4806),
    [anon_sym_shortint] = ACTIONS(4806),
    [anon_sym_int] = ACTIONS(4806),
    [anon_sym_longint] = ACTIONS(4806),
    [anon_sym_integer] = ACTIONS(4806),
    [anon_sym_time] = ACTIONS(4806),
    [anon_sym_bit] = ACTIONS(4806),
    [anon_sym_logic] = ACTIONS(4806),
    [anon_sym_reg] = ACTIONS(4806),
    [anon_sym_shortreal] = ACTIONS(4806),
    [anon_sym_real] = ACTIONS(4806),
    [anon_sym_realtime] = ACTIONS(4806),
    [anon_sym_supply0] = ACTIONS(4806),
    [anon_sym_supply1] = ACTIONS(4806),
    [anon_sym_signed] = ACTIONS(4806),
    [anon_sym_unsigned] = ACTIONS(4806),
    [anon_sym_task] = ACTIONS(4806),
    [anon_sym_assert] = ACTIONS(4806),
    [anon_sym_property] = ACTIONS(4806),
    [anon_sym_assume] = ACTIONS(4806),
    [anon_sym_cover] = ACTIONS(4806),
    [anon_sym_sequence] = ACTIONS(4806),
    [anon_sym_restrict] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_case] = ACTIONS(4806),
    [anon_sym_always] = ACTIONS(4806),
    [anon_sym_covergroup] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_pulldown] = ACTIONS(4806),
    [anon_sym_pullup] = ACTIONS(4806),
    [anon_sym_cmos] = ACTIONS(4806),
    [anon_sym_rcmos] = ACTIONS(4806),
    [anon_sym_bufif0] = ACTIONS(4806),
    [anon_sym_bufif1] = ACTIONS(4806),
    [anon_sym_notif0] = ACTIONS(4806),
    [anon_sym_notif1] = ACTIONS(4806),
    [anon_sym_nmos] = ACTIONS(4806),
    [anon_sym_pmos] = ACTIONS(4806),
    [anon_sym_rnmos] = ACTIONS(4806),
    [anon_sym_rpmos] = ACTIONS(4806),
    [anon_sym_nand] = ACTIONS(4806),
    [anon_sym_nor] = ACTIONS(4806),
    [anon_sym_xor] = ACTIONS(4806),
    [anon_sym_xnor] = ACTIONS(4806),
    [anon_sym_buf] = ACTIONS(4806),
    [anon_sym_tranif0] = ACTIONS(4806),
    [anon_sym_tranif1] = ACTIONS(4806),
    [anon_sym_rtranif1] = ACTIONS(4806),
    [anon_sym_rtranif0] = ACTIONS(4806),
    [anon_sym_tran] = ACTIONS(4806),
    [anon_sym_rtran] = ACTIONS(4806),
    [anon_sym_generate] = ACTIONS(4806),
    [anon_sym_endgenerate] = ACTIONS(4806),
    [anon_sym_for] = ACTIONS(4806),
    [anon_sym_initial] = ACTIONS(4806),
    [anon_sym_assign] = ACTIONS(4806),
    [anon_sym_alias] = ACTIONS(4806),
    [anon_sym_always_comb] = ACTIONS(4806),
    [anon_sym_always_latch] = ACTIONS(4806),
    [anon_sym_always_ff] = ACTIONS(4806),
    [anon_sym_final] = ACTIONS(4806),
    [anon_sym_global] = ACTIONS(4806),
    [anon_sym_LPAREN_STAR] = ACTIONS(4804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4804),
    [anon_sym_DOLLARunit] = ACTIONS(4804),
  },
  [4353] = {
    [sym_simple_identifier] = ACTIONS(4430),
    [anon_sym_wire] = ACTIONS(4430),
    [anon_sym_tri] = ACTIONS(4430),
    [anon_sym_tri0] = ACTIONS(4430),
    [anon_sym_tri1] = ACTIONS(4430),
    [anon_sym_wand] = ACTIONS(4430),
    [anon_sym_triand] = ACTIONS(4430),
    [anon_sym_wor] = ACTIONS(4430),
    [anon_sym_trior] = ACTIONS(4430),
    [anon_sym_trireg] = ACTIONS(4430),
    [anon_sym_uwire] = ACTIONS(4430),
    [anon_sym_SEMI] = ACTIONS(4428),
    [anon_sym_COLON] = ACTIONS(10427),
    [anon_sym_extern] = ACTIONS(4430),
    [anon_sym_interface] = ACTIONS(4430),
    [anon_sym_checker] = ACTIONS(4430),
    [anon_sym_virtual] = ACTIONS(4430),
    [anon_sym_class] = ACTIONS(4430),
    [anon_sym_type] = ACTIONS(4430),
    [anon_sym_DOLLARfatal] = ACTIONS(4428),
    [anon_sym_DOLLARerror] = ACTIONS(4428),
    [anon_sym_DOLLARwarning] = ACTIONS(4428),
    [anon_sym_DOLLARinfo] = ACTIONS(4428),
    [anon_sym_default] = ACTIONS(4430),
    [anon_sym_clocking] = ACTIONS(4430),
    [anon_sym_defparam] = ACTIONS(4430),
    [anon_sym_bind] = ACTIONS(4430),
    [anon_sym_rand] = ACTIONS(4430),
    [anon_sym_const] = ACTIONS(4430),
    [anon_sym_function] = ACTIONS(4430),
    [anon_sym_static] = ACTIONS(4430),
    [anon_sym_constraint] = ACTIONS(4430),
    [anon_sym_if] = ACTIONS(4430),
    [anon_sym_else] = ACTIONS(4430),
    [anon_sym_LBRACK] = ACTIONS(4428),
    [anon_sym_localparam] = ACTIONS(4430),
    [anon_sym_parameter] = ACTIONS(4430),
    [anon_sym_var] = ACTIONS(4430),
    [anon_sym_import] = ACTIONS(4430),
    [anon_sym_export] = ACTIONS(4430),
    [anon_sym_genvar] = ACTIONS(4430),
    [anon_sym_interconnect] = ACTIONS(4430),
    [anon_sym_typedef] = ACTIONS(4430),
    [anon_sym_enum] = ACTIONS(4430),
    [anon_sym_struct] = ACTIONS(4430),
    [anon_sym_union] = ACTIONS(4430),
    [anon_sym_nettype] = ACTIONS(4430),
    [anon_sym_automatic] = ACTIONS(4430),
    [anon_sym_string] = ACTIONS(4430),
    [anon_sym_chandle] = ACTIONS(4430),
    [anon_sym_event] = ACTIONS(4430),
    [anon_sym_byte] = ACTIONS(4430),
    [anon_sym_shortint] = ACTIONS(4430),
    [anon_sym_int] = ACTIONS(4430),
    [anon_sym_longint] = ACTIONS(4430),
    [anon_sym_integer] = ACTIONS(4430),
    [anon_sym_time] = ACTIONS(4430),
    [anon_sym_bit] = ACTIONS(4430),
    [anon_sym_logic] = ACTIONS(4430),
    [anon_sym_reg] = ACTIONS(4430),
    [anon_sym_shortreal] = ACTIONS(4430),
    [anon_sym_real] = ACTIONS(4430),
    [anon_sym_realtime] = ACTIONS(4430),
    [anon_sym_supply0] = ACTIONS(4430),
    [anon_sym_supply1] = ACTIONS(4430),
    [anon_sym_signed] = ACTIONS(4430),
    [anon_sym_unsigned] = ACTIONS(4430),
    [anon_sym_task] = ACTIONS(4430),
    [anon_sym_assert] = ACTIONS(4430),
    [anon_sym_property] = ACTIONS(4430),
    [anon_sym_assume] = ACTIONS(4430),
    [anon_sym_cover] = ACTIONS(4430),
    [anon_sym_sequence] = ACTIONS(4430),
    [anon_sym_restrict] = ACTIONS(4430),
    [anon_sym_not] = ACTIONS(4430),
    [anon_sym_or] = ACTIONS(4430),
    [anon_sym_and] = ACTIONS(4430),
    [anon_sym_case] = ACTIONS(4430),
    [anon_sym_always] = ACTIONS(4430),
    [anon_sym_covergroup] = ACTIONS(4430),
    [anon_sym_end] = ACTIONS(4430),
    [anon_sym_let] = ACTIONS(4430),
    [anon_sym_pulldown] = ACTIONS(4430),
    [anon_sym_pullup] = ACTIONS(4430),
    [anon_sym_cmos] = ACTIONS(4430),
    [anon_sym_rcmos] = ACTIONS(4430),
    [anon_sym_bufif0] = ACTIONS(4430),
    [anon_sym_bufif1] = ACTIONS(4430),
    [anon_sym_notif0] = ACTIONS(4430),
    [anon_sym_notif1] = ACTIONS(4430),
    [anon_sym_nmos] = ACTIONS(4430),
    [anon_sym_pmos] = ACTIONS(4430),
    [anon_sym_rnmos] = ACTIONS(4430),
    [anon_sym_rpmos] = ACTIONS(4430),
    [anon_sym_nand] = ACTIONS(4430),
    [anon_sym_nor] = ACTIONS(4430),
    [anon_sym_xor] = ACTIONS(4430),
    [anon_sym_xnor] = ACTIONS(4430),
    [anon_sym_buf] = ACTIONS(4430),
    [anon_sym_tranif0] = ACTIONS(4430),
    [anon_sym_tranif1] = ACTIONS(4430),
    [anon_sym_rtranif1] = ACTIONS(4430),
    [anon_sym_rtranif0] = ACTIONS(4430),
    [anon_sym_tran] = ACTIONS(4430),
    [anon_sym_rtran] = ACTIONS(4430),
    [anon_sym_generate] = ACTIONS(4430),
    [anon_sym_for] = ACTIONS(4430),
    [anon_sym_initial] = ACTIONS(4430),
    [anon_sym_assign] = ACTIONS(4430),
    [anon_sym_alias] = ACTIONS(4430),
    [anon_sym_always_comb] = ACTIONS(4430),
    [anon_sym_always_latch] = ACTIONS(4430),
    [anon_sym_always_ff] = ACTIONS(4430),
    [anon_sym_final] = ACTIONS(4430),
    [anon_sym_global] = ACTIONS(4430),
    [anon_sym_LPAREN_STAR] = ACTIONS(4428),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4428),
    [anon_sym_DOLLARunit] = ACTIONS(4428),
  },
  [4354] = {
    [sym_simple_identifier] = ACTIONS(4436),
    [anon_sym_wire] = ACTIONS(4436),
    [anon_sym_tri] = ACTIONS(4436),
    [anon_sym_tri0] = ACTIONS(4436),
    [anon_sym_tri1] = ACTIONS(4436),
    [anon_sym_wand] = ACTIONS(4436),
    [anon_sym_triand] = ACTIONS(4436),
    [anon_sym_wor] = ACTIONS(4436),
    [anon_sym_trior] = ACTIONS(4436),
    [anon_sym_trireg] = ACTIONS(4436),
    [anon_sym_uwire] = ACTIONS(4436),
    [anon_sym_SEMI] = ACTIONS(4434),
    [anon_sym_COLON] = ACTIONS(10429),
    [anon_sym_extern] = ACTIONS(4436),
    [anon_sym_interface] = ACTIONS(4436),
    [anon_sym_checker] = ACTIONS(4436),
    [anon_sym_virtual] = ACTIONS(4436),
    [anon_sym_class] = ACTIONS(4436),
    [anon_sym_type] = ACTIONS(4436),
    [anon_sym_DOLLARfatal] = ACTIONS(4434),
    [anon_sym_DOLLARerror] = ACTIONS(4434),
    [anon_sym_DOLLARwarning] = ACTIONS(4434),
    [anon_sym_DOLLARinfo] = ACTIONS(4434),
    [anon_sym_default] = ACTIONS(4436),
    [anon_sym_clocking] = ACTIONS(4436),
    [anon_sym_defparam] = ACTIONS(4436),
    [anon_sym_bind] = ACTIONS(4436),
    [anon_sym_rand] = ACTIONS(4436),
    [anon_sym_const] = ACTIONS(4436),
    [anon_sym_function] = ACTIONS(4436),
    [anon_sym_static] = ACTIONS(4436),
    [anon_sym_constraint] = ACTIONS(4436),
    [anon_sym_if] = ACTIONS(4436),
    [anon_sym_else] = ACTIONS(4436),
    [anon_sym_LBRACK] = ACTIONS(4434),
    [anon_sym_localparam] = ACTIONS(4436),
    [anon_sym_parameter] = ACTIONS(4436),
    [anon_sym_var] = ACTIONS(4436),
    [anon_sym_import] = ACTIONS(4436),
    [anon_sym_export] = ACTIONS(4436),
    [anon_sym_genvar] = ACTIONS(4436),
    [anon_sym_interconnect] = ACTIONS(4436),
    [anon_sym_typedef] = ACTIONS(4436),
    [anon_sym_enum] = ACTIONS(4436),
    [anon_sym_struct] = ACTIONS(4436),
    [anon_sym_union] = ACTIONS(4436),
    [anon_sym_nettype] = ACTIONS(4436),
    [anon_sym_automatic] = ACTIONS(4436),
    [anon_sym_string] = ACTIONS(4436),
    [anon_sym_chandle] = ACTIONS(4436),
    [anon_sym_event] = ACTIONS(4436),
    [anon_sym_byte] = ACTIONS(4436),
    [anon_sym_shortint] = ACTIONS(4436),
    [anon_sym_int] = ACTIONS(4436),
    [anon_sym_longint] = ACTIONS(4436),
    [anon_sym_integer] = ACTIONS(4436),
    [anon_sym_time] = ACTIONS(4436),
    [anon_sym_bit] = ACTIONS(4436),
    [anon_sym_logic] = ACTIONS(4436),
    [anon_sym_reg] = ACTIONS(4436),
    [anon_sym_shortreal] = ACTIONS(4436),
    [anon_sym_real] = ACTIONS(4436),
    [anon_sym_realtime] = ACTIONS(4436),
    [anon_sym_supply0] = ACTIONS(4436),
    [anon_sym_supply1] = ACTIONS(4436),
    [anon_sym_signed] = ACTIONS(4436),
    [anon_sym_unsigned] = ACTIONS(4436),
    [anon_sym_task] = ACTIONS(4436),
    [anon_sym_assert] = ACTIONS(4436),
    [anon_sym_property] = ACTIONS(4436),
    [anon_sym_assume] = ACTIONS(4436),
    [anon_sym_cover] = ACTIONS(4436),
    [anon_sym_sequence] = ACTIONS(4436),
    [anon_sym_restrict] = ACTIONS(4436),
    [anon_sym_not] = ACTIONS(4436),
    [anon_sym_or] = ACTIONS(4436),
    [anon_sym_and] = ACTIONS(4436),
    [anon_sym_case] = ACTIONS(4436),
    [anon_sym_always] = ACTIONS(4436),
    [anon_sym_covergroup] = ACTIONS(4436),
    [anon_sym_end] = ACTIONS(4436),
    [anon_sym_let] = ACTIONS(4436),
    [anon_sym_pulldown] = ACTIONS(4436),
    [anon_sym_pullup] = ACTIONS(4436),
    [anon_sym_cmos] = ACTIONS(4436),
    [anon_sym_rcmos] = ACTIONS(4436),
    [anon_sym_bufif0] = ACTIONS(4436),
    [anon_sym_bufif1] = ACTIONS(4436),
    [anon_sym_notif0] = ACTIONS(4436),
    [anon_sym_notif1] = ACTIONS(4436),
    [anon_sym_nmos] = ACTIONS(4436),
    [anon_sym_pmos] = ACTIONS(4436),
    [anon_sym_rnmos] = ACTIONS(4436),
    [anon_sym_rpmos] = ACTIONS(4436),
    [anon_sym_nand] = ACTIONS(4436),
    [anon_sym_nor] = ACTIONS(4436),
    [anon_sym_xor] = ACTIONS(4436),
    [anon_sym_xnor] = ACTIONS(4436),
    [anon_sym_buf] = ACTIONS(4436),
    [anon_sym_tranif0] = ACTIONS(4436),
    [anon_sym_tranif1] = ACTIONS(4436),
    [anon_sym_rtranif1] = ACTIONS(4436),
    [anon_sym_rtranif0] = ACTIONS(4436),
    [anon_sym_tran] = ACTIONS(4436),
    [anon_sym_rtran] = ACTIONS(4436),
    [anon_sym_generate] = ACTIONS(4436),
    [anon_sym_for] = ACTIONS(4436),
    [anon_sym_initial] = ACTIONS(4436),
    [anon_sym_assign] = ACTIONS(4436),
    [anon_sym_alias] = ACTIONS(4436),
    [anon_sym_always_comb] = ACTIONS(4436),
    [anon_sym_always_latch] = ACTIONS(4436),
    [anon_sym_always_ff] = ACTIONS(4436),
    [anon_sym_final] = ACTIONS(4436),
    [anon_sym_global] = ACTIONS(4436),
    [anon_sym_LPAREN_STAR] = ACTIONS(4434),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4434),
    [anon_sym_DOLLARunit] = ACTIONS(4434),
  },
  [4355] = {
    [sym_simple_identifier] = ACTIONS(4768),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_COLON] = ACTIONS(10431),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_rand] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_end] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [4356] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(10433),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_rand] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_endgenerate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [4357] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_COLON] = ACTIONS(10435),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_rand] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_endgenerate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [4358] = {
    [sym_simple_identifier] = ACTIONS(4618),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_COLON] = ACTIONS(10437),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_rand] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_endgenerate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [4359] = {
    [sym_simple_identifier] = ACTIONS(4726),
    [anon_sym_wire] = ACTIONS(4726),
    [anon_sym_tri] = ACTIONS(4726),
    [anon_sym_tri0] = ACTIONS(4726),
    [anon_sym_tri1] = ACTIONS(4726),
    [anon_sym_wand] = ACTIONS(4726),
    [anon_sym_triand] = ACTIONS(4726),
    [anon_sym_wor] = ACTIONS(4726),
    [anon_sym_trior] = ACTIONS(4726),
    [anon_sym_trireg] = ACTIONS(4726),
    [anon_sym_uwire] = ACTIONS(4726),
    [anon_sym_SEMI] = ACTIONS(4724),
    [anon_sym_COLON] = ACTIONS(10439),
    [anon_sym_extern] = ACTIONS(4726),
    [anon_sym_interface] = ACTIONS(4726),
    [anon_sym_checker] = ACTIONS(4726),
    [anon_sym_virtual] = ACTIONS(4726),
    [anon_sym_class] = ACTIONS(4726),
    [anon_sym_type] = ACTIONS(4726),
    [anon_sym_DOLLARfatal] = ACTIONS(4724),
    [anon_sym_DOLLARerror] = ACTIONS(4724),
    [anon_sym_DOLLARwarning] = ACTIONS(4724),
    [anon_sym_DOLLARinfo] = ACTIONS(4724),
    [anon_sym_default] = ACTIONS(4726),
    [anon_sym_clocking] = ACTIONS(4726),
    [anon_sym_defparam] = ACTIONS(4726),
    [anon_sym_bind] = ACTIONS(4726),
    [anon_sym_rand] = ACTIONS(4726),
    [anon_sym_const] = ACTIONS(4726),
    [anon_sym_function] = ACTIONS(4726),
    [anon_sym_static] = ACTIONS(4726),
    [anon_sym_constraint] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4726),
    [anon_sym_else] = ACTIONS(4726),
    [anon_sym_LBRACK] = ACTIONS(4724),
    [anon_sym_localparam] = ACTIONS(4726),
    [anon_sym_parameter] = ACTIONS(4726),
    [anon_sym_var] = ACTIONS(4726),
    [anon_sym_import] = ACTIONS(4726),
    [anon_sym_export] = ACTIONS(4726),
    [anon_sym_genvar] = ACTIONS(4726),
    [anon_sym_interconnect] = ACTIONS(4726),
    [anon_sym_typedef] = ACTIONS(4726),
    [anon_sym_enum] = ACTIONS(4726),
    [anon_sym_struct] = ACTIONS(4726),
    [anon_sym_union] = ACTIONS(4726),
    [anon_sym_nettype] = ACTIONS(4726),
    [anon_sym_automatic] = ACTIONS(4726),
    [anon_sym_string] = ACTIONS(4726),
    [anon_sym_chandle] = ACTIONS(4726),
    [anon_sym_event] = ACTIONS(4726),
    [anon_sym_byte] = ACTIONS(4726),
    [anon_sym_shortint] = ACTIONS(4726),
    [anon_sym_int] = ACTIONS(4726),
    [anon_sym_longint] = ACTIONS(4726),
    [anon_sym_integer] = ACTIONS(4726),
    [anon_sym_time] = ACTIONS(4726),
    [anon_sym_bit] = ACTIONS(4726),
    [anon_sym_logic] = ACTIONS(4726),
    [anon_sym_reg] = ACTIONS(4726),
    [anon_sym_shortreal] = ACTIONS(4726),
    [anon_sym_real] = ACTIONS(4726),
    [anon_sym_realtime] = ACTIONS(4726),
    [anon_sym_supply0] = ACTIONS(4726),
    [anon_sym_supply1] = ACTIONS(4726),
    [anon_sym_signed] = ACTIONS(4726),
    [anon_sym_unsigned] = ACTIONS(4726),
    [anon_sym_task] = ACTIONS(4726),
    [anon_sym_assert] = ACTIONS(4726),
    [anon_sym_property] = ACTIONS(4726),
    [anon_sym_assume] = ACTIONS(4726),
    [anon_sym_cover] = ACTIONS(4726),
    [anon_sym_sequence] = ACTIONS(4726),
    [anon_sym_restrict] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4726),
    [anon_sym_or] = ACTIONS(4726),
    [anon_sym_and] = ACTIONS(4726),
    [anon_sym_case] = ACTIONS(4726),
    [anon_sym_always] = ACTIONS(4726),
    [anon_sym_covergroup] = ACTIONS(4726),
    [anon_sym_end] = ACTIONS(4726),
    [anon_sym_let] = ACTIONS(4726),
    [anon_sym_pulldown] = ACTIONS(4726),
    [anon_sym_pullup] = ACTIONS(4726),
    [anon_sym_cmos] = ACTIONS(4726),
    [anon_sym_rcmos] = ACTIONS(4726),
    [anon_sym_bufif0] = ACTIONS(4726),
    [anon_sym_bufif1] = ACTIONS(4726),
    [anon_sym_notif0] = ACTIONS(4726),
    [anon_sym_notif1] = ACTIONS(4726),
    [anon_sym_nmos] = ACTIONS(4726),
    [anon_sym_pmos] = ACTIONS(4726),
    [anon_sym_rnmos] = ACTIONS(4726),
    [anon_sym_rpmos] = ACTIONS(4726),
    [anon_sym_nand] = ACTIONS(4726),
    [anon_sym_nor] = ACTIONS(4726),
    [anon_sym_xor] = ACTIONS(4726),
    [anon_sym_xnor] = ACTIONS(4726),
    [anon_sym_buf] = ACTIONS(4726),
    [anon_sym_tranif0] = ACTIONS(4726),
    [anon_sym_tranif1] = ACTIONS(4726),
    [anon_sym_rtranif1] = ACTIONS(4726),
    [anon_sym_rtranif0] = ACTIONS(4726),
    [anon_sym_tran] = ACTIONS(4726),
    [anon_sym_rtran] = ACTIONS(4726),
    [anon_sym_generate] = ACTIONS(4726),
    [anon_sym_for] = ACTIONS(4726),
    [anon_sym_initial] = ACTIONS(4726),
    [anon_sym_assign] = ACTIONS(4726),
    [anon_sym_alias] = ACTIONS(4726),
    [anon_sym_always_comb] = ACTIONS(4726),
    [anon_sym_always_latch] = ACTIONS(4726),
    [anon_sym_always_ff] = ACTIONS(4726),
    [anon_sym_final] = ACTIONS(4726),
    [anon_sym_global] = ACTIONS(4726),
    [anon_sym_LPAREN_STAR] = ACTIONS(4724),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4724),
    [anon_sym_DOLLARunit] = ACTIONS(4724),
  },
  [4360] = {
    [sym_simple_identifier] = ACTIONS(6101),
    [anon_sym_wire] = ACTIONS(6101),
    [anon_sym_tri] = ACTIONS(6101),
    [anon_sym_tri0] = ACTIONS(6101),
    [anon_sym_tri1] = ACTIONS(6101),
    [anon_sym_wand] = ACTIONS(6101),
    [anon_sym_triand] = ACTIONS(6101),
    [anon_sym_wor] = ACTIONS(6101),
    [anon_sym_trior] = ACTIONS(6101),
    [anon_sym_trireg] = ACTIONS(6101),
    [anon_sym_uwire] = ACTIONS(6101),
    [anon_sym_SEMI] = ACTIONS(6103),
    [anon_sym_COLON] = ACTIONS(10441),
    [anon_sym_extern] = ACTIONS(6101),
    [anon_sym_interface] = ACTIONS(6101),
    [anon_sym_checker] = ACTIONS(6101),
    [anon_sym_virtual] = ACTIONS(6101),
    [anon_sym_class] = ACTIONS(6101),
    [anon_sym_type] = ACTIONS(6101),
    [anon_sym_DOLLARfatal] = ACTIONS(6103),
    [anon_sym_DOLLARerror] = ACTIONS(6103),
    [anon_sym_DOLLARwarning] = ACTIONS(6103),
    [anon_sym_DOLLARinfo] = ACTIONS(6103),
    [anon_sym_default] = ACTIONS(6101),
    [anon_sym_clocking] = ACTIONS(6101),
    [anon_sym_defparam] = ACTIONS(6101),
    [anon_sym_bind] = ACTIONS(6101),
    [anon_sym_rand] = ACTIONS(6101),
    [anon_sym_const] = ACTIONS(6101),
    [anon_sym_function] = ACTIONS(6101),
    [anon_sym_static] = ACTIONS(6101),
    [anon_sym_constraint] = ACTIONS(6101),
    [anon_sym_if] = ACTIONS(6101),
    [anon_sym_else] = ACTIONS(6101),
    [anon_sym_LBRACK] = ACTIONS(6103),
    [anon_sym_localparam] = ACTIONS(6101),
    [anon_sym_parameter] = ACTIONS(6101),
    [anon_sym_var] = ACTIONS(6101),
    [anon_sym_import] = ACTIONS(6101),
    [anon_sym_export] = ACTIONS(6101),
    [anon_sym_genvar] = ACTIONS(6101),
    [anon_sym_interconnect] = ACTIONS(6101),
    [anon_sym_typedef] = ACTIONS(6101),
    [anon_sym_enum] = ACTIONS(6101),
    [anon_sym_struct] = ACTIONS(6101),
    [anon_sym_union] = ACTIONS(6101),
    [anon_sym_nettype] = ACTIONS(6101),
    [anon_sym_automatic] = ACTIONS(6101),
    [anon_sym_string] = ACTIONS(6101),
    [anon_sym_chandle] = ACTIONS(6101),
    [anon_sym_event] = ACTIONS(6101),
    [anon_sym_byte] = ACTIONS(6101),
    [anon_sym_shortint] = ACTIONS(6101),
    [anon_sym_int] = ACTIONS(6101),
    [anon_sym_longint] = ACTIONS(6101),
    [anon_sym_integer] = ACTIONS(6101),
    [anon_sym_time] = ACTIONS(6101),
    [anon_sym_bit] = ACTIONS(6101),
    [anon_sym_logic] = ACTIONS(6101),
    [anon_sym_reg] = ACTIONS(6101),
    [anon_sym_shortreal] = ACTIONS(6101),
    [anon_sym_real] = ACTIONS(6101),
    [anon_sym_realtime] = ACTIONS(6101),
    [anon_sym_supply0] = ACTIONS(6101),
    [anon_sym_supply1] = ACTIONS(6101),
    [anon_sym_signed] = ACTIONS(6101),
    [anon_sym_unsigned] = ACTIONS(6101),
    [anon_sym_task] = ACTIONS(6101),
    [anon_sym_assert] = ACTIONS(6101),
    [anon_sym_property] = ACTIONS(6101),
    [anon_sym_assume] = ACTIONS(6101),
    [anon_sym_cover] = ACTIONS(6101),
    [anon_sym_sequence] = ACTIONS(6101),
    [anon_sym_restrict] = ACTIONS(6101),
    [anon_sym_not] = ACTIONS(6101),
    [anon_sym_or] = ACTIONS(6101),
    [anon_sym_and] = ACTIONS(6101),
    [anon_sym_case] = ACTIONS(6101),
    [anon_sym_always] = ACTIONS(6101),
    [anon_sym_covergroup] = ACTIONS(6101),
    [anon_sym_let] = ACTIONS(6101),
    [anon_sym_pulldown] = ACTIONS(6101),
    [anon_sym_pullup] = ACTIONS(6101),
    [anon_sym_cmos] = ACTIONS(6101),
    [anon_sym_rcmos] = ACTIONS(6101),
    [anon_sym_bufif0] = ACTIONS(6101),
    [anon_sym_bufif1] = ACTIONS(6101),
    [anon_sym_notif0] = ACTIONS(6101),
    [anon_sym_notif1] = ACTIONS(6101),
    [anon_sym_nmos] = ACTIONS(6101),
    [anon_sym_pmos] = ACTIONS(6101),
    [anon_sym_rnmos] = ACTIONS(6101),
    [anon_sym_rpmos] = ACTIONS(6101),
    [anon_sym_nand] = ACTIONS(6101),
    [anon_sym_nor] = ACTIONS(6101),
    [anon_sym_xor] = ACTIONS(6101),
    [anon_sym_xnor] = ACTIONS(6101),
    [anon_sym_buf] = ACTIONS(6101),
    [anon_sym_tranif0] = ACTIONS(6101),
    [anon_sym_tranif1] = ACTIONS(6101),
    [anon_sym_rtranif1] = ACTIONS(6101),
    [anon_sym_rtranif0] = ACTIONS(6101),
    [anon_sym_tran] = ACTIONS(6101),
    [anon_sym_rtran] = ACTIONS(6101),
    [anon_sym_generate] = ACTIONS(6101),
    [anon_sym_endgenerate] = ACTIONS(6101),
    [anon_sym_for] = ACTIONS(6101),
    [anon_sym_initial] = ACTIONS(6101),
    [anon_sym_assign] = ACTIONS(6101),
    [anon_sym_alias] = ACTIONS(6101),
    [anon_sym_always_comb] = ACTIONS(6101),
    [anon_sym_always_latch] = ACTIONS(6101),
    [anon_sym_always_ff] = ACTIONS(6101),
    [anon_sym_final] = ACTIONS(6101),
    [anon_sym_global] = ACTIONS(6101),
    [anon_sym_LPAREN_STAR] = ACTIONS(6103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6103),
    [anon_sym_DOLLARunit] = ACTIONS(6103),
  },
  [4361] = {
    [sym_simple_identifier] = ACTIONS(4788),
    [anon_sym_wire] = ACTIONS(4788),
    [anon_sym_tri] = ACTIONS(4788),
    [anon_sym_tri0] = ACTIONS(4788),
    [anon_sym_tri1] = ACTIONS(4788),
    [anon_sym_wand] = ACTIONS(4788),
    [anon_sym_triand] = ACTIONS(4788),
    [anon_sym_wor] = ACTIONS(4788),
    [anon_sym_trior] = ACTIONS(4788),
    [anon_sym_trireg] = ACTIONS(4788),
    [anon_sym_uwire] = ACTIONS(4788),
    [anon_sym_SEMI] = ACTIONS(4786),
    [anon_sym_COLON] = ACTIONS(10443),
    [anon_sym_extern] = ACTIONS(4788),
    [anon_sym_interface] = ACTIONS(4788),
    [anon_sym_checker] = ACTIONS(4788),
    [anon_sym_virtual] = ACTIONS(4788),
    [anon_sym_class] = ACTIONS(4788),
    [anon_sym_type] = ACTIONS(4788),
    [anon_sym_DOLLARfatal] = ACTIONS(4786),
    [anon_sym_DOLLARerror] = ACTIONS(4786),
    [anon_sym_DOLLARwarning] = ACTIONS(4786),
    [anon_sym_DOLLARinfo] = ACTIONS(4786),
    [anon_sym_default] = ACTIONS(4788),
    [anon_sym_clocking] = ACTIONS(4788),
    [anon_sym_defparam] = ACTIONS(4788),
    [anon_sym_bind] = ACTIONS(4788),
    [anon_sym_rand] = ACTIONS(4788),
    [anon_sym_const] = ACTIONS(4788),
    [anon_sym_function] = ACTIONS(4788),
    [anon_sym_static] = ACTIONS(4788),
    [anon_sym_constraint] = ACTIONS(4788),
    [anon_sym_if] = ACTIONS(4788),
    [anon_sym_else] = ACTIONS(4788),
    [anon_sym_LBRACK] = ACTIONS(4786),
    [anon_sym_localparam] = ACTIONS(4788),
    [anon_sym_parameter] = ACTIONS(4788),
    [anon_sym_var] = ACTIONS(4788),
    [anon_sym_import] = ACTIONS(4788),
    [anon_sym_export] = ACTIONS(4788),
    [anon_sym_genvar] = ACTIONS(4788),
    [anon_sym_interconnect] = ACTIONS(4788),
    [anon_sym_typedef] = ACTIONS(4788),
    [anon_sym_enum] = ACTIONS(4788),
    [anon_sym_struct] = ACTIONS(4788),
    [anon_sym_union] = ACTIONS(4788),
    [anon_sym_nettype] = ACTIONS(4788),
    [anon_sym_automatic] = ACTIONS(4788),
    [anon_sym_string] = ACTIONS(4788),
    [anon_sym_chandle] = ACTIONS(4788),
    [anon_sym_event] = ACTIONS(4788),
    [anon_sym_byte] = ACTIONS(4788),
    [anon_sym_shortint] = ACTIONS(4788),
    [anon_sym_int] = ACTIONS(4788),
    [anon_sym_longint] = ACTIONS(4788),
    [anon_sym_integer] = ACTIONS(4788),
    [anon_sym_time] = ACTIONS(4788),
    [anon_sym_bit] = ACTIONS(4788),
    [anon_sym_logic] = ACTIONS(4788),
    [anon_sym_reg] = ACTIONS(4788),
    [anon_sym_shortreal] = ACTIONS(4788),
    [anon_sym_real] = ACTIONS(4788),
    [anon_sym_realtime] = ACTIONS(4788),
    [anon_sym_supply0] = ACTIONS(4788),
    [anon_sym_supply1] = ACTIONS(4788),
    [anon_sym_signed] = ACTIONS(4788),
    [anon_sym_unsigned] = ACTIONS(4788),
    [anon_sym_task] = ACTIONS(4788),
    [anon_sym_assert] = ACTIONS(4788),
    [anon_sym_property] = ACTIONS(4788),
    [anon_sym_assume] = ACTIONS(4788),
    [anon_sym_cover] = ACTIONS(4788),
    [anon_sym_sequence] = ACTIONS(4788),
    [anon_sym_restrict] = ACTIONS(4788),
    [anon_sym_not] = ACTIONS(4788),
    [anon_sym_or] = ACTIONS(4788),
    [anon_sym_and] = ACTIONS(4788),
    [anon_sym_case] = ACTIONS(4788),
    [anon_sym_always] = ACTIONS(4788),
    [anon_sym_covergroup] = ACTIONS(4788),
    [anon_sym_end] = ACTIONS(4788),
    [anon_sym_let] = ACTIONS(4788),
    [anon_sym_pulldown] = ACTIONS(4788),
    [anon_sym_pullup] = ACTIONS(4788),
    [anon_sym_cmos] = ACTIONS(4788),
    [anon_sym_rcmos] = ACTIONS(4788),
    [anon_sym_bufif0] = ACTIONS(4788),
    [anon_sym_bufif1] = ACTIONS(4788),
    [anon_sym_notif0] = ACTIONS(4788),
    [anon_sym_notif1] = ACTIONS(4788),
    [anon_sym_nmos] = ACTIONS(4788),
    [anon_sym_pmos] = ACTIONS(4788),
    [anon_sym_rnmos] = ACTIONS(4788),
    [anon_sym_rpmos] = ACTIONS(4788),
    [anon_sym_nand] = ACTIONS(4788),
    [anon_sym_nor] = ACTIONS(4788),
    [anon_sym_xor] = ACTIONS(4788),
    [anon_sym_xnor] = ACTIONS(4788),
    [anon_sym_buf] = ACTIONS(4788),
    [anon_sym_tranif0] = ACTIONS(4788),
    [anon_sym_tranif1] = ACTIONS(4788),
    [anon_sym_rtranif1] = ACTIONS(4788),
    [anon_sym_rtranif0] = ACTIONS(4788),
    [anon_sym_tran] = ACTIONS(4788),
    [anon_sym_rtran] = ACTIONS(4788),
    [anon_sym_generate] = ACTIONS(4788),
    [anon_sym_for] = ACTIONS(4788),
    [anon_sym_initial] = ACTIONS(4788),
    [anon_sym_assign] = ACTIONS(4788),
    [anon_sym_alias] = ACTIONS(4788),
    [anon_sym_always_comb] = ACTIONS(4788),
    [anon_sym_always_latch] = ACTIONS(4788),
    [anon_sym_always_ff] = ACTIONS(4788),
    [anon_sym_final] = ACTIONS(4788),
    [anon_sym_global] = ACTIONS(4788),
    [anon_sym_LPAREN_STAR] = ACTIONS(4786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4786),
    [anon_sym_DOLLARunit] = ACTIONS(4786),
  },
  [4362] = {
    [sym_simple_identifier] = ACTIONS(5688),
    [anon_sym_wire] = ACTIONS(5688),
    [anon_sym_tri] = ACTIONS(5688),
    [anon_sym_tri0] = ACTIONS(5688),
    [anon_sym_tri1] = ACTIONS(5688),
    [anon_sym_wand] = ACTIONS(5688),
    [anon_sym_triand] = ACTIONS(5688),
    [anon_sym_wor] = ACTIONS(5688),
    [anon_sym_trior] = ACTIONS(5688),
    [anon_sym_trireg] = ACTIONS(5688),
    [anon_sym_uwire] = ACTIONS(5688),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym_COLON] = ACTIONS(10445),
    [anon_sym_extern] = ACTIONS(5688),
    [anon_sym_interface] = ACTIONS(5688),
    [anon_sym_checker] = ACTIONS(5688),
    [anon_sym_virtual] = ACTIONS(5688),
    [anon_sym_class] = ACTIONS(5688),
    [anon_sym_type] = ACTIONS(5688),
    [anon_sym_DOLLARfatal] = ACTIONS(5690),
    [anon_sym_DOLLARerror] = ACTIONS(5690),
    [anon_sym_DOLLARwarning] = ACTIONS(5690),
    [anon_sym_DOLLARinfo] = ACTIONS(5690),
    [anon_sym_default] = ACTIONS(5688),
    [anon_sym_clocking] = ACTIONS(5688),
    [anon_sym_defparam] = ACTIONS(5688),
    [anon_sym_bind] = ACTIONS(5688),
    [anon_sym_rand] = ACTIONS(5688),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_function] = ACTIONS(5688),
    [anon_sym_static] = ACTIONS(5688),
    [anon_sym_constraint] = ACTIONS(5688),
    [anon_sym_if] = ACTIONS(5688),
    [anon_sym_else] = ACTIONS(5688),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_localparam] = ACTIONS(5688),
    [anon_sym_parameter] = ACTIONS(5688),
    [anon_sym_var] = ACTIONS(5688),
    [anon_sym_import] = ACTIONS(5688),
    [anon_sym_export] = ACTIONS(5688),
    [anon_sym_genvar] = ACTIONS(5688),
    [anon_sym_interconnect] = ACTIONS(5688),
    [anon_sym_typedef] = ACTIONS(5688),
    [anon_sym_enum] = ACTIONS(5688),
    [anon_sym_struct] = ACTIONS(5688),
    [anon_sym_union] = ACTIONS(5688),
    [anon_sym_nettype] = ACTIONS(5688),
    [anon_sym_automatic] = ACTIONS(5688),
    [anon_sym_string] = ACTIONS(5688),
    [anon_sym_chandle] = ACTIONS(5688),
    [anon_sym_event] = ACTIONS(5688),
    [anon_sym_byte] = ACTIONS(5688),
    [anon_sym_shortint] = ACTIONS(5688),
    [anon_sym_int] = ACTIONS(5688),
    [anon_sym_longint] = ACTIONS(5688),
    [anon_sym_integer] = ACTIONS(5688),
    [anon_sym_time] = ACTIONS(5688),
    [anon_sym_bit] = ACTIONS(5688),
    [anon_sym_logic] = ACTIONS(5688),
    [anon_sym_reg] = ACTIONS(5688),
    [anon_sym_shortreal] = ACTIONS(5688),
    [anon_sym_real] = ACTIONS(5688),
    [anon_sym_realtime] = ACTIONS(5688),
    [anon_sym_supply0] = ACTIONS(5688),
    [anon_sym_supply1] = ACTIONS(5688),
    [anon_sym_signed] = ACTIONS(5688),
    [anon_sym_unsigned] = ACTIONS(5688),
    [anon_sym_task] = ACTIONS(5688),
    [anon_sym_assert] = ACTIONS(5688),
    [anon_sym_property] = ACTIONS(5688),
    [anon_sym_assume] = ACTIONS(5688),
    [anon_sym_cover] = ACTIONS(5688),
    [anon_sym_sequence] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym_not] = ACTIONS(5688),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_case] = ACTIONS(5688),
    [anon_sym_always] = ACTIONS(5688),
    [anon_sym_covergroup] = ACTIONS(5688),
    [anon_sym_end] = ACTIONS(5688),
    [anon_sym_let] = ACTIONS(5688),
    [anon_sym_pulldown] = ACTIONS(5688),
    [anon_sym_pullup] = ACTIONS(5688),
    [anon_sym_cmos] = ACTIONS(5688),
    [anon_sym_rcmos] = ACTIONS(5688),
    [anon_sym_bufif0] = ACTIONS(5688),
    [anon_sym_bufif1] = ACTIONS(5688),
    [anon_sym_notif0] = ACTIONS(5688),
    [anon_sym_notif1] = ACTIONS(5688),
    [anon_sym_nmos] = ACTIONS(5688),
    [anon_sym_pmos] = ACTIONS(5688),
    [anon_sym_rnmos] = ACTIONS(5688),
    [anon_sym_rpmos] = ACTIONS(5688),
    [anon_sym_nand] = ACTIONS(5688),
    [anon_sym_nor] = ACTIONS(5688),
    [anon_sym_xor] = ACTIONS(5688),
    [anon_sym_xnor] = ACTIONS(5688),
    [anon_sym_buf] = ACTIONS(5688),
    [anon_sym_tranif0] = ACTIONS(5688),
    [anon_sym_tranif1] = ACTIONS(5688),
    [anon_sym_rtranif1] = ACTIONS(5688),
    [anon_sym_rtranif0] = ACTIONS(5688),
    [anon_sym_tran] = ACTIONS(5688),
    [anon_sym_rtran] = ACTIONS(5688),
    [anon_sym_generate] = ACTIONS(5688),
    [anon_sym_for] = ACTIONS(5688),
    [anon_sym_initial] = ACTIONS(5688),
    [anon_sym_assign] = ACTIONS(5688),
    [anon_sym_alias] = ACTIONS(5688),
    [anon_sym_always_comb] = ACTIONS(5688),
    [anon_sym_always_latch] = ACTIONS(5688),
    [anon_sym_always_ff] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_global] = ACTIONS(5688),
    [anon_sym_LPAREN_STAR] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5690),
    [anon_sym_DOLLARunit] = ACTIONS(5690),
  },
  [4363] = {
    [sym_simple_identifier] = ACTIONS(4720),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_COLON] = ACTIONS(10447),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_rand] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_endgenerate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [4364] = {
    [sym_simple_identifier] = ACTIONS(4612),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_COLON] = ACTIONS(10449),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_rand] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_end] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [4365] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_COLON] = ACTIONS(10451),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_rand] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_endgenerate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [4366] = {
    [sym_simple_identifier] = ACTIONS(4774),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_COLON] = ACTIONS(10453),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_rand] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_end] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [4367] = {
    [sym_simple_identifier] = ACTIONS(4242),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_COLON] = ACTIONS(10455),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_rand] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_end] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [4368] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(10457),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_rand] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_endgenerate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [4369] = {
    [sym_simple_identifier] = ACTIONS(4310),
    [anon_sym_wire] = ACTIONS(4310),
    [anon_sym_tri] = ACTIONS(4310),
    [anon_sym_tri0] = ACTIONS(4310),
    [anon_sym_tri1] = ACTIONS(4310),
    [anon_sym_wand] = ACTIONS(4310),
    [anon_sym_triand] = ACTIONS(4310),
    [anon_sym_wor] = ACTIONS(4310),
    [anon_sym_trior] = ACTIONS(4310),
    [anon_sym_trireg] = ACTIONS(4310),
    [anon_sym_uwire] = ACTIONS(4310),
    [anon_sym_SEMI] = ACTIONS(4308),
    [anon_sym_COLON] = ACTIONS(10459),
    [anon_sym_extern] = ACTIONS(4310),
    [anon_sym_interface] = ACTIONS(4310),
    [anon_sym_checker] = ACTIONS(4310),
    [anon_sym_virtual] = ACTIONS(4310),
    [anon_sym_class] = ACTIONS(4310),
    [anon_sym_type] = ACTIONS(4310),
    [anon_sym_DOLLARfatal] = ACTIONS(4308),
    [anon_sym_DOLLARerror] = ACTIONS(4308),
    [anon_sym_DOLLARwarning] = ACTIONS(4308),
    [anon_sym_DOLLARinfo] = ACTIONS(4308),
    [anon_sym_default] = ACTIONS(4310),
    [anon_sym_clocking] = ACTIONS(4310),
    [anon_sym_defparam] = ACTIONS(4310),
    [anon_sym_bind] = ACTIONS(4310),
    [anon_sym_rand] = ACTIONS(4310),
    [anon_sym_const] = ACTIONS(4310),
    [anon_sym_function] = ACTIONS(4310),
    [anon_sym_static] = ACTIONS(4310),
    [anon_sym_constraint] = ACTIONS(4310),
    [anon_sym_if] = ACTIONS(4310),
    [anon_sym_else] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4308),
    [anon_sym_localparam] = ACTIONS(4310),
    [anon_sym_parameter] = ACTIONS(4310),
    [anon_sym_var] = ACTIONS(4310),
    [anon_sym_import] = ACTIONS(4310),
    [anon_sym_export] = ACTIONS(4310),
    [anon_sym_genvar] = ACTIONS(4310),
    [anon_sym_interconnect] = ACTIONS(4310),
    [anon_sym_typedef] = ACTIONS(4310),
    [anon_sym_enum] = ACTIONS(4310),
    [anon_sym_struct] = ACTIONS(4310),
    [anon_sym_union] = ACTIONS(4310),
    [anon_sym_nettype] = ACTIONS(4310),
    [anon_sym_automatic] = ACTIONS(4310),
    [anon_sym_string] = ACTIONS(4310),
    [anon_sym_chandle] = ACTIONS(4310),
    [anon_sym_event] = ACTIONS(4310),
    [anon_sym_byte] = ACTIONS(4310),
    [anon_sym_shortint] = ACTIONS(4310),
    [anon_sym_int] = ACTIONS(4310),
    [anon_sym_longint] = ACTIONS(4310),
    [anon_sym_integer] = ACTIONS(4310),
    [anon_sym_time] = ACTIONS(4310),
    [anon_sym_bit] = ACTIONS(4310),
    [anon_sym_logic] = ACTIONS(4310),
    [anon_sym_reg] = ACTIONS(4310),
    [anon_sym_shortreal] = ACTIONS(4310),
    [anon_sym_real] = ACTIONS(4310),
    [anon_sym_realtime] = ACTIONS(4310),
    [anon_sym_supply0] = ACTIONS(4310),
    [anon_sym_supply1] = ACTIONS(4310),
    [anon_sym_signed] = ACTIONS(4310),
    [anon_sym_unsigned] = ACTIONS(4310),
    [anon_sym_task] = ACTIONS(4310),
    [anon_sym_assert] = ACTIONS(4310),
    [anon_sym_property] = ACTIONS(4310),
    [anon_sym_assume] = ACTIONS(4310),
    [anon_sym_cover] = ACTIONS(4310),
    [anon_sym_sequence] = ACTIONS(4310),
    [anon_sym_restrict] = ACTIONS(4310),
    [anon_sym_not] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_case] = ACTIONS(4310),
    [anon_sym_always] = ACTIONS(4310),
    [anon_sym_covergroup] = ACTIONS(4310),
    [anon_sym_let] = ACTIONS(4310),
    [anon_sym_pulldown] = ACTIONS(4310),
    [anon_sym_pullup] = ACTIONS(4310),
    [anon_sym_cmos] = ACTIONS(4310),
    [anon_sym_rcmos] = ACTIONS(4310),
    [anon_sym_bufif0] = ACTIONS(4310),
    [anon_sym_bufif1] = ACTIONS(4310),
    [anon_sym_notif0] = ACTIONS(4310),
    [anon_sym_notif1] = ACTIONS(4310),
    [anon_sym_nmos] = ACTIONS(4310),
    [anon_sym_pmos] = ACTIONS(4310),
    [anon_sym_rnmos] = ACTIONS(4310),
    [anon_sym_rpmos] = ACTIONS(4310),
    [anon_sym_nand] = ACTIONS(4310),
    [anon_sym_nor] = ACTIONS(4310),
    [anon_sym_xor] = ACTIONS(4310),
    [anon_sym_xnor] = ACTIONS(4310),
    [anon_sym_buf] = ACTIONS(4310),
    [anon_sym_tranif0] = ACTIONS(4310),
    [anon_sym_tranif1] = ACTIONS(4310),
    [anon_sym_rtranif1] = ACTIONS(4310),
    [anon_sym_rtranif0] = ACTIONS(4310),
    [anon_sym_tran] = ACTIONS(4310),
    [anon_sym_rtran] = ACTIONS(4310),
    [anon_sym_generate] = ACTIONS(4310),
    [anon_sym_endgenerate] = ACTIONS(4310),
    [anon_sym_for] = ACTIONS(4310),
    [anon_sym_initial] = ACTIONS(4310),
    [anon_sym_assign] = ACTIONS(4310),
    [anon_sym_alias] = ACTIONS(4310),
    [anon_sym_always_comb] = ACTIONS(4310),
    [anon_sym_always_latch] = ACTIONS(4310),
    [anon_sym_always_ff] = ACTIONS(4310),
    [anon_sym_final] = ACTIONS(4310),
    [anon_sym_global] = ACTIONS(4310),
    [anon_sym_LPAREN_STAR] = ACTIONS(4308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4308),
    [anon_sym_DOLLARunit] = ACTIONS(4308),
  },
  [4370] = {
    [sym_simple_identifier] = ACTIONS(4334),
    [anon_sym_wire] = ACTIONS(4334),
    [anon_sym_tri] = ACTIONS(4334),
    [anon_sym_tri0] = ACTIONS(4334),
    [anon_sym_tri1] = ACTIONS(4334),
    [anon_sym_wand] = ACTIONS(4334),
    [anon_sym_triand] = ACTIONS(4334),
    [anon_sym_wor] = ACTIONS(4334),
    [anon_sym_trior] = ACTIONS(4334),
    [anon_sym_trireg] = ACTIONS(4334),
    [anon_sym_uwire] = ACTIONS(4334),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym_COLON] = ACTIONS(10461),
    [anon_sym_extern] = ACTIONS(4334),
    [anon_sym_interface] = ACTIONS(4334),
    [anon_sym_checker] = ACTIONS(4334),
    [anon_sym_virtual] = ACTIONS(4334),
    [anon_sym_class] = ACTIONS(4334),
    [anon_sym_type] = ACTIONS(4334),
    [anon_sym_DOLLARfatal] = ACTIONS(4332),
    [anon_sym_DOLLARerror] = ACTIONS(4332),
    [anon_sym_DOLLARwarning] = ACTIONS(4332),
    [anon_sym_DOLLARinfo] = ACTIONS(4332),
    [anon_sym_default] = ACTIONS(4334),
    [anon_sym_clocking] = ACTIONS(4334),
    [anon_sym_defparam] = ACTIONS(4334),
    [anon_sym_bind] = ACTIONS(4334),
    [anon_sym_rand] = ACTIONS(4334),
    [anon_sym_const] = ACTIONS(4334),
    [anon_sym_function] = ACTIONS(4334),
    [anon_sym_static] = ACTIONS(4334),
    [anon_sym_constraint] = ACTIONS(4334),
    [anon_sym_if] = ACTIONS(4334),
    [anon_sym_else] = ACTIONS(4334),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_localparam] = ACTIONS(4334),
    [anon_sym_parameter] = ACTIONS(4334),
    [anon_sym_var] = ACTIONS(4334),
    [anon_sym_import] = ACTIONS(4334),
    [anon_sym_export] = ACTIONS(4334),
    [anon_sym_genvar] = ACTIONS(4334),
    [anon_sym_interconnect] = ACTIONS(4334),
    [anon_sym_typedef] = ACTIONS(4334),
    [anon_sym_enum] = ACTIONS(4334),
    [anon_sym_struct] = ACTIONS(4334),
    [anon_sym_union] = ACTIONS(4334),
    [anon_sym_nettype] = ACTIONS(4334),
    [anon_sym_automatic] = ACTIONS(4334),
    [anon_sym_string] = ACTIONS(4334),
    [anon_sym_chandle] = ACTIONS(4334),
    [anon_sym_event] = ACTIONS(4334),
    [anon_sym_byte] = ACTIONS(4334),
    [anon_sym_shortint] = ACTIONS(4334),
    [anon_sym_int] = ACTIONS(4334),
    [anon_sym_longint] = ACTIONS(4334),
    [anon_sym_integer] = ACTIONS(4334),
    [anon_sym_time] = ACTIONS(4334),
    [anon_sym_bit] = ACTIONS(4334),
    [anon_sym_logic] = ACTIONS(4334),
    [anon_sym_reg] = ACTIONS(4334),
    [anon_sym_shortreal] = ACTIONS(4334),
    [anon_sym_real] = ACTIONS(4334),
    [anon_sym_realtime] = ACTIONS(4334),
    [anon_sym_supply0] = ACTIONS(4334),
    [anon_sym_supply1] = ACTIONS(4334),
    [anon_sym_signed] = ACTIONS(4334),
    [anon_sym_unsigned] = ACTIONS(4334),
    [anon_sym_task] = ACTIONS(4334),
    [anon_sym_assert] = ACTIONS(4334),
    [anon_sym_property] = ACTIONS(4334),
    [anon_sym_assume] = ACTIONS(4334),
    [anon_sym_cover] = ACTIONS(4334),
    [anon_sym_sequence] = ACTIONS(4334),
    [anon_sym_restrict] = ACTIONS(4334),
    [anon_sym_not] = ACTIONS(4334),
    [anon_sym_or] = ACTIONS(4334),
    [anon_sym_and] = ACTIONS(4334),
    [anon_sym_case] = ACTIONS(4334),
    [anon_sym_always] = ACTIONS(4334),
    [anon_sym_covergroup] = ACTIONS(4334),
    [anon_sym_end] = ACTIONS(4334),
    [anon_sym_let] = ACTIONS(4334),
    [anon_sym_pulldown] = ACTIONS(4334),
    [anon_sym_pullup] = ACTIONS(4334),
    [anon_sym_cmos] = ACTIONS(4334),
    [anon_sym_rcmos] = ACTIONS(4334),
    [anon_sym_bufif0] = ACTIONS(4334),
    [anon_sym_bufif1] = ACTIONS(4334),
    [anon_sym_notif0] = ACTIONS(4334),
    [anon_sym_notif1] = ACTIONS(4334),
    [anon_sym_nmos] = ACTIONS(4334),
    [anon_sym_pmos] = ACTIONS(4334),
    [anon_sym_rnmos] = ACTIONS(4334),
    [anon_sym_rpmos] = ACTIONS(4334),
    [anon_sym_nand] = ACTIONS(4334),
    [anon_sym_nor] = ACTIONS(4334),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_xnor] = ACTIONS(4334),
    [anon_sym_buf] = ACTIONS(4334),
    [anon_sym_tranif0] = ACTIONS(4334),
    [anon_sym_tranif1] = ACTIONS(4334),
    [anon_sym_rtranif1] = ACTIONS(4334),
    [anon_sym_rtranif0] = ACTIONS(4334),
    [anon_sym_tran] = ACTIONS(4334),
    [anon_sym_rtran] = ACTIONS(4334),
    [anon_sym_generate] = ACTIONS(4334),
    [anon_sym_for] = ACTIONS(4334),
    [anon_sym_initial] = ACTIONS(4334),
    [anon_sym_assign] = ACTIONS(4334),
    [anon_sym_alias] = ACTIONS(4334),
    [anon_sym_always_comb] = ACTIONS(4334),
    [anon_sym_always_latch] = ACTIONS(4334),
    [anon_sym_always_ff] = ACTIONS(4334),
    [anon_sym_final] = ACTIONS(4334),
    [anon_sym_global] = ACTIONS(4334),
    [anon_sym_LPAREN_STAR] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4332),
    [anon_sym_DOLLARunit] = ACTIONS(4332),
  },
  [4371] = {
    [sym_simple_identifier] = ACTIONS(4286),
    [anon_sym_wire] = ACTIONS(4286),
    [anon_sym_tri] = ACTIONS(4286),
    [anon_sym_tri0] = ACTIONS(4286),
    [anon_sym_tri1] = ACTIONS(4286),
    [anon_sym_wand] = ACTIONS(4286),
    [anon_sym_triand] = ACTIONS(4286),
    [anon_sym_wor] = ACTIONS(4286),
    [anon_sym_trior] = ACTIONS(4286),
    [anon_sym_trireg] = ACTIONS(4286),
    [anon_sym_uwire] = ACTIONS(4286),
    [anon_sym_SEMI] = ACTIONS(4284),
    [anon_sym_COLON] = ACTIONS(10463),
    [anon_sym_extern] = ACTIONS(4286),
    [anon_sym_interface] = ACTIONS(4286),
    [anon_sym_checker] = ACTIONS(4286),
    [anon_sym_virtual] = ACTIONS(4286),
    [anon_sym_class] = ACTIONS(4286),
    [anon_sym_type] = ACTIONS(4286),
    [anon_sym_DOLLARfatal] = ACTIONS(4284),
    [anon_sym_DOLLARerror] = ACTIONS(4284),
    [anon_sym_DOLLARwarning] = ACTIONS(4284),
    [anon_sym_DOLLARinfo] = ACTIONS(4284),
    [anon_sym_default] = ACTIONS(4286),
    [anon_sym_clocking] = ACTIONS(4286),
    [anon_sym_defparam] = ACTIONS(4286),
    [anon_sym_bind] = ACTIONS(4286),
    [anon_sym_rand] = ACTIONS(4286),
    [anon_sym_const] = ACTIONS(4286),
    [anon_sym_function] = ACTIONS(4286),
    [anon_sym_static] = ACTIONS(4286),
    [anon_sym_constraint] = ACTIONS(4286),
    [anon_sym_if] = ACTIONS(4286),
    [anon_sym_else] = ACTIONS(4286),
    [anon_sym_LBRACK] = ACTIONS(4284),
    [anon_sym_localparam] = ACTIONS(4286),
    [anon_sym_parameter] = ACTIONS(4286),
    [anon_sym_var] = ACTIONS(4286),
    [anon_sym_import] = ACTIONS(4286),
    [anon_sym_export] = ACTIONS(4286),
    [anon_sym_genvar] = ACTIONS(4286),
    [anon_sym_interconnect] = ACTIONS(4286),
    [anon_sym_typedef] = ACTIONS(4286),
    [anon_sym_enum] = ACTIONS(4286),
    [anon_sym_struct] = ACTIONS(4286),
    [anon_sym_union] = ACTIONS(4286),
    [anon_sym_nettype] = ACTIONS(4286),
    [anon_sym_automatic] = ACTIONS(4286),
    [anon_sym_string] = ACTIONS(4286),
    [anon_sym_chandle] = ACTIONS(4286),
    [anon_sym_event] = ACTIONS(4286),
    [anon_sym_byte] = ACTIONS(4286),
    [anon_sym_shortint] = ACTIONS(4286),
    [anon_sym_int] = ACTIONS(4286),
    [anon_sym_longint] = ACTIONS(4286),
    [anon_sym_integer] = ACTIONS(4286),
    [anon_sym_time] = ACTIONS(4286),
    [anon_sym_bit] = ACTIONS(4286),
    [anon_sym_logic] = ACTIONS(4286),
    [anon_sym_reg] = ACTIONS(4286),
    [anon_sym_shortreal] = ACTIONS(4286),
    [anon_sym_real] = ACTIONS(4286),
    [anon_sym_realtime] = ACTIONS(4286),
    [anon_sym_supply0] = ACTIONS(4286),
    [anon_sym_supply1] = ACTIONS(4286),
    [anon_sym_signed] = ACTIONS(4286),
    [anon_sym_unsigned] = ACTIONS(4286),
    [anon_sym_task] = ACTIONS(4286),
    [anon_sym_assert] = ACTIONS(4286),
    [anon_sym_property] = ACTIONS(4286),
    [anon_sym_assume] = ACTIONS(4286),
    [anon_sym_cover] = ACTIONS(4286),
    [anon_sym_sequence] = ACTIONS(4286),
    [anon_sym_restrict] = ACTIONS(4286),
    [anon_sym_not] = ACTIONS(4286),
    [anon_sym_or] = ACTIONS(4286),
    [anon_sym_and] = ACTIONS(4286),
    [anon_sym_case] = ACTIONS(4286),
    [anon_sym_always] = ACTIONS(4286),
    [anon_sym_covergroup] = ACTIONS(4286),
    [anon_sym_end] = ACTIONS(4286),
    [anon_sym_let] = ACTIONS(4286),
    [anon_sym_pulldown] = ACTIONS(4286),
    [anon_sym_pullup] = ACTIONS(4286),
    [anon_sym_cmos] = ACTIONS(4286),
    [anon_sym_rcmos] = ACTIONS(4286),
    [anon_sym_bufif0] = ACTIONS(4286),
    [anon_sym_bufif1] = ACTIONS(4286),
    [anon_sym_notif0] = ACTIONS(4286),
    [anon_sym_notif1] = ACTIONS(4286),
    [anon_sym_nmos] = ACTIONS(4286),
    [anon_sym_pmos] = ACTIONS(4286),
    [anon_sym_rnmos] = ACTIONS(4286),
    [anon_sym_rpmos] = ACTIONS(4286),
    [anon_sym_nand] = ACTIONS(4286),
    [anon_sym_nor] = ACTIONS(4286),
    [anon_sym_xor] = ACTIONS(4286),
    [anon_sym_xnor] = ACTIONS(4286),
    [anon_sym_buf] = ACTIONS(4286),
    [anon_sym_tranif0] = ACTIONS(4286),
    [anon_sym_tranif1] = ACTIONS(4286),
    [anon_sym_rtranif1] = ACTIONS(4286),
    [anon_sym_rtranif0] = ACTIONS(4286),
    [anon_sym_tran] = ACTIONS(4286),
    [anon_sym_rtran] = ACTIONS(4286),
    [anon_sym_generate] = ACTIONS(4286),
    [anon_sym_for] = ACTIONS(4286),
    [anon_sym_initial] = ACTIONS(4286),
    [anon_sym_assign] = ACTIONS(4286),
    [anon_sym_alias] = ACTIONS(4286),
    [anon_sym_always_comb] = ACTIONS(4286),
    [anon_sym_always_latch] = ACTIONS(4286),
    [anon_sym_always_ff] = ACTIONS(4286),
    [anon_sym_final] = ACTIONS(4286),
    [anon_sym_global] = ACTIONS(4286),
    [anon_sym_LPAREN_STAR] = ACTIONS(4284),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4284),
    [anon_sym_DOLLARunit] = ACTIONS(4284),
  },
  [4372] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_COLON] = ACTIONS(10465),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_rand] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_endgenerate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [4373] = {
    [sym_simple_identifier] = ACTIONS(4418),
    [anon_sym_wire] = ACTIONS(4418),
    [anon_sym_tri] = ACTIONS(4418),
    [anon_sym_tri0] = ACTIONS(4418),
    [anon_sym_tri1] = ACTIONS(4418),
    [anon_sym_wand] = ACTIONS(4418),
    [anon_sym_triand] = ACTIONS(4418),
    [anon_sym_wor] = ACTIONS(4418),
    [anon_sym_trior] = ACTIONS(4418),
    [anon_sym_trireg] = ACTIONS(4418),
    [anon_sym_uwire] = ACTIONS(4418),
    [anon_sym_SEMI] = ACTIONS(4416),
    [anon_sym_COLON] = ACTIONS(10467),
    [anon_sym_extern] = ACTIONS(4418),
    [anon_sym_interface] = ACTIONS(4418),
    [anon_sym_checker] = ACTIONS(4418),
    [anon_sym_virtual] = ACTIONS(4418),
    [anon_sym_class] = ACTIONS(4418),
    [anon_sym_type] = ACTIONS(4418),
    [anon_sym_DOLLARfatal] = ACTIONS(4416),
    [anon_sym_DOLLARerror] = ACTIONS(4416),
    [anon_sym_DOLLARwarning] = ACTIONS(4416),
    [anon_sym_DOLLARinfo] = ACTIONS(4416),
    [anon_sym_default] = ACTIONS(4418),
    [anon_sym_clocking] = ACTIONS(4418),
    [anon_sym_defparam] = ACTIONS(4418),
    [anon_sym_bind] = ACTIONS(4418),
    [anon_sym_rand] = ACTIONS(4418),
    [anon_sym_const] = ACTIONS(4418),
    [anon_sym_function] = ACTIONS(4418),
    [anon_sym_static] = ACTIONS(4418),
    [anon_sym_constraint] = ACTIONS(4418),
    [anon_sym_if] = ACTIONS(4418),
    [anon_sym_else] = ACTIONS(4418),
    [anon_sym_LBRACK] = ACTIONS(4416),
    [anon_sym_localparam] = ACTIONS(4418),
    [anon_sym_parameter] = ACTIONS(4418),
    [anon_sym_var] = ACTIONS(4418),
    [anon_sym_import] = ACTIONS(4418),
    [anon_sym_export] = ACTIONS(4418),
    [anon_sym_genvar] = ACTIONS(4418),
    [anon_sym_interconnect] = ACTIONS(4418),
    [anon_sym_typedef] = ACTIONS(4418),
    [anon_sym_enum] = ACTIONS(4418),
    [anon_sym_struct] = ACTIONS(4418),
    [anon_sym_union] = ACTIONS(4418),
    [anon_sym_nettype] = ACTIONS(4418),
    [anon_sym_automatic] = ACTIONS(4418),
    [anon_sym_string] = ACTIONS(4418),
    [anon_sym_chandle] = ACTIONS(4418),
    [anon_sym_event] = ACTIONS(4418),
    [anon_sym_byte] = ACTIONS(4418),
    [anon_sym_shortint] = ACTIONS(4418),
    [anon_sym_int] = ACTIONS(4418),
    [anon_sym_longint] = ACTIONS(4418),
    [anon_sym_integer] = ACTIONS(4418),
    [anon_sym_time] = ACTIONS(4418),
    [anon_sym_bit] = ACTIONS(4418),
    [anon_sym_logic] = ACTIONS(4418),
    [anon_sym_reg] = ACTIONS(4418),
    [anon_sym_shortreal] = ACTIONS(4418),
    [anon_sym_real] = ACTIONS(4418),
    [anon_sym_realtime] = ACTIONS(4418),
    [anon_sym_supply0] = ACTIONS(4418),
    [anon_sym_supply1] = ACTIONS(4418),
    [anon_sym_signed] = ACTIONS(4418),
    [anon_sym_unsigned] = ACTIONS(4418),
    [anon_sym_task] = ACTIONS(4418),
    [anon_sym_assert] = ACTIONS(4418),
    [anon_sym_property] = ACTIONS(4418),
    [anon_sym_assume] = ACTIONS(4418),
    [anon_sym_cover] = ACTIONS(4418),
    [anon_sym_sequence] = ACTIONS(4418),
    [anon_sym_restrict] = ACTIONS(4418),
    [anon_sym_not] = ACTIONS(4418),
    [anon_sym_or] = ACTIONS(4418),
    [anon_sym_and] = ACTIONS(4418),
    [anon_sym_case] = ACTIONS(4418),
    [anon_sym_always] = ACTIONS(4418),
    [anon_sym_covergroup] = ACTIONS(4418),
    [anon_sym_end] = ACTIONS(4418),
    [anon_sym_let] = ACTIONS(4418),
    [anon_sym_pulldown] = ACTIONS(4418),
    [anon_sym_pullup] = ACTIONS(4418),
    [anon_sym_cmos] = ACTIONS(4418),
    [anon_sym_rcmos] = ACTIONS(4418),
    [anon_sym_bufif0] = ACTIONS(4418),
    [anon_sym_bufif1] = ACTIONS(4418),
    [anon_sym_notif0] = ACTIONS(4418),
    [anon_sym_notif1] = ACTIONS(4418),
    [anon_sym_nmos] = ACTIONS(4418),
    [anon_sym_pmos] = ACTIONS(4418),
    [anon_sym_rnmos] = ACTIONS(4418),
    [anon_sym_rpmos] = ACTIONS(4418),
    [anon_sym_nand] = ACTIONS(4418),
    [anon_sym_nor] = ACTIONS(4418),
    [anon_sym_xor] = ACTIONS(4418),
    [anon_sym_xnor] = ACTIONS(4418),
    [anon_sym_buf] = ACTIONS(4418),
    [anon_sym_tranif0] = ACTIONS(4418),
    [anon_sym_tranif1] = ACTIONS(4418),
    [anon_sym_rtranif1] = ACTIONS(4418),
    [anon_sym_rtranif0] = ACTIONS(4418),
    [anon_sym_tran] = ACTIONS(4418),
    [anon_sym_rtran] = ACTIONS(4418),
    [anon_sym_generate] = ACTIONS(4418),
    [anon_sym_for] = ACTIONS(4418),
    [anon_sym_initial] = ACTIONS(4418),
    [anon_sym_assign] = ACTIONS(4418),
    [anon_sym_alias] = ACTIONS(4418),
    [anon_sym_always_comb] = ACTIONS(4418),
    [anon_sym_always_latch] = ACTIONS(4418),
    [anon_sym_always_ff] = ACTIONS(4418),
    [anon_sym_final] = ACTIONS(4418),
    [anon_sym_global] = ACTIONS(4418),
    [anon_sym_LPAREN_STAR] = ACTIONS(4416),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4416),
    [anon_sym_DOLLARunit] = ACTIONS(4416),
  },
  [4374] = {
    [sym_simple_identifier] = ACTIONS(4690),
    [anon_sym_wire] = ACTIONS(4690),
    [anon_sym_tri] = ACTIONS(4690),
    [anon_sym_tri0] = ACTIONS(4690),
    [anon_sym_tri1] = ACTIONS(4690),
    [anon_sym_wand] = ACTIONS(4690),
    [anon_sym_triand] = ACTIONS(4690),
    [anon_sym_wor] = ACTIONS(4690),
    [anon_sym_trior] = ACTIONS(4690),
    [anon_sym_trireg] = ACTIONS(4690),
    [anon_sym_uwire] = ACTIONS(4690),
    [anon_sym_SEMI] = ACTIONS(4688),
    [anon_sym_COLON] = ACTIONS(10469),
    [anon_sym_extern] = ACTIONS(4690),
    [anon_sym_interface] = ACTIONS(4690),
    [anon_sym_checker] = ACTIONS(4690),
    [anon_sym_virtual] = ACTIONS(4690),
    [anon_sym_class] = ACTIONS(4690),
    [anon_sym_type] = ACTIONS(4690),
    [anon_sym_DOLLARfatal] = ACTIONS(4688),
    [anon_sym_DOLLARerror] = ACTIONS(4688),
    [anon_sym_DOLLARwarning] = ACTIONS(4688),
    [anon_sym_DOLLARinfo] = ACTIONS(4688),
    [anon_sym_default] = ACTIONS(4690),
    [anon_sym_clocking] = ACTIONS(4690),
    [anon_sym_defparam] = ACTIONS(4690),
    [anon_sym_bind] = ACTIONS(4690),
    [anon_sym_rand] = ACTIONS(4690),
    [anon_sym_const] = ACTIONS(4690),
    [anon_sym_function] = ACTIONS(4690),
    [anon_sym_static] = ACTIONS(4690),
    [anon_sym_constraint] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4690),
    [anon_sym_else] = ACTIONS(4690),
    [anon_sym_LBRACK] = ACTIONS(4688),
    [anon_sym_localparam] = ACTIONS(4690),
    [anon_sym_parameter] = ACTIONS(4690),
    [anon_sym_var] = ACTIONS(4690),
    [anon_sym_import] = ACTIONS(4690),
    [anon_sym_export] = ACTIONS(4690),
    [anon_sym_genvar] = ACTIONS(4690),
    [anon_sym_interconnect] = ACTIONS(4690),
    [anon_sym_typedef] = ACTIONS(4690),
    [anon_sym_enum] = ACTIONS(4690),
    [anon_sym_struct] = ACTIONS(4690),
    [anon_sym_union] = ACTIONS(4690),
    [anon_sym_nettype] = ACTIONS(4690),
    [anon_sym_automatic] = ACTIONS(4690),
    [anon_sym_string] = ACTIONS(4690),
    [anon_sym_chandle] = ACTIONS(4690),
    [anon_sym_event] = ACTIONS(4690),
    [anon_sym_byte] = ACTIONS(4690),
    [anon_sym_shortint] = ACTIONS(4690),
    [anon_sym_int] = ACTIONS(4690),
    [anon_sym_longint] = ACTIONS(4690),
    [anon_sym_integer] = ACTIONS(4690),
    [anon_sym_time] = ACTIONS(4690),
    [anon_sym_bit] = ACTIONS(4690),
    [anon_sym_logic] = ACTIONS(4690),
    [anon_sym_reg] = ACTIONS(4690),
    [anon_sym_shortreal] = ACTIONS(4690),
    [anon_sym_real] = ACTIONS(4690),
    [anon_sym_realtime] = ACTIONS(4690),
    [anon_sym_supply0] = ACTIONS(4690),
    [anon_sym_supply1] = ACTIONS(4690),
    [anon_sym_signed] = ACTIONS(4690),
    [anon_sym_unsigned] = ACTIONS(4690),
    [anon_sym_task] = ACTIONS(4690),
    [anon_sym_assert] = ACTIONS(4690),
    [anon_sym_property] = ACTIONS(4690),
    [anon_sym_assume] = ACTIONS(4690),
    [anon_sym_cover] = ACTIONS(4690),
    [anon_sym_sequence] = ACTIONS(4690),
    [anon_sym_restrict] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4690),
    [anon_sym_or] = ACTIONS(4690),
    [anon_sym_and] = ACTIONS(4690),
    [anon_sym_case] = ACTIONS(4690),
    [anon_sym_always] = ACTIONS(4690),
    [anon_sym_covergroup] = ACTIONS(4690),
    [anon_sym_end] = ACTIONS(4690),
    [anon_sym_let] = ACTIONS(4690),
    [anon_sym_pulldown] = ACTIONS(4690),
    [anon_sym_pullup] = ACTIONS(4690),
    [anon_sym_cmos] = ACTIONS(4690),
    [anon_sym_rcmos] = ACTIONS(4690),
    [anon_sym_bufif0] = ACTIONS(4690),
    [anon_sym_bufif1] = ACTIONS(4690),
    [anon_sym_notif0] = ACTIONS(4690),
    [anon_sym_notif1] = ACTIONS(4690),
    [anon_sym_nmos] = ACTIONS(4690),
    [anon_sym_pmos] = ACTIONS(4690),
    [anon_sym_rnmos] = ACTIONS(4690),
    [anon_sym_rpmos] = ACTIONS(4690),
    [anon_sym_nand] = ACTIONS(4690),
    [anon_sym_nor] = ACTIONS(4690),
    [anon_sym_xor] = ACTIONS(4690),
    [anon_sym_xnor] = ACTIONS(4690),
    [anon_sym_buf] = ACTIONS(4690),
    [anon_sym_tranif0] = ACTIONS(4690),
    [anon_sym_tranif1] = ACTIONS(4690),
    [anon_sym_rtranif1] = ACTIONS(4690),
    [anon_sym_rtranif0] = ACTIONS(4690),
    [anon_sym_tran] = ACTIONS(4690),
    [anon_sym_rtran] = ACTIONS(4690),
    [anon_sym_generate] = ACTIONS(4690),
    [anon_sym_for] = ACTIONS(4690),
    [anon_sym_initial] = ACTIONS(4690),
    [anon_sym_assign] = ACTIONS(4690),
    [anon_sym_alias] = ACTIONS(4690),
    [anon_sym_always_comb] = ACTIONS(4690),
    [anon_sym_always_latch] = ACTIONS(4690),
    [anon_sym_always_ff] = ACTIONS(4690),
    [anon_sym_final] = ACTIONS(4690),
    [anon_sym_global] = ACTIONS(4690),
    [anon_sym_LPAREN_STAR] = ACTIONS(4688),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4688),
    [anon_sym_DOLLARunit] = ACTIONS(4688),
  },
  [4375] = {
    [sym_simple_identifier] = ACTIONS(4744),
    [anon_sym_wire] = ACTIONS(4744),
    [anon_sym_tri] = ACTIONS(4744),
    [anon_sym_tri0] = ACTIONS(4744),
    [anon_sym_tri1] = ACTIONS(4744),
    [anon_sym_wand] = ACTIONS(4744),
    [anon_sym_triand] = ACTIONS(4744),
    [anon_sym_wor] = ACTIONS(4744),
    [anon_sym_trior] = ACTIONS(4744),
    [anon_sym_trireg] = ACTIONS(4744),
    [anon_sym_uwire] = ACTIONS(4744),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_COLON] = ACTIONS(10471),
    [anon_sym_extern] = ACTIONS(4744),
    [anon_sym_interface] = ACTIONS(4744),
    [anon_sym_checker] = ACTIONS(4744),
    [anon_sym_virtual] = ACTIONS(4744),
    [anon_sym_class] = ACTIONS(4744),
    [anon_sym_type] = ACTIONS(4744),
    [anon_sym_DOLLARfatal] = ACTIONS(4742),
    [anon_sym_DOLLARerror] = ACTIONS(4742),
    [anon_sym_DOLLARwarning] = ACTIONS(4742),
    [anon_sym_DOLLARinfo] = ACTIONS(4742),
    [anon_sym_default] = ACTIONS(4744),
    [anon_sym_clocking] = ACTIONS(4744),
    [anon_sym_defparam] = ACTIONS(4744),
    [anon_sym_bind] = ACTIONS(4744),
    [anon_sym_rand] = ACTIONS(4744),
    [anon_sym_const] = ACTIONS(4744),
    [anon_sym_function] = ACTIONS(4744),
    [anon_sym_static] = ACTIONS(4744),
    [anon_sym_constraint] = ACTIONS(4744),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [anon_sym_localparam] = ACTIONS(4744),
    [anon_sym_parameter] = ACTIONS(4744),
    [anon_sym_var] = ACTIONS(4744),
    [anon_sym_import] = ACTIONS(4744),
    [anon_sym_export] = ACTIONS(4744),
    [anon_sym_genvar] = ACTIONS(4744),
    [anon_sym_interconnect] = ACTIONS(4744),
    [anon_sym_typedef] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_struct] = ACTIONS(4744),
    [anon_sym_union] = ACTIONS(4744),
    [anon_sym_nettype] = ACTIONS(4744),
    [anon_sym_automatic] = ACTIONS(4744),
    [anon_sym_string] = ACTIONS(4744),
    [anon_sym_chandle] = ACTIONS(4744),
    [anon_sym_event] = ACTIONS(4744),
    [anon_sym_byte] = ACTIONS(4744),
    [anon_sym_shortint] = ACTIONS(4744),
    [anon_sym_int] = ACTIONS(4744),
    [anon_sym_longint] = ACTIONS(4744),
    [anon_sym_integer] = ACTIONS(4744),
    [anon_sym_time] = ACTIONS(4744),
    [anon_sym_bit] = ACTIONS(4744),
    [anon_sym_logic] = ACTIONS(4744),
    [anon_sym_reg] = ACTIONS(4744),
    [anon_sym_shortreal] = ACTIONS(4744),
    [anon_sym_real] = ACTIONS(4744),
    [anon_sym_realtime] = ACTIONS(4744),
    [anon_sym_supply0] = ACTIONS(4744),
    [anon_sym_supply1] = ACTIONS(4744),
    [anon_sym_signed] = ACTIONS(4744),
    [anon_sym_unsigned] = ACTIONS(4744),
    [anon_sym_task] = ACTIONS(4744),
    [anon_sym_assert] = ACTIONS(4744),
    [anon_sym_property] = ACTIONS(4744),
    [anon_sym_assume] = ACTIONS(4744),
    [anon_sym_cover] = ACTIONS(4744),
    [anon_sym_sequence] = ACTIONS(4744),
    [anon_sym_restrict] = ACTIONS(4744),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_or] = ACTIONS(4744),
    [anon_sym_and] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_always] = ACTIONS(4744),
    [anon_sym_covergroup] = ACTIONS(4744),
    [anon_sym_let] = ACTIONS(4744),
    [anon_sym_pulldown] = ACTIONS(4744),
    [anon_sym_pullup] = ACTIONS(4744),
    [anon_sym_cmos] = ACTIONS(4744),
    [anon_sym_rcmos] = ACTIONS(4744),
    [anon_sym_bufif0] = ACTIONS(4744),
    [anon_sym_bufif1] = ACTIONS(4744),
    [anon_sym_notif0] = ACTIONS(4744),
    [anon_sym_notif1] = ACTIONS(4744),
    [anon_sym_nmos] = ACTIONS(4744),
    [anon_sym_pmos] = ACTIONS(4744),
    [anon_sym_rnmos] = ACTIONS(4744),
    [anon_sym_rpmos] = ACTIONS(4744),
    [anon_sym_nand] = ACTIONS(4744),
    [anon_sym_nor] = ACTIONS(4744),
    [anon_sym_xor] = ACTIONS(4744),
    [anon_sym_xnor] = ACTIONS(4744),
    [anon_sym_buf] = ACTIONS(4744),
    [anon_sym_tranif0] = ACTIONS(4744),
    [anon_sym_tranif1] = ACTIONS(4744),
    [anon_sym_rtranif1] = ACTIONS(4744),
    [anon_sym_rtranif0] = ACTIONS(4744),
    [anon_sym_tran] = ACTIONS(4744),
    [anon_sym_rtran] = ACTIONS(4744),
    [anon_sym_generate] = ACTIONS(4744),
    [anon_sym_endgenerate] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_initial] = ACTIONS(4744),
    [anon_sym_assign] = ACTIONS(4744),
    [anon_sym_alias] = ACTIONS(4744),
    [anon_sym_always_comb] = ACTIONS(4744),
    [anon_sym_always_latch] = ACTIONS(4744),
    [anon_sym_always_ff] = ACTIONS(4744),
    [anon_sym_final] = ACTIONS(4744),
    [anon_sym_global] = ACTIONS(4744),
    [anon_sym_LPAREN_STAR] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4742),
    [anon_sym_DOLLARunit] = ACTIONS(4742),
  },
  [4376] = {
    [sym_simple_identifier] = ACTIONS(4536),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_COLON] = ACTIONS(10473),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_rand] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_endgenerate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [4377] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_COLON] = ACTIONS(10475),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_rand] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_end] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [4378] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_COLON] = ACTIONS(10477),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_rand] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_end] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [4379] = {
    [sym_simple_identifier] = ACTIONS(4230),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_COLON] = ACTIONS(10479),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_rand] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_endgenerate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [4380] = {
    [sym_simple_identifier] = ACTIONS(4412),
    [anon_sym_wire] = ACTIONS(4412),
    [anon_sym_tri] = ACTIONS(4412),
    [anon_sym_tri0] = ACTIONS(4412),
    [anon_sym_tri1] = ACTIONS(4412),
    [anon_sym_wand] = ACTIONS(4412),
    [anon_sym_triand] = ACTIONS(4412),
    [anon_sym_wor] = ACTIONS(4412),
    [anon_sym_trior] = ACTIONS(4412),
    [anon_sym_trireg] = ACTIONS(4412),
    [anon_sym_uwire] = ACTIONS(4412),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym_COLON] = ACTIONS(10481),
    [anon_sym_extern] = ACTIONS(4412),
    [anon_sym_interface] = ACTIONS(4412),
    [anon_sym_checker] = ACTIONS(4412),
    [anon_sym_virtual] = ACTIONS(4412),
    [anon_sym_class] = ACTIONS(4412),
    [anon_sym_type] = ACTIONS(4412),
    [anon_sym_DOLLARfatal] = ACTIONS(4410),
    [anon_sym_DOLLARerror] = ACTIONS(4410),
    [anon_sym_DOLLARwarning] = ACTIONS(4410),
    [anon_sym_DOLLARinfo] = ACTIONS(4410),
    [anon_sym_default] = ACTIONS(4412),
    [anon_sym_clocking] = ACTIONS(4412),
    [anon_sym_defparam] = ACTIONS(4412),
    [anon_sym_bind] = ACTIONS(4412),
    [anon_sym_rand] = ACTIONS(4412),
    [anon_sym_const] = ACTIONS(4412),
    [anon_sym_function] = ACTIONS(4412),
    [anon_sym_static] = ACTIONS(4412),
    [anon_sym_constraint] = ACTIONS(4412),
    [anon_sym_if] = ACTIONS(4412),
    [anon_sym_else] = ACTIONS(4412),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_localparam] = ACTIONS(4412),
    [anon_sym_parameter] = ACTIONS(4412),
    [anon_sym_var] = ACTIONS(4412),
    [anon_sym_import] = ACTIONS(4412),
    [anon_sym_export] = ACTIONS(4412),
    [anon_sym_genvar] = ACTIONS(4412),
    [anon_sym_interconnect] = ACTIONS(4412),
    [anon_sym_typedef] = ACTIONS(4412),
    [anon_sym_enum] = ACTIONS(4412),
    [anon_sym_struct] = ACTIONS(4412),
    [anon_sym_union] = ACTIONS(4412),
    [anon_sym_nettype] = ACTIONS(4412),
    [anon_sym_automatic] = ACTIONS(4412),
    [anon_sym_string] = ACTIONS(4412),
    [anon_sym_chandle] = ACTIONS(4412),
    [anon_sym_event] = ACTIONS(4412),
    [anon_sym_byte] = ACTIONS(4412),
    [anon_sym_shortint] = ACTIONS(4412),
    [anon_sym_int] = ACTIONS(4412),
    [anon_sym_longint] = ACTIONS(4412),
    [anon_sym_integer] = ACTIONS(4412),
    [anon_sym_time] = ACTIONS(4412),
    [anon_sym_bit] = ACTIONS(4412),
    [anon_sym_logic] = ACTIONS(4412),
    [anon_sym_reg] = ACTIONS(4412),
    [anon_sym_shortreal] = ACTIONS(4412),
    [anon_sym_real] = ACTIONS(4412),
    [anon_sym_realtime] = ACTIONS(4412),
    [anon_sym_supply0] = ACTIONS(4412),
    [anon_sym_supply1] = ACTIONS(4412),
    [anon_sym_signed] = ACTIONS(4412),
    [anon_sym_unsigned] = ACTIONS(4412),
    [anon_sym_task] = ACTIONS(4412),
    [anon_sym_assert] = ACTIONS(4412),
    [anon_sym_property] = ACTIONS(4412),
    [anon_sym_assume] = ACTIONS(4412),
    [anon_sym_cover] = ACTIONS(4412),
    [anon_sym_sequence] = ACTIONS(4412),
    [anon_sym_restrict] = ACTIONS(4412),
    [anon_sym_not] = ACTIONS(4412),
    [anon_sym_or] = ACTIONS(4412),
    [anon_sym_and] = ACTIONS(4412),
    [anon_sym_case] = ACTIONS(4412),
    [anon_sym_always] = ACTIONS(4412),
    [anon_sym_covergroup] = ACTIONS(4412),
    [anon_sym_let] = ACTIONS(4412),
    [anon_sym_pulldown] = ACTIONS(4412),
    [anon_sym_pullup] = ACTIONS(4412),
    [anon_sym_cmos] = ACTIONS(4412),
    [anon_sym_rcmos] = ACTIONS(4412),
    [anon_sym_bufif0] = ACTIONS(4412),
    [anon_sym_bufif1] = ACTIONS(4412),
    [anon_sym_notif0] = ACTIONS(4412),
    [anon_sym_notif1] = ACTIONS(4412),
    [anon_sym_nmos] = ACTIONS(4412),
    [anon_sym_pmos] = ACTIONS(4412),
    [anon_sym_rnmos] = ACTIONS(4412),
    [anon_sym_rpmos] = ACTIONS(4412),
    [anon_sym_nand] = ACTIONS(4412),
    [anon_sym_nor] = ACTIONS(4412),
    [anon_sym_xor] = ACTIONS(4412),
    [anon_sym_xnor] = ACTIONS(4412),
    [anon_sym_buf] = ACTIONS(4412),
    [anon_sym_tranif0] = ACTIONS(4412),
    [anon_sym_tranif1] = ACTIONS(4412),
    [anon_sym_rtranif1] = ACTIONS(4412),
    [anon_sym_rtranif0] = ACTIONS(4412),
    [anon_sym_tran] = ACTIONS(4412),
    [anon_sym_rtran] = ACTIONS(4412),
    [anon_sym_generate] = ACTIONS(4412),
    [anon_sym_endgenerate] = ACTIONS(4412),
    [anon_sym_for] = ACTIONS(4412),
    [anon_sym_initial] = ACTIONS(4412),
    [anon_sym_assign] = ACTIONS(4412),
    [anon_sym_alias] = ACTIONS(4412),
    [anon_sym_always_comb] = ACTIONS(4412),
    [anon_sym_always_latch] = ACTIONS(4412),
    [anon_sym_always_ff] = ACTIONS(4412),
    [anon_sym_final] = ACTIONS(4412),
    [anon_sym_global] = ACTIONS(4412),
    [anon_sym_LPAREN_STAR] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4410),
    [anon_sym_DOLLARunit] = ACTIONS(4410),
  },
  [4381] = {
    [sym_simple_identifier] = ACTIONS(4708),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_COLON] = ACTIONS(10483),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_rand] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_end] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [4382] = {
    [sym_simple_identifier] = ACTIONS(4352),
    [anon_sym_wire] = ACTIONS(4352),
    [anon_sym_tri] = ACTIONS(4352),
    [anon_sym_tri0] = ACTIONS(4352),
    [anon_sym_tri1] = ACTIONS(4352),
    [anon_sym_wand] = ACTIONS(4352),
    [anon_sym_triand] = ACTIONS(4352),
    [anon_sym_wor] = ACTIONS(4352),
    [anon_sym_trior] = ACTIONS(4352),
    [anon_sym_trireg] = ACTIONS(4352),
    [anon_sym_uwire] = ACTIONS(4352),
    [anon_sym_SEMI] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(10485),
    [anon_sym_extern] = ACTIONS(4352),
    [anon_sym_interface] = ACTIONS(4352),
    [anon_sym_checker] = ACTIONS(4352),
    [anon_sym_virtual] = ACTIONS(4352),
    [anon_sym_class] = ACTIONS(4352),
    [anon_sym_type] = ACTIONS(4352),
    [anon_sym_DOLLARfatal] = ACTIONS(4350),
    [anon_sym_DOLLARerror] = ACTIONS(4350),
    [anon_sym_DOLLARwarning] = ACTIONS(4350),
    [anon_sym_DOLLARinfo] = ACTIONS(4350),
    [anon_sym_default] = ACTIONS(4352),
    [anon_sym_clocking] = ACTIONS(4352),
    [anon_sym_defparam] = ACTIONS(4352),
    [anon_sym_bind] = ACTIONS(4352),
    [anon_sym_rand] = ACTIONS(4352),
    [anon_sym_const] = ACTIONS(4352),
    [anon_sym_function] = ACTIONS(4352),
    [anon_sym_static] = ACTIONS(4352),
    [anon_sym_constraint] = ACTIONS(4352),
    [anon_sym_if] = ACTIONS(4352),
    [anon_sym_else] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_localparam] = ACTIONS(4352),
    [anon_sym_parameter] = ACTIONS(4352),
    [anon_sym_var] = ACTIONS(4352),
    [anon_sym_import] = ACTIONS(4352),
    [anon_sym_export] = ACTIONS(4352),
    [anon_sym_genvar] = ACTIONS(4352),
    [anon_sym_interconnect] = ACTIONS(4352),
    [anon_sym_typedef] = ACTIONS(4352),
    [anon_sym_enum] = ACTIONS(4352),
    [anon_sym_struct] = ACTIONS(4352),
    [anon_sym_union] = ACTIONS(4352),
    [anon_sym_nettype] = ACTIONS(4352),
    [anon_sym_automatic] = ACTIONS(4352),
    [anon_sym_string] = ACTIONS(4352),
    [anon_sym_chandle] = ACTIONS(4352),
    [anon_sym_event] = ACTIONS(4352),
    [anon_sym_byte] = ACTIONS(4352),
    [anon_sym_shortint] = ACTIONS(4352),
    [anon_sym_int] = ACTIONS(4352),
    [anon_sym_longint] = ACTIONS(4352),
    [anon_sym_integer] = ACTIONS(4352),
    [anon_sym_time] = ACTIONS(4352),
    [anon_sym_bit] = ACTIONS(4352),
    [anon_sym_logic] = ACTIONS(4352),
    [anon_sym_reg] = ACTIONS(4352),
    [anon_sym_shortreal] = ACTIONS(4352),
    [anon_sym_real] = ACTIONS(4352),
    [anon_sym_realtime] = ACTIONS(4352),
    [anon_sym_supply0] = ACTIONS(4352),
    [anon_sym_supply1] = ACTIONS(4352),
    [anon_sym_signed] = ACTIONS(4352),
    [anon_sym_unsigned] = ACTIONS(4352),
    [anon_sym_task] = ACTIONS(4352),
    [anon_sym_assert] = ACTIONS(4352),
    [anon_sym_property] = ACTIONS(4352),
    [anon_sym_assume] = ACTIONS(4352),
    [anon_sym_cover] = ACTIONS(4352),
    [anon_sym_sequence] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym_not] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4352),
    [anon_sym_and] = ACTIONS(4352),
    [anon_sym_case] = ACTIONS(4352),
    [anon_sym_always] = ACTIONS(4352),
    [anon_sym_covergroup] = ACTIONS(4352),
    [anon_sym_end] = ACTIONS(4352),
    [anon_sym_let] = ACTIONS(4352),
    [anon_sym_pulldown] = ACTIONS(4352),
    [anon_sym_pullup] = ACTIONS(4352),
    [anon_sym_cmos] = ACTIONS(4352),
    [anon_sym_rcmos] = ACTIONS(4352),
    [anon_sym_bufif0] = ACTIONS(4352),
    [anon_sym_bufif1] = ACTIONS(4352),
    [anon_sym_notif0] = ACTIONS(4352),
    [anon_sym_notif1] = ACTIONS(4352),
    [anon_sym_nmos] = ACTIONS(4352),
    [anon_sym_pmos] = ACTIONS(4352),
    [anon_sym_rnmos] = ACTIONS(4352),
    [anon_sym_rpmos] = ACTIONS(4352),
    [anon_sym_nand] = ACTIONS(4352),
    [anon_sym_nor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4352),
    [anon_sym_xnor] = ACTIONS(4352),
    [anon_sym_buf] = ACTIONS(4352),
    [anon_sym_tranif0] = ACTIONS(4352),
    [anon_sym_tranif1] = ACTIONS(4352),
    [anon_sym_rtranif1] = ACTIONS(4352),
    [anon_sym_rtranif0] = ACTIONS(4352),
    [anon_sym_tran] = ACTIONS(4352),
    [anon_sym_rtran] = ACTIONS(4352),
    [anon_sym_generate] = ACTIONS(4352),
    [anon_sym_for] = ACTIONS(4352),
    [anon_sym_initial] = ACTIONS(4352),
    [anon_sym_assign] = ACTIONS(4352),
    [anon_sym_alias] = ACTIONS(4352),
    [anon_sym_always_comb] = ACTIONS(4352),
    [anon_sym_always_latch] = ACTIONS(4352),
    [anon_sym_always_ff] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_global] = ACTIONS(4352),
    [anon_sym_LPAREN_STAR] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4350),
    [anon_sym_DOLLARunit] = ACTIONS(4350),
  },
  [4383] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_COLON] = ACTIONS(10487),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_rand] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_endgenerate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [4384] = {
    [sym_simple_identifier] = ACTIONS(4652),
    [anon_sym_wire] = ACTIONS(4652),
    [anon_sym_tri] = ACTIONS(4652),
    [anon_sym_tri0] = ACTIONS(4652),
    [anon_sym_tri1] = ACTIONS(4652),
    [anon_sym_wand] = ACTIONS(4652),
    [anon_sym_triand] = ACTIONS(4652),
    [anon_sym_wor] = ACTIONS(4652),
    [anon_sym_trior] = ACTIONS(4652),
    [anon_sym_trireg] = ACTIONS(4652),
    [anon_sym_uwire] = ACTIONS(4652),
    [anon_sym_SEMI] = ACTIONS(4650),
    [anon_sym_COLON] = ACTIONS(10489),
    [anon_sym_extern] = ACTIONS(4652),
    [anon_sym_interface] = ACTIONS(4652),
    [anon_sym_checker] = ACTIONS(4652),
    [anon_sym_virtual] = ACTIONS(4652),
    [anon_sym_class] = ACTIONS(4652),
    [anon_sym_type] = ACTIONS(4652),
    [anon_sym_DOLLARfatal] = ACTIONS(4650),
    [anon_sym_DOLLARerror] = ACTIONS(4650),
    [anon_sym_DOLLARwarning] = ACTIONS(4650),
    [anon_sym_DOLLARinfo] = ACTIONS(4650),
    [anon_sym_default] = ACTIONS(4652),
    [anon_sym_clocking] = ACTIONS(4652),
    [anon_sym_defparam] = ACTIONS(4652),
    [anon_sym_bind] = ACTIONS(4652),
    [anon_sym_rand] = ACTIONS(4652),
    [anon_sym_const] = ACTIONS(4652),
    [anon_sym_function] = ACTIONS(4652),
    [anon_sym_static] = ACTIONS(4652),
    [anon_sym_constraint] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4652),
    [anon_sym_else] = ACTIONS(4652),
    [anon_sym_LBRACK] = ACTIONS(4650),
    [anon_sym_localparam] = ACTIONS(4652),
    [anon_sym_parameter] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4652),
    [anon_sym_import] = ACTIONS(4652),
    [anon_sym_export] = ACTIONS(4652),
    [anon_sym_genvar] = ACTIONS(4652),
    [anon_sym_interconnect] = ACTIONS(4652),
    [anon_sym_typedef] = ACTIONS(4652),
    [anon_sym_enum] = ACTIONS(4652),
    [anon_sym_struct] = ACTIONS(4652),
    [anon_sym_union] = ACTIONS(4652),
    [anon_sym_nettype] = ACTIONS(4652),
    [anon_sym_automatic] = ACTIONS(4652),
    [anon_sym_string] = ACTIONS(4652),
    [anon_sym_chandle] = ACTIONS(4652),
    [anon_sym_event] = ACTIONS(4652),
    [anon_sym_byte] = ACTIONS(4652),
    [anon_sym_shortint] = ACTIONS(4652),
    [anon_sym_int] = ACTIONS(4652),
    [anon_sym_longint] = ACTIONS(4652),
    [anon_sym_integer] = ACTIONS(4652),
    [anon_sym_time] = ACTIONS(4652),
    [anon_sym_bit] = ACTIONS(4652),
    [anon_sym_logic] = ACTIONS(4652),
    [anon_sym_reg] = ACTIONS(4652),
    [anon_sym_shortreal] = ACTIONS(4652),
    [anon_sym_real] = ACTIONS(4652),
    [anon_sym_realtime] = ACTIONS(4652),
    [anon_sym_supply0] = ACTIONS(4652),
    [anon_sym_supply1] = ACTIONS(4652),
    [anon_sym_signed] = ACTIONS(4652),
    [anon_sym_unsigned] = ACTIONS(4652),
    [anon_sym_task] = ACTIONS(4652),
    [anon_sym_assert] = ACTIONS(4652),
    [anon_sym_property] = ACTIONS(4652),
    [anon_sym_assume] = ACTIONS(4652),
    [anon_sym_cover] = ACTIONS(4652),
    [anon_sym_sequence] = ACTIONS(4652),
    [anon_sym_restrict] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4652),
    [anon_sym_or] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4652),
    [anon_sym_case] = ACTIONS(4652),
    [anon_sym_always] = ACTIONS(4652),
    [anon_sym_covergroup] = ACTIONS(4652),
    [anon_sym_end] = ACTIONS(4652),
    [anon_sym_let] = ACTIONS(4652),
    [anon_sym_pulldown] = ACTIONS(4652),
    [anon_sym_pullup] = ACTIONS(4652),
    [anon_sym_cmos] = ACTIONS(4652),
    [anon_sym_rcmos] = ACTIONS(4652),
    [anon_sym_bufif0] = ACTIONS(4652),
    [anon_sym_bufif1] = ACTIONS(4652),
    [anon_sym_notif0] = ACTIONS(4652),
    [anon_sym_notif1] = ACTIONS(4652),
    [anon_sym_nmos] = ACTIONS(4652),
    [anon_sym_pmos] = ACTIONS(4652),
    [anon_sym_rnmos] = ACTIONS(4652),
    [anon_sym_rpmos] = ACTIONS(4652),
    [anon_sym_nand] = ACTIONS(4652),
    [anon_sym_nor] = ACTIONS(4652),
    [anon_sym_xor] = ACTIONS(4652),
    [anon_sym_xnor] = ACTIONS(4652),
    [anon_sym_buf] = ACTIONS(4652),
    [anon_sym_tranif0] = ACTIONS(4652),
    [anon_sym_tranif1] = ACTIONS(4652),
    [anon_sym_rtranif1] = ACTIONS(4652),
    [anon_sym_rtranif0] = ACTIONS(4652),
    [anon_sym_tran] = ACTIONS(4652),
    [anon_sym_rtran] = ACTIONS(4652),
    [anon_sym_generate] = ACTIONS(4652),
    [anon_sym_for] = ACTIONS(4652),
    [anon_sym_initial] = ACTIONS(4652),
    [anon_sym_assign] = ACTIONS(4652),
    [anon_sym_alias] = ACTIONS(4652),
    [anon_sym_always_comb] = ACTIONS(4652),
    [anon_sym_always_latch] = ACTIONS(4652),
    [anon_sym_always_ff] = ACTIONS(4652),
    [anon_sym_final] = ACTIONS(4652),
    [anon_sym_global] = ACTIONS(4652),
    [anon_sym_LPAREN_STAR] = ACTIONS(4650),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4650),
    [anon_sym_DOLLARunit] = ACTIONS(4650),
  },
  [4385] = {
    [sym_simple_identifier] = ACTIONS(6101),
    [anon_sym_wire] = ACTIONS(6101),
    [anon_sym_tri] = ACTIONS(6101),
    [anon_sym_tri0] = ACTIONS(6101),
    [anon_sym_tri1] = ACTIONS(6101),
    [anon_sym_wand] = ACTIONS(6101),
    [anon_sym_triand] = ACTIONS(6101),
    [anon_sym_wor] = ACTIONS(6101),
    [anon_sym_trior] = ACTIONS(6101),
    [anon_sym_trireg] = ACTIONS(6101),
    [anon_sym_uwire] = ACTIONS(6101),
    [anon_sym_SEMI] = ACTIONS(6103),
    [anon_sym_COLON] = ACTIONS(10491),
    [anon_sym_extern] = ACTIONS(6101),
    [anon_sym_interface] = ACTIONS(6101),
    [anon_sym_checker] = ACTIONS(6101),
    [anon_sym_virtual] = ACTIONS(6101),
    [anon_sym_class] = ACTIONS(6101),
    [anon_sym_type] = ACTIONS(6101),
    [anon_sym_DOLLARfatal] = ACTIONS(6103),
    [anon_sym_DOLLARerror] = ACTIONS(6103),
    [anon_sym_DOLLARwarning] = ACTIONS(6103),
    [anon_sym_DOLLARinfo] = ACTIONS(6103),
    [anon_sym_default] = ACTIONS(6101),
    [anon_sym_clocking] = ACTIONS(6101),
    [anon_sym_defparam] = ACTIONS(6101),
    [anon_sym_bind] = ACTIONS(6101),
    [anon_sym_rand] = ACTIONS(6101),
    [anon_sym_const] = ACTIONS(6101),
    [anon_sym_function] = ACTIONS(6101),
    [anon_sym_static] = ACTIONS(6101),
    [anon_sym_constraint] = ACTIONS(6101),
    [anon_sym_if] = ACTIONS(6101),
    [anon_sym_else] = ACTIONS(6101),
    [anon_sym_LBRACK] = ACTIONS(6103),
    [anon_sym_localparam] = ACTIONS(6101),
    [anon_sym_parameter] = ACTIONS(6101),
    [anon_sym_var] = ACTIONS(6101),
    [anon_sym_import] = ACTIONS(6101),
    [anon_sym_export] = ACTIONS(6101),
    [anon_sym_genvar] = ACTIONS(6101),
    [anon_sym_interconnect] = ACTIONS(6101),
    [anon_sym_typedef] = ACTIONS(6101),
    [anon_sym_enum] = ACTIONS(6101),
    [anon_sym_struct] = ACTIONS(6101),
    [anon_sym_union] = ACTIONS(6101),
    [anon_sym_nettype] = ACTIONS(6101),
    [anon_sym_automatic] = ACTIONS(6101),
    [anon_sym_string] = ACTIONS(6101),
    [anon_sym_chandle] = ACTIONS(6101),
    [anon_sym_event] = ACTIONS(6101),
    [anon_sym_byte] = ACTIONS(6101),
    [anon_sym_shortint] = ACTIONS(6101),
    [anon_sym_int] = ACTIONS(6101),
    [anon_sym_longint] = ACTIONS(6101),
    [anon_sym_integer] = ACTIONS(6101),
    [anon_sym_time] = ACTIONS(6101),
    [anon_sym_bit] = ACTIONS(6101),
    [anon_sym_logic] = ACTIONS(6101),
    [anon_sym_reg] = ACTIONS(6101),
    [anon_sym_shortreal] = ACTIONS(6101),
    [anon_sym_real] = ACTIONS(6101),
    [anon_sym_realtime] = ACTIONS(6101),
    [anon_sym_supply0] = ACTIONS(6101),
    [anon_sym_supply1] = ACTIONS(6101),
    [anon_sym_signed] = ACTIONS(6101),
    [anon_sym_unsigned] = ACTIONS(6101),
    [anon_sym_task] = ACTIONS(6101),
    [anon_sym_assert] = ACTIONS(6101),
    [anon_sym_property] = ACTIONS(6101),
    [anon_sym_assume] = ACTIONS(6101),
    [anon_sym_cover] = ACTIONS(6101),
    [anon_sym_sequence] = ACTIONS(6101),
    [anon_sym_restrict] = ACTIONS(6101),
    [anon_sym_not] = ACTIONS(6101),
    [anon_sym_or] = ACTIONS(6101),
    [anon_sym_and] = ACTIONS(6101),
    [anon_sym_case] = ACTIONS(6101),
    [anon_sym_always] = ACTIONS(6101),
    [anon_sym_covergroup] = ACTIONS(6101),
    [anon_sym_end] = ACTIONS(6101),
    [anon_sym_let] = ACTIONS(6101),
    [anon_sym_pulldown] = ACTIONS(6101),
    [anon_sym_pullup] = ACTIONS(6101),
    [anon_sym_cmos] = ACTIONS(6101),
    [anon_sym_rcmos] = ACTIONS(6101),
    [anon_sym_bufif0] = ACTIONS(6101),
    [anon_sym_bufif1] = ACTIONS(6101),
    [anon_sym_notif0] = ACTIONS(6101),
    [anon_sym_notif1] = ACTIONS(6101),
    [anon_sym_nmos] = ACTIONS(6101),
    [anon_sym_pmos] = ACTIONS(6101),
    [anon_sym_rnmos] = ACTIONS(6101),
    [anon_sym_rpmos] = ACTIONS(6101),
    [anon_sym_nand] = ACTIONS(6101),
    [anon_sym_nor] = ACTIONS(6101),
    [anon_sym_xor] = ACTIONS(6101),
    [anon_sym_xnor] = ACTIONS(6101),
    [anon_sym_buf] = ACTIONS(6101),
    [anon_sym_tranif0] = ACTIONS(6101),
    [anon_sym_tranif1] = ACTIONS(6101),
    [anon_sym_rtranif1] = ACTIONS(6101),
    [anon_sym_rtranif0] = ACTIONS(6101),
    [anon_sym_tran] = ACTIONS(6101),
    [anon_sym_rtran] = ACTIONS(6101),
    [anon_sym_generate] = ACTIONS(6101),
    [anon_sym_for] = ACTIONS(6101),
    [anon_sym_initial] = ACTIONS(6101),
    [anon_sym_assign] = ACTIONS(6101),
    [anon_sym_alias] = ACTIONS(6101),
    [anon_sym_always_comb] = ACTIONS(6101),
    [anon_sym_always_latch] = ACTIONS(6101),
    [anon_sym_always_ff] = ACTIONS(6101),
    [anon_sym_final] = ACTIONS(6101),
    [anon_sym_global] = ACTIONS(6101),
    [anon_sym_LPAREN_STAR] = ACTIONS(6103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6103),
    [anon_sym_DOLLARunit] = ACTIONS(6103),
  },
  [4386] = {
    [sym_simple_identifier] = ACTIONS(4530),
    [anon_sym_wire] = ACTIONS(4530),
    [anon_sym_tri] = ACTIONS(4530),
    [anon_sym_tri0] = ACTIONS(4530),
    [anon_sym_tri1] = ACTIONS(4530),
    [anon_sym_wand] = ACTIONS(4530),
    [anon_sym_triand] = ACTIONS(4530),
    [anon_sym_wor] = ACTIONS(4530),
    [anon_sym_trior] = ACTIONS(4530),
    [anon_sym_trireg] = ACTIONS(4530),
    [anon_sym_uwire] = ACTIONS(4530),
    [anon_sym_SEMI] = ACTIONS(4528),
    [anon_sym_COLON] = ACTIONS(10493),
    [anon_sym_extern] = ACTIONS(4530),
    [anon_sym_interface] = ACTIONS(4530),
    [anon_sym_checker] = ACTIONS(4530),
    [anon_sym_virtual] = ACTIONS(4530),
    [anon_sym_class] = ACTIONS(4530),
    [anon_sym_type] = ACTIONS(4530),
    [anon_sym_DOLLARfatal] = ACTIONS(4528),
    [anon_sym_DOLLARerror] = ACTIONS(4528),
    [anon_sym_DOLLARwarning] = ACTIONS(4528),
    [anon_sym_DOLLARinfo] = ACTIONS(4528),
    [anon_sym_default] = ACTIONS(4530),
    [anon_sym_clocking] = ACTIONS(4530),
    [anon_sym_defparam] = ACTIONS(4530),
    [anon_sym_bind] = ACTIONS(4530),
    [anon_sym_rand] = ACTIONS(4530),
    [anon_sym_const] = ACTIONS(4530),
    [anon_sym_function] = ACTIONS(4530),
    [anon_sym_static] = ACTIONS(4530),
    [anon_sym_constraint] = ACTIONS(4530),
    [anon_sym_if] = ACTIONS(4530),
    [anon_sym_else] = ACTIONS(4530),
    [anon_sym_LBRACK] = ACTIONS(4528),
    [anon_sym_localparam] = ACTIONS(4530),
    [anon_sym_parameter] = ACTIONS(4530),
    [anon_sym_var] = ACTIONS(4530),
    [anon_sym_import] = ACTIONS(4530),
    [anon_sym_export] = ACTIONS(4530),
    [anon_sym_genvar] = ACTIONS(4530),
    [anon_sym_interconnect] = ACTIONS(4530),
    [anon_sym_typedef] = ACTIONS(4530),
    [anon_sym_enum] = ACTIONS(4530),
    [anon_sym_struct] = ACTIONS(4530),
    [anon_sym_union] = ACTIONS(4530),
    [anon_sym_nettype] = ACTIONS(4530),
    [anon_sym_automatic] = ACTIONS(4530),
    [anon_sym_string] = ACTIONS(4530),
    [anon_sym_chandle] = ACTIONS(4530),
    [anon_sym_event] = ACTIONS(4530),
    [anon_sym_byte] = ACTIONS(4530),
    [anon_sym_shortint] = ACTIONS(4530),
    [anon_sym_int] = ACTIONS(4530),
    [anon_sym_longint] = ACTIONS(4530),
    [anon_sym_integer] = ACTIONS(4530),
    [anon_sym_time] = ACTIONS(4530),
    [anon_sym_bit] = ACTIONS(4530),
    [anon_sym_logic] = ACTIONS(4530),
    [anon_sym_reg] = ACTIONS(4530),
    [anon_sym_shortreal] = ACTIONS(4530),
    [anon_sym_real] = ACTIONS(4530),
    [anon_sym_realtime] = ACTIONS(4530),
    [anon_sym_supply0] = ACTIONS(4530),
    [anon_sym_supply1] = ACTIONS(4530),
    [anon_sym_signed] = ACTIONS(4530),
    [anon_sym_unsigned] = ACTIONS(4530),
    [anon_sym_task] = ACTIONS(4530),
    [anon_sym_assert] = ACTIONS(4530),
    [anon_sym_property] = ACTIONS(4530),
    [anon_sym_assume] = ACTIONS(4530),
    [anon_sym_cover] = ACTIONS(4530),
    [anon_sym_sequence] = ACTIONS(4530),
    [anon_sym_restrict] = ACTIONS(4530),
    [anon_sym_not] = ACTIONS(4530),
    [anon_sym_or] = ACTIONS(4530),
    [anon_sym_and] = ACTIONS(4530),
    [anon_sym_case] = ACTIONS(4530),
    [anon_sym_always] = ACTIONS(4530),
    [anon_sym_covergroup] = ACTIONS(4530),
    [anon_sym_end] = ACTIONS(4530),
    [anon_sym_let] = ACTIONS(4530),
    [anon_sym_pulldown] = ACTIONS(4530),
    [anon_sym_pullup] = ACTIONS(4530),
    [anon_sym_cmos] = ACTIONS(4530),
    [anon_sym_rcmos] = ACTIONS(4530),
    [anon_sym_bufif0] = ACTIONS(4530),
    [anon_sym_bufif1] = ACTIONS(4530),
    [anon_sym_notif0] = ACTIONS(4530),
    [anon_sym_notif1] = ACTIONS(4530),
    [anon_sym_nmos] = ACTIONS(4530),
    [anon_sym_pmos] = ACTIONS(4530),
    [anon_sym_rnmos] = ACTIONS(4530),
    [anon_sym_rpmos] = ACTIONS(4530),
    [anon_sym_nand] = ACTIONS(4530),
    [anon_sym_nor] = ACTIONS(4530),
    [anon_sym_xor] = ACTIONS(4530),
    [anon_sym_xnor] = ACTIONS(4530),
    [anon_sym_buf] = ACTIONS(4530),
    [anon_sym_tranif0] = ACTIONS(4530),
    [anon_sym_tranif1] = ACTIONS(4530),
    [anon_sym_rtranif1] = ACTIONS(4530),
    [anon_sym_rtranif0] = ACTIONS(4530),
    [anon_sym_tran] = ACTIONS(4530),
    [anon_sym_rtran] = ACTIONS(4530),
    [anon_sym_generate] = ACTIONS(4530),
    [anon_sym_for] = ACTIONS(4530),
    [anon_sym_initial] = ACTIONS(4530),
    [anon_sym_assign] = ACTIONS(4530),
    [anon_sym_alias] = ACTIONS(4530),
    [anon_sym_always_comb] = ACTIONS(4530),
    [anon_sym_always_latch] = ACTIONS(4530),
    [anon_sym_always_ff] = ACTIONS(4530),
    [anon_sym_final] = ACTIONS(4530),
    [anon_sym_global] = ACTIONS(4530),
    [anon_sym_LPAREN_STAR] = ACTIONS(4528),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4528),
    [anon_sym_DOLLARunit] = ACTIONS(4528),
  },
  [4387] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_COLON] = ACTIONS(10495),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_rand] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_endgenerate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [4388] = {
    [sym_simple_identifier] = ACTIONS(4636),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_COLON] = ACTIONS(10497),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_rand] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_endgenerate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [4389] = {
    [sym_simple_identifier] = ACTIONS(4684),
    [anon_sym_wire] = ACTIONS(4684),
    [anon_sym_tri] = ACTIONS(4684),
    [anon_sym_tri0] = ACTIONS(4684),
    [anon_sym_tri1] = ACTIONS(4684),
    [anon_sym_wand] = ACTIONS(4684),
    [anon_sym_triand] = ACTIONS(4684),
    [anon_sym_wor] = ACTIONS(4684),
    [anon_sym_trior] = ACTIONS(4684),
    [anon_sym_trireg] = ACTIONS(4684),
    [anon_sym_uwire] = ACTIONS(4684),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_COLON] = ACTIONS(10499),
    [anon_sym_extern] = ACTIONS(4684),
    [anon_sym_interface] = ACTIONS(4684),
    [anon_sym_checker] = ACTIONS(4684),
    [anon_sym_virtual] = ACTIONS(4684),
    [anon_sym_class] = ACTIONS(4684),
    [anon_sym_type] = ACTIONS(4684),
    [anon_sym_DOLLARfatal] = ACTIONS(4682),
    [anon_sym_DOLLARerror] = ACTIONS(4682),
    [anon_sym_DOLLARwarning] = ACTIONS(4682),
    [anon_sym_DOLLARinfo] = ACTIONS(4682),
    [anon_sym_default] = ACTIONS(4684),
    [anon_sym_clocking] = ACTIONS(4684),
    [anon_sym_defparam] = ACTIONS(4684),
    [anon_sym_bind] = ACTIONS(4684),
    [anon_sym_rand] = ACTIONS(4684),
    [anon_sym_const] = ACTIONS(4684),
    [anon_sym_function] = ACTIONS(4684),
    [anon_sym_static] = ACTIONS(4684),
    [anon_sym_constraint] = ACTIONS(4684),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [anon_sym_localparam] = ACTIONS(4684),
    [anon_sym_parameter] = ACTIONS(4684),
    [anon_sym_var] = ACTIONS(4684),
    [anon_sym_import] = ACTIONS(4684),
    [anon_sym_export] = ACTIONS(4684),
    [anon_sym_genvar] = ACTIONS(4684),
    [anon_sym_interconnect] = ACTIONS(4684),
    [anon_sym_typedef] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_struct] = ACTIONS(4684),
    [anon_sym_union] = ACTIONS(4684),
    [anon_sym_nettype] = ACTIONS(4684),
    [anon_sym_automatic] = ACTIONS(4684),
    [anon_sym_string] = ACTIONS(4684),
    [anon_sym_chandle] = ACTIONS(4684),
    [anon_sym_event] = ACTIONS(4684),
    [anon_sym_byte] = ACTIONS(4684),
    [anon_sym_shortint] = ACTIONS(4684),
    [anon_sym_int] = ACTIONS(4684),
    [anon_sym_longint] = ACTIONS(4684),
    [anon_sym_integer] = ACTIONS(4684),
    [anon_sym_time] = ACTIONS(4684),
    [anon_sym_bit] = ACTIONS(4684),
    [anon_sym_logic] = ACTIONS(4684),
    [anon_sym_reg] = ACTIONS(4684),
    [anon_sym_shortreal] = ACTIONS(4684),
    [anon_sym_real] = ACTIONS(4684),
    [anon_sym_realtime] = ACTIONS(4684),
    [anon_sym_supply0] = ACTIONS(4684),
    [anon_sym_supply1] = ACTIONS(4684),
    [anon_sym_signed] = ACTIONS(4684),
    [anon_sym_unsigned] = ACTIONS(4684),
    [anon_sym_task] = ACTIONS(4684),
    [anon_sym_assert] = ACTIONS(4684),
    [anon_sym_property] = ACTIONS(4684),
    [anon_sym_assume] = ACTIONS(4684),
    [anon_sym_cover] = ACTIONS(4684),
    [anon_sym_sequence] = ACTIONS(4684),
    [anon_sym_restrict] = ACTIONS(4684),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_or] = ACTIONS(4684),
    [anon_sym_and] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_always] = ACTIONS(4684),
    [anon_sym_covergroup] = ACTIONS(4684),
    [anon_sym_let] = ACTIONS(4684),
    [anon_sym_pulldown] = ACTIONS(4684),
    [anon_sym_pullup] = ACTIONS(4684),
    [anon_sym_cmos] = ACTIONS(4684),
    [anon_sym_rcmos] = ACTIONS(4684),
    [anon_sym_bufif0] = ACTIONS(4684),
    [anon_sym_bufif1] = ACTIONS(4684),
    [anon_sym_notif0] = ACTIONS(4684),
    [anon_sym_notif1] = ACTIONS(4684),
    [anon_sym_nmos] = ACTIONS(4684),
    [anon_sym_pmos] = ACTIONS(4684),
    [anon_sym_rnmos] = ACTIONS(4684),
    [anon_sym_rpmos] = ACTIONS(4684),
    [anon_sym_nand] = ACTIONS(4684),
    [anon_sym_nor] = ACTIONS(4684),
    [anon_sym_xor] = ACTIONS(4684),
    [anon_sym_xnor] = ACTIONS(4684),
    [anon_sym_buf] = ACTIONS(4684),
    [anon_sym_tranif0] = ACTIONS(4684),
    [anon_sym_tranif1] = ACTIONS(4684),
    [anon_sym_rtranif1] = ACTIONS(4684),
    [anon_sym_rtranif0] = ACTIONS(4684),
    [anon_sym_tran] = ACTIONS(4684),
    [anon_sym_rtran] = ACTIONS(4684),
    [anon_sym_generate] = ACTIONS(4684),
    [anon_sym_endgenerate] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_initial] = ACTIONS(4684),
    [anon_sym_assign] = ACTIONS(4684),
    [anon_sym_alias] = ACTIONS(4684),
    [anon_sym_always_comb] = ACTIONS(4684),
    [anon_sym_always_latch] = ACTIONS(4684),
    [anon_sym_always_ff] = ACTIONS(4684),
    [anon_sym_final] = ACTIONS(4684),
    [anon_sym_global] = ACTIONS(4684),
    [anon_sym_LPAREN_STAR] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4682),
    [anon_sym_DOLLARunit] = ACTIONS(4682),
  },
  [4390] = {
    [sym_simple_identifier] = ACTIONS(4184),
    [anon_sym_wire] = ACTIONS(4184),
    [anon_sym_tri] = ACTIONS(4184),
    [anon_sym_tri0] = ACTIONS(4184),
    [anon_sym_tri1] = ACTIONS(4184),
    [anon_sym_wand] = ACTIONS(4184),
    [anon_sym_triand] = ACTIONS(4184),
    [anon_sym_wor] = ACTIONS(4184),
    [anon_sym_trior] = ACTIONS(4184),
    [anon_sym_trireg] = ACTIONS(4184),
    [anon_sym_uwire] = ACTIONS(4184),
    [anon_sym_SEMI] = ACTIONS(4182),
    [anon_sym_COLON] = ACTIONS(10501),
    [anon_sym_extern] = ACTIONS(4184),
    [anon_sym_interface] = ACTIONS(4184),
    [anon_sym_checker] = ACTIONS(4184),
    [anon_sym_virtual] = ACTIONS(4184),
    [anon_sym_class] = ACTIONS(4184),
    [anon_sym_type] = ACTIONS(4184),
    [anon_sym_DOLLARfatal] = ACTIONS(4182),
    [anon_sym_DOLLARerror] = ACTIONS(4182),
    [anon_sym_DOLLARwarning] = ACTIONS(4182),
    [anon_sym_DOLLARinfo] = ACTIONS(4182),
    [anon_sym_default] = ACTIONS(4184),
    [anon_sym_clocking] = ACTIONS(4184),
    [anon_sym_defparam] = ACTIONS(4184),
    [anon_sym_bind] = ACTIONS(4184),
    [anon_sym_rand] = ACTIONS(4184),
    [anon_sym_const] = ACTIONS(4184),
    [anon_sym_function] = ACTIONS(4184),
    [anon_sym_static] = ACTIONS(4184),
    [anon_sym_constraint] = ACTIONS(4184),
    [anon_sym_if] = ACTIONS(4184),
    [anon_sym_else] = ACTIONS(4184),
    [anon_sym_LBRACK] = ACTIONS(4182),
    [anon_sym_localparam] = ACTIONS(4184),
    [anon_sym_parameter] = ACTIONS(4184),
    [anon_sym_var] = ACTIONS(4184),
    [anon_sym_import] = ACTIONS(4184),
    [anon_sym_export] = ACTIONS(4184),
    [anon_sym_genvar] = ACTIONS(4184),
    [anon_sym_interconnect] = ACTIONS(4184),
    [anon_sym_typedef] = ACTIONS(4184),
    [anon_sym_enum] = ACTIONS(4184),
    [anon_sym_struct] = ACTIONS(4184),
    [anon_sym_union] = ACTIONS(4184),
    [anon_sym_nettype] = ACTIONS(4184),
    [anon_sym_automatic] = ACTIONS(4184),
    [anon_sym_string] = ACTIONS(4184),
    [anon_sym_chandle] = ACTIONS(4184),
    [anon_sym_event] = ACTIONS(4184),
    [anon_sym_byte] = ACTIONS(4184),
    [anon_sym_shortint] = ACTIONS(4184),
    [anon_sym_int] = ACTIONS(4184),
    [anon_sym_longint] = ACTIONS(4184),
    [anon_sym_integer] = ACTIONS(4184),
    [anon_sym_time] = ACTIONS(4184),
    [anon_sym_bit] = ACTIONS(4184),
    [anon_sym_logic] = ACTIONS(4184),
    [anon_sym_reg] = ACTIONS(4184),
    [anon_sym_shortreal] = ACTIONS(4184),
    [anon_sym_real] = ACTIONS(4184),
    [anon_sym_realtime] = ACTIONS(4184),
    [anon_sym_supply0] = ACTIONS(4184),
    [anon_sym_supply1] = ACTIONS(4184),
    [anon_sym_signed] = ACTIONS(4184),
    [anon_sym_unsigned] = ACTIONS(4184),
    [anon_sym_task] = ACTIONS(4184),
    [anon_sym_assert] = ACTIONS(4184),
    [anon_sym_property] = ACTIONS(4184),
    [anon_sym_assume] = ACTIONS(4184),
    [anon_sym_cover] = ACTIONS(4184),
    [anon_sym_sequence] = ACTIONS(4184),
    [anon_sym_restrict] = ACTIONS(4184),
    [anon_sym_not] = ACTIONS(4184),
    [anon_sym_or] = ACTIONS(4184),
    [anon_sym_and] = ACTIONS(4184),
    [anon_sym_case] = ACTIONS(4184),
    [anon_sym_always] = ACTIONS(4184),
    [anon_sym_covergroup] = ACTIONS(4184),
    [anon_sym_let] = ACTIONS(4184),
    [anon_sym_pulldown] = ACTIONS(4184),
    [anon_sym_pullup] = ACTIONS(4184),
    [anon_sym_cmos] = ACTIONS(4184),
    [anon_sym_rcmos] = ACTIONS(4184),
    [anon_sym_bufif0] = ACTIONS(4184),
    [anon_sym_bufif1] = ACTIONS(4184),
    [anon_sym_notif0] = ACTIONS(4184),
    [anon_sym_notif1] = ACTIONS(4184),
    [anon_sym_nmos] = ACTIONS(4184),
    [anon_sym_pmos] = ACTIONS(4184),
    [anon_sym_rnmos] = ACTIONS(4184),
    [anon_sym_rpmos] = ACTIONS(4184),
    [anon_sym_nand] = ACTIONS(4184),
    [anon_sym_nor] = ACTIONS(4184),
    [anon_sym_xor] = ACTIONS(4184),
    [anon_sym_xnor] = ACTIONS(4184),
    [anon_sym_buf] = ACTIONS(4184),
    [anon_sym_tranif0] = ACTIONS(4184),
    [anon_sym_tranif1] = ACTIONS(4184),
    [anon_sym_rtranif1] = ACTIONS(4184),
    [anon_sym_rtranif0] = ACTIONS(4184),
    [anon_sym_tran] = ACTIONS(4184),
    [anon_sym_rtran] = ACTIONS(4184),
    [anon_sym_generate] = ACTIONS(4184),
    [anon_sym_endgenerate] = ACTIONS(4184),
    [anon_sym_for] = ACTIONS(4184),
    [anon_sym_initial] = ACTIONS(4184),
    [anon_sym_assign] = ACTIONS(4184),
    [anon_sym_alias] = ACTIONS(4184),
    [anon_sym_always_comb] = ACTIONS(4184),
    [anon_sym_always_latch] = ACTIONS(4184),
    [anon_sym_always_ff] = ACTIONS(4184),
    [anon_sym_final] = ACTIONS(4184),
    [anon_sym_global] = ACTIONS(4184),
    [anon_sym_LPAREN_STAR] = ACTIONS(4182),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4182),
    [anon_sym_DOLLARunit] = ACTIONS(4182),
  },
  [4391] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_COLON] = ACTIONS(10503),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_rand] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_endgenerate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [4392] = {
    [sym_simple_identifier] = ACTIONS(4554),
    [anon_sym_wire] = ACTIONS(4554),
    [anon_sym_tri] = ACTIONS(4554),
    [anon_sym_tri0] = ACTIONS(4554),
    [anon_sym_tri1] = ACTIONS(4554),
    [anon_sym_wand] = ACTIONS(4554),
    [anon_sym_triand] = ACTIONS(4554),
    [anon_sym_wor] = ACTIONS(4554),
    [anon_sym_trior] = ACTIONS(4554),
    [anon_sym_trireg] = ACTIONS(4554),
    [anon_sym_uwire] = ACTIONS(4554),
    [anon_sym_SEMI] = ACTIONS(4552),
    [anon_sym_COLON] = ACTIONS(10505),
    [anon_sym_extern] = ACTIONS(4554),
    [anon_sym_interface] = ACTIONS(4554),
    [anon_sym_checker] = ACTIONS(4554),
    [anon_sym_virtual] = ACTIONS(4554),
    [anon_sym_class] = ACTIONS(4554),
    [anon_sym_type] = ACTIONS(4554),
    [anon_sym_DOLLARfatal] = ACTIONS(4552),
    [anon_sym_DOLLARerror] = ACTIONS(4552),
    [anon_sym_DOLLARwarning] = ACTIONS(4552),
    [anon_sym_DOLLARinfo] = ACTIONS(4552),
    [anon_sym_default] = ACTIONS(4554),
    [anon_sym_clocking] = ACTIONS(4554),
    [anon_sym_defparam] = ACTIONS(4554),
    [anon_sym_bind] = ACTIONS(4554),
    [anon_sym_rand] = ACTIONS(4554),
    [anon_sym_const] = ACTIONS(4554),
    [anon_sym_function] = ACTIONS(4554),
    [anon_sym_static] = ACTIONS(4554),
    [anon_sym_constraint] = ACTIONS(4554),
    [anon_sym_if] = ACTIONS(4554),
    [anon_sym_else] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4552),
    [anon_sym_localparam] = ACTIONS(4554),
    [anon_sym_parameter] = ACTIONS(4554),
    [anon_sym_var] = ACTIONS(4554),
    [anon_sym_import] = ACTIONS(4554),
    [anon_sym_export] = ACTIONS(4554),
    [anon_sym_genvar] = ACTIONS(4554),
    [anon_sym_interconnect] = ACTIONS(4554),
    [anon_sym_typedef] = ACTIONS(4554),
    [anon_sym_enum] = ACTIONS(4554),
    [anon_sym_struct] = ACTIONS(4554),
    [anon_sym_union] = ACTIONS(4554),
    [anon_sym_nettype] = ACTIONS(4554),
    [anon_sym_automatic] = ACTIONS(4554),
    [anon_sym_string] = ACTIONS(4554),
    [anon_sym_chandle] = ACTIONS(4554),
    [anon_sym_event] = ACTIONS(4554),
    [anon_sym_byte] = ACTIONS(4554),
    [anon_sym_shortint] = ACTIONS(4554),
    [anon_sym_int] = ACTIONS(4554),
    [anon_sym_longint] = ACTIONS(4554),
    [anon_sym_integer] = ACTIONS(4554),
    [anon_sym_time] = ACTIONS(4554),
    [anon_sym_bit] = ACTIONS(4554),
    [anon_sym_logic] = ACTIONS(4554),
    [anon_sym_reg] = ACTIONS(4554),
    [anon_sym_shortreal] = ACTIONS(4554),
    [anon_sym_real] = ACTIONS(4554),
    [anon_sym_realtime] = ACTIONS(4554),
    [anon_sym_supply0] = ACTIONS(4554),
    [anon_sym_supply1] = ACTIONS(4554),
    [anon_sym_signed] = ACTIONS(4554),
    [anon_sym_unsigned] = ACTIONS(4554),
    [anon_sym_task] = ACTIONS(4554),
    [anon_sym_assert] = ACTIONS(4554),
    [anon_sym_property] = ACTIONS(4554),
    [anon_sym_assume] = ACTIONS(4554),
    [anon_sym_cover] = ACTIONS(4554),
    [anon_sym_sequence] = ACTIONS(4554),
    [anon_sym_restrict] = ACTIONS(4554),
    [anon_sym_not] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_case] = ACTIONS(4554),
    [anon_sym_always] = ACTIONS(4554),
    [anon_sym_covergroup] = ACTIONS(4554),
    [anon_sym_let] = ACTIONS(4554),
    [anon_sym_pulldown] = ACTIONS(4554),
    [anon_sym_pullup] = ACTIONS(4554),
    [anon_sym_cmos] = ACTIONS(4554),
    [anon_sym_rcmos] = ACTIONS(4554),
    [anon_sym_bufif0] = ACTIONS(4554),
    [anon_sym_bufif1] = ACTIONS(4554),
    [anon_sym_notif0] = ACTIONS(4554),
    [anon_sym_notif1] = ACTIONS(4554),
    [anon_sym_nmos] = ACTIONS(4554),
    [anon_sym_pmos] = ACTIONS(4554),
    [anon_sym_rnmos] = ACTIONS(4554),
    [anon_sym_rpmos] = ACTIONS(4554),
    [anon_sym_nand] = ACTIONS(4554),
    [anon_sym_nor] = ACTIONS(4554),
    [anon_sym_xor] = ACTIONS(4554),
    [anon_sym_xnor] = ACTIONS(4554),
    [anon_sym_buf] = ACTIONS(4554),
    [anon_sym_tranif0] = ACTIONS(4554),
    [anon_sym_tranif1] = ACTIONS(4554),
    [anon_sym_rtranif1] = ACTIONS(4554),
    [anon_sym_rtranif0] = ACTIONS(4554),
    [anon_sym_tran] = ACTIONS(4554),
    [anon_sym_rtran] = ACTIONS(4554),
    [anon_sym_generate] = ACTIONS(4554),
    [anon_sym_endgenerate] = ACTIONS(4554),
    [anon_sym_for] = ACTIONS(4554),
    [anon_sym_initial] = ACTIONS(4554),
    [anon_sym_assign] = ACTIONS(4554),
    [anon_sym_alias] = ACTIONS(4554),
    [anon_sym_always_comb] = ACTIONS(4554),
    [anon_sym_always_latch] = ACTIONS(4554),
    [anon_sym_always_ff] = ACTIONS(4554),
    [anon_sym_final] = ACTIONS(4554),
    [anon_sym_global] = ACTIONS(4554),
    [anon_sym_LPAREN_STAR] = ACTIONS(4552),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4552),
    [anon_sym_DOLLARunit] = ACTIONS(4552),
  },
  [4393] = {
    [sym_simple_identifier] = ACTIONS(4406),
    [anon_sym_wire] = ACTIONS(4406),
    [anon_sym_tri] = ACTIONS(4406),
    [anon_sym_tri0] = ACTIONS(4406),
    [anon_sym_tri1] = ACTIONS(4406),
    [anon_sym_wand] = ACTIONS(4406),
    [anon_sym_triand] = ACTIONS(4406),
    [anon_sym_wor] = ACTIONS(4406),
    [anon_sym_trior] = ACTIONS(4406),
    [anon_sym_trireg] = ACTIONS(4406),
    [anon_sym_uwire] = ACTIONS(4406),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym_COLON] = ACTIONS(10507),
    [anon_sym_extern] = ACTIONS(4406),
    [anon_sym_interface] = ACTIONS(4406),
    [anon_sym_checker] = ACTIONS(4406),
    [anon_sym_virtual] = ACTIONS(4406),
    [anon_sym_class] = ACTIONS(4406),
    [anon_sym_type] = ACTIONS(4406),
    [anon_sym_DOLLARfatal] = ACTIONS(4404),
    [anon_sym_DOLLARerror] = ACTIONS(4404),
    [anon_sym_DOLLARwarning] = ACTIONS(4404),
    [anon_sym_DOLLARinfo] = ACTIONS(4404),
    [anon_sym_default] = ACTIONS(4406),
    [anon_sym_clocking] = ACTIONS(4406),
    [anon_sym_defparam] = ACTIONS(4406),
    [anon_sym_bind] = ACTIONS(4406),
    [anon_sym_rand] = ACTIONS(4406),
    [anon_sym_const] = ACTIONS(4406),
    [anon_sym_function] = ACTIONS(4406),
    [anon_sym_static] = ACTIONS(4406),
    [anon_sym_constraint] = ACTIONS(4406),
    [anon_sym_if] = ACTIONS(4406),
    [anon_sym_else] = ACTIONS(4406),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_localparam] = ACTIONS(4406),
    [anon_sym_parameter] = ACTIONS(4406),
    [anon_sym_var] = ACTIONS(4406),
    [anon_sym_import] = ACTIONS(4406),
    [anon_sym_export] = ACTIONS(4406),
    [anon_sym_genvar] = ACTIONS(4406),
    [anon_sym_interconnect] = ACTIONS(4406),
    [anon_sym_typedef] = ACTIONS(4406),
    [anon_sym_enum] = ACTIONS(4406),
    [anon_sym_struct] = ACTIONS(4406),
    [anon_sym_union] = ACTIONS(4406),
    [anon_sym_nettype] = ACTIONS(4406),
    [anon_sym_automatic] = ACTIONS(4406),
    [anon_sym_string] = ACTIONS(4406),
    [anon_sym_chandle] = ACTIONS(4406),
    [anon_sym_event] = ACTIONS(4406),
    [anon_sym_byte] = ACTIONS(4406),
    [anon_sym_shortint] = ACTIONS(4406),
    [anon_sym_int] = ACTIONS(4406),
    [anon_sym_longint] = ACTIONS(4406),
    [anon_sym_integer] = ACTIONS(4406),
    [anon_sym_time] = ACTIONS(4406),
    [anon_sym_bit] = ACTIONS(4406),
    [anon_sym_logic] = ACTIONS(4406),
    [anon_sym_reg] = ACTIONS(4406),
    [anon_sym_shortreal] = ACTIONS(4406),
    [anon_sym_real] = ACTIONS(4406),
    [anon_sym_realtime] = ACTIONS(4406),
    [anon_sym_supply0] = ACTIONS(4406),
    [anon_sym_supply1] = ACTIONS(4406),
    [anon_sym_signed] = ACTIONS(4406),
    [anon_sym_unsigned] = ACTIONS(4406),
    [anon_sym_task] = ACTIONS(4406),
    [anon_sym_assert] = ACTIONS(4406),
    [anon_sym_property] = ACTIONS(4406),
    [anon_sym_assume] = ACTIONS(4406),
    [anon_sym_cover] = ACTIONS(4406),
    [anon_sym_sequence] = ACTIONS(4406),
    [anon_sym_restrict] = ACTIONS(4406),
    [anon_sym_not] = ACTIONS(4406),
    [anon_sym_or] = ACTIONS(4406),
    [anon_sym_and] = ACTIONS(4406),
    [anon_sym_case] = ACTIONS(4406),
    [anon_sym_always] = ACTIONS(4406),
    [anon_sym_covergroup] = ACTIONS(4406),
    [anon_sym_let] = ACTIONS(4406),
    [anon_sym_pulldown] = ACTIONS(4406),
    [anon_sym_pullup] = ACTIONS(4406),
    [anon_sym_cmos] = ACTIONS(4406),
    [anon_sym_rcmos] = ACTIONS(4406),
    [anon_sym_bufif0] = ACTIONS(4406),
    [anon_sym_bufif1] = ACTIONS(4406),
    [anon_sym_notif0] = ACTIONS(4406),
    [anon_sym_notif1] = ACTIONS(4406),
    [anon_sym_nmos] = ACTIONS(4406),
    [anon_sym_pmos] = ACTIONS(4406),
    [anon_sym_rnmos] = ACTIONS(4406),
    [anon_sym_rpmos] = ACTIONS(4406),
    [anon_sym_nand] = ACTIONS(4406),
    [anon_sym_nor] = ACTIONS(4406),
    [anon_sym_xor] = ACTIONS(4406),
    [anon_sym_xnor] = ACTIONS(4406),
    [anon_sym_buf] = ACTIONS(4406),
    [anon_sym_tranif0] = ACTIONS(4406),
    [anon_sym_tranif1] = ACTIONS(4406),
    [anon_sym_rtranif1] = ACTIONS(4406),
    [anon_sym_rtranif0] = ACTIONS(4406),
    [anon_sym_tran] = ACTIONS(4406),
    [anon_sym_rtran] = ACTIONS(4406),
    [anon_sym_generate] = ACTIONS(4406),
    [anon_sym_endgenerate] = ACTIONS(4406),
    [anon_sym_for] = ACTIONS(4406),
    [anon_sym_initial] = ACTIONS(4406),
    [anon_sym_assign] = ACTIONS(4406),
    [anon_sym_alias] = ACTIONS(4406),
    [anon_sym_always_comb] = ACTIONS(4406),
    [anon_sym_always_latch] = ACTIONS(4406),
    [anon_sym_always_ff] = ACTIONS(4406),
    [anon_sym_final] = ACTIONS(4406),
    [anon_sym_global] = ACTIONS(4406),
    [anon_sym_LPAREN_STAR] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4404),
    [anon_sym_DOLLARunit] = ACTIONS(4404),
  },
  [4394] = {
    [sym_simple_identifier] = ACTIONS(4454),
    [anon_sym_wire] = ACTIONS(4454),
    [anon_sym_tri] = ACTIONS(4454),
    [anon_sym_tri0] = ACTIONS(4454),
    [anon_sym_tri1] = ACTIONS(4454),
    [anon_sym_wand] = ACTIONS(4454),
    [anon_sym_triand] = ACTIONS(4454),
    [anon_sym_wor] = ACTIONS(4454),
    [anon_sym_trior] = ACTIONS(4454),
    [anon_sym_trireg] = ACTIONS(4454),
    [anon_sym_uwire] = ACTIONS(4454),
    [anon_sym_SEMI] = ACTIONS(4452),
    [anon_sym_COLON] = ACTIONS(10509),
    [anon_sym_extern] = ACTIONS(4454),
    [anon_sym_interface] = ACTIONS(4454),
    [anon_sym_checker] = ACTIONS(4454),
    [anon_sym_virtual] = ACTIONS(4454),
    [anon_sym_class] = ACTIONS(4454),
    [anon_sym_type] = ACTIONS(4454),
    [anon_sym_DOLLARfatal] = ACTIONS(4452),
    [anon_sym_DOLLARerror] = ACTIONS(4452),
    [anon_sym_DOLLARwarning] = ACTIONS(4452),
    [anon_sym_DOLLARinfo] = ACTIONS(4452),
    [anon_sym_default] = ACTIONS(4454),
    [anon_sym_clocking] = ACTIONS(4454),
    [anon_sym_defparam] = ACTIONS(4454),
    [anon_sym_bind] = ACTIONS(4454),
    [anon_sym_rand] = ACTIONS(4454),
    [anon_sym_const] = ACTIONS(4454),
    [anon_sym_function] = ACTIONS(4454),
    [anon_sym_static] = ACTIONS(4454),
    [anon_sym_constraint] = ACTIONS(4454),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_else] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4452),
    [anon_sym_localparam] = ACTIONS(4454),
    [anon_sym_parameter] = ACTIONS(4454),
    [anon_sym_var] = ACTIONS(4454),
    [anon_sym_import] = ACTIONS(4454),
    [anon_sym_export] = ACTIONS(4454),
    [anon_sym_genvar] = ACTIONS(4454),
    [anon_sym_interconnect] = ACTIONS(4454),
    [anon_sym_typedef] = ACTIONS(4454),
    [anon_sym_enum] = ACTIONS(4454),
    [anon_sym_struct] = ACTIONS(4454),
    [anon_sym_union] = ACTIONS(4454),
    [anon_sym_nettype] = ACTIONS(4454),
    [anon_sym_automatic] = ACTIONS(4454),
    [anon_sym_string] = ACTIONS(4454),
    [anon_sym_chandle] = ACTIONS(4454),
    [anon_sym_event] = ACTIONS(4454),
    [anon_sym_byte] = ACTIONS(4454),
    [anon_sym_shortint] = ACTIONS(4454),
    [anon_sym_int] = ACTIONS(4454),
    [anon_sym_longint] = ACTIONS(4454),
    [anon_sym_integer] = ACTIONS(4454),
    [anon_sym_time] = ACTIONS(4454),
    [anon_sym_bit] = ACTIONS(4454),
    [anon_sym_logic] = ACTIONS(4454),
    [anon_sym_reg] = ACTIONS(4454),
    [anon_sym_shortreal] = ACTIONS(4454),
    [anon_sym_real] = ACTIONS(4454),
    [anon_sym_realtime] = ACTIONS(4454),
    [anon_sym_supply0] = ACTIONS(4454),
    [anon_sym_supply1] = ACTIONS(4454),
    [anon_sym_signed] = ACTIONS(4454),
    [anon_sym_unsigned] = ACTIONS(4454),
    [anon_sym_task] = ACTIONS(4454),
    [anon_sym_assert] = ACTIONS(4454),
    [anon_sym_property] = ACTIONS(4454),
    [anon_sym_assume] = ACTIONS(4454),
    [anon_sym_cover] = ACTIONS(4454),
    [anon_sym_sequence] = ACTIONS(4454),
    [anon_sym_restrict] = ACTIONS(4454),
    [anon_sym_not] = ACTIONS(4454),
    [anon_sym_or] = ACTIONS(4454),
    [anon_sym_and] = ACTIONS(4454),
    [anon_sym_case] = ACTIONS(4454),
    [anon_sym_always] = ACTIONS(4454),
    [anon_sym_covergroup] = ACTIONS(4454),
    [anon_sym_let] = ACTIONS(4454),
    [anon_sym_pulldown] = ACTIONS(4454),
    [anon_sym_pullup] = ACTIONS(4454),
    [anon_sym_cmos] = ACTIONS(4454),
    [anon_sym_rcmos] = ACTIONS(4454),
    [anon_sym_bufif0] = ACTIONS(4454),
    [anon_sym_bufif1] = ACTIONS(4454),
    [anon_sym_notif0] = ACTIONS(4454),
    [anon_sym_notif1] = ACTIONS(4454),
    [anon_sym_nmos] = ACTIONS(4454),
    [anon_sym_pmos] = ACTIONS(4454),
    [anon_sym_rnmos] = ACTIONS(4454),
    [anon_sym_rpmos] = ACTIONS(4454),
    [anon_sym_nand] = ACTIONS(4454),
    [anon_sym_nor] = ACTIONS(4454),
    [anon_sym_xor] = ACTIONS(4454),
    [anon_sym_xnor] = ACTIONS(4454),
    [anon_sym_buf] = ACTIONS(4454),
    [anon_sym_tranif0] = ACTIONS(4454),
    [anon_sym_tranif1] = ACTIONS(4454),
    [anon_sym_rtranif1] = ACTIONS(4454),
    [anon_sym_rtranif0] = ACTIONS(4454),
    [anon_sym_tran] = ACTIONS(4454),
    [anon_sym_rtran] = ACTIONS(4454),
    [anon_sym_generate] = ACTIONS(4454),
    [anon_sym_endgenerate] = ACTIONS(4454),
    [anon_sym_for] = ACTIONS(4454),
    [anon_sym_initial] = ACTIONS(4454),
    [anon_sym_assign] = ACTIONS(4454),
    [anon_sym_alias] = ACTIONS(4454),
    [anon_sym_always_comb] = ACTIONS(4454),
    [anon_sym_always_latch] = ACTIONS(4454),
    [anon_sym_always_ff] = ACTIONS(4454),
    [anon_sym_final] = ACTIONS(4454),
    [anon_sym_global] = ACTIONS(4454),
    [anon_sym_LPAREN_STAR] = ACTIONS(4452),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4452),
    [anon_sym_DOLLARunit] = ACTIONS(4452),
  },
  [4395] = {
    [sym_simple_identifier] = ACTIONS(4624),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_COLON] = ACTIONS(10511),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_rand] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_end] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [4396] = {
    [sym_simple_identifier] = ACTIONS(4566),
    [anon_sym_wire] = ACTIONS(4566),
    [anon_sym_tri] = ACTIONS(4566),
    [anon_sym_tri0] = ACTIONS(4566),
    [anon_sym_tri1] = ACTIONS(4566),
    [anon_sym_wand] = ACTIONS(4566),
    [anon_sym_triand] = ACTIONS(4566),
    [anon_sym_wor] = ACTIONS(4566),
    [anon_sym_trior] = ACTIONS(4566),
    [anon_sym_trireg] = ACTIONS(4566),
    [anon_sym_uwire] = ACTIONS(4566),
    [anon_sym_SEMI] = ACTIONS(4564),
    [anon_sym_COLON] = ACTIONS(10513),
    [anon_sym_extern] = ACTIONS(4566),
    [anon_sym_interface] = ACTIONS(4566),
    [anon_sym_checker] = ACTIONS(4566),
    [anon_sym_virtual] = ACTIONS(4566),
    [anon_sym_class] = ACTIONS(4566),
    [anon_sym_type] = ACTIONS(4566),
    [anon_sym_DOLLARfatal] = ACTIONS(4564),
    [anon_sym_DOLLARerror] = ACTIONS(4564),
    [anon_sym_DOLLARwarning] = ACTIONS(4564),
    [anon_sym_DOLLARinfo] = ACTIONS(4564),
    [anon_sym_default] = ACTIONS(4566),
    [anon_sym_clocking] = ACTIONS(4566),
    [anon_sym_defparam] = ACTIONS(4566),
    [anon_sym_bind] = ACTIONS(4566),
    [anon_sym_rand] = ACTIONS(4566),
    [anon_sym_const] = ACTIONS(4566),
    [anon_sym_function] = ACTIONS(4566),
    [anon_sym_static] = ACTIONS(4566),
    [anon_sym_constraint] = ACTIONS(4566),
    [anon_sym_if] = ACTIONS(4566),
    [anon_sym_else] = ACTIONS(4566),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_localparam] = ACTIONS(4566),
    [anon_sym_parameter] = ACTIONS(4566),
    [anon_sym_var] = ACTIONS(4566),
    [anon_sym_import] = ACTIONS(4566),
    [anon_sym_export] = ACTIONS(4566),
    [anon_sym_genvar] = ACTIONS(4566),
    [anon_sym_interconnect] = ACTIONS(4566),
    [anon_sym_typedef] = ACTIONS(4566),
    [anon_sym_enum] = ACTIONS(4566),
    [anon_sym_struct] = ACTIONS(4566),
    [anon_sym_union] = ACTIONS(4566),
    [anon_sym_nettype] = ACTIONS(4566),
    [anon_sym_automatic] = ACTIONS(4566),
    [anon_sym_string] = ACTIONS(4566),
    [anon_sym_chandle] = ACTIONS(4566),
    [anon_sym_event] = ACTIONS(4566),
    [anon_sym_byte] = ACTIONS(4566),
    [anon_sym_shortint] = ACTIONS(4566),
    [anon_sym_int] = ACTIONS(4566),
    [anon_sym_longint] = ACTIONS(4566),
    [anon_sym_integer] = ACTIONS(4566),
    [anon_sym_time] = ACTIONS(4566),
    [anon_sym_bit] = ACTIONS(4566),
    [anon_sym_logic] = ACTIONS(4566),
    [anon_sym_reg] = ACTIONS(4566),
    [anon_sym_shortreal] = ACTIONS(4566),
    [anon_sym_real] = ACTIONS(4566),
    [anon_sym_realtime] = ACTIONS(4566),
    [anon_sym_supply0] = ACTIONS(4566),
    [anon_sym_supply1] = ACTIONS(4566),
    [anon_sym_signed] = ACTIONS(4566),
    [anon_sym_unsigned] = ACTIONS(4566),
    [anon_sym_task] = ACTIONS(4566),
    [anon_sym_assert] = ACTIONS(4566),
    [anon_sym_property] = ACTIONS(4566),
    [anon_sym_assume] = ACTIONS(4566),
    [anon_sym_cover] = ACTIONS(4566),
    [anon_sym_sequence] = ACTIONS(4566),
    [anon_sym_restrict] = ACTIONS(4566),
    [anon_sym_not] = ACTIONS(4566),
    [anon_sym_or] = ACTIONS(4566),
    [anon_sym_and] = ACTIONS(4566),
    [anon_sym_case] = ACTIONS(4566),
    [anon_sym_always] = ACTIONS(4566),
    [anon_sym_covergroup] = ACTIONS(4566),
    [anon_sym_let] = ACTIONS(4566),
    [anon_sym_pulldown] = ACTIONS(4566),
    [anon_sym_pullup] = ACTIONS(4566),
    [anon_sym_cmos] = ACTIONS(4566),
    [anon_sym_rcmos] = ACTIONS(4566),
    [anon_sym_bufif0] = ACTIONS(4566),
    [anon_sym_bufif1] = ACTIONS(4566),
    [anon_sym_notif0] = ACTIONS(4566),
    [anon_sym_notif1] = ACTIONS(4566),
    [anon_sym_nmos] = ACTIONS(4566),
    [anon_sym_pmos] = ACTIONS(4566),
    [anon_sym_rnmos] = ACTIONS(4566),
    [anon_sym_rpmos] = ACTIONS(4566),
    [anon_sym_nand] = ACTIONS(4566),
    [anon_sym_nor] = ACTIONS(4566),
    [anon_sym_xor] = ACTIONS(4566),
    [anon_sym_xnor] = ACTIONS(4566),
    [anon_sym_buf] = ACTIONS(4566),
    [anon_sym_tranif0] = ACTIONS(4566),
    [anon_sym_tranif1] = ACTIONS(4566),
    [anon_sym_rtranif1] = ACTIONS(4566),
    [anon_sym_rtranif0] = ACTIONS(4566),
    [anon_sym_tran] = ACTIONS(4566),
    [anon_sym_rtran] = ACTIONS(4566),
    [anon_sym_generate] = ACTIONS(4566),
    [anon_sym_endgenerate] = ACTIONS(4566),
    [anon_sym_for] = ACTIONS(4566),
    [anon_sym_initial] = ACTIONS(4566),
    [anon_sym_assign] = ACTIONS(4566),
    [anon_sym_alias] = ACTIONS(4566),
    [anon_sym_always_comb] = ACTIONS(4566),
    [anon_sym_always_latch] = ACTIONS(4566),
    [anon_sym_always_ff] = ACTIONS(4566),
    [anon_sym_final] = ACTIONS(4566),
    [anon_sym_global] = ACTIONS(4566),
    [anon_sym_LPAREN_STAR] = ACTIONS(4564),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4564),
    [anon_sym_DOLLARunit] = ACTIONS(4564),
  },
  [4397] = {
    [sym_simple_identifier] = ACTIONS(4794),
    [anon_sym_wire] = ACTIONS(4794),
    [anon_sym_tri] = ACTIONS(4794),
    [anon_sym_tri0] = ACTIONS(4794),
    [anon_sym_tri1] = ACTIONS(4794),
    [anon_sym_wand] = ACTIONS(4794),
    [anon_sym_triand] = ACTIONS(4794),
    [anon_sym_wor] = ACTIONS(4794),
    [anon_sym_trior] = ACTIONS(4794),
    [anon_sym_trireg] = ACTIONS(4794),
    [anon_sym_uwire] = ACTIONS(4794),
    [anon_sym_SEMI] = ACTIONS(4792),
    [anon_sym_COLON] = ACTIONS(10515),
    [anon_sym_extern] = ACTIONS(4794),
    [anon_sym_interface] = ACTIONS(4794),
    [anon_sym_checker] = ACTIONS(4794),
    [anon_sym_virtual] = ACTIONS(4794),
    [anon_sym_class] = ACTIONS(4794),
    [anon_sym_type] = ACTIONS(4794),
    [anon_sym_DOLLARfatal] = ACTIONS(4792),
    [anon_sym_DOLLARerror] = ACTIONS(4792),
    [anon_sym_DOLLARwarning] = ACTIONS(4792),
    [anon_sym_DOLLARinfo] = ACTIONS(4792),
    [anon_sym_default] = ACTIONS(4794),
    [anon_sym_clocking] = ACTIONS(4794),
    [anon_sym_defparam] = ACTIONS(4794),
    [anon_sym_bind] = ACTIONS(4794),
    [anon_sym_rand] = ACTIONS(4794),
    [anon_sym_const] = ACTIONS(4794),
    [anon_sym_function] = ACTIONS(4794),
    [anon_sym_static] = ACTIONS(4794),
    [anon_sym_constraint] = ACTIONS(4794),
    [anon_sym_if] = ACTIONS(4794),
    [anon_sym_else] = ACTIONS(4794),
    [anon_sym_LBRACK] = ACTIONS(4792),
    [anon_sym_localparam] = ACTIONS(4794),
    [anon_sym_parameter] = ACTIONS(4794),
    [anon_sym_var] = ACTIONS(4794),
    [anon_sym_import] = ACTIONS(4794),
    [anon_sym_export] = ACTIONS(4794),
    [anon_sym_genvar] = ACTIONS(4794),
    [anon_sym_interconnect] = ACTIONS(4794),
    [anon_sym_typedef] = ACTIONS(4794),
    [anon_sym_enum] = ACTIONS(4794),
    [anon_sym_struct] = ACTIONS(4794),
    [anon_sym_union] = ACTIONS(4794),
    [anon_sym_nettype] = ACTIONS(4794),
    [anon_sym_automatic] = ACTIONS(4794),
    [anon_sym_string] = ACTIONS(4794),
    [anon_sym_chandle] = ACTIONS(4794),
    [anon_sym_event] = ACTIONS(4794),
    [anon_sym_byte] = ACTIONS(4794),
    [anon_sym_shortint] = ACTIONS(4794),
    [anon_sym_int] = ACTIONS(4794),
    [anon_sym_longint] = ACTIONS(4794),
    [anon_sym_integer] = ACTIONS(4794),
    [anon_sym_time] = ACTIONS(4794),
    [anon_sym_bit] = ACTIONS(4794),
    [anon_sym_logic] = ACTIONS(4794),
    [anon_sym_reg] = ACTIONS(4794),
    [anon_sym_shortreal] = ACTIONS(4794),
    [anon_sym_real] = ACTIONS(4794),
    [anon_sym_realtime] = ACTIONS(4794),
    [anon_sym_supply0] = ACTIONS(4794),
    [anon_sym_supply1] = ACTIONS(4794),
    [anon_sym_signed] = ACTIONS(4794),
    [anon_sym_unsigned] = ACTIONS(4794),
    [anon_sym_task] = ACTIONS(4794),
    [anon_sym_assert] = ACTIONS(4794),
    [anon_sym_property] = ACTIONS(4794),
    [anon_sym_assume] = ACTIONS(4794),
    [anon_sym_cover] = ACTIONS(4794),
    [anon_sym_sequence] = ACTIONS(4794),
    [anon_sym_restrict] = ACTIONS(4794),
    [anon_sym_not] = ACTIONS(4794),
    [anon_sym_or] = ACTIONS(4794),
    [anon_sym_and] = ACTIONS(4794),
    [anon_sym_case] = ACTIONS(4794),
    [anon_sym_always] = ACTIONS(4794),
    [anon_sym_covergroup] = ACTIONS(4794),
    [anon_sym_end] = ACTIONS(4794),
    [anon_sym_let] = ACTIONS(4794),
    [anon_sym_pulldown] = ACTIONS(4794),
    [anon_sym_pullup] = ACTIONS(4794),
    [anon_sym_cmos] = ACTIONS(4794),
    [anon_sym_rcmos] = ACTIONS(4794),
    [anon_sym_bufif0] = ACTIONS(4794),
    [anon_sym_bufif1] = ACTIONS(4794),
    [anon_sym_notif0] = ACTIONS(4794),
    [anon_sym_notif1] = ACTIONS(4794),
    [anon_sym_nmos] = ACTIONS(4794),
    [anon_sym_pmos] = ACTIONS(4794),
    [anon_sym_rnmos] = ACTIONS(4794),
    [anon_sym_rpmos] = ACTIONS(4794),
    [anon_sym_nand] = ACTIONS(4794),
    [anon_sym_nor] = ACTIONS(4794),
    [anon_sym_xor] = ACTIONS(4794),
    [anon_sym_xnor] = ACTIONS(4794),
    [anon_sym_buf] = ACTIONS(4794),
    [anon_sym_tranif0] = ACTIONS(4794),
    [anon_sym_tranif1] = ACTIONS(4794),
    [anon_sym_rtranif1] = ACTIONS(4794),
    [anon_sym_rtranif0] = ACTIONS(4794),
    [anon_sym_tran] = ACTIONS(4794),
    [anon_sym_rtran] = ACTIONS(4794),
    [anon_sym_generate] = ACTIONS(4794),
    [anon_sym_for] = ACTIONS(4794),
    [anon_sym_initial] = ACTIONS(4794),
    [anon_sym_assign] = ACTIONS(4794),
    [anon_sym_alias] = ACTIONS(4794),
    [anon_sym_always_comb] = ACTIONS(4794),
    [anon_sym_always_latch] = ACTIONS(4794),
    [anon_sym_always_ff] = ACTIONS(4794),
    [anon_sym_final] = ACTIONS(4794),
    [anon_sym_global] = ACTIONS(4794),
    [anon_sym_LPAREN_STAR] = ACTIONS(4792),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4792),
    [anon_sym_DOLLARunit] = ACTIONS(4792),
  },
  [4398] = {
    [sym_simple_identifier] = ACTIONS(4572),
    [anon_sym_wire] = ACTIONS(4572),
    [anon_sym_tri] = ACTIONS(4572),
    [anon_sym_tri0] = ACTIONS(4572),
    [anon_sym_tri1] = ACTIONS(4572),
    [anon_sym_wand] = ACTIONS(4572),
    [anon_sym_triand] = ACTIONS(4572),
    [anon_sym_wor] = ACTIONS(4572),
    [anon_sym_trior] = ACTIONS(4572),
    [anon_sym_trireg] = ACTIONS(4572),
    [anon_sym_uwire] = ACTIONS(4572),
    [anon_sym_SEMI] = ACTIONS(4570),
    [anon_sym_COLON] = ACTIONS(10517),
    [anon_sym_extern] = ACTIONS(4572),
    [anon_sym_interface] = ACTIONS(4572),
    [anon_sym_checker] = ACTIONS(4572),
    [anon_sym_virtual] = ACTIONS(4572),
    [anon_sym_class] = ACTIONS(4572),
    [anon_sym_type] = ACTIONS(4572),
    [anon_sym_DOLLARfatal] = ACTIONS(4570),
    [anon_sym_DOLLARerror] = ACTIONS(4570),
    [anon_sym_DOLLARwarning] = ACTIONS(4570),
    [anon_sym_DOLLARinfo] = ACTIONS(4570),
    [anon_sym_default] = ACTIONS(4572),
    [anon_sym_clocking] = ACTIONS(4572),
    [anon_sym_defparam] = ACTIONS(4572),
    [anon_sym_bind] = ACTIONS(4572),
    [anon_sym_rand] = ACTIONS(4572),
    [anon_sym_const] = ACTIONS(4572),
    [anon_sym_function] = ACTIONS(4572),
    [anon_sym_static] = ACTIONS(4572),
    [anon_sym_constraint] = ACTIONS(4572),
    [anon_sym_if] = ACTIONS(4572),
    [anon_sym_else] = ACTIONS(4572),
    [anon_sym_LBRACK] = ACTIONS(4570),
    [anon_sym_localparam] = ACTIONS(4572),
    [anon_sym_parameter] = ACTIONS(4572),
    [anon_sym_var] = ACTIONS(4572),
    [anon_sym_import] = ACTIONS(4572),
    [anon_sym_export] = ACTIONS(4572),
    [anon_sym_genvar] = ACTIONS(4572),
    [anon_sym_interconnect] = ACTIONS(4572),
    [anon_sym_typedef] = ACTIONS(4572),
    [anon_sym_enum] = ACTIONS(4572),
    [anon_sym_struct] = ACTIONS(4572),
    [anon_sym_union] = ACTIONS(4572),
    [anon_sym_nettype] = ACTIONS(4572),
    [anon_sym_automatic] = ACTIONS(4572),
    [anon_sym_string] = ACTIONS(4572),
    [anon_sym_chandle] = ACTIONS(4572),
    [anon_sym_event] = ACTIONS(4572),
    [anon_sym_byte] = ACTIONS(4572),
    [anon_sym_shortint] = ACTIONS(4572),
    [anon_sym_int] = ACTIONS(4572),
    [anon_sym_longint] = ACTIONS(4572),
    [anon_sym_integer] = ACTIONS(4572),
    [anon_sym_time] = ACTIONS(4572),
    [anon_sym_bit] = ACTIONS(4572),
    [anon_sym_logic] = ACTIONS(4572),
    [anon_sym_reg] = ACTIONS(4572),
    [anon_sym_shortreal] = ACTIONS(4572),
    [anon_sym_real] = ACTIONS(4572),
    [anon_sym_realtime] = ACTIONS(4572),
    [anon_sym_supply0] = ACTIONS(4572),
    [anon_sym_supply1] = ACTIONS(4572),
    [anon_sym_signed] = ACTIONS(4572),
    [anon_sym_unsigned] = ACTIONS(4572),
    [anon_sym_task] = ACTIONS(4572),
    [anon_sym_assert] = ACTIONS(4572),
    [anon_sym_property] = ACTIONS(4572),
    [anon_sym_assume] = ACTIONS(4572),
    [anon_sym_cover] = ACTIONS(4572),
    [anon_sym_sequence] = ACTIONS(4572),
    [anon_sym_restrict] = ACTIONS(4572),
    [anon_sym_not] = ACTIONS(4572),
    [anon_sym_or] = ACTIONS(4572),
    [anon_sym_and] = ACTIONS(4572),
    [anon_sym_case] = ACTIONS(4572),
    [anon_sym_always] = ACTIONS(4572),
    [anon_sym_covergroup] = ACTIONS(4572),
    [anon_sym_let] = ACTIONS(4572),
    [anon_sym_pulldown] = ACTIONS(4572),
    [anon_sym_pullup] = ACTIONS(4572),
    [anon_sym_cmos] = ACTIONS(4572),
    [anon_sym_rcmos] = ACTIONS(4572),
    [anon_sym_bufif0] = ACTIONS(4572),
    [anon_sym_bufif1] = ACTIONS(4572),
    [anon_sym_notif0] = ACTIONS(4572),
    [anon_sym_notif1] = ACTIONS(4572),
    [anon_sym_nmos] = ACTIONS(4572),
    [anon_sym_pmos] = ACTIONS(4572),
    [anon_sym_rnmos] = ACTIONS(4572),
    [anon_sym_rpmos] = ACTIONS(4572),
    [anon_sym_nand] = ACTIONS(4572),
    [anon_sym_nor] = ACTIONS(4572),
    [anon_sym_xor] = ACTIONS(4572),
    [anon_sym_xnor] = ACTIONS(4572),
    [anon_sym_buf] = ACTIONS(4572),
    [anon_sym_tranif0] = ACTIONS(4572),
    [anon_sym_tranif1] = ACTIONS(4572),
    [anon_sym_rtranif1] = ACTIONS(4572),
    [anon_sym_rtranif0] = ACTIONS(4572),
    [anon_sym_tran] = ACTIONS(4572),
    [anon_sym_rtran] = ACTIONS(4572),
    [anon_sym_generate] = ACTIONS(4572),
    [anon_sym_endgenerate] = ACTIONS(4572),
    [anon_sym_for] = ACTIONS(4572),
    [anon_sym_initial] = ACTIONS(4572),
    [anon_sym_assign] = ACTIONS(4572),
    [anon_sym_alias] = ACTIONS(4572),
    [anon_sym_always_comb] = ACTIONS(4572),
    [anon_sym_always_latch] = ACTIONS(4572),
    [anon_sym_always_ff] = ACTIONS(4572),
    [anon_sym_final] = ACTIONS(4572),
    [anon_sym_global] = ACTIONS(4572),
    [anon_sym_LPAREN_STAR] = ACTIONS(4570),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4570),
    [anon_sym_DOLLARunit] = ACTIONS(4570),
  },
  [4399] = {
    [sym_simple_identifier] = ACTIONS(4578),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_COLON] = ACTIONS(10519),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_rand] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_endgenerate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [4400] = {
    [sym_simple_identifier] = ACTIONS(4212),
    [anon_sym_wire] = ACTIONS(4212),
    [anon_sym_tri] = ACTIONS(4212),
    [anon_sym_tri0] = ACTIONS(4212),
    [anon_sym_tri1] = ACTIONS(4212),
    [anon_sym_wand] = ACTIONS(4212),
    [anon_sym_triand] = ACTIONS(4212),
    [anon_sym_wor] = ACTIONS(4212),
    [anon_sym_trior] = ACTIONS(4212),
    [anon_sym_trireg] = ACTIONS(4212),
    [anon_sym_uwire] = ACTIONS(4212),
    [anon_sym_SEMI] = ACTIONS(4210),
    [anon_sym_COLON] = ACTIONS(10521),
    [anon_sym_extern] = ACTIONS(4212),
    [anon_sym_interface] = ACTIONS(4212),
    [anon_sym_checker] = ACTIONS(4212),
    [anon_sym_virtual] = ACTIONS(4212),
    [anon_sym_class] = ACTIONS(4212),
    [anon_sym_type] = ACTIONS(4212),
    [anon_sym_DOLLARfatal] = ACTIONS(4210),
    [anon_sym_DOLLARerror] = ACTIONS(4210),
    [anon_sym_DOLLARwarning] = ACTIONS(4210),
    [anon_sym_DOLLARinfo] = ACTIONS(4210),
    [anon_sym_default] = ACTIONS(4212),
    [anon_sym_clocking] = ACTIONS(4212),
    [anon_sym_defparam] = ACTIONS(4212),
    [anon_sym_bind] = ACTIONS(4212),
    [anon_sym_rand] = ACTIONS(4212),
    [anon_sym_const] = ACTIONS(4212),
    [anon_sym_function] = ACTIONS(4212),
    [anon_sym_static] = ACTIONS(4212),
    [anon_sym_constraint] = ACTIONS(4212),
    [anon_sym_if] = ACTIONS(4212),
    [anon_sym_else] = ACTIONS(4212),
    [anon_sym_LBRACK] = ACTIONS(4210),
    [anon_sym_localparam] = ACTIONS(4212),
    [anon_sym_parameter] = ACTIONS(4212),
    [anon_sym_var] = ACTIONS(4212),
    [anon_sym_import] = ACTIONS(4212),
    [anon_sym_export] = ACTIONS(4212),
    [anon_sym_genvar] = ACTIONS(4212),
    [anon_sym_interconnect] = ACTIONS(4212),
    [anon_sym_typedef] = ACTIONS(4212),
    [anon_sym_enum] = ACTIONS(4212),
    [anon_sym_struct] = ACTIONS(4212),
    [anon_sym_union] = ACTIONS(4212),
    [anon_sym_nettype] = ACTIONS(4212),
    [anon_sym_automatic] = ACTIONS(4212),
    [anon_sym_string] = ACTIONS(4212),
    [anon_sym_chandle] = ACTIONS(4212),
    [anon_sym_event] = ACTIONS(4212),
    [anon_sym_byte] = ACTIONS(4212),
    [anon_sym_shortint] = ACTIONS(4212),
    [anon_sym_int] = ACTIONS(4212),
    [anon_sym_longint] = ACTIONS(4212),
    [anon_sym_integer] = ACTIONS(4212),
    [anon_sym_time] = ACTIONS(4212),
    [anon_sym_bit] = ACTIONS(4212),
    [anon_sym_logic] = ACTIONS(4212),
    [anon_sym_reg] = ACTIONS(4212),
    [anon_sym_shortreal] = ACTIONS(4212),
    [anon_sym_real] = ACTIONS(4212),
    [anon_sym_realtime] = ACTIONS(4212),
    [anon_sym_supply0] = ACTIONS(4212),
    [anon_sym_supply1] = ACTIONS(4212),
    [anon_sym_signed] = ACTIONS(4212),
    [anon_sym_unsigned] = ACTIONS(4212),
    [anon_sym_task] = ACTIONS(4212),
    [anon_sym_assert] = ACTIONS(4212),
    [anon_sym_property] = ACTIONS(4212),
    [anon_sym_assume] = ACTIONS(4212),
    [anon_sym_cover] = ACTIONS(4212),
    [anon_sym_sequence] = ACTIONS(4212),
    [anon_sym_restrict] = ACTIONS(4212),
    [anon_sym_not] = ACTIONS(4212),
    [anon_sym_or] = ACTIONS(4212),
    [anon_sym_and] = ACTIONS(4212),
    [anon_sym_case] = ACTIONS(4212),
    [anon_sym_always] = ACTIONS(4212),
    [anon_sym_covergroup] = ACTIONS(4212),
    [anon_sym_end] = ACTIONS(4212),
    [anon_sym_let] = ACTIONS(4212),
    [anon_sym_pulldown] = ACTIONS(4212),
    [anon_sym_pullup] = ACTIONS(4212),
    [anon_sym_cmos] = ACTIONS(4212),
    [anon_sym_rcmos] = ACTIONS(4212),
    [anon_sym_bufif0] = ACTIONS(4212),
    [anon_sym_bufif1] = ACTIONS(4212),
    [anon_sym_notif0] = ACTIONS(4212),
    [anon_sym_notif1] = ACTIONS(4212),
    [anon_sym_nmos] = ACTIONS(4212),
    [anon_sym_pmos] = ACTIONS(4212),
    [anon_sym_rnmos] = ACTIONS(4212),
    [anon_sym_rpmos] = ACTIONS(4212),
    [anon_sym_nand] = ACTIONS(4212),
    [anon_sym_nor] = ACTIONS(4212),
    [anon_sym_xor] = ACTIONS(4212),
    [anon_sym_xnor] = ACTIONS(4212),
    [anon_sym_buf] = ACTIONS(4212),
    [anon_sym_tranif0] = ACTIONS(4212),
    [anon_sym_tranif1] = ACTIONS(4212),
    [anon_sym_rtranif1] = ACTIONS(4212),
    [anon_sym_rtranif0] = ACTIONS(4212),
    [anon_sym_tran] = ACTIONS(4212),
    [anon_sym_rtran] = ACTIONS(4212),
    [anon_sym_generate] = ACTIONS(4212),
    [anon_sym_for] = ACTIONS(4212),
    [anon_sym_initial] = ACTIONS(4212),
    [anon_sym_assign] = ACTIONS(4212),
    [anon_sym_alias] = ACTIONS(4212),
    [anon_sym_always_comb] = ACTIONS(4212),
    [anon_sym_always_latch] = ACTIONS(4212),
    [anon_sym_always_ff] = ACTIONS(4212),
    [anon_sym_final] = ACTIONS(4212),
    [anon_sym_global] = ACTIONS(4212),
    [anon_sym_LPAREN_STAR] = ACTIONS(4210),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4210),
    [anon_sym_DOLLARunit] = ACTIONS(4210),
  },
  [4401] = {
    [sym_simple_identifier] = ACTIONS(4494),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_COLON] = ACTIONS(10523),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_rand] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_end] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [4402] = {
    [sym_simple_identifier] = ACTIONS(4668),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(10525),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_rand] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_end] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [4403] = {
    [sym_simple_identifier] = ACTIONS(4696),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_COLON] = ACTIONS(10527),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_rand] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_endgenerate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [4404] = {
    [sym_simple_identifier] = ACTIONS(4714),
    [anon_sym_wire] = ACTIONS(4714),
    [anon_sym_tri] = ACTIONS(4714),
    [anon_sym_tri0] = ACTIONS(4714),
    [anon_sym_tri1] = ACTIONS(4714),
    [anon_sym_wand] = ACTIONS(4714),
    [anon_sym_triand] = ACTIONS(4714),
    [anon_sym_wor] = ACTIONS(4714),
    [anon_sym_trior] = ACTIONS(4714),
    [anon_sym_trireg] = ACTIONS(4714),
    [anon_sym_uwire] = ACTIONS(4714),
    [anon_sym_SEMI] = ACTIONS(4712),
    [anon_sym_COLON] = ACTIONS(10529),
    [anon_sym_extern] = ACTIONS(4714),
    [anon_sym_interface] = ACTIONS(4714),
    [anon_sym_checker] = ACTIONS(4714),
    [anon_sym_virtual] = ACTIONS(4714),
    [anon_sym_class] = ACTIONS(4714),
    [anon_sym_type] = ACTIONS(4714),
    [anon_sym_DOLLARfatal] = ACTIONS(4712),
    [anon_sym_DOLLARerror] = ACTIONS(4712),
    [anon_sym_DOLLARwarning] = ACTIONS(4712),
    [anon_sym_DOLLARinfo] = ACTIONS(4712),
    [anon_sym_default] = ACTIONS(4714),
    [anon_sym_clocking] = ACTIONS(4714),
    [anon_sym_defparam] = ACTIONS(4714),
    [anon_sym_bind] = ACTIONS(4714),
    [anon_sym_rand] = ACTIONS(4714),
    [anon_sym_const] = ACTIONS(4714),
    [anon_sym_function] = ACTIONS(4714),
    [anon_sym_static] = ACTIONS(4714),
    [anon_sym_constraint] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4714),
    [anon_sym_else] = ACTIONS(4714),
    [anon_sym_LBRACK] = ACTIONS(4712),
    [anon_sym_localparam] = ACTIONS(4714),
    [anon_sym_parameter] = ACTIONS(4714),
    [anon_sym_var] = ACTIONS(4714),
    [anon_sym_import] = ACTIONS(4714),
    [anon_sym_export] = ACTIONS(4714),
    [anon_sym_genvar] = ACTIONS(4714),
    [anon_sym_interconnect] = ACTIONS(4714),
    [anon_sym_typedef] = ACTIONS(4714),
    [anon_sym_enum] = ACTIONS(4714),
    [anon_sym_struct] = ACTIONS(4714),
    [anon_sym_union] = ACTIONS(4714),
    [anon_sym_nettype] = ACTIONS(4714),
    [anon_sym_automatic] = ACTIONS(4714),
    [anon_sym_string] = ACTIONS(4714),
    [anon_sym_chandle] = ACTIONS(4714),
    [anon_sym_event] = ACTIONS(4714),
    [anon_sym_byte] = ACTIONS(4714),
    [anon_sym_shortint] = ACTIONS(4714),
    [anon_sym_int] = ACTIONS(4714),
    [anon_sym_longint] = ACTIONS(4714),
    [anon_sym_integer] = ACTIONS(4714),
    [anon_sym_time] = ACTIONS(4714),
    [anon_sym_bit] = ACTIONS(4714),
    [anon_sym_logic] = ACTIONS(4714),
    [anon_sym_reg] = ACTIONS(4714),
    [anon_sym_shortreal] = ACTIONS(4714),
    [anon_sym_real] = ACTIONS(4714),
    [anon_sym_realtime] = ACTIONS(4714),
    [anon_sym_supply0] = ACTIONS(4714),
    [anon_sym_supply1] = ACTIONS(4714),
    [anon_sym_signed] = ACTIONS(4714),
    [anon_sym_unsigned] = ACTIONS(4714),
    [anon_sym_task] = ACTIONS(4714),
    [anon_sym_assert] = ACTIONS(4714),
    [anon_sym_property] = ACTIONS(4714),
    [anon_sym_assume] = ACTIONS(4714),
    [anon_sym_cover] = ACTIONS(4714),
    [anon_sym_sequence] = ACTIONS(4714),
    [anon_sym_restrict] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4714),
    [anon_sym_or] = ACTIONS(4714),
    [anon_sym_and] = ACTIONS(4714),
    [anon_sym_case] = ACTIONS(4714),
    [anon_sym_always] = ACTIONS(4714),
    [anon_sym_covergroup] = ACTIONS(4714),
    [anon_sym_let] = ACTIONS(4714),
    [anon_sym_pulldown] = ACTIONS(4714),
    [anon_sym_pullup] = ACTIONS(4714),
    [anon_sym_cmos] = ACTIONS(4714),
    [anon_sym_rcmos] = ACTIONS(4714),
    [anon_sym_bufif0] = ACTIONS(4714),
    [anon_sym_bufif1] = ACTIONS(4714),
    [anon_sym_notif0] = ACTIONS(4714),
    [anon_sym_notif1] = ACTIONS(4714),
    [anon_sym_nmos] = ACTIONS(4714),
    [anon_sym_pmos] = ACTIONS(4714),
    [anon_sym_rnmos] = ACTIONS(4714),
    [anon_sym_rpmos] = ACTIONS(4714),
    [anon_sym_nand] = ACTIONS(4714),
    [anon_sym_nor] = ACTIONS(4714),
    [anon_sym_xor] = ACTIONS(4714),
    [anon_sym_xnor] = ACTIONS(4714),
    [anon_sym_buf] = ACTIONS(4714),
    [anon_sym_tranif0] = ACTIONS(4714),
    [anon_sym_tranif1] = ACTIONS(4714),
    [anon_sym_rtranif1] = ACTIONS(4714),
    [anon_sym_rtranif0] = ACTIONS(4714),
    [anon_sym_tran] = ACTIONS(4714),
    [anon_sym_rtran] = ACTIONS(4714),
    [anon_sym_generate] = ACTIONS(4714),
    [anon_sym_endgenerate] = ACTIONS(4714),
    [anon_sym_for] = ACTIONS(4714),
    [anon_sym_initial] = ACTIONS(4714),
    [anon_sym_assign] = ACTIONS(4714),
    [anon_sym_alias] = ACTIONS(4714),
    [anon_sym_always_comb] = ACTIONS(4714),
    [anon_sym_always_latch] = ACTIONS(4714),
    [anon_sym_always_ff] = ACTIONS(4714),
    [anon_sym_final] = ACTIONS(4714),
    [anon_sym_global] = ACTIONS(4714),
    [anon_sym_LPAREN_STAR] = ACTIONS(4712),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4712),
    [anon_sym_DOLLARunit] = ACTIONS(4712),
  },
  [4405] = {
    [sym_simple_identifier] = ACTIONS(4206),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_COLON] = ACTIONS(10531),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_rand] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_end] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [4406] = {
    [sym_simple_identifier] = ACTIONS(4594),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_COLON] = ACTIONS(10533),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_rand] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_endgenerate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [4407] = {
    [sym_simple_identifier] = ACTIONS(4600),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_COLON] = ACTIONS(10535),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_rand] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_endgenerate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [4408] = {
    [sym_simple_identifier] = ACTIONS(4294),
    [anon_sym_wire] = ACTIONS(4294),
    [anon_sym_tri] = ACTIONS(4294),
    [anon_sym_tri0] = ACTIONS(4294),
    [anon_sym_tri1] = ACTIONS(4294),
    [anon_sym_wand] = ACTIONS(4294),
    [anon_sym_triand] = ACTIONS(4294),
    [anon_sym_wor] = ACTIONS(4294),
    [anon_sym_trior] = ACTIONS(4294),
    [anon_sym_trireg] = ACTIONS(4294),
    [anon_sym_uwire] = ACTIONS(4294),
    [anon_sym_SEMI] = ACTIONS(4292),
    [anon_sym_COLON] = ACTIONS(10537),
    [anon_sym_extern] = ACTIONS(4294),
    [anon_sym_interface] = ACTIONS(4294),
    [anon_sym_checker] = ACTIONS(4294),
    [anon_sym_virtual] = ACTIONS(4294),
    [anon_sym_class] = ACTIONS(4294),
    [anon_sym_type] = ACTIONS(4294),
    [anon_sym_DOLLARfatal] = ACTIONS(4292),
    [anon_sym_DOLLARerror] = ACTIONS(4292),
    [anon_sym_DOLLARwarning] = ACTIONS(4292),
    [anon_sym_DOLLARinfo] = ACTIONS(4292),
    [anon_sym_default] = ACTIONS(4294),
    [anon_sym_clocking] = ACTIONS(4294),
    [anon_sym_defparam] = ACTIONS(4294),
    [anon_sym_bind] = ACTIONS(4294),
    [anon_sym_rand] = ACTIONS(4294),
    [anon_sym_const] = ACTIONS(4294),
    [anon_sym_function] = ACTIONS(4294),
    [anon_sym_static] = ACTIONS(4294),
    [anon_sym_constraint] = ACTIONS(4294),
    [anon_sym_if] = ACTIONS(4294),
    [anon_sym_else] = ACTIONS(4294),
    [anon_sym_LBRACK] = ACTIONS(4292),
    [anon_sym_localparam] = ACTIONS(4294),
    [anon_sym_parameter] = ACTIONS(4294),
    [anon_sym_var] = ACTIONS(4294),
    [anon_sym_import] = ACTIONS(4294),
    [anon_sym_export] = ACTIONS(4294),
    [anon_sym_genvar] = ACTIONS(4294),
    [anon_sym_interconnect] = ACTIONS(4294),
    [anon_sym_typedef] = ACTIONS(4294),
    [anon_sym_enum] = ACTIONS(4294),
    [anon_sym_struct] = ACTIONS(4294),
    [anon_sym_union] = ACTIONS(4294),
    [anon_sym_nettype] = ACTIONS(4294),
    [anon_sym_automatic] = ACTIONS(4294),
    [anon_sym_string] = ACTIONS(4294),
    [anon_sym_chandle] = ACTIONS(4294),
    [anon_sym_event] = ACTIONS(4294),
    [anon_sym_byte] = ACTIONS(4294),
    [anon_sym_shortint] = ACTIONS(4294),
    [anon_sym_int] = ACTIONS(4294),
    [anon_sym_longint] = ACTIONS(4294),
    [anon_sym_integer] = ACTIONS(4294),
    [anon_sym_time] = ACTIONS(4294),
    [anon_sym_bit] = ACTIONS(4294),
    [anon_sym_logic] = ACTIONS(4294),
    [anon_sym_reg] = ACTIONS(4294),
    [anon_sym_shortreal] = ACTIONS(4294),
    [anon_sym_real] = ACTIONS(4294),
    [anon_sym_realtime] = ACTIONS(4294),
    [anon_sym_supply0] = ACTIONS(4294),
    [anon_sym_supply1] = ACTIONS(4294),
    [anon_sym_signed] = ACTIONS(4294),
    [anon_sym_unsigned] = ACTIONS(4294),
    [anon_sym_task] = ACTIONS(4294),
    [anon_sym_assert] = ACTIONS(4294),
    [anon_sym_property] = ACTIONS(4294),
    [anon_sym_assume] = ACTIONS(4294),
    [anon_sym_cover] = ACTIONS(4294),
    [anon_sym_sequence] = ACTIONS(4294),
    [anon_sym_restrict] = ACTIONS(4294),
    [anon_sym_not] = ACTIONS(4294),
    [anon_sym_or] = ACTIONS(4294),
    [anon_sym_and] = ACTIONS(4294),
    [anon_sym_case] = ACTIONS(4294),
    [anon_sym_always] = ACTIONS(4294),
    [anon_sym_covergroup] = ACTIONS(4294),
    [anon_sym_end] = ACTIONS(4294),
    [anon_sym_let] = ACTIONS(4294),
    [anon_sym_pulldown] = ACTIONS(4294),
    [anon_sym_pullup] = ACTIONS(4294),
    [anon_sym_cmos] = ACTIONS(4294),
    [anon_sym_rcmos] = ACTIONS(4294),
    [anon_sym_bufif0] = ACTIONS(4294),
    [anon_sym_bufif1] = ACTIONS(4294),
    [anon_sym_notif0] = ACTIONS(4294),
    [anon_sym_notif1] = ACTIONS(4294),
    [anon_sym_nmos] = ACTIONS(4294),
    [anon_sym_pmos] = ACTIONS(4294),
    [anon_sym_rnmos] = ACTIONS(4294),
    [anon_sym_rpmos] = ACTIONS(4294),
    [anon_sym_nand] = ACTIONS(4294),
    [anon_sym_nor] = ACTIONS(4294),
    [anon_sym_xor] = ACTIONS(4294),
    [anon_sym_xnor] = ACTIONS(4294),
    [anon_sym_buf] = ACTIONS(4294),
    [anon_sym_tranif0] = ACTIONS(4294),
    [anon_sym_tranif1] = ACTIONS(4294),
    [anon_sym_rtranif1] = ACTIONS(4294),
    [anon_sym_rtranif0] = ACTIONS(4294),
    [anon_sym_tran] = ACTIONS(4294),
    [anon_sym_rtran] = ACTIONS(4294),
    [anon_sym_generate] = ACTIONS(4294),
    [anon_sym_for] = ACTIONS(4294),
    [anon_sym_initial] = ACTIONS(4294),
    [anon_sym_assign] = ACTIONS(4294),
    [anon_sym_alias] = ACTIONS(4294),
    [anon_sym_always_comb] = ACTIONS(4294),
    [anon_sym_always_latch] = ACTIONS(4294),
    [anon_sym_always_ff] = ACTIONS(4294),
    [anon_sym_final] = ACTIONS(4294),
    [anon_sym_global] = ACTIONS(4294),
    [anon_sym_LPAREN_STAR] = ACTIONS(4292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4292),
    [anon_sym_DOLLARunit] = ACTIONS(4292),
  },
  [4409] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_COLON] = ACTIONS(10539),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_rand] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_end] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [4410] = {
    [sym_simple_identifier] = ACTIONS(4190),
    [anon_sym_wire] = ACTIONS(4190),
    [anon_sym_tri] = ACTIONS(4190),
    [anon_sym_tri0] = ACTIONS(4190),
    [anon_sym_tri1] = ACTIONS(4190),
    [anon_sym_wand] = ACTIONS(4190),
    [anon_sym_triand] = ACTIONS(4190),
    [anon_sym_wor] = ACTIONS(4190),
    [anon_sym_trior] = ACTIONS(4190),
    [anon_sym_trireg] = ACTIONS(4190),
    [anon_sym_uwire] = ACTIONS(4190),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_COLON] = ACTIONS(10541),
    [anon_sym_extern] = ACTIONS(4190),
    [anon_sym_interface] = ACTIONS(4190),
    [anon_sym_checker] = ACTIONS(4190),
    [anon_sym_virtual] = ACTIONS(4190),
    [anon_sym_class] = ACTIONS(4190),
    [anon_sym_type] = ACTIONS(4190),
    [anon_sym_DOLLARfatal] = ACTIONS(4188),
    [anon_sym_DOLLARerror] = ACTIONS(4188),
    [anon_sym_DOLLARwarning] = ACTIONS(4188),
    [anon_sym_DOLLARinfo] = ACTIONS(4188),
    [anon_sym_default] = ACTIONS(4190),
    [anon_sym_clocking] = ACTIONS(4190),
    [anon_sym_defparam] = ACTIONS(4190),
    [anon_sym_bind] = ACTIONS(4190),
    [anon_sym_rand] = ACTIONS(4190),
    [anon_sym_const] = ACTIONS(4190),
    [anon_sym_function] = ACTIONS(4190),
    [anon_sym_static] = ACTIONS(4190),
    [anon_sym_constraint] = ACTIONS(4190),
    [anon_sym_if] = ACTIONS(4190),
    [anon_sym_else] = ACTIONS(4190),
    [anon_sym_LBRACK] = ACTIONS(4188),
    [anon_sym_localparam] = ACTIONS(4190),
    [anon_sym_parameter] = ACTIONS(4190),
    [anon_sym_var] = ACTIONS(4190),
    [anon_sym_import] = ACTIONS(4190),
    [anon_sym_export] = ACTIONS(4190),
    [anon_sym_genvar] = ACTIONS(4190),
    [anon_sym_interconnect] = ACTIONS(4190),
    [anon_sym_typedef] = ACTIONS(4190),
    [anon_sym_enum] = ACTIONS(4190),
    [anon_sym_struct] = ACTIONS(4190),
    [anon_sym_union] = ACTIONS(4190),
    [anon_sym_nettype] = ACTIONS(4190),
    [anon_sym_automatic] = ACTIONS(4190),
    [anon_sym_string] = ACTIONS(4190),
    [anon_sym_chandle] = ACTIONS(4190),
    [anon_sym_event] = ACTIONS(4190),
    [anon_sym_byte] = ACTIONS(4190),
    [anon_sym_shortint] = ACTIONS(4190),
    [anon_sym_int] = ACTIONS(4190),
    [anon_sym_longint] = ACTIONS(4190),
    [anon_sym_integer] = ACTIONS(4190),
    [anon_sym_time] = ACTIONS(4190),
    [anon_sym_bit] = ACTIONS(4190),
    [anon_sym_logic] = ACTIONS(4190),
    [anon_sym_reg] = ACTIONS(4190),
    [anon_sym_shortreal] = ACTIONS(4190),
    [anon_sym_real] = ACTIONS(4190),
    [anon_sym_realtime] = ACTIONS(4190),
    [anon_sym_supply0] = ACTIONS(4190),
    [anon_sym_supply1] = ACTIONS(4190),
    [anon_sym_signed] = ACTIONS(4190),
    [anon_sym_unsigned] = ACTIONS(4190),
    [anon_sym_task] = ACTIONS(4190),
    [anon_sym_assert] = ACTIONS(4190),
    [anon_sym_property] = ACTIONS(4190),
    [anon_sym_assume] = ACTIONS(4190),
    [anon_sym_cover] = ACTIONS(4190),
    [anon_sym_sequence] = ACTIONS(4190),
    [anon_sym_restrict] = ACTIONS(4190),
    [anon_sym_not] = ACTIONS(4190),
    [anon_sym_or] = ACTIONS(4190),
    [anon_sym_and] = ACTIONS(4190),
    [anon_sym_case] = ACTIONS(4190),
    [anon_sym_always] = ACTIONS(4190),
    [anon_sym_covergroup] = ACTIONS(4190),
    [anon_sym_let] = ACTIONS(4190),
    [anon_sym_pulldown] = ACTIONS(4190),
    [anon_sym_pullup] = ACTIONS(4190),
    [anon_sym_cmos] = ACTIONS(4190),
    [anon_sym_rcmos] = ACTIONS(4190),
    [anon_sym_bufif0] = ACTIONS(4190),
    [anon_sym_bufif1] = ACTIONS(4190),
    [anon_sym_notif0] = ACTIONS(4190),
    [anon_sym_notif1] = ACTIONS(4190),
    [anon_sym_nmos] = ACTIONS(4190),
    [anon_sym_pmos] = ACTIONS(4190),
    [anon_sym_rnmos] = ACTIONS(4190),
    [anon_sym_rpmos] = ACTIONS(4190),
    [anon_sym_nand] = ACTIONS(4190),
    [anon_sym_nor] = ACTIONS(4190),
    [anon_sym_xor] = ACTIONS(4190),
    [anon_sym_xnor] = ACTIONS(4190),
    [anon_sym_buf] = ACTIONS(4190),
    [anon_sym_tranif0] = ACTIONS(4190),
    [anon_sym_tranif1] = ACTIONS(4190),
    [anon_sym_rtranif1] = ACTIONS(4190),
    [anon_sym_rtranif0] = ACTIONS(4190),
    [anon_sym_tran] = ACTIONS(4190),
    [anon_sym_rtran] = ACTIONS(4190),
    [anon_sym_generate] = ACTIONS(4190),
    [anon_sym_endgenerate] = ACTIONS(4190),
    [anon_sym_for] = ACTIONS(4190),
    [anon_sym_initial] = ACTIONS(4190),
    [anon_sym_assign] = ACTIONS(4190),
    [anon_sym_alias] = ACTIONS(4190),
    [anon_sym_always_comb] = ACTIONS(4190),
    [anon_sym_always_latch] = ACTIONS(4190),
    [anon_sym_always_ff] = ACTIONS(4190),
    [anon_sym_final] = ACTIONS(4190),
    [anon_sym_global] = ACTIONS(4190),
    [anon_sym_LPAREN_STAR] = ACTIONS(4188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4188),
    [anon_sym_DOLLARunit] = ACTIONS(4188),
  },
  [4411] = {
    [sym_simple_identifier] = ACTIONS(4218),
    [anon_sym_wire] = ACTIONS(4218),
    [anon_sym_tri] = ACTIONS(4218),
    [anon_sym_tri0] = ACTIONS(4218),
    [anon_sym_tri1] = ACTIONS(4218),
    [anon_sym_wand] = ACTIONS(4218),
    [anon_sym_triand] = ACTIONS(4218),
    [anon_sym_wor] = ACTIONS(4218),
    [anon_sym_trior] = ACTIONS(4218),
    [anon_sym_trireg] = ACTIONS(4218),
    [anon_sym_uwire] = ACTIONS(4218),
    [anon_sym_SEMI] = ACTIONS(4216),
    [anon_sym_COLON] = ACTIONS(10543),
    [anon_sym_extern] = ACTIONS(4218),
    [anon_sym_interface] = ACTIONS(4218),
    [anon_sym_checker] = ACTIONS(4218),
    [anon_sym_virtual] = ACTIONS(4218),
    [anon_sym_class] = ACTIONS(4218),
    [anon_sym_type] = ACTIONS(4218),
    [anon_sym_DOLLARfatal] = ACTIONS(4216),
    [anon_sym_DOLLARerror] = ACTIONS(4216),
    [anon_sym_DOLLARwarning] = ACTIONS(4216),
    [anon_sym_DOLLARinfo] = ACTIONS(4216),
    [anon_sym_default] = ACTIONS(4218),
    [anon_sym_clocking] = ACTIONS(4218),
    [anon_sym_defparam] = ACTIONS(4218),
    [anon_sym_bind] = ACTIONS(4218),
    [anon_sym_rand] = ACTIONS(4218),
    [anon_sym_const] = ACTIONS(4218),
    [anon_sym_function] = ACTIONS(4218),
    [anon_sym_static] = ACTIONS(4218),
    [anon_sym_constraint] = ACTIONS(4218),
    [anon_sym_if] = ACTIONS(4218),
    [anon_sym_else] = ACTIONS(4218),
    [anon_sym_LBRACK] = ACTIONS(4216),
    [anon_sym_localparam] = ACTIONS(4218),
    [anon_sym_parameter] = ACTIONS(4218),
    [anon_sym_var] = ACTIONS(4218),
    [anon_sym_import] = ACTIONS(4218),
    [anon_sym_export] = ACTIONS(4218),
    [anon_sym_genvar] = ACTIONS(4218),
    [anon_sym_interconnect] = ACTIONS(4218),
    [anon_sym_typedef] = ACTIONS(4218),
    [anon_sym_enum] = ACTIONS(4218),
    [anon_sym_struct] = ACTIONS(4218),
    [anon_sym_union] = ACTIONS(4218),
    [anon_sym_nettype] = ACTIONS(4218),
    [anon_sym_automatic] = ACTIONS(4218),
    [anon_sym_string] = ACTIONS(4218),
    [anon_sym_chandle] = ACTIONS(4218),
    [anon_sym_event] = ACTIONS(4218),
    [anon_sym_byte] = ACTIONS(4218),
    [anon_sym_shortint] = ACTIONS(4218),
    [anon_sym_int] = ACTIONS(4218),
    [anon_sym_longint] = ACTIONS(4218),
    [anon_sym_integer] = ACTIONS(4218),
    [anon_sym_time] = ACTIONS(4218),
    [anon_sym_bit] = ACTIONS(4218),
    [anon_sym_logic] = ACTIONS(4218),
    [anon_sym_reg] = ACTIONS(4218),
    [anon_sym_shortreal] = ACTIONS(4218),
    [anon_sym_real] = ACTIONS(4218),
    [anon_sym_realtime] = ACTIONS(4218),
    [anon_sym_supply0] = ACTIONS(4218),
    [anon_sym_supply1] = ACTIONS(4218),
    [anon_sym_signed] = ACTIONS(4218),
    [anon_sym_unsigned] = ACTIONS(4218),
    [anon_sym_task] = ACTIONS(4218),
    [anon_sym_assert] = ACTIONS(4218),
    [anon_sym_property] = ACTIONS(4218),
    [anon_sym_assume] = ACTIONS(4218),
    [anon_sym_cover] = ACTIONS(4218),
    [anon_sym_sequence] = ACTIONS(4218),
    [anon_sym_restrict] = ACTIONS(4218),
    [anon_sym_not] = ACTIONS(4218),
    [anon_sym_or] = ACTIONS(4218),
    [anon_sym_and] = ACTIONS(4218),
    [anon_sym_case] = ACTIONS(4218),
    [anon_sym_always] = ACTIONS(4218),
    [anon_sym_covergroup] = ACTIONS(4218),
    [anon_sym_end] = ACTIONS(4218),
    [anon_sym_let] = ACTIONS(4218),
    [anon_sym_pulldown] = ACTIONS(4218),
    [anon_sym_pullup] = ACTIONS(4218),
    [anon_sym_cmos] = ACTIONS(4218),
    [anon_sym_rcmos] = ACTIONS(4218),
    [anon_sym_bufif0] = ACTIONS(4218),
    [anon_sym_bufif1] = ACTIONS(4218),
    [anon_sym_notif0] = ACTIONS(4218),
    [anon_sym_notif1] = ACTIONS(4218),
    [anon_sym_nmos] = ACTIONS(4218),
    [anon_sym_pmos] = ACTIONS(4218),
    [anon_sym_rnmos] = ACTIONS(4218),
    [anon_sym_rpmos] = ACTIONS(4218),
    [anon_sym_nand] = ACTIONS(4218),
    [anon_sym_nor] = ACTIONS(4218),
    [anon_sym_xor] = ACTIONS(4218),
    [anon_sym_xnor] = ACTIONS(4218),
    [anon_sym_buf] = ACTIONS(4218),
    [anon_sym_tranif0] = ACTIONS(4218),
    [anon_sym_tranif1] = ACTIONS(4218),
    [anon_sym_rtranif1] = ACTIONS(4218),
    [anon_sym_rtranif0] = ACTIONS(4218),
    [anon_sym_tran] = ACTIONS(4218),
    [anon_sym_rtran] = ACTIONS(4218),
    [anon_sym_generate] = ACTIONS(4218),
    [anon_sym_for] = ACTIONS(4218),
    [anon_sym_initial] = ACTIONS(4218),
    [anon_sym_assign] = ACTIONS(4218),
    [anon_sym_alias] = ACTIONS(4218),
    [anon_sym_always_comb] = ACTIONS(4218),
    [anon_sym_always_latch] = ACTIONS(4218),
    [anon_sym_always_ff] = ACTIONS(4218),
    [anon_sym_final] = ACTIONS(4218),
    [anon_sym_global] = ACTIONS(4218),
    [anon_sym_LPAREN_STAR] = ACTIONS(4216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4216),
    [anon_sym_DOLLARunit] = ACTIONS(4216),
  },
  [4412] = {
    [sym_simple_identifier] = ACTIONS(4612),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_COLON] = ACTIONS(10545),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_rand] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_endgenerate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [4413] = {
    [sym_simple_identifier] = ACTIONS(6365),
    [anon_sym_wire] = ACTIONS(6365),
    [anon_sym_tri] = ACTIONS(6365),
    [anon_sym_tri0] = ACTIONS(6365),
    [anon_sym_tri1] = ACTIONS(6365),
    [anon_sym_wand] = ACTIONS(6365),
    [anon_sym_triand] = ACTIONS(6365),
    [anon_sym_wor] = ACTIONS(6365),
    [anon_sym_trior] = ACTIONS(6365),
    [anon_sym_trireg] = ACTIONS(6365),
    [anon_sym_uwire] = ACTIONS(6365),
    [anon_sym_SEMI] = ACTIONS(6367),
    [anon_sym_COLON] = ACTIONS(10547),
    [anon_sym_extern] = ACTIONS(6365),
    [anon_sym_interface] = ACTIONS(6365),
    [anon_sym_checker] = ACTIONS(6365),
    [anon_sym_virtual] = ACTIONS(6365),
    [anon_sym_class] = ACTIONS(6365),
    [anon_sym_type] = ACTIONS(6365),
    [anon_sym_DOLLARfatal] = ACTIONS(6367),
    [anon_sym_DOLLARerror] = ACTIONS(6367),
    [anon_sym_DOLLARwarning] = ACTIONS(6367),
    [anon_sym_DOLLARinfo] = ACTIONS(6367),
    [anon_sym_default] = ACTIONS(6365),
    [anon_sym_clocking] = ACTIONS(6365),
    [anon_sym_defparam] = ACTIONS(6365),
    [anon_sym_bind] = ACTIONS(6365),
    [anon_sym_rand] = ACTIONS(6365),
    [anon_sym_const] = ACTIONS(6365),
    [anon_sym_function] = ACTIONS(6365),
    [anon_sym_static] = ACTIONS(6365),
    [anon_sym_constraint] = ACTIONS(6365),
    [anon_sym_if] = ACTIONS(6365),
    [anon_sym_else] = ACTIONS(6365),
    [anon_sym_LBRACK] = ACTIONS(6367),
    [anon_sym_localparam] = ACTIONS(6365),
    [anon_sym_parameter] = ACTIONS(6365),
    [anon_sym_var] = ACTIONS(6365),
    [anon_sym_import] = ACTIONS(6365),
    [anon_sym_export] = ACTIONS(6365),
    [anon_sym_genvar] = ACTIONS(6365),
    [anon_sym_interconnect] = ACTIONS(6365),
    [anon_sym_typedef] = ACTIONS(6365),
    [anon_sym_enum] = ACTIONS(6365),
    [anon_sym_struct] = ACTIONS(6365),
    [anon_sym_union] = ACTIONS(6365),
    [anon_sym_nettype] = ACTIONS(6365),
    [anon_sym_automatic] = ACTIONS(6365),
    [anon_sym_string] = ACTIONS(6365),
    [anon_sym_chandle] = ACTIONS(6365),
    [anon_sym_event] = ACTIONS(6365),
    [anon_sym_byte] = ACTIONS(6365),
    [anon_sym_shortint] = ACTIONS(6365),
    [anon_sym_int] = ACTIONS(6365),
    [anon_sym_longint] = ACTIONS(6365),
    [anon_sym_integer] = ACTIONS(6365),
    [anon_sym_time] = ACTIONS(6365),
    [anon_sym_bit] = ACTIONS(6365),
    [anon_sym_logic] = ACTIONS(6365),
    [anon_sym_reg] = ACTIONS(6365),
    [anon_sym_shortreal] = ACTIONS(6365),
    [anon_sym_real] = ACTIONS(6365),
    [anon_sym_realtime] = ACTIONS(6365),
    [anon_sym_supply0] = ACTIONS(6365),
    [anon_sym_supply1] = ACTIONS(6365),
    [anon_sym_signed] = ACTIONS(6365),
    [anon_sym_unsigned] = ACTIONS(6365),
    [anon_sym_task] = ACTIONS(6365),
    [anon_sym_assert] = ACTIONS(6365),
    [anon_sym_property] = ACTIONS(6365),
    [anon_sym_assume] = ACTIONS(6365),
    [anon_sym_cover] = ACTIONS(6365),
    [anon_sym_sequence] = ACTIONS(6365),
    [anon_sym_restrict] = ACTIONS(6365),
    [anon_sym_not] = ACTIONS(6365),
    [anon_sym_or] = ACTIONS(6365),
    [anon_sym_and] = ACTIONS(6365),
    [anon_sym_case] = ACTIONS(6365),
    [anon_sym_always] = ACTIONS(6365),
    [anon_sym_covergroup] = ACTIONS(6365),
    [anon_sym_let] = ACTIONS(6365),
    [anon_sym_pulldown] = ACTIONS(6365),
    [anon_sym_pullup] = ACTIONS(6365),
    [anon_sym_cmos] = ACTIONS(6365),
    [anon_sym_rcmos] = ACTIONS(6365),
    [anon_sym_bufif0] = ACTIONS(6365),
    [anon_sym_bufif1] = ACTIONS(6365),
    [anon_sym_notif0] = ACTIONS(6365),
    [anon_sym_notif1] = ACTIONS(6365),
    [anon_sym_nmos] = ACTIONS(6365),
    [anon_sym_pmos] = ACTIONS(6365),
    [anon_sym_rnmos] = ACTIONS(6365),
    [anon_sym_rpmos] = ACTIONS(6365),
    [anon_sym_nand] = ACTIONS(6365),
    [anon_sym_nor] = ACTIONS(6365),
    [anon_sym_xor] = ACTIONS(6365),
    [anon_sym_xnor] = ACTIONS(6365),
    [anon_sym_buf] = ACTIONS(6365),
    [anon_sym_tranif0] = ACTIONS(6365),
    [anon_sym_tranif1] = ACTIONS(6365),
    [anon_sym_rtranif1] = ACTIONS(6365),
    [anon_sym_rtranif0] = ACTIONS(6365),
    [anon_sym_tran] = ACTIONS(6365),
    [anon_sym_rtran] = ACTIONS(6365),
    [anon_sym_generate] = ACTIONS(6365),
    [anon_sym_endgenerate] = ACTIONS(6365),
    [anon_sym_for] = ACTIONS(6365),
    [anon_sym_initial] = ACTIONS(6365),
    [anon_sym_assign] = ACTIONS(6365),
    [anon_sym_alias] = ACTIONS(6365),
    [anon_sym_always_comb] = ACTIONS(6365),
    [anon_sym_always_latch] = ACTIONS(6365),
    [anon_sym_always_ff] = ACTIONS(6365),
    [anon_sym_final] = ACTIONS(6365),
    [anon_sym_global] = ACTIONS(6365),
    [anon_sym_LPAREN_STAR] = ACTIONS(6367),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6367),
    [anon_sym_DOLLARunit] = ACTIONS(6367),
  },
  [4414] = {
    [sym_simple_identifier] = ACTIONS(4624),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_COLON] = ACTIONS(10549),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_rand] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_endgenerate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [4415] = {
    [sym_simple_identifier] = ACTIONS(4212),
    [anon_sym_wire] = ACTIONS(4212),
    [anon_sym_tri] = ACTIONS(4212),
    [anon_sym_tri0] = ACTIONS(4212),
    [anon_sym_tri1] = ACTIONS(4212),
    [anon_sym_wand] = ACTIONS(4212),
    [anon_sym_triand] = ACTIONS(4212),
    [anon_sym_wor] = ACTIONS(4212),
    [anon_sym_trior] = ACTIONS(4212),
    [anon_sym_trireg] = ACTIONS(4212),
    [anon_sym_uwire] = ACTIONS(4212),
    [anon_sym_SEMI] = ACTIONS(4210),
    [anon_sym_COLON] = ACTIONS(10551),
    [anon_sym_extern] = ACTIONS(4212),
    [anon_sym_interface] = ACTIONS(4212),
    [anon_sym_checker] = ACTIONS(4212),
    [anon_sym_virtual] = ACTIONS(4212),
    [anon_sym_class] = ACTIONS(4212),
    [anon_sym_type] = ACTIONS(4212),
    [anon_sym_DOLLARfatal] = ACTIONS(4210),
    [anon_sym_DOLLARerror] = ACTIONS(4210),
    [anon_sym_DOLLARwarning] = ACTIONS(4210),
    [anon_sym_DOLLARinfo] = ACTIONS(4210),
    [anon_sym_default] = ACTIONS(4212),
    [anon_sym_clocking] = ACTIONS(4212),
    [anon_sym_defparam] = ACTIONS(4212),
    [anon_sym_bind] = ACTIONS(4212),
    [anon_sym_rand] = ACTIONS(4212),
    [anon_sym_const] = ACTIONS(4212),
    [anon_sym_function] = ACTIONS(4212),
    [anon_sym_static] = ACTIONS(4212),
    [anon_sym_constraint] = ACTIONS(4212),
    [anon_sym_if] = ACTIONS(4212),
    [anon_sym_else] = ACTIONS(4212),
    [anon_sym_LBRACK] = ACTIONS(4210),
    [anon_sym_localparam] = ACTIONS(4212),
    [anon_sym_parameter] = ACTIONS(4212),
    [anon_sym_var] = ACTIONS(4212),
    [anon_sym_import] = ACTIONS(4212),
    [anon_sym_export] = ACTIONS(4212),
    [anon_sym_genvar] = ACTIONS(4212),
    [anon_sym_interconnect] = ACTIONS(4212),
    [anon_sym_typedef] = ACTIONS(4212),
    [anon_sym_enum] = ACTIONS(4212),
    [anon_sym_struct] = ACTIONS(4212),
    [anon_sym_union] = ACTIONS(4212),
    [anon_sym_nettype] = ACTIONS(4212),
    [anon_sym_automatic] = ACTIONS(4212),
    [anon_sym_string] = ACTIONS(4212),
    [anon_sym_chandle] = ACTIONS(4212),
    [anon_sym_event] = ACTIONS(4212),
    [anon_sym_byte] = ACTIONS(4212),
    [anon_sym_shortint] = ACTIONS(4212),
    [anon_sym_int] = ACTIONS(4212),
    [anon_sym_longint] = ACTIONS(4212),
    [anon_sym_integer] = ACTIONS(4212),
    [anon_sym_time] = ACTIONS(4212),
    [anon_sym_bit] = ACTIONS(4212),
    [anon_sym_logic] = ACTIONS(4212),
    [anon_sym_reg] = ACTIONS(4212),
    [anon_sym_shortreal] = ACTIONS(4212),
    [anon_sym_real] = ACTIONS(4212),
    [anon_sym_realtime] = ACTIONS(4212),
    [anon_sym_supply0] = ACTIONS(4212),
    [anon_sym_supply1] = ACTIONS(4212),
    [anon_sym_signed] = ACTIONS(4212),
    [anon_sym_unsigned] = ACTIONS(4212),
    [anon_sym_task] = ACTIONS(4212),
    [anon_sym_assert] = ACTIONS(4212),
    [anon_sym_property] = ACTIONS(4212),
    [anon_sym_assume] = ACTIONS(4212),
    [anon_sym_cover] = ACTIONS(4212),
    [anon_sym_sequence] = ACTIONS(4212),
    [anon_sym_restrict] = ACTIONS(4212),
    [anon_sym_not] = ACTIONS(4212),
    [anon_sym_or] = ACTIONS(4212),
    [anon_sym_and] = ACTIONS(4212),
    [anon_sym_case] = ACTIONS(4212),
    [anon_sym_always] = ACTIONS(4212),
    [anon_sym_covergroup] = ACTIONS(4212),
    [anon_sym_let] = ACTIONS(4212),
    [anon_sym_pulldown] = ACTIONS(4212),
    [anon_sym_pullup] = ACTIONS(4212),
    [anon_sym_cmos] = ACTIONS(4212),
    [anon_sym_rcmos] = ACTIONS(4212),
    [anon_sym_bufif0] = ACTIONS(4212),
    [anon_sym_bufif1] = ACTIONS(4212),
    [anon_sym_notif0] = ACTIONS(4212),
    [anon_sym_notif1] = ACTIONS(4212),
    [anon_sym_nmos] = ACTIONS(4212),
    [anon_sym_pmos] = ACTIONS(4212),
    [anon_sym_rnmos] = ACTIONS(4212),
    [anon_sym_rpmos] = ACTIONS(4212),
    [anon_sym_nand] = ACTIONS(4212),
    [anon_sym_nor] = ACTIONS(4212),
    [anon_sym_xor] = ACTIONS(4212),
    [anon_sym_xnor] = ACTIONS(4212),
    [anon_sym_buf] = ACTIONS(4212),
    [anon_sym_tranif0] = ACTIONS(4212),
    [anon_sym_tranif1] = ACTIONS(4212),
    [anon_sym_rtranif1] = ACTIONS(4212),
    [anon_sym_rtranif0] = ACTIONS(4212),
    [anon_sym_tran] = ACTIONS(4212),
    [anon_sym_rtran] = ACTIONS(4212),
    [anon_sym_generate] = ACTIONS(4212),
    [anon_sym_endgenerate] = ACTIONS(4212),
    [anon_sym_for] = ACTIONS(4212),
    [anon_sym_initial] = ACTIONS(4212),
    [anon_sym_assign] = ACTIONS(4212),
    [anon_sym_alias] = ACTIONS(4212),
    [anon_sym_always_comb] = ACTIONS(4212),
    [anon_sym_always_latch] = ACTIONS(4212),
    [anon_sym_always_ff] = ACTIONS(4212),
    [anon_sym_final] = ACTIONS(4212),
    [anon_sym_global] = ACTIONS(4212),
    [anon_sym_LPAREN_STAR] = ACTIONS(4210),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4210),
    [anon_sym_DOLLARunit] = ACTIONS(4210),
  },
  [4416] = {
    [sym_simple_identifier] = ACTIONS(4588),
    [anon_sym_wire] = ACTIONS(4588),
    [anon_sym_tri] = ACTIONS(4588),
    [anon_sym_tri0] = ACTIONS(4588),
    [anon_sym_tri1] = ACTIONS(4588),
    [anon_sym_wand] = ACTIONS(4588),
    [anon_sym_triand] = ACTIONS(4588),
    [anon_sym_wor] = ACTIONS(4588),
    [anon_sym_trior] = ACTIONS(4588),
    [anon_sym_trireg] = ACTIONS(4588),
    [anon_sym_uwire] = ACTIONS(4588),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_COLON] = ACTIONS(10553),
    [anon_sym_extern] = ACTIONS(4588),
    [anon_sym_interface] = ACTIONS(4588),
    [anon_sym_checker] = ACTIONS(4588),
    [anon_sym_virtual] = ACTIONS(4588),
    [anon_sym_class] = ACTIONS(4588),
    [anon_sym_type] = ACTIONS(4588),
    [anon_sym_DOLLARfatal] = ACTIONS(4586),
    [anon_sym_DOLLARerror] = ACTIONS(4586),
    [anon_sym_DOLLARwarning] = ACTIONS(4586),
    [anon_sym_DOLLARinfo] = ACTIONS(4586),
    [anon_sym_default] = ACTIONS(4588),
    [anon_sym_clocking] = ACTIONS(4588),
    [anon_sym_defparam] = ACTIONS(4588),
    [anon_sym_bind] = ACTIONS(4588),
    [anon_sym_rand] = ACTIONS(4588),
    [anon_sym_const] = ACTIONS(4588),
    [anon_sym_function] = ACTIONS(4588),
    [anon_sym_static] = ACTIONS(4588),
    [anon_sym_constraint] = ACTIONS(4588),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [anon_sym_localparam] = ACTIONS(4588),
    [anon_sym_parameter] = ACTIONS(4588),
    [anon_sym_var] = ACTIONS(4588),
    [anon_sym_import] = ACTIONS(4588),
    [anon_sym_export] = ACTIONS(4588),
    [anon_sym_genvar] = ACTIONS(4588),
    [anon_sym_interconnect] = ACTIONS(4588),
    [anon_sym_typedef] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_struct] = ACTIONS(4588),
    [anon_sym_union] = ACTIONS(4588),
    [anon_sym_nettype] = ACTIONS(4588),
    [anon_sym_automatic] = ACTIONS(4588),
    [anon_sym_string] = ACTIONS(4588),
    [anon_sym_chandle] = ACTIONS(4588),
    [anon_sym_event] = ACTIONS(4588),
    [anon_sym_byte] = ACTIONS(4588),
    [anon_sym_shortint] = ACTIONS(4588),
    [anon_sym_int] = ACTIONS(4588),
    [anon_sym_longint] = ACTIONS(4588),
    [anon_sym_integer] = ACTIONS(4588),
    [anon_sym_time] = ACTIONS(4588),
    [anon_sym_bit] = ACTIONS(4588),
    [anon_sym_logic] = ACTIONS(4588),
    [anon_sym_reg] = ACTIONS(4588),
    [anon_sym_shortreal] = ACTIONS(4588),
    [anon_sym_real] = ACTIONS(4588),
    [anon_sym_realtime] = ACTIONS(4588),
    [anon_sym_supply0] = ACTIONS(4588),
    [anon_sym_supply1] = ACTIONS(4588),
    [anon_sym_signed] = ACTIONS(4588),
    [anon_sym_unsigned] = ACTIONS(4588),
    [anon_sym_task] = ACTIONS(4588),
    [anon_sym_assert] = ACTIONS(4588),
    [anon_sym_property] = ACTIONS(4588),
    [anon_sym_assume] = ACTIONS(4588),
    [anon_sym_cover] = ACTIONS(4588),
    [anon_sym_sequence] = ACTIONS(4588),
    [anon_sym_restrict] = ACTIONS(4588),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_or] = ACTIONS(4588),
    [anon_sym_and] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_always] = ACTIONS(4588),
    [anon_sym_covergroup] = ACTIONS(4588),
    [anon_sym_end] = ACTIONS(4588),
    [anon_sym_let] = ACTIONS(4588),
    [anon_sym_pulldown] = ACTIONS(4588),
    [anon_sym_pullup] = ACTIONS(4588),
    [anon_sym_cmos] = ACTIONS(4588),
    [anon_sym_rcmos] = ACTIONS(4588),
    [anon_sym_bufif0] = ACTIONS(4588),
    [anon_sym_bufif1] = ACTIONS(4588),
    [anon_sym_notif0] = ACTIONS(4588),
    [anon_sym_notif1] = ACTIONS(4588),
    [anon_sym_nmos] = ACTIONS(4588),
    [anon_sym_pmos] = ACTIONS(4588),
    [anon_sym_rnmos] = ACTIONS(4588),
    [anon_sym_rpmos] = ACTIONS(4588),
    [anon_sym_nand] = ACTIONS(4588),
    [anon_sym_nor] = ACTIONS(4588),
    [anon_sym_xor] = ACTIONS(4588),
    [anon_sym_xnor] = ACTIONS(4588),
    [anon_sym_buf] = ACTIONS(4588),
    [anon_sym_tranif0] = ACTIONS(4588),
    [anon_sym_tranif1] = ACTIONS(4588),
    [anon_sym_rtranif1] = ACTIONS(4588),
    [anon_sym_rtranif0] = ACTIONS(4588),
    [anon_sym_tran] = ACTIONS(4588),
    [anon_sym_rtran] = ACTIONS(4588),
    [anon_sym_generate] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_initial] = ACTIONS(4588),
    [anon_sym_assign] = ACTIONS(4588),
    [anon_sym_alias] = ACTIONS(4588),
    [anon_sym_always_comb] = ACTIONS(4588),
    [anon_sym_always_latch] = ACTIONS(4588),
    [anon_sym_always_ff] = ACTIONS(4588),
    [anon_sym_final] = ACTIONS(4588),
    [anon_sym_global] = ACTIONS(4588),
    [anon_sym_LPAREN_STAR] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4586),
    [anon_sym_DOLLARunit] = ACTIONS(4586),
  },
  [4417] = {
    [sym_simple_identifier] = ACTIONS(4218),
    [anon_sym_wire] = ACTIONS(4218),
    [anon_sym_tri] = ACTIONS(4218),
    [anon_sym_tri0] = ACTIONS(4218),
    [anon_sym_tri1] = ACTIONS(4218),
    [anon_sym_wand] = ACTIONS(4218),
    [anon_sym_triand] = ACTIONS(4218),
    [anon_sym_wor] = ACTIONS(4218),
    [anon_sym_trior] = ACTIONS(4218),
    [anon_sym_trireg] = ACTIONS(4218),
    [anon_sym_uwire] = ACTIONS(4218),
    [anon_sym_SEMI] = ACTIONS(4216),
    [anon_sym_COLON] = ACTIONS(10555),
    [anon_sym_extern] = ACTIONS(4218),
    [anon_sym_interface] = ACTIONS(4218),
    [anon_sym_checker] = ACTIONS(4218),
    [anon_sym_virtual] = ACTIONS(4218),
    [anon_sym_class] = ACTIONS(4218),
    [anon_sym_type] = ACTIONS(4218),
    [anon_sym_DOLLARfatal] = ACTIONS(4216),
    [anon_sym_DOLLARerror] = ACTIONS(4216),
    [anon_sym_DOLLARwarning] = ACTIONS(4216),
    [anon_sym_DOLLARinfo] = ACTIONS(4216),
    [anon_sym_default] = ACTIONS(4218),
    [anon_sym_clocking] = ACTIONS(4218),
    [anon_sym_defparam] = ACTIONS(4218),
    [anon_sym_bind] = ACTIONS(4218),
    [anon_sym_rand] = ACTIONS(4218),
    [anon_sym_const] = ACTIONS(4218),
    [anon_sym_function] = ACTIONS(4218),
    [anon_sym_static] = ACTIONS(4218),
    [anon_sym_constraint] = ACTIONS(4218),
    [anon_sym_if] = ACTIONS(4218),
    [anon_sym_else] = ACTIONS(4218),
    [anon_sym_LBRACK] = ACTIONS(4216),
    [anon_sym_localparam] = ACTIONS(4218),
    [anon_sym_parameter] = ACTIONS(4218),
    [anon_sym_var] = ACTIONS(4218),
    [anon_sym_import] = ACTIONS(4218),
    [anon_sym_export] = ACTIONS(4218),
    [anon_sym_genvar] = ACTIONS(4218),
    [anon_sym_interconnect] = ACTIONS(4218),
    [anon_sym_typedef] = ACTIONS(4218),
    [anon_sym_enum] = ACTIONS(4218),
    [anon_sym_struct] = ACTIONS(4218),
    [anon_sym_union] = ACTIONS(4218),
    [anon_sym_nettype] = ACTIONS(4218),
    [anon_sym_automatic] = ACTIONS(4218),
    [anon_sym_string] = ACTIONS(4218),
    [anon_sym_chandle] = ACTIONS(4218),
    [anon_sym_event] = ACTIONS(4218),
    [anon_sym_byte] = ACTIONS(4218),
    [anon_sym_shortint] = ACTIONS(4218),
    [anon_sym_int] = ACTIONS(4218),
    [anon_sym_longint] = ACTIONS(4218),
    [anon_sym_integer] = ACTIONS(4218),
    [anon_sym_time] = ACTIONS(4218),
    [anon_sym_bit] = ACTIONS(4218),
    [anon_sym_logic] = ACTIONS(4218),
    [anon_sym_reg] = ACTIONS(4218),
    [anon_sym_shortreal] = ACTIONS(4218),
    [anon_sym_real] = ACTIONS(4218),
    [anon_sym_realtime] = ACTIONS(4218),
    [anon_sym_supply0] = ACTIONS(4218),
    [anon_sym_supply1] = ACTIONS(4218),
    [anon_sym_signed] = ACTIONS(4218),
    [anon_sym_unsigned] = ACTIONS(4218),
    [anon_sym_task] = ACTIONS(4218),
    [anon_sym_assert] = ACTIONS(4218),
    [anon_sym_property] = ACTIONS(4218),
    [anon_sym_assume] = ACTIONS(4218),
    [anon_sym_cover] = ACTIONS(4218),
    [anon_sym_sequence] = ACTIONS(4218),
    [anon_sym_restrict] = ACTIONS(4218),
    [anon_sym_not] = ACTIONS(4218),
    [anon_sym_or] = ACTIONS(4218),
    [anon_sym_and] = ACTIONS(4218),
    [anon_sym_case] = ACTIONS(4218),
    [anon_sym_always] = ACTIONS(4218),
    [anon_sym_covergroup] = ACTIONS(4218),
    [anon_sym_let] = ACTIONS(4218),
    [anon_sym_pulldown] = ACTIONS(4218),
    [anon_sym_pullup] = ACTIONS(4218),
    [anon_sym_cmos] = ACTIONS(4218),
    [anon_sym_rcmos] = ACTIONS(4218),
    [anon_sym_bufif0] = ACTIONS(4218),
    [anon_sym_bufif1] = ACTIONS(4218),
    [anon_sym_notif0] = ACTIONS(4218),
    [anon_sym_notif1] = ACTIONS(4218),
    [anon_sym_nmos] = ACTIONS(4218),
    [anon_sym_pmos] = ACTIONS(4218),
    [anon_sym_rnmos] = ACTIONS(4218),
    [anon_sym_rpmos] = ACTIONS(4218),
    [anon_sym_nand] = ACTIONS(4218),
    [anon_sym_nor] = ACTIONS(4218),
    [anon_sym_xor] = ACTIONS(4218),
    [anon_sym_xnor] = ACTIONS(4218),
    [anon_sym_buf] = ACTIONS(4218),
    [anon_sym_tranif0] = ACTIONS(4218),
    [anon_sym_tranif1] = ACTIONS(4218),
    [anon_sym_rtranif1] = ACTIONS(4218),
    [anon_sym_rtranif0] = ACTIONS(4218),
    [anon_sym_tran] = ACTIONS(4218),
    [anon_sym_rtran] = ACTIONS(4218),
    [anon_sym_generate] = ACTIONS(4218),
    [anon_sym_endgenerate] = ACTIONS(4218),
    [anon_sym_for] = ACTIONS(4218),
    [anon_sym_initial] = ACTIONS(4218),
    [anon_sym_assign] = ACTIONS(4218),
    [anon_sym_alias] = ACTIONS(4218),
    [anon_sym_always_comb] = ACTIONS(4218),
    [anon_sym_always_latch] = ACTIONS(4218),
    [anon_sym_always_ff] = ACTIONS(4218),
    [anon_sym_final] = ACTIONS(4218),
    [anon_sym_global] = ACTIONS(4218),
    [anon_sym_LPAREN_STAR] = ACTIONS(4216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4216),
    [anon_sym_DOLLARunit] = ACTIONS(4216),
  },
  [4418] = {
    [sym_simple_identifier] = ACTIONS(4630),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_COLON] = ACTIONS(10557),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_rand] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_end] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [4419] = {
    [sym_simple_identifier] = ACTIONS(4588),
    [anon_sym_wire] = ACTIONS(4588),
    [anon_sym_tri] = ACTIONS(4588),
    [anon_sym_tri0] = ACTIONS(4588),
    [anon_sym_tri1] = ACTIONS(4588),
    [anon_sym_wand] = ACTIONS(4588),
    [anon_sym_triand] = ACTIONS(4588),
    [anon_sym_wor] = ACTIONS(4588),
    [anon_sym_trior] = ACTIONS(4588),
    [anon_sym_trireg] = ACTIONS(4588),
    [anon_sym_uwire] = ACTIONS(4588),
    [anon_sym_SEMI] = ACTIONS(4586),
    [anon_sym_COLON] = ACTIONS(10559),
    [anon_sym_extern] = ACTIONS(4588),
    [anon_sym_interface] = ACTIONS(4588),
    [anon_sym_checker] = ACTIONS(4588),
    [anon_sym_virtual] = ACTIONS(4588),
    [anon_sym_class] = ACTIONS(4588),
    [anon_sym_type] = ACTIONS(4588),
    [anon_sym_DOLLARfatal] = ACTIONS(4586),
    [anon_sym_DOLLARerror] = ACTIONS(4586),
    [anon_sym_DOLLARwarning] = ACTIONS(4586),
    [anon_sym_DOLLARinfo] = ACTIONS(4586),
    [anon_sym_default] = ACTIONS(4588),
    [anon_sym_clocking] = ACTIONS(4588),
    [anon_sym_defparam] = ACTIONS(4588),
    [anon_sym_bind] = ACTIONS(4588),
    [anon_sym_rand] = ACTIONS(4588),
    [anon_sym_const] = ACTIONS(4588),
    [anon_sym_function] = ACTIONS(4588),
    [anon_sym_static] = ACTIONS(4588),
    [anon_sym_constraint] = ACTIONS(4588),
    [anon_sym_if] = ACTIONS(4588),
    [anon_sym_else] = ACTIONS(4588),
    [anon_sym_LBRACK] = ACTIONS(4586),
    [anon_sym_localparam] = ACTIONS(4588),
    [anon_sym_parameter] = ACTIONS(4588),
    [anon_sym_var] = ACTIONS(4588),
    [anon_sym_import] = ACTIONS(4588),
    [anon_sym_export] = ACTIONS(4588),
    [anon_sym_genvar] = ACTIONS(4588),
    [anon_sym_interconnect] = ACTIONS(4588),
    [anon_sym_typedef] = ACTIONS(4588),
    [anon_sym_enum] = ACTIONS(4588),
    [anon_sym_struct] = ACTIONS(4588),
    [anon_sym_union] = ACTIONS(4588),
    [anon_sym_nettype] = ACTIONS(4588),
    [anon_sym_automatic] = ACTIONS(4588),
    [anon_sym_string] = ACTIONS(4588),
    [anon_sym_chandle] = ACTIONS(4588),
    [anon_sym_event] = ACTIONS(4588),
    [anon_sym_byte] = ACTIONS(4588),
    [anon_sym_shortint] = ACTIONS(4588),
    [anon_sym_int] = ACTIONS(4588),
    [anon_sym_longint] = ACTIONS(4588),
    [anon_sym_integer] = ACTIONS(4588),
    [anon_sym_time] = ACTIONS(4588),
    [anon_sym_bit] = ACTIONS(4588),
    [anon_sym_logic] = ACTIONS(4588),
    [anon_sym_reg] = ACTIONS(4588),
    [anon_sym_shortreal] = ACTIONS(4588),
    [anon_sym_real] = ACTIONS(4588),
    [anon_sym_realtime] = ACTIONS(4588),
    [anon_sym_supply0] = ACTIONS(4588),
    [anon_sym_supply1] = ACTIONS(4588),
    [anon_sym_signed] = ACTIONS(4588),
    [anon_sym_unsigned] = ACTIONS(4588),
    [anon_sym_task] = ACTIONS(4588),
    [anon_sym_assert] = ACTIONS(4588),
    [anon_sym_property] = ACTIONS(4588),
    [anon_sym_assume] = ACTIONS(4588),
    [anon_sym_cover] = ACTIONS(4588),
    [anon_sym_sequence] = ACTIONS(4588),
    [anon_sym_restrict] = ACTIONS(4588),
    [anon_sym_not] = ACTIONS(4588),
    [anon_sym_or] = ACTIONS(4588),
    [anon_sym_and] = ACTIONS(4588),
    [anon_sym_case] = ACTIONS(4588),
    [anon_sym_always] = ACTIONS(4588),
    [anon_sym_covergroup] = ACTIONS(4588),
    [anon_sym_let] = ACTIONS(4588),
    [anon_sym_pulldown] = ACTIONS(4588),
    [anon_sym_pullup] = ACTIONS(4588),
    [anon_sym_cmos] = ACTIONS(4588),
    [anon_sym_rcmos] = ACTIONS(4588),
    [anon_sym_bufif0] = ACTIONS(4588),
    [anon_sym_bufif1] = ACTIONS(4588),
    [anon_sym_notif0] = ACTIONS(4588),
    [anon_sym_notif1] = ACTIONS(4588),
    [anon_sym_nmos] = ACTIONS(4588),
    [anon_sym_pmos] = ACTIONS(4588),
    [anon_sym_rnmos] = ACTIONS(4588),
    [anon_sym_rpmos] = ACTIONS(4588),
    [anon_sym_nand] = ACTIONS(4588),
    [anon_sym_nor] = ACTIONS(4588),
    [anon_sym_xor] = ACTIONS(4588),
    [anon_sym_xnor] = ACTIONS(4588),
    [anon_sym_buf] = ACTIONS(4588),
    [anon_sym_tranif0] = ACTIONS(4588),
    [anon_sym_tranif1] = ACTIONS(4588),
    [anon_sym_rtranif1] = ACTIONS(4588),
    [anon_sym_rtranif0] = ACTIONS(4588),
    [anon_sym_tran] = ACTIONS(4588),
    [anon_sym_rtran] = ACTIONS(4588),
    [anon_sym_generate] = ACTIONS(4588),
    [anon_sym_endgenerate] = ACTIONS(4588),
    [anon_sym_for] = ACTIONS(4588),
    [anon_sym_initial] = ACTIONS(4588),
    [anon_sym_assign] = ACTIONS(4588),
    [anon_sym_alias] = ACTIONS(4588),
    [anon_sym_always_comb] = ACTIONS(4588),
    [anon_sym_always_latch] = ACTIONS(4588),
    [anon_sym_always_ff] = ACTIONS(4588),
    [anon_sym_final] = ACTIONS(4588),
    [anon_sym_global] = ACTIONS(4588),
    [anon_sym_LPAREN_STAR] = ACTIONS(4586),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4586),
    [anon_sym_DOLLARunit] = ACTIONS(4586),
  },
  [4420] = {
    [sym_simple_identifier] = ACTIONS(6475),
    [anon_sym_wire] = ACTIONS(6475),
    [anon_sym_tri] = ACTIONS(6475),
    [anon_sym_tri0] = ACTIONS(6475),
    [anon_sym_tri1] = ACTIONS(6475),
    [anon_sym_wand] = ACTIONS(6475),
    [anon_sym_triand] = ACTIONS(6475),
    [anon_sym_wor] = ACTIONS(6475),
    [anon_sym_trior] = ACTIONS(6475),
    [anon_sym_trireg] = ACTIONS(6475),
    [anon_sym_uwire] = ACTIONS(6475),
    [anon_sym_SEMI] = ACTIONS(6477),
    [anon_sym_extern] = ACTIONS(6475),
    [anon_sym_interface] = ACTIONS(6475),
    [anon_sym_checker] = ACTIONS(6475),
    [anon_sym_virtual] = ACTIONS(6475),
    [anon_sym_class] = ACTIONS(6475),
    [anon_sym_type] = ACTIONS(6475),
    [anon_sym_DOT] = ACTIONS(6477),
    [anon_sym_DOLLARfatal] = ACTIONS(6477),
    [anon_sym_DOLLARerror] = ACTIONS(6477),
    [anon_sym_DOLLARwarning] = ACTIONS(6477),
    [anon_sym_DOLLARinfo] = ACTIONS(6477),
    [anon_sym_default] = ACTIONS(6475),
    [anon_sym_clocking] = ACTIONS(6475),
    [anon_sym_defparam] = ACTIONS(6475),
    [anon_sym_bind] = ACTIONS(6475),
    [anon_sym_rand] = ACTIONS(6475),
    [anon_sym_const] = ACTIONS(6475),
    [anon_sym_function] = ACTIONS(6475),
    [anon_sym_static] = ACTIONS(6475),
    [anon_sym_constraint] = ACTIONS(6475),
    [anon_sym_if] = ACTIONS(6475),
    [anon_sym_else] = ACTIONS(6475),
    [anon_sym_LBRACK] = ACTIONS(6477),
    [anon_sym_localparam] = ACTIONS(6475),
    [anon_sym_parameter] = ACTIONS(6475),
    [anon_sym_var] = ACTIONS(6475),
    [anon_sym_import] = ACTIONS(6475),
    [anon_sym_export] = ACTIONS(6475),
    [anon_sym_genvar] = ACTIONS(6475),
    [anon_sym_interconnect] = ACTIONS(6475),
    [anon_sym_typedef] = ACTIONS(6475),
    [anon_sym_enum] = ACTIONS(6475),
    [anon_sym_struct] = ACTIONS(6475),
    [anon_sym_union] = ACTIONS(6475),
    [anon_sym_nettype] = ACTIONS(6475),
    [anon_sym_automatic] = ACTIONS(6475),
    [anon_sym_string] = ACTIONS(6475),
    [anon_sym_chandle] = ACTIONS(6475),
    [anon_sym_event] = ACTIONS(6475),
    [anon_sym_byte] = ACTIONS(6475),
    [anon_sym_shortint] = ACTIONS(6475),
    [anon_sym_int] = ACTIONS(6475),
    [anon_sym_longint] = ACTIONS(6475),
    [anon_sym_integer] = ACTIONS(6475),
    [anon_sym_time] = ACTIONS(6475),
    [anon_sym_bit] = ACTIONS(6475),
    [anon_sym_logic] = ACTIONS(6475),
    [anon_sym_reg] = ACTIONS(6475),
    [anon_sym_shortreal] = ACTIONS(6475),
    [anon_sym_real] = ACTIONS(6475),
    [anon_sym_realtime] = ACTIONS(6475),
    [anon_sym_supply0] = ACTIONS(6475),
    [anon_sym_supply1] = ACTIONS(6475),
    [anon_sym_signed] = ACTIONS(6475),
    [anon_sym_unsigned] = ACTIONS(6475),
    [anon_sym_task] = ACTIONS(6475),
    [anon_sym_assert] = ACTIONS(6475),
    [anon_sym_property] = ACTIONS(6475),
    [anon_sym_assume] = ACTIONS(6475),
    [anon_sym_cover] = ACTIONS(6475),
    [anon_sym_sequence] = ACTIONS(6475),
    [anon_sym_restrict] = ACTIONS(6475),
    [anon_sym_not] = ACTIONS(6475),
    [anon_sym_or] = ACTIONS(6475),
    [anon_sym_and] = ACTIONS(6475),
    [anon_sym_case] = ACTIONS(6475),
    [anon_sym_always] = ACTIONS(6475),
    [anon_sym_covergroup] = ACTIONS(6475),
    [anon_sym_end] = ACTIONS(6475),
    [anon_sym_let] = ACTIONS(6475),
    [anon_sym_pulldown] = ACTIONS(6475),
    [anon_sym_pullup] = ACTIONS(6475),
    [anon_sym_cmos] = ACTIONS(6475),
    [anon_sym_rcmos] = ACTIONS(6475),
    [anon_sym_bufif0] = ACTIONS(6475),
    [anon_sym_bufif1] = ACTIONS(6475),
    [anon_sym_notif0] = ACTIONS(6475),
    [anon_sym_notif1] = ACTIONS(6475),
    [anon_sym_nmos] = ACTIONS(6475),
    [anon_sym_pmos] = ACTIONS(6475),
    [anon_sym_rnmos] = ACTIONS(6475),
    [anon_sym_rpmos] = ACTIONS(6475),
    [anon_sym_nand] = ACTIONS(6475),
    [anon_sym_nor] = ACTIONS(6475),
    [anon_sym_xor] = ACTIONS(6475),
    [anon_sym_xnor] = ACTIONS(6475),
    [anon_sym_buf] = ACTIONS(6475),
    [anon_sym_tranif0] = ACTIONS(6475),
    [anon_sym_tranif1] = ACTIONS(6475),
    [anon_sym_rtranif1] = ACTIONS(6475),
    [anon_sym_rtranif0] = ACTIONS(6475),
    [anon_sym_tran] = ACTIONS(6475),
    [anon_sym_rtran] = ACTIONS(6475),
    [anon_sym_generate] = ACTIONS(6475),
    [anon_sym_for] = ACTIONS(6475),
    [anon_sym_initial] = ACTIONS(6475),
    [anon_sym_assign] = ACTIONS(6475),
    [anon_sym_alias] = ACTIONS(6475),
    [anon_sym_always_comb] = ACTIONS(6475),
    [anon_sym_always_latch] = ACTIONS(6475),
    [anon_sym_always_ff] = ACTIONS(6475),
    [anon_sym_final] = ACTIONS(6475),
    [anon_sym_global] = ACTIONS(6475),
    [anon_sym_LPAREN_STAR] = ACTIONS(6477),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6477),
    [anon_sym_DOLLARunit] = ACTIONS(6477),
  },
  [4421] = {
    [sym_simple_identifier] = ACTIONS(4646),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_COLON] = ACTIONS(10561),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_rand] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_end] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [4422] = {
    [sym_simple_identifier] = ACTIONS(4274),
    [anon_sym_wire] = ACTIONS(4274),
    [anon_sym_tri] = ACTIONS(4274),
    [anon_sym_tri0] = ACTIONS(4274),
    [anon_sym_tri1] = ACTIONS(4274),
    [anon_sym_wand] = ACTIONS(4274),
    [anon_sym_triand] = ACTIONS(4274),
    [anon_sym_wor] = ACTIONS(4274),
    [anon_sym_trior] = ACTIONS(4274),
    [anon_sym_trireg] = ACTIONS(4274),
    [anon_sym_uwire] = ACTIONS(4274),
    [anon_sym_SEMI] = ACTIONS(4272),
    [anon_sym_COLON] = ACTIONS(10563),
    [anon_sym_extern] = ACTIONS(4274),
    [anon_sym_interface] = ACTIONS(4274),
    [anon_sym_checker] = ACTIONS(4274),
    [anon_sym_virtual] = ACTIONS(4274),
    [anon_sym_class] = ACTIONS(4274),
    [anon_sym_type] = ACTIONS(4274),
    [anon_sym_DOLLARfatal] = ACTIONS(4272),
    [anon_sym_DOLLARerror] = ACTIONS(4272),
    [anon_sym_DOLLARwarning] = ACTIONS(4272),
    [anon_sym_DOLLARinfo] = ACTIONS(4272),
    [anon_sym_default] = ACTIONS(4274),
    [anon_sym_clocking] = ACTIONS(4274),
    [anon_sym_defparam] = ACTIONS(4274),
    [anon_sym_bind] = ACTIONS(4274),
    [anon_sym_rand] = ACTIONS(4274),
    [anon_sym_const] = ACTIONS(4274),
    [anon_sym_function] = ACTIONS(4274),
    [anon_sym_static] = ACTIONS(4274),
    [anon_sym_constraint] = ACTIONS(4274),
    [anon_sym_if] = ACTIONS(4274),
    [anon_sym_else] = ACTIONS(4274),
    [anon_sym_LBRACK] = ACTIONS(4272),
    [anon_sym_localparam] = ACTIONS(4274),
    [anon_sym_parameter] = ACTIONS(4274),
    [anon_sym_var] = ACTIONS(4274),
    [anon_sym_import] = ACTIONS(4274),
    [anon_sym_export] = ACTIONS(4274),
    [anon_sym_genvar] = ACTIONS(4274),
    [anon_sym_interconnect] = ACTIONS(4274),
    [anon_sym_typedef] = ACTIONS(4274),
    [anon_sym_enum] = ACTIONS(4274),
    [anon_sym_struct] = ACTIONS(4274),
    [anon_sym_union] = ACTIONS(4274),
    [anon_sym_nettype] = ACTIONS(4274),
    [anon_sym_automatic] = ACTIONS(4274),
    [anon_sym_string] = ACTIONS(4274),
    [anon_sym_chandle] = ACTIONS(4274),
    [anon_sym_event] = ACTIONS(4274),
    [anon_sym_byte] = ACTIONS(4274),
    [anon_sym_shortint] = ACTIONS(4274),
    [anon_sym_int] = ACTIONS(4274),
    [anon_sym_longint] = ACTIONS(4274),
    [anon_sym_integer] = ACTIONS(4274),
    [anon_sym_time] = ACTIONS(4274),
    [anon_sym_bit] = ACTIONS(4274),
    [anon_sym_logic] = ACTIONS(4274),
    [anon_sym_reg] = ACTIONS(4274),
    [anon_sym_shortreal] = ACTIONS(4274),
    [anon_sym_real] = ACTIONS(4274),
    [anon_sym_realtime] = ACTIONS(4274),
    [anon_sym_supply0] = ACTIONS(4274),
    [anon_sym_supply1] = ACTIONS(4274),
    [anon_sym_signed] = ACTIONS(4274),
    [anon_sym_unsigned] = ACTIONS(4274),
    [anon_sym_task] = ACTIONS(4274),
    [anon_sym_assert] = ACTIONS(4274),
    [anon_sym_property] = ACTIONS(4274),
    [anon_sym_assume] = ACTIONS(4274),
    [anon_sym_cover] = ACTIONS(4274),
    [anon_sym_sequence] = ACTIONS(4274),
    [anon_sym_restrict] = ACTIONS(4274),
    [anon_sym_not] = ACTIONS(4274),
    [anon_sym_or] = ACTIONS(4274),
    [anon_sym_and] = ACTIONS(4274),
    [anon_sym_case] = ACTIONS(4274),
    [anon_sym_always] = ACTIONS(4274),
    [anon_sym_covergroup] = ACTIONS(4274),
    [anon_sym_end] = ACTIONS(4274),
    [anon_sym_let] = ACTIONS(4274),
    [anon_sym_pulldown] = ACTIONS(4274),
    [anon_sym_pullup] = ACTIONS(4274),
    [anon_sym_cmos] = ACTIONS(4274),
    [anon_sym_rcmos] = ACTIONS(4274),
    [anon_sym_bufif0] = ACTIONS(4274),
    [anon_sym_bufif1] = ACTIONS(4274),
    [anon_sym_notif0] = ACTIONS(4274),
    [anon_sym_notif1] = ACTIONS(4274),
    [anon_sym_nmos] = ACTIONS(4274),
    [anon_sym_pmos] = ACTIONS(4274),
    [anon_sym_rnmos] = ACTIONS(4274),
    [anon_sym_rpmos] = ACTIONS(4274),
    [anon_sym_nand] = ACTIONS(4274),
    [anon_sym_nor] = ACTIONS(4274),
    [anon_sym_xor] = ACTIONS(4274),
    [anon_sym_xnor] = ACTIONS(4274),
    [anon_sym_buf] = ACTIONS(4274),
    [anon_sym_tranif0] = ACTIONS(4274),
    [anon_sym_tranif1] = ACTIONS(4274),
    [anon_sym_rtranif1] = ACTIONS(4274),
    [anon_sym_rtranif0] = ACTIONS(4274),
    [anon_sym_tran] = ACTIONS(4274),
    [anon_sym_rtran] = ACTIONS(4274),
    [anon_sym_generate] = ACTIONS(4274),
    [anon_sym_for] = ACTIONS(4274),
    [anon_sym_initial] = ACTIONS(4274),
    [anon_sym_assign] = ACTIONS(4274),
    [anon_sym_alias] = ACTIONS(4274),
    [anon_sym_always_comb] = ACTIONS(4274),
    [anon_sym_always_latch] = ACTIONS(4274),
    [anon_sym_always_ff] = ACTIONS(4274),
    [anon_sym_final] = ACTIONS(4274),
    [anon_sym_global] = ACTIONS(4274),
    [anon_sym_LPAREN_STAR] = ACTIONS(4272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4272),
    [anon_sym_DOLLARunit] = ACTIONS(4272),
  },
  [4423] = {
    [sym_simple_identifier] = ACTIONS(4248),
    [anon_sym_wire] = ACTIONS(4248),
    [anon_sym_tri] = ACTIONS(4248),
    [anon_sym_tri0] = ACTIONS(4248),
    [anon_sym_tri1] = ACTIONS(4248),
    [anon_sym_wand] = ACTIONS(4248),
    [anon_sym_triand] = ACTIONS(4248),
    [anon_sym_wor] = ACTIONS(4248),
    [anon_sym_trior] = ACTIONS(4248),
    [anon_sym_trireg] = ACTIONS(4248),
    [anon_sym_uwire] = ACTIONS(4248),
    [anon_sym_SEMI] = ACTIONS(4246),
    [anon_sym_COLON] = ACTIONS(10565),
    [anon_sym_extern] = ACTIONS(4248),
    [anon_sym_interface] = ACTIONS(4248),
    [anon_sym_checker] = ACTIONS(4248),
    [anon_sym_virtual] = ACTIONS(4248),
    [anon_sym_class] = ACTIONS(4248),
    [anon_sym_type] = ACTIONS(4248),
    [anon_sym_DOLLARfatal] = ACTIONS(4246),
    [anon_sym_DOLLARerror] = ACTIONS(4246),
    [anon_sym_DOLLARwarning] = ACTIONS(4246),
    [anon_sym_DOLLARinfo] = ACTIONS(4246),
    [anon_sym_default] = ACTIONS(4248),
    [anon_sym_clocking] = ACTIONS(4248),
    [anon_sym_defparam] = ACTIONS(4248),
    [anon_sym_bind] = ACTIONS(4248),
    [anon_sym_rand] = ACTIONS(4248),
    [anon_sym_const] = ACTIONS(4248),
    [anon_sym_function] = ACTIONS(4248),
    [anon_sym_static] = ACTIONS(4248),
    [anon_sym_constraint] = ACTIONS(4248),
    [anon_sym_if] = ACTIONS(4248),
    [anon_sym_else] = ACTIONS(4248),
    [anon_sym_LBRACK] = ACTIONS(4246),
    [anon_sym_localparam] = ACTIONS(4248),
    [anon_sym_parameter] = ACTIONS(4248),
    [anon_sym_var] = ACTIONS(4248),
    [anon_sym_import] = ACTIONS(4248),
    [anon_sym_export] = ACTIONS(4248),
    [anon_sym_genvar] = ACTIONS(4248),
    [anon_sym_interconnect] = ACTIONS(4248),
    [anon_sym_typedef] = ACTIONS(4248),
    [anon_sym_enum] = ACTIONS(4248),
    [anon_sym_struct] = ACTIONS(4248),
    [anon_sym_union] = ACTIONS(4248),
    [anon_sym_nettype] = ACTIONS(4248),
    [anon_sym_automatic] = ACTIONS(4248),
    [anon_sym_string] = ACTIONS(4248),
    [anon_sym_chandle] = ACTIONS(4248),
    [anon_sym_event] = ACTIONS(4248),
    [anon_sym_byte] = ACTIONS(4248),
    [anon_sym_shortint] = ACTIONS(4248),
    [anon_sym_int] = ACTIONS(4248),
    [anon_sym_longint] = ACTIONS(4248),
    [anon_sym_integer] = ACTIONS(4248),
    [anon_sym_time] = ACTIONS(4248),
    [anon_sym_bit] = ACTIONS(4248),
    [anon_sym_logic] = ACTIONS(4248),
    [anon_sym_reg] = ACTIONS(4248),
    [anon_sym_shortreal] = ACTIONS(4248),
    [anon_sym_real] = ACTIONS(4248),
    [anon_sym_realtime] = ACTIONS(4248),
    [anon_sym_supply0] = ACTIONS(4248),
    [anon_sym_supply1] = ACTIONS(4248),
    [anon_sym_signed] = ACTIONS(4248),
    [anon_sym_unsigned] = ACTIONS(4248),
    [anon_sym_task] = ACTIONS(4248),
    [anon_sym_assert] = ACTIONS(4248),
    [anon_sym_property] = ACTIONS(4248),
    [anon_sym_assume] = ACTIONS(4248),
    [anon_sym_cover] = ACTIONS(4248),
    [anon_sym_sequence] = ACTIONS(4248),
    [anon_sym_restrict] = ACTIONS(4248),
    [anon_sym_not] = ACTIONS(4248),
    [anon_sym_or] = ACTIONS(4248),
    [anon_sym_and] = ACTIONS(4248),
    [anon_sym_case] = ACTIONS(4248),
    [anon_sym_always] = ACTIONS(4248),
    [anon_sym_covergroup] = ACTIONS(4248),
    [anon_sym_let] = ACTIONS(4248),
    [anon_sym_pulldown] = ACTIONS(4248),
    [anon_sym_pullup] = ACTIONS(4248),
    [anon_sym_cmos] = ACTIONS(4248),
    [anon_sym_rcmos] = ACTIONS(4248),
    [anon_sym_bufif0] = ACTIONS(4248),
    [anon_sym_bufif1] = ACTIONS(4248),
    [anon_sym_notif0] = ACTIONS(4248),
    [anon_sym_notif1] = ACTIONS(4248),
    [anon_sym_nmos] = ACTIONS(4248),
    [anon_sym_pmos] = ACTIONS(4248),
    [anon_sym_rnmos] = ACTIONS(4248),
    [anon_sym_rpmos] = ACTIONS(4248),
    [anon_sym_nand] = ACTIONS(4248),
    [anon_sym_nor] = ACTIONS(4248),
    [anon_sym_xor] = ACTIONS(4248),
    [anon_sym_xnor] = ACTIONS(4248),
    [anon_sym_buf] = ACTIONS(4248),
    [anon_sym_tranif0] = ACTIONS(4248),
    [anon_sym_tranif1] = ACTIONS(4248),
    [anon_sym_rtranif1] = ACTIONS(4248),
    [anon_sym_rtranif0] = ACTIONS(4248),
    [anon_sym_tran] = ACTIONS(4248),
    [anon_sym_rtran] = ACTIONS(4248),
    [anon_sym_generate] = ACTIONS(4248),
    [anon_sym_endgenerate] = ACTIONS(4248),
    [anon_sym_for] = ACTIONS(4248),
    [anon_sym_initial] = ACTIONS(4248),
    [anon_sym_assign] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4248),
    [anon_sym_always_comb] = ACTIONS(4248),
    [anon_sym_always_latch] = ACTIONS(4248),
    [anon_sym_always_ff] = ACTIONS(4248),
    [anon_sym_final] = ACTIONS(4248),
    [anon_sym_global] = ACTIONS(4248),
    [anon_sym_LPAREN_STAR] = ACTIONS(4246),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4246),
    [anon_sym_DOLLARunit] = ACTIONS(4246),
  },
  [4424] = {
    [sym_simple_identifier] = ACTIONS(4472),
    [anon_sym_wire] = ACTIONS(4472),
    [anon_sym_tri] = ACTIONS(4472),
    [anon_sym_tri0] = ACTIONS(4472),
    [anon_sym_tri1] = ACTIONS(4472),
    [anon_sym_wand] = ACTIONS(4472),
    [anon_sym_triand] = ACTIONS(4472),
    [anon_sym_wor] = ACTIONS(4472),
    [anon_sym_trior] = ACTIONS(4472),
    [anon_sym_trireg] = ACTIONS(4472),
    [anon_sym_uwire] = ACTIONS(4472),
    [anon_sym_SEMI] = ACTIONS(4470),
    [anon_sym_COLON] = ACTIONS(10567),
    [anon_sym_extern] = ACTIONS(4472),
    [anon_sym_interface] = ACTIONS(4472),
    [anon_sym_checker] = ACTIONS(4472),
    [anon_sym_virtual] = ACTIONS(4472),
    [anon_sym_class] = ACTIONS(4472),
    [anon_sym_type] = ACTIONS(4472),
    [anon_sym_DOLLARfatal] = ACTIONS(4470),
    [anon_sym_DOLLARerror] = ACTIONS(4470),
    [anon_sym_DOLLARwarning] = ACTIONS(4470),
    [anon_sym_DOLLARinfo] = ACTIONS(4470),
    [anon_sym_default] = ACTIONS(4472),
    [anon_sym_clocking] = ACTIONS(4472),
    [anon_sym_defparam] = ACTIONS(4472),
    [anon_sym_bind] = ACTIONS(4472),
    [anon_sym_rand] = ACTIONS(4472),
    [anon_sym_const] = ACTIONS(4472),
    [anon_sym_function] = ACTIONS(4472),
    [anon_sym_static] = ACTIONS(4472),
    [anon_sym_constraint] = ACTIONS(4472),
    [anon_sym_if] = ACTIONS(4472),
    [anon_sym_else] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4470),
    [anon_sym_localparam] = ACTIONS(4472),
    [anon_sym_parameter] = ACTIONS(4472),
    [anon_sym_var] = ACTIONS(4472),
    [anon_sym_import] = ACTIONS(4472),
    [anon_sym_export] = ACTIONS(4472),
    [anon_sym_genvar] = ACTIONS(4472),
    [anon_sym_interconnect] = ACTIONS(4472),
    [anon_sym_typedef] = ACTIONS(4472),
    [anon_sym_enum] = ACTIONS(4472),
    [anon_sym_struct] = ACTIONS(4472),
    [anon_sym_union] = ACTIONS(4472),
    [anon_sym_nettype] = ACTIONS(4472),
    [anon_sym_automatic] = ACTIONS(4472),
    [anon_sym_string] = ACTIONS(4472),
    [anon_sym_chandle] = ACTIONS(4472),
    [anon_sym_event] = ACTIONS(4472),
    [anon_sym_byte] = ACTIONS(4472),
    [anon_sym_shortint] = ACTIONS(4472),
    [anon_sym_int] = ACTIONS(4472),
    [anon_sym_longint] = ACTIONS(4472),
    [anon_sym_integer] = ACTIONS(4472),
    [anon_sym_time] = ACTIONS(4472),
    [anon_sym_bit] = ACTIONS(4472),
    [anon_sym_logic] = ACTIONS(4472),
    [anon_sym_reg] = ACTIONS(4472),
    [anon_sym_shortreal] = ACTIONS(4472),
    [anon_sym_real] = ACTIONS(4472),
    [anon_sym_realtime] = ACTIONS(4472),
    [anon_sym_supply0] = ACTIONS(4472),
    [anon_sym_supply1] = ACTIONS(4472),
    [anon_sym_signed] = ACTIONS(4472),
    [anon_sym_unsigned] = ACTIONS(4472),
    [anon_sym_task] = ACTIONS(4472),
    [anon_sym_assert] = ACTIONS(4472),
    [anon_sym_property] = ACTIONS(4472),
    [anon_sym_assume] = ACTIONS(4472),
    [anon_sym_cover] = ACTIONS(4472),
    [anon_sym_sequence] = ACTIONS(4472),
    [anon_sym_restrict] = ACTIONS(4472),
    [anon_sym_not] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_case] = ACTIONS(4472),
    [anon_sym_always] = ACTIONS(4472),
    [anon_sym_covergroup] = ACTIONS(4472),
    [anon_sym_end] = ACTIONS(4472),
    [anon_sym_let] = ACTIONS(4472),
    [anon_sym_pulldown] = ACTIONS(4472),
    [anon_sym_pullup] = ACTIONS(4472),
    [anon_sym_cmos] = ACTIONS(4472),
    [anon_sym_rcmos] = ACTIONS(4472),
    [anon_sym_bufif0] = ACTIONS(4472),
    [anon_sym_bufif1] = ACTIONS(4472),
    [anon_sym_notif0] = ACTIONS(4472),
    [anon_sym_notif1] = ACTIONS(4472),
    [anon_sym_nmos] = ACTIONS(4472),
    [anon_sym_pmos] = ACTIONS(4472),
    [anon_sym_rnmos] = ACTIONS(4472),
    [anon_sym_rpmos] = ACTIONS(4472),
    [anon_sym_nand] = ACTIONS(4472),
    [anon_sym_nor] = ACTIONS(4472),
    [anon_sym_xor] = ACTIONS(4472),
    [anon_sym_xnor] = ACTIONS(4472),
    [anon_sym_buf] = ACTIONS(4472),
    [anon_sym_tranif0] = ACTIONS(4472),
    [anon_sym_tranif1] = ACTIONS(4472),
    [anon_sym_rtranif1] = ACTIONS(4472),
    [anon_sym_rtranif0] = ACTIONS(4472),
    [anon_sym_tran] = ACTIONS(4472),
    [anon_sym_rtran] = ACTIONS(4472),
    [anon_sym_generate] = ACTIONS(4472),
    [anon_sym_for] = ACTIONS(4472),
    [anon_sym_initial] = ACTIONS(4472),
    [anon_sym_assign] = ACTIONS(4472),
    [anon_sym_alias] = ACTIONS(4472),
    [anon_sym_always_comb] = ACTIONS(4472),
    [anon_sym_always_latch] = ACTIONS(4472),
    [anon_sym_always_ff] = ACTIONS(4472),
    [anon_sym_final] = ACTIONS(4472),
    [anon_sym_global] = ACTIONS(4472),
    [anon_sym_LPAREN_STAR] = ACTIONS(4470),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4470),
    [anon_sym_DOLLARunit] = ACTIONS(4470),
  },
  [4425] = {
    [sym_simple_identifier] = ACTIONS(4800),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_COLON] = ACTIONS(10569),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_rand] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_end] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [4426] = {
    [sym_simple_identifier] = ACTIONS(4254),
    [anon_sym_wire] = ACTIONS(4254),
    [anon_sym_tri] = ACTIONS(4254),
    [anon_sym_tri0] = ACTIONS(4254),
    [anon_sym_tri1] = ACTIONS(4254),
    [anon_sym_wand] = ACTIONS(4254),
    [anon_sym_triand] = ACTIONS(4254),
    [anon_sym_wor] = ACTIONS(4254),
    [anon_sym_trior] = ACTIONS(4254),
    [anon_sym_trireg] = ACTIONS(4254),
    [anon_sym_uwire] = ACTIONS(4254),
    [anon_sym_SEMI] = ACTIONS(4252),
    [anon_sym_COLON] = ACTIONS(10571),
    [anon_sym_extern] = ACTIONS(4254),
    [anon_sym_interface] = ACTIONS(4254),
    [anon_sym_checker] = ACTIONS(4254),
    [anon_sym_virtual] = ACTIONS(4254),
    [anon_sym_class] = ACTIONS(4254),
    [anon_sym_type] = ACTIONS(4254),
    [anon_sym_DOLLARfatal] = ACTIONS(4252),
    [anon_sym_DOLLARerror] = ACTIONS(4252),
    [anon_sym_DOLLARwarning] = ACTIONS(4252),
    [anon_sym_DOLLARinfo] = ACTIONS(4252),
    [anon_sym_default] = ACTIONS(4254),
    [anon_sym_clocking] = ACTIONS(4254),
    [anon_sym_defparam] = ACTIONS(4254),
    [anon_sym_bind] = ACTIONS(4254),
    [anon_sym_rand] = ACTIONS(4254),
    [anon_sym_const] = ACTIONS(4254),
    [anon_sym_function] = ACTIONS(4254),
    [anon_sym_static] = ACTIONS(4254),
    [anon_sym_constraint] = ACTIONS(4254),
    [anon_sym_if] = ACTIONS(4254),
    [anon_sym_else] = ACTIONS(4254),
    [anon_sym_LBRACK] = ACTIONS(4252),
    [anon_sym_localparam] = ACTIONS(4254),
    [anon_sym_parameter] = ACTIONS(4254),
    [anon_sym_var] = ACTIONS(4254),
    [anon_sym_import] = ACTIONS(4254),
    [anon_sym_export] = ACTIONS(4254),
    [anon_sym_genvar] = ACTIONS(4254),
    [anon_sym_interconnect] = ACTIONS(4254),
    [anon_sym_typedef] = ACTIONS(4254),
    [anon_sym_enum] = ACTIONS(4254),
    [anon_sym_struct] = ACTIONS(4254),
    [anon_sym_union] = ACTIONS(4254),
    [anon_sym_nettype] = ACTIONS(4254),
    [anon_sym_automatic] = ACTIONS(4254),
    [anon_sym_string] = ACTIONS(4254),
    [anon_sym_chandle] = ACTIONS(4254),
    [anon_sym_event] = ACTIONS(4254),
    [anon_sym_byte] = ACTIONS(4254),
    [anon_sym_shortint] = ACTIONS(4254),
    [anon_sym_int] = ACTIONS(4254),
    [anon_sym_longint] = ACTIONS(4254),
    [anon_sym_integer] = ACTIONS(4254),
    [anon_sym_time] = ACTIONS(4254),
    [anon_sym_bit] = ACTIONS(4254),
    [anon_sym_logic] = ACTIONS(4254),
    [anon_sym_reg] = ACTIONS(4254),
    [anon_sym_shortreal] = ACTIONS(4254),
    [anon_sym_real] = ACTIONS(4254),
    [anon_sym_realtime] = ACTIONS(4254),
    [anon_sym_supply0] = ACTIONS(4254),
    [anon_sym_supply1] = ACTIONS(4254),
    [anon_sym_signed] = ACTIONS(4254),
    [anon_sym_unsigned] = ACTIONS(4254),
    [anon_sym_task] = ACTIONS(4254),
    [anon_sym_assert] = ACTIONS(4254),
    [anon_sym_property] = ACTIONS(4254),
    [anon_sym_assume] = ACTIONS(4254),
    [anon_sym_cover] = ACTIONS(4254),
    [anon_sym_sequence] = ACTIONS(4254),
    [anon_sym_restrict] = ACTIONS(4254),
    [anon_sym_not] = ACTIONS(4254),
    [anon_sym_or] = ACTIONS(4254),
    [anon_sym_and] = ACTIONS(4254),
    [anon_sym_case] = ACTIONS(4254),
    [anon_sym_always] = ACTIONS(4254),
    [anon_sym_covergroup] = ACTIONS(4254),
    [anon_sym_end] = ACTIONS(4254),
    [anon_sym_let] = ACTIONS(4254),
    [anon_sym_pulldown] = ACTIONS(4254),
    [anon_sym_pullup] = ACTIONS(4254),
    [anon_sym_cmos] = ACTIONS(4254),
    [anon_sym_rcmos] = ACTIONS(4254),
    [anon_sym_bufif0] = ACTIONS(4254),
    [anon_sym_bufif1] = ACTIONS(4254),
    [anon_sym_notif0] = ACTIONS(4254),
    [anon_sym_notif1] = ACTIONS(4254),
    [anon_sym_nmos] = ACTIONS(4254),
    [anon_sym_pmos] = ACTIONS(4254),
    [anon_sym_rnmos] = ACTIONS(4254),
    [anon_sym_rpmos] = ACTIONS(4254),
    [anon_sym_nand] = ACTIONS(4254),
    [anon_sym_nor] = ACTIONS(4254),
    [anon_sym_xor] = ACTIONS(4254),
    [anon_sym_xnor] = ACTIONS(4254),
    [anon_sym_buf] = ACTIONS(4254),
    [anon_sym_tranif0] = ACTIONS(4254),
    [anon_sym_tranif1] = ACTIONS(4254),
    [anon_sym_rtranif1] = ACTIONS(4254),
    [anon_sym_rtranif0] = ACTIONS(4254),
    [anon_sym_tran] = ACTIONS(4254),
    [anon_sym_rtran] = ACTIONS(4254),
    [anon_sym_generate] = ACTIONS(4254),
    [anon_sym_for] = ACTIONS(4254),
    [anon_sym_initial] = ACTIONS(4254),
    [anon_sym_assign] = ACTIONS(4254),
    [anon_sym_alias] = ACTIONS(4254),
    [anon_sym_always_comb] = ACTIONS(4254),
    [anon_sym_always_latch] = ACTIONS(4254),
    [anon_sym_always_ff] = ACTIONS(4254),
    [anon_sym_final] = ACTIONS(4254),
    [anon_sym_global] = ACTIONS(4254),
    [anon_sym_LPAREN_STAR] = ACTIONS(4252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4252),
    [anon_sym_DOLLARunit] = ACTIONS(4252),
  },
  [4427] = {
    [sym_simple_identifier] = ACTIONS(4264),
    [anon_sym_wire] = ACTIONS(4264),
    [anon_sym_tri] = ACTIONS(4264),
    [anon_sym_tri0] = ACTIONS(4264),
    [anon_sym_tri1] = ACTIONS(4264),
    [anon_sym_wand] = ACTIONS(4264),
    [anon_sym_triand] = ACTIONS(4264),
    [anon_sym_wor] = ACTIONS(4264),
    [anon_sym_trior] = ACTIONS(4264),
    [anon_sym_trireg] = ACTIONS(4264),
    [anon_sym_uwire] = ACTIONS(4264),
    [anon_sym_SEMI] = ACTIONS(4262),
    [anon_sym_COLON] = ACTIONS(10573),
    [anon_sym_extern] = ACTIONS(4264),
    [anon_sym_interface] = ACTIONS(4264),
    [anon_sym_checker] = ACTIONS(4264),
    [anon_sym_virtual] = ACTIONS(4264),
    [anon_sym_class] = ACTIONS(4264),
    [anon_sym_type] = ACTIONS(4264),
    [anon_sym_DOLLARfatal] = ACTIONS(4262),
    [anon_sym_DOLLARerror] = ACTIONS(4262),
    [anon_sym_DOLLARwarning] = ACTIONS(4262),
    [anon_sym_DOLLARinfo] = ACTIONS(4262),
    [anon_sym_default] = ACTIONS(4264),
    [anon_sym_clocking] = ACTIONS(4264),
    [anon_sym_defparam] = ACTIONS(4264),
    [anon_sym_bind] = ACTIONS(4264),
    [anon_sym_rand] = ACTIONS(4264),
    [anon_sym_const] = ACTIONS(4264),
    [anon_sym_function] = ACTIONS(4264),
    [anon_sym_static] = ACTIONS(4264),
    [anon_sym_constraint] = ACTIONS(4264),
    [anon_sym_if] = ACTIONS(4264),
    [anon_sym_else] = ACTIONS(4264),
    [anon_sym_LBRACK] = ACTIONS(4262),
    [anon_sym_localparam] = ACTIONS(4264),
    [anon_sym_parameter] = ACTIONS(4264),
    [anon_sym_var] = ACTIONS(4264),
    [anon_sym_import] = ACTIONS(4264),
    [anon_sym_export] = ACTIONS(4264),
    [anon_sym_genvar] = ACTIONS(4264),
    [anon_sym_interconnect] = ACTIONS(4264),
    [anon_sym_typedef] = ACTIONS(4264),
    [anon_sym_enum] = ACTIONS(4264),
    [anon_sym_struct] = ACTIONS(4264),
    [anon_sym_union] = ACTIONS(4264),
    [anon_sym_nettype] = ACTIONS(4264),
    [anon_sym_automatic] = ACTIONS(4264),
    [anon_sym_string] = ACTIONS(4264),
    [anon_sym_chandle] = ACTIONS(4264),
    [anon_sym_event] = ACTIONS(4264),
    [anon_sym_byte] = ACTIONS(4264),
    [anon_sym_shortint] = ACTIONS(4264),
    [anon_sym_int] = ACTIONS(4264),
    [anon_sym_longint] = ACTIONS(4264),
    [anon_sym_integer] = ACTIONS(4264),
    [anon_sym_time] = ACTIONS(4264),
    [anon_sym_bit] = ACTIONS(4264),
    [anon_sym_logic] = ACTIONS(4264),
    [anon_sym_reg] = ACTIONS(4264),
    [anon_sym_shortreal] = ACTIONS(4264),
    [anon_sym_real] = ACTIONS(4264),
    [anon_sym_realtime] = ACTIONS(4264),
    [anon_sym_supply0] = ACTIONS(4264),
    [anon_sym_supply1] = ACTIONS(4264),
    [anon_sym_signed] = ACTIONS(4264),
    [anon_sym_unsigned] = ACTIONS(4264),
    [anon_sym_task] = ACTIONS(4264),
    [anon_sym_assert] = ACTIONS(4264),
    [anon_sym_property] = ACTIONS(4264),
    [anon_sym_assume] = ACTIONS(4264),
    [anon_sym_cover] = ACTIONS(4264),
    [anon_sym_sequence] = ACTIONS(4264),
    [anon_sym_restrict] = ACTIONS(4264),
    [anon_sym_not] = ACTIONS(4264),
    [anon_sym_or] = ACTIONS(4264),
    [anon_sym_and] = ACTIONS(4264),
    [anon_sym_case] = ACTIONS(4264),
    [anon_sym_always] = ACTIONS(4264),
    [anon_sym_covergroup] = ACTIONS(4264),
    [anon_sym_end] = ACTIONS(4264),
    [anon_sym_let] = ACTIONS(4264),
    [anon_sym_pulldown] = ACTIONS(4264),
    [anon_sym_pullup] = ACTIONS(4264),
    [anon_sym_cmos] = ACTIONS(4264),
    [anon_sym_rcmos] = ACTIONS(4264),
    [anon_sym_bufif0] = ACTIONS(4264),
    [anon_sym_bufif1] = ACTIONS(4264),
    [anon_sym_notif0] = ACTIONS(4264),
    [anon_sym_notif1] = ACTIONS(4264),
    [anon_sym_nmos] = ACTIONS(4264),
    [anon_sym_pmos] = ACTIONS(4264),
    [anon_sym_rnmos] = ACTIONS(4264),
    [anon_sym_rpmos] = ACTIONS(4264),
    [anon_sym_nand] = ACTIONS(4264),
    [anon_sym_nor] = ACTIONS(4264),
    [anon_sym_xor] = ACTIONS(4264),
    [anon_sym_xnor] = ACTIONS(4264),
    [anon_sym_buf] = ACTIONS(4264),
    [anon_sym_tranif0] = ACTIONS(4264),
    [anon_sym_tranif1] = ACTIONS(4264),
    [anon_sym_rtranif1] = ACTIONS(4264),
    [anon_sym_rtranif0] = ACTIONS(4264),
    [anon_sym_tran] = ACTIONS(4264),
    [anon_sym_rtran] = ACTIONS(4264),
    [anon_sym_generate] = ACTIONS(4264),
    [anon_sym_for] = ACTIONS(4264),
    [anon_sym_initial] = ACTIONS(4264),
    [anon_sym_assign] = ACTIONS(4264),
    [anon_sym_alias] = ACTIONS(4264),
    [anon_sym_always_comb] = ACTIONS(4264),
    [anon_sym_always_latch] = ACTIONS(4264),
    [anon_sym_always_ff] = ACTIONS(4264),
    [anon_sym_final] = ACTIONS(4264),
    [anon_sym_global] = ACTIONS(4264),
    [anon_sym_LPAREN_STAR] = ACTIONS(4262),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4262),
    [anon_sym_DOLLARunit] = ACTIONS(4262),
  },
  [4428] = {
    [sym_simple_identifier] = ACTIONS(4304),
    [anon_sym_wire] = ACTIONS(4304),
    [anon_sym_tri] = ACTIONS(4304),
    [anon_sym_tri0] = ACTIONS(4304),
    [anon_sym_tri1] = ACTIONS(4304),
    [anon_sym_wand] = ACTIONS(4304),
    [anon_sym_triand] = ACTIONS(4304),
    [anon_sym_wor] = ACTIONS(4304),
    [anon_sym_trior] = ACTIONS(4304),
    [anon_sym_trireg] = ACTIONS(4304),
    [anon_sym_uwire] = ACTIONS(4304),
    [anon_sym_SEMI] = ACTIONS(4302),
    [anon_sym_COLON] = ACTIONS(10575),
    [anon_sym_extern] = ACTIONS(4304),
    [anon_sym_interface] = ACTIONS(4304),
    [anon_sym_checker] = ACTIONS(4304),
    [anon_sym_virtual] = ACTIONS(4304),
    [anon_sym_class] = ACTIONS(4304),
    [anon_sym_type] = ACTIONS(4304),
    [anon_sym_DOLLARfatal] = ACTIONS(4302),
    [anon_sym_DOLLARerror] = ACTIONS(4302),
    [anon_sym_DOLLARwarning] = ACTIONS(4302),
    [anon_sym_DOLLARinfo] = ACTIONS(4302),
    [anon_sym_default] = ACTIONS(4304),
    [anon_sym_clocking] = ACTIONS(4304),
    [anon_sym_defparam] = ACTIONS(4304),
    [anon_sym_bind] = ACTIONS(4304),
    [anon_sym_rand] = ACTIONS(4304),
    [anon_sym_const] = ACTIONS(4304),
    [anon_sym_function] = ACTIONS(4304),
    [anon_sym_static] = ACTIONS(4304),
    [anon_sym_constraint] = ACTIONS(4304),
    [anon_sym_if] = ACTIONS(4304),
    [anon_sym_else] = ACTIONS(4304),
    [anon_sym_LBRACK] = ACTIONS(4302),
    [anon_sym_localparam] = ACTIONS(4304),
    [anon_sym_parameter] = ACTIONS(4304),
    [anon_sym_var] = ACTIONS(4304),
    [anon_sym_import] = ACTIONS(4304),
    [anon_sym_export] = ACTIONS(4304),
    [anon_sym_genvar] = ACTIONS(4304),
    [anon_sym_interconnect] = ACTIONS(4304),
    [anon_sym_typedef] = ACTIONS(4304),
    [anon_sym_enum] = ACTIONS(4304),
    [anon_sym_struct] = ACTIONS(4304),
    [anon_sym_union] = ACTIONS(4304),
    [anon_sym_nettype] = ACTIONS(4304),
    [anon_sym_automatic] = ACTIONS(4304),
    [anon_sym_string] = ACTIONS(4304),
    [anon_sym_chandle] = ACTIONS(4304),
    [anon_sym_event] = ACTIONS(4304),
    [anon_sym_byte] = ACTIONS(4304),
    [anon_sym_shortint] = ACTIONS(4304),
    [anon_sym_int] = ACTIONS(4304),
    [anon_sym_longint] = ACTIONS(4304),
    [anon_sym_integer] = ACTIONS(4304),
    [anon_sym_time] = ACTIONS(4304),
    [anon_sym_bit] = ACTIONS(4304),
    [anon_sym_logic] = ACTIONS(4304),
    [anon_sym_reg] = ACTIONS(4304),
    [anon_sym_shortreal] = ACTIONS(4304),
    [anon_sym_real] = ACTIONS(4304),
    [anon_sym_realtime] = ACTIONS(4304),
    [anon_sym_supply0] = ACTIONS(4304),
    [anon_sym_supply1] = ACTIONS(4304),
    [anon_sym_signed] = ACTIONS(4304),
    [anon_sym_unsigned] = ACTIONS(4304),
    [anon_sym_task] = ACTIONS(4304),
    [anon_sym_assert] = ACTIONS(4304),
    [anon_sym_property] = ACTIONS(4304),
    [anon_sym_assume] = ACTIONS(4304),
    [anon_sym_cover] = ACTIONS(4304),
    [anon_sym_sequence] = ACTIONS(4304),
    [anon_sym_restrict] = ACTIONS(4304),
    [anon_sym_not] = ACTIONS(4304),
    [anon_sym_or] = ACTIONS(4304),
    [anon_sym_and] = ACTIONS(4304),
    [anon_sym_case] = ACTIONS(4304),
    [anon_sym_always] = ACTIONS(4304),
    [anon_sym_covergroup] = ACTIONS(4304),
    [anon_sym_end] = ACTIONS(4304),
    [anon_sym_let] = ACTIONS(4304),
    [anon_sym_pulldown] = ACTIONS(4304),
    [anon_sym_pullup] = ACTIONS(4304),
    [anon_sym_cmos] = ACTIONS(4304),
    [anon_sym_rcmos] = ACTIONS(4304),
    [anon_sym_bufif0] = ACTIONS(4304),
    [anon_sym_bufif1] = ACTIONS(4304),
    [anon_sym_notif0] = ACTIONS(4304),
    [anon_sym_notif1] = ACTIONS(4304),
    [anon_sym_nmos] = ACTIONS(4304),
    [anon_sym_pmos] = ACTIONS(4304),
    [anon_sym_rnmos] = ACTIONS(4304),
    [anon_sym_rpmos] = ACTIONS(4304),
    [anon_sym_nand] = ACTIONS(4304),
    [anon_sym_nor] = ACTIONS(4304),
    [anon_sym_xor] = ACTIONS(4304),
    [anon_sym_xnor] = ACTIONS(4304),
    [anon_sym_buf] = ACTIONS(4304),
    [anon_sym_tranif0] = ACTIONS(4304),
    [anon_sym_tranif1] = ACTIONS(4304),
    [anon_sym_rtranif1] = ACTIONS(4304),
    [anon_sym_rtranif0] = ACTIONS(4304),
    [anon_sym_tran] = ACTIONS(4304),
    [anon_sym_rtran] = ACTIONS(4304),
    [anon_sym_generate] = ACTIONS(4304),
    [anon_sym_for] = ACTIONS(4304),
    [anon_sym_initial] = ACTIONS(4304),
    [anon_sym_assign] = ACTIONS(4304),
    [anon_sym_alias] = ACTIONS(4304),
    [anon_sym_always_comb] = ACTIONS(4304),
    [anon_sym_always_latch] = ACTIONS(4304),
    [anon_sym_always_ff] = ACTIONS(4304),
    [anon_sym_final] = ACTIONS(4304),
    [anon_sym_global] = ACTIONS(4304),
    [anon_sym_LPAREN_STAR] = ACTIONS(4302),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4302),
    [anon_sym_DOLLARunit] = ACTIONS(4302),
  },
  [4429] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_COLON] = ACTIONS(10577),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_rand] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_end] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [4430] = {
    [sym_simple_identifier] = ACTIONS(4696),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_COLON] = ACTIONS(10579),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_rand] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_end] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [4431] = {
    [sym_simple_identifier] = ACTIONS(5660),
    [anon_sym_wire] = ACTIONS(5660),
    [anon_sym_tri] = ACTIONS(5660),
    [anon_sym_tri0] = ACTIONS(5660),
    [anon_sym_tri1] = ACTIONS(5660),
    [anon_sym_wand] = ACTIONS(5660),
    [anon_sym_triand] = ACTIONS(5660),
    [anon_sym_wor] = ACTIONS(5660),
    [anon_sym_trior] = ACTIONS(5660),
    [anon_sym_trireg] = ACTIONS(5660),
    [anon_sym_uwire] = ACTIONS(5660),
    [anon_sym_SEMI] = ACTIONS(5662),
    [anon_sym_COLON] = ACTIONS(10581),
    [anon_sym_extern] = ACTIONS(5660),
    [anon_sym_interface] = ACTIONS(5660),
    [anon_sym_checker] = ACTIONS(5660),
    [anon_sym_virtual] = ACTIONS(5660),
    [anon_sym_class] = ACTIONS(5660),
    [anon_sym_type] = ACTIONS(5660),
    [anon_sym_DOLLARfatal] = ACTIONS(5662),
    [anon_sym_DOLLARerror] = ACTIONS(5662),
    [anon_sym_DOLLARwarning] = ACTIONS(5662),
    [anon_sym_DOLLARinfo] = ACTIONS(5662),
    [anon_sym_default] = ACTIONS(5660),
    [anon_sym_clocking] = ACTIONS(5660),
    [anon_sym_defparam] = ACTIONS(5660),
    [anon_sym_bind] = ACTIONS(5660),
    [anon_sym_rand] = ACTIONS(5660),
    [anon_sym_const] = ACTIONS(5660),
    [anon_sym_function] = ACTIONS(5660),
    [anon_sym_static] = ACTIONS(5660),
    [anon_sym_constraint] = ACTIONS(5660),
    [anon_sym_if] = ACTIONS(5660),
    [anon_sym_else] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5662),
    [anon_sym_localparam] = ACTIONS(5660),
    [anon_sym_parameter] = ACTIONS(5660),
    [anon_sym_var] = ACTIONS(5660),
    [anon_sym_import] = ACTIONS(5660),
    [anon_sym_export] = ACTIONS(5660),
    [anon_sym_genvar] = ACTIONS(5660),
    [anon_sym_interconnect] = ACTIONS(5660),
    [anon_sym_typedef] = ACTIONS(5660),
    [anon_sym_enum] = ACTIONS(5660),
    [anon_sym_struct] = ACTIONS(5660),
    [anon_sym_union] = ACTIONS(5660),
    [anon_sym_nettype] = ACTIONS(5660),
    [anon_sym_automatic] = ACTIONS(5660),
    [anon_sym_string] = ACTIONS(5660),
    [anon_sym_chandle] = ACTIONS(5660),
    [anon_sym_event] = ACTIONS(5660),
    [anon_sym_byte] = ACTIONS(5660),
    [anon_sym_shortint] = ACTIONS(5660),
    [anon_sym_int] = ACTIONS(5660),
    [anon_sym_longint] = ACTIONS(5660),
    [anon_sym_integer] = ACTIONS(5660),
    [anon_sym_time] = ACTIONS(5660),
    [anon_sym_bit] = ACTIONS(5660),
    [anon_sym_logic] = ACTIONS(5660),
    [anon_sym_reg] = ACTIONS(5660),
    [anon_sym_shortreal] = ACTIONS(5660),
    [anon_sym_real] = ACTIONS(5660),
    [anon_sym_realtime] = ACTIONS(5660),
    [anon_sym_supply0] = ACTIONS(5660),
    [anon_sym_supply1] = ACTIONS(5660),
    [anon_sym_signed] = ACTIONS(5660),
    [anon_sym_unsigned] = ACTIONS(5660),
    [anon_sym_task] = ACTIONS(5660),
    [anon_sym_assert] = ACTIONS(5660),
    [anon_sym_property] = ACTIONS(5660),
    [anon_sym_assume] = ACTIONS(5660),
    [anon_sym_cover] = ACTIONS(5660),
    [anon_sym_sequence] = ACTIONS(5660),
    [anon_sym_restrict] = ACTIONS(5660),
    [anon_sym_not] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_case] = ACTIONS(5660),
    [anon_sym_always] = ACTIONS(5660),
    [anon_sym_covergroup] = ACTIONS(5660),
    [anon_sym_let] = ACTIONS(5660),
    [anon_sym_pulldown] = ACTIONS(5660),
    [anon_sym_pullup] = ACTIONS(5660),
    [anon_sym_cmos] = ACTIONS(5660),
    [anon_sym_rcmos] = ACTIONS(5660),
    [anon_sym_bufif0] = ACTIONS(5660),
    [anon_sym_bufif1] = ACTIONS(5660),
    [anon_sym_notif0] = ACTIONS(5660),
    [anon_sym_notif1] = ACTIONS(5660),
    [anon_sym_nmos] = ACTIONS(5660),
    [anon_sym_pmos] = ACTIONS(5660),
    [anon_sym_rnmos] = ACTIONS(5660),
    [anon_sym_rpmos] = ACTIONS(5660),
    [anon_sym_nand] = ACTIONS(5660),
    [anon_sym_nor] = ACTIONS(5660),
    [anon_sym_xor] = ACTIONS(5660),
    [anon_sym_xnor] = ACTIONS(5660),
    [anon_sym_buf] = ACTIONS(5660),
    [anon_sym_tranif0] = ACTIONS(5660),
    [anon_sym_tranif1] = ACTIONS(5660),
    [anon_sym_rtranif1] = ACTIONS(5660),
    [anon_sym_rtranif0] = ACTIONS(5660),
    [anon_sym_tran] = ACTIONS(5660),
    [anon_sym_rtran] = ACTIONS(5660),
    [anon_sym_generate] = ACTIONS(5660),
    [anon_sym_endgenerate] = ACTIONS(5660),
    [anon_sym_for] = ACTIONS(5660),
    [anon_sym_initial] = ACTIONS(5660),
    [anon_sym_assign] = ACTIONS(5660),
    [anon_sym_alias] = ACTIONS(5660),
    [anon_sym_always_comb] = ACTIONS(5660),
    [anon_sym_always_latch] = ACTIONS(5660),
    [anon_sym_always_ff] = ACTIONS(5660),
    [anon_sym_final] = ACTIONS(5660),
    [anon_sym_global] = ACTIONS(5660),
    [anon_sym_LPAREN_STAR] = ACTIONS(5662),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5662),
    [anon_sym_DOLLARunit] = ACTIONS(5662),
  },
  [4432] = {
    [sym_simple_identifier] = ACTIONS(4310),
    [anon_sym_wire] = ACTIONS(4310),
    [anon_sym_tri] = ACTIONS(4310),
    [anon_sym_tri0] = ACTIONS(4310),
    [anon_sym_tri1] = ACTIONS(4310),
    [anon_sym_wand] = ACTIONS(4310),
    [anon_sym_triand] = ACTIONS(4310),
    [anon_sym_wor] = ACTIONS(4310),
    [anon_sym_trior] = ACTIONS(4310),
    [anon_sym_trireg] = ACTIONS(4310),
    [anon_sym_uwire] = ACTIONS(4310),
    [anon_sym_SEMI] = ACTIONS(4308),
    [anon_sym_COLON] = ACTIONS(10583),
    [anon_sym_extern] = ACTIONS(4310),
    [anon_sym_interface] = ACTIONS(4310),
    [anon_sym_checker] = ACTIONS(4310),
    [anon_sym_virtual] = ACTIONS(4310),
    [anon_sym_class] = ACTIONS(4310),
    [anon_sym_type] = ACTIONS(4310),
    [anon_sym_DOLLARfatal] = ACTIONS(4308),
    [anon_sym_DOLLARerror] = ACTIONS(4308),
    [anon_sym_DOLLARwarning] = ACTIONS(4308),
    [anon_sym_DOLLARinfo] = ACTIONS(4308),
    [anon_sym_default] = ACTIONS(4310),
    [anon_sym_clocking] = ACTIONS(4310),
    [anon_sym_defparam] = ACTIONS(4310),
    [anon_sym_bind] = ACTIONS(4310),
    [anon_sym_rand] = ACTIONS(4310),
    [anon_sym_const] = ACTIONS(4310),
    [anon_sym_function] = ACTIONS(4310),
    [anon_sym_static] = ACTIONS(4310),
    [anon_sym_constraint] = ACTIONS(4310),
    [anon_sym_if] = ACTIONS(4310),
    [anon_sym_else] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4308),
    [anon_sym_localparam] = ACTIONS(4310),
    [anon_sym_parameter] = ACTIONS(4310),
    [anon_sym_var] = ACTIONS(4310),
    [anon_sym_import] = ACTIONS(4310),
    [anon_sym_export] = ACTIONS(4310),
    [anon_sym_genvar] = ACTIONS(4310),
    [anon_sym_interconnect] = ACTIONS(4310),
    [anon_sym_typedef] = ACTIONS(4310),
    [anon_sym_enum] = ACTIONS(4310),
    [anon_sym_struct] = ACTIONS(4310),
    [anon_sym_union] = ACTIONS(4310),
    [anon_sym_nettype] = ACTIONS(4310),
    [anon_sym_automatic] = ACTIONS(4310),
    [anon_sym_string] = ACTIONS(4310),
    [anon_sym_chandle] = ACTIONS(4310),
    [anon_sym_event] = ACTIONS(4310),
    [anon_sym_byte] = ACTIONS(4310),
    [anon_sym_shortint] = ACTIONS(4310),
    [anon_sym_int] = ACTIONS(4310),
    [anon_sym_longint] = ACTIONS(4310),
    [anon_sym_integer] = ACTIONS(4310),
    [anon_sym_time] = ACTIONS(4310),
    [anon_sym_bit] = ACTIONS(4310),
    [anon_sym_logic] = ACTIONS(4310),
    [anon_sym_reg] = ACTIONS(4310),
    [anon_sym_shortreal] = ACTIONS(4310),
    [anon_sym_real] = ACTIONS(4310),
    [anon_sym_realtime] = ACTIONS(4310),
    [anon_sym_supply0] = ACTIONS(4310),
    [anon_sym_supply1] = ACTIONS(4310),
    [anon_sym_signed] = ACTIONS(4310),
    [anon_sym_unsigned] = ACTIONS(4310),
    [anon_sym_task] = ACTIONS(4310),
    [anon_sym_assert] = ACTIONS(4310),
    [anon_sym_property] = ACTIONS(4310),
    [anon_sym_assume] = ACTIONS(4310),
    [anon_sym_cover] = ACTIONS(4310),
    [anon_sym_sequence] = ACTIONS(4310),
    [anon_sym_restrict] = ACTIONS(4310),
    [anon_sym_not] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_case] = ACTIONS(4310),
    [anon_sym_always] = ACTIONS(4310),
    [anon_sym_covergroup] = ACTIONS(4310),
    [anon_sym_end] = ACTIONS(4310),
    [anon_sym_let] = ACTIONS(4310),
    [anon_sym_pulldown] = ACTIONS(4310),
    [anon_sym_pullup] = ACTIONS(4310),
    [anon_sym_cmos] = ACTIONS(4310),
    [anon_sym_rcmos] = ACTIONS(4310),
    [anon_sym_bufif0] = ACTIONS(4310),
    [anon_sym_bufif1] = ACTIONS(4310),
    [anon_sym_notif0] = ACTIONS(4310),
    [anon_sym_notif1] = ACTIONS(4310),
    [anon_sym_nmos] = ACTIONS(4310),
    [anon_sym_pmos] = ACTIONS(4310),
    [anon_sym_rnmos] = ACTIONS(4310),
    [anon_sym_rpmos] = ACTIONS(4310),
    [anon_sym_nand] = ACTIONS(4310),
    [anon_sym_nor] = ACTIONS(4310),
    [anon_sym_xor] = ACTIONS(4310),
    [anon_sym_xnor] = ACTIONS(4310),
    [anon_sym_buf] = ACTIONS(4310),
    [anon_sym_tranif0] = ACTIONS(4310),
    [anon_sym_tranif1] = ACTIONS(4310),
    [anon_sym_rtranif1] = ACTIONS(4310),
    [anon_sym_rtranif0] = ACTIONS(4310),
    [anon_sym_tran] = ACTIONS(4310),
    [anon_sym_rtran] = ACTIONS(4310),
    [anon_sym_generate] = ACTIONS(4310),
    [anon_sym_for] = ACTIONS(4310),
    [anon_sym_initial] = ACTIONS(4310),
    [anon_sym_assign] = ACTIONS(4310),
    [anon_sym_alias] = ACTIONS(4310),
    [anon_sym_always_comb] = ACTIONS(4310),
    [anon_sym_always_latch] = ACTIONS(4310),
    [anon_sym_always_ff] = ACTIONS(4310),
    [anon_sym_final] = ACTIONS(4310),
    [anon_sym_global] = ACTIONS(4310),
    [anon_sym_LPAREN_STAR] = ACTIONS(4308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4308),
    [anon_sym_DOLLARunit] = ACTIONS(4308),
  },
  [4433] = {
    [sym_simple_identifier] = ACTIONS(4714),
    [anon_sym_wire] = ACTIONS(4714),
    [anon_sym_tri] = ACTIONS(4714),
    [anon_sym_tri0] = ACTIONS(4714),
    [anon_sym_tri1] = ACTIONS(4714),
    [anon_sym_wand] = ACTIONS(4714),
    [anon_sym_triand] = ACTIONS(4714),
    [anon_sym_wor] = ACTIONS(4714),
    [anon_sym_trior] = ACTIONS(4714),
    [anon_sym_trireg] = ACTIONS(4714),
    [anon_sym_uwire] = ACTIONS(4714),
    [anon_sym_SEMI] = ACTIONS(4712),
    [anon_sym_COLON] = ACTIONS(10585),
    [anon_sym_extern] = ACTIONS(4714),
    [anon_sym_interface] = ACTIONS(4714),
    [anon_sym_checker] = ACTIONS(4714),
    [anon_sym_virtual] = ACTIONS(4714),
    [anon_sym_class] = ACTIONS(4714),
    [anon_sym_type] = ACTIONS(4714),
    [anon_sym_DOLLARfatal] = ACTIONS(4712),
    [anon_sym_DOLLARerror] = ACTIONS(4712),
    [anon_sym_DOLLARwarning] = ACTIONS(4712),
    [anon_sym_DOLLARinfo] = ACTIONS(4712),
    [anon_sym_default] = ACTIONS(4714),
    [anon_sym_clocking] = ACTIONS(4714),
    [anon_sym_defparam] = ACTIONS(4714),
    [anon_sym_bind] = ACTIONS(4714),
    [anon_sym_rand] = ACTIONS(4714),
    [anon_sym_const] = ACTIONS(4714),
    [anon_sym_function] = ACTIONS(4714),
    [anon_sym_static] = ACTIONS(4714),
    [anon_sym_constraint] = ACTIONS(4714),
    [anon_sym_if] = ACTIONS(4714),
    [anon_sym_else] = ACTIONS(4714),
    [anon_sym_LBRACK] = ACTIONS(4712),
    [anon_sym_localparam] = ACTIONS(4714),
    [anon_sym_parameter] = ACTIONS(4714),
    [anon_sym_var] = ACTIONS(4714),
    [anon_sym_import] = ACTIONS(4714),
    [anon_sym_export] = ACTIONS(4714),
    [anon_sym_genvar] = ACTIONS(4714),
    [anon_sym_interconnect] = ACTIONS(4714),
    [anon_sym_typedef] = ACTIONS(4714),
    [anon_sym_enum] = ACTIONS(4714),
    [anon_sym_struct] = ACTIONS(4714),
    [anon_sym_union] = ACTIONS(4714),
    [anon_sym_nettype] = ACTIONS(4714),
    [anon_sym_automatic] = ACTIONS(4714),
    [anon_sym_string] = ACTIONS(4714),
    [anon_sym_chandle] = ACTIONS(4714),
    [anon_sym_event] = ACTIONS(4714),
    [anon_sym_byte] = ACTIONS(4714),
    [anon_sym_shortint] = ACTIONS(4714),
    [anon_sym_int] = ACTIONS(4714),
    [anon_sym_longint] = ACTIONS(4714),
    [anon_sym_integer] = ACTIONS(4714),
    [anon_sym_time] = ACTIONS(4714),
    [anon_sym_bit] = ACTIONS(4714),
    [anon_sym_logic] = ACTIONS(4714),
    [anon_sym_reg] = ACTIONS(4714),
    [anon_sym_shortreal] = ACTIONS(4714),
    [anon_sym_real] = ACTIONS(4714),
    [anon_sym_realtime] = ACTIONS(4714),
    [anon_sym_supply0] = ACTIONS(4714),
    [anon_sym_supply1] = ACTIONS(4714),
    [anon_sym_signed] = ACTIONS(4714),
    [anon_sym_unsigned] = ACTIONS(4714),
    [anon_sym_task] = ACTIONS(4714),
    [anon_sym_assert] = ACTIONS(4714),
    [anon_sym_property] = ACTIONS(4714),
    [anon_sym_assume] = ACTIONS(4714),
    [anon_sym_cover] = ACTIONS(4714),
    [anon_sym_sequence] = ACTIONS(4714),
    [anon_sym_restrict] = ACTIONS(4714),
    [anon_sym_not] = ACTIONS(4714),
    [anon_sym_or] = ACTIONS(4714),
    [anon_sym_and] = ACTIONS(4714),
    [anon_sym_case] = ACTIONS(4714),
    [anon_sym_always] = ACTIONS(4714),
    [anon_sym_covergroup] = ACTIONS(4714),
    [anon_sym_end] = ACTIONS(4714),
    [anon_sym_let] = ACTIONS(4714),
    [anon_sym_pulldown] = ACTIONS(4714),
    [anon_sym_pullup] = ACTIONS(4714),
    [anon_sym_cmos] = ACTIONS(4714),
    [anon_sym_rcmos] = ACTIONS(4714),
    [anon_sym_bufif0] = ACTIONS(4714),
    [anon_sym_bufif1] = ACTIONS(4714),
    [anon_sym_notif0] = ACTIONS(4714),
    [anon_sym_notif1] = ACTIONS(4714),
    [anon_sym_nmos] = ACTIONS(4714),
    [anon_sym_pmos] = ACTIONS(4714),
    [anon_sym_rnmos] = ACTIONS(4714),
    [anon_sym_rpmos] = ACTIONS(4714),
    [anon_sym_nand] = ACTIONS(4714),
    [anon_sym_nor] = ACTIONS(4714),
    [anon_sym_xor] = ACTIONS(4714),
    [anon_sym_xnor] = ACTIONS(4714),
    [anon_sym_buf] = ACTIONS(4714),
    [anon_sym_tranif0] = ACTIONS(4714),
    [anon_sym_tranif1] = ACTIONS(4714),
    [anon_sym_rtranif1] = ACTIONS(4714),
    [anon_sym_rtranif0] = ACTIONS(4714),
    [anon_sym_tran] = ACTIONS(4714),
    [anon_sym_rtran] = ACTIONS(4714),
    [anon_sym_generate] = ACTIONS(4714),
    [anon_sym_for] = ACTIONS(4714),
    [anon_sym_initial] = ACTIONS(4714),
    [anon_sym_assign] = ACTIONS(4714),
    [anon_sym_alias] = ACTIONS(4714),
    [anon_sym_always_comb] = ACTIONS(4714),
    [anon_sym_always_latch] = ACTIONS(4714),
    [anon_sym_always_ff] = ACTIONS(4714),
    [anon_sym_final] = ACTIONS(4714),
    [anon_sym_global] = ACTIONS(4714),
    [anon_sym_LPAREN_STAR] = ACTIONS(4712),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4712),
    [anon_sym_DOLLARunit] = ACTIONS(4712),
  },
  [4434] = {
    [sym_simple_identifier] = ACTIONS(4190),
    [anon_sym_wire] = ACTIONS(4190),
    [anon_sym_tri] = ACTIONS(4190),
    [anon_sym_tri0] = ACTIONS(4190),
    [anon_sym_tri1] = ACTIONS(4190),
    [anon_sym_wand] = ACTIONS(4190),
    [anon_sym_triand] = ACTIONS(4190),
    [anon_sym_wor] = ACTIONS(4190),
    [anon_sym_trior] = ACTIONS(4190),
    [anon_sym_trireg] = ACTIONS(4190),
    [anon_sym_uwire] = ACTIONS(4190),
    [anon_sym_SEMI] = ACTIONS(4188),
    [anon_sym_COLON] = ACTIONS(10587),
    [anon_sym_extern] = ACTIONS(4190),
    [anon_sym_interface] = ACTIONS(4190),
    [anon_sym_checker] = ACTIONS(4190),
    [anon_sym_virtual] = ACTIONS(4190),
    [anon_sym_class] = ACTIONS(4190),
    [anon_sym_type] = ACTIONS(4190),
    [anon_sym_DOLLARfatal] = ACTIONS(4188),
    [anon_sym_DOLLARerror] = ACTIONS(4188),
    [anon_sym_DOLLARwarning] = ACTIONS(4188),
    [anon_sym_DOLLARinfo] = ACTIONS(4188),
    [anon_sym_default] = ACTIONS(4190),
    [anon_sym_clocking] = ACTIONS(4190),
    [anon_sym_defparam] = ACTIONS(4190),
    [anon_sym_bind] = ACTIONS(4190),
    [anon_sym_rand] = ACTIONS(4190),
    [anon_sym_const] = ACTIONS(4190),
    [anon_sym_function] = ACTIONS(4190),
    [anon_sym_static] = ACTIONS(4190),
    [anon_sym_constraint] = ACTIONS(4190),
    [anon_sym_if] = ACTIONS(4190),
    [anon_sym_else] = ACTIONS(4190),
    [anon_sym_LBRACK] = ACTIONS(4188),
    [anon_sym_localparam] = ACTIONS(4190),
    [anon_sym_parameter] = ACTIONS(4190),
    [anon_sym_var] = ACTIONS(4190),
    [anon_sym_import] = ACTIONS(4190),
    [anon_sym_export] = ACTIONS(4190),
    [anon_sym_genvar] = ACTIONS(4190),
    [anon_sym_interconnect] = ACTIONS(4190),
    [anon_sym_typedef] = ACTIONS(4190),
    [anon_sym_enum] = ACTIONS(4190),
    [anon_sym_struct] = ACTIONS(4190),
    [anon_sym_union] = ACTIONS(4190),
    [anon_sym_nettype] = ACTIONS(4190),
    [anon_sym_automatic] = ACTIONS(4190),
    [anon_sym_string] = ACTIONS(4190),
    [anon_sym_chandle] = ACTIONS(4190),
    [anon_sym_event] = ACTIONS(4190),
    [anon_sym_byte] = ACTIONS(4190),
    [anon_sym_shortint] = ACTIONS(4190),
    [anon_sym_int] = ACTIONS(4190),
    [anon_sym_longint] = ACTIONS(4190),
    [anon_sym_integer] = ACTIONS(4190),
    [anon_sym_time] = ACTIONS(4190),
    [anon_sym_bit] = ACTIONS(4190),
    [anon_sym_logic] = ACTIONS(4190),
    [anon_sym_reg] = ACTIONS(4190),
    [anon_sym_shortreal] = ACTIONS(4190),
    [anon_sym_real] = ACTIONS(4190),
    [anon_sym_realtime] = ACTIONS(4190),
    [anon_sym_supply0] = ACTIONS(4190),
    [anon_sym_supply1] = ACTIONS(4190),
    [anon_sym_signed] = ACTIONS(4190),
    [anon_sym_unsigned] = ACTIONS(4190),
    [anon_sym_task] = ACTIONS(4190),
    [anon_sym_assert] = ACTIONS(4190),
    [anon_sym_property] = ACTIONS(4190),
    [anon_sym_assume] = ACTIONS(4190),
    [anon_sym_cover] = ACTIONS(4190),
    [anon_sym_sequence] = ACTIONS(4190),
    [anon_sym_restrict] = ACTIONS(4190),
    [anon_sym_not] = ACTIONS(4190),
    [anon_sym_or] = ACTIONS(4190),
    [anon_sym_and] = ACTIONS(4190),
    [anon_sym_case] = ACTIONS(4190),
    [anon_sym_always] = ACTIONS(4190),
    [anon_sym_covergroup] = ACTIONS(4190),
    [anon_sym_end] = ACTIONS(4190),
    [anon_sym_let] = ACTIONS(4190),
    [anon_sym_pulldown] = ACTIONS(4190),
    [anon_sym_pullup] = ACTIONS(4190),
    [anon_sym_cmos] = ACTIONS(4190),
    [anon_sym_rcmos] = ACTIONS(4190),
    [anon_sym_bufif0] = ACTIONS(4190),
    [anon_sym_bufif1] = ACTIONS(4190),
    [anon_sym_notif0] = ACTIONS(4190),
    [anon_sym_notif1] = ACTIONS(4190),
    [anon_sym_nmos] = ACTIONS(4190),
    [anon_sym_pmos] = ACTIONS(4190),
    [anon_sym_rnmos] = ACTIONS(4190),
    [anon_sym_rpmos] = ACTIONS(4190),
    [anon_sym_nand] = ACTIONS(4190),
    [anon_sym_nor] = ACTIONS(4190),
    [anon_sym_xor] = ACTIONS(4190),
    [anon_sym_xnor] = ACTIONS(4190),
    [anon_sym_buf] = ACTIONS(4190),
    [anon_sym_tranif0] = ACTIONS(4190),
    [anon_sym_tranif1] = ACTIONS(4190),
    [anon_sym_rtranif1] = ACTIONS(4190),
    [anon_sym_rtranif0] = ACTIONS(4190),
    [anon_sym_tran] = ACTIONS(4190),
    [anon_sym_rtran] = ACTIONS(4190),
    [anon_sym_generate] = ACTIONS(4190),
    [anon_sym_for] = ACTIONS(4190),
    [anon_sym_initial] = ACTIONS(4190),
    [anon_sym_assign] = ACTIONS(4190),
    [anon_sym_alias] = ACTIONS(4190),
    [anon_sym_always_comb] = ACTIONS(4190),
    [anon_sym_always_latch] = ACTIONS(4190),
    [anon_sym_always_ff] = ACTIONS(4190),
    [anon_sym_final] = ACTIONS(4190),
    [anon_sym_global] = ACTIONS(4190),
    [anon_sym_LPAREN_STAR] = ACTIONS(4188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4188),
    [anon_sym_DOLLARunit] = ACTIONS(4188),
  },
  [4435] = {
    [sym_simple_identifier] = ACTIONS(4316),
    [anon_sym_wire] = ACTIONS(4316),
    [anon_sym_tri] = ACTIONS(4316),
    [anon_sym_tri0] = ACTIONS(4316),
    [anon_sym_tri1] = ACTIONS(4316),
    [anon_sym_wand] = ACTIONS(4316),
    [anon_sym_triand] = ACTIONS(4316),
    [anon_sym_wor] = ACTIONS(4316),
    [anon_sym_trior] = ACTIONS(4316),
    [anon_sym_trireg] = ACTIONS(4316),
    [anon_sym_uwire] = ACTIONS(4316),
    [anon_sym_SEMI] = ACTIONS(4314),
    [anon_sym_COLON] = ACTIONS(10589),
    [anon_sym_extern] = ACTIONS(4316),
    [anon_sym_interface] = ACTIONS(4316),
    [anon_sym_checker] = ACTIONS(4316),
    [anon_sym_virtual] = ACTIONS(4316),
    [anon_sym_class] = ACTIONS(4316),
    [anon_sym_type] = ACTIONS(4316),
    [anon_sym_DOLLARfatal] = ACTIONS(4314),
    [anon_sym_DOLLARerror] = ACTIONS(4314),
    [anon_sym_DOLLARwarning] = ACTIONS(4314),
    [anon_sym_DOLLARinfo] = ACTIONS(4314),
    [anon_sym_default] = ACTIONS(4316),
    [anon_sym_clocking] = ACTIONS(4316),
    [anon_sym_defparam] = ACTIONS(4316),
    [anon_sym_bind] = ACTIONS(4316),
    [anon_sym_rand] = ACTIONS(4316),
    [anon_sym_const] = ACTIONS(4316),
    [anon_sym_function] = ACTIONS(4316),
    [anon_sym_static] = ACTIONS(4316),
    [anon_sym_constraint] = ACTIONS(4316),
    [anon_sym_if] = ACTIONS(4316),
    [anon_sym_else] = ACTIONS(4316),
    [anon_sym_LBRACK] = ACTIONS(4314),
    [anon_sym_localparam] = ACTIONS(4316),
    [anon_sym_parameter] = ACTIONS(4316),
    [anon_sym_var] = ACTIONS(4316),
    [anon_sym_import] = ACTIONS(4316),
    [anon_sym_export] = ACTIONS(4316),
    [anon_sym_genvar] = ACTIONS(4316),
    [anon_sym_interconnect] = ACTIONS(4316),
    [anon_sym_typedef] = ACTIONS(4316),
    [anon_sym_enum] = ACTIONS(4316),
    [anon_sym_struct] = ACTIONS(4316),
    [anon_sym_union] = ACTIONS(4316),
    [anon_sym_nettype] = ACTIONS(4316),
    [anon_sym_automatic] = ACTIONS(4316),
    [anon_sym_string] = ACTIONS(4316),
    [anon_sym_chandle] = ACTIONS(4316),
    [anon_sym_event] = ACTIONS(4316),
    [anon_sym_byte] = ACTIONS(4316),
    [anon_sym_shortint] = ACTIONS(4316),
    [anon_sym_int] = ACTIONS(4316),
    [anon_sym_longint] = ACTIONS(4316),
    [anon_sym_integer] = ACTIONS(4316),
    [anon_sym_time] = ACTIONS(4316),
    [anon_sym_bit] = ACTIONS(4316),
    [anon_sym_logic] = ACTIONS(4316),
    [anon_sym_reg] = ACTIONS(4316),
    [anon_sym_shortreal] = ACTIONS(4316),
    [anon_sym_real] = ACTIONS(4316),
    [anon_sym_realtime] = ACTIONS(4316),
    [anon_sym_supply0] = ACTIONS(4316),
    [anon_sym_supply1] = ACTIONS(4316),
    [anon_sym_signed] = ACTIONS(4316),
    [anon_sym_unsigned] = ACTIONS(4316),
    [anon_sym_task] = ACTIONS(4316),
    [anon_sym_assert] = ACTIONS(4316),
    [anon_sym_property] = ACTIONS(4316),
    [anon_sym_assume] = ACTIONS(4316),
    [anon_sym_cover] = ACTIONS(4316),
    [anon_sym_sequence] = ACTIONS(4316),
    [anon_sym_restrict] = ACTIONS(4316),
    [anon_sym_not] = ACTIONS(4316),
    [anon_sym_or] = ACTIONS(4316),
    [anon_sym_and] = ACTIONS(4316),
    [anon_sym_case] = ACTIONS(4316),
    [anon_sym_always] = ACTIONS(4316),
    [anon_sym_covergroup] = ACTIONS(4316),
    [anon_sym_let] = ACTIONS(4316),
    [anon_sym_pulldown] = ACTIONS(4316),
    [anon_sym_pullup] = ACTIONS(4316),
    [anon_sym_cmos] = ACTIONS(4316),
    [anon_sym_rcmos] = ACTIONS(4316),
    [anon_sym_bufif0] = ACTIONS(4316),
    [anon_sym_bufif1] = ACTIONS(4316),
    [anon_sym_notif0] = ACTIONS(4316),
    [anon_sym_notif1] = ACTIONS(4316),
    [anon_sym_nmos] = ACTIONS(4316),
    [anon_sym_pmos] = ACTIONS(4316),
    [anon_sym_rnmos] = ACTIONS(4316),
    [anon_sym_rpmos] = ACTIONS(4316),
    [anon_sym_nand] = ACTIONS(4316),
    [anon_sym_nor] = ACTIONS(4316),
    [anon_sym_xor] = ACTIONS(4316),
    [anon_sym_xnor] = ACTIONS(4316),
    [anon_sym_buf] = ACTIONS(4316),
    [anon_sym_tranif0] = ACTIONS(4316),
    [anon_sym_tranif1] = ACTIONS(4316),
    [anon_sym_rtranif1] = ACTIONS(4316),
    [anon_sym_rtranif0] = ACTIONS(4316),
    [anon_sym_tran] = ACTIONS(4316),
    [anon_sym_rtran] = ACTIONS(4316),
    [anon_sym_generate] = ACTIONS(4316),
    [anon_sym_endgenerate] = ACTIONS(4316),
    [anon_sym_for] = ACTIONS(4316),
    [anon_sym_initial] = ACTIONS(4316),
    [anon_sym_assign] = ACTIONS(4316),
    [anon_sym_alias] = ACTIONS(4316),
    [anon_sym_always_comb] = ACTIONS(4316),
    [anon_sym_always_latch] = ACTIONS(4316),
    [anon_sym_always_ff] = ACTIONS(4316),
    [anon_sym_final] = ACTIONS(4316),
    [anon_sym_global] = ACTIONS(4316),
    [anon_sym_LPAREN_STAR] = ACTIONS(4314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4314),
    [anon_sym_DOLLARunit] = ACTIONS(4314),
  },
  [4436] = {
    [sym_simple_identifier] = ACTIONS(4400),
    [anon_sym_wire] = ACTIONS(4400),
    [anon_sym_tri] = ACTIONS(4400),
    [anon_sym_tri0] = ACTIONS(4400),
    [anon_sym_tri1] = ACTIONS(4400),
    [anon_sym_wand] = ACTIONS(4400),
    [anon_sym_triand] = ACTIONS(4400),
    [anon_sym_wor] = ACTIONS(4400),
    [anon_sym_trior] = ACTIONS(4400),
    [anon_sym_trireg] = ACTIONS(4400),
    [anon_sym_uwire] = ACTIONS(4400),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym_COLON] = ACTIONS(10591),
    [anon_sym_extern] = ACTIONS(4400),
    [anon_sym_interface] = ACTIONS(4400),
    [anon_sym_checker] = ACTIONS(4400),
    [anon_sym_virtual] = ACTIONS(4400),
    [anon_sym_class] = ACTIONS(4400),
    [anon_sym_type] = ACTIONS(4400),
    [anon_sym_DOLLARfatal] = ACTIONS(4398),
    [anon_sym_DOLLARerror] = ACTIONS(4398),
    [anon_sym_DOLLARwarning] = ACTIONS(4398),
    [anon_sym_DOLLARinfo] = ACTIONS(4398),
    [anon_sym_default] = ACTIONS(4400),
    [anon_sym_clocking] = ACTIONS(4400),
    [anon_sym_defparam] = ACTIONS(4400),
    [anon_sym_bind] = ACTIONS(4400),
    [anon_sym_rand] = ACTIONS(4400),
    [anon_sym_const] = ACTIONS(4400),
    [anon_sym_function] = ACTIONS(4400),
    [anon_sym_static] = ACTIONS(4400),
    [anon_sym_constraint] = ACTIONS(4400),
    [anon_sym_if] = ACTIONS(4400),
    [anon_sym_else] = ACTIONS(4400),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_localparam] = ACTIONS(4400),
    [anon_sym_parameter] = ACTIONS(4400),
    [anon_sym_var] = ACTIONS(4400),
    [anon_sym_import] = ACTIONS(4400),
    [anon_sym_export] = ACTIONS(4400),
    [anon_sym_genvar] = ACTIONS(4400),
    [anon_sym_interconnect] = ACTIONS(4400),
    [anon_sym_typedef] = ACTIONS(4400),
    [anon_sym_enum] = ACTIONS(4400),
    [anon_sym_struct] = ACTIONS(4400),
    [anon_sym_union] = ACTIONS(4400),
    [anon_sym_nettype] = ACTIONS(4400),
    [anon_sym_automatic] = ACTIONS(4400),
    [anon_sym_string] = ACTIONS(4400),
    [anon_sym_chandle] = ACTIONS(4400),
    [anon_sym_event] = ACTIONS(4400),
    [anon_sym_byte] = ACTIONS(4400),
    [anon_sym_shortint] = ACTIONS(4400),
    [anon_sym_int] = ACTIONS(4400),
    [anon_sym_longint] = ACTIONS(4400),
    [anon_sym_integer] = ACTIONS(4400),
    [anon_sym_time] = ACTIONS(4400),
    [anon_sym_bit] = ACTIONS(4400),
    [anon_sym_logic] = ACTIONS(4400),
    [anon_sym_reg] = ACTIONS(4400),
    [anon_sym_shortreal] = ACTIONS(4400),
    [anon_sym_real] = ACTIONS(4400),
    [anon_sym_realtime] = ACTIONS(4400),
    [anon_sym_supply0] = ACTIONS(4400),
    [anon_sym_supply1] = ACTIONS(4400),
    [anon_sym_signed] = ACTIONS(4400),
    [anon_sym_unsigned] = ACTIONS(4400),
    [anon_sym_task] = ACTIONS(4400),
    [anon_sym_assert] = ACTIONS(4400),
    [anon_sym_property] = ACTIONS(4400),
    [anon_sym_assume] = ACTIONS(4400),
    [anon_sym_cover] = ACTIONS(4400),
    [anon_sym_sequence] = ACTIONS(4400),
    [anon_sym_restrict] = ACTIONS(4400),
    [anon_sym_not] = ACTIONS(4400),
    [anon_sym_or] = ACTIONS(4400),
    [anon_sym_and] = ACTIONS(4400),
    [anon_sym_case] = ACTIONS(4400),
    [anon_sym_always] = ACTIONS(4400),
    [anon_sym_covergroup] = ACTIONS(4400),
    [anon_sym_end] = ACTIONS(4400),
    [anon_sym_let] = ACTIONS(4400),
    [anon_sym_pulldown] = ACTIONS(4400),
    [anon_sym_pullup] = ACTIONS(4400),
    [anon_sym_cmos] = ACTIONS(4400),
    [anon_sym_rcmos] = ACTIONS(4400),
    [anon_sym_bufif0] = ACTIONS(4400),
    [anon_sym_bufif1] = ACTIONS(4400),
    [anon_sym_notif0] = ACTIONS(4400),
    [anon_sym_notif1] = ACTIONS(4400),
    [anon_sym_nmos] = ACTIONS(4400),
    [anon_sym_pmos] = ACTIONS(4400),
    [anon_sym_rnmos] = ACTIONS(4400),
    [anon_sym_rpmos] = ACTIONS(4400),
    [anon_sym_nand] = ACTIONS(4400),
    [anon_sym_nor] = ACTIONS(4400),
    [anon_sym_xor] = ACTIONS(4400),
    [anon_sym_xnor] = ACTIONS(4400),
    [anon_sym_buf] = ACTIONS(4400),
    [anon_sym_tranif0] = ACTIONS(4400),
    [anon_sym_tranif1] = ACTIONS(4400),
    [anon_sym_rtranif1] = ACTIONS(4400),
    [anon_sym_rtranif0] = ACTIONS(4400),
    [anon_sym_tran] = ACTIONS(4400),
    [anon_sym_rtran] = ACTIONS(4400),
    [anon_sym_generate] = ACTIONS(4400),
    [anon_sym_for] = ACTIONS(4400),
    [anon_sym_initial] = ACTIONS(4400),
    [anon_sym_assign] = ACTIONS(4400),
    [anon_sym_alias] = ACTIONS(4400),
    [anon_sym_always_comb] = ACTIONS(4400),
    [anon_sym_always_latch] = ACTIONS(4400),
    [anon_sym_always_ff] = ACTIONS(4400),
    [anon_sym_final] = ACTIONS(4400),
    [anon_sym_global] = ACTIONS(4400),
    [anon_sym_LPAREN_STAR] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4398),
    [anon_sym_DOLLARunit] = ACTIONS(4398),
  },
  [4437] = {
    [sym_simple_identifier] = ACTIONS(5682),
    [anon_sym_wire] = ACTIONS(5682),
    [anon_sym_tri] = ACTIONS(5682),
    [anon_sym_tri0] = ACTIONS(5682),
    [anon_sym_tri1] = ACTIONS(5682),
    [anon_sym_wand] = ACTIONS(5682),
    [anon_sym_triand] = ACTIONS(5682),
    [anon_sym_wor] = ACTIONS(5682),
    [anon_sym_trior] = ACTIONS(5682),
    [anon_sym_trireg] = ACTIONS(5682),
    [anon_sym_uwire] = ACTIONS(5682),
    [anon_sym_SEMI] = ACTIONS(5684),
    [anon_sym_COLON] = ACTIONS(5684),
    [anon_sym_extern] = ACTIONS(5682),
    [anon_sym_interface] = ACTIONS(5682),
    [anon_sym_checker] = ACTIONS(5682),
    [anon_sym_virtual] = ACTIONS(5682),
    [anon_sym_class] = ACTIONS(5682),
    [anon_sym_type] = ACTIONS(5682),
    [anon_sym_DOLLARfatal] = ACTIONS(5684),
    [anon_sym_DOLLARerror] = ACTIONS(5684),
    [anon_sym_DOLLARwarning] = ACTIONS(5684),
    [anon_sym_DOLLARinfo] = ACTIONS(5684),
    [anon_sym_default] = ACTIONS(5682),
    [anon_sym_clocking] = ACTIONS(5682),
    [anon_sym_defparam] = ACTIONS(5682),
    [anon_sym_bind] = ACTIONS(5682),
    [anon_sym_rand] = ACTIONS(5682),
    [anon_sym_const] = ACTIONS(5682),
    [anon_sym_function] = ACTIONS(5682),
    [anon_sym_static] = ACTIONS(5682),
    [anon_sym_constraint] = ACTIONS(5682),
    [anon_sym_if] = ACTIONS(5682),
    [anon_sym_else] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5684),
    [anon_sym_localparam] = ACTIONS(5682),
    [anon_sym_parameter] = ACTIONS(5682),
    [anon_sym_var] = ACTIONS(5682),
    [anon_sym_import] = ACTIONS(5682),
    [anon_sym_export] = ACTIONS(5682),
    [anon_sym_genvar] = ACTIONS(5682),
    [anon_sym_interconnect] = ACTIONS(5682),
    [anon_sym_typedef] = ACTIONS(5682),
    [anon_sym_enum] = ACTIONS(5682),
    [anon_sym_struct] = ACTIONS(5682),
    [anon_sym_union] = ACTIONS(5682),
    [anon_sym_nettype] = ACTIONS(5682),
    [anon_sym_automatic] = ACTIONS(5682),
    [anon_sym_string] = ACTIONS(5682),
    [anon_sym_chandle] = ACTIONS(5682),
    [anon_sym_event] = ACTIONS(5682),
    [anon_sym_byte] = ACTIONS(5682),
    [anon_sym_shortint] = ACTIONS(5682),
    [anon_sym_int] = ACTIONS(5682),
    [anon_sym_longint] = ACTIONS(5682),
    [anon_sym_integer] = ACTIONS(5682),
    [anon_sym_time] = ACTIONS(5682),
    [anon_sym_bit] = ACTIONS(5682),
    [anon_sym_logic] = ACTIONS(5682),
    [anon_sym_reg] = ACTIONS(5682),
    [anon_sym_shortreal] = ACTIONS(5682),
    [anon_sym_real] = ACTIONS(5682),
    [anon_sym_realtime] = ACTIONS(5682),
    [anon_sym_supply0] = ACTIONS(5682),
    [anon_sym_supply1] = ACTIONS(5682),
    [anon_sym_signed] = ACTIONS(5682),
    [anon_sym_unsigned] = ACTIONS(5682),
    [anon_sym_task] = ACTIONS(5682),
    [anon_sym_assert] = ACTIONS(5682),
    [anon_sym_property] = ACTIONS(5682),
    [anon_sym_assume] = ACTIONS(5682),
    [anon_sym_cover] = ACTIONS(5682),
    [anon_sym_sequence] = ACTIONS(5682),
    [anon_sym_restrict] = ACTIONS(5682),
    [anon_sym_not] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_case] = ACTIONS(5682),
    [anon_sym_always] = ACTIONS(5682),
    [anon_sym_covergroup] = ACTIONS(5682),
    [anon_sym_let] = ACTIONS(5682),
    [anon_sym_pulldown] = ACTIONS(5682),
    [anon_sym_pullup] = ACTIONS(5682),
    [anon_sym_cmos] = ACTIONS(5682),
    [anon_sym_rcmos] = ACTIONS(5682),
    [anon_sym_bufif0] = ACTIONS(5682),
    [anon_sym_bufif1] = ACTIONS(5682),
    [anon_sym_notif0] = ACTIONS(5682),
    [anon_sym_notif1] = ACTIONS(5682),
    [anon_sym_nmos] = ACTIONS(5682),
    [anon_sym_pmos] = ACTIONS(5682),
    [anon_sym_rnmos] = ACTIONS(5682),
    [anon_sym_rpmos] = ACTIONS(5682),
    [anon_sym_nand] = ACTIONS(5682),
    [anon_sym_nor] = ACTIONS(5682),
    [anon_sym_xor] = ACTIONS(5682),
    [anon_sym_xnor] = ACTIONS(5682),
    [anon_sym_buf] = ACTIONS(5682),
    [anon_sym_tranif0] = ACTIONS(5682),
    [anon_sym_tranif1] = ACTIONS(5682),
    [anon_sym_rtranif1] = ACTIONS(5682),
    [anon_sym_rtranif0] = ACTIONS(5682),
    [anon_sym_tran] = ACTIONS(5682),
    [anon_sym_rtran] = ACTIONS(5682),
    [anon_sym_generate] = ACTIONS(5682),
    [anon_sym_endgenerate] = ACTIONS(5682),
    [anon_sym_for] = ACTIONS(5682),
    [anon_sym_initial] = ACTIONS(5682),
    [anon_sym_assign] = ACTIONS(5682),
    [anon_sym_alias] = ACTIONS(5682),
    [anon_sym_always_comb] = ACTIONS(5682),
    [anon_sym_always_latch] = ACTIONS(5682),
    [anon_sym_always_ff] = ACTIONS(5682),
    [anon_sym_final] = ACTIONS(5682),
    [anon_sym_global] = ACTIONS(5682),
    [anon_sym_LPAREN_STAR] = ACTIONS(5684),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5684),
    [anon_sym_DOLLARunit] = ACTIONS(5684),
  },
  [4438] = {
    [sym_simple_identifier] = ACTIONS(5688),
    [anon_sym_wire] = ACTIONS(5688),
    [anon_sym_tri] = ACTIONS(5688),
    [anon_sym_tri0] = ACTIONS(5688),
    [anon_sym_tri1] = ACTIONS(5688),
    [anon_sym_wand] = ACTIONS(5688),
    [anon_sym_triand] = ACTIONS(5688),
    [anon_sym_wor] = ACTIONS(5688),
    [anon_sym_trior] = ACTIONS(5688),
    [anon_sym_trireg] = ACTIONS(5688),
    [anon_sym_uwire] = ACTIONS(5688),
    [anon_sym_SEMI] = ACTIONS(5690),
    [anon_sym_COLON] = ACTIONS(10593),
    [anon_sym_extern] = ACTIONS(5688),
    [anon_sym_interface] = ACTIONS(5688),
    [anon_sym_checker] = ACTIONS(5688),
    [anon_sym_virtual] = ACTIONS(5688),
    [anon_sym_class] = ACTIONS(5688),
    [anon_sym_type] = ACTIONS(5688),
    [anon_sym_DOLLARfatal] = ACTIONS(5690),
    [anon_sym_DOLLARerror] = ACTIONS(5690),
    [anon_sym_DOLLARwarning] = ACTIONS(5690),
    [anon_sym_DOLLARinfo] = ACTIONS(5690),
    [anon_sym_default] = ACTIONS(5688),
    [anon_sym_clocking] = ACTIONS(5688),
    [anon_sym_defparam] = ACTIONS(5688),
    [anon_sym_bind] = ACTIONS(5688),
    [anon_sym_rand] = ACTIONS(5688),
    [anon_sym_const] = ACTIONS(5688),
    [anon_sym_function] = ACTIONS(5688),
    [anon_sym_static] = ACTIONS(5688),
    [anon_sym_constraint] = ACTIONS(5688),
    [anon_sym_if] = ACTIONS(5688),
    [anon_sym_else] = ACTIONS(5688),
    [anon_sym_LBRACK] = ACTIONS(5690),
    [anon_sym_localparam] = ACTIONS(5688),
    [anon_sym_parameter] = ACTIONS(5688),
    [anon_sym_var] = ACTIONS(5688),
    [anon_sym_import] = ACTIONS(5688),
    [anon_sym_export] = ACTIONS(5688),
    [anon_sym_genvar] = ACTIONS(5688),
    [anon_sym_interconnect] = ACTIONS(5688),
    [anon_sym_typedef] = ACTIONS(5688),
    [anon_sym_enum] = ACTIONS(5688),
    [anon_sym_struct] = ACTIONS(5688),
    [anon_sym_union] = ACTIONS(5688),
    [anon_sym_nettype] = ACTIONS(5688),
    [anon_sym_automatic] = ACTIONS(5688),
    [anon_sym_string] = ACTIONS(5688),
    [anon_sym_chandle] = ACTIONS(5688),
    [anon_sym_event] = ACTIONS(5688),
    [anon_sym_byte] = ACTIONS(5688),
    [anon_sym_shortint] = ACTIONS(5688),
    [anon_sym_int] = ACTIONS(5688),
    [anon_sym_longint] = ACTIONS(5688),
    [anon_sym_integer] = ACTIONS(5688),
    [anon_sym_time] = ACTIONS(5688),
    [anon_sym_bit] = ACTIONS(5688),
    [anon_sym_logic] = ACTIONS(5688),
    [anon_sym_reg] = ACTIONS(5688),
    [anon_sym_shortreal] = ACTIONS(5688),
    [anon_sym_real] = ACTIONS(5688),
    [anon_sym_realtime] = ACTIONS(5688),
    [anon_sym_supply0] = ACTIONS(5688),
    [anon_sym_supply1] = ACTIONS(5688),
    [anon_sym_signed] = ACTIONS(5688),
    [anon_sym_unsigned] = ACTIONS(5688),
    [anon_sym_task] = ACTIONS(5688),
    [anon_sym_assert] = ACTIONS(5688),
    [anon_sym_property] = ACTIONS(5688),
    [anon_sym_assume] = ACTIONS(5688),
    [anon_sym_cover] = ACTIONS(5688),
    [anon_sym_sequence] = ACTIONS(5688),
    [anon_sym_restrict] = ACTIONS(5688),
    [anon_sym_not] = ACTIONS(5688),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_and] = ACTIONS(5688),
    [anon_sym_case] = ACTIONS(5688),
    [anon_sym_always] = ACTIONS(5688),
    [anon_sym_covergroup] = ACTIONS(5688),
    [anon_sym_let] = ACTIONS(5688),
    [anon_sym_pulldown] = ACTIONS(5688),
    [anon_sym_pullup] = ACTIONS(5688),
    [anon_sym_cmos] = ACTIONS(5688),
    [anon_sym_rcmos] = ACTIONS(5688),
    [anon_sym_bufif0] = ACTIONS(5688),
    [anon_sym_bufif1] = ACTIONS(5688),
    [anon_sym_notif0] = ACTIONS(5688),
    [anon_sym_notif1] = ACTIONS(5688),
    [anon_sym_nmos] = ACTIONS(5688),
    [anon_sym_pmos] = ACTIONS(5688),
    [anon_sym_rnmos] = ACTIONS(5688),
    [anon_sym_rpmos] = ACTIONS(5688),
    [anon_sym_nand] = ACTIONS(5688),
    [anon_sym_nor] = ACTIONS(5688),
    [anon_sym_xor] = ACTIONS(5688),
    [anon_sym_xnor] = ACTIONS(5688),
    [anon_sym_buf] = ACTIONS(5688),
    [anon_sym_tranif0] = ACTIONS(5688),
    [anon_sym_tranif1] = ACTIONS(5688),
    [anon_sym_rtranif1] = ACTIONS(5688),
    [anon_sym_rtranif0] = ACTIONS(5688),
    [anon_sym_tran] = ACTIONS(5688),
    [anon_sym_rtran] = ACTIONS(5688),
    [anon_sym_generate] = ACTIONS(5688),
    [anon_sym_endgenerate] = ACTIONS(5688),
    [anon_sym_for] = ACTIONS(5688),
    [anon_sym_initial] = ACTIONS(5688),
    [anon_sym_assign] = ACTIONS(5688),
    [anon_sym_alias] = ACTIONS(5688),
    [anon_sym_always_comb] = ACTIONS(5688),
    [anon_sym_always_latch] = ACTIONS(5688),
    [anon_sym_always_ff] = ACTIONS(5688),
    [anon_sym_final] = ACTIONS(5688),
    [anon_sym_global] = ACTIONS(5688),
    [anon_sym_LPAREN_STAR] = ACTIONS(5690),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5690),
    [anon_sym_DOLLARunit] = ACTIONS(5690),
  },
  [4439] = {
    [sym_simple_identifier] = ACTIONS(5870),
    [anon_sym_wire] = ACTIONS(5870),
    [anon_sym_tri] = ACTIONS(5870),
    [anon_sym_tri0] = ACTIONS(5870),
    [anon_sym_tri1] = ACTIONS(5870),
    [anon_sym_wand] = ACTIONS(5870),
    [anon_sym_triand] = ACTIONS(5870),
    [anon_sym_wor] = ACTIONS(5870),
    [anon_sym_trior] = ACTIONS(5870),
    [anon_sym_trireg] = ACTIONS(5870),
    [anon_sym_uwire] = ACTIONS(5870),
    [anon_sym_SEMI] = ACTIONS(5872),
    [anon_sym_COLON] = ACTIONS(10595),
    [anon_sym_extern] = ACTIONS(5870),
    [anon_sym_interface] = ACTIONS(5870),
    [anon_sym_checker] = ACTIONS(5870),
    [anon_sym_virtual] = ACTIONS(5870),
    [anon_sym_class] = ACTIONS(5870),
    [anon_sym_type] = ACTIONS(5870),
    [anon_sym_DOLLARfatal] = ACTIONS(5872),
    [anon_sym_DOLLARerror] = ACTIONS(5872),
    [anon_sym_DOLLARwarning] = ACTIONS(5872),
    [anon_sym_DOLLARinfo] = ACTIONS(5872),
    [anon_sym_default] = ACTIONS(5870),
    [anon_sym_clocking] = ACTIONS(5870),
    [anon_sym_defparam] = ACTIONS(5870),
    [anon_sym_bind] = ACTIONS(5870),
    [anon_sym_rand] = ACTIONS(5870),
    [anon_sym_const] = ACTIONS(5870),
    [anon_sym_function] = ACTIONS(5870),
    [anon_sym_static] = ACTIONS(5870),
    [anon_sym_constraint] = ACTIONS(5870),
    [anon_sym_if] = ACTIONS(5870),
    [anon_sym_else] = ACTIONS(5870),
    [anon_sym_LBRACK] = ACTIONS(5872),
    [anon_sym_localparam] = ACTIONS(5870),
    [anon_sym_parameter] = ACTIONS(5870),
    [anon_sym_var] = ACTIONS(5870),
    [anon_sym_import] = ACTIONS(5870),
    [anon_sym_export] = ACTIONS(5870),
    [anon_sym_genvar] = ACTIONS(5870),
    [anon_sym_interconnect] = ACTIONS(5870),
    [anon_sym_typedef] = ACTIONS(5870),
    [anon_sym_enum] = ACTIONS(5870),
    [anon_sym_struct] = ACTIONS(5870),
    [anon_sym_union] = ACTIONS(5870),
    [anon_sym_nettype] = ACTIONS(5870),
    [anon_sym_automatic] = ACTIONS(5870),
    [anon_sym_string] = ACTIONS(5870),
    [anon_sym_chandle] = ACTIONS(5870),
    [anon_sym_event] = ACTIONS(5870),
    [anon_sym_byte] = ACTIONS(5870),
    [anon_sym_shortint] = ACTIONS(5870),
    [anon_sym_int] = ACTIONS(5870),
    [anon_sym_longint] = ACTIONS(5870),
    [anon_sym_integer] = ACTIONS(5870),
    [anon_sym_time] = ACTIONS(5870),
    [anon_sym_bit] = ACTIONS(5870),
    [anon_sym_logic] = ACTIONS(5870),
    [anon_sym_reg] = ACTIONS(5870),
    [anon_sym_shortreal] = ACTIONS(5870),
    [anon_sym_real] = ACTIONS(5870),
    [anon_sym_realtime] = ACTIONS(5870),
    [anon_sym_supply0] = ACTIONS(5870),
    [anon_sym_supply1] = ACTIONS(5870),
    [anon_sym_signed] = ACTIONS(5870),
    [anon_sym_unsigned] = ACTIONS(5870),
    [anon_sym_task] = ACTIONS(5870),
    [anon_sym_assert] = ACTIONS(5870),
    [anon_sym_property] = ACTIONS(5870),
    [anon_sym_assume] = ACTIONS(5870),
    [anon_sym_cover] = ACTIONS(5870),
    [anon_sym_sequence] = ACTIONS(5870),
    [anon_sym_restrict] = ACTIONS(5870),
    [anon_sym_not] = ACTIONS(5870),
    [anon_sym_or] = ACTIONS(5870),
    [anon_sym_and] = ACTIONS(5870),
    [anon_sym_case] = ACTIONS(5870),
    [anon_sym_always] = ACTIONS(5870),
    [anon_sym_covergroup] = ACTIONS(5870),
    [anon_sym_end] = ACTIONS(5870),
    [anon_sym_let] = ACTIONS(5870),
    [anon_sym_pulldown] = ACTIONS(5870),
    [anon_sym_pullup] = ACTIONS(5870),
    [anon_sym_cmos] = ACTIONS(5870),
    [anon_sym_rcmos] = ACTIONS(5870),
    [anon_sym_bufif0] = ACTIONS(5870),
    [anon_sym_bufif1] = ACTIONS(5870),
    [anon_sym_notif0] = ACTIONS(5870),
    [anon_sym_notif1] = ACTIONS(5870),
    [anon_sym_nmos] = ACTIONS(5870),
    [anon_sym_pmos] = ACTIONS(5870),
    [anon_sym_rnmos] = ACTIONS(5870),
    [anon_sym_rpmos] = ACTIONS(5870),
    [anon_sym_nand] = ACTIONS(5870),
    [anon_sym_nor] = ACTIONS(5870),
    [anon_sym_xor] = ACTIONS(5870),
    [anon_sym_xnor] = ACTIONS(5870),
    [anon_sym_buf] = ACTIONS(5870),
    [anon_sym_tranif0] = ACTIONS(5870),
    [anon_sym_tranif1] = ACTIONS(5870),
    [anon_sym_rtranif1] = ACTIONS(5870),
    [anon_sym_rtranif0] = ACTIONS(5870),
    [anon_sym_tran] = ACTIONS(5870),
    [anon_sym_rtran] = ACTIONS(5870),
    [anon_sym_generate] = ACTIONS(5870),
    [anon_sym_for] = ACTIONS(5870),
    [anon_sym_initial] = ACTIONS(5870),
    [anon_sym_assign] = ACTIONS(5870),
    [anon_sym_alias] = ACTIONS(5870),
    [anon_sym_always_comb] = ACTIONS(5870),
    [anon_sym_always_latch] = ACTIONS(5870),
    [anon_sym_always_ff] = ACTIONS(5870),
    [anon_sym_final] = ACTIONS(5870),
    [anon_sym_global] = ACTIONS(5870),
    [anon_sym_LPAREN_STAR] = ACTIONS(5872),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5872),
    [anon_sym_DOLLARunit] = ACTIONS(5872),
  },
  [4440] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(10597),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_rand] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_end] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [4441] = {
    [sym_simple_identifier] = ACTIONS(4388),
    [anon_sym_wire] = ACTIONS(4388),
    [anon_sym_tri] = ACTIONS(4388),
    [anon_sym_tri0] = ACTIONS(4388),
    [anon_sym_tri1] = ACTIONS(4388),
    [anon_sym_wand] = ACTIONS(4388),
    [anon_sym_triand] = ACTIONS(4388),
    [anon_sym_wor] = ACTIONS(4388),
    [anon_sym_trior] = ACTIONS(4388),
    [anon_sym_trireg] = ACTIONS(4388),
    [anon_sym_uwire] = ACTIONS(4388),
    [anon_sym_SEMI] = ACTIONS(4386),
    [anon_sym_COLON] = ACTIONS(10599),
    [anon_sym_extern] = ACTIONS(4388),
    [anon_sym_interface] = ACTIONS(4388),
    [anon_sym_checker] = ACTIONS(4388),
    [anon_sym_virtual] = ACTIONS(4388),
    [anon_sym_class] = ACTIONS(4388),
    [anon_sym_type] = ACTIONS(4388),
    [anon_sym_DOLLARfatal] = ACTIONS(4386),
    [anon_sym_DOLLARerror] = ACTIONS(4386),
    [anon_sym_DOLLARwarning] = ACTIONS(4386),
    [anon_sym_DOLLARinfo] = ACTIONS(4386),
    [anon_sym_default] = ACTIONS(4388),
    [anon_sym_clocking] = ACTIONS(4388),
    [anon_sym_defparam] = ACTIONS(4388),
    [anon_sym_bind] = ACTIONS(4388),
    [anon_sym_rand] = ACTIONS(4388),
    [anon_sym_const] = ACTIONS(4388),
    [anon_sym_function] = ACTIONS(4388),
    [anon_sym_static] = ACTIONS(4388),
    [anon_sym_constraint] = ACTIONS(4388),
    [anon_sym_if] = ACTIONS(4388),
    [anon_sym_else] = ACTIONS(4388),
    [anon_sym_LBRACK] = ACTIONS(4386),
    [anon_sym_localparam] = ACTIONS(4388),
    [anon_sym_parameter] = ACTIONS(4388),
    [anon_sym_var] = ACTIONS(4388),
    [anon_sym_import] = ACTIONS(4388),
    [anon_sym_export] = ACTIONS(4388),
    [anon_sym_genvar] = ACTIONS(4388),
    [anon_sym_interconnect] = ACTIONS(4388),
    [anon_sym_typedef] = ACTIONS(4388),
    [anon_sym_enum] = ACTIONS(4388),
    [anon_sym_struct] = ACTIONS(4388),
    [anon_sym_union] = ACTIONS(4388),
    [anon_sym_nettype] = ACTIONS(4388),
    [anon_sym_automatic] = ACTIONS(4388),
    [anon_sym_string] = ACTIONS(4388),
    [anon_sym_chandle] = ACTIONS(4388),
    [anon_sym_event] = ACTIONS(4388),
    [anon_sym_byte] = ACTIONS(4388),
    [anon_sym_shortint] = ACTIONS(4388),
    [anon_sym_int] = ACTIONS(4388),
    [anon_sym_longint] = ACTIONS(4388),
    [anon_sym_integer] = ACTIONS(4388),
    [anon_sym_time] = ACTIONS(4388),
    [anon_sym_bit] = ACTIONS(4388),
    [anon_sym_logic] = ACTIONS(4388),
    [anon_sym_reg] = ACTIONS(4388),
    [anon_sym_shortreal] = ACTIONS(4388),
    [anon_sym_real] = ACTIONS(4388),
    [anon_sym_realtime] = ACTIONS(4388),
    [anon_sym_supply0] = ACTIONS(4388),
    [anon_sym_supply1] = ACTIONS(4388),
    [anon_sym_signed] = ACTIONS(4388),
    [anon_sym_unsigned] = ACTIONS(4388),
    [anon_sym_task] = ACTIONS(4388),
    [anon_sym_assert] = ACTIONS(4388),
    [anon_sym_property] = ACTIONS(4388),
    [anon_sym_assume] = ACTIONS(4388),
    [anon_sym_cover] = ACTIONS(4388),
    [anon_sym_sequence] = ACTIONS(4388),
    [anon_sym_restrict] = ACTIONS(4388),
    [anon_sym_not] = ACTIONS(4388),
    [anon_sym_or] = ACTIONS(4388),
    [anon_sym_and] = ACTIONS(4388),
    [anon_sym_case] = ACTIONS(4388),
    [anon_sym_always] = ACTIONS(4388),
    [anon_sym_covergroup] = ACTIONS(4388),
    [anon_sym_end] = ACTIONS(4388),
    [anon_sym_let] = ACTIONS(4388),
    [anon_sym_pulldown] = ACTIONS(4388),
    [anon_sym_pullup] = ACTIONS(4388),
    [anon_sym_cmos] = ACTIONS(4388),
    [anon_sym_rcmos] = ACTIONS(4388),
    [anon_sym_bufif0] = ACTIONS(4388),
    [anon_sym_bufif1] = ACTIONS(4388),
    [anon_sym_notif0] = ACTIONS(4388),
    [anon_sym_notif1] = ACTIONS(4388),
    [anon_sym_nmos] = ACTIONS(4388),
    [anon_sym_pmos] = ACTIONS(4388),
    [anon_sym_rnmos] = ACTIONS(4388),
    [anon_sym_rpmos] = ACTIONS(4388),
    [anon_sym_nand] = ACTIONS(4388),
    [anon_sym_nor] = ACTIONS(4388),
    [anon_sym_xor] = ACTIONS(4388),
    [anon_sym_xnor] = ACTIONS(4388),
    [anon_sym_buf] = ACTIONS(4388),
    [anon_sym_tranif0] = ACTIONS(4388),
    [anon_sym_tranif1] = ACTIONS(4388),
    [anon_sym_rtranif1] = ACTIONS(4388),
    [anon_sym_rtranif0] = ACTIONS(4388),
    [anon_sym_tran] = ACTIONS(4388),
    [anon_sym_rtran] = ACTIONS(4388),
    [anon_sym_generate] = ACTIONS(4388),
    [anon_sym_for] = ACTIONS(4388),
    [anon_sym_initial] = ACTIONS(4388),
    [anon_sym_assign] = ACTIONS(4388),
    [anon_sym_alias] = ACTIONS(4388),
    [anon_sym_always_comb] = ACTIONS(4388),
    [anon_sym_always_latch] = ACTIONS(4388),
    [anon_sym_always_ff] = ACTIONS(4388),
    [anon_sym_final] = ACTIONS(4388),
    [anon_sym_global] = ACTIONS(4388),
    [anon_sym_LPAREN_STAR] = ACTIONS(4386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4386),
    [anon_sym_DOLLARunit] = ACTIONS(4386),
  },
  [4442] = {
    [sym_simple_identifier] = ACTIONS(4500),
    [anon_sym_wire] = ACTIONS(4500),
    [anon_sym_tri] = ACTIONS(4500),
    [anon_sym_tri0] = ACTIONS(4500),
    [anon_sym_tri1] = ACTIONS(4500),
    [anon_sym_wand] = ACTIONS(4500),
    [anon_sym_triand] = ACTIONS(4500),
    [anon_sym_wor] = ACTIONS(4500),
    [anon_sym_trior] = ACTIONS(4500),
    [anon_sym_trireg] = ACTIONS(4500),
    [anon_sym_uwire] = ACTIONS(4500),
    [anon_sym_SEMI] = ACTIONS(4498),
    [anon_sym_COLON] = ACTIONS(10601),
    [anon_sym_extern] = ACTIONS(4500),
    [anon_sym_interface] = ACTIONS(4500),
    [anon_sym_checker] = ACTIONS(4500),
    [anon_sym_virtual] = ACTIONS(4500),
    [anon_sym_class] = ACTIONS(4500),
    [anon_sym_type] = ACTIONS(4500),
    [anon_sym_DOLLARfatal] = ACTIONS(4498),
    [anon_sym_DOLLARerror] = ACTIONS(4498),
    [anon_sym_DOLLARwarning] = ACTIONS(4498),
    [anon_sym_DOLLARinfo] = ACTIONS(4498),
    [anon_sym_default] = ACTIONS(4500),
    [anon_sym_clocking] = ACTIONS(4500),
    [anon_sym_defparam] = ACTIONS(4500),
    [anon_sym_bind] = ACTIONS(4500),
    [anon_sym_rand] = ACTIONS(4500),
    [anon_sym_const] = ACTIONS(4500),
    [anon_sym_function] = ACTIONS(4500),
    [anon_sym_static] = ACTIONS(4500),
    [anon_sym_constraint] = ACTIONS(4500),
    [anon_sym_if] = ACTIONS(4500),
    [anon_sym_else] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4498),
    [anon_sym_localparam] = ACTIONS(4500),
    [anon_sym_parameter] = ACTIONS(4500),
    [anon_sym_var] = ACTIONS(4500),
    [anon_sym_import] = ACTIONS(4500),
    [anon_sym_export] = ACTIONS(4500),
    [anon_sym_genvar] = ACTIONS(4500),
    [anon_sym_interconnect] = ACTIONS(4500),
    [anon_sym_typedef] = ACTIONS(4500),
    [anon_sym_enum] = ACTIONS(4500),
    [anon_sym_struct] = ACTIONS(4500),
    [anon_sym_union] = ACTIONS(4500),
    [anon_sym_nettype] = ACTIONS(4500),
    [anon_sym_automatic] = ACTIONS(4500),
    [anon_sym_string] = ACTIONS(4500),
    [anon_sym_chandle] = ACTIONS(4500),
    [anon_sym_event] = ACTIONS(4500),
    [anon_sym_byte] = ACTIONS(4500),
    [anon_sym_shortint] = ACTIONS(4500),
    [anon_sym_int] = ACTIONS(4500),
    [anon_sym_longint] = ACTIONS(4500),
    [anon_sym_integer] = ACTIONS(4500),
    [anon_sym_time] = ACTIONS(4500),
    [anon_sym_bit] = ACTIONS(4500),
    [anon_sym_logic] = ACTIONS(4500),
    [anon_sym_reg] = ACTIONS(4500),
    [anon_sym_shortreal] = ACTIONS(4500),
    [anon_sym_real] = ACTIONS(4500),
    [anon_sym_realtime] = ACTIONS(4500),
    [anon_sym_supply0] = ACTIONS(4500),
    [anon_sym_supply1] = ACTIONS(4500),
    [anon_sym_signed] = ACTIONS(4500),
    [anon_sym_unsigned] = ACTIONS(4500),
    [anon_sym_task] = ACTIONS(4500),
    [anon_sym_assert] = ACTIONS(4500),
    [anon_sym_property] = ACTIONS(4500),
    [anon_sym_assume] = ACTIONS(4500),
    [anon_sym_cover] = ACTIONS(4500),
    [anon_sym_sequence] = ACTIONS(4500),
    [anon_sym_restrict] = ACTIONS(4500),
    [anon_sym_not] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_case] = ACTIONS(4500),
    [anon_sym_always] = ACTIONS(4500),
    [anon_sym_covergroup] = ACTIONS(4500),
    [anon_sym_let] = ACTIONS(4500),
    [anon_sym_pulldown] = ACTIONS(4500),
    [anon_sym_pullup] = ACTIONS(4500),
    [anon_sym_cmos] = ACTIONS(4500),
    [anon_sym_rcmos] = ACTIONS(4500),
    [anon_sym_bufif0] = ACTIONS(4500),
    [anon_sym_bufif1] = ACTIONS(4500),
    [anon_sym_notif0] = ACTIONS(4500),
    [anon_sym_notif1] = ACTIONS(4500),
    [anon_sym_nmos] = ACTIONS(4500),
    [anon_sym_pmos] = ACTIONS(4500),
    [anon_sym_rnmos] = ACTIONS(4500),
    [anon_sym_rpmos] = ACTIONS(4500),
    [anon_sym_nand] = ACTIONS(4500),
    [anon_sym_nor] = ACTIONS(4500),
    [anon_sym_xor] = ACTIONS(4500),
    [anon_sym_xnor] = ACTIONS(4500),
    [anon_sym_buf] = ACTIONS(4500),
    [anon_sym_tranif0] = ACTIONS(4500),
    [anon_sym_tranif1] = ACTIONS(4500),
    [anon_sym_rtranif1] = ACTIONS(4500),
    [anon_sym_rtranif0] = ACTIONS(4500),
    [anon_sym_tran] = ACTIONS(4500),
    [anon_sym_rtran] = ACTIONS(4500),
    [anon_sym_generate] = ACTIONS(4500),
    [anon_sym_endgenerate] = ACTIONS(4500),
    [anon_sym_for] = ACTIONS(4500),
    [anon_sym_initial] = ACTIONS(4500),
    [anon_sym_assign] = ACTIONS(4500),
    [anon_sym_alias] = ACTIONS(4500),
    [anon_sym_always_comb] = ACTIONS(4500),
    [anon_sym_always_latch] = ACTIONS(4500),
    [anon_sym_always_ff] = ACTIONS(4500),
    [anon_sym_final] = ACTIONS(4500),
    [anon_sym_global] = ACTIONS(4500),
    [anon_sym_LPAREN_STAR] = ACTIONS(4498),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4498),
    [anon_sym_DOLLARunit] = ACTIONS(4498),
  },
  [4443] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_COLON] = ACTIONS(10603),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_rand] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_end] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [4444] = {
    [sym_simple_identifier] = ACTIONS(4340),
    [anon_sym_wire] = ACTIONS(4340),
    [anon_sym_tri] = ACTIONS(4340),
    [anon_sym_tri0] = ACTIONS(4340),
    [anon_sym_tri1] = ACTIONS(4340),
    [anon_sym_wand] = ACTIONS(4340),
    [anon_sym_triand] = ACTIONS(4340),
    [anon_sym_wor] = ACTIONS(4340),
    [anon_sym_trior] = ACTIONS(4340),
    [anon_sym_trireg] = ACTIONS(4340),
    [anon_sym_uwire] = ACTIONS(4340),
    [anon_sym_SEMI] = ACTIONS(4338),
    [anon_sym_COLON] = ACTIONS(10605),
    [anon_sym_extern] = ACTIONS(4340),
    [anon_sym_interface] = ACTIONS(4340),
    [anon_sym_checker] = ACTIONS(4340),
    [anon_sym_virtual] = ACTIONS(4340),
    [anon_sym_class] = ACTIONS(4340),
    [anon_sym_type] = ACTIONS(4340),
    [anon_sym_DOLLARfatal] = ACTIONS(4338),
    [anon_sym_DOLLARerror] = ACTIONS(4338),
    [anon_sym_DOLLARwarning] = ACTIONS(4338),
    [anon_sym_DOLLARinfo] = ACTIONS(4338),
    [anon_sym_default] = ACTIONS(4340),
    [anon_sym_clocking] = ACTIONS(4340),
    [anon_sym_defparam] = ACTIONS(4340),
    [anon_sym_bind] = ACTIONS(4340),
    [anon_sym_rand] = ACTIONS(4340),
    [anon_sym_const] = ACTIONS(4340),
    [anon_sym_function] = ACTIONS(4340),
    [anon_sym_static] = ACTIONS(4340),
    [anon_sym_constraint] = ACTIONS(4340),
    [anon_sym_if] = ACTIONS(4340),
    [anon_sym_else] = ACTIONS(4340),
    [anon_sym_LBRACK] = ACTIONS(4338),
    [anon_sym_localparam] = ACTIONS(4340),
    [anon_sym_parameter] = ACTIONS(4340),
    [anon_sym_var] = ACTIONS(4340),
    [anon_sym_import] = ACTIONS(4340),
    [anon_sym_export] = ACTIONS(4340),
    [anon_sym_genvar] = ACTIONS(4340),
    [anon_sym_interconnect] = ACTIONS(4340),
    [anon_sym_typedef] = ACTIONS(4340),
    [anon_sym_enum] = ACTIONS(4340),
    [anon_sym_struct] = ACTIONS(4340),
    [anon_sym_union] = ACTIONS(4340),
    [anon_sym_nettype] = ACTIONS(4340),
    [anon_sym_automatic] = ACTIONS(4340),
    [anon_sym_string] = ACTIONS(4340),
    [anon_sym_chandle] = ACTIONS(4340),
    [anon_sym_event] = ACTIONS(4340),
    [anon_sym_byte] = ACTIONS(4340),
    [anon_sym_shortint] = ACTIONS(4340),
    [anon_sym_int] = ACTIONS(4340),
    [anon_sym_longint] = ACTIONS(4340),
    [anon_sym_integer] = ACTIONS(4340),
    [anon_sym_time] = ACTIONS(4340),
    [anon_sym_bit] = ACTIONS(4340),
    [anon_sym_logic] = ACTIONS(4340),
    [anon_sym_reg] = ACTIONS(4340),
    [anon_sym_shortreal] = ACTIONS(4340),
    [anon_sym_real] = ACTIONS(4340),
    [anon_sym_realtime] = ACTIONS(4340),
    [anon_sym_supply0] = ACTIONS(4340),
    [anon_sym_supply1] = ACTIONS(4340),
    [anon_sym_signed] = ACTIONS(4340),
    [anon_sym_unsigned] = ACTIONS(4340),
    [anon_sym_task] = ACTIONS(4340),
    [anon_sym_assert] = ACTIONS(4340),
    [anon_sym_property] = ACTIONS(4340),
    [anon_sym_assume] = ACTIONS(4340),
    [anon_sym_cover] = ACTIONS(4340),
    [anon_sym_sequence] = ACTIONS(4340),
    [anon_sym_restrict] = ACTIONS(4340),
    [anon_sym_not] = ACTIONS(4340),
    [anon_sym_or] = ACTIONS(4340),
    [anon_sym_and] = ACTIONS(4340),
    [anon_sym_case] = ACTIONS(4340),
    [anon_sym_always] = ACTIONS(4340),
    [anon_sym_covergroup] = ACTIONS(4340),
    [anon_sym_end] = ACTIONS(4340),
    [anon_sym_let] = ACTIONS(4340),
    [anon_sym_pulldown] = ACTIONS(4340),
    [anon_sym_pullup] = ACTIONS(4340),
    [anon_sym_cmos] = ACTIONS(4340),
    [anon_sym_rcmos] = ACTIONS(4340),
    [anon_sym_bufif0] = ACTIONS(4340),
    [anon_sym_bufif1] = ACTIONS(4340),
    [anon_sym_notif0] = ACTIONS(4340),
    [anon_sym_notif1] = ACTIONS(4340),
    [anon_sym_nmos] = ACTIONS(4340),
    [anon_sym_pmos] = ACTIONS(4340),
    [anon_sym_rnmos] = ACTIONS(4340),
    [anon_sym_rpmos] = ACTIONS(4340),
    [anon_sym_nand] = ACTIONS(4340),
    [anon_sym_nor] = ACTIONS(4340),
    [anon_sym_xor] = ACTIONS(4340),
    [anon_sym_xnor] = ACTIONS(4340),
    [anon_sym_buf] = ACTIONS(4340),
    [anon_sym_tranif0] = ACTIONS(4340),
    [anon_sym_tranif1] = ACTIONS(4340),
    [anon_sym_rtranif1] = ACTIONS(4340),
    [anon_sym_rtranif0] = ACTIONS(4340),
    [anon_sym_tran] = ACTIONS(4340),
    [anon_sym_rtran] = ACTIONS(4340),
    [anon_sym_generate] = ACTIONS(4340),
    [anon_sym_for] = ACTIONS(4340),
    [anon_sym_initial] = ACTIONS(4340),
    [anon_sym_assign] = ACTIONS(4340),
    [anon_sym_alias] = ACTIONS(4340),
    [anon_sym_always_comb] = ACTIONS(4340),
    [anon_sym_always_latch] = ACTIONS(4340),
    [anon_sym_always_ff] = ACTIONS(4340),
    [anon_sym_final] = ACTIONS(4340),
    [anon_sym_global] = ACTIONS(4340),
    [anon_sym_LPAREN_STAR] = ACTIONS(4338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4338),
    [anon_sym_DOLLARunit] = ACTIONS(4338),
  },
  [4445] = {
    [sym_simple_identifier] = ACTIONS(4442),
    [anon_sym_wire] = ACTIONS(4442),
    [anon_sym_tri] = ACTIONS(4442),
    [anon_sym_tri0] = ACTIONS(4442),
    [anon_sym_tri1] = ACTIONS(4442),
    [anon_sym_wand] = ACTIONS(4442),
    [anon_sym_triand] = ACTIONS(4442),
    [anon_sym_wor] = ACTIONS(4442),
    [anon_sym_trior] = ACTIONS(4442),
    [anon_sym_trireg] = ACTIONS(4442),
    [anon_sym_uwire] = ACTIONS(4442),
    [anon_sym_SEMI] = ACTIONS(4440),
    [anon_sym_COLON] = ACTIONS(10607),
    [anon_sym_extern] = ACTIONS(4442),
    [anon_sym_interface] = ACTIONS(4442),
    [anon_sym_checker] = ACTIONS(4442),
    [anon_sym_virtual] = ACTIONS(4442),
    [anon_sym_class] = ACTIONS(4442),
    [anon_sym_type] = ACTIONS(4442),
    [anon_sym_DOLLARfatal] = ACTIONS(4440),
    [anon_sym_DOLLARerror] = ACTIONS(4440),
    [anon_sym_DOLLARwarning] = ACTIONS(4440),
    [anon_sym_DOLLARinfo] = ACTIONS(4440),
    [anon_sym_default] = ACTIONS(4442),
    [anon_sym_clocking] = ACTIONS(4442),
    [anon_sym_defparam] = ACTIONS(4442),
    [anon_sym_bind] = ACTIONS(4442),
    [anon_sym_rand] = ACTIONS(4442),
    [anon_sym_const] = ACTIONS(4442),
    [anon_sym_function] = ACTIONS(4442),
    [anon_sym_static] = ACTIONS(4442),
    [anon_sym_constraint] = ACTIONS(4442),
    [anon_sym_if] = ACTIONS(4442),
    [anon_sym_else] = ACTIONS(4442),
    [anon_sym_LBRACK] = ACTIONS(4440),
    [anon_sym_localparam] = ACTIONS(4442),
    [anon_sym_parameter] = ACTIONS(4442),
    [anon_sym_var] = ACTIONS(4442),
    [anon_sym_import] = ACTIONS(4442),
    [anon_sym_export] = ACTIONS(4442),
    [anon_sym_genvar] = ACTIONS(4442),
    [anon_sym_interconnect] = ACTIONS(4442),
    [anon_sym_typedef] = ACTIONS(4442),
    [anon_sym_enum] = ACTIONS(4442),
    [anon_sym_struct] = ACTIONS(4442),
    [anon_sym_union] = ACTIONS(4442),
    [anon_sym_nettype] = ACTIONS(4442),
    [anon_sym_automatic] = ACTIONS(4442),
    [anon_sym_string] = ACTIONS(4442),
    [anon_sym_chandle] = ACTIONS(4442),
    [anon_sym_event] = ACTIONS(4442),
    [anon_sym_byte] = ACTIONS(4442),
    [anon_sym_shortint] = ACTIONS(4442),
    [anon_sym_int] = ACTIONS(4442),
    [anon_sym_longint] = ACTIONS(4442),
    [anon_sym_integer] = ACTIONS(4442),
    [anon_sym_time] = ACTIONS(4442),
    [anon_sym_bit] = ACTIONS(4442),
    [anon_sym_logic] = ACTIONS(4442),
    [anon_sym_reg] = ACTIONS(4442),
    [anon_sym_shortreal] = ACTIONS(4442),
    [anon_sym_real] = ACTIONS(4442),
    [anon_sym_realtime] = ACTIONS(4442),
    [anon_sym_supply0] = ACTIONS(4442),
    [anon_sym_supply1] = ACTIONS(4442),
    [anon_sym_signed] = ACTIONS(4442),
    [anon_sym_unsigned] = ACTIONS(4442),
    [anon_sym_task] = ACTIONS(4442),
    [anon_sym_assert] = ACTIONS(4442),
    [anon_sym_property] = ACTIONS(4442),
    [anon_sym_assume] = ACTIONS(4442),
    [anon_sym_cover] = ACTIONS(4442),
    [anon_sym_sequence] = ACTIONS(4442),
    [anon_sym_restrict] = ACTIONS(4442),
    [anon_sym_not] = ACTIONS(4442),
    [anon_sym_or] = ACTIONS(4442),
    [anon_sym_and] = ACTIONS(4442),
    [anon_sym_case] = ACTIONS(4442),
    [anon_sym_always] = ACTIONS(4442),
    [anon_sym_covergroup] = ACTIONS(4442),
    [anon_sym_end] = ACTIONS(4442),
    [anon_sym_let] = ACTIONS(4442),
    [anon_sym_pulldown] = ACTIONS(4442),
    [anon_sym_pullup] = ACTIONS(4442),
    [anon_sym_cmos] = ACTIONS(4442),
    [anon_sym_rcmos] = ACTIONS(4442),
    [anon_sym_bufif0] = ACTIONS(4442),
    [anon_sym_bufif1] = ACTIONS(4442),
    [anon_sym_notif0] = ACTIONS(4442),
    [anon_sym_notif1] = ACTIONS(4442),
    [anon_sym_nmos] = ACTIONS(4442),
    [anon_sym_pmos] = ACTIONS(4442),
    [anon_sym_rnmos] = ACTIONS(4442),
    [anon_sym_rpmos] = ACTIONS(4442),
    [anon_sym_nand] = ACTIONS(4442),
    [anon_sym_nor] = ACTIONS(4442),
    [anon_sym_xor] = ACTIONS(4442),
    [anon_sym_xnor] = ACTIONS(4442),
    [anon_sym_buf] = ACTIONS(4442),
    [anon_sym_tranif0] = ACTIONS(4442),
    [anon_sym_tranif1] = ACTIONS(4442),
    [anon_sym_rtranif1] = ACTIONS(4442),
    [anon_sym_rtranif0] = ACTIONS(4442),
    [anon_sym_tran] = ACTIONS(4442),
    [anon_sym_rtran] = ACTIONS(4442),
    [anon_sym_generate] = ACTIONS(4442),
    [anon_sym_for] = ACTIONS(4442),
    [anon_sym_initial] = ACTIONS(4442),
    [anon_sym_assign] = ACTIONS(4442),
    [anon_sym_alias] = ACTIONS(4442),
    [anon_sym_always_comb] = ACTIONS(4442),
    [anon_sym_always_latch] = ACTIONS(4442),
    [anon_sym_always_ff] = ACTIONS(4442),
    [anon_sym_final] = ACTIONS(4442),
    [anon_sym_global] = ACTIONS(4442),
    [anon_sym_LPAREN_STAR] = ACTIONS(4440),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4440),
    [anon_sym_DOLLARunit] = ACTIONS(4440),
  },
  [4446] = {
    [sym_simple_identifier] = ACTIONS(4448),
    [anon_sym_wire] = ACTIONS(4448),
    [anon_sym_tri] = ACTIONS(4448),
    [anon_sym_tri0] = ACTIONS(4448),
    [anon_sym_tri1] = ACTIONS(4448),
    [anon_sym_wand] = ACTIONS(4448),
    [anon_sym_triand] = ACTIONS(4448),
    [anon_sym_wor] = ACTIONS(4448),
    [anon_sym_trior] = ACTIONS(4448),
    [anon_sym_trireg] = ACTIONS(4448),
    [anon_sym_uwire] = ACTIONS(4448),
    [anon_sym_SEMI] = ACTIONS(4446),
    [anon_sym_COLON] = ACTIONS(10609),
    [anon_sym_extern] = ACTIONS(4448),
    [anon_sym_interface] = ACTIONS(4448),
    [anon_sym_checker] = ACTIONS(4448),
    [anon_sym_virtual] = ACTIONS(4448),
    [anon_sym_class] = ACTIONS(4448),
    [anon_sym_type] = ACTIONS(4448),
    [anon_sym_DOLLARfatal] = ACTIONS(4446),
    [anon_sym_DOLLARerror] = ACTIONS(4446),
    [anon_sym_DOLLARwarning] = ACTIONS(4446),
    [anon_sym_DOLLARinfo] = ACTIONS(4446),
    [anon_sym_default] = ACTIONS(4448),
    [anon_sym_clocking] = ACTIONS(4448),
    [anon_sym_defparam] = ACTIONS(4448),
    [anon_sym_bind] = ACTIONS(4448),
    [anon_sym_rand] = ACTIONS(4448),
    [anon_sym_const] = ACTIONS(4448),
    [anon_sym_function] = ACTIONS(4448),
    [anon_sym_static] = ACTIONS(4448),
    [anon_sym_constraint] = ACTIONS(4448),
    [anon_sym_if] = ACTIONS(4448),
    [anon_sym_else] = ACTIONS(4448),
    [anon_sym_LBRACK] = ACTIONS(4446),
    [anon_sym_localparam] = ACTIONS(4448),
    [anon_sym_parameter] = ACTIONS(4448),
    [anon_sym_var] = ACTIONS(4448),
    [anon_sym_import] = ACTIONS(4448),
    [anon_sym_export] = ACTIONS(4448),
    [anon_sym_genvar] = ACTIONS(4448),
    [anon_sym_interconnect] = ACTIONS(4448),
    [anon_sym_typedef] = ACTIONS(4448),
    [anon_sym_enum] = ACTIONS(4448),
    [anon_sym_struct] = ACTIONS(4448),
    [anon_sym_union] = ACTIONS(4448),
    [anon_sym_nettype] = ACTIONS(4448),
    [anon_sym_automatic] = ACTIONS(4448),
    [anon_sym_string] = ACTIONS(4448),
    [anon_sym_chandle] = ACTIONS(4448),
    [anon_sym_event] = ACTIONS(4448),
    [anon_sym_byte] = ACTIONS(4448),
    [anon_sym_shortint] = ACTIONS(4448),
    [anon_sym_int] = ACTIONS(4448),
    [anon_sym_longint] = ACTIONS(4448),
    [anon_sym_integer] = ACTIONS(4448),
    [anon_sym_time] = ACTIONS(4448),
    [anon_sym_bit] = ACTIONS(4448),
    [anon_sym_logic] = ACTIONS(4448),
    [anon_sym_reg] = ACTIONS(4448),
    [anon_sym_shortreal] = ACTIONS(4448),
    [anon_sym_real] = ACTIONS(4448),
    [anon_sym_realtime] = ACTIONS(4448),
    [anon_sym_supply0] = ACTIONS(4448),
    [anon_sym_supply1] = ACTIONS(4448),
    [anon_sym_signed] = ACTIONS(4448),
    [anon_sym_unsigned] = ACTIONS(4448),
    [anon_sym_task] = ACTIONS(4448),
    [anon_sym_assert] = ACTIONS(4448),
    [anon_sym_property] = ACTIONS(4448),
    [anon_sym_assume] = ACTIONS(4448),
    [anon_sym_cover] = ACTIONS(4448),
    [anon_sym_sequence] = ACTIONS(4448),
    [anon_sym_restrict] = ACTIONS(4448),
    [anon_sym_not] = ACTIONS(4448),
    [anon_sym_or] = ACTIONS(4448),
    [anon_sym_and] = ACTIONS(4448),
    [anon_sym_case] = ACTIONS(4448),
    [anon_sym_always] = ACTIONS(4448),
    [anon_sym_covergroup] = ACTIONS(4448),
    [anon_sym_end] = ACTIONS(4448),
    [anon_sym_let] = ACTIONS(4448),
    [anon_sym_pulldown] = ACTIONS(4448),
    [anon_sym_pullup] = ACTIONS(4448),
    [anon_sym_cmos] = ACTIONS(4448),
    [anon_sym_rcmos] = ACTIONS(4448),
    [anon_sym_bufif0] = ACTIONS(4448),
    [anon_sym_bufif1] = ACTIONS(4448),
    [anon_sym_notif0] = ACTIONS(4448),
    [anon_sym_notif1] = ACTIONS(4448),
    [anon_sym_nmos] = ACTIONS(4448),
    [anon_sym_pmos] = ACTIONS(4448),
    [anon_sym_rnmos] = ACTIONS(4448),
    [anon_sym_rpmos] = ACTIONS(4448),
    [anon_sym_nand] = ACTIONS(4448),
    [anon_sym_nor] = ACTIONS(4448),
    [anon_sym_xor] = ACTIONS(4448),
    [anon_sym_xnor] = ACTIONS(4448),
    [anon_sym_buf] = ACTIONS(4448),
    [anon_sym_tranif0] = ACTIONS(4448),
    [anon_sym_tranif1] = ACTIONS(4448),
    [anon_sym_rtranif1] = ACTIONS(4448),
    [anon_sym_rtranif0] = ACTIONS(4448),
    [anon_sym_tran] = ACTIONS(4448),
    [anon_sym_rtran] = ACTIONS(4448),
    [anon_sym_generate] = ACTIONS(4448),
    [anon_sym_for] = ACTIONS(4448),
    [anon_sym_initial] = ACTIONS(4448),
    [anon_sym_assign] = ACTIONS(4448),
    [anon_sym_alias] = ACTIONS(4448),
    [anon_sym_always_comb] = ACTIONS(4448),
    [anon_sym_always_latch] = ACTIONS(4448),
    [anon_sym_always_ff] = ACTIONS(4448),
    [anon_sym_final] = ACTIONS(4448),
    [anon_sym_global] = ACTIONS(4448),
    [anon_sym_LPAREN_STAR] = ACTIONS(4446),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4446),
    [anon_sym_DOLLARunit] = ACTIONS(4446),
  },
  [4447] = {
    [sym_simple_identifier] = ACTIONS(5792),
    [anon_sym_wire] = ACTIONS(5792),
    [anon_sym_tri] = ACTIONS(5792),
    [anon_sym_tri0] = ACTIONS(5792),
    [anon_sym_tri1] = ACTIONS(5792),
    [anon_sym_wand] = ACTIONS(5792),
    [anon_sym_triand] = ACTIONS(5792),
    [anon_sym_wor] = ACTIONS(5792),
    [anon_sym_trior] = ACTIONS(5792),
    [anon_sym_trireg] = ACTIONS(5792),
    [anon_sym_uwire] = ACTIONS(5792),
    [anon_sym_SEMI] = ACTIONS(5794),
    [anon_sym_COLON] = ACTIONS(10611),
    [anon_sym_extern] = ACTIONS(5792),
    [anon_sym_interface] = ACTIONS(5792),
    [anon_sym_checker] = ACTIONS(5792),
    [anon_sym_virtual] = ACTIONS(5792),
    [anon_sym_class] = ACTIONS(5792),
    [anon_sym_type] = ACTIONS(5792),
    [anon_sym_DOLLARfatal] = ACTIONS(5794),
    [anon_sym_DOLLARerror] = ACTIONS(5794),
    [anon_sym_DOLLARwarning] = ACTIONS(5794),
    [anon_sym_DOLLARinfo] = ACTIONS(5794),
    [anon_sym_default] = ACTIONS(5792),
    [anon_sym_clocking] = ACTIONS(5792),
    [anon_sym_defparam] = ACTIONS(5792),
    [anon_sym_bind] = ACTIONS(5792),
    [anon_sym_rand] = ACTIONS(5792),
    [anon_sym_const] = ACTIONS(5792),
    [anon_sym_function] = ACTIONS(5792),
    [anon_sym_static] = ACTIONS(5792),
    [anon_sym_constraint] = ACTIONS(5792),
    [anon_sym_if] = ACTIONS(5792),
    [anon_sym_else] = ACTIONS(5792),
    [anon_sym_LBRACK] = ACTIONS(5794),
    [anon_sym_localparam] = ACTIONS(5792),
    [anon_sym_parameter] = ACTIONS(5792),
    [anon_sym_var] = ACTIONS(5792),
    [anon_sym_import] = ACTIONS(5792),
    [anon_sym_export] = ACTIONS(5792),
    [anon_sym_genvar] = ACTIONS(5792),
    [anon_sym_interconnect] = ACTIONS(5792),
    [anon_sym_typedef] = ACTIONS(5792),
    [anon_sym_enum] = ACTIONS(5792),
    [anon_sym_struct] = ACTIONS(5792),
    [anon_sym_union] = ACTIONS(5792),
    [anon_sym_nettype] = ACTIONS(5792),
    [anon_sym_automatic] = ACTIONS(5792),
    [anon_sym_string] = ACTIONS(5792),
    [anon_sym_chandle] = ACTIONS(5792),
    [anon_sym_event] = ACTIONS(5792),
    [anon_sym_byte] = ACTIONS(5792),
    [anon_sym_shortint] = ACTIONS(5792),
    [anon_sym_int] = ACTIONS(5792),
    [anon_sym_longint] = ACTIONS(5792),
    [anon_sym_integer] = ACTIONS(5792),
    [anon_sym_time] = ACTIONS(5792),
    [anon_sym_bit] = ACTIONS(5792),
    [anon_sym_logic] = ACTIONS(5792),
    [anon_sym_reg] = ACTIONS(5792),
    [anon_sym_shortreal] = ACTIONS(5792),
    [anon_sym_real] = ACTIONS(5792),
    [anon_sym_realtime] = ACTIONS(5792),
    [anon_sym_supply0] = ACTIONS(5792),
    [anon_sym_supply1] = ACTIONS(5792),
    [anon_sym_signed] = ACTIONS(5792),
    [anon_sym_unsigned] = ACTIONS(5792),
    [anon_sym_task] = ACTIONS(5792),
    [anon_sym_assert] = ACTIONS(5792),
    [anon_sym_property] = ACTIONS(5792),
    [anon_sym_assume] = ACTIONS(5792),
    [anon_sym_cover] = ACTIONS(5792),
    [anon_sym_sequence] = ACTIONS(5792),
    [anon_sym_restrict] = ACTIONS(5792),
    [anon_sym_not] = ACTIONS(5792),
    [anon_sym_or] = ACTIONS(5792),
    [anon_sym_and] = ACTIONS(5792),
    [anon_sym_case] = ACTIONS(5792),
    [anon_sym_always] = ACTIONS(5792),
    [anon_sym_covergroup] = ACTIONS(5792),
    [anon_sym_end] = ACTIONS(5792),
    [anon_sym_let] = ACTIONS(5792),
    [anon_sym_pulldown] = ACTIONS(5792),
    [anon_sym_pullup] = ACTIONS(5792),
    [anon_sym_cmos] = ACTIONS(5792),
    [anon_sym_rcmos] = ACTIONS(5792),
    [anon_sym_bufif0] = ACTIONS(5792),
    [anon_sym_bufif1] = ACTIONS(5792),
    [anon_sym_notif0] = ACTIONS(5792),
    [anon_sym_notif1] = ACTIONS(5792),
    [anon_sym_nmos] = ACTIONS(5792),
    [anon_sym_pmos] = ACTIONS(5792),
    [anon_sym_rnmos] = ACTIONS(5792),
    [anon_sym_rpmos] = ACTIONS(5792),
    [anon_sym_nand] = ACTIONS(5792),
    [anon_sym_nor] = ACTIONS(5792),
    [anon_sym_xor] = ACTIONS(5792),
    [anon_sym_xnor] = ACTIONS(5792),
    [anon_sym_buf] = ACTIONS(5792),
    [anon_sym_tranif0] = ACTIONS(5792),
    [anon_sym_tranif1] = ACTIONS(5792),
    [anon_sym_rtranif1] = ACTIONS(5792),
    [anon_sym_rtranif0] = ACTIONS(5792),
    [anon_sym_tran] = ACTIONS(5792),
    [anon_sym_rtran] = ACTIONS(5792),
    [anon_sym_generate] = ACTIONS(5792),
    [anon_sym_for] = ACTIONS(5792),
    [anon_sym_initial] = ACTIONS(5792),
    [anon_sym_assign] = ACTIONS(5792),
    [anon_sym_alias] = ACTIONS(5792),
    [anon_sym_always_comb] = ACTIONS(5792),
    [anon_sym_always_latch] = ACTIONS(5792),
    [anon_sym_always_ff] = ACTIONS(5792),
    [anon_sym_final] = ACTIONS(5792),
    [anon_sym_global] = ACTIONS(5792),
    [anon_sym_LPAREN_STAR] = ACTIONS(5794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5794),
    [anon_sym_DOLLARunit] = ACTIONS(5794),
  },
  [4448] = {
    [sym_simple_identifier] = ACTIONS(4506),
    [anon_sym_wire] = ACTIONS(4506),
    [anon_sym_tri] = ACTIONS(4506),
    [anon_sym_tri0] = ACTIONS(4506),
    [anon_sym_tri1] = ACTIONS(4506),
    [anon_sym_wand] = ACTIONS(4506),
    [anon_sym_triand] = ACTIONS(4506),
    [anon_sym_wor] = ACTIONS(4506),
    [anon_sym_trior] = ACTIONS(4506),
    [anon_sym_trireg] = ACTIONS(4506),
    [anon_sym_uwire] = ACTIONS(4506),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(10613),
    [anon_sym_extern] = ACTIONS(4506),
    [anon_sym_interface] = ACTIONS(4506),
    [anon_sym_checker] = ACTIONS(4506),
    [anon_sym_virtual] = ACTIONS(4506),
    [anon_sym_class] = ACTIONS(4506),
    [anon_sym_type] = ACTIONS(4506),
    [anon_sym_DOLLARfatal] = ACTIONS(4504),
    [anon_sym_DOLLARerror] = ACTIONS(4504),
    [anon_sym_DOLLARwarning] = ACTIONS(4504),
    [anon_sym_DOLLARinfo] = ACTIONS(4504),
    [anon_sym_default] = ACTIONS(4506),
    [anon_sym_clocking] = ACTIONS(4506),
    [anon_sym_defparam] = ACTIONS(4506),
    [anon_sym_bind] = ACTIONS(4506),
    [anon_sym_rand] = ACTIONS(4506),
    [anon_sym_const] = ACTIONS(4506),
    [anon_sym_function] = ACTIONS(4506),
    [anon_sym_static] = ACTIONS(4506),
    [anon_sym_constraint] = ACTIONS(4506),
    [anon_sym_if] = ACTIONS(4506),
    [anon_sym_else] = ACTIONS(4506),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_localparam] = ACTIONS(4506),
    [anon_sym_parameter] = ACTIONS(4506),
    [anon_sym_var] = ACTIONS(4506),
    [anon_sym_import] = ACTIONS(4506),
    [anon_sym_export] = ACTIONS(4506),
    [anon_sym_genvar] = ACTIONS(4506),
    [anon_sym_interconnect] = ACTIONS(4506),
    [anon_sym_typedef] = ACTIONS(4506),
    [anon_sym_enum] = ACTIONS(4506),
    [anon_sym_struct] = ACTIONS(4506),
    [anon_sym_union] = ACTIONS(4506),
    [anon_sym_nettype] = ACTIONS(4506),
    [anon_sym_automatic] = ACTIONS(4506),
    [anon_sym_string] = ACTIONS(4506),
    [anon_sym_chandle] = ACTIONS(4506),
    [anon_sym_event] = ACTIONS(4506),
    [anon_sym_byte] = ACTIONS(4506),
    [anon_sym_shortint] = ACTIONS(4506),
    [anon_sym_int] = ACTIONS(4506),
    [anon_sym_longint] = ACTIONS(4506),
    [anon_sym_integer] = ACTIONS(4506),
    [anon_sym_time] = ACTIONS(4506),
    [anon_sym_bit] = ACTIONS(4506),
    [anon_sym_logic] = ACTIONS(4506),
    [anon_sym_reg] = ACTIONS(4506),
    [anon_sym_shortreal] = ACTIONS(4506),
    [anon_sym_real] = ACTIONS(4506),
    [anon_sym_realtime] = ACTIONS(4506),
    [anon_sym_supply0] = ACTIONS(4506),
    [anon_sym_supply1] = ACTIONS(4506),
    [anon_sym_signed] = ACTIONS(4506),
    [anon_sym_unsigned] = ACTIONS(4506),
    [anon_sym_task] = ACTIONS(4506),
    [anon_sym_assert] = ACTIONS(4506),
    [anon_sym_property] = ACTIONS(4506),
    [anon_sym_assume] = ACTIONS(4506),
    [anon_sym_cover] = ACTIONS(4506),
    [anon_sym_sequence] = ACTIONS(4506),
    [anon_sym_restrict] = ACTIONS(4506),
    [anon_sym_not] = ACTIONS(4506),
    [anon_sym_or] = ACTIONS(4506),
    [anon_sym_and] = ACTIONS(4506),
    [anon_sym_case] = ACTIONS(4506),
    [anon_sym_always] = ACTIONS(4506),
    [anon_sym_covergroup] = ACTIONS(4506),
    [anon_sym_let] = ACTIONS(4506),
    [anon_sym_pulldown] = ACTIONS(4506),
    [anon_sym_pullup] = ACTIONS(4506),
    [anon_sym_cmos] = ACTIONS(4506),
    [anon_sym_rcmos] = ACTIONS(4506),
    [anon_sym_bufif0] = ACTIONS(4506),
    [anon_sym_bufif1] = ACTIONS(4506),
    [anon_sym_notif0] = ACTIONS(4506),
    [anon_sym_notif1] = ACTIONS(4506),
    [anon_sym_nmos] = ACTIONS(4506),
    [anon_sym_pmos] = ACTIONS(4506),
    [anon_sym_rnmos] = ACTIONS(4506),
    [anon_sym_rpmos] = ACTIONS(4506),
    [anon_sym_nand] = ACTIONS(4506),
    [anon_sym_nor] = ACTIONS(4506),
    [anon_sym_xor] = ACTIONS(4506),
    [anon_sym_xnor] = ACTIONS(4506),
    [anon_sym_buf] = ACTIONS(4506),
    [anon_sym_tranif0] = ACTIONS(4506),
    [anon_sym_tranif1] = ACTIONS(4506),
    [anon_sym_rtranif1] = ACTIONS(4506),
    [anon_sym_rtranif0] = ACTIONS(4506),
    [anon_sym_tran] = ACTIONS(4506),
    [anon_sym_rtran] = ACTIONS(4506),
    [anon_sym_generate] = ACTIONS(4506),
    [anon_sym_endgenerate] = ACTIONS(4506),
    [anon_sym_for] = ACTIONS(4506),
    [anon_sym_initial] = ACTIONS(4506),
    [anon_sym_assign] = ACTIONS(4506),
    [anon_sym_alias] = ACTIONS(4506),
    [anon_sym_always_comb] = ACTIONS(4506),
    [anon_sym_always_latch] = ACTIONS(4506),
    [anon_sym_always_ff] = ACTIONS(4506),
    [anon_sym_final] = ACTIONS(4506),
    [anon_sym_global] = ACTIONS(4506),
    [anon_sym_LPAREN_STAR] = ACTIONS(4504),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4504),
    [anon_sym_DOLLARunit] = ACTIONS(4504),
  },
  [4449] = {
    [sym_simple_identifier] = ACTIONS(4536),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_COLON] = ACTIONS(10615),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_rand] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_end] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [4450] = {
    [sym_simple_identifier] = ACTIONS(4636),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_COLON] = ACTIONS(10617),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_rand] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_end] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [4451] = {
    [sym_simple_identifier] = ACTIONS(4684),
    [anon_sym_wire] = ACTIONS(4684),
    [anon_sym_tri] = ACTIONS(4684),
    [anon_sym_tri0] = ACTIONS(4684),
    [anon_sym_tri1] = ACTIONS(4684),
    [anon_sym_wand] = ACTIONS(4684),
    [anon_sym_triand] = ACTIONS(4684),
    [anon_sym_wor] = ACTIONS(4684),
    [anon_sym_trior] = ACTIONS(4684),
    [anon_sym_trireg] = ACTIONS(4684),
    [anon_sym_uwire] = ACTIONS(4684),
    [anon_sym_SEMI] = ACTIONS(4682),
    [anon_sym_COLON] = ACTIONS(10619),
    [anon_sym_extern] = ACTIONS(4684),
    [anon_sym_interface] = ACTIONS(4684),
    [anon_sym_checker] = ACTIONS(4684),
    [anon_sym_virtual] = ACTIONS(4684),
    [anon_sym_class] = ACTIONS(4684),
    [anon_sym_type] = ACTIONS(4684),
    [anon_sym_DOLLARfatal] = ACTIONS(4682),
    [anon_sym_DOLLARerror] = ACTIONS(4682),
    [anon_sym_DOLLARwarning] = ACTIONS(4682),
    [anon_sym_DOLLARinfo] = ACTIONS(4682),
    [anon_sym_default] = ACTIONS(4684),
    [anon_sym_clocking] = ACTIONS(4684),
    [anon_sym_defparam] = ACTIONS(4684),
    [anon_sym_bind] = ACTIONS(4684),
    [anon_sym_rand] = ACTIONS(4684),
    [anon_sym_const] = ACTIONS(4684),
    [anon_sym_function] = ACTIONS(4684),
    [anon_sym_static] = ACTIONS(4684),
    [anon_sym_constraint] = ACTIONS(4684),
    [anon_sym_if] = ACTIONS(4684),
    [anon_sym_else] = ACTIONS(4684),
    [anon_sym_LBRACK] = ACTIONS(4682),
    [anon_sym_localparam] = ACTIONS(4684),
    [anon_sym_parameter] = ACTIONS(4684),
    [anon_sym_var] = ACTIONS(4684),
    [anon_sym_import] = ACTIONS(4684),
    [anon_sym_export] = ACTIONS(4684),
    [anon_sym_genvar] = ACTIONS(4684),
    [anon_sym_interconnect] = ACTIONS(4684),
    [anon_sym_typedef] = ACTIONS(4684),
    [anon_sym_enum] = ACTIONS(4684),
    [anon_sym_struct] = ACTIONS(4684),
    [anon_sym_union] = ACTIONS(4684),
    [anon_sym_nettype] = ACTIONS(4684),
    [anon_sym_automatic] = ACTIONS(4684),
    [anon_sym_string] = ACTIONS(4684),
    [anon_sym_chandle] = ACTIONS(4684),
    [anon_sym_event] = ACTIONS(4684),
    [anon_sym_byte] = ACTIONS(4684),
    [anon_sym_shortint] = ACTIONS(4684),
    [anon_sym_int] = ACTIONS(4684),
    [anon_sym_longint] = ACTIONS(4684),
    [anon_sym_integer] = ACTIONS(4684),
    [anon_sym_time] = ACTIONS(4684),
    [anon_sym_bit] = ACTIONS(4684),
    [anon_sym_logic] = ACTIONS(4684),
    [anon_sym_reg] = ACTIONS(4684),
    [anon_sym_shortreal] = ACTIONS(4684),
    [anon_sym_real] = ACTIONS(4684),
    [anon_sym_realtime] = ACTIONS(4684),
    [anon_sym_supply0] = ACTIONS(4684),
    [anon_sym_supply1] = ACTIONS(4684),
    [anon_sym_signed] = ACTIONS(4684),
    [anon_sym_unsigned] = ACTIONS(4684),
    [anon_sym_task] = ACTIONS(4684),
    [anon_sym_assert] = ACTIONS(4684),
    [anon_sym_property] = ACTIONS(4684),
    [anon_sym_assume] = ACTIONS(4684),
    [anon_sym_cover] = ACTIONS(4684),
    [anon_sym_sequence] = ACTIONS(4684),
    [anon_sym_restrict] = ACTIONS(4684),
    [anon_sym_not] = ACTIONS(4684),
    [anon_sym_or] = ACTIONS(4684),
    [anon_sym_and] = ACTIONS(4684),
    [anon_sym_case] = ACTIONS(4684),
    [anon_sym_always] = ACTIONS(4684),
    [anon_sym_covergroup] = ACTIONS(4684),
    [anon_sym_end] = ACTIONS(4684),
    [anon_sym_let] = ACTIONS(4684),
    [anon_sym_pulldown] = ACTIONS(4684),
    [anon_sym_pullup] = ACTIONS(4684),
    [anon_sym_cmos] = ACTIONS(4684),
    [anon_sym_rcmos] = ACTIONS(4684),
    [anon_sym_bufif0] = ACTIONS(4684),
    [anon_sym_bufif1] = ACTIONS(4684),
    [anon_sym_notif0] = ACTIONS(4684),
    [anon_sym_notif1] = ACTIONS(4684),
    [anon_sym_nmos] = ACTIONS(4684),
    [anon_sym_pmos] = ACTIONS(4684),
    [anon_sym_rnmos] = ACTIONS(4684),
    [anon_sym_rpmos] = ACTIONS(4684),
    [anon_sym_nand] = ACTIONS(4684),
    [anon_sym_nor] = ACTIONS(4684),
    [anon_sym_xor] = ACTIONS(4684),
    [anon_sym_xnor] = ACTIONS(4684),
    [anon_sym_buf] = ACTIONS(4684),
    [anon_sym_tranif0] = ACTIONS(4684),
    [anon_sym_tranif1] = ACTIONS(4684),
    [anon_sym_rtranif1] = ACTIONS(4684),
    [anon_sym_rtranif0] = ACTIONS(4684),
    [anon_sym_tran] = ACTIONS(4684),
    [anon_sym_rtran] = ACTIONS(4684),
    [anon_sym_generate] = ACTIONS(4684),
    [anon_sym_for] = ACTIONS(4684),
    [anon_sym_initial] = ACTIONS(4684),
    [anon_sym_assign] = ACTIONS(4684),
    [anon_sym_alias] = ACTIONS(4684),
    [anon_sym_always_comb] = ACTIONS(4684),
    [anon_sym_always_latch] = ACTIONS(4684),
    [anon_sym_always_ff] = ACTIONS(4684),
    [anon_sym_final] = ACTIONS(4684),
    [anon_sym_global] = ACTIONS(4684),
    [anon_sym_LPAREN_STAR] = ACTIONS(4682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4682),
    [anon_sym_DOLLARunit] = ACTIONS(4682),
  },
  [4452] = {
    [sym_simple_identifier] = ACTIONS(4606),
    [anon_sym_wire] = ACTIONS(4606),
    [anon_sym_tri] = ACTIONS(4606),
    [anon_sym_tri0] = ACTIONS(4606),
    [anon_sym_tri1] = ACTIONS(4606),
    [anon_sym_wand] = ACTIONS(4606),
    [anon_sym_triand] = ACTIONS(4606),
    [anon_sym_wor] = ACTIONS(4606),
    [anon_sym_trior] = ACTIONS(4606),
    [anon_sym_trireg] = ACTIONS(4606),
    [anon_sym_uwire] = ACTIONS(4606),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_COLON] = ACTIONS(10621),
    [anon_sym_extern] = ACTIONS(4606),
    [anon_sym_interface] = ACTIONS(4606),
    [anon_sym_checker] = ACTIONS(4606),
    [anon_sym_virtual] = ACTIONS(4606),
    [anon_sym_class] = ACTIONS(4606),
    [anon_sym_type] = ACTIONS(4606),
    [anon_sym_DOLLARfatal] = ACTIONS(4604),
    [anon_sym_DOLLARerror] = ACTIONS(4604),
    [anon_sym_DOLLARwarning] = ACTIONS(4604),
    [anon_sym_DOLLARinfo] = ACTIONS(4604),
    [anon_sym_default] = ACTIONS(4606),
    [anon_sym_clocking] = ACTIONS(4606),
    [anon_sym_defparam] = ACTIONS(4606),
    [anon_sym_bind] = ACTIONS(4606),
    [anon_sym_rand] = ACTIONS(4606),
    [anon_sym_const] = ACTIONS(4606),
    [anon_sym_function] = ACTIONS(4606),
    [anon_sym_static] = ACTIONS(4606),
    [anon_sym_constraint] = ACTIONS(4606),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [anon_sym_localparam] = ACTIONS(4606),
    [anon_sym_parameter] = ACTIONS(4606),
    [anon_sym_var] = ACTIONS(4606),
    [anon_sym_import] = ACTIONS(4606),
    [anon_sym_export] = ACTIONS(4606),
    [anon_sym_genvar] = ACTIONS(4606),
    [anon_sym_interconnect] = ACTIONS(4606),
    [anon_sym_typedef] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_struct] = ACTIONS(4606),
    [anon_sym_union] = ACTIONS(4606),
    [anon_sym_nettype] = ACTIONS(4606),
    [anon_sym_automatic] = ACTIONS(4606),
    [anon_sym_string] = ACTIONS(4606),
    [anon_sym_chandle] = ACTIONS(4606),
    [anon_sym_event] = ACTIONS(4606),
    [anon_sym_byte] = ACTIONS(4606),
    [anon_sym_shortint] = ACTIONS(4606),
    [anon_sym_int] = ACTIONS(4606),
    [anon_sym_longint] = ACTIONS(4606),
    [anon_sym_integer] = ACTIONS(4606),
    [anon_sym_time] = ACTIONS(4606),
    [anon_sym_bit] = ACTIONS(4606),
    [anon_sym_logic] = ACTIONS(4606),
    [anon_sym_reg] = ACTIONS(4606),
    [anon_sym_shortreal] = ACTIONS(4606),
    [anon_sym_real] = ACTIONS(4606),
    [anon_sym_realtime] = ACTIONS(4606),
    [anon_sym_supply0] = ACTIONS(4606),
    [anon_sym_supply1] = ACTIONS(4606),
    [anon_sym_signed] = ACTIONS(4606),
    [anon_sym_unsigned] = ACTIONS(4606),
    [anon_sym_task] = ACTIONS(4606),
    [anon_sym_assert] = ACTIONS(4606),
    [anon_sym_property] = ACTIONS(4606),
    [anon_sym_assume] = ACTIONS(4606),
    [anon_sym_cover] = ACTIONS(4606),
    [anon_sym_sequence] = ACTIONS(4606),
    [anon_sym_restrict] = ACTIONS(4606),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_or] = ACTIONS(4606),
    [anon_sym_and] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_always] = ACTIONS(4606),
    [anon_sym_covergroup] = ACTIONS(4606),
    [anon_sym_let] = ACTIONS(4606),
    [anon_sym_pulldown] = ACTIONS(4606),
    [anon_sym_pullup] = ACTIONS(4606),
    [anon_sym_cmos] = ACTIONS(4606),
    [anon_sym_rcmos] = ACTIONS(4606),
    [anon_sym_bufif0] = ACTIONS(4606),
    [anon_sym_bufif1] = ACTIONS(4606),
    [anon_sym_notif0] = ACTIONS(4606),
    [anon_sym_notif1] = ACTIONS(4606),
    [anon_sym_nmos] = ACTIONS(4606),
    [anon_sym_pmos] = ACTIONS(4606),
    [anon_sym_rnmos] = ACTIONS(4606),
    [anon_sym_rpmos] = ACTIONS(4606),
    [anon_sym_nand] = ACTIONS(4606),
    [anon_sym_nor] = ACTIONS(4606),
    [anon_sym_xor] = ACTIONS(4606),
    [anon_sym_xnor] = ACTIONS(4606),
    [anon_sym_buf] = ACTIONS(4606),
    [anon_sym_tranif0] = ACTIONS(4606),
    [anon_sym_tranif1] = ACTIONS(4606),
    [anon_sym_rtranif1] = ACTIONS(4606),
    [anon_sym_rtranif0] = ACTIONS(4606),
    [anon_sym_tran] = ACTIONS(4606),
    [anon_sym_rtran] = ACTIONS(4606),
    [anon_sym_generate] = ACTIONS(4606),
    [anon_sym_endgenerate] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_initial] = ACTIONS(4606),
    [anon_sym_assign] = ACTIONS(4606),
    [anon_sym_alias] = ACTIONS(4606),
    [anon_sym_always_comb] = ACTIONS(4606),
    [anon_sym_always_latch] = ACTIONS(4606),
    [anon_sym_always_ff] = ACTIONS(4606),
    [anon_sym_final] = ACTIONS(4606),
    [anon_sym_global] = ACTIONS(4606),
    [anon_sym_LPAREN_STAR] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4604),
    [anon_sym_DOLLARunit] = ACTIONS(4604),
  },
  [4453] = {
    [sym_simple_identifier] = ACTIONS(4184),
    [anon_sym_wire] = ACTIONS(4184),
    [anon_sym_tri] = ACTIONS(4184),
    [anon_sym_tri0] = ACTIONS(4184),
    [anon_sym_tri1] = ACTIONS(4184),
    [anon_sym_wand] = ACTIONS(4184),
    [anon_sym_triand] = ACTIONS(4184),
    [anon_sym_wor] = ACTIONS(4184),
    [anon_sym_trior] = ACTIONS(4184),
    [anon_sym_trireg] = ACTIONS(4184),
    [anon_sym_uwire] = ACTIONS(4184),
    [anon_sym_SEMI] = ACTIONS(4182),
    [anon_sym_COLON] = ACTIONS(10623),
    [anon_sym_extern] = ACTIONS(4184),
    [anon_sym_interface] = ACTIONS(4184),
    [anon_sym_checker] = ACTIONS(4184),
    [anon_sym_virtual] = ACTIONS(4184),
    [anon_sym_class] = ACTIONS(4184),
    [anon_sym_type] = ACTIONS(4184),
    [anon_sym_DOLLARfatal] = ACTIONS(4182),
    [anon_sym_DOLLARerror] = ACTIONS(4182),
    [anon_sym_DOLLARwarning] = ACTIONS(4182),
    [anon_sym_DOLLARinfo] = ACTIONS(4182),
    [anon_sym_default] = ACTIONS(4184),
    [anon_sym_clocking] = ACTIONS(4184),
    [anon_sym_defparam] = ACTIONS(4184),
    [anon_sym_bind] = ACTIONS(4184),
    [anon_sym_rand] = ACTIONS(4184),
    [anon_sym_const] = ACTIONS(4184),
    [anon_sym_function] = ACTIONS(4184),
    [anon_sym_static] = ACTIONS(4184),
    [anon_sym_constraint] = ACTIONS(4184),
    [anon_sym_if] = ACTIONS(4184),
    [anon_sym_else] = ACTIONS(4184),
    [anon_sym_LBRACK] = ACTIONS(4182),
    [anon_sym_localparam] = ACTIONS(4184),
    [anon_sym_parameter] = ACTIONS(4184),
    [anon_sym_var] = ACTIONS(4184),
    [anon_sym_import] = ACTIONS(4184),
    [anon_sym_export] = ACTIONS(4184),
    [anon_sym_genvar] = ACTIONS(4184),
    [anon_sym_interconnect] = ACTIONS(4184),
    [anon_sym_typedef] = ACTIONS(4184),
    [anon_sym_enum] = ACTIONS(4184),
    [anon_sym_struct] = ACTIONS(4184),
    [anon_sym_union] = ACTIONS(4184),
    [anon_sym_nettype] = ACTIONS(4184),
    [anon_sym_automatic] = ACTIONS(4184),
    [anon_sym_string] = ACTIONS(4184),
    [anon_sym_chandle] = ACTIONS(4184),
    [anon_sym_event] = ACTIONS(4184),
    [anon_sym_byte] = ACTIONS(4184),
    [anon_sym_shortint] = ACTIONS(4184),
    [anon_sym_int] = ACTIONS(4184),
    [anon_sym_longint] = ACTIONS(4184),
    [anon_sym_integer] = ACTIONS(4184),
    [anon_sym_time] = ACTIONS(4184),
    [anon_sym_bit] = ACTIONS(4184),
    [anon_sym_logic] = ACTIONS(4184),
    [anon_sym_reg] = ACTIONS(4184),
    [anon_sym_shortreal] = ACTIONS(4184),
    [anon_sym_real] = ACTIONS(4184),
    [anon_sym_realtime] = ACTIONS(4184),
    [anon_sym_supply0] = ACTIONS(4184),
    [anon_sym_supply1] = ACTIONS(4184),
    [anon_sym_signed] = ACTIONS(4184),
    [anon_sym_unsigned] = ACTIONS(4184),
    [anon_sym_task] = ACTIONS(4184),
    [anon_sym_assert] = ACTIONS(4184),
    [anon_sym_property] = ACTIONS(4184),
    [anon_sym_assume] = ACTIONS(4184),
    [anon_sym_cover] = ACTIONS(4184),
    [anon_sym_sequence] = ACTIONS(4184),
    [anon_sym_restrict] = ACTIONS(4184),
    [anon_sym_not] = ACTIONS(4184),
    [anon_sym_or] = ACTIONS(4184),
    [anon_sym_and] = ACTIONS(4184),
    [anon_sym_case] = ACTIONS(4184),
    [anon_sym_always] = ACTIONS(4184),
    [anon_sym_covergroup] = ACTIONS(4184),
    [anon_sym_end] = ACTIONS(4184),
    [anon_sym_let] = ACTIONS(4184),
    [anon_sym_pulldown] = ACTIONS(4184),
    [anon_sym_pullup] = ACTIONS(4184),
    [anon_sym_cmos] = ACTIONS(4184),
    [anon_sym_rcmos] = ACTIONS(4184),
    [anon_sym_bufif0] = ACTIONS(4184),
    [anon_sym_bufif1] = ACTIONS(4184),
    [anon_sym_notif0] = ACTIONS(4184),
    [anon_sym_notif1] = ACTIONS(4184),
    [anon_sym_nmos] = ACTIONS(4184),
    [anon_sym_pmos] = ACTIONS(4184),
    [anon_sym_rnmos] = ACTIONS(4184),
    [anon_sym_rpmos] = ACTIONS(4184),
    [anon_sym_nand] = ACTIONS(4184),
    [anon_sym_nor] = ACTIONS(4184),
    [anon_sym_xor] = ACTIONS(4184),
    [anon_sym_xnor] = ACTIONS(4184),
    [anon_sym_buf] = ACTIONS(4184),
    [anon_sym_tranif0] = ACTIONS(4184),
    [anon_sym_tranif1] = ACTIONS(4184),
    [anon_sym_rtranif1] = ACTIONS(4184),
    [anon_sym_rtranif0] = ACTIONS(4184),
    [anon_sym_tran] = ACTIONS(4184),
    [anon_sym_rtran] = ACTIONS(4184),
    [anon_sym_generate] = ACTIONS(4184),
    [anon_sym_for] = ACTIONS(4184),
    [anon_sym_initial] = ACTIONS(4184),
    [anon_sym_assign] = ACTIONS(4184),
    [anon_sym_alias] = ACTIONS(4184),
    [anon_sym_always_comb] = ACTIONS(4184),
    [anon_sym_always_latch] = ACTIONS(4184),
    [anon_sym_always_ff] = ACTIONS(4184),
    [anon_sym_final] = ACTIONS(4184),
    [anon_sym_global] = ACTIONS(4184),
    [anon_sym_LPAREN_STAR] = ACTIONS(4182),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4182),
    [anon_sym_DOLLARunit] = ACTIONS(4182),
  },
  [4454] = {
    [sym_simple_identifier] = ACTIONS(4406),
    [anon_sym_wire] = ACTIONS(4406),
    [anon_sym_tri] = ACTIONS(4406),
    [anon_sym_tri0] = ACTIONS(4406),
    [anon_sym_tri1] = ACTIONS(4406),
    [anon_sym_wand] = ACTIONS(4406),
    [anon_sym_triand] = ACTIONS(4406),
    [anon_sym_wor] = ACTIONS(4406),
    [anon_sym_trior] = ACTIONS(4406),
    [anon_sym_trireg] = ACTIONS(4406),
    [anon_sym_uwire] = ACTIONS(4406),
    [anon_sym_SEMI] = ACTIONS(4404),
    [anon_sym_COLON] = ACTIONS(10625),
    [anon_sym_extern] = ACTIONS(4406),
    [anon_sym_interface] = ACTIONS(4406),
    [anon_sym_checker] = ACTIONS(4406),
    [anon_sym_virtual] = ACTIONS(4406),
    [anon_sym_class] = ACTIONS(4406),
    [anon_sym_type] = ACTIONS(4406),
    [anon_sym_DOLLARfatal] = ACTIONS(4404),
    [anon_sym_DOLLARerror] = ACTIONS(4404),
    [anon_sym_DOLLARwarning] = ACTIONS(4404),
    [anon_sym_DOLLARinfo] = ACTIONS(4404),
    [anon_sym_default] = ACTIONS(4406),
    [anon_sym_clocking] = ACTIONS(4406),
    [anon_sym_defparam] = ACTIONS(4406),
    [anon_sym_bind] = ACTIONS(4406),
    [anon_sym_rand] = ACTIONS(4406),
    [anon_sym_const] = ACTIONS(4406),
    [anon_sym_function] = ACTIONS(4406),
    [anon_sym_static] = ACTIONS(4406),
    [anon_sym_constraint] = ACTIONS(4406),
    [anon_sym_if] = ACTIONS(4406),
    [anon_sym_else] = ACTIONS(4406),
    [anon_sym_LBRACK] = ACTIONS(4404),
    [anon_sym_localparam] = ACTIONS(4406),
    [anon_sym_parameter] = ACTIONS(4406),
    [anon_sym_var] = ACTIONS(4406),
    [anon_sym_import] = ACTIONS(4406),
    [anon_sym_export] = ACTIONS(4406),
    [anon_sym_genvar] = ACTIONS(4406),
    [anon_sym_interconnect] = ACTIONS(4406),
    [anon_sym_typedef] = ACTIONS(4406),
    [anon_sym_enum] = ACTIONS(4406),
    [anon_sym_struct] = ACTIONS(4406),
    [anon_sym_union] = ACTIONS(4406),
    [anon_sym_nettype] = ACTIONS(4406),
    [anon_sym_automatic] = ACTIONS(4406),
    [anon_sym_string] = ACTIONS(4406),
    [anon_sym_chandle] = ACTIONS(4406),
    [anon_sym_event] = ACTIONS(4406),
    [anon_sym_byte] = ACTIONS(4406),
    [anon_sym_shortint] = ACTIONS(4406),
    [anon_sym_int] = ACTIONS(4406),
    [anon_sym_longint] = ACTIONS(4406),
    [anon_sym_integer] = ACTIONS(4406),
    [anon_sym_time] = ACTIONS(4406),
    [anon_sym_bit] = ACTIONS(4406),
    [anon_sym_logic] = ACTIONS(4406),
    [anon_sym_reg] = ACTIONS(4406),
    [anon_sym_shortreal] = ACTIONS(4406),
    [anon_sym_real] = ACTIONS(4406),
    [anon_sym_realtime] = ACTIONS(4406),
    [anon_sym_supply0] = ACTIONS(4406),
    [anon_sym_supply1] = ACTIONS(4406),
    [anon_sym_signed] = ACTIONS(4406),
    [anon_sym_unsigned] = ACTIONS(4406),
    [anon_sym_task] = ACTIONS(4406),
    [anon_sym_assert] = ACTIONS(4406),
    [anon_sym_property] = ACTIONS(4406),
    [anon_sym_assume] = ACTIONS(4406),
    [anon_sym_cover] = ACTIONS(4406),
    [anon_sym_sequence] = ACTIONS(4406),
    [anon_sym_restrict] = ACTIONS(4406),
    [anon_sym_not] = ACTIONS(4406),
    [anon_sym_or] = ACTIONS(4406),
    [anon_sym_and] = ACTIONS(4406),
    [anon_sym_case] = ACTIONS(4406),
    [anon_sym_always] = ACTIONS(4406),
    [anon_sym_covergroup] = ACTIONS(4406),
    [anon_sym_end] = ACTIONS(4406),
    [anon_sym_let] = ACTIONS(4406),
    [anon_sym_pulldown] = ACTIONS(4406),
    [anon_sym_pullup] = ACTIONS(4406),
    [anon_sym_cmos] = ACTIONS(4406),
    [anon_sym_rcmos] = ACTIONS(4406),
    [anon_sym_bufif0] = ACTIONS(4406),
    [anon_sym_bufif1] = ACTIONS(4406),
    [anon_sym_notif0] = ACTIONS(4406),
    [anon_sym_notif1] = ACTIONS(4406),
    [anon_sym_nmos] = ACTIONS(4406),
    [anon_sym_pmos] = ACTIONS(4406),
    [anon_sym_rnmos] = ACTIONS(4406),
    [anon_sym_rpmos] = ACTIONS(4406),
    [anon_sym_nand] = ACTIONS(4406),
    [anon_sym_nor] = ACTIONS(4406),
    [anon_sym_xor] = ACTIONS(4406),
    [anon_sym_xnor] = ACTIONS(4406),
    [anon_sym_buf] = ACTIONS(4406),
    [anon_sym_tranif0] = ACTIONS(4406),
    [anon_sym_tranif1] = ACTIONS(4406),
    [anon_sym_rtranif1] = ACTIONS(4406),
    [anon_sym_rtranif0] = ACTIONS(4406),
    [anon_sym_tran] = ACTIONS(4406),
    [anon_sym_rtran] = ACTIONS(4406),
    [anon_sym_generate] = ACTIONS(4406),
    [anon_sym_for] = ACTIONS(4406),
    [anon_sym_initial] = ACTIONS(4406),
    [anon_sym_assign] = ACTIONS(4406),
    [anon_sym_alias] = ACTIONS(4406),
    [anon_sym_always_comb] = ACTIONS(4406),
    [anon_sym_always_latch] = ACTIONS(4406),
    [anon_sym_always_ff] = ACTIONS(4406),
    [anon_sym_final] = ACTIONS(4406),
    [anon_sym_global] = ACTIONS(4406),
    [anon_sym_LPAREN_STAR] = ACTIONS(4404),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4404),
    [anon_sym_DOLLARunit] = ACTIONS(4404),
  },
  [4455] = {
    [sym_simple_identifier] = ACTIONS(6365),
    [anon_sym_wire] = ACTIONS(6365),
    [anon_sym_tri] = ACTIONS(6365),
    [anon_sym_tri0] = ACTIONS(6365),
    [anon_sym_tri1] = ACTIONS(6365),
    [anon_sym_wand] = ACTIONS(6365),
    [anon_sym_triand] = ACTIONS(6365),
    [anon_sym_wor] = ACTIONS(6365),
    [anon_sym_trior] = ACTIONS(6365),
    [anon_sym_trireg] = ACTIONS(6365),
    [anon_sym_uwire] = ACTIONS(6365),
    [anon_sym_SEMI] = ACTIONS(6367),
    [anon_sym_COLON] = ACTIONS(10627),
    [anon_sym_extern] = ACTIONS(6365),
    [anon_sym_interface] = ACTIONS(6365),
    [anon_sym_checker] = ACTIONS(6365),
    [anon_sym_virtual] = ACTIONS(6365),
    [anon_sym_class] = ACTIONS(6365),
    [anon_sym_type] = ACTIONS(6365),
    [anon_sym_DOLLARfatal] = ACTIONS(6367),
    [anon_sym_DOLLARerror] = ACTIONS(6367),
    [anon_sym_DOLLARwarning] = ACTIONS(6367),
    [anon_sym_DOLLARinfo] = ACTIONS(6367),
    [anon_sym_default] = ACTIONS(6365),
    [anon_sym_clocking] = ACTIONS(6365),
    [anon_sym_defparam] = ACTIONS(6365),
    [anon_sym_bind] = ACTIONS(6365),
    [anon_sym_rand] = ACTIONS(6365),
    [anon_sym_const] = ACTIONS(6365),
    [anon_sym_function] = ACTIONS(6365),
    [anon_sym_static] = ACTIONS(6365),
    [anon_sym_constraint] = ACTIONS(6365),
    [anon_sym_if] = ACTIONS(6365),
    [anon_sym_else] = ACTIONS(6365),
    [anon_sym_LBRACK] = ACTIONS(6367),
    [anon_sym_localparam] = ACTIONS(6365),
    [anon_sym_parameter] = ACTIONS(6365),
    [anon_sym_var] = ACTIONS(6365),
    [anon_sym_import] = ACTIONS(6365),
    [anon_sym_export] = ACTIONS(6365),
    [anon_sym_genvar] = ACTIONS(6365),
    [anon_sym_interconnect] = ACTIONS(6365),
    [anon_sym_typedef] = ACTIONS(6365),
    [anon_sym_enum] = ACTIONS(6365),
    [anon_sym_struct] = ACTIONS(6365),
    [anon_sym_union] = ACTIONS(6365),
    [anon_sym_nettype] = ACTIONS(6365),
    [anon_sym_automatic] = ACTIONS(6365),
    [anon_sym_string] = ACTIONS(6365),
    [anon_sym_chandle] = ACTIONS(6365),
    [anon_sym_event] = ACTIONS(6365),
    [anon_sym_byte] = ACTIONS(6365),
    [anon_sym_shortint] = ACTIONS(6365),
    [anon_sym_int] = ACTIONS(6365),
    [anon_sym_longint] = ACTIONS(6365),
    [anon_sym_integer] = ACTIONS(6365),
    [anon_sym_time] = ACTIONS(6365),
    [anon_sym_bit] = ACTIONS(6365),
    [anon_sym_logic] = ACTIONS(6365),
    [anon_sym_reg] = ACTIONS(6365),
    [anon_sym_shortreal] = ACTIONS(6365),
    [anon_sym_real] = ACTIONS(6365),
    [anon_sym_realtime] = ACTIONS(6365),
    [anon_sym_supply0] = ACTIONS(6365),
    [anon_sym_supply1] = ACTIONS(6365),
    [anon_sym_signed] = ACTIONS(6365),
    [anon_sym_unsigned] = ACTIONS(6365),
    [anon_sym_task] = ACTIONS(6365),
    [anon_sym_assert] = ACTIONS(6365),
    [anon_sym_property] = ACTIONS(6365),
    [anon_sym_assume] = ACTIONS(6365),
    [anon_sym_cover] = ACTIONS(6365),
    [anon_sym_sequence] = ACTIONS(6365),
    [anon_sym_restrict] = ACTIONS(6365),
    [anon_sym_not] = ACTIONS(6365),
    [anon_sym_or] = ACTIONS(6365),
    [anon_sym_and] = ACTIONS(6365),
    [anon_sym_case] = ACTIONS(6365),
    [anon_sym_always] = ACTIONS(6365),
    [anon_sym_covergroup] = ACTIONS(6365),
    [anon_sym_end] = ACTIONS(6365),
    [anon_sym_let] = ACTIONS(6365),
    [anon_sym_pulldown] = ACTIONS(6365),
    [anon_sym_pullup] = ACTIONS(6365),
    [anon_sym_cmos] = ACTIONS(6365),
    [anon_sym_rcmos] = ACTIONS(6365),
    [anon_sym_bufif0] = ACTIONS(6365),
    [anon_sym_bufif1] = ACTIONS(6365),
    [anon_sym_notif0] = ACTIONS(6365),
    [anon_sym_notif1] = ACTIONS(6365),
    [anon_sym_nmos] = ACTIONS(6365),
    [anon_sym_pmos] = ACTIONS(6365),
    [anon_sym_rnmos] = ACTIONS(6365),
    [anon_sym_rpmos] = ACTIONS(6365),
    [anon_sym_nand] = ACTIONS(6365),
    [anon_sym_nor] = ACTIONS(6365),
    [anon_sym_xor] = ACTIONS(6365),
    [anon_sym_xnor] = ACTIONS(6365),
    [anon_sym_buf] = ACTIONS(6365),
    [anon_sym_tranif0] = ACTIONS(6365),
    [anon_sym_tranif1] = ACTIONS(6365),
    [anon_sym_rtranif1] = ACTIONS(6365),
    [anon_sym_rtranif0] = ACTIONS(6365),
    [anon_sym_tran] = ACTIONS(6365),
    [anon_sym_rtran] = ACTIONS(6365),
    [anon_sym_generate] = ACTIONS(6365),
    [anon_sym_for] = ACTIONS(6365),
    [anon_sym_initial] = ACTIONS(6365),
    [anon_sym_assign] = ACTIONS(6365),
    [anon_sym_alias] = ACTIONS(6365),
    [anon_sym_always_comb] = ACTIONS(6365),
    [anon_sym_always_latch] = ACTIONS(6365),
    [anon_sym_always_ff] = ACTIONS(6365),
    [anon_sym_final] = ACTIONS(6365),
    [anon_sym_global] = ACTIONS(6365),
    [anon_sym_LPAREN_STAR] = ACTIONS(6367),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6367),
    [anon_sym_DOLLARunit] = ACTIONS(6367),
  },
  [4456] = {
    [sym_simple_identifier] = ACTIONS(4806),
    [anon_sym_wire] = ACTIONS(4806),
    [anon_sym_tri] = ACTIONS(4806),
    [anon_sym_tri0] = ACTIONS(4806),
    [anon_sym_tri1] = ACTIONS(4806),
    [anon_sym_wand] = ACTIONS(4806),
    [anon_sym_triand] = ACTIONS(4806),
    [anon_sym_wor] = ACTIONS(4806),
    [anon_sym_trior] = ACTIONS(4806),
    [anon_sym_trireg] = ACTIONS(4806),
    [anon_sym_uwire] = ACTIONS(4806),
    [anon_sym_SEMI] = ACTIONS(4804),
    [anon_sym_COLON] = ACTIONS(10629),
    [anon_sym_extern] = ACTIONS(4806),
    [anon_sym_interface] = ACTIONS(4806),
    [anon_sym_checker] = ACTIONS(4806),
    [anon_sym_virtual] = ACTIONS(4806),
    [anon_sym_class] = ACTIONS(4806),
    [anon_sym_type] = ACTIONS(4806),
    [anon_sym_DOLLARfatal] = ACTIONS(4804),
    [anon_sym_DOLLARerror] = ACTIONS(4804),
    [anon_sym_DOLLARwarning] = ACTIONS(4804),
    [anon_sym_DOLLARinfo] = ACTIONS(4804),
    [anon_sym_default] = ACTIONS(4806),
    [anon_sym_clocking] = ACTIONS(4806),
    [anon_sym_defparam] = ACTIONS(4806),
    [anon_sym_bind] = ACTIONS(4806),
    [anon_sym_rand] = ACTIONS(4806),
    [anon_sym_const] = ACTIONS(4806),
    [anon_sym_function] = ACTIONS(4806),
    [anon_sym_static] = ACTIONS(4806),
    [anon_sym_constraint] = ACTIONS(4806),
    [anon_sym_if] = ACTIONS(4806),
    [anon_sym_else] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(4804),
    [anon_sym_localparam] = ACTIONS(4806),
    [anon_sym_parameter] = ACTIONS(4806),
    [anon_sym_var] = ACTIONS(4806),
    [anon_sym_import] = ACTIONS(4806),
    [anon_sym_export] = ACTIONS(4806),
    [anon_sym_genvar] = ACTIONS(4806),
    [anon_sym_interconnect] = ACTIONS(4806),
    [anon_sym_typedef] = ACTIONS(4806),
    [anon_sym_enum] = ACTIONS(4806),
    [anon_sym_struct] = ACTIONS(4806),
    [anon_sym_union] = ACTIONS(4806),
    [anon_sym_nettype] = ACTIONS(4806),
    [anon_sym_automatic] = ACTIONS(4806),
    [anon_sym_string] = ACTIONS(4806),
    [anon_sym_chandle] = ACTIONS(4806),
    [anon_sym_event] = ACTIONS(4806),
    [anon_sym_byte] = ACTIONS(4806),
    [anon_sym_shortint] = ACTIONS(4806),
    [anon_sym_int] = ACTIONS(4806),
    [anon_sym_longint] = ACTIONS(4806),
    [anon_sym_integer] = ACTIONS(4806),
    [anon_sym_time] = ACTIONS(4806),
    [anon_sym_bit] = ACTIONS(4806),
    [anon_sym_logic] = ACTIONS(4806),
    [anon_sym_reg] = ACTIONS(4806),
    [anon_sym_shortreal] = ACTIONS(4806),
    [anon_sym_real] = ACTIONS(4806),
    [anon_sym_realtime] = ACTIONS(4806),
    [anon_sym_supply0] = ACTIONS(4806),
    [anon_sym_supply1] = ACTIONS(4806),
    [anon_sym_signed] = ACTIONS(4806),
    [anon_sym_unsigned] = ACTIONS(4806),
    [anon_sym_task] = ACTIONS(4806),
    [anon_sym_assert] = ACTIONS(4806),
    [anon_sym_property] = ACTIONS(4806),
    [anon_sym_assume] = ACTIONS(4806),
    [anon_sym_cover] = ACTIONS(4806),
    [anon_sym_sequence] = ACTIONS(4806),
    [anon_sym_restrict] = ACTIONS(4806),
    [anon_sym_not] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_case] = ACTIONS(4806),
    [anon_sym_always] = ACTIONS(4806),
    [anon_sym_covergroup] = ACTIONS(4806),
    [anon_sym_end] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_pulldown] = ACTIONS(4806),
    [anon_sym_pullup] = ACTIONS(4806),
    [anon_sym_cmos] = ACTIONS(4806),
    [anon_sym_rcmos] = ACTIONS(4806),
    [anon_sym_bufif0] = ACTIONS(4806),
    [anon_sym_bufif1] = ACTIONS(4806),
    [anon_sym_notif0] = ACTIONS(4806),
    [anon_sym_notif1] = ACTIONS(4806),
    [anon_sym_nmos] = ACTIONS(4806),
    [anon_sym_pmos] = ACTIONS(4806),
    [anon_sym_rnmos] = ACTIONS(4806),
    [anon_sym_rpmos] = ACTIONS(4806),
    [anon_sym_nand] = ACTIONS(4806),
    [anon_sym_nor] = ACTIONS(4806),
    [anon_sym_xor] = ACTIONS(4806),
    [anon_sym_xnor] = ACTIONS(4806),
    [anon_sym_buf] = ACTIONS(4806),
    [anon_sym_tranif0] = ACTIONS(4806),
    [anon_sym_tranif1] = ACTIONS(4806),
    [anon_sym_rtranif1] = ACTIONS(4806),
    [anon_sym_rtranif0] = ACTIONS(4806),
    [anon_sym_tran] = ACTIONS(4806),
    [anon_sym_rtran] = ACTIONS(4806),
    [anon_sym_generate] = ACTIONS(4806),
    [anon_sym_for] = ACTIONS(4806),
    [anon_sym_initial] = ACTIONS(4806),
    [anon_sym_assign] = ACTIONS(4806),
    [anon_sym_alias] = ACTIONS(4806),
    [anon_sym_always_comb] = ACTIONS(4806),
    [anon_sym_always_latch] = ACTIONS(4806),
    [anon_sym_always_ff] = ACTIONS(4806),
    [anon_sym_final] = ACTIONS(4806),
    [anon_sym_global] = ACTIONS(4806),
    [anon_sym_LPAREN_STAR] = ACTIONS(4804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4804),
    [anon_sym_DOLLARunit] = ACTIONS(4804),
  },
  [4457] = {
    [sym_simple_identifier] = ACTIONS(4662),
    [anon_sym_wire] = ACTIONS(4662),
    [anon_sym_tri] = ACTIONS(4662),
    [anon_sym_tri0] = ACTIONS(4662),
    [anon_sym_tri1] = ACTIONS(4662),
    [anon_sym_wand] = ACTIONS(4662),
    [anon_sym_triand] = ACTIONS(4662),
    [anon_sym_wor] = ACTIONS(4662),
    [anon_sym_trior] = ACTIONS(4662),
    [anon_sym_trireg] = ACTIONS(4662),
    [anon_sym_uwire] = ACTIONS(4662),
    [anon_sym_SEMI] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(10631),
    [anon_sym_extern] = ACTIONS(4662),
    [anon_sym_interface] = ACTIONS(4662),
    [anon_sym_checker] = ACTIONS(4662),
    [anon_sym_virtual] = ACTIONS(4662),
    [anon_sym_class] = ACTIONS(4662),
    [anon_sym_type] = ACTIONS(4662),
    [anon_sym_DOLLARfatal] = ACTIONS(4660),
    [anon_sym_DOLLARerror] = ACTIONS(4660),
    [anon_sym_DOLLARwarning] = ACTIONS(4660),
    [anon_sym_DOLLARinfo] = ACTIONS(4660),
    [anon_sym_default] = ACTIONS(4662),
    [anon_sym_clocking] = ACTIONS(4662),
    [anon_sym_defparam] = ACTIONS(4662),
    [anon_sym_bind] = ACTIONS(4662),
    [anon_sym_rand] = ACTIONS(4662),
    [anon_sym_const] = ACTIONS(4662),
    [anon_sym_function] = ACTIONS(4662),
    [anon_sym_static] = ACTIONS(4662),
    [anon_sym_constraint] = ACTIONS(4662),
    [anon_sym_if] = ACTIONS(4662),
    [anon_sym_else] = ACTIONS(4662),
    [anon_sym_LBRACK] = ACTIONS(4660),
    [anon_sym_localparam] = ACTIONS(4662),
    [anon_sym_parameter] = ACTIONS(4662),
    [anon_sym_var] = ACTIONS(4662),
    [anon_sym_import] = ACTIONS(4662),
    [anon_sym_export] = ACTIONS(4662),
    [anon_sym_genvar] = ACTIONS(4662),
    [anon_sym_interconnect] = ACTIONS(4662),
    [anon_sym_typedef] = ACTIONS(4662),
    [anon_sym_enum] = ACTIONS(4662),
    [anon_sym_struct] = ACTIONS(4662),
    [anon_sym_union] = ACTIONS(4662),
    [anon_sym_nettype] = ACTIONS(4662),
    [anon_sym_automatic] = ACTIONS(4662),
    [anon_sym_string] = ACTIONS(4662),
    [anon_sym_chandle] = ACTIONS(4662),
    [anon_sym_event] = ACTIONS(4662),
    [anon_sym_byte] = ACTIONS(4662),
    [anon_sym_shortint] = ACTIONS(4662),
    [anon_sym_int] = ACTIONS(4662),
    [anon_sym_longint] = ACTIONS(4662),
    [anon_sym_integer] = ACTIONS(4662),
    [anon_sym_time] = ACTIONS(4662),
    [anon_sym_bit] = ACTIONS(4662),
    [anon_sym_logic] = ACTIONS(4662),
    [anon_sym_reg] = ACTIONS(4662),
    [anon_sym_shortreal] = ACTIONS(4662),
    [anon_sym_real] = ACTIONS(4662),
    [anon_sym_realtime] = ACTIONS(4662),
    [anon_sym_supply0] = ACTIONS(4662),
    [anon_sym_supply1] = ACTIONS(4662),
    [anon_sym_signed] = ACTIONS(4662),
    [anon_sym_unsigned] = ACTIONS(4662),
    [anon_sym_task] = ACTIONS(4662),
    [anon_sym_assert] = ACTIONS(4662),
    [anon_sym_property] = ACTIONS(4662),
    [anon_sym_assume] = ACTIONS(4662),
    [anon_sym_cover] = ACTIONS(4662),
    [anon_sym_sequence] = ACTIONS(4662),
    [anon_sym_restrict] = ACTIONS(4662),
    [anon_sym_not] = ACTIONS(4662),
    [anon_sym_or] = ACTIONS(4662),
    [anon_sym_and] = ACTIONS(4662),
    [anon_sym_case] = ACTIONS(4662),
    [anon_sym_always] = ACTIONS(4662),
    [anon_sym_covergroup] = ACTIONS(4662),
    [anon_sym_let] = ACTIONS(4662),
    [anon_sym_pulldown] = ACTIONS(4662),
    [anon_sym_pullup] = ACTIONS(4662),
    [anon_sym_cmos] = ACTIONS(4662),
    [anon_sym_rcmos] = ACTIONS(4662),
    [anon_sym_bufif0] = ACTIONS(4662),
    [anon_sym_bufif1] = ACTIONS(4662),
    [anon_sym_notif0] = ACTIONS(4662),
    [anon_sym_notif1] = ACTIONS(4662),
    [anon_sym_nmos] = ACTIONS(4662),
    [anon_sym_pmos] = ACTIONS(4662),
    [anon_sym_rnmos] = ACTIONS(4662),
    [anon_sym_rpmos] = ACTIONS(4662),
    [anon_sym_nand] = ACTIONS(4662),
    [anon_sym_nor] = ACTIONS(4662),
    [anon_sym_xor] = ACTIONS(4662),
    [anon_sym_xnor] = ACTIONS(4662),
    [anon_sym_buf] = ACTIONS(4662),
    [anon_sym_tranif0] = ACTIONS(4662),
    [anon_sym_tranif1] = ACTIONS(4662),
    [anon_sym_rtranif1] = ACTIONS(4662),
    [anon_sym_rtranif0] = ACTIONS(4662),
    [anon_sym_tran] = ACTIONS(4662),
    [anon_sym_rtran] = ACTIONS(4662),
    [anon_sym_generate] = ACTIONS(4662),
    [anon_sym_endgenerate] = ACTIONS(4662),
    [anon_sym_for] = ACTIONS(4662),
    [anon_sym_initial] = ACTIONS(4662),
    [anon_sym_assign] = ACTIONS(4662),
    [anon_sym_alias] = ACTIONS(4662),
    [anon_sym_always_comb] = ACTIONS(4662),
    [anon_sym_always_latch] = ACTIONS(4662),
    [anon_sym_always_ff] = ACTIONS(4662),
    [anon_sym_final] = ACTIONS(4662),
    [anon_sym_global] = ACTIONS(4662),
    [anon_sym_LPAREN_STAR] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4660),
    [anon_sym_DOLLARunit] = ACTIONS(4660),
  },
  [4458] = {
    [sym_simple_identifier] = ACTIONS(4500),
    [anon_sym_wire] = ACTIONS(4500),
    [anon_sym_tri] = ACTIONS(4500),
    [anon_sym_tri0] = ACTIONS(4500),
    [anon_sym_tri1] = ACTIONS(4500),
    [anon_sym_wand] = ACTIONS(4500),
    [anon_sym_triand] = ACTIONS(4500),
    [anon_sym_wor] = ACTIONS(4500),
    [anon_sym_trior] = ACTIONS(4500),
    [anon_sym_trireg] = ACTIONS(4500),
    [anon_sym_uwire] = ACTIONS(4500),
    [anon_sym_SEMI] = ACTIONS(4498),
    [anon_sym_COLON] = ACTIONS(10633),
    [anon_sym_extern] = ACTIONS(4500),
    [anon_sym_interface] = ACTIONS(4500),
    [anon_sym_checker] = ACTIONS(4500),
    [anon_sym_virtual] = ACTIONS(4500),
    [anon_sym_class] = ACTIONS(4500),
    [anon_sym_type] = ACTIONS(4500),
    [anon_sym_DOLLARfatal] = ACTIONS(4498),
    [anon_sym_DOLLARerror] = ACTIONS(4498),
    [anon_sym_DOLLARwarning] = ACTIONS(4498),
    [anon_sym_DOLLARinfo] = ACTIONS(4498),
    [anon_sym_default] = ACTIONS(4500),
    [anon_sym_clocking] = ACTIONS(4500),
    [anon_sym_defparam] = ACTIONS(4500),
    [anon_sym_bind] = ACTIONS(4500),
    [anon_sym_rand] = ACTIONS(4500),
    [anon_sym_const] = ACTIONS(4500),
    [anon_sym_function] = ACTIONS(4500),
    [anon_sym_static] = ACTIONS(4500),
    [anon_sym_constraint] = ACTIONS(4500),
    [anon_sym_if] = ACTIONS(4500),
    [anon_sym_else] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4498),
    [anon_sym_localparam] = ACTIONS(4500),
    [anon_sym_parameter] = ACTIONS(4500),
    [anon_sym_var] = ACTIONS(4500),
    [anon_sym_import] = ACTIONS(4500),
    [anon_sym_export] = ACTIONS(4500),
    [anon_sym_genvar] = ACTIONS(4500),
    [anon_sym_interconnect] = ACTIONS(4500),
    [anon_sym_typedef] = ACTIONS(4500),
    [anon_sym_enum] = ACTIONS(4500),
    [anon_sym_struct] = ACTIONS(4500),
    [anon_sym_union] = ACTIONS(4500),
    [anon_sym_nettype] = ACTIONS(4500),
    [anon_sym_automatic] = ACTIONS(4500),
    [anon_sym_string] = ACTIONS(4500),
    [anon_sym_chandle] = ACTIONS(4500),
    [anon_sym_event] = ACTIONS(4500),
    [anon_sym_byte] = ACTIONS(4500),
    [anon_sym_shortint] = ACTIONS(4500),
    [anon_sym_int] = ACTIONS(4500),
    [anon_sym_longint] = ACTIONS(4500),
    [anon_sym_integer] = ACTIONS(4500),
    [anon_sym_time] = ACTIONS(4500),
    [anon_sym_bit] = ACTIONS(4500),
    [anon_sym_logic] = ACTIONS(4500),
    [anon_sym_reg] = ACTIONS(4500),
    [anon_sym_shortreal] = ACTIONS(4500),
    [anon_sym_real] = ACTIONS(4500),
    [anon_sym_realtime] = ACTIONS(4500),
    [anon_sym_supply0] = ACTIONS(4500),
    [anon_sym_supply1] = ACTIONS(4500),
    [anon_sym_signed] = ACTIONS(4500),
    [anon_sym_unsigned] = ACTIONS(4500),
    [anon_sym_task] = ACTIONS(4500),
    [anon_sym_assert] = ACTIONS(4500),
    [anon_sym_property] = ACTIONS(4500),
    [anon_sym_assume] = ACTIONS(4500),
    [anon_sym_cover] = ACTIONS(4500),
    [anon_sym_sequence] = ACTIONS(4500),
    [anon_sym_restrict] = ACTIONS(4500),
    [anon_sym_not] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_case] = ACTIONS(4500),
    [anon_sym_always] = ACTIONS(4500),
    [anon_sym_covergroup] = ACTIONS(4500),
    [anon_sym_end] = ACTIONS(4500),
    [anon_sym_let] = ACTIONS(4500),
    [anon_sym_pulldown] = ACTIONS(4500),
    [anon_sym_pullup] = ACTIONS(4500),
    [anon_sym_cmos] = ACTIONS(4500),
    [anon_sym_rcmos] = ACTIONS(4500),
    [anon_sym_bufif0] = ACTIONS(4500),
    [anon_sym_bufif1] = ACTIONS(4500),
    [anon_sym_notif0] = ACTIONS(4500),
    [anon_sym_notif1] = ACTIONS(4500),
    [anon_sym_nmos] = ACTIONS(4500),
    [anon_sym_pmos] = ACTIONS(4500),
    [anon_sym_rnmos] = ACTIONS(4500),
    [anon_sym_rpmos] = ACTIONS(4500),
    [anon_sym_nand] = ACTIONS(4500),
    [anon_sym_nor] = ACTIONS(4500),
    [anon_sym_xor] = ACTIONS(4500),
    [anon_sym_xnor] = ACTIONS(4500),
    [anon_sym_buf] = ACTIONS(4500),
    [anon_sym_tranif0] = ACTIONS(4500),
    [anon_sym_tranif1] = ACTIONS(4500),
    [anon_sym_rtranif1] = ACTIONS(4500),
    [anon_sym_rtranif0] = ACTIONS(4500),
    [anon_sym_tran] = ACTIONS(4500),
    [anon_sym_rtran] = ACTIONS(4500),
    [anon_sym_generate] = ACTIONS(4500),
    [anon_sym_for] = ACTIONS(4500),
    [anon_sym_initial] = ACTIONS(4500),
    [anon_sym_assign] = ACTIONS(4500),
    [anon_sym_alias] = ACTIONS(4500),
    [anon_sym_always_comb] = ACTIONS(4500),
    [anon_sym_always_latch] = ACTIONS(4500),
    [anon_sym_always_ff] = ACTIONS(4500),
    [anon_sym_final] = ACTIONS(4500),
    [anon_sym_global] = ACTIONS(4500),
    [anon_sym_LPAREN_STAR] = ACTIONS(4498),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4498),
    [anon_sym_DOLLARunit] = ACTIONS(4498),
  },
  [4459] = {
    [sym_simple_identifier] = ACTIONS(4506),
    [anon_sym_wire] = ACTIONS(4506),
    [anon_sym_tri] = ACTIONS(4506),
    [anon_sym_tri0] = ACTIONS(4506),
    [anon_sym_tri1] = ACTIONS(4506),
    [anon_sym_wand] = ACTIONS(4506),
    [anon_sym_triand] = ACTIONS(4506),
    [anon_sym_wor] = ACTIONS(4506),
    [anon_sym_trior] = ACTIONS(4506),
    [anon_sym_trireg] = ACTIONS(4506),
    [anon_sym_uwire] = ACTIONS(4506),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(10635),
    [anon_sym_extern] = ACTIONS(4506),
    [anon_sym_interface] = ACTIONS(4506),
    [anon_sym_checker] = ACTIONS(4506),
    [anon_sym_virtual] = ACTIONS(4506),
    [anon_sym_class] = ACTIONS(4506),
    [anon_sym_type] = ACTIONS(4506),
    [anon_sym_DOLLARfatal] = ACTIONS(4504),
    [anon_sym_DOLLARerror] = ACTIONS(4504),
    [anon_sym_DOLLARwarning] = ACTIONS(4504),
    [anon_sym_DOLLARinfo] = ACTIONS(4504),
    [anon_sym_default] = ACTIONS(4506),
    [anon_sym_clocking] = ACTIONS(4506),
    [anon_sym_defparam] = ACTIONS(4506),
    [anon_sym_bind] = ACTIONS(4506),
    [anon_sym_rand] = ACTIONS(4506),
    [anon_sym_const] = ACTIONS(4506),
    [anon_sym_function] = ACTIONS(4506),
    [anon_sym_static] = ACTIONS(4506),
    [anon_sym_constraint] = ACTIONS(4506),
    [anon_sym_if] = ACTIONS(4506),
    [anon_sym_else] = ACTIONS(4506),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_localparam] = ACTIONS(4506),
    [anon_sym_parameter] = ACTIONS(4506),
    [anon_sym_var] = ACTIONS(4506),
    [anon_sym_import] = ACTIONS(4506),
    [anon_sym_export] = ACTIONS(4506),
    [anon_sym_genvar] = ACTIONS(4506),
    [anon_sym_interconnect] = ACTIONS(4506),
    [anon_sym_typedef] = ACTIONS(4506),
    [anon_sym_enum] = ACTIONS(4506),
    [anon_sym_struct] = ACTIONS(4506),
    [anon_sym_union] = ACTIONS(4506),
    [anon_sym_nettype] = ACTIONS(4506),
    [anon_sym_automatic] = ACTIONS(4506),
    [anon_sym_string] = ACTIONS(4506),
    [anon_sym_chandle] = ACTIONS(4506),
    [anon_sym_event] = ACTIONS(4506),
    [anon_sym_byte] = ACTIONS(4506),
    [anon_sym_shortint] = ACTIONS(4506),
    [anon_sym_int] = ACTIONS(4506),
    [anon_sym_longint] = ACTIONS(4506),
    [anon_sym_integer] = ACTIONS(4506),
    [anon_sym_time] = ACTIONS(4506),
    [anon_sym_bit] = ACTIONS(4506),
    [anon_sym_logic] = ACTIONS(4506),
    [anon_sym_reg] = ACTIONS(4506),
    [anon_sym_shortreal] = ACTIONS(4506),
    [anon_sym_real] = ACTIONS(4506),
    [anon_sym_realtime] = ACTIONS(4506),
    [anon_sym_supply0] = ACTIONS(4506),
    [anon_sym_supply1] = ACTIONS(4506),
    [anon_sym_signed] = ACTIONS(4506),
    [anon_sym_unsigned] = ACTIONS(4506),
    [anon_sym_task] = ACTIONS(4506),
    [anon_sym_assert] = ACTIONS(4506),
    [anon_sym_property] = ACTIONS(4506),
    [anon_sym_assume] = ACTIONS(4506),
    [anon_sym_cover] = ACTIONS(4506),
    [anon_sym_sequence] = ACTIONS(4506),
    [anon_sym_restrict] = ACTIONS(4506),
    [anon_sym_not] = ACTIONS(4506),
    [anon_sym_or] = ACTIONS(4506),
    [anon_sym_and] = ACTIONS(4506),
    [anon_sym_case] = ACTIONS(4506),
    [anon_sym_always] = ACTIONS(4506),
    [anon_sym_covergroup] = ACTIONS(4506),
    [anon_sym_end] = ACTIONS(4506),
    [anon_sym_let] = ACTIONS(4506),
    [anon_sym_pulldown] = ACTIONS(4506),
    [anon_sym_pullup] = ACTIONS(4506),
    [anon_sym_cmos] = ACTIONS(4506),
    [anon_sym_rcmos] = ACTIONS(4506),
    [anon_sym_bufif0] = ACTIONS(4506),
    [anon_sym_bufif1] = ACTIONS(4506),
    [anon_sym_notif0] = ACTIONS(4506),
    [anon_sym_notif1] = ACTIONS(4506),
    [anon_sym_nmos] = ACTIONS(4506),
    [anon_sym_pmos] = ACTIONS(4506),
    [anon_sym_rnmos] = ACTIONS(4506),
    [anon_sym_rpmos] = ACTIONS(4506),
    [anon_sym_nand] = ACTIONS(4506),
    [anon_sym_nor] = ACTIONS(4506),
    [anon_sym_xor] = ACTIONS(4506),
    [anon_sym_xnor] = ACTIONS(4506),
    [anon_sym_buf] = ACTIONS(4506),
    [anon_sym_tranif0] = ACTIONS(4506),
    [anon_sym_tranif1] = ACTIONS(4506),
    [anon_sym_rtranif1] = ACTIONS(4506),
    [anon_sym_rtranif0] = ACTIONS(4506),
    [anon_sym_tran] = ACTIONS(4506),
    [anon_sym_rtran] = ACTIONS(4506),
    [anon_sym_generate] = ACTIONS(4506),
    [anon_sym_for] = ACTIONS(4506),
    [anon_sym_initial] = ACTIONS(4506),
    [anon_sym_assign] = ACTIONS(4506),
    [anon_sym_alias] = ACTIONS(4506),
    [anon_sym_always_comb] = ACTIONS(4506),
    [anon_sym_always_latch] = ACTIONS(4506),
    [anon_sym_always_ff] = ACTIONS(4506),
    [anon_sym_final] = ACTIONS(4506),
    [anon_sym_global] = ACTIONS(4506),
    [anon_sym_LPAREN_STAR] = ACTIONS(4504),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4504),
    [anon_sym_DOLLARunit] = ACTIONS(4504),
  },
  [4460] = {
    [sym_simple_identifier] = ACTIONS(4606),
    [anon_sym_wire] = ACTIONS(4606),
    [anon_sym_tri] = ACTIONS(4606),
    [anon_sym_tri0] = ACTIONS(4606),
    [anon_sym_tri1] = ACTIONS(4606),
    [anon_sym_wand] = ACTIONS(4606),
    [anon_sym_triand] = ACTIONS(4606),
    [anon_sym_wor] = ACTIONS(4606),
    [anon_sym_trior] = ACTIONS(4606),
    [anon_sym_trireg] = ACTIONS(4606),
    [anon_sym_uwire] = ACTIONS(4606),
    [anon_sym_SEMI] = ACTIONS(4604),
    [anon_sym_COLON] = ACTIONS(10637),
    [anon_sym_extern] = ACTIONS(4606),
    [anon_sym_interface] = ACTIONS(4606),
    [anon_sym_checker] = ACTIONS(4606),
    [anon_sym_virtual] = ACTIONS(4606),
    [anon_sym_class] = ACTIONS(4606),
    [anon_sym_type] = ACTIONS(4606),
    [anon_sym_DOLLARfatal] = ACTIONS(4604),
    [anon_sym_DOLLARerror] = ACTIONS(4604),
    [anon_sym_DOLLARwarning] = ACTIONS(4604),
    [anon_sym_DOLLARinfo] = ACTIONS(4604),
    [anon_sym_default] = ACTIONS(4606),
    [anon_sym_clocking] = ACTIONS(4606),
    [anon_sym_defparam] = ACTIONS(4606),
    [anon_sym_bind] = ACTIONS(4606),
    [anon_sym_rand] = ACTIONS(4606),
    [anon_sym_const] = ACTIONS(4606),
    [anon_sym_function] = ACTIONS(4606),
    [anon_sym_static] = ACTIONS(4606),
    [anon_sym_constraint] = ACTIONS(4606),
    [anon_sym_if] = ACTIONS(4606),
    [anon_sym_else] = ACTIONS(4606),
    [anon_sym_LBRACK] = ACTIONS(4604),
    [anon_sym_localparam] = ACTIONS(4606),
    [anon_sym_parameter] = ACTIONS(4606),
    [anon_sym_var] = ACTIONS(4606),
    [anon_sym_import] = ACTIONS(4606),
    [anon_sym_export] = ACTIONS(4606),
    [anon_sym_genvar] = ACTIONS(4606),
    [anon_sym_interconnect] = ACTIONS(4606),
    [anon_sym_typedef] = ACTIONS(4606),
    [anon_sym_enum] = ACTIONS(4606),
    [anon_sym_struct] = ACTIONS(4606),
    [anon_sym_union] = ACTIONS(4606),
    [anon_sym_nettype] = ACTIONS(4606),
    [anon_sym_automatic] = ACTIONS(4606),
    [anon_sym_string] = ACTIONS(4606),
    [anon_sym_chandle] = ACTIONS(4606),
    [anon_sym_event] = ACTIONS(4606),
    [anon_sym_byte] = ACTIONS(4606),
    [anon_sym_shortint] = ACTIONS(4606),
    [anon_sym_int] = ACTIONS(4606),
    [anon_sym_longint] = ACTIONS(4606),
    [anon_sym_integer] = ACTIONS(4606),
    [anon_sym_time] = ACTIONS(4606),
    [anon_sym_bit] = ACTIONS(4606),
    [anon_sym_logic] = ACTIONS(4606),
    [anon_sym_reg] = ACTIONS(4606),
    [anon_sym_shortreal] = ACTIONS(4606),
    [anon_sym_real] = ACTIONS(4606),
    [anon_sym_realtime] = ACTIONS(4606),
    [anon_sym_supply0] = ACTIONS(4606),
    [anon_sym_supply1] = ACTIONS(4606),
    [anon_sym_signed] = ACTIONS(4606),
    [anon_sym_unsigned] = ACTIONS(4606),
    [anon_sym_task] = ACTIONS(4606),
    [anon_sym_assert] = ACTIONS(4606),
    [anon_sym_property] = ACTIONS(4606),
    [anon_sym_assume] = ACTIONS(4606),
    [anon_sym_cover] = ACTIONS(4606),
    [anon_sym_sequence] = ACTIONS(4606),
    [anon_sym_restrict] = ACTIONS(4606),
    [anon_sym_not] = ACTIONS(4606),
    [anon_sym_or] = ACTIONS(4606),
    [anon_sym_and] = ACTIONS(4606),
    [anon_sym_case] = ACTIONS(4606),
    [anon_sym_always] = ACTIONS(4606),
    [anon_sym_covergroup] = ACTIONS(4606),
    [anon_sym_end] = ACTIONS(4606),
    [anon_sym_let] = ACTIONS(4606),
    [anon_sym_pulldown] = ACTIONS(4606),
    [anon_sym_pullup] = ACTIONS(4606),
    [anon_sym_cmos] = ACTIONS(4606),
    [anon_sym_rcmos] = ACTIONS(4606),
    [anon_sym_bufif0] = ACTIONS(4606),
    [anon_sym_bufif1] = ACTIONS(4606),
    [anon_sym_notif0] = ACTIONS(4606),
    [anon_sym_notif1] = ACTIONS(4606),
    [anon_sym_nmos] = ACTIONS(4606),
    [anon_sym_pmos] = ACTIONS(4606),
    [anon_sym_rnmos] = ACTIONS(4606),
    [anon_sym_rpmos] = ACTIONS(4606),
    [anon_sym_nand] = ACTIONS(4606),
    [anon_sym_nor] = ACTIONS(4606),
    [anon_sym_xor] = ACTIONS(4606),
    [anon_sym_xnor] = ACTIONS(4606),
    [anon_sym_buf] = ACTIONS(4606),
    [anon_sym_tranif0] = ACTIONS(4606),
    [anon_sym_tranif1] = ACTIONS(4606),
    [anon_sym_rtranif1] = ACTIONS(4606),
    [anon_sym_rtranif0] = ACTIONS(4606),
    [anon_sym_tran] = ACTIONS(4606),
    [anon_sym_rtran] = ACTIONS(4606),
    [anon_sym_generate] = ACTIONS(4606),
    [anon_sym_for] = ACTIONS(4606),
    [anon_sym_initial] = ACTIONS(4606),
    [anon_sym_assign] = ACTIONS(4606),
    [anon_sym_alias] = ACTIONS(4606),
    [anon_sym_always_comb] = ACTIONS(4606),
    [anon_sym_always_latch] = ACTIONS(4606),
    [anon_sym_always_ff] = ACTIONS(4606),
    [anon_sym_final] = ACTIONS(4606),
    [anon_sym_global] = ACTIONS(4606),
    [anon_sym_LPAREN_STAR] = ACTIONS(4604),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4604),
    [anon_sym_DOLLARunit] = ACTIONS(4604),
  },
  [4461] = {
    [sym_simple_identifier] = ACTIONS(4702),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_COLON] = ACTIONS(10639),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_rand] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_endgenerate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [4462] = {
    [sym_simple_identifier] = ACTIONS(4400),
    [anon_sym_wire] = ACTIONS(4400),
    [anon_sym_tri] = ACTIONS(4400),
    [anon_sym_tri0] = ACTIONS(4400),
    [anon_sym_tri1] = ACTIONS(4400),
    [anon_sym_wand] = ACTIONS(4400),
    [anon_sym_triand] = ACTIONS(4400),
    [anon_sym_wor] = ACTIONS(4400),
    [anon_sym_trior] = ACTIONS(4400),
    [anon_sym_trireg] = ACTIONS(4400),
    [anon_sym_uwire] = ACTIONS(4400),
    [anon_sym_SEMI] = ACTIONS(4398),
    [anon_sym_COLON] = ACTIONS(10641),
    [anon_sym_extern] = ACTIONS(4400),
    [anon_sym_interface] = ACTIONS(4400),
    [anon_sym_checker] = ACTIONS(4400),
    [anon_sym_virtual] = ACTIONS(4400),
    [anon_sym_class] = ACTIONS(4400),
    [anon_sym_type] = ACTIONS(4400),
    [anon_sym_DOLLARfatal] = ACTIONS(4398),
    [anon_sym_DOLLARerror] = ACTIONS(4398),
    [anon_sym_DOLLARwarning] = ACTIONS(4398),
    [anon_sym_DOLLARinfo] = ACTIONS(4398),
    [anon_sym_default] = ACTIONS(4400),
    [anon_sym_clocking] = ACTIONS(4400),
    [anon_sym_defparam] = ACTIONS(4400),
    [anon_sym_bind] = ACTIONS(4400),
    [anon_sym_rand] = ACTIONS(4400),
    [anon_sym_const] = ACTIONS(4400),
    [anon_sym_function] = ACTIONS(4400),
    [anon_sym_static] = ACTIONS(4400),
    [anon_sym_constraint] = ACTIONS(4400),
    [anon_sym_if] = ACTIONS(4400),
    [anon_sym_else] = ACTIONS(4400),
    [anon_sym_LBRACK] = ACTIONS(4398),
    [anon_sym_localparam] = ACTIONS(4400),
    [anon_sym_parameter] = ACTIONS(4400),
    [anon_sym_var] = ACTIONS(4400),
    [anon_sym_import] = ACTIONS(4400),
    [anon_sym_export] = ACTIONS(4400),
    [anon_sym_genvar] = ACTIONS(4400),
    [anon_sym_interconnect] = ACTIONS(4400),
    [anon_sym_typedef] = ACTIONS(4400),
    [anon_sym_enum] = ACTIONS(4400),
    [anon_sym_struct] = ACTIONS(4400),
    [anon_sym_union] = ACTIONS(4400),
    [anon_sym_nettype] = ACTIONS(4400),
    [anon_sym_automatic] = ACTIONS(4400),
    [anon_sym_string] = ACTIONS(4400),
    [anon_sym_chandle] = ACTIONS(4400),
    [anon_sym_event] = ACTIONS(4400),
    [anon_sym_byte] = ACTIONS(4400),
    [anon_sym_shortint] = ACTIONS(4400),
    [anon_sym_int] = ACTIONS(4400),
    [anon_sym_longint] = ACTIONS(4400),
    [anon_sym_integer] = ACTIONS(4400),
    [anon_sym_time] = ACTIONS(4400),
    [anon_sym_bit] = ACTIONS(4400),
    [anon_sym_logic] = ACTIONS(4400),
    [anon_sym_reg] = ACTIONS(4400),
    [anon_sym_shortreal] = ACTIONS(4400),
    [anon_sym_real] = ACTIONS(4400),
    [anon_sym_realtime] = ACTIONS(4400),
    [anon_sym_supply0] = ACTIONS(4400),
    [anon_sym_supply1] = ACTIONS(4400),
    [anon_sym_signed] = ACTIONS(4400),
    [anon_sym_unsigned] = ACTIONS(4400),
    [anon_sym_task] = ACTIONS(4400),
    [anon_sym_assert] = ACTIONS(4400),
    [anon_sym_property] = ACTIONS(4400),
    [anon_sym_assume] = ACTIONS(4400),
    [anon_sym_cover] = ACTIONS(4400),
    [anon_sym_sequence] = ACTIONS(4400),
    [anon_sym_restrict] = ACTIONS(4400),
    [anon_sym_not] = ACTIONS(4400),
    [anon_sym_or] = ACTIONS(4400),
    [anon_sym_and] = ACTIONS(4400),
    [anon_sym_case] = ACTIONS(4400),
    [anon_sym_always] = ACTIONS(4400),
    [anon_sym_covergroup] = ACTIONS(4400),
    [anon_sym_let] = ACTIONS(4400),
    [anon_sym_pulldown] = ACTIONS(4400),
    [anon_sym_pullup] = ACTIONS(4400),
    [anon_sym_cmos] = ACTIONS(4400),
    [anon_sym_rcmos] = ACTIONS(4400),
    [anon_sym_bufif0] = ACTIONS(4400),
    [anon_sym_bufif1] = ACTIONS(4400),
    [anon_sym_notif0] = ACTIONS(4400),
    [anon_sym_notif1] = ACTIONS(4400),
    [anon_sym_nmos] = ACTIONS(4400),
    [anon_sym_pmos] = ACTIONS(4400),
    [anon_sym_rnmos] = ACTIONS(4400),
    [anon_sym_rpmos] = ACTIONS(4400),
    [anon_sym_nand] = ACTIONS(4400),
    [anon_sym_nor] = ACTIONS(4400),
    [anon_sym_xor] = ACTIONS(4400),
    [anon_sym_xnor] = ACTIONS(4400),
    [anon_sym_buf] = ACTIONS(4400),
    [anon_sym_tranif0] = ACTIONS(4400),
    [anon_sym_tranif1] = ACTIONS(4400),
    [anon_sym_rtranif1] = ACTIONS(4400),
    [anon_sym_rtranif0] = ACTIONS(4400),
    [anon_sym_tran] = ACTIONS(4400),
    [anon_sym_rtran] = ACTIONS(4400),
    [anon_sym_generate] = ACTIONS(4400),
    [anon_sym_endgenerate] = ACTIONS(4400),
    [anon_sym_for] = ACTIONS(4400),
    [anon_sym_initial] = ACTIONS(4400),
    [anon_sym_assign] = ACTIONS(4400),
    [anon_sym_alias] = ACTIONS(4400),
    [anon_sym_always_comb] = ACTIONS(4400),
    [anon_sym_always_latch] = ACTIONS(4400),
    [anon_sym_always_ff] = ACTIONS(4400),
    [anon_sym_final] = ACTIONS(4400),
    [anon_sym_global] = ACTIONS(4400),
    [anon_sym_LPAREN_STAR] = ACTIONS(4398),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4398),
    [anon_sym_DOLLARunit] = ACTIONS(4398),
  },
  [4463] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_COLON] = ACTIONS(10643),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_rand] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_end] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [4464] = {
    [sym_simple_identifier] = ACTIONS(4720),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_COLON] = ACTIONS(10645),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_rand] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_end] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [4465] = {
    [sym_simple_identifier] = ACTIONS(4518),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_COLON] = ACTIONS(10647),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_rand] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_endgenerate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [4466] = {
    [sym_simple_identifier] = ACTIONS(4548),
    [anon_sym_wire] = ACTIONS(4548),
    [anon_sym_tri] = ACTIONS(4548),
    [anon_sym_tri0] = ACTIONS(4548),
    [anon_sym_tri1] = ACTIONS(4548),
    [anon_sym_wand] = ACTIONS(4548),
    [anon_sym_triand] = ACTIONS(4548),
    [anon_sym_wor] = ACTIONS(4548),
    [anon_sym_trior] = ACTIONS(4548),
    [anon_sym_trireg] = ACTIONS(4548),
    [anon_sym_uwire] = ACTIONS(4548),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(10649),
    [anon_sym_extern] = ACTIONS(4548),
    [anon_sym_interface] = ACTIONS(4548),
    [anon_sym_checker] = ACTIONS(4548),
    [anon_sym_virtual] = ACTIONS(4548),
    [anon_sym_class] = ACTIONS(4548),
    [anon_sym_type] = ACTIONS(4548),
    [anon_sym_DOLLARfatal] = ACTIONS(4546),
    [anon_sym_DOLLARerror] = ACTIONS(4546),
    [anon_sym_DOLLARwarning] = ACTIONS(4546),
    [anon_sym_DOLLARinfo] = ACTIONS(4546),
    [anon_sym_default] = ACTIONS(4548),
    [anon_sym_clocking] = ACTIONS(4548),
    [anon_sym_defparam] = ACTIONS(4548),
    [anon_sym_bind] = ACTIONS(4548),
    [anon_sym_rand] = ACTIONS(4548),
    [anon_sym_const] = ACTIONS(4548),
    [anon_sym_function] = ACTIONS(4548),
    [anon_sym_static] = ACTIONS(4548),
    [anon_sym_constraint] = ACTIONS(4548),
    [anon_sym_if] = ACTIONS(4548),
    [anon_sym_else] = ACTIONS(4548),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_localparam] = ACTIONS(4548),
    [anon_sym_parameter] = ACTIONS(4548),
    [anon_sym_var] = ACTIONS(4548),
    [anon_sym_import] = ACTIONS(4548),
    [anon_sym_export] = ACTIONS(4548),
    [anon_sym_genvar] = ACTIONS(4548),
    [anon_sym_interconnect] = ACTIONS(4548),
    [anon_sym_typedef] = ACTIONS(4548),
    [anon_sym_enum] = ACTIONS(4548),
    [anon_sym_struct] = ACTIONS(4548),
    [anon_sym_union] = ACTIONS(4548),
    [anon_sym_nettype] = ACTIONS(4548),
    [anon_sym_automatic] = ACTIONS(4548),
    [anon_sym_string] = ACTIONS(4548),
    [anon_sym_chandle] = ACTIONS(4548),
    [anon_sym_event] = ACTIONS(4548),
    [anon_sym_byte] = ACTIONS(4548),
    [anon_sym_shortint] = ACTIONS(4548),
    [anon_sym_int] = ACTIONS(4548),
    [anon_sym_longint] = ACTIONS(4548),
    [anon_sym_integer] = ACTIONS(4548),
    [anon_sym_time] = ACTIONS(4548),
    [anon_sym_bit] = ACTIONS(4548),
    [anon_sym_logic] = ACTIONS(4548),
    [anon_sym_reg] = ACTIONS(4548),
    [anon_sym_shortreal] = ACTIONS(4548),
    [anon_sym_real] = ACTIONS(4548),
    [anon_sym_realtime] = ACTIONS(4548),
    [anon_sym_supply0] = ACTIONS(4548),
    [anon_sym_supply1] = ACTIONS(4548),
    [anon_sym_signed] = ACTIONS(4548),
    [anon_sym_unsigned] = ACTIONS(4548),
    [anon_sym_task] = ACTIONS(4548),
    [anon_sym_assert] = ACTIONS(4548),
    [anon_sym_property] = ACTIONS(4548),
    [anon_sym_assume] = ACTIONS(4548),
    [anon_sym_cover] = ACTIONS(4548),
    [anon_sym_sequence] = ACTIONS(4548),
    [anon_sym_restrict] = ACTIONS(4548),
    [anon_sym_not] = ACTIONS(4548),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_and] = ACTIONS(4548),
    [anon_sym_case] = ACTIONS(4548),
    [anon_sym_always] = ACTIONS(4548),
    [anon_sym_covergroup] = ACTIONS(4548),
    [anon_sym_let] = ACTIONS(4548),
    [anon_sym_pulldown] = ACTIONS(4548),
    [anon_sym_pullup] = ACTIONS(4548),
    [anon_sym_cmos] = ACTIONS(4548),
    [anon_sym_rcmos] = ACTIONS(4548),
    [anon_sym_bufif0] = ACTIONS(4548),
    [anon_sym_bufif1] = ACTIONS(4548),
    [anon_sym_notif0] = ACTIONS(4548),
    [anon_sym_notif1] = ACTIONS(4548),
    [anon_sym_nmos] = ACTIONS(4548),
    [anon_sym_pmos] = ACTIONS(4548),
    [anon_sym_rnmos] = ACTIONS(4548),
    [anon_sym_rpmos] = ACTIONS(4548),
    [anon_sym_nand] = ACTIONS(4548),
    [anon_sym_nor] = ACTIONS(4548),
    [anon_sym_xor] = ACTIONS(4548),
    [anon_sym_xnor] = ACTIONS(4548),
    [anon_sym_buf] = ACTIONS(4548),
    [anon_sym_tranif0] = ACTIONS(4548),
    [anon_sym_tranif1] = ACTIONS(4548),
    [anon_sym_rtranif1] = ACTIONS(4548),
    [anon_sym_rtranif0] = ACTIONS(4548),
    [anon_sym_tran] = ACTIONS(4548),
    [anon_sym_rtran] = ACTIONS(4548),
    [anon_sym_generate] = ACTIONS(4548),
    [anon_sym_endgenerate] = ACTIONS(4548),
    [anon_sym_for] = ACTIONS(4548),
    [anon_sym_initial] = ACTIONS(4548),
    [anon_sym_assign] = ACTIONS(4548),
    [anon_sym_alias] = ACTIONS(4548),
    [anon_sym_always_comb] = ACTIONS(4548),
    [anon_sym_always_latch] = ACTIONS(4548),
    [anon_sym_always_ff] = ACTIONS(4548),
    [anon_sym_final] = ACTIONS(4548),
    [anon_sym_global] = ACTIONS(4548),
    [anon_sym_LPAREN_STAR] = ACTIONS(4546),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4546),
    [anon_sym_DOLLARunit] = ACTIONS(4546),
  },
  [4467] = {
    [sym_simple_identifier] = ACTIONS(4750),
    [anon_sym_wire] = ACTIONS(4750),
    [anon_sym_tri] = ACTIONS(4750),
    [anon_sym_tri0] = ACTIONS(4750),
    [anon_sym_tri1] = ACTIONS(4750),
    [anon_sym_wand] = ACTIONS(4750),
    [anon_sym_triand] = ACTIONS(4750),
    [anon_sym_wor] = ACTIONS(4750),
    [anon_sym_trior] = ACTIONS(4750),
    [anon_sym_trireg] = ACTIONS(4750),
    [anon_sym_uwire] = ACTIONS(4750),
    [anon_sym_SEMI] = ACTIONS(4748),
    [anon_sym_COLON] = ACTIONS(10651),
    [anon_sym_extern] = ACTIONS(4750),
    [anon_sym_interface] = ACTIONS(4750),
    [anon_sym_checker] = ACTIONS(4750),
    [anon_sym_virtual] = ACTIONS(4750),
    [anon_sym_class] = ACTIONS(4750),
    [anon_sym_type] = ACTIONS(4750),
    [anon_sym_DOLLARfatal] = ACTIONS(4748),
    [anon_sym_DOLLARerror] = ACTIONS(4748),
    [anon_sym_DOLLARwarning] = ACTIONS(4748),
    [anon_sym_DOLLARinfo] = ACTIONS(4748),
    [anon_sym_default] = ACTIONS(4750),
    [anon_sym_clocking] = ACTIONS(4750),
    [anon_sym_defparam] = ACTIONS(4750),
    [anon_sym_bind] = ACTIONS(4750),
    [anon_sym_rand] = ACTIONS(4750),
    [anon_sym_const] = ACTIONS(4750),
    [anon_sym_function] = ACTIONS(4750),
    [anon_sym_static] = ACTIONS(4750),
    [anon_sym_constraint] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4750),
    [anon_sym_else] = ACTIONS(4750),
    [anon_sym_LBRACK] = ACTIONS(4748),
    [anon_sym_localparam] = ACTIONS(4750),
    [anon_sym_parameter] = ACTIONS(4750),
    [anon_sym_var] = ACTIONS(4750),
    [anon_sym_import] = ACTIONS(4750),
    [anon_sym_export] = ACTIONS(4750),
    [anon_sym_genvar] = ACTIONS(4750),
    [anon_sym_interconnect] = ACTIONS(4750),
    [anon_sym_typedef] = ACTIONS(4750),
    [anon_sym_enum] = ACTIONS(4750),
    [anon_sym_struct] = ACTIONS(4750),
    [anon_sym_union] = ACTIONS(4750),
    [anon_sym_nettype] = ACTIONS(4750),
    [anon_sym_automatic] = ACTIONS(4750),
    [anon_sym_string] = ACTIONS(4750),
    [anon_sym_chandle] = ACTIONS(4750),
    [anon_sym_event] = ACTIONS(4750),
    [anon_sym_byte] = ACTIONS(4750),
    [anon_sym_shortint] = ACTIONS(4750),
    [anon_sym_int] = ACTIONS(4750),
    [anon_sym_longint] = ACTIONS(4750),
    [anon_sym_integer] = ACTIONS(4750),
    [anon_sym_time] = ACTIONS(4750),
    [anon_sym_bit] = ACTIONS(4750),
    [anon_sym_logic] = ACTIONS(4750),
    [anon_sym_reg] = ACTIONS(4750),
    [anon_sym_shortreal] = ACTIONS(4750),
    [anon_sym_real] = ACTIONS(4750),
    [anon_sym_realtime] = ACTIONS(4750),
    [anon_sym_supply0] = ACTIONS(4750),
    [anon_sym_supply1] = ACTIONS(4750),
    [anon_sym_signed] = ACTIONS(4750),
    [anon_sym_unsigned] = ACTIONS(4750),
    [anon_sym_task] = ACTIONS(4750),
    [anon_sym_assert] = ACTIONS(4750),
    [anon_sym_property] = ACTIONS(4750),
    [anon_sym_assume] = ACTIONS(4750),
    [anon_sym_cover] = ACTIONS(4750),
    [anon_sym_sequence] = ACTIONS(4750),
    [anon_sym_restrict] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4750),
    [anon_sym_or] = ACTIONS(4750),
    [anon_sym_and] = ACTIONS(4750),
    [anon_sym_case] = ACTIONS(4750),
    [anon_sym_always] = ACTIONS(4750),
    [anon_sym_covergroup] = ACTIONS(4750),
    [anon_sym_let] = ACTIONS(4750),
    [anon_sym_pulldown] = ACTIONS(4750),
    [anon_sym_pullup] = ACTIONS(4750),
    [anon_sym_cmos] = ACTIONS(4750),
    [anon_sym_rcmos] = ACTIONS(4750),
    [anon_sym_bufif0] = ACTIONS(4750),
    [anon_sym_bufif1] = ACTIONS(4750),
    [anon_sym_notif0] = ACTIONS(4750),
    [anon_sym_notif1] = ACTIONS(4750),
    [anon_sym_nmos] = ACTIONS(4750),
    [anon_sym_pmos] = ACTIONS(4750),
    [anon_sym_rnmos] = ACTIONS(4750),
    [anon_sym_rpmos] = ACTIONS(4750),
    [anon_sym_nand] = ACTIONS(4750),
    [anon_sym_nor] = ACTIONS(4750),
    [anon_sym_xor] = ACTIONS(4750),
    [anon_sym_xnor] = ACTIONS(4750),
    [anon_sym_buf] = ACTIONS(4750),
    [anon_sym_tranif0] = ACTIONS(4750),
    [anon_sym_tranif1] = ACTIONS(4750),
    [anon_sym_rtranif1] = ACTIONS(4750),
    [anon_sym_rtranif0] = ACTIONS(4750),
    [anon_sym_tran] = ACTIONS(4750),
    [anon_sym_rtran] = ACTIONS(4750),
    [anon_sym_generate] = ACTIONS(4750),
    [anon_sym_endgenerate] = ACTIONS(4750),
    [anon_sym_for] = ACTIONS(4750),
    [anon_sym_initial] = ACTIONS(4750),
    [anon_sym_assign] = ACTIONS(4750),
    [anon_sym_alias] = ACTIONS(4750),
    [anon_sym_always_comb] = ACTIONS(4750),
    [anon_sym_always_latch] = ACTIONS(4750),
    [anon_sym_always_ff] = ACTIONS(4750),
    [anon_sym_final] = ACTIONS(4750),
    [anon_sym_global] = ACTIONS(4750),
    [anon_sym_LPAREN_STAR] = ACTIONS(4748),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4748),
    [anon_sym_DOLLARunit] = ACTIONS(4748),
  },
  [4468] = {
    [sym_simple_identifier] = ACTIONS(4578),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_COLON] = ACTIONS(10653),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_rand] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_end] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [4469] = {
    [sym_simple_identifier] = ACTIONS(4662),
    [anon_sym_wire] = ACTIONS(4662),
    [anon_sym_tri] = ACTIONS(4662),
    [anon_sym_tri0] = ACTIONS(4662),
    [anon_sym_tri1] = ACTIONS(4662),
    [anon_sym_wand] = ACTIONS(4662),
    [anon_sym_triand] = ACTIONS(4662),
    [anon_sym_wor] = ACTIONS(4662),
    [anon_sym_trior] = ACTIONS(4662),
    [anon_sym_trireg] = ACTIONS(4662),
    [anon_sym_uwire] = ACTIONS(4662),
    [anon_sym_SEMI] = ACTIONS(4660),
    [anon_sym_COLON] = ACTIONS(10655),
    [anon_sym_extern] = ACTIONS(4662),
    [anon_sym_interface] = ACTIONS(4662),
    [anon_sym_checker] = ACTIONS(4662),
    [anon_sym_virtual] = ACTIONS(4662),
    [anon_sym_class] = ACTIONS(4662),
    [anon_sym_type] = ACTIONS(4662),
    [anon_sym_DOLLARfatal] = ACTIONS(4660),
    [anon_sym_DOLLARerror] = ACTIONS(4660),
    [anon_sym_DOLLARwarning] = ACTIONS(4660),
    [anon_sym_DOLLARinfo] = ACTIONS(4660),
    [anon_sym_default] = ACTIONS(4662),
    [anon_sym_clocking] = ACTIONS(4662),
    [anon_sym_defparam] = ACTIONS(4662),
    [anon_sym_bind] = ACTIONS(4662),
    [anon_sym_rand] = ACTIONS(4662),
    [anon_sym_const] = ACTIONS(4662),
    [anon_sym_function] = ACTIONS(4662),
    [anon_sym_static] = ACTIONS(4662),
    [anon_sym_constraint] = ACTIONS(4662),
    [anon_sym_if] = ACTIONS(4662),
    [anon_sym_else] = ACTIONS(4662),
    [anon_sym_LBRACK] = ACTIONS(4660),
    [anon_sym_localparam] = ACTIONS(4662),
    [anon_sym_parameter] = ACTIONS(4662),
    [anon_sym_var] = ACTIONS(4662),
    [anon_sym_import] = ACTIONS(4662),
    [anon_sym_export] = ACTIONS(4662),
    [anon_sym_genvar] = ACTIONS(4662),
    [anon_sym_interconnect] = ACTIONS(4662),
    [anon_sym_typedef] = ACTIONS(4662),
    [anon_sym_enum] = ACTIONS(4662),
    [anon_sym_struct] = ACTIONS(4662),
    [anon_sym_union] = ACTIONS(4662),
    [anon_sym_nettype] = ACTIONS(4662),
    [anon_sym_automatic] = ACTIONS(4662),
    [anon_sym_string] = ACTIONS(4662),
    [anon_sym_chandle] = ACTIONS(4662),
    [anon_sym_event] = ACTIONS(4662),
    [anon_sym_byte] = ACTIONS(4662),
    [anon_sym_shortint] = ACTIONS(4662),
    [anon_sym_int] = ACTIONS(4662),
    [anon_sym_longint] = ACTIONS(4662),
    [anon_sym_integer] = ACTIONS(4662),
    [anon_sym_time] = ACTIONS(4662),
    [anon_sym_bit] = ACTIONS(4662),
    [anon_sym_logic] = ACTIONS(4662),
    [anon_sym_reg] = ACTIONS(4662),
    [anon_sym_shortreal] = ACTIONS(4662),
    [anon_sym_real] = ACTIONS(4662),
    [anon_sym_realtime] = ACTIONS(4662),
    [anon_sym_supply0] = ACTIONS(4662),
    [anon_sym_supply1] = ACTIONS(4662),
    [anon_sym_signed] = ACTIONS(4662),
    [anon_sym_unsigned] = ACTIONS(4662),
    [anon_sym_task] = ACTIONS(4662),
    [anon_sym_assert] = ACTIONS(4662),
    [anon_sym_property] = ACTIONS(4662),
    [anon_sym_assume] = ACTIONS(4662),
    [anon_sym_cover] = ACTIONS(4662),
    [anon_sym_sequence] = ACTIONS(4662),
    [anon_sym_restrict] = ACTIONS(4662),
    [anon_sym_not] = ACTIONS(4662),
    [anon_sym_or] = ACTIONS(4662),
    [anon_sym_and] = ACTIONS(4662),
    [anon_sym_case] = ACTIONS(4662),
    [anon_sym_always] = ACTIONS(4662),
    [anon_sym_covergroup] = ACTIONS(4662),
    [anon_sym_end] = ACTIONS(4662),
    [anon_sym_let] = ACTIONS(4662),
    [anon_sym_pulldown] = ACTIONS(4662),
    [anon_sym_pullup] = ACTIONS(4662),
    [anon_sym_cmos] = ACTIONS(4662),
    [anon_sym_rcmos] = ACTIONS(4662),
    [anon_sym_bufif0] = ACTIONS(4662),
    [anon_sym_bufif1] = ACTIONS(4662),
    [anon_sym_notif0] = ACTIONS(4662),
    [anon_sym_notif1] = ACTIONS(4662),
    [anon_sym_nmos] = ACTIONS(4662),
    [anon_sym_pmos] = ACTIONS(4662),
    [anon_sym_rnmos] = ACTIONS(4662),
    [anon_sym_rpmos] = ACTIONS(4662),
    [anon_sym_nand] = ACTIONS(4662),
    [anon_sym_nor] = ACTIONS(4662),
    [anon_sym_xor] = ACTIONS(4662),
    [anon_sym_xnor] = ACTIONS(4662),
    [anon_sym_buf] = ACTIONS(4662),
    [anon_sym_tranif0] = ACTIONS(4662),
    [anon_sym_tranif1] = ACTIONS(4662),
    [anon_sym_rtranif1] = ACTIONS(4662),
    [anon_sym_rtranif0] = ACTIONS(4662),
    [anon_sym_tran] = ACTIONS(4662),
    [anon_sym_rtran] = ACTIONS(4662),
    [anon_sym_generate] = ACTIONS(4662),
    [anon_sym_for] = ACTIONS(4662),
    [anon_sym_initial] = ACTIONS(4662),
    [anon_sym_assign] = ACTIONS(4662),
    [anon_sym_alias] = ACTIONS(4662),
    [anon_sym_always_comb] = ACTIONS(4662),
    [anon_sym_always_latch] = ACTIONS(4662),
    [anon_sym_always_ff] = ACTIONS(4662),
    [anon_sym_final] = ACTIONS(4662),
    [anon_sym_global] = ACTIONS(4662),
    [anon_sym_LPAREN_STAR] = ACTIONS(4660),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4660),
    [anon_sym_DOLLARunit] = ACTIONS(4660),
  },
  [4470] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_COLON] = ACTIONS(10657),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_rand] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_end] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [4471] = {
    [sym_simple_identifier] = ACTIONS(4702),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_COLON] = ACTIONS(10659),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_rand] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_end] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [4472] = {
    [sym_simple_identifier] = ACTIONS(4286),
    [anon_sym_wire] = ACTIONS(4286),
    [anon_sym_tri] = ACTIONS(4286),
    [anon_sym_tri0] = ACTIONS(4286),
    [anon_sym_tri1] = ACTIONS(4286),
    [anon_sym_wand] = ACTIONS(4286),
    [anon_sym_triand] = ACTIONS(4286),
    [anon_sym_wor] = ACTIONS(4286),
    [anon_sym_trior] = ACTIONS(4286),
    [anon_sym_trireg] = ACTIONS(4286),
    [anon_sym_uwire] = ACTIONS(4286),
    [anon_sym_SEMI] = ACTIONS(4284),
    [anon_sym_COLON] = ACTIONS(10661),
    [anon_sym_extern] = ACTIONS(4286),
    [anon_sym_interface] = ACTIONS(4286),
    [anon_sym_checker] = ACTIONS(4286),
    [anon_sym_virtual] = ACTIONS(4286),
    [anon_sym_class] = ACTIONS(4286),
    [anon_sym_type] = ACTIONS(4286),
    [anon_sym_DOLLARfatal] = ACTIONS(4284),
    [anon_sym_DOLLARerror] = ACTIONS(4284),
    [anon_sym_DOLLARwarning] = ACTIONS(4284),
    [anon_sym_DOLLARinfo] = ACTIONS(4284),
    [anon_sym_default] = ACTIONS(4286),
    [anon_sym_clocking] = ACTIONS(4286),
    [anon_sym_defparam] = ACTIONS(4286),
    [anon_sym_bind] = ACTIONS(4286),
    [anon_sym_rand] = ACTIONS(4286),
    [anon_sym_const] = ACTIONS(4286),
    [anon_sym_function] = ACTIONS(4286),
    [anon_sym_static] = ACTIONS(4286),
    [anon_sym_constraint] = ACTIONS(4286),
    [anon_sym_if] = ACTIONS(4286),
    [anon_sym_else] = ACTIONS(4286),
    [anon_sym_LBRACK] = ACTIONS(4284),
    [anon_sym_localparam] = ACTIONS(4286),
    [anon_sym_parameter] = ACTIONS(4286),
    [anon_sym_var] = ACTIONS(4286),
    [anon_sym_import] = ACTIONS(4286),
    [anon_sym_export] = ACTIONS(4286),
    [anon_sym_genvar] = ACTIONS(4286),
    [anon_sym_interconnect] = ACTIONS(4286),
    [anon_sym_typedef] = ACTIONS(4286),
    [anon_sym_enum] = ACTIONS(4286),
    [anon_sym_struct] = ACTIONS(4286),
    [anon_sym_union] = ACTIONS(4286),
    [anon_sym_nettype] = ACTIONS(4286),
    [anon_sym_automatic] = ACTIONS(4286),
    [anon_sym_string] = ACTIONS(4286),
    [anon_sym_chandle] = ACTIONS(4286),
    [anon_sym_event] = ACTIONS(4286),
    [anon_sym_byte] = ACTIONS(4286),
    [anon_sym_shortint] = ACTIONS(4286),
    [anon_sym_int] = ACTIONS(4286),
    [anon_sym_longint] = ACTIONS(4286),
    [anon_sym_integer] = ACTIONS(4286),
    [anon_sym_time] = ACTIONS(4286),
    [anon_sym_bit] = ACTIONS(4286),
    [anon_sym_logic] = ACTIONS(4286),
    [anon_sym_reg] = ACTIONS(4286),
    [anon_sym_shortreal] = ACTIONS(4286),
    [anon_sym_real] = ACTIONS(4286),
    [anon_sym_realtime] = ACTIONS(4286),
    [anon_sym_supply0] = ACTIONS(4286),
    [anon_sym_supply1] = ACTIONS(4286),
    [anon_sym_signed] = ACTIONS(4286),
    [anon_sym_unsigned] = ACTIONS(4286),
    [anon_sym_task] = ACTIONS(4286),
    [anon_sym_assert] = ACTIONS(4286),
    [anon_sym_property] = ACTIONS(4286),
    [anon_sym_assume] = ACTIONS(4286),
    [anon_sym_cover] = ACTIONS(4286),
    [anon_sym_sequence] = ACTIONS(4286),
    [anon_sym_restrict] = ACTIONS(4286),
    [anon_sym_not] = ACTIONS(4286),
    [anon_sym_or] = ACTIONS(4286),
    [anon_sym_and] = ACTIONS(4286),
    [anon_sym_case] = ACTIONS(4286),
    [anon_sym_always] = ACTIONS(4286),
    [anon_sym_covergroup] = ACTIONS(4286),
    [anon_sym_let] = ACTIONS(4286),
    [anon_sym_pulldown] = ACTIONS(4286),
    [anon_sym_pullup] = ACTIONS(4286),
    [anon_sym_cmos] = ACTIONS(4286),
    [anon_sym_rcmos] = ACTIONS(4286),
    [anon_sym_bufif0] = ACTIONS(4286),
    [anon_sym_bufif1] = ACTIONS(4286),
    [anon_sym_notif0] = ACTIONS(4286),
    [anon_sym_notif1] = ACTIONS(4286),
    [anon_sym_nmos] = ACTIONS(4286),
    [anon_sym_pmos] = ACTIONS(4286),
    [anon_sym_rnmos] = ACTIONS(4286),
    [anon_sym_rpmos] = ACTIONS(4286),
    [anon_sym_nand] = ACTIONS(4286),
    [anon_sym_nor] = ACTIONS(4286),
    [anon_sym_xor] = ACTIONS(4286),
    [anon_sym_xnor] = ACTIONS(4286),
    [anon_sym_buf] = ACTIONS(4286),
    [anon_sym_tranif0] = ACTIONS(4286),
    [anon_sym_tranif1] = ACTIONS(4286),
    [anon_sym_rtranif1] = ACTIONS(4286),
    [anon_sym_rtranif0] = ACTIONS(4286),
    [anon_sym_tran] = ACTIONS(4286),
    [anon_sym_rtran] = ACTIONS(4286),
    [anon_sym_generate] = ACTIONS(4286),
    [anon_sym_endgenerate] = ACTIONS(4286),
    [anon_sym_for] = ACTIONS(4286),
    [anon_sym_initial] = ACTIONS(4286),
    [anon_sym_assign] = ACTIONS(4286),
    [anon_sym_alias] = ACTIONS(4286),
    [anon_sym_always_comb] = ACTIONS(4286),
    [anon_sym_always_latch] = ACTIONS(4286),
    [anon_sym_always_ff] = ACTIONS(4286),
    [anon_sym_final] = ACTIONS(4286),
    [anon_sym_global] = ACTIONS(4286),
    [anon_sym_LPAREN_STAR] = ACTIONS(4284),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4284),
    [anon_sym_DOLLARunit] = ACTIONS(4284),
  },
  [4473] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_COLON] = ACTIONS(10663),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_rand] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_end] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [4474] = {
    [sym_simple_identifier] = ACTIONS(4478),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_COLON] = ACTIONS(10665),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_rand] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_end] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [4475] = {
    [sym_simple_identifier] = ACTIONS(4678),
    [anon_sym_wire] = ACTIONS(4678),
    [anon_sym_tri] = ACTIONS(4678),
    [anon_sym_tri0] = ACTIONS(4678),
    [anon_sym_tri1] = ACTIONS(4678),
    [anon_sym_wand] = ACTIONS(4678),
    [anon_sym_triand] = ACTIONS(4678),
    [anon_sym_wor] = ACTIONS(4678),
    [anon_sym_trior] = ACTIONS(4678),
    [anon_sym_trireg] = ACTIONS(4678),
    [anon_sym_uwire] = ACTIONS(4678),
    [anon_sym_SEMI] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(10667),
    [anon_sym_extern] = ACTIONS(4678),
    [anon_sym_interface] = ACTIONS(4678),
    [anon_sym_checker] = ACTIONS(4678),
    [anon_sym_virtual] = ACTIONS(4678),
    [anon_sym_class] = ACTIONS(4678),
    [anon_sym_type] = ACTIONS(4678),
    [anon_sym_DOLLARfatal] = ACTIONS(4676),
    [anon_sym_DOLLARerror] = ACTIONS(4676),
    [anon_sym_DOLLARwarning] = ACTIONS(4676),
    [anon_sym_DOLLARinfo] = ACTIONS(4676),
    [anon_sym_default] = ACTIONS(4678),
    [anon_sym_clocking] = ACTIONS(4678),
    [anon_sym_defparam] = ACTIONS(4678),
    [anon_sym_bind] = ACTIONS(4678),
    [anon_sym_rand] = ACTIONS(4678),
    [anon_sym_const] = ACTIONS(4678),
    [anon_sym_function] = ACTIONS(4678),
    [anon_sym_static] = ACTIONS(4678),
    [anon_sym_constraint] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4678),
    [anon_sym_else] = ACTIONS(4678),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_localparam] = ACTIONS(4678),
    [anon_sym_parameter] = ACTIONS(4678),
    [anon_sym_var] = ACTIONS(4678),
    [anon_sym_import] = ACTIONS(4678),
    [anon_sym_export] = ACTIONS(4678),
    [anon_sym_genvar] = ACTIONS(4678),
    [anon_sym_interconnect] = ACTIONS(4678),
    [anon_sym_typedef] = ACTIONS(4678),
    [anon_sym_enum] = ACTIONS(4678),
    [anon_sym_struct] = ACTIONS(4678),
    [anon_sym_union] = ACTIONS(4678),
    [anon_sym_nettype] = ACTIONS(4678),
    [anon_sym_automatic] = ACTIONS(4678),
    [anon_sym_string] = ACTIONS(4678),
    [anon_sym_chandle] = ACTIONS(4678),
    [anon_sym_event] = ACTIONS(4678),
    [anon_sym_byte] = ACTIONS(4678),
    [anon_sym_shortint] = ACTIONS(4678),
    [anon_sym_int] = ACTIONS(4678),
    [anon_sym_longint] = ACTIONS(4678),
    [anon_sym_integer] = ACTIONS(4678),
    [anon_sym_time] = ACTIONS(4678),
    [anon_sym_bit] = ACTIONS(4678),
    [anon_sym_logic] = ACTIONS(4678),
    [anon_sym_reg] = ACTIONS(4678),
    [anon_sym_shortreal] = ACTIONS(4678),
    [anon_sym_real] = ACTIONS(4678),
    [anon_sym_realtime] = ACTIONS(4678),
    [anon_sym_supply0] = ACTIONS(4678),
    [anon_sym_supply1] = ACTIONS(4678),
    [anon_sym_signed] = ACTIONS(4678),
    [anon_sym_unsigned] = ACTIONS(4678),
    [anon_sym_task] = ACTIONS(4678),
    [anon_sym_assert] = ACTIONS(4678),
    [anon_sym_property] = ACTIONS(4678),
    [anon_sym_assume] = ACTIONS(4678),
    [anon_sym_cover] = ACTIONS(4678),
    [anon_sym_sequence] = ACTIONS(4678),
    [anon_sym_restrict] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4678),
    [anon_sym_or] = ACTIONS(4678),
    [anon_sym_and] = ACTIONS(4678),
    [anon_sym_case] = ACTIONS(4678),
    [anon_sym_always] = ACTIONS(4678),
    [anon_sym_covergroup] = ACTIONS(4678),
    [anon_sym_end] = ACTIONS(4678),
    [anon_sym_let] = ACTIONS(4678),
    [anon_sym_pulldown] = ACTIONS(4678),
    [anon_sym_pullup] = ACTIONS(4678),
    [anon_sym_cmos] = ACTIONS(4678),
    [anon_sym_rcmos] = ACTIONS(4678),
    [anon_sym_bufif0] = ACTIONS(4678),
    [anon_sym_bufif1] = ACTIONS(4678),
    [anon_sym_notif0] = ACTIONS(4678),
    [anon_sym_notif1] = ACTIONS(4678),
    [anon_sym_nmos] = ACTIONS(4678),
    [anon_sym_pmos] = ACTIONS(4678),
    [anon_sym_rnmos] = ACTIONS(4678),
    [anon_sym_rpmos] = ACTIONS(4678),
    [anon_sym_nand] = ACTIONS(4678),
    [anon_sym_nor] = ACTIONS(4678),
    [anon_sym_xor] = ACTIONS(4678),
    [anon_sym_xnor] = ACTIONS(4678),
    [anon_sym_buf] = ACTIONS(4678),
    [anon_sym_tranif0] = ACTIONS(4678),
    [anon_sym_tranif1] = ACTIONS(4678),
    [anon_sym_rtranif1] = ACTIONS(4678),
    [anon_sym_rtranif0] = ACTIONS(4678),
    [anon_sym_tran] = ACTIONS(4678),
    [anon_sym_rtran] = ACTIONS(4678),
    [anon_sym_generate] = ACTIONS(4678),
    [anon_sym_for] = ACTIONS(4678),
    [anon_sym_initial] = ACTIONS(4678),
    [anon_sym_assign] = ACTIONS(4678),
    [anon_sym_alias] = ACTIONS(4678),
    [anon_sym_always_comb] = ACTIONS(4678),
    [anon_sym_always_latch] = ACTIONS(4678),
    [anon_sym_always_ff] = ACTIONS(4678),
    [anon_sym_final] = ACTIONS(4678),
    [anon_sym_global] = ACTIONS(4678),
    [anon_sym_LPAREN_STAR] = ACTIONS(4676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4676),
    [anon_sym_DOLLARunit] = ACTIONS(4676),
  },
  [4476] = {
    [sym_simple_identifier] = ACTIONS(4162),
    [anon_sym_wire] = ACTIONS(4162),
    [anon_sym_tri] = ACTIONS(4162),
    [anon_sym_tri0] = ACTIONS(4162),
    [anon_sym_tri1] = ACTIONS(4162),
    [anon_sym_wand] = ACTIONS(4162),
    [anon_sym_triand] = ACTIONS(4162),
    [anon_sym_wor] = ACTIONS(4162),
    [anon_sym_trior] = ACTIONS(4162),
    [anon_sym_trireg] = ACTIONS(4162),
    [anon_sym_uwire] = ACTIONS(4162),
    [anon_sym_SEMI] = ACTIONS(4160),
    [anon_sym_COLON] = ACTIONS(10669),
    [anon_sym_extern] = ACTIONS(4162),
    [anon_sym_interface] = ACTIONS(4162),
    [anon_sym_checker] = ACTIONS(4162),
    [anon_sym_virtual] = ACTIONS(4162),
    [anon_sym_class] = ACTIONS(4162),
    [anon_sym_type] = ACTIONS(4162),
    [anon_sym_DOLLARfatal] = ACTIONS(4160),
    [anon_sym_DOLLARerror] = ACTIONS(4160),
    [anon_sym_DOLLARwarning] = ACTIONS(4160),
    [anon_sym_DOLLARinfo] = ACTIONS(4160),
    [anon_sym_default] = ACTIONS(4162),
    [anon_sym_clocking] = ACTIONS(4162),
    [anon_sym_defparam] = ACTIONS(4162),
    [anon_sym_bind] = ACTIONS(4162),
    [anon_sym_rand] = ACTIONS(4162),
    [anon_sym_const] = ACTIONS(4162),
    [anon_sym_function] = ACTIONS(4162),
    [anon_sym_static] = ACTIONS(4162),
    [anon_sym_constraint] = ACTIONS(4162),
    [anon_sym_if] = ACTIONS(4162),
    [anon_sym_else] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4160),
    [anon_sym_localparam] = ACTIONS(4162),
    [anon_sym_parameter] = ACTIONS(4162),
    [anon_sym_var] = ACTIONS(4162),
    [anon_sym_import] = ACTIONS(4162),
    [anon_sym_export] = ACTIONS(4162),
    [anon_sym_genvar] = ACTIONS(4162),
    [anon_sym_interconnect] = ACTIONS(4162),
    [anon_sym_typedef] = ACTIONS(4162),
    [anon_sym_enum] = ACTIONS(4162),
    [anon_sym_struct] = ACTIONS(4162),
    [anon_sym_union] = ACTIONS(4162),
    [anon_sym_nettype] = ACTIONS(4162),
    [anon_sym_automatic] = ACTIONS(4162),
    [anon_sym_string] = ACTIONS(4162),
    [anon_sym_chandle] = ACTIONS(4162),
    [anon_sym_event] = ACTIONS(4162),
    [anon_sym_byte] = ACTIONS(4162),
    [anon_sym_shortint] = ACTIONS(4162),
    [anon_sym_int] = ACTIONS(4162),
    [anon_sym_longint] = ACTIONS(4162),
    [anon_sym_integer] = ACTIONS(4162),
    [anon_sym_time] = ACTIONS(4162),
    [anon_sym_bit] = ACTIONS(4162),
    [anon_sym_logic] = ACTIONS(4162),
    [anon_sym_reg] = ACTIONS(4162),
    [anon_sym_shortreal] = ACTIONS(4162),
    [anon_sym_real] = ACTIONS(4162),
    [anon_sym_realtime] = ACTIONS(4162),
    [anon_sym_supply0] = ACTIONS(4162),
    [anon_sym_supply1] = ACTIONS(4162),
    [anon_sym_signed] = ACTIONS(4162),
    [anon_sym_unsigned] = ACTIONS(4162),
    [anon_sym_task] = ACTIONS(4162),
    [anon_sym_assert] = ACTIONS(4162),
    [anon_sym_property] = ACTIONS(4162),
    [anon_sym_assume] = ACTIONS(4162),
    [anon_sym_cover] = ACTIONS(4162),
    [anon_sym_sequence] = ACTIONS(4162),
    [anon_sym_restrict] = ACTIONS(4162),
    [anon_sym_not] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_case] = ACTIONS(4162),
    [anon_sym_always] = ACTIONS(4162),
    [anon_sym_covergroup] = ACTIONS(4162),
    [anon_sym_end] = ACTIONS(4162),
    [anon_sym_let] = ACTIONS(4162),
    [anon_sym_pulldown] = ACTIONS(4162),
    [anon_sym_pullup] = ACTIONS(4162),
    [anon_sym_cmos] = ACTIONS(4162),
    [anon_sym_rcmos] = ACTIONS(4162),
    [anon_sym_bufif0] = ACTIONS(4162),
    [anon_sym_bufif1] = ACTIONS(4162),
    [anon_sym_notif0] = ACTIONS(4162),
    [anon_sym_notif1] = ACTIONS(4162),
    [anon_sym_nmos] = ACTIONS(4162),
    [anon_sym_pmos] = ACTIONS(4162),
    [anon_sym_rnmos] = ACTIONS(4162),
    [anon_sym_rpmos] = ACTIONS(4162),
    [anon_sym_nand] = ACTIONS(4162),
    [anon_sym_nor] = ACTIONS(4162),
    [anon_sym_xor] = ACTIONS(4162),
    [anon_sym_xnor] = ACTIONS(4162),
    [anon_sym_buf] = ACTIONS(4162),
    [anon_sym_tranif0] = ACTIONS(4162),
    [anon_sym_tranif1] = ACTIONS(4162),
    [anon_sym_rtranif1] = ACTIONS(4162),
    [anon_sym_rtranif0] = ACTIONS(4162),
    [anon_sym_tran] = ACTIONS(4162),
    [anon_sym_rtran] = ACTIONS(4162),
    [anon_sym_generate] = ACTIONS(4162),
    [anon_sym_for] = ACTIONS(4162),
    [anon_sym_initial] = ACTIONS(4162),
    [anon_sym_assign] = ACTIONS(4162),
    [anon_sym_alias] = ACTIONS(4162),
    [anon_sym_always_comb] = ACTIONS(4162),
    [anon_sym_always_latch] = ACTIONS(4162),
    [anon_sym_always_ff] = ACTIONS(4162),
    [anon_sym_final] = ACTIONS(4162),
    [anon_sym_global] = ACTIONS(4162),
    [anon_sym_LPAREN_STAR] = ACTIONS(4160),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4160),
    [anon_sym_DOLLARunit] = ACTIONS(4160),
  },
  [4477] = {
    [sym_simple_identifier] = ACTIONS(4732),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_COLON] = ACTIONS(10671),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_rand] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_end] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [4478] = {
    [sym_simple_identifier] = ACTIONS(4418),
    [anon_sym_wire] = ACTIONS(4418),
    [anon_sym_tri] = ACTIONS(4418),
    [anon_sym_tri0] = ACTIONS(4418),
    [anon_sym_tri1] = ACTIONS(4418),
    [anon_sym_wand] = ACTIONS(4418),
    [anon_sym_triand] = ACTIONS(4418),
    [anon_sym_wor] = ACTIONS(4418),
    [anon_sym_trior] = ACTIONS(4418),
    [anon_sym_trireg] = ACTIONS(4418),
    [anon_sym_uwire] = ACTIONS(4418),
    [anon_sym_SEMI] = ACTIONS(4416),
    [anon_sym_COLON] = ACTIONS(10673),
    [anon_sym_extern] = ACTIONS(4418),
    [anon_sym_interface] = ACTIONS(4418),
    [anon_sym_checker] = ACTIONS(4418),
    [anon_sym_virtual] = ACTIONS(4418),
    [anon_sym_class] = ACTIONS(4418),
    [anon_sym_type] = ACTIONS(4418),
    [anon_sym_DOLLARfatal] = ACTIONS(4416),
    [anon_sym_DOLLARerror] = ACTIONS(4416),
    [anon_sym_DOLLARwarning] = ACTIONS(4416),
    [anon_sym_DOLLARinfo] = ACTIONS(4416),
    [anon_sym_default] = ACTIONS(4418),
    [anon_sym_clocking] = ACTIONS(4418),
    [anon_sym_defparam] = ACTIONS(4418),
    [anon_sym_bind] = ACTIONS(4418),
    [anon_sym_rand] = ACTIONS(4418),
    [anon_sym_const] = ACTIONS(4418),
    [anon_sym_function] = ACTIONS(4418),
    [anon_sym_static] = ACTIONS(4418),
    [anon_sym_constraint] = ACTIONS(4418),
    [anon_sym_if] = ACTIONS(4418),
    [anon_sym_else] = ACTIONS(4418),
    [anon_sym_LBRACK] = ACTIONS(4416),
    [anon_sym_localparam] = ACTIONS(4418),
    [anon_sym_parameter] = ACTIONS(4418),
    [anon_sym_var] = ACTIONS(4418),
    [anon_sym_import] = ACTIONS(4418),
    [anon_sym_export] = ACTIONS(4418),
    [anon_sym_genvar] = ACTIONS(4418),
    [anon_sym_interconnect] = ACTIONS(4418),
    [anon_sym_typedef] = ACTIONS(4418),
    [anon_sym_enum] = ACTIONS(4418),
    [anon_sym_struct] = ACTIONS(4418),
    [anon_sym_union] = ACTIONS(4418),
    [anon_sym_nettype] = ACTIONS(4418),
    [anon_sym_automatic] = ACTIONS(4418),
    [anon_sym_string] = ACTIONS(4418),
    [anon_sym_chandle] = ACTIONS(4418),
    [anon_sym_event] = ACTIONS(4418),
    [anon_sym_byte] = ACTIONS(4418),
    [anon_sym_shortint] = ACTIONS(4418),
    [anon_sym_int] = ACTIONS(4418),
    [anon_sym_longint] = ACTIONS(4418),
    [anon_sym_integer] = ACTIONS(4418),
    [anon_sym_time] = ACTIONS(4418),
    [anon_sym_bit] = ACTIONS(4418),
    [anon_sym_logic] = ACTIONS(4418),
    [anon_sym_reg] = ACTIONS(4418),
    [anon_sym_shortreal] = ACTIONS(4418),
    [anon_sym_real] = ACTIONS(4418),
    [anon_sym_realtime] = ACTIONS(4418),
    [anon_sym_supply0] = ACTIONS(4418),
    [anon_sym_supply1] = ACTIONS(4418),
    [anon_sym_signed] = ACTIONS(4418),
    [anon_sym_unsigned] = ACTIONS(4418),
    [anon_sym_task] = ACTIONS(4418),
    [anon_sym_assert] = ACTIONS(4418),
    [anon_sym_property] = ACTIONS(4418),
    [anon_sym_assume] = ACTIONS(4418),
    [anon_sym_cover] = ACTIONS(4418),
    [anon_sym_sequence] = ACTIONS(4418),
    [anon_sym_restrict] = ACTIONS(4418),
    [anon_sym_not] = ACTIONS(4418),
    [anon_sym_or] = ACTIONS(4418),
    [anon_sym_and] = ACTIONS(4418),
    [anon_sym_case] = ACTIONS(4418),
    [anon_sym_always] = ACTIONS(4418),
    [anon_sym_covergroup] = ACTIONS(4418),
    [anon_sym_let] = ACTIONS(4418),
    [anon_sym_pulldown] = ACTIONS(4418),
    [anon_sym_pullup] = ACTIONS(4418),
    [anon_sym_cmos] = ACTIONS(4418),
    [anon_sym_rcmos] = ACTIONS(4418),
    [anon_sym_bufif0] = ACTIONS(4418),
    [anon_sym_bufif1] = ACTIONS(4418),
    [anon_sym_notif0] = ACTIONS(4418),
    [anon_sym_notif1] = ACTIONS(4418),
    [anon_sym_nmos] = ACTIONS(4418),
    [anon_sym_pmos] = ACTIONS(4418),
    [anon_sym_rnmos] = ACTIONS(4418),
    [anon_sym_rpmos] = ACTIONS(4418),
    [anon_sym_nand] = ACTIONS(4418),
    [anon_sym_nor] = ACTIONS(4418),
    [anon_sym_xor] = ACTIONS(4418),
    [anon_sym_xnor] = ACTIONS(4418),
    [anon_sym_buf] = ACTIONS(4418),
    [anon_sym_tranif0] = ACTIONS(4418),
    [anon_sym_tranif1] = ACTIONS(4418),
    [anon_sym_rtranif1] = ACTIONS(4418),
    [anon_sym_rtranif0] = ACTIONS(4418),
    [anon_sym_tran] = ACTIONS(4418),
    [anon_sym_rtran] = ACTIONS(4418),
    [anon_sym_generate] = ACTIONS(4418),
    [anon_sym_endgenerate] = ACTIONS(4418),
    [anon_sym_for] = ACTIONS(4418),
    [anon_sym_initial] = ACTIONS(4418),
    [anon_sym_assign] = ACTIONS(4418),
    [anon_sym_alias] = ACTIONS(4418),
    [anon_sym_always_comb] = ACTIONS(4418),
    [anon_sym_always_latch] = ACTIONS(4418),
    [anon_sym_always_ff] = ACTIONS(4418),
    [anon_sym_final] = ACTIONS(4418),
    [anon_sym_global] = ACTIONS(4418),
    [anon_sym_LPAREN_STAR] = ACTIONS(4416),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4416),
    [anon_sym_DOLLARunit] = ACTIONS(4416),
  },
  [4479] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_COLON] = ACTIONS(10675),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_rand] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_end] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [4480] = {
    [sym_simple_identifier] = ACTIONS(4478),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_COLON] = ACTIONS(10677),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_rand] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_endgenerate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [4481] = {
    [sym_simple_identifier] = ACTIONS(4678),
    [anon_sym_wire] = ACTIONS(4678),
    [anon_sym_tri] = ACTIONS(4678),
    [anon_sym_tri0] = ACTIONS(4678),
    [anon_sym_tri1] = ACTIONS(4678),
    [anon_sym_wand] = ACTIONS(4678),
    [anon_sym_triand] = ACTIONS(4678),
    [anon_sym_wor] = ACTIONS(4678),
    [anon_sym_trior] = ACTIONS(4678),
    [anon_sym_trireg] = ACTIONS(4678),
    [anon_sym_uwire] = ACTIONS(4678),
    [anon_sym_SEMI] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(10679),
    [anon_sym_extern] = ACTIONS(4678),
    [anon_sym_interface] = ACTIONS(4678),
    [anon_sym_checker] = ACTIONS(4678),
    [anon_sym_virtual] = ACTIONS(4678),
    [anon_sym_class] = ACTIONS(4678),
    [anon_sym_type] = ACTIONS(4678),
    [anon_sym_DOLLARfatal] = ACTIONS(4676),
    [anon_sym_DOLLARerror] = ACTIONS(4676),
    [anon_sym_DOLLARwarning] = ACTIONS(4676),
    [anon_sym_DOLLARinfo] = ACTIONS(4676),
    [anon_sym_default] = ACTIONS(4678),
    [anon_sym_clocking] = ACTIONS(4678),
    [anon_sym_defparam] = ACTIONS(4678),
    [anon_sym_bind] = ACTIONS(4678),
    [anon_sym_rand] = ACTIONS(4678),
    [anon_sym_const] = ACTIONS(4678),
    [anon_sym_function] = ACTIONS(4678),
    [anon_sym_static] = ACTIONS(4678),
    [anon_sym_constraint] = ACTIONS(4678),
    [anon_sym_if] = ACTIONS(4678),
    [anon_sym_else] = ACTIONS(4678),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_localparam] = ACTIONS(4678),
    [anon_sym_parameter] = ACTIONS(4678),
    [anon_sym_var] = ACTIONS(4678),
    [anon_sym_import] = ACTIONS(4678),
    [anon_sym_export] = ACTIONS(4678),
    [anon_sym_genvar] = ACTIONS(4678),
    [anon_sym_interconnect] = ACTIONS(4678),
    [anon_sym_typedef] = ACTIONS(4678),
    [anon_sym_enum] = ACTIONS(4678),
    [anon_sym_struct] = ACTIONS(4678),
    [anon_sym_union] = ACTIONS(4678),
    [anon_sym_nettype] = ACTIONS(4678),
    [anon_sym_automatic] = ACTIONS(4678),
    [anon_sym_string] = ACTIONS(4678),
    [anon_sym_chandle] = ACTIONS(4678),
    [anon_sym_event] = ACTIONS(4678),
    [anon_sym_byte] = ACTIONS(4678),
    [anon_sym_shortint] = ACTIONS(4678),
    [anon_sym_int] = ACTIONS(4678),
    [anon_sym_longint] = ACTIONS(4678),
    [anon_sym_integer] = ACTIONS(4678),
    [anon_sym_time] = ACTIONS(4678),
    [anon_sym_bit] = ACTIONS(4678),
    [anon_sym_logic] = ACTIONS(4678),
    [anon_sym_reg] = ACTIONS(4678),
    [anon_sym_shortreal] = ACTIONS(4678),
    [anon_sym_real] = ACTIONS(4678),
    [anon_sym_realtime] = ACTIONS(4678),
    [anon_sym_supply0] = ACTIONS(4678),
    [anon_sym_supply1] = ACTIONS(4678),
    [anon_sym_signed] = ACTIONS(4678),
    [anon_sym_unsigned] = ACTIONS(4678),
    [anon_sym_task] = ACTIONS(4678),
    [anon_sym_assert] = ACTIONS(4678),
    [anon_sym_property] = ACTIONS(4678),
    [anon_sym_assume] = ACTIONS(4678),
    [anon_sym_cover] = ACTIONS(4678),
    [anon_sym_sequence] = ACTIONS(4678),
    [anon_sym_restrict] = ACTIONS(4678),
    [anon_sym_not] = ACTIONS(4678),
    [anon_sym_or] = ACTIONS(4678),
    [anon_sym_and] = ACTIONS(4678),
    [anon_sym_case] = ACTIONS(4678),
    [anon_sym_always] = ACTIONS(4678),
    [anon_sym_covergroup] = ACTIONS(4678),
    [anon_sym_let] = ACTIONS(4678),
    [anon_sym_pulldown] = ACTIONS(4678),
    [anon_sym_pullup] = ACTIONS(4678),
    [anon_sym_cmos] = ACTIONS(4678),
    [anon_sym_rcmos] = ACTIONS(4678),
    [anon_sym_bufif0] = ACTIONS(4678),
    [anon_sym_bufif1] = ACTIONS(4678),
    [anon_sym_notif0] = ACTIONS(4678),
    [anon_sym_notif1] = ACTIONS(4678),
    [anon_sym_nmos] = ACTIONS(4678),
    [anon_sym_pmos] = ACTIONS(4678),
    [anon_sym_rnmos] = ACTIONS(4678),
    [anon_sym_rpmos] = ACTIONS(4678),
    [anon_sym_nand] = ACTIONS(4678),
    [anon_sym_nor] = ACTIONS(4678),
    [anon_sym_xor] = ACTIONS(4678),
    [anon_sym_xnor] = ACTIONS(4678),
    [anon_sym_buf] = ACTIONS(4678),
    [anon_sym_tranif0] = ACTIONS(4678),
    [anon_sym_tranif1] = ACTIONS(4678),
    [anon_sym_rtranif1] = ACTIONS(4678),
    [anon_sym_rtranif0] = ACTIONS(4678),
    [anon_sym_tran] = ACTIONS(4678),
    [anon_sym_rtran] = ACTIONS(4678),
    [anon_sym_generate] = ACTIONS(4678),
    [anon_sym_endgenerate] = ACTIONS(4678),
    [anon_sym_for] = ACTIONS(4678),
    [anon_sym_initial] = ACTIONS(4678),
    [anon_sym_assign] = ACTIONS(4678),
    [anon_sym_alias] = ACTIONS(4678),
    [anon_sym_always_comb] = ACTIONS(4678),
    [anon_sym_always_latch] = ACTIONS(4678),
    [anon_sym_always_ff] = ACTIONS(4678),
    [anon_sym_final] = ACTIONS(4678),
    [anon_sym_global] = ACTIONS(4678),
    [anon_sym_LPAREN_STAR] = ACTIONS(4676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4676),
    [anon_sym_DOLLARunit] = ACTIONS(4676),
  },
  [4482] = {
    [sym_simple_identifier] = ACTIONS(4162),
    [anon_sym_wire] = ACTIONS(4162),
    [anon_sym_tri] = ACTIONS(4162),
    [anon_sym_tri0] = ACTIONS(4162),
    [anon_sym_tri1] = ACTIONS(4162),
    [anon_sym_wand] = ACTIONS(4162),
    [anon_sym_triand] = ACTIONS(4162),
    [anon_sym_wor] = ACTIONS(4162),
    [anon_sym_trior] = ACTIONS(4162),
    [anon_sym_trireg] = ACTIONS(4162),
    [anon_sym_uwire] = ACTIONS(4162),
    [anon_sym_SEMI] = ACTIONS(4160),
    [anon_sym_COLON] = ACTIONS(10681),
    [anon_sym_extern] = ACTIONS(4162),
    [anon_sym_interface] = ACTIONS(4162),
    [anon_sym_checker] = ACTIONS(4162),
    [anon_sym_virtual] = ACTIONS(4162),
    [anon_sym_class] = ACTIONS(4162),
    [anon_sym_type] = ACTIONS(4162),
    [anon_sym_DOLLARfatal] = ACTIONS(4160),
    [anon_sym_DOLLARerror] = ACTIONS(4160),
    [anon_sym_DOLLARwarning] = ACTIONS(4160),
    [anon_sym_DOLLARinfo] = ACTIONS(4160),
    [anon_sym_default] = ACTIONS(4162),
    [anon_sym_clocking] = ACTIONS(4162),
    [anon_sym_defparam] = ACTIONS(4162),
    [anon_sym_bind] = ACTIONS(4162),
    [anon_sym_rand] = ACTIONS(4162),
    [anon_sym_const] = ACTIONS(4162),
    [anon_sym_function] = ACTIONS(4162),
    [anon_sym_static] = ACTIONS(4162),
    [anon_sym_constraint] = ACTIONS(4162),
    [anon_sym_if] = ACTIONS(4162),
    [anon_sym_else] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4160),
    [anon_sym_localparam] = ACTIONS(4162),
    [anon_sym_parameter] = ACTIONS(4162),
    [anon_sym_var] = ACTIONS(4162),
    [anon_sym_import] = ACTIONS(4162),
    [anon_sym_export] = ACTIONS(4162),
    [anon_sym_genvar] = ACTIONS(4162),
    [anon_sym_interconnect] = ACTIONS(4162),
    [anon_sym_typedef] = ACTIONS(4162),
    [anon_sym_enum] = ACTIONS(4162),
    [anon_sym_struct] = ACTIONS(4162),
    [anon_sym_union] = ACTIONS(4162),
    [anon_sym_nettype] = ACTIONS(4162),
    [anon_sym_automatic] = ACTIONS(4162),
    [anon_sym_string] = ACTIONS(4162),
    [anon_sym_chandle] = ACTIONS(4162),
    [anon_sym_event] = ACTIONS(4162),
    [anon_sym_byte] = ACTIONS(4162),
    [anon_sym_shortint] = ACTIONS(4162),
    [anon_sym_int] = ACTIONS(4162),
    [anon_sym_longint] = ACTIONS(4162),
    [anon_sym_integer] = ACTIONS(4162),
    [anon_sym_time] = ACTIONS(4162),
    [anon_sym_bit] = ACTIONS(4162),
    [anon_sym_logic] = ACTIONS(4162),
    [anon_sym_reg] = ACTIONS(4162),
    [anon_sym_shortreal] = ACTIONS(4162),
    [anon_sym_real] = ACTIONS(4162),
    [anon_sym_realtime] = ACTIONS(4162),
    [anon_sym_supply0] = ACTIONS(4162),
    [anon_sym_supply1] = ACTIONS(4162),
    [anon_sym_signed] = ACTIONS(4162),
    [anon_sym_unsigned] = ACTIONS(4162),
    [anon_sym_task] = ACTIONS(4162),
    [anon_sym_assert] = ACTIONS(4162),
    [anon_sym_property] = ACTIONS(4162),
    [anon_sym_assume] = ACTIONS(4162),
    [anon_sym_cover] = ACTIONS(4162),
    [anon_sym_sequence] = ACTIONS(4162),
    [anon_sym_restrict] = ACTIONS(4162),
    [anon_sym_not] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_case] = ACTIONS(4162),
    [anon_sym_always] = ACTIONS(4162),
    [anon_sym_covergroup] = ACTIONS(4162),
    [anon_sym_let] = ACTIONS(4162),
    [anon_sym_pulldown] = ACTIONS(4162),
    [anon_sym_pullup] = ACTIONS(4162),
    [anon_sym_cmos] = ACTIONS(4162),
    [anon_sym_rcmos] = ACTIONS(4162),
    [anon_sym_bufif0] = ACTIONS(4162),
    [anon_sym_bufif1] = ACTIONS(4162),
    [anon_sym_notif0] = ACTIONS(4162),
    [anon_sym_notif1] = ACTIONS(4162),
    [anon_sym_nmos] = ACTIONS(4162),
    [anon_sym_pmos] = ACTIONS(4162),
    [anon_sym_rnmos] = ACTIONS(4162),
    [anon_sym_rpmos] = ACTIONS(4162),
    [anon_sym_nand] = ACTIONS(4162),
    [anon_sym_nor] = ACTIONS(4162),
    [anon_sym_xor] = ACTIONS(4162),
    [anon_sym_xnor] = ACTIONS(4162),
    [anon_sym_buf] = ACTIONS(4162),
    [anon_sym_tranif0] = ACTIONS(4162),
    [anon_sym_tranif1] = ACTIONS(4162),
    [anon_sym_rtranif1] = ACTIONS(4162),
    [anon_sym_rtranif0] = ACTIONS(4162),
    [anon_sym_tran] = ACTIONS(4162),
    [anon_sym_rtran] = ACTIONS(4162),
    [anon_sym_generate] = ACTIONS(4162),
    [anon_sym_endgenerate] = ACTIONS(4162),
    [anon_sym_for] = ACTIONS(4162),
    [anon_sym_initial] = ACTIONS(4162),
    [anon_sym_assign] = ACTIONS(4162),
    [anon_sym_alias] = ACTIONS(4162),
    [anon_sym_always_comb] = ACTIONS(4162),
    [anon_sym_always_latch] = ACTIONS(4162),
    [anon_sym_always_ff] = ACTIONS(4162),
    [anon_sym_final] = ACTIONS(4162),
    [anon_sym_global] = ACTIONS(4162),
    [anon_sym_LPAREN_STAR] = ACTIONS(4160),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4160),
    [anon_sym_DOLLARunit] = ACTIONS(4160),
  },
  [4483] = {
    [sym_simple_identifier] = ACTIONS(4732),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_COLON] = ACTIONS(10683),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_rand] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_endgenerate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [4484] = {
    [sym_simple_identifier] = ACTIONS(4530),
    [anon_sym_wire] = ACTIONS(4530),
    [anon_sym_tri] = ACTIONS(4530),
    [anon_sym_tri0] = ACTIONS(4530),
    [anon_sym_tri1] = ACTIONS(4530),
    [anon_sym_wand] = ACTIONS(4530),
    [anon_sym_triand] = ACTIONS(4530),
    [anon_sym_wor] = ACTIONS(4530),
    [anon_sym_trior] = ACTIONS(4530),
    [anon_sym_trireg] = ACTIONS(4530),
    [anon_sym_uwire] = ACTIONS(4530),
    [anon_sym_SEMI] = ACTIONS(4528),
    [anon_sym_COLON] = ACTIONS(10685),
    [anon_sym_extern] = ACTIONS(4530),
    [anon_sym_interface] = ACTIONS(4530),
    [anon_sym_checker] = ACTIONS(4530),
    [anon_sym_virtual] = ACTIONS(4530),
    [anon_sym_class] = ACTIONS(4530),
    [anon_sym_type] = ACTIONS(4530),
    [anon_sym_DOLLARfatal] = ACTIONS(4528),
    [anon_sym_DOLLARerror] = ACTIONS(4528),
    [anon_sym_DOLLARwarning] = ACTIONS(4528),
    [anon_sym_DOLLARinfo] = ACTIONS(4528),
    [anon_sym_default] = ACTIONS(4530),
    [anon_sym_clocking] = ACTIONS(4530),
    [anon_sym_defparam] = ACTIONS(4530),
    [anon_sym_bind] = ACTIONS(4530),
    [anon_sym_rand] = ACTIONS(4530),
    [anon_sym_const] = ACTIONS(4530),
    [anon_sym_function] = ACTIONS(4530),
    [anon_sym_static] = ACTIONS(4530),
    [anon_sym_constraint] = ACTIONS(4530),
    [anon_sym_if] = ACTIONS(4530),
    [anon_sym_else] = ACTIONS(4530),
    [anon_sym_LBRACK] = ACTIONS(4528),
    [anon_sym_localparam] = ACTIONS(4530),
    [anon_sym_parameter] = ACTIONS(4530),
    [anon_sym_var] = ACTIONS(4530),
    [anon_sym_import] = ACTIONS(4530),
    [anon_sym_export] = ACTIONS(4530),
    [anon_sym_genvar] = ACTIONS(4530),
    [anon_sym_interconnect] = ACTIONS(4530),
    [anon_sym_typedef] = ACTIONS(4530),
    [anon_sym_enum] = ACTIONS(4530),
    [anon_sym_struct] = ACTIONS(4530),
    [anon_sym_union] = ACTIONS(4530),
    [anon_sym_nettype] = ACTIONS(4530),
    [anon_sym_automatic] = ACTIONS(4530),
    [anon_sym_string] = ACTIONS(4530),
    [anon_sym_chandle] = ACTIONS(4530),
    [anon_sym_event] = ACTIONS(4530),
    [anon_sym_byte] = ACTIONS(4530),
    [anon_sym_shortint] = ACTIONS(4530),
    [anon_sym_int] = ACTIONS(4530),
    [anon_sym_longint] = ACTIONS(4530),
    [anon_sym_integer] = ACTIONS(4530),
    [anon_sym_time] = ACTIONS(4530),
    [anon_sym_bit] = ACTIONS(4530),
    [anon_sym_logic] = ACTIONS(4530),
    [anon_sym_reg] = ACTIONS(4530),
    [anon_sym_shortreal] = ACTIONS(4530),
    [anon_sym_real] = ACTIONS(4530),
    [anon_sym_realtime] = ACTIONS(4530),
    [anon_sym_supply0] = ACTIONS(4530),
    [anon_sym_supply1] = ACTIONS(4530),
    [anon_sym_signed] = ACTIONS(4530),
    [anon_sym_unsigned] = ACTIONS(4530),
    [anon_sym_task] = ACTIONS(4530),
    [anon_sym_assert] = ACTIONS(4530),
    [anon_sym_property] = ACTIONS(4530),
    [anon_sym_assume] = ACTIONS(4530),
    [anon_sym_cover] = ACTIONS(4530),
    [anon_sym_sequence] = ACTIONS(4530),
    [anon_sym_restrict] = ACTIONS(4530),
    [anon_sym_not] = ACTIONS(4530),
    [anon_sym_or] = ACTIONS(4530),
    [anon_sym_and] = ACTIONS(4530),
    [anon_sym_case] = ACTIONS(4530),
    [anon_sym_always] = ACTIONS(4530),
    [anon_sym_covergroup] = ACTIONS(4530),
    [anon_sym_let] = ACTIONS(4530),
    [anon_sym_pulldown] = ACTIONS(4530),
    [anon_sym_pullup] = ACTIONS(4530),
    [anon_sym_cmos] = ACTIONS(4530),
    [anon_sym_rcmos] = ACTIONS(4530),
    [anon_sym_bufif0] = ACTIONS(4530),
    [anon_sym_bufif1] = ACTIONS(4530),
    [anon_sym_notif0] = ACTIONS(4530),
    [anon_sym_notif1] = ACTIONS(4530),
    [anon_sym_nmos] = ACTIONS(4530),
    [anon_sym_pmos] = ACTIONS(4530),
    [anon_sym_rnmos] = ACTIONS(4530),
    [anon_sym_rpmos] = ACTIONS(4530),
    [anon_sym_nand] = ACTIONS(4530),
    [anon_sym_nor] = ACTIONS(4530),
    [anon_sym_xor] = ACTIONS(4530),
    [anon_sym_xnor] = ACTIONS(4530),
    [anon_sym_buf] = ACTIONS(4530),
    [anon_sym_tranif0] = ACTIONS(4530),
    [anon_sym_tranif1] = ACTIONS(4530),
    [anon_sym_rtranif1] = ACTIONS(4530),
    [anon_sym_rtranif0] = ACTIONS(4530),
    [anon_sym_tran] = ACTIONS(4530),
    [anon_sym_rtran] = ACTIONS(4530),
    [anon_sym_generate] = ACTIONS(4530),
    [anon_sym_endgenerate] = ACTIONS(4530),
    [anon_sym_for] = ACTIONS(4530),
    [anon_sym_initial] = ACTIONS(4530),
    [anon_sym_assign] = ACTIONS(4530),
    [anon_sym_alias] = ACTIONS(4530),
    [anon_sym_always_comb] = ACTIONS(4530),
    [anon_sym_always_latch] = ACTIONS(4530),
    [anon_sym_always_ff] = ACTIONS(4530),
    [anon_sym_final] = ACTIONS(4530),
    [anon_sym_global] = ACTIONS(4530),
    [anon_sym_LPAREN_STAR] = ACTIONS(4528),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4528),
    [anon_sym_DOLLARunit] = ACTIONS(4528),
  },
  [4485] = {
    [sym_simple_identifier] = ACTIONS(4488),
    [anon_sym_wire] = ACTIONS(4488),
    [anon_sym_tri] = ACTIONS(4488),
    [anon_sym_tri0] = ACTIONS(4488),
    [anon_sym_tri1] = ACTIONS(4488),
    [anon_sym_wand] = ACTIONS(4488),
    [anon_sym_triand] = ACTIONS(4488),
    [anon_sym_wor] = ACTIONS(4488),
    [anon_sym_trior] = ACTIONS(4488),
    [anon_sym_trireg] = ACTIONS(4488),
    [anon_sym_uwire] = ACTIONS(4488),
    [anon_sym_SEMI] = ACTIONS(4486),
    [anon_sym_COLON] = ACTIONS(10687),
    [anon_sym_extern] = ACTIONS(4488),
    [anon_sym_interface] = ACTIONS(4488),
    [anon_sym_checker] = ACTIONS(4488),
    [anon_sym_virtual] = ACTIONS(4488),
    [anon_sym_class] = ACTIONS(4488),
    [anon_sym_type] = ACTIONS(4488),
    [anon_sym_DOLLARfatal] = ACTIONS(4486),
    [anon_sym_DOLLARerror] = ACTIONS(4486),
    [anon_sym_DOLLARwarning] = ACTIONS(4486),
    [anon_sym_DOLLARinfo] = ACTIONS(4486),
    [anon_sym_default] = ACTIONS(4488),
    [anon_sym_clocking] = ACTIONS(4488),
    [anon_sym_defparam] = ACTIONS(4488),
    [anon_sym_bind] = ACTIONS(4488),
    [anon_sym_rand] = ACTIONS(4488),
    [anon_sym_const] = ACTIONS(4488),
    [anon_sym_function] = ACTIONS(4488),
    [anon_sym_static] = ACTIONS(4488),
    [anon_sym_constraint] = ACTIONS(4488),
    [anon_sym_if] = ACTIONS(4488),
    [anon_sym_else] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4486),
    [anon_sym_localparam] = ACTIONS(4488),
    [anon_sym_parameter] = ACTIONS(4488),
    [anon_sym_var] = ACTIONS(4488),
    [anon_sym_import] = ACTIONS(4488),
    [anon_sym_export] = ACTIONS(4488),
    [anon_sym_genvar] = ACTIONS(4488),
    [anon_sym_interconnect] = ACTIONS(4488),
    [anon_sym_typedef] = ACTIONS(4488),
    [anon_sym_enum] = ACTIONS(4488),
    [anon_sym_struct] = ACTIONS(4488),
    [anon_sym_union] = ACTIONS(4488),
    [anon_sym_nettype] = ACTIONS(4488),
    [anon_sym_automatic] = ACTIONS(4488),
    [anon_sym_string] = ACTIONS(4488),
    [anon_sym_chandle] = ACTIONS(4488),
    [anon_sym_event] = ACTIONS(4488),
    [anon_sym_byte] = ACTIONS(4488),
    [anon_sym_shortint] = ACTIONS(4488),
    [anon_sym_int] = ACTIONS(4488),
    [anon_sym_longint] = ACTIONS(4488),
    [anon_sym_integer] = ACTIONS(4488),
    [anon_sym_time] = ACTIONS(4488),
    [anon_sym_bit] = ACTIONS(4488),
    [anon_sym_logic] = ACTIONS(4488),
    [anon_sym_reg] = ACTIONS(4488),
    [anon_sym_shortreal] = ACTIONS(4488),
    [anon_sym_real] = ACTIONS(4488),
    [anon_sym_realtime] = ACTIONS(4488),
    [anon_sym_supply0] = ACTIONS(4488),
    [anon_sym_supply1] = ACTIONS(4488),
    [anon_sym_signed] = ACTIONS(4488),
    [anon_sym_unsigned] = ACTIONS(4488),
    [anon_sym_task] = ACTIONS(4488),
    [anon_sym_assert] = ACTIONS(4488),
    [anon_sym_property] = ACTIONS(4488),
    [anon_sym_assume] = ACTIONS(4488),
    [anon_sym_cover] = ACTIONS(4488),
    [anon_sym_sequence] = ACTIONS(4488),
    [anon_sym_restrict] = ACTIONS(4488),
    [anon_sym_not] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_case] = ACTIONS(4488),
    [anon_sym_always] = ACTIONS(4488),
    [anon_sym_covergroup] = ACTIONS(4488),
    [anon_sym_end] = ACTIONS(4488),
    [anon_sym_let] = ACTIONS(4488),
    [anon_sym_pulldown] = ACTIONS(4488),
    [anon_sym_pullup] = ACTIONS(4488),
    [anon_sym_cmos] = ACTIONS(4488),
    [anon_sym_rcmos] = ACTIONS(4488),
    [anon_sym_bufif0] = ACTIONS(4488),
    [anon_sym_bufif1] = ACTIONS(4488),
    [anon_sym_notif0] = ACTIONS(4488),
    [anon_sym_notif1] = ACTIONS(4488),
    [anon_sym_nmos] = ACTIONS(4488),
    [anon_sym_pmos] = ACTIONS(4488),
    [anon_sym_rnmos] = ACTIONS(4488),
    [anon_sym_rpmos] = ACTIONS(4488),
    [anon_sym_nand] = ACTIONS(4488),
    [anon_sym_nor] = ACTIONS(4488),
    [anon_sym_xor] = ACTIONS(4488),
    [anon_sym_xnor] = ACTIONS(4488),
    [anon_sym_buf] = ACTIONS(4488),
    [anon_sym_tranif0] = ACTIONS(4488),
    [anon_sym_tranif1] = ACTIONS(4488),
    [anon_sym_rtranif1] = ACTIONS(4488),
    [anon_sym_rtranif0] = ACTIONS(4488),
    [anon_sym_tran] = ACTIONS(4488),
    [anon_sym_rtran] = ACTIONS(4488),
    [anon_sym_generate] = ACTIONS(4488),
    [anon_sym_for] = ACTIONS(4488),
    [anon_sym_initial] = ACTIONS(4488),
    [anon_sym_assign] = ACTIONS(4488),
    [anon_sym_alias] = ACTIONS(4488),
    [anon_sym_always_comb] = ACTIONS(4488),
    [anon_sym_always_latch] = ACTIONS(4488),
    [anon_sym_always_ff] = ACTIONS(4488),
    [anon_sym_final] = ACTIONS(4488),
    [anon_sym_global] = ACTIONS(4488),
    [anon_sym_LPAREN_STAR] = ACTIONS(4486),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4486),
    [anon_sym_DOLLARunit] = ACTIONS(4486),
  },
  [4486] = {
    [sym_simple_identifier] = ACTIONS(4738),
    [anon_sym_wire] = ACTIONS(4738),
    [anon_sym_tri] = ACTIONS(4738),
    [anon_sym_tri0] = ACTIONS(4738),
    [anon_sym_tri1] = ACTIONS(4738),
    [anon_sym_wand] = ACTIONS(4738),
    [anon_sym_triand] = ACTIONS(4738),
    [anon_sym_wor] = ACTIONS(4738),
    [anon_sym_trior] = ACTIONS(4738),
    [anon_sym_trireg] = ACTIONS(4738),
    [anon_sym_uwire] = ACTIONS(4738),
    [anon_sym_SEMI] = ACTIONS(4736),
    [anon_sym_COLON] = ACTIONS(10689),
    [anon_sym_extern] = ACTIONS(4738),
    [anon_sym_interface] = ACTIONS(4738),
    [anon_sym_checker] = ACTIONS(4738),
    [anon_sym_virtual] = ACTIONS(4738),
    [anon_sym_class] = ACTIONS(4738),
    [anon_sym_type] = ACTIONS(4738),
    [anon_sym_DOLLARfatal] = ACTIONS(4736),
    [anon_sym_DOLLARerror] = ACTIONS(4736),
    [anon_sym_DOLLARwarning] = ACTIONS(4736),
    [anon_sym_DOLLARinfo] = ACTIONS(4736),
    [anon_sym_default] = ACTIONS(4738),
    [anon_sym_clocking] = ACTIONS(4738),
    [anon_sym_defparam] = ACTIONS(4738),
    [anon_sym_bind] = ACTIONS(4738),
    [anon_sym_rand] = ACTIONS(4738),
    [anon_sym_const] = ACTIONS(4738),
    [anon_sym_function] = ACTIONS(4738),
    [anon_sym_static] = ACTIONS(4738),
    [anon_sym_constraint] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4738),
    [anon_sym_else] = ACTIONS(4738),
    [anon_sym_LBRACK] = ACTIONS(4736),
    [anon_sym_localparam] = ACTIONS(4738),
    [anon_sym_parameter] = ACTIONS(4738),
    [anon_sym_var] = ACTIONS(4738),
    [anon_sym_import] = ACTIONS(4738),
    [anon_sym_export] = ACTIONS(4738),
    [anon_sym_genvar] = ACTIONS(4738),
    [anon_sym_interconnect] = ACTIONS(4738),
    [anon_sym_typedef] = ACTIONS(4738),
    [anon_sym_enum] = ACTIONS(4738),
    [anon_sym_struct] = ACTIONS(4738),
    [anon_sym_union] = ACTIONS(4738),
    [anon_sym_nettype] = ACTIONS(4738),
    [anon_sym_automatic] = ACTIONS(4738),
    [anon_sym_string] = ACTIONS(4738),
    [anon_sym_chandle] = ACTIONS(4738),
    [anon_sym_event] = ACTIONS(4738),
    [anon_sym_byte] = ACTIONS(4738),
    [anon_sym_shortint] = ACTIONS(4738),
    [anon_sym_int] = ACTIONS(4738),
    [anon_sym_longint] = ACTIONS(4738),
    [anon_sym_integer] = ACTIONS(4738),
    [anon_sym_time] = ACTIONS(4738),
    [anon_sym_bit] = ACTIONS(4738),
    [anon_sym_logic] = ACTIONS(4738),
    [anon_sym_reg] = ACTIONS(4738),
    [anon_sym_shortreal] = ACTIONS(4738),
    [anon_sym_real] = ACTIONS(4738),
    [anon_sym_realtime] = ACTIONS(4738),
    [anon_sym_supply0] = ACTIONS(4738),
    [anon_sym_supply1] = ACTIONS(4738),
    [anon_sym_signed] = ACTIONS(4738),
    [anon_sym_unsigned] = ACTIONS(4738),
    [anon_sym_task] = ACTIONS(4738),
    [anon_sym_assert] = ACTIONS(4738),
    [anon_sym_property] = ACTIONS(4738),
    [anon_sym_assume] = ACTIONS(4738),
    [anon_sym_cover] = ACTIONS(4738),
    [anon_sym_sequence] = ACTIONS(4738),
    [anon_sym_restrict] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4738),
    [anon_sym_or] = ACTIONS(4738),
    [anon_sym_and] = ACTIONS(4738),
    [anon_sym_case] = ACTIONS(4738),
    [anon_sym_always] = ACTIONS(4738),
    [anon_sym_covergroup] = ACTIONS(4738),
    [anon_sym_end] = ACTIONS(4738),
    [anon_sym_let] = ACTIONS(4738),
    [anon_sym_pulldown] = ACTIONS(4738),
    [anon_sym_pullup] = ACTIONS(4738),
    [anon_sym_cmos] = ACTIONS(4738),
    [anon_sym_rcmos] = ACTIONS(4738),
    [anon_sym_bufif0] = ACTIONS(4738),
    [anon_sym_bufif1] = ACTIONS(4738),
    [anon_sym_notif0] = ACTIONS(4738),
    [anon_sym_notif1] = ACTIONS(4738),
    [anon_sym_nmos] = ACTIONS(4738),
    [anon_sym_pmos] = ACTIONS(4738),
    [anon_sym_rnmos] = ACTIONS(4738),
    [anon_sym_rpmos] = ACTIONS(4738),
    [anon_sym_nand] = ACTIONS(4738),
    [anon_sym_nor] = ACTIONS(4738),
    [anon_sym_xor] = ACTIONS(4738),
    [anon_sym_xnor] = ACTIONS(4738),
    [anon_sym_buf] = ACTIONS(4738),
    [anon_sym_tranif0] = ACTIONS(4738),
    [anon_sym_tranif1] = ACTIONS(4738),
    [anon_sym_rtranif1] = ACTIONS(4738),
    [anon_sym_rtranif0] = ACTIONS(4738),
    [anon_sym_tran] = ACTIONS(4738),
    [anon_sym_rtran] = ACTIONS(4738),
    [anon_sym_generate] = ACTIONS(4738),
    [anon_sym_for] = ACTIONS(4738),
    [anon_sym_initial] = ACTIONS(4738),
    [anon_sym_assign] = ACTIONS(4738),
    [anon_sym_alias] = ACTIONS(4738),
    [anon_sym_always_comb] = ACTIONS(4738),
    [anon_sym_always_latch] = ACTIONS(4738),
    [anon_sym_always_ff] = ACTIONS(4738),
    [anon_sym_final] = ACTIONS(4738),
    [anon_sym_global] = ACTIONS(4738),
    [anon_sym_LPAREN_STAR] = ACTIONS(4736),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4736),
    [anon_sym_DOLLARunit] = ACTIONS(4736),
  },
  [4487] = {
    [sym_simple_identifier] = ACTIONS(4756),
    [anon_sym_wire] = ACTIONS(4756),
    [anon_sym_tri] = ACTIONS(4756),
    [anon_sym_tri0] = ACTIONS(4756),
    [anon_sym_tri1] = ACTIONS(4756),
    [anon_sym_wand] = ACTIONS(4756),
    [anon_sym_triand] = ACTIONS(4756),
    [anon_sym_wor] = ACTIONS(4756),
    [anon_sym_trior] = ACTIONS(4756),
    [anon_sym_trireg] = ACTIONS(4756),
    [anon_sym_uwire] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_COLON] = ACTIONS(10691),
    [anon_sym_extern] = ACTIONS(4756),
    [anon_sym_interface] = ACTIONS(4756),
    [anon_sym_checker] = ACTIONS(4756),
    [anon_sym_virtual] = ACTIONS(4756),
    [anon_sym_class] = ACTIONS(4756),
    [anon_sym_type] = ACTIONS(4756),
    [anon_sym_DOLLARfatal] = ACTIONS(4754),
    [anon_sym_DOLLARerror] = ACTIONS(4754),
    [anon_sym_DOLLARwarning] = ACTIONS(4754),
    [anon_sym_DOLLARinfo] = ACTIONS(4754),
    [anon_sym_default] = ACTIONS(4756),
    [anon_sym_clocking] = ACTIONS(4756),
    [anon_sym_defparam] = ACTIONS(4756),
    [anon_sym_bind] = ACTIONS(4756),
    [anon_sym_rand] = ACTIONS(4756),
    [anon_sym_const] = ACTIONS(4756),
    [anon_sym_function] = ACTIONS(4756),
    [anon_sym_static] = ACTIONS(4756),
    [anon_sym_constraint] = ACTIONS(4756),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [anon_sym_localparam] = ACTIONS(4756),
    [anon_sym_parameter] = ACTIONS(4756),
    [anon_sym_var] = ACTIONS(4756),
    [anon_sym_import] = ACTIONS(4756),
    [anon_sym_export] = ACTIONS(4756),
    [anon_sym_genvar] = ACTIONS(4756),
    [anon_sym_interconnect] = ACTIONS(4756),
    [anon_sym_typedef] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_struct] = ACTIONS(4756),
    [anon_sym_union] = ACTIONS(4756),
    [anon_sym_nettype] = ACTIONS(4756),
    [anon_sym_automatic] = ACTIONS(4756),
    [anon_sym_string] = ACTIONS(4756),
    [anon_sym_chandle] = ACTIONS(4756),
    [anon_sym_event] = ACTIONS(4756),
    [anon_sym_byte] = ACTIONS(4756),
    [anon_sym_shortint] = ACTIONS(4756),
    [anon_sym_int] = ACTIONS(4756),
    [anon_sym_longint] = ACTIONS(4756),
    [anon_sym_integer] = ACTIONS(4756),
    [anon_sym_time] = ACTIONS(4756),
    [anon_sym_bit] = ACTIONS(4756),
    [anon_sym_logic] = ACTIONS(4756),
    [anon_sym_reg] = ACTIONS(4756),
    [anon_sym_shortreal] = ACTIONS(4756),
    [anon_sym_real] = ACTIONS(4756),
    [anon_sym_realtime] = ACTIONS(4756),
    [anon_sym_supply0] = ACTIONS(4756),
    [anon_sym_supply1] = ACTIONS(4756),
    [anon_sym_signed] = ACTIONS(4756),
    [anon_sym_unsigned] = ACTIONS(4756),
    [anon_sym_task] = ACTIONS(4756),
    [anon_sym_assert] = ACTIONS(4756),
    [anon_sym_property] = ACTIONS(4756),
    [anon_sym_assume] = ACTIONS(4756),
    [anon_sym_cover] = ACTIONS(4756),
    [anon_sym_sequence] = ACTIONS(4756),
    [anon_sym_restrict] = ACTIONS(4756),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_or] = ACTIONS(4756),
    [anon_sym_and] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_always] = ACTIONS(4756),
    [anon_sym_covergroup] = ACTIONS(4756),
    [anon_sym_let] = ACTIONS(4756),
    [anon_sym_pulldown] = ACTIONS(4756),
    [anon_sym_pullup] = ACTIONS(4756),
    [anon_sym_cmos] = ACTIONS(4756),
    [anon_sym_rcmos] = ACTIONS(4756),
    [anon_sym_bufif0] = ACTIONS(4756),
    [anon_sym_bufif1] = ACTIONS(4756),
    [anon_sym_notif0] = ACTIONS(4756),
    [anon_sym_notif1] = ACTIONS(4756),
    [anon_sym_nmos] = ACTIONS(4756),
    [anon_sym_pmos] = ACTIONS(4756),
    [anon_sym_rnmos] = ACTIONS(4756),
    [anon_sym_rpmos] = ACTIONS(4756),
    [anon_sym_nand] = ACTIONS(4756),
    [anon_sym_nor] = ACTIONS(4756),
    [anon_sym_xor] = ACTIONS(4756),
    [anon_sym_xnor] = ACTIONS(4756),
    [anon_sym_buf] = ACTIONS(4756),
    [anon_sym_tranif0] = ACTIONS(4756),
    [anon_sym_tranif1] = ACTIONS(4756),
    [anon_sym_rtranif1] = ACTIONS(4756),
    [anon_sym_rtranif0] = ACTIONS(4756),
    [anon_sym_tran] = ACTIONS(4756),
    [anon_sym_rtran] = ACTIONS(4756),
    [anon_sym_generate] = ACTIONS(4756),
    [anon_sym_endgenerate] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_initial] = ACTIONS(4756),
    [anon_sym_assign] = ACTIONS(4756),
    [anon_sym_alias] = ACTIONS(4756),
    [anon_sym_always_comb] = ACTIONS(4756),
    [anon_sym_always_latch] = ACTIONS(4756),
    [anon_sym_always_ff] = ACTIONS(4756),
    [anon_sym_final] = ACTIONS(4756),
    [anon_sym_global] = ACTIONS(4756),
    [anon_sym_LPAREN_STAR] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4754),
    [anon_sym_DOLLARunit] = ACTIONS(4754),
  },
  [4488] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_COLON] = ACTIONS(10693),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_rand] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_endgenerate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [4489] = {
    [sym_simple_identifier] = ACTIONS(4254),
    [anon_sym_wire] = ACTIONS(4254),
    [anon_sym_tri] = ACTIONS(4254),
    [anon_sym_tri0] = ACTIONS(4254),
    [anon_sym_tri1] = ACTIONS(4254),
    [anon_sym_wand] = ACTIONS(4254),
    [anon_sym_triand] = ACTIONS(4254),
    [anon_sym_wor] = ACTIONS(4254),
    [anon_sym_trior] = ACTIONS(4254),
    [anon_sym_trireg] = ACTIONS(4254),
    [anon_sym_uwire] = ACTIONS(4254),
    [anon_sym_SEMI] = ACTIONS(4252),
    [anon_sym_COLON] = ACTIONS(10695),
    [anon_sym_extern] = ACTIONS(4254),
    [anon_sym_interface] = ACTIONS(4254),
    [anon_sym_checker] = ACTIONS(4254),
    [anon_sym_virtual] = ACTIONS(4254),
    [anon_sym_class] = ACTIONS(4254),
    [anon_sym_type] = ACTIONS(4254),
    [anon_sym_DOLLARfatal] = ACTIONS(4252),
    [anon_sym_DOLLARerror] = ACTIONS(4252),
    [anon_sym_DOLLARwarning] = ACTIONS(4252),
    [anon_sym_DOLLARinfo] = ACTIONS(4252),
    [anon_sym_default] = ACTIONS(4254),
    [anon_sym_clocking] = ACTIONS(4254),
    [anon_sym_defparam] = ACTIONS(4254),
    [anon_sym_bind] = ACTIONS(4254),
    [anon_sym_rand] = ACTIONS(4254),
    [anon_sym_const] = ACTIONS(4254),
    [anon_sym_function] = ACTIONS(4254),
    [anon_sym_static] = ACTIONS(4254),
    [anon_sym_constraint] = ACTIONS(4254),
    [anon_sym_if] = ACTIONS(4254),
    [anon_sym_else] = ACTIONS(4254),
    [anon_sym_LBRACK] = ACTIONS(4252),
    [anon_sym_localparam] = ACTIONS(4254),
    [anon_sym_parameter] = ACTIONS(4254),
    [anon_sym_var] = ACTIONS(4254),
    [anon_sym_import] = ACTIONS(4254),
    [anon_sym_export] = ACTIONS(4254),
    [anon_sym_genvar] = ACTIONS(4254),
    [anon_sym_interconnect] = ACTIONS(4254),
    [anon_sym_typedef] = ACTIONS(4254),
    [anon_sym_enum] = ACTIONS(4254),
    [anon_sym_struct] = ACTIONS(4254),
    [anon_sym_union] = ACTIONS(4254),
    [anon_sym_nettype] = ACTIONS(4254),
    [anon_sym_automatic] = ACTIONS(4254),
    [anon_sym_string] = ACTIONS(4254),
    [anon_sym_chandle] = ACTIONS(4254),
    [anon_sym_event] = ACTIONS(4254),
    [anon_sym_byte] = ACTIONS(4254),
    [anon_sym_shortint] = ACTIONS(4254),
    [anon_sym_int] = ACTIONS(4254),
    [anon_sym_longint] = ACTIONS(4254),
    [anon_sym_integer] = ACTIONS(4254),
    [anon_sym_time] = ACTIONS(4254),
    [anon_sym_bit] = ACTIONS(4254),
    [anon_sym_logic] = ACTIONS(4254),
    [anon_sym_reg] = ACTIONS(4254),
    [anon_sym_shortreal] = ACTIONS(4254),
    [anon_sym_real] = ACTIONS(4254),
    [anon_sym_realtime] = ACTIONS(4254),
    [anon_sym_supply0] = ACTIONS(4254),
    [anon_sym_supply1] = ACTIONS(4254),
    [anon_sym_signed] = ACTIONS(4254),
    [anon_sym_unsigned] = ACTIONS(4254),
    [anon_sym_task] = ACTIONS(4254),
    [anon_sym_assert] = ACTIONS(4254),
    [anon_sym_property] = ACTIONS(4254),
    [anon_sym_assume] = ACTIONS(4254),
    [anon_sym_cover] = ACTIONS(4254),
    [anon_sym_sequence] = ACTIONS(4254),
    [anon_sym_restrict] = ACTIONS(4254),
    [anon_sym_not] = ACTIONS(4254),
    [anon_sym_or] = ACTIONS(4254),
    [anon_sym_and] = ACTIONS(4254),
    [anon_sym_case] = ACTIONS(4254),
    [anon_sym_always] = ACTIONS(4254),
    [anon_sym_covergroup] = ACTIONS(4254),
    [anon_sym_let] = ACTIONS(4254),
    [anon_sym_pulldown] = ACTIONS(4254),
    [anon_sym_pullup] = ACTIONS(4254),
    [anon_sym_cmos] = ACTIONS(4254),
    [anon_sym_rcmos] = ACTIONS(4254),
    [anon_sym_bufif0] = ACTIONS(4254),
    [anon_sym_bufif1] = ACTIONS(4254),
    [anon_sym_notif0] = ACTIONS(4254),
    [anon_sym_notif1] = ACTIONS(4254),
    [anon_sym_nmos] = ACTIONS(4254),
    [anon_sym_pmos] = ACTIONS(4254),
    [anon_sym_rnmos] = ACTIONS(4254),
    [anon_sym_rpmos] = ACTIONS(4254),
    [anon_sym_nand] = ACTIONS(4254),
    [anon_sym_nor] = ACTIONS(4254),
    [anon_sym_xor] = ACTIONS(4254),
    [anon_sym_xnor] = ACTIONS(4254),
    [anon_sym_buf] = ACTIONS(4254),
    [anon_sym_tranif0] = ACTIONS(4254),
    [anon_sym_tranif1] = ACTIONS(4254),
    [anon_sym_rtranif1] = ACTIONS(4254),
    [anon_sym_rtranif0] = ACTIONS(4254),
    [anon_sym_tran] = ACTIONS(4254),
    [anon_sym_rtran] = ACTIONS(4254),
    [anon_sym_generate] = ACTIONS(4254),
    [anon_sym_endgenerate] = ACTIONS(4254),
    [anon_sym_for] = ACTIONS(4254),
    [anon_sym_initial] = ACTIONS(4254),
    [anon_sym_assign] = ACTIONS(4254),
    [anon_sym_alias] = ACTIONS(4254),
    [anon_sym_always_comb] = ACTIONS(4254),
    [anon_sym_always_latch] = ACTIONS(4254),
    [anon_sym_always_ff] = ACTIONS(4254),
    [anon_sym_final] = ACTIONS(4254),
    [anon_sym_global] = ACTIONS(4254),
    [anon_sym_LPAREN_STAR] = ACTIONS(4252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4252),
    [anon_sym_DOLLARunit] = ACTIONS(4252),
  },
  [4490] = {
    [sym_simple_identifier] = ACTIONS(4274),
    [anon_sym_wire] = ACTIONS(4274),
    [anon_sym_tri] = ACTIONS(4274),
    [anon_sym_tri0] = ACTIONS(4274),
    [anon_sym_tri1] = ACTIONS(4274),
    [anon_sym_wand] = ACTIONS(4274),
    [anon_sym_triand] = ACTIONS(4274),
    [anon_sym_wor] = ACTIONS(4274),
    [anon_sym_trior] = ACTIONS(4274),
    [anon_sym_trireg] = ACTIONS(4274),
    [anon_sym_uwire] = ACTIONS(4274),
    [anon_sym_SEMI] = ACTIONS(4272),
    [anon_sym_COLON] = ACTIONS(10697),
    [anon_sym_extern] = ACTIONS(4274),
    [anon_sym_interface] = ACTIONS(4274),
    [anon_sym_checker] = ACTIONS(4274),
    [anon_sym_virtual] = ACTIONS(4274),
    [anon_sym_class] = ACTIONS(4274),
    [anon_sym_type] = ACTIONS(4274),
    [anon_sym_DOLLARfatal] = ACTIONS(4272),
    [anon_sym_DOLLARerror] = ACTIONS(4272),
    [anon_sym_DOLLARwarning] = ACTIONS(4272),
    [anon_sym_DOLLARinfo] = ACTIONS(4272),
    [anon_sym_default] = ACTIONS(4274),
    [anon_sym_clocking] = ACTIONS(4274),
    [anon_sym_defparam] = ACTIONS(4274),
    [anon_sym_bind] = ACTIONS(4274),
    [anon_sym_rand] = ACTIONS(4274),
    [anon_sym_const] = ACTIONS(4274),
    [anon_sym_function] = ACTIONS(4274),
    [anon_sym_static] = ACTIONS(4274),
    [anon_sym_constraint] = ACTIONS(4274),
    [anon_sym_if] = ACTIONS(4274),
    [anon_sym_else] = ACTIONS(4274),
    [anon_sym_LBRACK] = ACTIONS(4272),
    [anon_sym_localparam] = ACTIONS(4274),
    [anon_sym_parameter] = ACTIONS(4274),
    [anon_sym_var] = ACTIONS(4274),
    [anon_sym_import] = ACTIONS(4274),
    [anon_sym_export] = ACTIONS(4274),
    [anon_sym_genvar] = ACTIONS(4274),
    [anon_sym_interconnect] = ACTIONS(4274),
    [anon_sym_typedef] = ACTIONS(4274),
    [anon_sym_enum] = ACTIONS(4274),
    [anon_sym_struct] = ACTIONS(4274),
    [anon_sym_union] = ACTIONS(4274),
    [anon_sym_nettype] = ACTIONS(4274),
    [anon_sym_automatic] = ACTIONS(4274),
    [anon_sym_string] = ACTIONS(4274),
    [anon_sym_chandle] = ACTIONS(4274),
    [anon_sym_event] = ACTIONS(4274),
    [anon_sym_byte] = ACTIONS(4274),
    [anon_sym_shortint] = ACTIONS(4274),
    [anon_sym_int] = ACTIONS(4274),
    [anon_sym_longint] = ACTIONS(4274),
    [anon_sym_integer] = ACTIONS(4274),
    [anon_sym_time] = ACTIONS(4274),
    [anon_sym_bit] = ACTIONS(4274),
    [anon_sym_logic] = ACTIONS(4274),
    [anon_sym_reg] = ACTIONS(4274),
    [anon_sym_shortreal] = ACTIONS(4274),
    [anon_sym_real] = ACTIONS(4274),
    [anon_sym_realtime] = ACTIONS(4274),
    [anon_sym_supply0] = ACTIONS(4274),
    [anon_sym_supply1] = ACTIONS(4274),
    [anon_sym_signed] = ACTIONS(4274),
    [anon_sym_unsigned] = ACTIONS(4274),
    [anon_sym_task] = ACTIONS(4274),
    [anon_sym_assert] = ACTIONS(4274),
    [anon_sym_property] = ACTIONS(4274),
    [anon_sym_assume] = ACTIONS(4274),
    [anon_sym_cover] = ACTIONS(4274),
    [anon_sym_sequence] = ACTIONS(4274),
    [anon_sym_restrict] = ACTIONS(4274),
    [anon_sym_not] = ACTIONS(4274),
    [anon_sym_or] = ACTIONS(4274),
    [anon_sym_and] = ACTIONS(4274),
    [anon_sym_case] = ACTIONS(4274),
    [anon_sym_always] = ACTIONS(4274),
    [anon_sym_covergroup] = ACTIONS(4274),
    [anon_sym_let] = ACTIONS(4274),
    [anon_sym_pulldown] = ACTIONS(4274),
    [anon_sym_pullup] = ACTIONS(4274),
    [anon_sym_cmos] = ACTIONS(4274),
    [anon_sym_rcmos] = ACTIONS(4274),
    [anon_sym_bufif0] = ACTIONS(4274),
    [anon_sym_bufif1] = ACTIONS(4274),
    [anon_sym_notif0] = ACTIONS(4274),
    [anon_sym_notif1] = ACTIONS(4274),
    [anon_sym_nmos] = ACTIONS(4274),
    [anon_sym_pmos] = ACTIONS(4274),
    [anon_sym_rnmos] = ACTIONS(4274),
    [anon_sym_rpmos] = ACTIONS(4274),
    [anon_sym_nand] = ACTIONS(4274),
    [anon_sym_nor] = ACTIONS(4274),
    [anon_sym_xor] = ACTIONS(4274),
    [anon_sym_xnor] = ACTIONS(4274),
    [anon_sym_buf] = ACTIONS(4274),
    [anon_sym_tranif0] = ACTIONS(4274),
    [anon_sym_tranif1] = ACTIONS(4274),
    [anon_sym_rtranif1] = ACTIONS(4274),
    [anon_sym_rtranif0] = ACTIONS(4274),
    [anon_sym_tran] = ACTIONS(4274),
    [anon_sym_rtran] = ACTIONS(4274),
    [anon_sym_generate] = ACTIONS(4274),
    [anon_sym_endgenerate] = ACTIONS(4274),
    [anon_sym_for] = ACTIONS(4274),
    [anon_sym_initial] = ACTIONS(4274),
    [anon_sym_assign] = ACTIONS(4274),
    [anon_sym_alias] = ACTIONS(4274),
    [anon_sym_always_comb] = ACTIONS(4274),
    [anon_sym_always_latch] = ACTIONS(4274),
    [anon_sym_always_ff] = ACTIONS(4274),
    [anon_sym_final] = ACTIONS(4274),
    [anon_sym_global] = ACTIONS(4274),
    [anon_sym_LPAREN_STAR] = ACTIONS(4272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4272),
    [anon_sym_DOLLARunit] = ACTIONS(4272),
  },
  [4491] = {
    [sym_simple_identifier] = ACTIONS(4430),
    [anon_sym_wire] = ACTIONS(4430),
    [anon_sym_tri] = ACTIONS(4430),
    [anon_sym_tri0] = ACTIONS(4430),
    [anon_sym_tri1] = ACTIONS(4430),
    [anon_sym_wand] = ACTIONS(4430),
    [anon_sym_triand] = ACTIONS(4430),
    [anon_sym_wor] = ACTIONS(4430),
    [anon_sym_trior] = ACTIONS(4430),
    [anon_sym_trireg] = ACTIONS(4430),
    [anon_sym_uwire] = ACTIONS(4430),
    [anon_sym_SEMI] = ACTIONS(4428),
    [anon_sym_COLON] = ACTIONS(10699),
    [anon_sym_extern] = ACTIONS(4430),
    [anon_sym_interface] = ACTIONS(4430),
    [anon_sym_checker] = ACTIONS(4430),
    [anon_sym_virtual] = ACTIONS(4430),
    [anon_sym_class] = ACTIONS(4430),
    [anon_sym_type] = ACTIONS(4430),
    [anon_sym_DOLLARfatal] = ACTIONS(4428),
    [anon_sym_DOLLARerror] = ACTIONS(4428),
    [anon_sym_DOLLARwarning] = ACTIONS(4428),
    [anon_sym_DOLLARinfo] = ACTIONS(4428),
    [anon_sym_default] = ACTIONS(4430),
    [anon_sym_clocking] = ACTIONS(4430),
    [anon_sym_defparam] = ACTIONS(4430),
    [anon_sym_bind] = ACTIONS(4430),
    [anon_sym_rand] = ACTIONS(4430),
    [anon_sym_const] = ACTIONS(4430),
    [anon_sym_function] = ACTIONS(4430),
    [anon_sym_static] = ACTIONS(4430),
    [anon_sym_constraint] = ACTIONS(4430),
    [anon_sym_if] = ACTIONS(4430),
    [anon_sym_else] = ACTIONS(4430),
    [anon_sym_LBRACK] = ACTIONS(4428),
    [anon_sym_localparam] = ACTIONS(4430),
    [anon_sym_parameter] = ACTIONS(4430),
    [anon_sym_var] = ACTIONS(4430),
    [anon_sym_import] = ACTIONS(4430),
    [anon_sym_export] = ACTIONS(4430),
    [anon_sym_genvar] = ACTIONS(4430),
    [anon_sym_interconnect] = ACTIONS(4430),
    [anon_sym_typedef] = ACTIONS(4430),
    [anon_sym_enum] = ACTIONS(4430),
    [anon_sym_struct] = ACTIONS(4430),
    [anon_sym_union] = ACTIONS(4430),
    [anon_sym_nettype] = ACTIONS(4430),
    [anon_sym_automatic] = ACTIONS(4430),
    [anon_sym_string] = ACTIONS(4430),
    [anon_sym_chandle] = ACTIONS(4430),
    [anon_sym_event] = ACTIONS(4430),
    [anon_sym_byte] = ACTIONS(4430),
    [anon_sym_shortint] = ACTIONS(4430),
    [anon_sym_int] = ACTIONS(4430),
    [anon_sym_longint] = ACTIONS(4430),
    [anon_sym_integer] = ACTIONS(4430),
    [anon_sym_time] = ACTIONS(4430),
    [anon_sym_bit] = ACTIONS(4430),
    [anon_sym_logic] = ACTIONS(4430),
    [anon_sym_reg] = ACTIONS(4430),
    [anon_sym_shortreal] = ACTIONS(4430),
    [anon_sym_real] = ACTIONS(4430),
    [anon_sym_realtime] = ACTIONS(4430),
    [anon_sym_supply0] = ACTIONS(4430),
    [anon_sym_supply1] = ACTIONS(4430),
    [anon_sym_signed] = ACTIONS(4430),
    [anon_sym_unsigned] = ACTIONS(4430),
    [anon_sym_task] = ACTIONS(4430),
    [anon_sym_assert] = ACTIONS(4430),
    [anon_sym_property] = ACTIONS(4430),
    [anon_sym_assume] = ACTIONS(4430),
    [anon_sym_cover] = ACTIONS(4430),
    [anon_sym_sequence] = ACTIONS(4430),
    [anon_sym_restrict] = ACTIONS(4430),
    [anon_sym_not] = ACTIONS(4430),
    [anon_sym_or] = ACTIONS(4430),
    [anon_sym_and] = ACTIONS(4430),
    [anon_sym_case] = ACTIONS(4430),
    [anon_sym_always] = ACTIONS(4430),
    [anon_sym_covergroup] = ACTIONS(4430),
    [anon_sym_let] = ACTIONS(4430),
    [anon_sym_pulldown] = ACTIONS(4430),
    [anon_sym_pullup] = ACTIONS(4430),
    [anon_sym_cmos] = ACTIONS(4430),
    [anon_sym_rcmos] = ACTIONS(4430),
    [anon_sym_bufif0] = ACTIONS(4430),
    [anon_sym_bufif1] = ACTIONS(4430),
    [anon_sym_notif0] = ACTIONS(4430),
    [anon_sym_notif1] = ACTIONS(4430),
    [anon_sym_nmos] = ACTIONS(4430),
    [anon_sym_pmos] = ACTIONS(4430),
    [anon_sym_rnmos] = ACTIONS(4430),
    [anon_sym_rpmos] = ACTIONS(4430),
    [anon_sym_nand] = ACTIONS(4430),
    [anon_sym_nor] = ACTIONS(4430),
    [anon_sym_xor] = ACTIONS(4430),
    [anon_sym_xnor] = ACTIONS(4430),
    [anon_sym_buf] = ACTIONS(4430),
    [anon_sym_tranif0] = ACTIONS(4430),
    [anon_sym_tranif1] = ACTIONS(4430),
    [anon_sym_rtranif1] = ACTIONS(4430),
    [anon_sym_rtranif0] = ACTIONS(4430),
    [anon_sym_tran] = ACTIONS(4430),
    [anon_sym_rtran] = ACTIONS(4430),
    [anon_sym_generate] = ACTIONS(4430),
    [anon_sym_endgenerate] = ACTIONS(4430),
    [anon_sym_for] = ACTIONS(4430),
    [anon_sym_initial] = ACTIONS(4430),
    [anon_sym_assign] = ACTIONS(4430),
    [anon_sym_alias] = ACTIONS(4430),
    [anon_sym_always_comb] = ACTIONS(4430),
    [anon_sym_always_latch] = ACTIONS(4430),
    [anon_sym_always_ff] = ACTIONS(4430),
    [anon_sym_final] = ACTIONS(4430),
    [anon_sym_global] = ACTIONS(4430),
    [anon_sym_LPAREN_STAR] = ACTIONS(4428),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4428),
    [anon_sym_DOLLARunit] = ACTIONS(4428),
  },
  [4492] = {
    [sym_simple_identifier] = ACTIONS(4726),
    [anon_sym_wire] = ACTIONS(4726),
    [anon_sym_tri] = ACTIONS(4726),
    [anon_sym_tri0] = ACTIONS(4726),
    [anon_sym_tri1] = ACTIONS(4726),
    [anon_sym_wand] = ACTIONS(4726),
    [anon_sym_triand] = ACTIONS(4726),
    [anon_sym_wor] = ACTIONS(4726),
    [anon_sym_trior] = ACTIONS(4726),
    [anon_sym_trireg] = ACTIONS(4726),
    [anon_sym_uwire] = ACTIONS(4726),
    [anon_sym_SEMI] = ACTIONS(4724),
    [anon_sym_COLON] = ACTIONS(10701),
    [anon_sym_extern] = ACTIONS(4726),
    [anon_sym_interface] = ACTIONS(4726),
    [anon_sym_checker] = ACTIONS(4726),
    [anon_sym_virtual] = ACTIONS(4726),
    [anon_sym_class] = ACTIONS(4726),
    [anon_sym_type] = ACTIONS(4726),
    [anon_sym_DOLLARfatal] = ACTIONS(4724),
    [anon_sym_DOLLARerror] = ACTIONS(4724),
    [anon_sym_DOLLARwarning] = ACTIONS(4724),
    [anon_sym_DOLLARinfo] = ACTIONS(4724),
    [anon_sym_default] = ACTIONS(4726),
    [anon_sym_clocking] = ACTIONS(4726),
    [anon_sym_defparam] = ACTIONS(4726),
    [anon_sym_bind] = ACTIONS(4726),
    [anon_sym_rand] = ACTIONS(4726),
    [anon_sym_const] = ACTIONS(4726),
    [anon_sym_function] = ACTIONS(4726),
    [anon_sym_static] = ACTIONS(4726),
    [anon_sym_constraint] = ACTIONS(4726),
    [anon_sym_if] = ACTIONS(4726),
    [anon_sym_else] = ACTIONS(4726),
    [anon_sym_LBRACK] = ACTIONS(4724),
    [anon_sym_localparam] = ACTIONS(4726),
    [anon_sym_parameter] = ACTIONS(4726),
    [anon_sym_var] = ACTIONS(4726),
    [anon_sym_import] = ACTIONS(4726),
    [anon_sym_export] = ACTIONS(4726),
    [anon_sym_genvar] = ACTIONS(4726),
    [anon_sym_interconnect] = ACTIONS(4726),
    [anon_sym_typedef] = ACTIONS(4726),
    [anon_sym_enum] = ACTIONS(4726),
    [anon_sym_struct] = ACTIONS(4726),
    [anon_sym_union] = ACTIONS(4726),
    [anon_sym_nettype] = ACTIONS(4726),
    [anon_sym_automatic] = ACTIONS(4726),
    [anon_sym_string] = ACTIONS(4726),
    [anon_sym_chandle] = ACTIONS(4726),
    [anon_sym_event] = ACTIONS(4726),
    [anon_sym_byte] = ACTIONS(4726),
    [anon_sym_shortint] = ACTIONS(4726),
    [anon_sym_int] = ACTIONS(4726),
    [anon_sym_longint] = ACTIONS(4726),
    [anon_sym_integer] = ACTIONS(4726),
    [anon_sym_time] = ACTIONS(4726),
    [anon_sym_bit] = ACTIONS(4726),
    [anon_sym_logic] = ACTIONS(4726),
    [anon_sym_reg] = ACTIONS(4726),
    [anon_sym_shortreal] = ACTIONS(4726),
    [anon_sym_real] = ACTIONS(4726),
    [anon_sym_realtime] = ACTIONS(4726),
    [anon_sym_supply0] = ACTIONS(4726),
    [anon_sym_supply1] = ACTIONS(4726),
    [anon_sym_signed] = ACTIONS(4726),
    [anon_sym_unsigned] = ACTIONS(4726),
    [anon_sym_task] = ACTIONS(4726),
    [anon_sym_assert] = ACTIONS(4726),
    [anon_sym_property] = ACTIONS(4726),
    [anon_sym_assume] = ACTIONS(4726),
    [anon_sym_cover] = ACTIONS(4726),
    [anon_sym_sequence] = ACTIONS(4726),
    [anon_sym_restrict] = ACTIONS(4726),
    [anon_sym_not] = ACTIONS(4726),
    [anon_sym_or] = ACTIONS(4726),
    [anon_sym_and] = ACTIONS(4726),
    [anon_sym_case] = ACTIONS(4726),
    [anon_sym_always] = ACTIONS(4726),
    [anon_sym_covergroup] = ACTIONS(4726),
    [anon_sym_let] = ACTIONS(4726),
    [anon_sym_pulldown] = ACTIONS(4726),
    [anon_sym_pullup] = ACTIONS(4726),
    [anon_sym_cmos] = ACTIONS(4726),
    [anon_sym_rcmos] = ACTIONS(4726),
    [anon_sym_bufif0] = ACTIONS(4726),
    [anon_sym_bufif1] = ACTIONS(4726),
    [anon_sym_notif0] = ACTIONS(4726),
    [anon_sym_notif1] = ACTIONS(4726),
    [anon_sym_nmos] = ACTIONS(4726),
    [anon_sym_pmos] = ACTIONS(4726),
    [anon_sym_rnmos] = ACTIONS(4726),
    [anon_sym_rpmos] = ACTIONS(4726),
    [anon_sym_nand] = ACTIONS(4726),
    [anon_sym_nor] = ACTIONS(4726),
    [anon_sym_xor] = ACTIONS(4726),
    [anon_sym_xnor] = ACTIONS(4726),
    [anon_sym_buf] = ACTIONS(4726),
    [anon_sym_tranif0] = ACTIONS(4726),
    [anon_sym_tranif1] = ACTIONS(4726),
    [anon_sym_rtranif1] = ACTIONS(4726),
    [anon_sym_rtranif0] = ACTIONS(4726),
    [anon_sym_tran] = ACTIONS(4726),
    [anon_sym_rtran] = ACTIONS(4726),
    [anon_sym_generate] = ACTIONS(4726),
    [anon_sym_endgenerate] = ACTIONS(4726),
    [anon_sym_for] = ACTIONS(4726),
    [anon_sym_initial] = ACTIONS(4726),
    [anon_sym_assign] = ACTIONS(4726),
    [anon_sym_alias] = ACTIONS(4726),
    [anon_sym_always_comb] = ACTIONS(4726),
    [anon_sym_always_latch] = ACTIONS(4726),
    [anon_sym_always_ff] = ACTIONS(4726),
    [anon_sym_final] = ACTIONS(4726),
    [anon_sym_global] = ACTIONS(4726),
    [anon_sym_LPAREN_STAR] = ACTIONS(4724),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4724),
    [anon_sym_DOLLARunit] = ACTIONS(4724),
  },
  [4493] = {
    [sym_simple_identifier] = ACTIONS(4488),
    [anon_sym_wire] = ACTIONS(4488),
    [anon_sym_tri] = ACTIONS(4488),
    [anon_sym_tri0] = ACTIONS(4488),
    [anon_sym_tri1] = ACTIONS(4488),
    [anon_sym_wand] = ACTIONS(4488),
    [anon_sym_triand] = ACTIONS(4488),
    [anon_sym_wor] = ACTIONS(4488),
    [anon_sym_trior] = ACTIONS(4488),
    [anon_sym_trireg] = ACTIONS(4488),
    [anon_sym_uwire] = ACTIONS(4488),
    [anon_sym_SEMI] = ACTIONS(4486),
    [anon_sym_COLON] = ACTIONS(10703),
    [anon_sym_extern] = ACTIONS(4488),
    [anon_sym_interface] = ACTIONS(4488),
    [anon_sym_checker] = ACTIONS(4488),
    [anon_sym_virtual] = ACTIONS(4488),
    [anon_sym_class] = ACTIONS(4488),
    [anon_sym_type] = ACTIONS(4488),
    [anon_sym_DOLLARfatal] = ACTIONS(4486),
    [anon_sym_DOLLARerror] = ACTIONS(4486),
    [anon_sym_DOLLARwarning] = ACTIONS(4486),
    [anon_sym_DOLLARinfo] = ACTIONS(4486),
    [anon_sym_default] = ACTIONS(4488),
    [anon_sym_clocking] = ACTIONS(4488),
    [anon_sym_defparam] = ACTIONS(4488),
    [anon_sym_bind] = ACTIONS(4488),
    [anon_sym_rand] = ACTIONS(4488),
    [anon_sym_const] = ACTIONS(4488),
    [anon_sym_function] = ACTIONS(4488),
    [anon_sym_static] = ACTIONS(4488),
    [anon_sym_constraint] = ACTIONS(4488),
    [anon_sym_if] = ACTIONS(4488),
    [anon_sym_else] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4486),
    [anon_sym_localparam] = ACTIONS(4488),
    [anon_sym_parameter] = ACTIONS(4488),
    [anon_sym_var] = ACTIONS(4488),
    [anon_sym_import] = ACTIONS(4488),
    [anon_sym_export] = ACTIONS(4488),
    [anon_sym_genvar] = ACTIONS(4488),
    [anon_sym_interconnect] = ACTIONS(4488),
    [anon_sym_typedef] = ACTIONS(4488),
    [anon_sym_enum] = ACTIONS(4488),
    [anon_sym_struct] = ACTIONS(4488),
    [anon_sym_union] = ACTIONS(4488),
    [anon_sym_nettype] = ACTIONS(4488),
    [anon_sym_automatic] = ACTIONS(4488),
    [anon_sym_string] = ACTIONS(4488),
    [anon_sym_chandle] = ACTIONS(4488),
    [anon_sym_event] = ACTIONS(4488),
    [anon_sym_byte] = ACTIONS(4488),
    [anon_sym_shortint] = ACTIONS(4488),
    [anon_sym_int] = ACTIONS(4488),
    [anon_sym_longint] = ACTIONS(4488),
    [anon_sym_integer] = ACTIONS(4488),
    [anon_sym_time] = ACTIONS(4488),
    [anon_sym_bit] = ACTIONS(4488),
    [anon_sym_logic] = ACTIONS(4488),
    [anon_sym_reg] = ACTIONS(4488),
    [anon_sym_shortreal] = ACTIONS(4488),
    [anon_sym_real] = ACTIONS(4488),
    [anon_sym_realtime] = ACTIONS(4488),
    [anon_sym_supply0] = ACTIONS(4488),
    [anon_sym_supply1] = ACTIONS(4488),
    [anon_sym_signed] = ACTIONS(4488),
    [anon_sym_unsigned] = ACTIONS(4488),
    [anon_sym_task] = ACTIONS(4488),
    [anon_sym_assert] = ACTIONS(4488),
    [anon_sym_property] = ACTIONS(4488),
    [anon_sym_assume] = ACTIONS(4488),
    [anon_sym_cover] = ACTIONS(4488),
    [anon_sym_sequence] = ACTIONS(4488),
    [anon_sym_restrict] = ACTIONS(4488),
    [anon_sym_not] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_case] = ACTIONS(4488),
    [anon_sym_always] = ACTIONS(4488),
    [anon_sym_covergroup] = ACTIONS(4488),
    [anon_sym_let] = ACTIONS(4488),
    [anon_sym_pulldown] = ACTIONS(4488),
    [anon_sym_pullup] = ACTIONS(4488),
    [anon_sym_cmos] = ACTIONS(4488),
    [anon_sym_rcmos] = ACTIONS(4488),
    [anon_sym_bufif0] = ACTIONS(4488),
    [anon_sym_bufif1] = ACTIONS(4488),
    [anon_sym_notif0] = ACTIONS(4488),
    [anon_sym_notif1] = ACTIONS(4488),
    [anon_sym_nmos] = ACTIONS(4488),
    [anon_sym_pmos] = ACTIONS(4488),
    [anon_sym_rnmos] = ACTIONS(4488),
    [anon_sym_rpmos] = ACTIONS(4488),
    [anon_sym_nand] = ACTIONS(4488),
    [anon_sym_nor] = ACTIONS(4488),
    [anon_sym_xor] = ACTIONS(4488),
    [anon_sym_xnor] = ACTIONS(4488),
    [anon_sym_buf] = ACTIONS(4488),
    [anon_sym_tranif0] = ACTIONS(4488),
    [anon_sym_tranif1] = ACTIONS(4488),
    [anon_sym_rtranif1] = ACTIONS(4488),
    [anon_sym_rtranif0] = ACTIONS(4488),
    [anon_sym_tran] = ACTIONS(4488),
    [anon_sym_rtran] = ACTIONS(4488),
    [anon_sym_generate] = ACTIONS(4488),
    [anon_sym_endgenerate] = ACTIONS(4488),
    [anon_sym_for] = ACTIONS(4488),
    [anon_sym_initial] = ACTIONS(4488),
    [anon_sym_assign] = ACTIONS(4488),
    [anon_sym_alias] = ACTIONS(4488),
    [anon_sym_always_comb] = ACTIONS(4488),
    [anon_sym_always_latch] = ACTIONS(4488),
    [anon_sym_always_ff] = ACTIONS(4488),
    [anon_sym_final] = ACTIONS(4488),
    [anon_sym_global] = ACTIONS(4488),
    [anon_sym_LPAREN_STAR] = ACTIONS(4486),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4486),
    [anon_sym_DOLLARunit] = ACTIONS(4486),
  },
  [4494] = {
    [sym_simple_identifier] = ACTIONS(4738),
    [anon_sym_wire] = ACTIONS(4738),
    [anon_sym_tri] = ACTIONS(4738),
    [anon_sym_tri0] = ACTIONS(4738),
    [anon_sym_tri1] = ACTIONS(4738),
    [anon_sym_wand] = ACTIONS(4738),
    [anon_sym_triand] = ACTIONS(4738),
    [anon_sym_wor] = ACTIONS(4738),
    [anon_sym_trior] = ACTIONS(4738),
    [anon_sym_trireg] = ACTIONS(4738),
    [anon_sym_uwire] = ACTIONS(4738),
    [anon_sym_SEMI] = ACTIONS(4736),
    [anon_sym_COLON] = ACTIONS(10705),
    [anon_sym_extern] = ACTIONS(4738),
    [anon_sym_interface] = ACTIONS(4738),
    [anon_sym_checker] = ACTIONS(4738),
    [anon_sym_virtual] = ACTIONS(4738),
    [anon_sym_class] = ACTIONS(4738),
    [anon_sym_type] = ACTIONS(4738),
    [anon_sym_DOLLARfatal] = ACTIONS(4736),
    [anon_sym_DOLLARerror] = ACTIONS(4736),
    [anon_sym_DOLLARwarning] = ACTIONS(4736),
    [anon_sym_DOLLARinfo] = ACTIONS(4736),
    [anon_sym_default] = ACTIONS(4738),
    [anon_sym_clocking] = ACTIONS(4738),
    [anon_sym_defparam] = ACTIONS(4738),
    [anon_sym_bind] = ACTIONS(4738),
    [anon_sym_rand] = ACTIONS(4738),
    [anon_sym_const] = ACTIONS(4738),
    [anon_sym_function] = ACTIONS(4738),
    [anon_sym_static] = ACTIONS(4738),
    [anon_sym_constraint] = ACTIONS(4738),
    [anon_sym_if] = ACTIONS(4738),
    [anon_sym_else] = ACTIONS(4738),
    [anon_sym_LBRACK] = ACTIONS(4736),
    [anon_sym_localparam] = ACTIONS(4738),
    [anon_sym_parameter] = ACTIONS(4738),
    [anon_sym_var] = ACTIONS(4738),
    [anon_sym_import] = ACTIONS(4738),
    [anon_sym_export] = ACTIONS(4738),
    [anon_sym_genvar] = ACTIONS(4738),
    [anon_sym_interconnect] = ACTIONS(4738),
    [anon_sym_typedef] = ACTIONS(4738),
    [anon_sym_enum] = ACTIONS(4738),
    [anon_sym_struct] = ACTIONS(4738),
    [anon_sym_union] = ACTIONS(4738),
    [anon_sym_nettype] = ACTIONS(4738),
    [anon_sym_automatic] = ACTIONS(4738),
    [anon_sym_string] = ACTIONS(4738),
    [anon_sym_chandle] = ACTIONS(4738),
    [anon_sym_event] = ACTIONS(4738),
    [anon_sym_byte] = ACTIONS(4738),
    [anon_sym_shortint] = ACTIONS(4738),
    [anon_sym_int] = ACTIONS(4738),
    [anon_sym_longint] = ACTIONS(4738),
    [anon_sym_integer] = ACTIONS(4738),
    [anon_sym_time] = ACTIONS(4738),
    [anon_sym_bit] = ACTIONS(4738),
    [anon_sym_logic] = ACTIONS(4738),
    [anon_sym_reg] = ACTIONS(4738),
    [anon_sym_shortreal] = ACTIONS(4738),
    [anon_sym_real] = ACTIONS(4738),
    [anon_sym_realtime] = ACTIONS(4738),
    [anon_sym_supply0] = ACTIONS(4738),
    [anon_sym_supply1] = ACTIONS(4738),
    [anon_sym_signed] = ACTIONS(4738),
    [anon_sym_unsigned] = ACTIONS(4738),
    [anon_sym_task] = ACTIONS(4738),
    [anon_sym_assert] = ACTIONS(4738),
    [anon_sym_property] = ACTIONS(4738),
    [anon_sym_assume] = ACTIONS(4738),
    [anon_sym_cover] = ACTIONS(4738),
    [anon_sym_sequence] = ACTIONS(4738),
    [anon_sym_restrict] = ACTIONS(4738),
    [anon_sym_not] = ACTIONS(4738),
    [anon_sym_or] = ACTIONS(4738),
    [anon_sym_and] = ACTIONS(4738),
    [anon_sym_case] = ACTIONS(4738),
    [anon_sym_always] = ACTIONS(4738),
    [anon_sym_covergroup] = ACTIONS(4738),
    [anon_sym_let] = ACTIONS(4738),
    [anon_sym_pulldown] = ACTIONS(4738),
    [anon_sym_pullup] = ACTIONS(4738),
    [anon_sym_cmos] = ACTIONS(4738),
    [anon_sym_rcmos] = ACTIONS(4738),
    [anon_sym_bufif0] = ACTIONS(4738),
    [anon_sym_bufif1] = ACTIONS(4738),
    [anon_sym_notif0] = ACTIONS(4738),
    [anon_sym_notif1] = ACTIONS(4738),
    [anon_sym_nmos] = ACTIONS(4738),
    [anon_sym_pmos] = ACTIONS(4738),
    [anon_sym_rnmos] = ACTIONS(4738),
    [anon_sym_rpmos] = ACTIONS(4738),
    [anon_sym_nand] = ACTIONS(4738),
    [anon_sym_nor] = ACTIONS(4738),
    [anon_sym_xor] = ACTIONS(4738),
    [anon_sym_xnor] = ACTIONS(4738),
    [anon_sym_buf] = ACTIONS(4738),
    [anon_sym_tranif0] = ACTIONS(4738),
    [anon_sym_tranif1] = ACTIONS(4738),
    [anon_sym_rtranif1] = ACTIONS(4738),
    [anon_sym_rtranif0] = ACTIONS(4738),
    [anon_sym_tran] = ACTIONS(4738),
    [anon_sym_rtran] = ACTIONS(4738),
    [anon_sym_generate] = ACTIONS(4738),
    [anon_sym_endgenerate] = ACTIONS(4738),
    [anon_sym_for] = ACTIONS(4738),
    [anon_sym_initial] = ACTIONS(4738),
    [anon_sym_assign] = ACTIONS(4738),
    [anon_sym_alias] = ACTIONS(4738),
    [anon_sym_always_comb] = ACTIONS(4738),
    [anon_sym_always_latch] = ACTIONS(4738),
    [anon_sym_always_ff] = ACTIONS(4738),
    [anon_sym_final] = ACTIONS(4738),
    [anon_sym_global] = ACTIONS(4738),
    [anon_sym_LPAREN_STAR] = ACTIONS(4736),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4736),
    [anon_sym_DOLLARunit] = ACTIONS(4736),
  },
  [4495] = {
    [sym_simple_identifier] = ACTIONS(4328),
    [anon_sym_wire] = ACTIONS(4328),
    [anon_sym_tri] = ACTIONS(4328),
    [anon_sym_tri0] = ACTIONS(4328),
    [anon_sym_tri1] = ACTIONS(4328),
    [anon_sym_wand] = ACTIONS(4328),
    [anon_sym_triand] = ACTIONS(4328),
    [anon_sym_wor] = ACTIONS(4328),
    [anon_sym_trior] = ACTIONS(4328),
    [anon_sym_trireg] = ACTIONS(4328),
    [anon_sym_uwire] = ACTIONS(4328),
    [anon_sym_SEMI] = ACTIONS(4326),
    [anon_sym_COLON] = ACTIONS(10707),
    [anon_sym_extern] = ACTIONS(4328),
    [anon_sym_interface] = ACTIONS(4328),
    [anon_sym_checker] = ACTIONS(4328),
    [anon_sym_virtual] = ACTIONS(4328),
    [anon_sym_class] = ACTIONS(4328),
    [anon_sym_type] = ACTIONS(4328),
    [anon_sym_DOLLARfatal] = ACTIONS(4326),
    [anon_sym_DOLLARerror] = ACTIONS(4326),
    [anon_sym_DOLLARwarning] = ACTIONS(4326),
    [anon_sym_DOLLARinfo] = ACTIONS(4326),
    [anon_sym_default] = ACTIONS(4328),
    [anon_sym_clocking] = ACTIONS(4328),
    [anon_sym_defparam] = ACTIONS(4328),
    [anon_sym_bind] = ACTIONS(4328),
    [anon_sym_rand] = ACTIONS(4328),
    [anon_sym_const] = ACTIONS(4328),
    [anon_sym_function] = ACTIONS(4328),
    [anon_sym_static] = ACTIONS(4328),
    [anon_sym_constraint] = ACTIONS(4328),
    [anon_sym_if] = ACTIONS(4328),
    [anon_sym_else] = ACTIONS(4328),
    [anon_sym_LBRACK] = ACTIONS(4326),
    [anon_sym_localparam] = ACTIONS(4328),
    [anon_sym_parameter] = ACTIONS(4328),
    [anon_sym_var] = ACTIONS(4328),
    [anon_sym_import] = ACTIONS(4328),
    [anon_sym_export] = ACTIONS(4328),
    [anon_sym_genvar] = ACTIONS(4328),
    [anon_sym_interconnect] = ACTIONS(4328),
    [anon_sym_typedef] = ACTIONS(4328),
    [anon_sym_enum] = ACTIONS(4328),
    [anon_sym_struct] = ACTIONS(4328),
    [anon_sym_union] = ACTIONS(4328),
    [anon_sym_nettype] = ACTIONS(4328),
    [anon_sym_automatic] = ACTIONS(4328),
    [anon_sym_string] = ACTIONS(4328),
    [anon_sym_chandle] = ACTIONS(4328),
    [anon_sym_event] = ACTIONS(4328),
    [anon_sym_byte] = ACTIONS(4328),
    [anon_sym_shortint] = ACTIONS(4328),
    [anon_sym_int] = ACTIONS(4328),
    [anon_sym_longint] = ACTIONS(4328),
    [anon_sym_integer] = ACTIONS(4328),
    [anon_sym_time] = ACTIONS(4328),
    [anon_sym_bit] = ACTIONS(4328),
    [anon_sym_logic] = ACTIONS(4328),
    [anon_sym_reg] = ACTIONS(4328),
    [anon_sym_shortreal] = ACTIONS(4328),
    [anon_sym_real] = ACTIONS(4328),
    [anon_sym_realtime] = ACTIONS(4328),
    [anon_sym_supply0] = ACTIONS(4328),
    [anon_sym_supply1] = ACTIONS(4328),
    [anon_sym_signed] = ACTIONS(4328),
    [anon_sym_unsigned] = ACTIONS(4328),
    [anon_sym_task] = ACTIONS(4328),
    [anon_sym_assert] = ACTIONS(4328),
    [anon_sym_property] = ACTIONS(4328),
    [anon_sym_assume] = ACTIONS(4328),
    [anon_sym_cover] = ACTIONS(4328),
    [anon_sym_sequence] = ACTIONS(4328),
    [anon_sym_restrict] = ACTIONS(4328),
    [anon_sym_not] = ACTIONS(4328),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_and] = ACTIONS(4328),
    [anon_sym_case] = ACTIONS(4328),
    [anon_sym_always] = ACTIONS(4328),
    [anon_sym_covergroup] = ACTIONS(4328),
    [anon_sym_let] = ACTIONS(4328),
    [anon_sym_pulldown] = ACTIONS(4328),
    [anon_sym_pullup] = ACTIONS(4328),
    [anon_sym_cmos] = ACTIONS(4328),
    [anon_sym_rcmos] = ACTIONS(4328),
    [anon_sym_bufif0] = ACTIONS(4328),
    [anon_sym_bufif1] = ACTIONS(4328),
    [anon_sym_notif0] = ACTIONS(4328),
    [anon_sym_notif1] = ACTIONS(4328),
    [anon_sym_nmos] = ACTIONS(4328),
    [anon_sym_pmos] = ACTIONS(4328),
    [anon_sym_rnmos] = ACTIONS(4328),
    [anon_sym_rpmos] = ACTIONS(4328),
    [anon_sym_nand] = ACTIONS(4328),
    [anon_sym_nor] = ACTIONS(4328),
    [anon_sym_xor] = ACTIONS(4328),
    [anon_sym_xnor] = ACTIONS(4328),
    [anon_sym_buf] = ACTIONS(4328),
    [anon_sym_tranif0] = ACTIONS(4328),
    [anon_sym_tranif1] = ACTIONS(4328),
    [anon_sym_rtranif1] = ACTIONS(4328),
    [anon_sym_rtranif0] = ACTIONS(4328),
    [anon_sym_tran] = ACTIONS(4328),
    [anon_sym_rtran] = ACTIONS(4328),
    [anon_sym_generate] = ACTIONS(4328),
    [anon_sym_endgenerate] = ACTIONS(4328),
    [anon_sym_for] = ACTIONS(4328),
    [anon_sym_initial] = ACTIONS(4328),
    [anon_sym_assign] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4328),
    [anon_sym_always_comb] = ACTIONS(4328),
    [anon_sym_always_latch] = ACTIONS(4328),
    [anon_sym_always_ff] = ACTIONS(4328),
    [anon_sym_final] = ACTIONS(4328),
    [anon_sym_global] = ACTIONS(4328),
    [anon_sym_LPAREN_STAR] = ACTIONS(4326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4326),
    [anon_sym_DOLLARunit] = ACTIONS(4326),
  },
  [4496] = {
    [sym_simple_identifier] = ACTIONS(5870),
    [anon_sym_wire] = ACTIONS(5870),
    [anon_sym_tri] = ACTIONS(5870),
    [anon_sym_tri0] = ACTIONS(5870),
    [anon_sym_tri1] = ACTIONS(5870),
    [anon_sym_wand] = ACTIONS(5870),
    [anon_sym_triand] = ACTIONS(5870),
    [anon_sym_wor] = ACTIONS(5870),
    [anon_sym_trior] = ACTIONS(5870),
    [anon_sym_trireg] = ACTIONS(5870),
    [anon_sym_uwire] = ACTIONS(5870),
    [anon_sym_SEMI] = ACTIONS(5872),
    [anon_sym_COLON] = ACTIONS(10709),
    [anon_sym_extern] = ACTIONS(5870),
    [anon_sym_interface] = ACTIONS(5870),
    [anon_sym_checker] = ACTIONS(5870),
    [anon_sym_virtual] = ACTIONS(5870),
    [anon_sym_class] = ACTIONS(5870),
    [anon_sym_type] = ACTIONS(5870),
    [anon_sym_DOLLARfatal] = ACTIONS(5872),
    [anon_sym_DOLLARerror] = ACTIONS(5872),
    [anon_sym_DOLLARwarning] = ACTIONS(5872),
    [anon_sym_DOLLARinfo] = ACTIONS(5872),
    [anon_sym_default] = ACTIONS(5870),
    [anon_sym_clocking] = ACTIONS(5870),
    [anon_sym_defparam] = ACTIONS(5870),
    [anon_sym_bind] = ACTIONS(5870),
    [anon_sym_rand] = ACTIONS(5870),
    [anon_sym_const] = ACTIONS(5870),
    [anon_sym_function] = ACTIONS(5870),
    [anon_sym_static] = ACTIONS(5870),
    [anon_sym_constraint] = ACTIONS(5870),
    [anon_sym_if] = ACTIONS(5870),
    [anon_sym_else] = ACTIONS(5870),
    [anon_sym_LBRACK] = ACTIONS(5872),
    [anon_sym_localparam] = ACTIONS(5870),
    [anon_sym_parameter] = ACTIONS(5870),
    [anon_sym_var] = ACTIONS(5870),
    [anon_sym_import] = ACTIONS(5870),
    [anon_sym_export] = ACTIONS(5870),
    [anon_sym_genvar] = ACTIONS(5870),
    [anon_sym_interconnect] = ACTIONS(5870),
    [anon_sym_typedef] = ACTIONS(5870),
    [anon_sym_enum] = ACTIONS(5870),
    [anon_sym_struct] = ACTIONS(5870),
    [anon_sym_union] = ACTIONS(5870),
    [anon_sym_nettype] = ACTIONS(5870),
    [anon_sym_automatic] = ACTIONS(5870),
    [anon_sym_string] = ACTIONS(5870),
    [anon_sym_chandle] = ACTIONS(5870),
    [anon_sym_event] = ACTIONS(5870),
    [anon_sym_byte] = ACTIONS(5870),
    [anon_sym_shortint] = ACTIONS(5870),
    [anon_sym_int] = ACTIONS(5870),
    [anon_sym_longint] = ACTIONS(5870),
    [anon_sym_integer] = ACTIONS(5870),
    [anon_sym_time] = ACTIONS(5870),
    [anon_sym_bit] = ACTIONS(5870),
    [anon_sym_logic] = ACTIONS(5870),
    [anon_sym_reg] = ACTIONS(5870),
    [anon_sym_shortreal] = ACTIONS(5870),
    [anon_sym_real] = ACTIONS(5870),
    [anon_sym_realtime] = ACTIONS(5870),
    [anon_sym_supply0] = ACTIONS(5870),
    [anon_sym_supply1] = ACTIONS(5870),
    [anon_sym_signed] = ACTIONS(5870),
    [anon_sym_unsigned] = ACTIONS(5870),
    [anon_sym_task] = ACTIONS(5870),
    [anon_sym_assert] = ACTIONS(5870),
    [anon_sym_property] = ACTIONS(5870),
    [anon_sym_assume] = ACTIONS(5870),
    [anon_sym_cover] = ACTIONS(5870),
    [anon_sym_sequence] = ACTIONS(5870),
    [anon_sym_restrict] = ACTIONS(5870),
    [anon_sym_not] = ACTIONS(5870),
    [anon_sym_or] = ACTIONS(5870),
    [anon_sym_and] = ACTIONS(5870),
    [anon_sym_case] = ACTIONS(5870),
    [anon_sym_always] = ACTIONS(5870),
    [anon_sym_covergroup] = ACTIONS(5870),
    [anon_sym_let] = ACTIONS(5870),
    [anon_sym_pulldown] = ACTIONS(5870),
    [anon_sym_pullup] = ACTIONS(5870),
    [anon_sym_cmos] = ACTIONS(5870),
    [anon_sym_rcmos] = ACTIONS(5870),
    [anon_sym_bufif0] = ACTIONS(5870),
    [anon_sym_bufif1] = ACTIONS(5870),
    [anon_sym_notif0] = ACTIONS(5870),
    [anon_sym_notif1] = ACTIONS(5870),
    [anon_sym_nmos] = ACTIONS(5870),
    [anon_sym_pmos] = ACTIONS(5870),
    [anon_sym_rnmos] = ACTIONS(5870),
    [anon_sym_rpmos] = ACTIONS(5870),
    [anon_sym_nand] = ACTIONS(5870),
    [anon_sym_nor] = ACTIONS(5870),
    [anon_sym_xor] = ACTIONS(5870),
    [anon_sym_xnor] = ACTIONS(5870),
    [anon_sym_buf] = ACTIONS(5870),
    [anon_sym_tranif0] = ACTIONS(5870),
    [anon_sym_tranif1] = ACTIONS(5870),
    [anon_sym_rtranif1] = ACTIONS(5870),
    [anon_sym_rtranif0] = ACTIONS(5870),
    [anon_sym_tran] = ACTIONS(5870),
    [anon_sym_rtran] = ACTIONS(5870),
    [anon_sym_generate] = ACTIONS(5870),
    [anon_sym_endgenerate] = ACTIONS(5870),
    [anon_sym_for] = ACTIONS(5870),
    [anon_sym_initial] = ACTIONS(5870),
    [anon_sym_assign] = ACTIONS(5870),
    [anon_sym_alias] = ACTIONS(5870),
    [anon_sym_always_comb] = ACTIONS(5870),
    [anon_sym_always_latch] = ACTIONS(5870),
    [anon_sym_always_ff] = ACTIONS(5870),
    [anon_sym_final] = ACTIONS(5870),
    [anon_sym_global] = ACTIONS(5870),
    [anon_sym_LPAREN_STAR] = ACTIONS(5872),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5872),
    [anon_sym_DOLLARunit] = ACTIONS(5872),
  },
  [4497] = {
    [sym_simple_identifier] = ACTIONS(4466),
    [anon_sym_wire] = ACTIONS(4466),
    [anon_sym_tri] = ACTIONS(4466),
    [anon_sym_tri0] = ACTIONS(4466),
    [anon_sym_tri1] = ACTIONS(4466),
    [anon_sym_wand] = ACTIONS(4466),
    [anon_sym_triand] = ACTIONS(4466),
    [anon_sym_wor] = ACTIONS(4466),
    [anon_sym_trior] = ACTIONS(4466),
    [anon_sym_trireg] = ACTIONS(4466),
    [anon_sym_uwire] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(10711),
    [anon_sym_extern] = ACTIONS(4466),
    [anon_sym_interface] = ACTIONS(4466),
    [anon_sym_checker] = ACTIONS(4466),
    [anon_sym_virtual] = ACTIONS(4466),
    [anon_sym_class] = ACTIONS(4466),
    [anon_sym_type] = ACTIONS(4466),
    [anon_sym_DOLLARfatal] = ACTIONS(4464),
    [anon_sym_DOLLARerror] = ACTIONS(4464),
    [anon_sym_DOLLARwarning] = ACTIONS(4464),
    [anon_sym_DOLLARinfo] = ACTIONS(4464),
    [anon_sym_default] = ACTIONS(4466),
    [anon_sym_clocking] = ACTIONS(4466),
    [anon_sym_defparam] = ACTIONS(4466),
    [anon_sym_bind] = ACTIONS(4466),
    [anon_sym_rand] = ACTIONS(4466),
    [anon_sym_const] = ACTIONS(4466),
    [anon_sym_function] = ACTIONS(4466),
    [anon_sym_static] = ACTIONS(4466),
    [anon_sym_constraint] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_else] = ACTIONS(4466),
    [anon_sym_LBRACK] = ACTIONS(4464),
    [anon_sym_localparam] = ACTIONS(4466),
    [anon_sym_parameter] = ACTIONS(4466),
    [anon_sym_var] = ACTIONS(4466),
    [anon_sym_import] = ACTIONS(4466),
    [anon_sym_export] = ACTIONS(4466),
    [anon_sym_genvar] = ACTIONS(4466),
    [anon_sym_interconnect] = ACTIONS(4466),
    [anon_sym_typedef] = ACTIONS(4466),
    [anon_sym_enum] = ACTIONS(4466),
    [anon_sym_struct] = ACTIONS(4466),
    [anon_sym_union] = ACTIONS(4466),
    [anon_sym_nettype] = ACTIONS(4466),
    [anon_sym_automatic] = ACTIONS(4466),
    [anon_sym_string] = ACTIONS(4466),
    [anon_sym_chandle] = ACTIONS(4466),
    [anon_sym_event] = ACTIONS(4466),
    [anon_sym_byte] = ACTIONS(4466),
    [anon_sym_shortint] = ACTIONS(4466),
    [anon_sym_int] = ACTIONS(4466),
    [anon_sym_longint] = ACTIONS(4466),
    [anon_sym_integer] = ACTIONS(4466),
    [anon_sym_time] = ACTIONS(4466),
    [anon_sym_bit] = ACTIONS(4466),
    [anon_sym_logic] = ACTIONS(4466),
    [anon_sym_reg] = ACTIONS(4466),
    [anon_sym_shortreal] = ACTIONS(4466),
    [anon_sym_real] = ACTIONS(4466),
    [anon_sym_realtime] = ACTIONS(4466),
    [anon_sym_supply0] = ACTIONS(4466),
    [anon_sym_supply1] = ACTIONS(4466),
    [anon_sym_signed] = ACTIONS(4466),
    [anon_sym_unsigned] = ACTIONS(4466),
    [anon_sym_task] = ACTIONS(4466),
    [anon_sym_assert] = ACTIONS(4466),
    [anon_sym_property] = ACTIONS(4466),
    [anon_sym_assume] = ACTIONS(4466),
    [anon_sym_cover] = ACTIONS(4466),
    [anon_sym_sequence] = ACTIONS(4466),
    [anon_sym_restrict] = ACTIONS(4466),
    [anon_sym_not] = ACTIONS(4466),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_and] = ACTIONS(4466),
    [anon_sym_case] = ACTIONS(4466),
    [anon_sym_always] = ACTIONS(4466),
    [anon_sym_covergroup] = ACTIONS(4466),
    [anon_sym_let] = ACTIONS(4466),
    [anon_sym_pulldown] = ACTIONS(4466),
    [anon_sym_pullup] = ACTIONS(4466),
    [anon_sym_cmos] = ACTIONS(4466),
    [anon_sym_rcmos] = ACTIONS(4466),
    [anon_sym_bufif0] = ACTIONS(4466),
    [anon_sym_bufif1] = ACTIONS(4466),
    [anon_sym_notif0] = ACTIONS(4466),
    [anon_sym_notif1] = ACTIONS(4466),
    [anon_sym_nmos] = ACTIONS(4466),
    [anon_sym_pmos] = ACTIONS(4466),
    [anon_sym_rnmos] = ACTIONS(4466),
    [anon_sym_rpmos] = ACTIONS(4466),
    [anon_sym_nand] = ACTIONS(4466),
    [anon_sym_nor] = ACTIONS(4466),
    [anon_sym_xor] = ACTIONS(4466),
    [anon_sym_xnor] = ACTIONS(4466),
    [anon_sym_buf] = ACTIONS(4466),
    [anon_sym_tranif0] = ACTIONS(4466),
    [anon_sym_tranif1] = ACTIONS(4466),
    [anon_sym_rtranif1] = ACTIONS(4466),
    [anon_sym_rtranif0] = ACTIONS(4466),
    [anon_sym_tran] = ACTIONS(4466),
    [anon_sym_rtran] = ACTIONS(4466),
    [anon_sym_generate] = ACTIONS(4466),
    [anon_sym_endgenerate] = ACTIONS(4466),
    [anon_sym_for] = ACTIONS(4466),
    [anon_sym_initial] = ACTIONS(4466),
    [anon_sym_assign] = ACTIONS(4466),
    [anon_sym_alias] = ACTIONS(4466),
    [anon_sym_always_comb] = ACTIONS(4466),
    [anon_sym_always_latch] = ACTIONS(4466),
    [anon_sym_always_ff] = ACTIONS(4466),
    [anon_sym_final] = ACTIONS(4466),
    [anon_sym_global] = ACTIONS(4466),
    [anon_sym_LPAREN_STAR] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4464),
    [anon_sym_DOLLARunit] = ACTIONS(4464),
  },
  [4498] = {
    [sym_simple_identifier] = ACTIONS(4248),
    [anon_sym_wire] = ACTIONS(4248),
    [anon_sym_tri] = ACTIONS(4248),
    [anon_sym_tri0] = ACTIONS(4248),
    [anon_sym_tri1] = ACTIONS(4248),
    [anon_sym_wand] = ACTIONS(4248),
    [anon_sym_triand] = ACTIONS(4248),
    [anon_sym_wor] = ACTIONS(4248),
    [anon_sym_trior] = ACTIONS(4248),
    [anon_sym_trireg] = ACTIONS(4248),
    [anon_sym_uwire] = ACTIONS(4248),
    [anon_sym_SEMI] = ACTIONS(4246),
    [anon_sym_COLON] = ACTIONS(10713),
    [anon_sym_extern] = ACTIONS(4248),
    [anon_sym_interface] = ACTIONS(4248),
    [anon_sym_checker] = ACTIONS(4248),
    [anon_sym_virtual] = ACTIONS(4248),
    [anon_sym_class] = ACTIONS(4248),
    [anon_sym_type] = ACTIONS(4248),
    [anon_sym_DOLLARfatal] = ACTIONS(4246),
    [anon_sym_DOLLARerror] = ACTIONS(4246),
    [anon_sym_DOLLARwarning] = ACTIONS(4246),
    [anon_sym_DOLLARinfo] = ACTIONS(4246),
    [anon_sym_default] = ACTIONS(4248),
    [anon_sym_clocking] = ACTIONS(4248),
    [anon_sym_defparam] = ACTIONS(4248),
    [anon_sym_bind] = ACTIONS(4248),
    [anon_sym_rand] = ACTIONS(4248),
    [anon_sym_const] = ACTIONS(4248),
    [anon_sym_function] = ACTIONS(4248),
    [anon_sym_static] = ACTIONS(4248),
    [anon_sym_constraint] = ACTIONS(4248),
    [anon_sym_if] = ACTIONS(4248),
    [anon_sym_else] = ACTIONS(4248),
    [anon_sym_LBRACK] = ACTIONS(4246),
    [anon_sym_localparam] = ACTIONS(4248),
    [anon_sym_parameter] = ACTIONS(4248),
    [anon_sym_var] = ACTIONS(4248),
    [anon_sym_import] = ACTIONS(4248),
    [anon_sym_export] = ACTIONS(4248),
    [anon_sym_genvar] = ACTIONS(4248),
    [anon_sym_interconnect] = ACTIONS(4248),
    [anon_sym_typedef] = ACTIONS(4248),
    [anon_sym_enum] = ACTIONS(4248),
    [anon_sym_struct] = ACTIONS(4248),
    [anon_sym_union] = ACTIONS(4248),
    [anon_sym_nettype] = ACTIONS(4248),
    [anon_sym_automatic] = ACTIONS(4248),
    [anon_sym_string] = ACTIONS(4248),
    [anon_sym_chandle] = ACTIONS(4248),
    [anon_sym_event] = ACTIONS(4248),
    [anon_sym_byte] = ACTIONS(4248),
    [anon_sym_shortint] = ACTIONS(4248),
    [anon_sym_int] = ACTIONS(4248),
    [anon_sym_longint] = ACTIONS(4248),
    [anon_sym_integer] = ACTIONS(4248),
    [anon_sym_time] = ACTIONS(4248),
    [anon_sym_bit] = ACTIONS(4248),
    [anon_sym_logic] = ACTIONS(4248),
    [anon_sym_reg] = ACTIONS(4248),
    [anon_sym_shortreal] = ACTIONS(4248),
    [anon_sym_real] = ACTIONS(4248),
    [anon_sym_realtime] = ACTIONS(4248),
    [anon_sym_supply0] = ACTIONS(4248),
    [anon_sym_supply1] = ACTIONS(4248),
    [anon_sym_signed] = ACTIONS(4248),
    [anon_sym_unsigned] = ACTIONS(4248),
    [anon_sym_task] = ACTIONS(4248),
    [anon_sym_assert] = ACTIONS(4248),
    [anon_sym_property] = ACTIONS(4248),
    [anon_sym_assume] = ACTIONS(4248),
    [anon_sym_cover] = ACTIONS(4248),
    [anon_sym_sequence] = ACTIONS(4248),
    [anon_sym_restrict] = ACTIONS(4248),
    [anon_sym_not] = ACTIONS(4248),
    [anon_sym_or] = ACTIONS(4248),
    [anon_sym_and] = ACTIONS(4248),
    [anon_sym_case] = ACTIONS(4248),
    [anon_sym_always] = ACTIONS(4248),
    [anon_sym_covergroup] = ACTIONS(4248),
    [anon_sym_end] = ACTIONS(4248),
    [anon_sym_let] = ACTIONS(4248),
    [anon_sym_pulldown] = ACTIONS(4248),
    [anon_sym_pullup] = ACTIONS(4248),
    [anon_sym_cmos] = ACTIONS(4248),
    [anon_sym_rcmos] = ACTIONS(4248),
    [anon_sym_bufif0] = ACTIONS(4248),
    [anon_sym_bufif1] = ACTIONS(4248),
    [anon_sym_notif0] = ACTIONS(4248),
    [anon_sym_notif1] = ACTIONS(4248),
    [anon_sym_nmos] = ACTIONS(4248),
    [anon_sym_pmos] = ACTIONS(4248),
    [anon_sym_rnmos] = ACTIONS(4248),
    [anon_sym_rpmos] = ACTIONS(4248),
    [anon_sym_nand] = ACTIONS(4248),
    [anon_sym_nor] = ACTIONS(4248),
    [anon_sym_xor] = ACTIONS(4248),
    [anon_sym_xnor] = ACTIONS(4248),
    [anon_sym_buf] = ACTIONS(4248),
    [anon_sym_tranif0] = ACTIONS(4248),
    [anon_sym_tranif1] = ACTIONS(4248),
    [anon_sym_rtranif1] = ACTIONS(4248),
    [anon_sym_rtranif0] = ACTIONS(4248),
    [anon_sym_tran] = ACTIONS(4248),
    [anon_sym_rtran] = ACTIONS(4248),
    [anon_sym_generate] = ACTIONS(4248),
    [anon_sym_for] = ACTIONS(4248),
    [anon_sym_initial] = ACTIONS(4248),
    [anon_sym_assign] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4248),
    [anon_sym_always_comb] = ACTIONS(4248),
    [anon_sym_always_latch] = ACTIONS(4248),
    [anon_sym_always_ff] = ACTIONS(4248),
    [anon_sym_final] = ACTIONS(4248),
    [anon_sym_global] = ACTIONS(4248),
    [anon_sym_LPAREN_STAR] = ACTIONS(4246),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4246),
    [anon_sym_DOLLARunit] = ACTIONS(4246),
  },
  [4499] = {
    [sym_simple_identifier] = ACTIONS(4512),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_COLON] = ACTIONS(10715),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_rand] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_endgenerate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [4500] = {
    [sym_simple_identifier] = ACTIONS(4744),
    [anon_sym_wire] = ACTIONS(4744),
    [anon_sym_tri] = ACTIONS(4744),
    [anon_sym_tri0] = ACTIONS(4744),
    [anon_sym_tri1] = ACTIONS(4744),
    [anon_sym_wand] = ACTIONS(4744),
    [anon_sym_triand] = ACTIONS(4744),
    [anon_sym_wor] = ACTIONS(4744),
    [anon_sym_trior] = ACTIONS(4744),
    [anon_sym_trireg] = ACTIONS(4744),
    [anon_sym_uwire] = ACTIONS(4744),
    [anon_sym_SEMI] = ACTIONS(4742),
    [anon_sym_COLON] = ACTIONS(10717),
    [anon_sym_extern] = ACTIONS(4744),
    [anon_sym_interface] = ACTIONS(4744),
    [anon_sym_checker] = ACTIONS(4744),
    [anon_sym_virtual] = ACTIONS(4744),
    [anon_sym_class] = ACTIONS(4744),
    [anon_sym_type] = ACTIONS(4744),
    [anon_sym_DOLLARfatal] = ACTIONS(4742),
    [anon_sym_DOLLARerror] = ACTIONS(4742),
    [anon_sym_DOLLARwarning] = ACTIONS(4742),
    [anon_sym_DOLLARinfo] = ACTIONS(4742),
    [anon_sym_default] = ACTIONS(4744),
    [anon_sym_clocking] = ACTIONS(4744),
    [anon_sym_defparam] = ACTIONS(4744),
    [anon_sym_bind] = ACTIONS(4744),
    [anon_sym_rand] = ACTIONS(4744),
    [anon_sym_const] = ACTIONS(4744),
    [anon_sym_function] = ACTIONS(4744),
    [anon_sym_static] = ACTIONS(4744),
    [anon_sym_constraint] = ACTIONS(4744),
    [anon_sym_if] = ACTIONS(4744),
    [anon_sym_else] = ACTIONS(4744),
    [anon_sym_LBRACK] = ACTIONS(4742),
    [anon_sym_localparam] = ACTIONS(4744),
    [anon_sym_parameter] = ACTIONS(4744),
    [anon_sym_var] = ACTIONS(4744),
    [anon_sym_import] = ACTIONS(4744),
    [anon_sym_export] = ACTIONS(4744),
    [anon_sym_genvar] = ACTIONS(4744),
    [anon_sym_interconnect] = ACTIONS(4744),
    [anon_sym_typedef] = ACTIONS(4744),
    [anon_sym_enum] = ACTIONS(4744),
    [anon_sym_struct] = ACTIONS(4744),
    [anon_sym_union] = ACTIONS(4744),
    [anon_sym_nettype] = ACTIONS(4744),
    [anon_sym_automatic] = ACTIONS(4744),
    [anon_sym_string] = ACTIONS(4744),
    [anon_sym_chandle] = ACTIONS(4744),
    [anon_sym_event] = ACTIONS(4744),
    [anon_sym_byte] = ACTIONS(4744),
    [anon_sym_shortint] = ACTIONS(4744),
    [anon_sym_int] = ACTIONS(4744),
    [anon_sym_longint] = ACTIONS(4744),
    [anon_sym_integer] = ACTIONS(4744),
    [anon_sym_time] = ACTIONS(4744),
    [anon_sym_bit] = ACTIONS(4744),
    [anon_sym_logic] = ACTIONS(4744),
    [anon_sym_reg] = ACTIONS(4744),
    [anon_sym_shortreal] = ACTIONS(4744),
    [anon_sym_real] = ACTIONS(4744),
    [anon_sym_realtime] = ACTIONS(4744),
    [anon_sym_supply0] = ACTIONS(4744),
    [anon_sym_supply1] = ACTIONS(4744),
    [anon_sym_signed] = ACTIONS(4744),
    [anon_sym_unsigned] = ACTIONS(4744),
    [anon_sym_task] = ACTIONS(4744),
    [anon_sym_assert] = ACTIONS(4744),
    [anon_sym_property] = ACTIONS(4744),
    [anon_sym_assume] = ACTIONS(4744),
    [anon_sym_cover] = ACTIONS(4744),
    [anon_sym_sequence] = ACTIONS(4744),
    [anon_sym_restrict] = ACTIONS(4744),
    [anon_sym_not] = ACTIONS(4744),
    [anon_sym_or] = ACTIONS(4744),
    [anon_sym_and] = ACTIONS(4744),
    [anon_sym_case] = ACTIONS(4744),
    [anon_sym_always] = ACTIONS(4744),
    [anon_sym_covergroup] = ACTIONS(4744),
    [anon_sym_end] = ACTIONS(4744),
    [anon_sym_let] = ACTIONS(4744),
    [anon_sym_pulldown] = ACTIONS(4744),
    [anon_sym_pullup] = ACTIONS(4744),
    [anon_sym_cmos] = ACTIONS(4744),
    [anon_sym_rcmos] = ACTIONS(4744),
    [anon_sym_bufif0] = ACTIONS(4744),
    [anon_sym_bufif1] = ACTIONS(4744),
    [anon_sym_notif0] = ACTIONS(4744),
    [anon_sym_notif1] = ACTIONS(4744),
    [anon_sym_nmos] = ACTIONS(4744),
    [anon_sym_pmos] = ACTIONS(4744),
    [anon_sym_rnmos] = ACTIONS(4744),
    [anon_sym_rpmos] = ACTIONS(4744),
    [anon_sym_nand] = ACTIONS(4744),
    [anon_sym_nor] = ACTIONS(4744),
    [anon_sym_xor] = ACTIONS(4744),
    [anon_sym_xnor] = ACTIONS(4744),
    [anon_sym_buf] = ACTIONS(4744),
    [anon_sym_tranif0] = ACTIONS(4744),
    [anon_sym_tranif1] = ACTIONS(4744),
    [anon_sym_rtranif1] = ACTIONS(4744),
    [anon_sym_rtranif0] = ACTIONS(4744),
    [anon_sym_tran] = ACTIONS(4744),
    [anon_sym_rtran] = ACTIONS(4744),
    [anon_sym_generate] = ACTIONS(4744),
    [anon_sym_for] = ACTIONS(4744),
    [anon_sym_initial] = ACTIONS(4744),
    [anon_sym_assign] = ACTIONS(4744),
    [anon_sym_alias] = ACTIONS(4744),
    [anon_sym_always_comb] = ACTIONS(4744),
    [anon_sym_always_latch] = ACTIONS(4744),
    [anon_sym_always_ff] = ACTIONS(4744),
    [anon_sym_final] = ACTIONS(4744),
    [anon_sym_global] = ACTIONS(4744),
    [anon_sym_LPAREN_STAR] = ACTIONS(4742),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4742),
    [anon_sym_DOLLARunit] = ACTIONS(4742),
  },
  [4501] = {
    [sym_simple_identifier] = ACTIONS(4242),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_COLON] = ACTIONS(10719),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_rand] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_endgenerate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [4502] = {
    [sym_simple_identifier] = ACTIONS(4524),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_COLON] = ACTIONS(10721),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_rand] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_endgenerate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [4503] = {
    [sym_simple_identifier] = ACTIONS(4690),
    [anon_sym_wire] = ACTIONS(4690),
    [anon_sym_tri] = ACTIONS(4690),
    [anon_sym_tri0] = ACTIONS(4690),
    [anon_sym_tri1] = ACTIONS(4690),
    [anon_sym_wand] = ACTIONS(4690),
    [anon_sym_triand] = ACTIONS(4690),
    [anon_sym_wor] = ACTIONS(4690),
    [anon_sym_trior] = ACTIONS(4690),
    [anon_sym_trireg] = ACTIONS(4690),
    [anon_sym_uwire] = ACTIONS(4690),
    [anon_sym_SEMI] = ACTIONS(4688),
    [anon_sym_COLON] = ACTIONS(10723),
    [anon_sym_extern] = ACTIONS(4690),
    [anon_sym_interface] = ACTIONS(4690),
    [anon_sym_checker] = ACTIONS(4690),
    [anon_sym_virtual] = ACTIONS(4690),
    [anon_sym_class] = ACTIONS(4690),
    [anon_sym_type] = ACTIONS(4690),
    [anon_sym_DOLLARfatal] = ACTIONS(4688),
    [anon_sym_DOLLARerror] = ACTIONS(4688),
    [anon_sym_DOLLARwarning] = ACTIONS(4688),
    [anon_sym_DOLLARinfo] = ACTIONS(4688),
    [anon_sym_default] = ACTIONS(4690),
    [anon_sym_clocking] = ACTIONS(4690),
    [anon_sym_defparam] = ACTIONS(4690),
    [anon_sym_bind] = ACTIONS(4690),
    [anon_sym_rand] = ACTIONS(4690),
    [anon_sym_const] = ACTIONS(4690),
    [anon_sym_function] = ACTIONS(4690),
    [anon_sym_static] = ACTIONS(4690),
    [anon_sym_constraint] = ACTIONS(4690),
    [anon_sym_if] = ACTIONS(4690),
    [anon_sym_else] = ACTIONS(4690),
    [anon_sym_LBRACK] = ACTIONS(4688),
    [anon_sym_localparam] = ACTIONS(4690),
    [anon_sym_parameter] = ACTIONS(4690),
    [anon_sym_var] = ACTIONS(4690),
    [anon_sym_import] = ACTIONS(4690),
    [anon_sym_export] = ACTIONS(4690),
    [anon_sym_genvar] = ACTIONS(4690),
    [anon_sym_interconnect] = ACTIONS(4690),
    [anon_sym_typedef] = ACTIONS(4690),
    [anon_sym_enum] = ACTIONS(4690),
    [anon_sym_struct] = ACTIONS(4690),
    [anon_sym_union] = ACTIONS(4690),
    [anon_sym_nettype] = ACTIONS(4690),
    [anon_sym_automatic] = ACTIONS(4690),
    [anon_sym_string] = ACTIONS(4690),
    [anon_sym_chandle] = ACTIONS(4690),
    [anon_sym_event] = ACTIONS(4690),
    [anon_sym_byte] = ACTIONS(4690),
    [anon_sym_shortint] = ACTIONS(4690),
    [anon_sym_int] = ACTIONS(4690),
    [anon_sym_longint] = ACTIONS(4690),
    [anon_sym_integer] = ACTIONS(4690),
    [anon_sym_time] = ACTIONS(4690),
    [anon_sym_bit] = ACTIONS(4690),
    [anon_sym_logic] = ACTIONS(4690),
    [anon_sym_reg] = ACTIONS(4690),
    [anon_sym_shortreal] = ACTIONS(4690),
    [anon_sym_real] = ACTIONS(4690),
    [anon_sym_realtime] = ACTIONS(4690),
    [anon_sym_supply0] = ACTIONS(4690),
    [anon_sym_supply1] = ACTIONS(4690),
    [anon_sym_signed] = ACTIONS(4690),
    [anon_sym_unsigned] = ACTIONS(4690),
    [anon_sym_task] = ACTIONS(4690),
    [anon_sym_assert] = ACTIONS(4690),
    [anon_sym_property] = ACTIONS(4690),
    [anon_sym_assume] = ACTIONS(4690),
    [anon_sym_cover] = ACTIONS(4690),
    [anon_sym_sequence] = ACTIONS(4690),
    [anon_sym_restrict] = ACTIONS(4690),
    [anon_sym_not] = ACTIONS(4690),
    [anon_sym_or] = ACTIONS(4690),
    [anon_sym_and] = ACTIONS(4690),
    [anon_sym_case] = ACTIONS(4690),
    [anon_sym_always] = ACTIONS(4690),
    [anon_sym_covergroup] = ACTIONS(4690),
    [anon_sym_let] = ACTIONS(4690),
    [anon_sym_pulldown] = ACTIONS(4690),
    [anon_sym_pullup] = ACTIONS(4690),
    [anon_sym_cmos] = ACTIONS(4690),
    [anon_sym_rcmos] = ACTIONS(4690),
    [anon_sym_bufif0] = ACTIONS(4690),
    [anon_sym_bufif1] = ACTIONS(4690),
    [anon_sym_notif0] = ACTIONS(4690),
    [anon_sym_notif1] = ACTIONS(4690),
    [anon_sym_nmos] = ACTIONS(4690),
    [anon_sym_pmos] = ACTIONS(4690),
    [anon_sym_rnmos] = ACTIONS(4690),
    [anon_sym_rpmos] = ACTIONS(4690),
    [anon_sym_nand] = ACTIONS(4690),
    [anon_sym_nor] = ACTIONS(4690),
    [anon_sym_xor] = ACTIONS(4690),
    [anon_sym_xnor] = ACTIONS(4690),
    [anon_sym_buf] = ACTIONS(4690),
    [anon_sym_tranif0] = ACTIONS(4690),
    [anon_sym_tranif1] = ACTIONS(4690),
    [anon_sym_rtranif1] = ACTIONS(4690),
    [anon_sym_rtranif0] = ACTIONS(4690),
    [anon_sym_tran] = ACTIONS(4690),
    [anon_sym_rtran] = ACTIONS(4690),
    [anon_sym_generate] = ACTIONS(4690),
    [anon_sym_endgenerate] = ACTIONS(4690),
    [anon_sym_for] = ACTIONS(4690),
    [anon_sym_initial] = ACTIONS(4690),
    [anon_sym_assign] = ACTIONS(4690),
    [anon_sym_alias] = ACTIONS(4690),
    [anon_sym_always_comb] = ACTIONS(4690),
    [anon_sym_always_latch] = ACTIONS(4690),
    [anon_sym_always_ff] = ACTIONS(4690),
    [anon_sym_final] = ACTIONS(4690),
    [anon_sym_global] = ACTIONS(4690),
    [anon_sym_LPAREN_STAR] = ACTIONS(4688),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4688),
    [anon_sym_DOLLARunit] = ACTIONS(4688),
  },
  [4504] = {
    [sym_simple_identifier] = ACTIONS(4708),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_COLON] = ACTIONS(10725),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_rand] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_endgenerate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [4505] = {
    [sym_simple_identifier] = ACTIONS(4322),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_COLON] = ACTIONS(10727),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_rand] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_endgenerate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [4506] = {
    [sym_simple_identifier] = ACTIONS(4200),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_COLON] = ACTIONS(10729),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_rand] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_end] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [4507] = {
    [sym_simple_identifier] = ACTIONS(4364),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_COLON] = ACTIONS(10731),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_rand] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_endgenerate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [4508] = {
    [sym_simple_identifier] = ACTIONS(4264),
    [anon_sym_wire] = ACTIONS(4264),
    [anon_sym_tri] = ACTIONS(4264),
    [anon_sym_tri0] = ACTIONS(4264),
    [anon_sym_tri1] = ACTIONS(4264),
    [anon_sym_wand] = ACTIONS(4264),
    [anon_sym_triand] = ACTIONS(4264),
    [anon_sym_wor] = ACTIONS(4264),
    [anon_sym_trior] = ACTIONS(4264),
    [anon_sym_trireg] = ACTIONS(4264),
    [anon_sym_uwire] = ACTIONS(4264),
    [anon_sym_SEMI] = ACTIONS(4262),
    [anon_sym_COLON] = ACTIONS(10733),
    [anon_sym_extern] = ACTIONS(4264),
    [anon_sym_interface] = ACTIONS(4264),
    [anon_sym_checker] = ACTIONS(4264),
    [anon_sym_virtual] = ACTIONS(4264),
    [anon_sym_class] = ACTIONS(4264),
    [anon_sym_type] = ACTIONS(4264),
    [anon_sym_DOLLARfatal] = ACTIONS(4262),
    [anon_sym_DOLLARerror] = ACTIONS(4262),
    [anon_sym_DOLLARwarning] = ACTIONS(4262),
    [anon_sym_DOLLARinfo] = ACTIONS(4262),
    [anon_sym_default] = ACTIONS(4264),
    [anon_sym_clocking] = ACTIONS(4264),
    [anon_sym_defparam] = ACTIONS(4264),
    [anon_sym_bind] = ACTIONS(4264),
    [anon_sym_rand] = ACTIONS(4264),
    [anon_sym_const] = ACTIONS(4264),
    [anon_sym_function] = ACTIONS(4264),
    [anon_sym_static] = ACTIONS(4264),
    [anon_sym_constraint] = ACTIONS(4264),
    [anon_sym_if] = ACTIONS(4264),
    [anon_sym_else] = ACTIONS(4264),
    [anon_sym_LBRACK] = ACTIONS(4262),
    [anon_sym_localparam] = ACTIONS(4264),
    [anon_sym_parameter] = ACTIONS(4264),
    [anon_sym_var] = ACTIONS(4264),
    [anon_sym_import] = ACTIONS(4264),
    [anon_sym_export] = ACTIONS(4264),
    [anon_sym_genvar] = ACTIONS(4264),
    [anon_sym_interconnect] = ACTIONS(4264),
    [anon_sym_typedef] = ACTIONS(4264),
    [anon_sym_enum] = ACTIONS(4264),
    [anon_sym_struct] = ACTIONS(4264),
    [anon_sym_union] = ACTIONS(4264),
    [anon_sym_nettype] = ACTIONS(4264),
    [anon_sym_automatic] = ACTIONS(4264),
    [anon_sym_string] = ACTIONS(4264),
    [anon_sym_chandle] = ACTIONS(4264),
    [anon_sym_event] = ACTIONS(4264),
    [anon_sym_byte] = ACTIONS(4264),
    [anon_sym_shortint] = ACTIONS(4264),
    [anon_sym_int] = ACTIONS(4264),
    [anon_sym_longint] = ACTIONS(4264),
    [anon_sym_integer] = ACTIONS(4264),
    [anon_sym_time] = ACTIONS(4264),
    [anon_sym_bit] = ACTIONS(4264),
    [anon_sym_logic] = ACTIONS(4264),
    [anon_sym_reg] = ACTIONS(4264),
    [anon_sym_shortreal] = ACTIONS(4264),
    [anon_sym_real] = ACTIONS(4264),
    [anon_sym_realtime] = ACTIONS(4264),
    [anon_sym_supply0] = ACTIONS(4264),
    [anon_sym_supply1] = ACTIONS(4264),
    [anon_sym_signed] = ACTIONS(4264),
    [anon_sym_unsigned] = ACTIONS(4264),
    [anon_sym_task] = ACTIONS(4264),
    [anon_sym_assert] = ACTIONS(4264),
    [anon_sym_property] = ACTIONS(4264),
    [anon_sym_assume] = ACTIONS(4264),
    [anon_sym_cover] = ACTIONS(4264),
    [anon_sym_sequence] = ACTIONS(4264),
    [anon_sym_restrict] = ACTIONS(4264),
    [anon_sym_not] = ACTIONS(4264),
    [anon_sym_or] = ACTIONS(4264),
    [anon_sym_and] = ACTIONS(4264),
    [anon_sym_case] = ACTIONS(4264),
    [anon_sym_always] = ACTIONS(4264),
    [anon_sym_covergroup] = ACTIONS(4264),
    [anon_sym_let] = ACTIONS(4264),
    [anon_sym_pulldown] = ACTIONS(4264),
    [anon_sym_pullup] = ACTIONS(4264),
    [anon_sym_cmos] = ACTIONS(4264),
    [anon_sym_rcmos] = ACTIONS(4264),
    [anon_sym_bufif0] = ACTIONS(4264),
    [anon_sym_bufif1] = ACTIONS(4264),
    [anon_sym_notif0] = ACTIONS(4264),
    [anon_sym_notif1] = ACTIONS(4264),
    [anon_sym_nmos] = ACTIONS(4264),
    [anon_sym_pmos] = ACTIONS(4264),
    [anon_sym_rnmos] = ACTIONS(4264),
    [anon_sym_rpmos] = ACTIONS(4264),
    [anon_sym_nand] = ACTIONS(4264),
    [anon_sym_nor] = ACTIONS(4264),
    [anon_sym_xor] = ACTIONS(4264),
    [anon_sym_xnor] = ACTIONS(4264),
    [anon_sym_buf] = ACTIONS(4264),
    [anon_sym_tranif0] = ACTIONS(4264),
    [anon_sym_tranif1] = ACTIONS(4264),
    [anon_sym_rtranif1] = ACTIONS(4264),
    [anon_sym_rtranif0] = ACTIONS(4264),
    [anon_sym_tran] = ACTIONS(4264),
    [anon_sym_rtran] = ACTIONS(4264),
    [anon_sym_generate] = ACTIONS(4264),
    [anon_sym_endgenerate] = ACTIONS(4264),
    [anon_sym_for] = ACTIONS(4264),
    [anon_sym_initial] = ACTIONS(4264),
    [anon_sym_assign] = ACTIONS(4264),
    [anon_sym_alias] = ACTIONS(4264),
    [anon_sym_always_comb] = ACTIONS(4264),
    [anon_sym_always_latch] = ACTIONS(4264),
    [anon_sym_always_ff] = ACTIONS(4264),
    [anon_sym_final] = ACTIONS(4264),
    [anon_sym_global] = ACTIONS(4264),
    [anon_sym_LPAREN_STAR] = ACTIONS(4262),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4262),
    [anon_sym_DOLLARunit] = ACTIONS(4262),
  },
  [4509] = {
    [sym_simple_identifier] = ACTIONS(4304),
    [anon_sym_wire] = ACTIONS(4304),
    [anon_sym_tri] = ACTIONS(4304),
    [anon_sym_tri0] = ACTIONS(4304),
    [anon_sym_tri1] = ACTIONS(4304),
    [anon_sym_wand] = ACTIONS(4304),
    [anon_sym_triand] = ACTIONS(4304),
    [anon_sym_wor] = ACTIONS(4304),
    [anon_sym_trior] = ACTIONS(4304),
    [anon_sym_trireg] = ACTIONS(4304),
    [anon_sym_uwire] = ACTIONS(4304),
    [anon_sym_SEMI] = ACTIONS(4302),
    [anon_sym_COLON] = ACTIONS(10735),
    [anon_sym_extern] = ACTIONS(4304),
    [anon_sym_interface] = ACTIONS(4304),
    [anon_sym_checker] = ACTIONS(4304),
    [anon_sym_virtual] = ACTIONS(4304),
    [anon_sym_class] = ACTIONS(4304),
    [anon_sym_type] = ACTIONS(4304),
    [anon_sym_DOLLARfatal] = ACTIONS(4302),
    [anon_sym_DOLLARerror] = ACTIONS(4302),
    [anon_sym_DOLLARwarning] = ACTIONS(4302),
    [anon_sym_DOLLARinfo] = ACTIONS(4302),
    [anon_sym_default] = ACTIONS(4304),
    [anon_sym_clocking] = ACTIONS(4304),
    [anon_sym_defparam] = ACTIONS(4304),
    [anon_sym_bind] = ACTIONS(4304),
    [anon_sym_rand] = ACTIONS(4304),
    [anon_sym_const] = ACTIONS(4304),
    [anon_sym_function] = ACTIONS(4304),
    [anon_sym_static] = ACTIONS(4304),
    [anon_sym_constraint] = ACTIONS(4304),
    [anon_sym_if] = ACTIONS(4304),
    [anon_sym_else] = ACTIONS(4304),
    [anon_sym_LBRACK] = ACTIONS(4302),
    [anon_sym_localparam] = ACTIONS(4304),
    [anon_sym_parameter] = ACTIONS(4304),
    [anon_sym_var] = ACTIONS(4304),
    [anon_sym_import] = ACTIONS(4304),
    [anon_sym_export] = ACTIONS(4304),
    [anon_sym_genvar] = ACTIONS(4304),
    [anon_sym_interconnect] = ACTIONS(4304),
    [anon_sym_typedef] = ACTIONS(4304),
    [anon_sym_enum] = ACTIONS(4304),
    [anon_sym_struct] = ACTIONS(4304),
    [anon_sym_union] = ACTIONS(4304),
    [anon_sym_nettype] = ACTIONS(4304),
    [anon_sym_automatic] = ACTIONS(4304),
    [anon_sym_string] = ACTIONS(4304),
    [anon_sym_chandle] = ACTIONS(4304),
    [anon_sym_event] = ACTIONS(4304),
    [anon_sym_byte] = ACTIONS(4304),
    [anon_sym_shortint] = ACTIONS(4304),
    [anon_sym_int] = ACTIONS(4304),
    [anon_sym_longint] = ACTIONS(4304),
    [anon_sym_integer] = ACTIONS(4304),
    [anon_sym_time] = ACTIONS(4304),
    [anon_sym_bit] = ACTIONS(4304),
    [anon_sym_logic] = ACTIONS(4304),
    [anon_sym_reg] = ACTIONS(4304),
    [anon_sym_shortreal] = ACTIONS(4304),
    [anon_sym_real] = ACTIONS(4304),
    [anon_sym_realtime] = ACTIONS(4304),
    [anon_sym_supply0] = ACTIONS(4304),
    [anon_sym_supply1] = ACTIONS(4304),
    [anon_sym_signed] = ACTIONS(4304),
    [anon_sym_unsigned] = ACTIONS(4304),
    [anon_sym_task] = ACTIONS(4304),
    [anon_sym_assert] = ACTIONS(4304),
    [anon_sym_property] = ACTIONS(4304),
    [anon_sym_assume] = ACTIONS(4304),
    [anon_sym_cover] = ACTIONS(4304),
    [anon_sym_sequence] = ACTIONS(4304),
    [anon_sym_restrict] = ACTIONS(4304),
    [anon_sym_not] = ACTIONS(4304),
    [anon_sym_or] = ACTIONS(4304),
    [anon_sym_and] = ACTIONS(4304),
    [anon_sym_case] = ACTIONS(4304),
    [anon_sym_always] = ACTIONS(4304),
    [anon_sym_covergroup] = ACTIONS(4304),
    [anon_sym_let] = ACTIONS(4304),
    [anon_sym_pulldown] = ACTIONS(4304),
    [anon_sym_pullup] = ACTIONS(4304),
    [anon_sym_cmos] = ACTIONS(4304),
    [anon_sym_rcmos] = ACTIONS(4304),
    [anon_sym_bufif0] = ACTIONS(4304),
    [anon_sym_bufif1] = ACTIONS(4304),
    [anon_sym_notif0] = ACTIONS(4304),
    [anon_sym_notif1] = ACTIONS(4304),
    [anon_sym_nmos] = ACTIONS(4304),
    [anon_sym_pmos] = ACTIONS(4304),
    [anon_sym_rnmos] = ACTIONS(4304),
    [anon_sym_rpmos] = ACTIONS(4304),
    [anon_sym_nand] = ACTIONS(4304),
    [anon_sym_nor] = ACTIONS(4304),
    [anon_sym_xor] = ACTIONS(4304),
    [anon_sym_xnor] = ACTIONS(4304),
    [anon_sym_buf] = ACTIONS(4304),
    [anon_sym_tranif0] = ACTIONS(4304),
    [anon_sym_tranif1] = ACTIONS(4304),
    [anon_sym_rtranif1] = ACTIONS(4304),
    [anon_sym_rtranif0] = ACTIONS(4304),
    [anon_sym_tran] = ACTIONS(4304),
    [anon_sym_rtran] = ACTIONS(4304),
    [anon_sym_generate] = ACTIONS(4304),
    [anon_sym_endgenerate] = ACTIONS(4304),
    [anon_sym_for] = ACTIONS(4304),
    [anon_sym_initial] = ACTIONS(4304),
    [anon_sym_assign] = ACTIONS(4304),
    [anon_sym_alias] = ACTIONS(4304),
    [anon_sym_always_comb] = ACTIONS(4304),
    [anon_sym_always_latch] = ACTIONS(4304),
    [anon_sym_always_ff] = ACTIONS(4304),
    [anon_sym_final] = ACTIONS(4304),
    [anon_sym_global] = ACTIONS(4304),
    [anon_sym_LPAREN_STAR] = ACTIONS(4302),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4302),
    [anon_sym_DOLLARunit] = ACTIONS(4302),
  },
  [4510] = {
    [sym_simple_identifier] = ACTIONS(4132),
    [anon_sym_wire] = ACTIONS(4132),
    [anon_sym_tri] = ACTIONS(4132),
    [anon_sym_tri0] = ACTIONS(4132),
    [anon_sym_tri1] = ACTIONS(4132),
    [anon_sym_wand] = ACTIONS(4132),
    [anon_sym_triand] = ACTIONS(4132),
    [anon_sym_wor] = ACTIONS(4132),
    [anon_sym_trior] = ACTIONS(4132),
    [anon_sym_trireg] = ACTIONS(4132),
    [anon_sym_uwire] = ACTIONS(4132),
    [anon_sym_SEMI] = ACTIONS(4130),
    [anon_sym_COLON] = ACTIONS(10737),
    [anon_sym_extern] = ACTIONS(4132),
    [anon_sym_interface] = ACTIONS(4132),
    [anon_sym_checker] = ACTIONS(4132),
    [anon_sym_virtual] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4132),
    [anon_sym_type] = ACTIONS(4132),
    [anon_sym_DOLLARfatal] = ACTIONS(4130),
    [anon_sym_DOLLARerror] = ACTIONS(4130),
    [anon_sym_DOLLARwarning] = ACTIONS(4130),
    [anon_sym_DOLLARinfo] = ACTIONS(4130),
    [anon_sym_default] = ACTIONS(4132),
    [anon_sym_clocking] = ACTIONS(4132),
    [anon_sym_defparam] = ACTIONS(4132),
    [anon_sym_bind] = ACTIONS(4132),
    [anon_sym_rand] = ACTIONS(4132),
    [anon_sym_const] = ACTIONS(4132),
    [anon_sym_function] = ACTIONS(4132),
    [anon_sym_static] = ACTIONS(4132),
    [anon_sym_constraint] = ACTIONS(4132),
    [anon_sym_if] = ACTIONS(4132),
    [anon_sym_else] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4130),
    [anon_sym_localparam] = ACTIONS(4132),
    [anon_sym_parameter] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4132),
    [anon_sym_import] = ACTIONS(4132),
    [anon_sym_export] = ACTIONS(4132),
    [anon_sym_genvar] = ACTIONS(4132),
    [anon_sym_interconnect] = ACTIONS(4132),
    [anon_sym_typedef] = ACTIONS(4132),
    [anon_sym_enum] = ACTIONS(4132),
    [anon_sym_struct] = ACTIONS(4132),
    [anon_sym_union] = ACTIONS(4132),
    [anon_sym_nettype] = ACTIONS(4132),
    [anon_sym_automatic] = ACTIONS(4132),
    [anon_sym_string] = ACTIONS(4132),
    [anon_sym_chandle] = ACTIONS(4132),
    [anon_sym_event] = ACTIONS(4132),
    [anon_sym_byte] = ACTIONS(4132),
    [anon_sym_shortint] = ACTIONS(4132),
    [anon_sym_int] = ACTIONS(4132),
    [anon_sym_longint] = ACTIONS(4132),
    [anon_sym_integer] = ACTIONS(4132),
    [anon_sym_time] = ACTIONS(4132),
    [anon_sym_bit] = ACTIONS(4132),
    [anon_sym_logic] = ACTIONS(4132),
    [anon_sym_reg] = ACTIONS(4132),
    [anon_sym_shortreal] = ACTIONS(4132),
    [anon_sym_real] = ACTIONS(4132),
    [anon_sym_realtime] = ACTIONS(4132),
    [anon_sym_supply0] = ACTIONS(4132),
    [anon_sym_supply1] = ACTIONS(4132),
    [anon_sym_signed] = ACTIONS(4132),
    [anon_sym_unsigned] = ACTIONS(4132),
    [anon_sym_task] = ACTIONS(4132),
    [anon_sym_assert] = ACTIONS(4132),
    [anon_sym_property] = ACTIONS(4132),
    [anon_sym_assume] = ACTIONS(4132),
    [anon_sym_cover] = ACTIONS(4132),
    [anon_sym_sequence] = ACTIONS(4132),
    [anon_sym_restrict] = ACTIONS(4132),
    [anon_sym_not] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_case] = ACTIONS(4132),
    [anon_sym_always] = ACTIONS(4132),
    [anon_sym_covergroup] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_pulldown] = ACTIONS(4132),
    [anon_sym_pullup] = ACTIONS(4132),
    [anon_sym_cmos] = ACTIONS(4132),
    [anon_sym_rcmos] = ACTIONS(4132),
    [anon_sym_bufif0] = ACTIONS(4132),
    [anon_sym_bufif1] = ACTIONS(4132),
    [anon_sym_notif0] = ACTIONS(4132),
    [anon_sym_notif1] = ACTIONS(4132),
    [anon_sym_nmos] = ACTIONS(4132),
    [anon_sym_pmos] = ACTIONS(4132),
    [anon_sym_rnmos] = ACTIONS(4132),
    [anon_sym_rpmos] = ACTIONS(4132),
    [anon_sym_nand] = ACTIONS(4132),
    [anon_sym_nor] = ACTIONS(4132),
    [anon_sym_xor] = ACTIONS(4132),
    [anon_sym_xnor] = ACTIONS(4132),
    [anon_sym_buf] = ACTIONS(4132),
    [anon_sym_tranif0] = ACTIONS(4132),
    [anon_sym_tranif1] = ACTIONS(4132),
    [anon_sym_rtranif1] = ACTIONS(4132),
    [anon_sym_rtranif0] = ACTIONS(4132),
    [anon_sym_tran] = ACTIONS(4132),
    [anon_sym_rtran] = ACTIONS(4132),
    [anon_sym_generate] = ACTIONS(4132),
    [anon_sym_endgenerate] = ACTIONS(4132),
    [anon_sym_for] = ACTIONS(4132),
    [anon_sym_initial] = ACTIONS(4132),
    [anon_sym_assign] = ACTIONS(4132),
    [anon_sym_alias] = ACTIONS(4132),
    [anon_sym_always_comb] = ACTIONS(4132),
    [anon_sym_always_latch] = ACTIONS(4132),
    [anon_sym_always_ff] = ACTIONS(4132),
    [anon_sym_final] = ACTIONS(4132),
    [anon_sym_global] = ACTIONS(4132),
    [anon_sym_LPAREN_STAR] = ACTIONS(4130),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4130),
    [anon_sym_DOLLARunit] = ACTIONS(4130),
  },
  [4511] = {
    [sym_simple_identifier] = ACTIONS(4560),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_COLON] = ACTIONS(10739),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_rand] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_endgenerate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [4512] = {
    [sym_simple_identifier] = ACTIONS(4652),
    [anon_sym_wire] = ACTIONS(4652),
    [anon_sym_tri] = ACTIONS(4652),
    [anon_sym_tri0] = ACTIONS(4652),
    [anon_sym_tri1] = ACTIONS(4652),
    [anon_sym_wand] = ACTIONS(4652),
    [anon_sym_triand] = ACTIONS(4652),
    [anon_sym_wor] = ACTIONS(4652),
    [anon_sym_trior] = ACTIONS(4652),
    [anon_sym_trireg] = ACTIONS(4652),
    [anon_sym_uwire] = ACTIONS(4652),
    [anon_sym_SEMI] = ACTIONS(4650),
    [anon_sym_COLON] = ACTIONS(10741),
    [anon_sym_extern] = ACTIONS(4652),
    [anon_sym_interface] = ACTIONS(4652),
    [anon_sym_checker] = ACTIONS(4652),
    [anon_sym_virtual] = ACTIONS(4652),
    [anon_sym_class] = ACTIONS(4652),
    [anon_sym_type] = ACTIONS(4652),
    [anon_sym_DOLLARfatal] = ACTIONS(4650),
    [anon_sym_DOLLARerror] = ACTIONS(4650),
    [anon_sym_DOLLARwarning] = ACTIONS(4650),
    [anon_sym_DOLLARinfo] = ACTIONS(4650),
    [anon_sym_default] = ACTIONS(4652),
    [anon_sym_clocking] = ACTIONS(4652),
    [anon_sym_defparam] = ACTIONS(4652),
    [anon_sym_bind] = ACTIONS(4652),
    [anon_sym_rand] = ACTIONS(4652),
    [anon_sym_const] = ACTIONS(4652),
    [anon_sym_function] = ACTIONS(4652),
    [anon_sym_static] = ACTIONS(4652),
    [anon_sym_constraint] = ACTIONS(4652),
    [anon_sym_if] = ACTIONS(4652),
    [anon_sym_else] = ACTIONS(4652),
    [anon_sym_LBRACK] = ACTIONS(4650),
    [anon_sym_localparam] = ACTIONS(4652),
    [anon_sym_parameter] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4652),
    [anon_sym_import] = ACTIONS(4652),
    [anon_sym_export] = ACTIONS(4652),
    [anon_sym_genvar] = ACTIONS(4652),
    [anon_sym_interconnect] = ACTIONS(4652),
    [anon_sym_typedef] = ACTIONS(4652),
    [anon_sym_enum] = ACTIONS(4652),
    [anon_sym_struct] = ACTIONS(4652),
    [anon_sym_union] = ACTIONS(4652),
    [anon_sym_nettype] = ACTIONS(4652),
    [anon_sym_automatic] = ACTIONS(4652),
    [anon_sym_string] = ACTIONS(4652),
    [anon_sym_chandle] = ACTIONS(4652),
    [anon_sym_event] = ACTIONS(4652),
    [anon_sym_byte] = ACTIONS(4652),
    [anon_sym_shortint] = ACTIONS(4652),
    [anon_sym_int] = ACTIONS(4652),
    [anon_sym_longint] = ACTIONS(4652),
    [anon_sym_integer] = ACTIONS(4652),
    [anon_sym_time] = ACTIONS(4652),
    [anon_sym_bit] = ACTIONS(4652),
    [anon_sym_logic] = ACTIONS(4652),
    [anon_sym_reg] = ACTIONS(4652),
    [anon_sym_shortreal] = ACTIONS(4652),
    [anon_sym_real] = ACTIONS(4652),
    [anon_sym_realtime] = ACTIONS(4652),
    [anon_sym_supply0] = ACTIONS(4652),
    [anon_sym_supply1] = ACTIONS(4652),
    [anon_sym_signed] = ACTIONS(4652),
    [anon_sym_unsigned] = ACTIONS(4652),
    [anon_sym_task] = ACTIONS(4652),
    [anon_sym_assert] = ACTIONS(4652),
    [anon_sym_property] = ACTIONS(4652),
    [anon_sym_assume] = ACTIONS(4652),
    [anon_sym_cover] = ACTIONS(4652),
    [anon_sym_sequence] = ACTIONS(4652),
    [anon_sym_restrict] = ACTIONS(4652),
    [anon_sym_not] = ACTIONS(4652),
    [anon_sym_or] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4652),
    [anon_sym_case] = ACTIONS(4652),
    [anon_sym_always] = ACTIONS(4652),
    [anon_sym_covergroup] = ACTIONS(4652),
    [anon_sym_let] = ACTIONS(4652),
    [anon_sym_pulldown] = ACTIONS(4652),
    [anon_sym_pullup] = ACTIONS(4652),
    [anon_sym_cmos] = ACTIONS(4652),
    [anon_sym_rcmos] = ACTIONS(4652),
    [anon_sym_bufif0] = ACTIONS(4652),
    [anon_sym_bufif1] = ACTIONS(4652),
    [anon_sym_notif0] = ACTIONS(4652),
    [anon_sym_notif1] = ACTIONS(4652),
    [anon_sym_nmos] = ACTIONS(4652),
    [anon_sym_pmos] = ACTIONS(4652),
    [anon_sym_rnmos] = ACTIONS(4652),
    [anon_sym_rpmos] = ACTIONS(4652),
    [anon_sym_nand] = ACTIONS(4652),
    [anon_sym_nor] = ACTIONS(4652),
    [anon_sym_xor] = ACTIONS(4652),
    [anon_sym_xnor] = ACTIONS(4652),
    [anon_sym_buf] = ACTIONS(4652),
    [anon_sym_tranif0] = ACTIONS(4652),
    [anon_sym_tranif1] = ACTIONS(4652),
    [anon_sym_rtranif1] = ACTIONS(4652),
    [anon_sym_rtranif0] = ACTIONS(4652),
    [anon_sym_tran] = ACTIONS(4652),
    [anon_sym_rtran] = ACTIONS(4652),
    [anon_sym_generate] = ACTIONS(4652),
    [anon_sym_endgenerate] = ACTIONS(4652),
    [anon_sym_for] = ACTIONS(4652),
    [anon_sym_initial] = ACTIONS(4652),
    [anon_sym_assign] = ACTIONS(4652),
    [anon_sym_alias] = ACTIONS(4652),
    [anon_sym_always_comb] = ACTIONS(4652),
    [anon_sym_always_latch] = ACTIONS(4652),
    [anon_sym_always_ff] = ACTIONS(4652),
    [anon_sym_final] = ACTIONS(4652),
    [anon_sym_global] = ACTIONS(4652),
    [anon_sym_LPAREN_STAR] = ACTIONS(4650),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4650),
    [anon_sym_DOLLARunit] = ACTIONS(4650),
  },
  [4513] = {
    [sym_simple_identifier] = ACTIONS(4750),
    [anon_sym_wire] = ACTIONS(4750),
    [anon_sym_tri] = ACTIONS(4750),
    [anon_sym_tri0] = ACTIONS(4750),
    [anon_sym_tri1] = ACTIONS(4750),
    [anon_sym_wand] = ACTIONS(4750),
    [anon_sym_triand] = ACTIONS(4750),
    [anon_sym_wor] = ACTIONS(4750),
    [anon_sym_trior] = ACTIONS(4750),
    [anon_sym_trireg] = ACTIONS(4750),
    [anon_sym_uwire] = ACTIONS(4750),
    [anon_sym_SEMI] = ACTIONS(4748),
    [anon_sym_COLON] = ACTIONS(10743),
    [anon_sym_extern] = ACTIONS(4750),
    [anon_sym_interface] = ACTIONS(4750),
    [anon_sym_checker] = ACTIONS(4750),
    [anon_sym_virtual] = ACTIONS(4750),
    [anon_sym_class] = ACTIONS(4750),
    [anon_sym_type] = ACTIONS(4750),
    [anon_sym_DOLLARfatal] = ACTIONS(4748),
    [anon_sym_DOLLARerror] = ACTIONS(4748),
    [anon_sym_DOLLARwarning] = ACTIONS(4748),
    [anon_sym_DOLLARinfo] = ACTIONS(4748),
    [anon_sym_default] = ACTIONS(4750),
    [anon_sym_clocking] = ACTIONS(4750),
    [anon_sym_defparam] = ACTIONS(4750),
    [anon_sym_bind] = ACTIONS(4750),
    [anon_sym_rand] = ACTIONS(4750),
    [anon_sym_const] = ACTIONS(4750),
    [anon_sym_function] = ACTIONS(4750),
    [anon_sym_static] = ACTIONS(4750),
    [anon_sym_constraint] = ACTIONS(4750),
    [anon_sym_if] = ACTIONS(4750),
    [anon_sym_else] = ACTIONS(4750),
    [anon_sym_LBRACK] = ACTIONS(4748),
    [anon_sym_localparam] = ACTIONS(4750),
    [anon_sym_parameter] = ACTIONS(4750),
    [anon_sym_var] = ACTIONS(4750),
    [anon_sym_import] = ACTIONS(4750),
    [anon_sym_export] = ACTIONS(4750),
    [anon_sym_genvar] = ACTIONS(4750),
    [anon_sym_interconnect] = ACTIONS(4750),
    [anon_sym_typedef] = ACTIONS(4750),
    [anon_sym_enum] = ACTIONS(4750),
    [anon_sym_struct] = ACTIONS(4750),
    [anon_sym_union] = ACTIONS(4750),
    [anon_sym_nettype] = ACTIONS(4750),
    [anon_sym_automatic] = ACTIONS(4750),
    [anon_sym_string] = ACTIONS(4750),
    [anon_sym_chandle] = ACTIONS(4750),
    [anon_sym_event] = ACTIONS(4750),
    [anon_sym_byte] = ACTIONS(4750),
    [anon_sym_shortint] = ACTIONS(4750),
    [anon_sym_int] = ACTIONS(4750),
    [anon_sym_longint] = ACTIONS(4750),
    [anon_sym_integer] = ACTIONS(4750),
    [anon_sym_time] = ACTIONS(4750),
    [anon_sym_bit] = ACTIONS(4750),
    [anon_sym_logic] = ACTIONS(4750),
    [anon_sym_reg] = ACTIONS(4750),
    [anon_sym_shortreal] = ACTIONS(4750),
    [anon_sym_real] = ACTIONS(4750),
    [anon_sym_realtime] = ACTIONS(4750),
    [anon_sym_supply0] = ACTIONS(4750),
    [anon_sym_supply1] = ACTIONS(4750),
    [anon_sym_signed] = ACTIONS(4750),
    [anon_sym_unsigned] = ACTIONS(4750),
    [anon_sym_task] = ACTIONS(4750),
    [anon_sym_assert] = ACTIONS(4750),
    [anon_sym_property] = ACTIONS(4750),
    [anon_sym_assume] = ACTIONS(4750),
    [anon_sym_cover] = ACTIONS(4750),
    [anon_sym_sequence] = ACTIONS(4750),
    [anon_sym_restrict] = ACTIONS(4750),
    [anon_sym_not] = ACTIONS(4750),
    [anon_sym_or] = ACTIONS(4750),
    [anon_sym_and] = ACTIONS(4750),
    [anon_sym_case] = ACTIONS(4750),
    [anon_sym_always] = ACTIONS(4750),
    [anon_sym_covergroup] = ACTIONS(4750),
    [anon_sym_end] = ACTIONS(4750),
    [anon_sym_let] = ACTIONS(4750),
    [anon_sym_pulldown] = ACTIONS(4750),
    [anon_sym_pullup] = ACTIONS(4750),
    [anon_sym_cmos] = ACTIONS(4750),
    [anon_sym_rcmos] = ACTIONS(4750),
    [anon_sym_bufif0] = ACTIONS(4750),
    [anon_sym_bufif1] = ACTIONS(4750),
    [anon_sym_notif0] = ACTIONS(4750),
    [anon_sym_notif1] = ACTIONS(4750),
    [anon_sym_nmos] = ACTIONS(4750),
    [anon_sym_pmos] = ACTIONS(4750),
    [anon_sym_rnmos] = ACTIONS(4750),
    [anon_sym_rpmos] = ACTIONS(4750),
    [anon_sym_nand] = ACTIONS(4750),
    [anon_sym_nor] = ACTIONS(4750),
    [anon_sym_xor] = ACTIONS(4750),
    [anon_sym_xnor] = ACTIONS(4750),
    [anon_sym_buf] = ACTIONS(4750),
    [anon_sym_tranif0] = ACTIONS(4750),
    [anon_sym_tranif1] = ACTIONS(4750),
    [anon_sym_rtranif1] = ACTIONS(4750),
    [anon_sym_rtranif0] = ACTIONS(4750),
    [anon_sym_tran] = ACTIONS(4750),
    [anon_sym_rtran] = ACTIONS(4750),
    [anon_sym_generate] = ACTIONS(4750),
    [anon_sym_for] = ACTIONS(4750),
    [anon_sym_initial] = ACTIONS(4750),
    [anon_sym_assign] = ACTIONS(4750),
    [anon_sym_alias] = ACTIONS(4750),
    [anon_sym_always_comb] = ACTIONS(4750),
    [anon_sym_always_latch] = ACTIONS(4750),
    [anon_sym_always_ff] = ACTIONS(4750),
    [anon_sym_final] = ACTIONS(4750),
    [anon_sym_global] = ACTIONS(4750),
    [anon_sym_LPAREN_STAR] = ACTIONS(4748),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4748),
    [anon_sym_DOLLARunit] = ACTIONS(4748),
  },
  [4514] = {
    [sym_simple_identifier] = ACTIONS(4472),
    [anon_sym_wire] = ACTIONS(4472),
    [anon_sym_tri] = ACTIONS(4472),
    [anon_sym_tri0] = ACTIONS(4472),
    [anon_sym_tri1] = ACTIONS(4472),
    [anon_sym_wand] = ACTIONS(4472),
    [anon_sym_triand] = ACTIONS(4472),
    [anon_sym_wor] = ACTIONS(4472),
    [anon_sym_trior] = ACTIONS(4472),
    [anon_sym_trireg] = ACTIONS(4472),
    [anon_sym_uwire] = ACTIONS(4472),
    [anon_sym_SEMI] = ACTIONS(4470),
    [anon_sym_COLON] = ACTIONS(10745),
    [anon_sym_extern] = ACTIONS(4472),
    [anon_sym_interface] = ACTIONS(4472),
    [anon_sym_checker] = ACTIONS(4472),
    [anon_sym_virtual] = ACTIONS(4472),
    [anon_sym_class] = ACTIONS(4472),
    [anon_sym_type] = ACTIONS(4472),
    [anon_sym_DOLLARfatal] = ACTIONS(4470),
    [anon_sym_DOLLARerror] = ACTIONS(4470),
    [anon_sym_DOLLARwarning] = ACTIONS(4470),
    [anon_sym_DOLLARinfo] = ACTIONS(4470),
    [anon_sym_default] = ACTIONS(4472),
    [anon_sym_clocking] = ACTIONS(4472),
    [anon_sym_defparam] = ACTIONS(4472),
    [anon_sym_bind] = ACTIONS(4472),
    [anon_sym_rand] = ACTIONS(4472),
    [anon_sym_const] = ACTIONS(4472),
    [anon_sym_function] = ACTIONS(4472),
    [anon_sym_static] = ACTIONS(4472),
    [anon_sym_constraint] = ACTIONS(4472),
    [anon_sym_if] = ACTIONS(4472),
    [anon_sym_else] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4470),
    [anon_sym_localparam] = ACTIONS(4472),
    [anon_sym_parameter] = ACTIONS(4472),
    [anon_sym_var] = ACTIONS(4472),
    [anon_sym_import] = ACTIONS(4472),
    [anon_sym_export] = ACTIONS(4472),
    [anon_sym_genvar] = ACTIONS(4472),
    [anon_sym_interconnect] = ACTIONS(4472),
    [anon_sym_typedef] = ACTIONS(4472),
    [anon_sym_enum] = ACTIONS(4472),
    [anon_sym_struct] = ACTIONS(4472),
    [anon_sym_union] = ACTIONS(4472),
    [anon_sym_nettype] = ACTIONS(4472),
    [anon_sym_automatic] = ACTIONS(4472),
    [anon_sym_string] = ACTIONS(4472),
    [anon_sym_chandle] = ACTIONS(4472),
    [anon_sym_event] = ACTIONS(4472),
    [anon_sym_byte] = ACTIONS(4472),
    [anon_sym_shortint] = ACTIONS(4472),
    [anon_sym_int] = ACTIONS(4472),
    [anon_sym_longint] = ACTIONS(4472),
    [anon_sym_integer] = ACTIONS(4472),
    [anon_sym_time] = ACTIONS(4472),
    [anon_sym_bit] = ACTIONS(4472),
    [anon_sym_logic] = ACTIONS(4472),
    [anon_sym_reg] = ACTIONS(4472),
    [anon_sym_shortreal] = ACTIONS(4472),
    [anon_sym_real] = ACTIONS(4472),
    [anon_sym_realtime] = ACTIONS(4472),
    [anon_sym_supply0] = ACTIONS(4472),
    [anon_sym_supply1] = ACTIONS(4472),
    [anon_sym_signed] = ACTIONS(4472),
    [anon_sym_unsigned] = ACTIONS(4472),
    [anon_sym_task] = ACTIONS(4472),
    [anon_sym_assert] = ACTIONS(4472),
    [anon_sym_property] = ACTIONS(4472),
    [anon_sym_assume] = ACTIONS(4472),
    [anon_sym_cover] = ACTIONS(4472),
    [anon_sym_sequence] = ACTIONS(4472),
    [anon_sym_restrict] = ACTIONS(4472),
    [anon_sym_not] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_case] = ACTIONS(4472),
    [anon_sym_always] = ACTIONS(4472),
    [anon_sym_covergroup] = ACTIONS(4472),
    [anon_sym_let] = ACTIONS(4472),
    [anon_sym_pulldown] = ACTIONS(4472),
    [anon_sym_pullup] = ACTIONS(4472),
    [anon_sym_cmos] = ACTIONS(4472),
    [anon_sym_rcmos] = ACTIONS(4472),
    [anon_sym_bufif0] = ACTIONS(4472),
    [anon_sym_bufif1] = ACTIONS(4472),
    [anon_sym_notif0] = ACTIONS(4472),
    [anon_sym_notif1] = ACTIONS(4472),
    [anon_sym_nmos] = ACTIONS(4472),
    [anon_sym_pmos] = ACTIONS(4472),
    [anon_sym_rnmos] = ACTIONS(4472),
    [anon_sym_rpmos] = ACTIONS(4472),
    [anon_sym_nand] = ACTIONS(4472),
    [anon_sym_nor] = ACTIONS(4472),
    [anon_sym_xor] = ACTIONS(4472),
    [anon_sym_xnor] = ACTIONS(4472),
    [anon_sym_buf] = ACTIONS(4472),
    [anon_sym_tranif0] = ACTIONS(4472),
    [anon_sym_tranif1] = ACTIONS(4472),
    [anon_sym_rtranif1] = ACTIONS(4472),
    [anon_sym_rtranif0] = ACTIONS(4472),
    [anon_sym_tran] = ACTIONS(4472),
    [anon_sym_rtran] = ACTIONS(4472),
    [anon_sym_generate] = ACTIONS(4472),
    [anon_sym_endgenerate] = ACTIONS(4472),
    [anon_sym_for] = ACTIONS(4472),
    [anon_sym_initial] = ACTIONS(4472),
    [anon_sym_assign] = ACTIONS(4472),
    [anon_sym_alias] = ACTIONS(4472),
    [anon_sym_always_comb] = ACTIONS(4472),
    [anon_sym_always_latch] = ACTIONS(4472),
    [anon_sym_always_ff] = ACTIONS(4472),
    [anon_sym_final] = ACTIONS(4472),
    [anon_sym_global] = ACTIONS(4472),
    [anon_sym_LPAREN_STAR] = ACTIONS(4470),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4470),
    [anon_sym_DOLLARunit] = ACTIONS(4470),
  },
  [4515] = {
    [sym_simple_identifier] = ACTIONS(4762),
    [anon_sym_wire] = ACTIONS(4762),
    [anon_sym_tri] = ACTIONS(4762),
    [anon_sym_tri0] = ACTIONS(4762),
    [anon_sym_tri1] = ACTIONS(4762),
    [anon_sym_wand] = ACTIONS(4762),
    [anon_sym_triand] = ACTIONS(4762),
    [anon_sym_wor] = ACTIONS(4762),
    [anon_sym_trior] = ACTIONS(4762),
    [anon_sym_trireg] = ACTIONS(4762),
    [anon_sym_uwire] = ACTIONS(4762),
    [anon_sym_SEMI] = ACTIONS(4760),
    [anon_sym_COLON] = ACTIONS(10747),
    [anon_sym_extern] = ACTIONS(4762),
    [anon_sym_interface] = ACTIONS(4762),
    [anon_sym_checker] = ACTIONS(4762),
    [anon_sym_virtual] = ACTIONS(4762),
    [anon_sym_class] = ACTIONS(4762),
    [anon_sym_type] = ACTIONS(4762),
    [anon_sym_DOLLARfatal] = ACTIONS(4760),
    [anon_sym_DOLLARerror] = ACTIONS(4760),
    [anon_sym_DOLLARwarning] = ACTIONS(4760),
    [anon_sym_DOLLARinfo] = ACTIONS(4760),
    [anon_sym_default] = ACTIONS(4762),
    [anon_sym_clocking] = ACTIONS(4762),
    [anon_sym_defparam] = ACTIONS(4762),
    [anon_sym_bind] = ACTIONS(4762),
    [anon_sym_rand] = ACTIONS(4762),
    [anon_sym_const] = ACTIONS(4762),
    [anon_sym_function] = ACTIONS(4762),
    [anon_sym_static] = ACTIONS(4762),
    [anon_sym_constraint] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4762),
    [anon_sym_else] = ACTIONS(4762),
    [anon_sym_LBRACK] = ACTIONS(4760),
    [anon_sym_localparam] = ACTIONS(4762),
    [anon_sym_parameter] = ACTIONS(4762),
    [anon_sym_var] = ACTIONS(4762),
    [anon_sym_import] = ACTIONS(4762),
    [anon_sym_export] = ACTIONS(4762),
    [anon_sym_genvar] = ACTIONS(4762),
    [anon_sym_interconnect] = ACTIONS(4762),
    [anon_sym_typedef] = ACTIONS(4762),
    [anon_sym_enum] = ACTIONS(4762),
    [anon_sym_struct] = ACTIONS(4762),
    [anon_sym_union] = ACTIONS(4762),
    [anon_sym_nettype] = ACTIONS(4762),
    [anon_sym_automatic] = ACTIONS(4762),
    [anon_sym_string] = ACTIONS(4762),
    [anon_sym_chandle] = ACTIONS(4762),
    [anon_sym_event] = ACTIONS(4762),
    [anon_sym_byte] = ACTIONS(4762),
    [anon_sym_shortint] = ACTIONS(4762),
    [anon_sym_int] = ACTIONS(4762),
    [anon_sym_longint] = ACTIONS(4762),
    [anon_sym_integer] = ACTIONS(4762),
    [anon_sym_time] = ACTIONS(4762),
    [anon_sym_bit] = ACTIONS(4762),
    [anon_sym_logic] = ACTIONS(4762),
    [anon_sym_reg] = ACTIONS(4762),
    [anon_sym_shortreal] = ACTIONS(4762),
    [anon_sym_real] = ACTIONS(4762),
    [anon_sym_realtime] = ACTIONS(4762),
    [anon_sym_supply0] = ACTIONS(4762),
    [anon_sym_supply1] = ACTIONS(4762),
    [anon_sym_signed] = ACTIONS(4762),
    [anon_sym_unsigned] = ACTIONS(4762),
    [anon_sym_task] = ACTIONS(4762),
    [anon_sym_assert] = ACTIONS(4762),
    [anon_sym_property] = ACTIONS(4762),
    [anon_sym_assume] = ACTIONS(4762),
    [anon_sym_cover] = ACTIONS(4762),
    [anon_sym_sequence] = ACTIONS(4762),
    [anon_sym_restrict] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4762),
    [anon_sym_or] = ACTIONS(4762),
    [anon_sym_and] = ACTIONS(4762),
    [anon_sym_case] = ACTIONS(4762),
    [anon_sym_always] = ACTIONS(4762),
    [anon_sym_covergroup] = ACTIONS(4762),
    [anon_sym_let] = ACTIONS(4762),
    [anon_sym_pulldown] = ACTIONS(4762),
    [anon_sym_pullup] = ACTIONS(4762),
    [anon_sym_cmos] = ACTIONS(4762),
    [anon_sym_rcmos] = ACTIONS(4762),
    [anon_sym_bufif0] = ACTIONS(4762),
    [anon_sym_bufif1] = ACTIONS(4762),
    [anon_sym_notif0] = ACTIONS(4762),
    [anon_sym_notif1] = ACTIONS(4762),
    [anon_sym_nmos] = ACTIONS(4762),
    [anon_sym_pmos] = ACTIONS(4762),
    [anon_sym_rnmos] = ACTIONS(4762),
    [anon_sym_rpmos] = ACTIONS(4762),
    [anon_sym_nand] = ACTIONS(4762),
    [anon_sym_nor] = ACTIONS(4762),
    [anon_sym_xor] = ACTIONS(4762),
    [anon_sym_xnor] = ACTIONS(4762),
    [anon_sym_buf] = ACTIONS(4762),
    [anon_sym_tranif0] = ACTIONS(4762),
    [anon_sym_tranif1] = ACTIONS(4762),
    [anon_sym_rtranif1] = ACTIONS(4762),
    [anon_sym_rtranif0] = ACTIONS(4762),
    [anon_sym_tran] = ACTIONS(4762),
    [anon_sym_rtran] = ACTIONS(4762),
    [anon_sym_generate] = ACTIONS(4762),
    [anon_sym_endgenerate] = ACTIONS(4762),
    [anon_sym_for] = ACTIONS(4762),
    [anon_sym_initial] = ACTIONS(4762),
    [anon_sym_assign] = ACTIONS(4762),
    [anon_sym_alias] = ACTIONS(4762),
    [anon_sym_always_comb] = ACTIONS(4762),
    [anon_sym_always_latch] = ACTIONS(4762),
    [anon_sym_always_ff] = ACTIONS(4762),
    [anon_sym_final] = ACTIONS(4762),
    [anon_sym_global] = ACTIONS(4762),
    [anon_sym_LPAREN_STAR] = ACTIONS(4760),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4760),
    [anon_sym_DOLLARunit] = ACTIONS(4760),
  },
  [4516] = {
    [sym_simple_identifier] = ACTIONS(4768),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_COLON] = ACTIONS(10749),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_rand] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_endgenerate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [4517] = {
    [sym_simple_identifier] = ACTIONS(4328),
    [anon_sym_wire] = ACTIONS(4328),
    [anon_sym_tri] = ACTIONS(4328),
    [anon_sym_tri0] = ACTIONS(4328),
    [anon_sym_tri1] = ACTIONS(4328),
    [anon_sym_wand] = ACTIONS(4328),
    [anon_sym_triand] = ACTIONS(4328),
    [anon_sym_wor] = ACTIONS(4328),
    [anon_sym_trior] = ACTIONS(4328),
    [anon_sym_trireg] = ACTIONS(4328),
    [anon_sym_uwire] = ACTIONS(4328),
    [anon_sym_SEMI] = ACTIONS(4326),
    [anon_sym_COLON] = ACTIONS(10751),
    [anon_sym_extern] = ACTIONS(4328),
    [anon_sym_interface] = ACTIONS(4328),
    [anon_sym_checker] = ACTIONS(4328),
    [anon_sym_virtual] = ACTIONS(4328),
    [anon_sym_class] = ACTIONS(4328),
    [anon_sym_type] = ACTIONS(4328),
    [anon_sym_DOLLARfatal] = ACTIONS(4326),
    [anon_sym_DOLLARerror] = ACTIONS(4326),
    [anon_sym_DOLLARwarning] = ACTIONS(4326),
    [anon_sym_DOLLARinfo] = ACTIONS(4326),
    [anon_sym_default] = ACTIONS(4328),
    [anon_sym_clocking] = ACTIONS(4328),
    [anon_sym_defparam] = ACTIONS(4328),
    [anon_sym_bind] = ACTIONS(4328),
    [anon_sym_rand] = ACTIONS(4328),
    [anon_sym_const] = ACTIONS(4328),
    [anon_sym_function] = ACTIONS(4328),
    [anon_sym_static] = ACTIONS(4328),
    [anon_sym_constraint] = ACTIONS(4328),
    [anon_sym_if] = ACTIONS(4328),
    [anon_sym_else] = ACTIONS(4328),
    [anon_sym_LBRACK] = ACTIONS(4326),
    [anon_sym_localparam] = ACTIONS(4328),
    [anon_sym_parameter] = ACTIONS(4328),
    [anon_sym_var] = ACTIONS(4328),
    [anon_sym_import] = ACTIONS(4328),
    [anon_sym_export] = ACTIONS(4328),
    [anon_sym_genvar] = ACTIONS(4328),
    [anon_sym_interconnect] = ACTIONS(4328),
    [anon_sym_typedef] = ACTIONS(4328),
    [anon_sym_enum] = ACTIONS(4328),
    [anon_sym_struct] = ACTIONS(4328),
    [anon_sym_union] = ACTIONS(4328),
    [anon_sym_nettype] = ACTIONS(4328),
    [anon_sym_automatic] = ACTIONS(4328),
    [anon_sym_string] = ACTIONS(4328),
    [anon_sym_chandle] = ACTIONS(4328),
    [anon_sym_event] = ACTIONS(4328),
    [anon_sym_byte] = ACTIONS(4328),
    [anon_sym_shortint] = ACTIONS(4328),
    [anon_sym_int] = ACTIONS(4328),
    [anon_sym_longint] = ACTIONS(4328),
    [anon_sym_integer] = ACTIONS(4328),
    [anon_sym_time] = ACTIONS(4328),
    [anon_sym_bit] = ACTIONS(4328),
    [anon_sym_logic] = ACTIONS(4328),
    [anon_sym_reg] = ACTIONS(4328),
    [anon_sym_shortreal] = ACTIONS(4328),
    [anon_sym_real] = ACTIONS(4328),
    [anon_sym_realtime] = ACTIONS(4328),
    [anon_sym_supply0] = ACTIONS(4328),
    [anon_sym_supply1] = ACTIONS(4328),
    [anon_sym_signed] = ACTIONS(4328),
    [anon_sym_unsigned] = ACTIONS(4328),
    [anon_sym_task] = ACTIONS(4328),
    [anon_sym_assert] = ACTIONS(4328),
    [anon_sym_property] = ACTIONS(4328),
    [anon_sym_assume] = ACTIONS(4328),
    [anon_sym_cover] = ACTIONS(4328),
    [anon_sym_sequence] = ACTIONS(4328),
    [anon_sym_restrict] = ACTIONS(4328),
    [anon_sym_not] = ACTIONS(4328),
    [anon_sym_or] = ACTIONS(4328),
    [anon_sym_and] = ACTIONS(4328),
    [anon_sym_case] = ACTIONS(4328),
    [anon_sym_always] = ACTIONS(4328),
    [anon_sym_covergroup] = ACTIONS(4328),
    [anon_sym_end] = ACTIONS(4328),
    [anon_sym_let] = ACTIONS(4328),
    [anon_sym_pulldown] = ACTIONS(4328),
    [anon_sym_pullup] = ACTIONS(4328),
    [anon_sym_cmos] = ACTIONS(4328),
    [anon_sym_rcmos] = ACTIONS(4328),
    [anon_sym_bufif0] = ACTIONS(4328),
    [anon_sym_bufif1] = ACTIONS(4328),
    [anon_sym_notif0] = ACTIONS(4328),
    [anon_sym_notif1] = ACTIONS(4328),
    [anon_sym_nmos] = ACTIONS(4328),
    [anon_sym_pmos] = ACTIONS(4328),
    [anon_sym_rnmos] = ACTIONS(4328),
    [anon_sym_rpmos] = ACTIONS(4328),
    [anon_sym_nand] = ACTIONS(4328),
    [anon_sym_nor] = ACTIONS(4328),
    [anon_sym_xor] = ACTIONS(4328),
    [anon_sym_xnor] = ACTIONS(4328),
    [anon_sym_buf] = ACTIONS(4328),
    [anon_sym_tranif0] = ACTIONS(4328),
    [anon_sym_tranif1] = ACTIONS(4328),
    [anon_sym_rtranif1] = ACTIONS(4328),
    [anon_sym_rtranif0] = ACTIONS(4328),
    [anon_sym_tran] = ACTIONS(4328),
    [anon_sym_rtran] = ACTIONS(4328),
    [anon_sym_generate] = ACTIONS(4328),
    [anon_sym_for] = ACTIONS(4328),
    [anon_sym_initial] = ACTIONS(4328),
    [anon_sym_assign] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4328),
    [anon_sym_always_comb] = ACTIONS(4328),
    [anon_sym_always_latch] = ACTIONS(4328),
    [anon_sym_always_ff] = ACTIONS(4328),
    [anon_sym_final] = ACTIONS(4328),
    [anon_sym_global] = ACTIONS(4328),
    [anon_sym_LPAREN_STAR] = ACTIONS(4326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4326),
    [anon_sym_DOLLARunit] = ACTIONS(4326),
  },
  [4518] = {
    [sym_simple_identifier] = ACTIONS(4774),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_COLON] = ACTIONS(10753),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_rand] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_endgenerate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [4519] = {
    [sym_simple_identifier] = ACTIONS(4756),
    [anon_sym_wire] = ACTIONS(4756),
    [anon_sym_tri] = ACTIONS(4756),
    [anon_sym_tri0] = ACTIONS(4756),
    [anon_sym_tri1] = ACTIONS(4756),
    [anon_sym_wand] = ACTIONS(4756),
    [anon_sym_triand] = ACTIONS(4756),
    [anon_sym_wor] = ACTIONS(4756),
    [anon_sym_trior] = ACTIONS(4756),
    [anon_sym_trireg] = ACTIONS(4756),
    [anon_sym_uwire] = ACTIONS(4756),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_COLON] = ACTIONS(10755),
    [anon_sym_extern] = ACTIONS(4756),
    [anon_sym_interface] = ACTIONS(4756),
    [anon_sym_checker] = ACTIONS(4756),
    [anon_sym_virtual] = ACTIONS(4756),
    [anon_sym_class] = ACTIONS(4756),
    [anon_sym_type] = ACTIONS(4756),
    [anon_sym_DOLLARfatal] = ACTIONS(4754),
    [anon_sym_DOLLARerror] = ACTIONS(4754),
    [anon_sym_DOLLARwarning] = ACTIONS(4754),
    [anon_sym_DOLLARinfo] = ACTIONS(4754),
    [anon_sym_default] = ACTIONS(4756),
    [anon_sym_clocking] = ACTIONS(4756),
    [anon_sym_defparam] = ACTIONS(4756),
    [anon_sym_bind] = ACTIONS(4756),
    [anon_sym_rand] = ACTIONS(4756),
    [anon_sym_const] = ACTIONS(4756),
    [anon_sym_function] = ACTIONS(4756),
    [anon_sym_static] = ACTIONS(4756),
    [anon_sym_constraint] = ACTIONS(4756),
    [anon_sym_if] = ACTIONS(4756),
    [anon_sym_else] = ACTIONS(4756),
    [anon_sym_LBRACK] = ACTIONS(4754),
    [anon_sym_localparam] = ACTIONS(4756),
    [anon_sym_parameter] = ACTIONS(4756),
    [anon_sym_var] = ACTIONS(4756),
    [anon_sym_import] = ACTIONS(4756),
    [anon_sym_export] = ACTIONS(4756),
    [anon_sym_genvar] = ACTIONS(4756),
    [anon_sym_interconnect] = ACTIONS(4756),
    [anon_sym_typedef] = ACTIONS(4756),
    [anon_sym_enum] = ACTIONS(4756),
    [anon_sym_struct] = ACTIONS(4756),
    [anon_sym_union] = ACTIONS(4756),
    [anon_sym_nettype] = ACTIONS(4756),
    [anon_sym_automatic] = ACTIONS(4756),
    [anon_sym_string] = ACTIONS(4756),
    [anon_sym_chandle] = ACTIONS(4756),
    [anon_sym_event] = ACTIONS(4756),
    [anon_sym_byte] = ACTIONS(4756),
    [anon_sym_shortint] = ACTIONS(4756),
    [anon_sym_int] = ACTIONS(4756),
    [anon_sym_longint] = ACTIONS(4756),
    [anon_sym_integer] = ACTIONS(4756),
    [anon_sym_time] = ACTIONS(4756),
    [anon_sym_bit] = ACTIONS(4756),
    [anon_sym_logic] = ACTIONS(4756),
    [anon_sym_reg] = ACTIONS(4756),
    [anon_sym_shortreal] = ACTIONS(4756),
    [anon_sym_real] = ACTIONS(4756),
    [anon_sym_realtime] = ACTIONS(4756),
    [anon_sym_supply0] = ACTIONS(4756),
    [anon_sym_supply1] = ACTIONS(4756),
    [anon_sym_signed] = ACTIONS(4756),
    [anon_sym_unsigned] = ACTIONS(4756),
    [anon_sym_task] = ACTIONS(4756),
    [anon_sym_assert] = ACTIONS(4756),
    [anon_sym_property] = ACTIONS(4756),
    [anon_sym_assume] = ACTIONS(4756),
    [anon_sym_cover] = ACTIONS(4756),
    [anon_sym_sequence] = ACTIONS(4756),
    [anon_sym_restrict] = ACTIONS(4756),
    [anon_sym_not] = ACTIONS(4756),
    [anon_sym_or] = ACTIONS(4756),
    [anon_sym_and] = ACTIONS(4756),
    [anon_sym_case] = ACTIONS(4756),
    [anon_sym_always] = ACTIONS(4756),
    [anon_sym_covergroup] = ACTIONS(4756),
    [anon_sym_end] = ACTIONS(4756),
    [anon_sym_let] = ACTIONS(4756),
    [anon_sym_pulldown] = ACTIONS(4756),
    [anon_sym_pullup] = ACTIONS(4756),
    [anon_sym_cmos] = ACTIONS(4756),
    [anon_sym_rcmos] = ACTIONS(4756),
    [anon_sym_bufif0] = ACTIONS(4756),
    [anon_sym_bufif1] = ACTIONS(4756),
    [anon_sym_notif0] = ACTIONS(4756),
    [anon_sym_notif1] = ACTIONS(4756),
    [anon_sym_nmos] = ACTIONS(4756),
    [anon_sym_pmos] = ACTIONS(4756),
    [anon_sym_rnmos] = ACTIONS(4756),
    [anon_sym_rpmos] = ACTIONS(4756),
    [anon_sym_nand] = ACTIONS(4756),
    [anon_sym_nor] = ACTIONS(4756),
    [anon_sym_xor] = ACTIONS(4756),
    [anon_sym_xnor] = ACTIONS(4756),
    [anon_sym_buf] = ACTIONS(4756),
    [anon_sym_tranif0] = ACTIONS(4756),
    [anon_sym_tranif1] = ACTIONS(4756),
    [anon_sym_rtranif1] = ACTIONS(4756),
    [anon_sym_rtranif0] = ACTIONS(4756),
    [anon_sym_tran] = ACTIONS(4756),
    [anon_sym_rtran] = ACTIONS(4756),
    [anon_sym_generate] = ACTIONS(4756),
    [anon_sym_for] = ACTIONS(4756),
    [anon_sym_initial] = ACTIONS(4756),
    [anon_sym_assign] = ACTIONS(4756),
    [anon_sym_alias] = ACTIONS(4756),
    [anon_sym_always_comb] = ACTIONS(4756),
    [anon_sym_always_latch] = ACTIONS(4756),
    [anon_sym_always_ff] = ACTIONS(4756),
    [anon_sym_final] = ACTIONS(4756),
    [anon_sym_global] = ACTIONS(4756),
    [anon_sym_LPAREN_STAR] = ACTIONS(4754),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4754),
    [anon_sym_DOLLARunit] = ACTIONS(4754),
  },
  [4520] = {
    [sym_simple_identifier] = ACTIONS(4436),
    [anon_sym_wire] = ACTIONS(4436),
    [anon_sym_tri] = ACTIONS(4436),
    [anon_sym_tri0] = ACTIONS(4436),
    [anon_sym_tri1] = ACTIONS(4436),
    [anon_sym_wand] = ACTIONS(4436),
    [anon_sym_triand] = ACTIONS(4436),
    [anon_sym_wor] = ACTIONS(4436),
    [anon_sym_trior] = ACTIONS(4436),
    [anon_sym_trireg] = ACTIONS(4436),
    [anon_sym_uwire] = ACTIONS(4436),
    [anon_sym_SEMI] = ACTIONS(4434),
    [anon_sym_COLON] = ACTIONS(10757),
    [anon_sym_extern] = ACTIONS(4436),
    [anon_sym_interface] = ACTIONS(4436),
    [anon_sym_checker] = ACTIONS(4436),
    [anon_sym_virtual] = ACTIONS(4436),
    [anon_sym_class] = ACTIONS(4436),
    [anon_sym_type] = ACTIONS(4436),
    [anon_sym_DOLLARfatal] = ACTIONS(4434),
    [anon_sym_DOLLARerror] = ACTIONS(4434),
    [anon_sym_DOLLARwarning] = ACTIONS(4434),
    [anon_sym_DOLLARinfo] = ACTIONS(4434),
    [anon_sym_default] = ACTIONS(4436),
    [anon_sym_clocking] = ACTIONS(4436),
    [anon_sym_defparam] = ACTIONS(4436),
    [anon_sym_bind] = ACTIONS(4436),
    [anon_sym_rand] = ACTIONS(4436),
    [anon_sym_const] = ACTIONS(4436),
    [anon_sym_function] = ACTIONS(4436),
    [anon_sym_static] = ACTIONS(4436),
    [anon_sym_constraint] = ACTIONS(4436),
    [anon_sym_if] = ACTIONS(4436),
    [anon_sym_else] = ACTIONS(4436),
    [anon_sym_LBRACK] = ACTIONS(4434),
    [anon_sym_localparam] = ACTIONS(4436),
    [anon_sym_parameter] = ACTIONS(4436),
    [anon_sym_var] = ACTIONS(4436),
    [anon_sym_import] = ACTIONS(4436),
    [anon_sym_export] = ACTIONS(4436),
    [anon_sym_genvar] = ACTIONS(4436),
    [anon_sym_interconnect] = ACTIONS(4436),
    [anon_sym_typedef] = ACTIONS(4436),
    [anon_sym_enum] = ACTIONS(4436),
    [anon_sym_struct] = ACTIONS(4436),
    [anon_sym_union] = ACTIONS(4436),
    [anon_sym_nettype] = ACTIONS(4436),
    [anon_sym_automatic] = ACTIONS(4436),
    [anon_sym_string] = ACTIONS(4436),
    [anon_sym_chandle] = ACTIONS(4436),
    [anon_sym_event] = ACTIONS(4436),
    [anon_sym_byte] = ACTIONS(4436),
    [anon_sym_shortint] = ACTIONS(4436),
    [anon_sym_int] = ACTIONS(4436),
    [anon_sym_longint] = ACTIONS(4436),
    [anon_sym_integer] = ACTIONS(4436),
    [anon_sym_time] = ACTIONS(4436),
    [anon_sym_bit] = ACTIONS(4436),
    [anon_sym_logic] = ACTIONS(4436),
    [anon_sym_reg] = ACTIONS(4436),
    [anon_sym_shortreal] = ACTIONS(4436),
    [anon_sym_real] = ACTIONS(4436),
    [anon_sym_realtime] = ACTIONS(4436),
    [anon_sym_supply0] = ACTIONS(4436),
    [anon_sym_supply1] = ACTIONS(4436),
    [anon_sym_signed] = ACTIONS(4436),
    [anon_sym_unsigned] = ACTIONS(4436),
    [anon_sym_task] = ACTIONS(4436),
    [anon_sym_assert] = ACTIONS(4436),
    [anon_sym_property] = ACTIONS(4436),
    [anon_sym_assume] = ACTIONS(4436),
    [anon_sym_cover] = ACTIONS(4436),
    [anon_sym_sequence] = ACTIONS(4436),
    [anon_sym_restrict] = ACTIONS(4436),
    [anon_sym_not] = ACTIONS(4436),
    [anon_sym_or] = ACTIONS(4436),
    [anon_sym_and] = ACTIONS(4436),
    [anon_sym_case] = ACTIONS(4436),
    [anon_sym_always] = ACTIONS(4436),
    [anon_sym_covergroup] = ACTIONS(4436),
    [anon_sym_let] = ACTIONS(4436),
    [anon_sym_pulldown] = ACTIONS(4436),
    [anon_sym_pullup] = ACTIONS(4436),
    [anon_sym_cmos] = ACTIONS(4436),
    [anon_sym_rcmos] = ACTIONS(4436),
    [anon_sym_bufif0] = ACTIONS(4436),
    [anon_sym_bufif1] = ACTIONS(4436),
    [anon_sym_notif0] = ACTIONS(4436),
    [anon_sym_notif1] = ACTIONS(4436),
    [anon_sym_nmos] = ACTIONS(4436),
    [anon_sym_pmos] = ACTIONS(4436),
    [anon_sym_rnmos] = ACTIONS(4436),
    [anon_sym_rpmos] = ACTIONS(4436),
    [anon_sym_nand] = ACTIONS(4436),
    [anon_sym_nor] = ACTIONS(4436),
    [anon_sym_xor] = ACTIONS(4436),
    [anon_sym_xnor] = ACTIONS(4436),
    [anon_sym_buf] = ACTIONS(4436),
    [anon_sym_tranif0] = ACTIONS(4436),
    [anon_sym_tranif1] = ACTIONS(4436),
    [anon_sym_rtranif1] = ACTIONS(4436),
    [anon_sym_rtranif0] = ACTIONS(4436),
    [anon_sym_tran] = ACTIONS(4436),
    [anon_sym_rtran] = ACTIONS(4436),
    [anon_sym_generate] = ACTIONS(4436),
    [anon_sym_endgenerate] = ACTIONS(4436),
    [anon_sym_for] = ACTIONS(4436),
    [anon_sym_initial] = ACTIONS(4436),
    [anon_sym_assign] = ACTIONS(4436),
    [anon_sym_alias] = ACTIONS(4436),
    [anon_sym_always_comb] = ACTIONS(4436),
    [anon_sym_always_latch] = ACTIONS(4436),
    [anon_sym_always_ff] = ACTIONS(4436),
    [anon_sym_final] = ACTIONS(4436),
    [anon_sym_global] = ACTIONS(4436),
    [anon_sym_LPAREN_STAR] = ACTIONS(4434),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4434),
    [anon_sym_DOLLARunit] = ACTIONS(4434),
  },
  [4521] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_COLON] = ACTIONS(10759),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_rand] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_end] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [4522] = {
    [sym_simple_identifier] = ACTIONS(5660),
    [anon_sym_wire] = ACTIONS(5660),
    [anon_sym_tri] = ACTIONS(5660),
    [anon_sym_tri0] = ACTIONS(5660),
    [anon_sym_tri1] = ACTIONS(5660),
    [anon_sym_wand] = ACTIONS(5660),
    [anon_sym_triand] = ACTIONS(5660),
    [anon_sym_wor] = ACTIONS(5660),
    [anon_sym_trior] = ACTIONS(5660),
    [anon_sym_trireg] = ACTIONS(5660),
    [anon_sym_uwire] = ACTIONS(5660),
    [anon_sym_SEMI] = ACTIONS(5662),
    [anon_sym_COLON] = ACTIONS(10761),
    [anon_sym_extern] = ACTIONS(5660),
    [anon_sym_interface] = ACTIONS(5660),
    [anon_sym_checker] = ACTIONS(5660),
    [anon_sym_virtual] = ACTIONS(5660),
    [anon_sym_class] = ACTIONS(5660),
    [anon_sym_type] = ACTIONS(5660),
    [anon_sym_DOLLARfatal] = ACTIONS(5662),
    [anon_sym_DOLLARerror] = ACTIONS(5662),
    [anon_sym_DOLLARwarning] = ACTIONS(5662),
    [anon_sym_DOLLARinfo] = ACTIONS(5662),
    [anon_sym_default] = ACTIONS(5660),
    [anon_sym_clocking] = ACTIONS(5660),
    [anon_sym_defparam] = ACTIONS(5660),
    [anon_sym_bind] = ACTIONS(5660),
    [anon_sym_rand] = ACTIONS(5660),
    [anon_sym_const] = ACTIONS(5660),
    [anon_sym_function] = ACTIONS(5660),
    [anon_sym_static] = ACTIONS(5660),
    [anon_sym_constraint] = ACTIONS(5660),
    [anon_sym_if] = ACTIONS(5660),
    [anon_sym_else] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5662),
    [anon_sym_localparam] = ACTIONS(5660),
    [anon_sym_parameter] = ACTIONS(5660),
    [anon_sym_var] = ACTIONS(5660),
    [anon_sym_import] = ACTIONS(5660),
    [anon_sym_export] = ACTIONS(5660),
    [anon_sym_genvar] = ACTIONS(5660),
    [anon_sym_interconnect] = ACTIONS(5660),
    [anon_sym_typedef] = ACTIONS(5660),
    [anon_sym_enum] = ACTIONS(5660),
    [anon_sym_struct] = ACTIONS(5660),
    [anon_sym_union] = ACTIONS(5660),
    [anon_sym_nettype] = ACTIONS(5660),
    [anon_sym_automatic] = ACTIONS(5660),
    [anon_sym_string] = ACTIONS(5660),
    [anon_sym_chandle] = ACTIONS(5660),
    [anon_sym_event] = ACTIONS(5660),
    [anon_sym_byte] = ACTIONS(5660),
    [anon_sym_shortint] = ACTIONS(5660),
    [anon_sym_int] = ACTIONS(5660),
    [anon_sym_longint] = ACTIONS(5660),
    [anon_sym_integer] = ACTIONS(5660),
    [anon_sym_time] = ACTIONS(5660),
    [anon_sym_bit] = ACTIONS(5660),
    [anon_sym_logic] = ACTIONS(5660),
    [anon_sym_reg] = ACTIONS(5660),
    [anon_sym_shortreal] = ACTIONS(5660),
    [anon_sym_real] = ACTIONS(5660),
    [anon_sym_realtime] = ACTIONS(5660),
    [anon_sym_supply0] = ACTIONS(5660),
    [anon_sym_supply1] = ACTIONS(5660),
    [anon_sym_signed] = ACTIONS(5660),
    [anon_sym_unsigned] = ACTIONS(5660),
    [anon_sym_task] = ACTIONS(5660),
    [anon_sym_assert] = ACTIONS(5660),
    [anon_sym_property] = ACTIONS(5660),
    [anon_sym_assume] = ACTIONS(5660),
    [anon_sym_cover] = ACTIONS(5660),
    [anon_sym_sequence] = ACTIONS(5660),
    [anon_sym_restrict] = ACTIONS(5660),
    [anon_sym_not] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_case] = ACTIONS(5660),
    [anon_sym_always] = ACTIONS(5660),
    [anon_sym_covergroup] = ACTIONS(5660),
    [anon_sym_end] = ACTIONS(5660),
    [anon_sym_let] = ACTIONS(5660),
    [anon_sym_pulldown] = ACTIONS(5660),
    [anon_sym_pullup] = ACTIONS(5660),
    [anon_sym_cmos] = ACTIONS(5660),
    [anon_sym_rcmos] = ACTIONS(5660),
    [anon_sym_bufif0] = ACTIONS(5660),
    [anon_sym_bufif1] = ACTIONS(5660),
    [anon_sym_notif0] = ACTIONS(5660),
    [anon_sym_notif1] = ACTIONS(5660),
    [anon_sym_nmos] = ACTIONS(5660),
    [anon_sym_pmos] = ACTIONS(5660),
    [anon_sym_rnmos] = ACTIONS(5660),
    [anon_sym_rpmos] = ACTIONS(5660),
    [anon_sym_nand] = ACTIONS(5660),
    [anon_sym_nor] = ACTIONS(5660),
    [anon_sym_xor] = ACTIONS(5660),
    [anon_sym_xnor] = ACTIONS(5660),
    [anon_sym_buf] = ACTIONS(5660),
    [anon_sym_tranif0] = ACTIONS(5660),
    [anon_sym_tranif1] = ACTIONS(5660),
    [anon_sym_rtranif1] = ACTIONS(5660),
    [anon_sym_rtranif0] = ACTIONS(5660),
    [anon_sym_tran] = ACTIONS(5660),
    [anon_sym_rtran] = ACTIONS(5660),
    [anon_sym_generate] = ACTIONS(5660),
    [anon_sym_for] = ACTIONS(5660),
    [anon_sym_initial] = ACTIONS(5660),
    [anon_sym_assign] = ACTIONS(5660),
    [anon_sym_alias] = ACTIONS(5660),
    [anon_sym_always_comb] = ACTIONS(5660),
    [anon_sym_always_latch] = ACTIONS(5660),
    [anon_sym_always_ff] = ACTIONS(5660),
    [anon_sym_final] = ACTIONS(5660),
    [anon_sym_global] = ACTIONS(5660),
    [anon_sym_LPAREN_STAR] = ACTIONS(5662),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5662),
    [anon_sym_DOLLARunit] = ACTIONS(5662),
  },
  [4523] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_COLON] = ACTIONS(10763),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_rand] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_endgenerate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [4524] = {
    [sym_simple_identifier] = ACTIONS(4548),
    [anon_sym_wire] = ACTIONS(4548),
    [anon_sym_tri] = ACTIONS(4548),
    [anon_sym_tri0] = ACTIONS(4548),
    [anon_sym_tri1] = ACTIONS(4548),
    [anon_sym_wand] = ACTIONS(4548),
    [anon_sym_triand] = ACTIONS(4548),
    [anon_sym_wor] = ACTIONS(4548),
    [anon_sym_trior] = ACTIONS(4548),
    [anon_sym_trireg] = ACTIONS(4548),
    [anon_sym_uwire] = ACTIONS(4548),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(10765),
    [anon_sym_extern] = ACTIONS(4548),
    [anon_sym_interface] = ACTIONS(4548),
    [anon_sym_checker] = ACTIONS(4548),
    [anon_sym_virtual] = ACTIONS(4548),
    [anon_sym_class] = ACTIONS(4548),
    [anon_sym_type] = ACTIONS(4548),
    [anon_sym_DOLLARfatal] = ACTIONS(4546),
    [anon_sym_DOLLARerror] = ACTIONS(4546),
    [anon_sym_DOLLARwarning] = ACTIONS(4546),
    [anon_sym_DOLLARinfo] = ACTIONS(4546),
    [anon_sym_default] = ACTIONS(4548),
    [anon_sym_clocking] = ACTIONS(4548),
    [anon_sym_defparam] = ACTIONS(4548),
    [anon_sym_bind] = ACTIONS(4548),
    [anon_sym_rand] = ACTIONS(4548),
    [anon_sym_const] = ACTIONS(4548),
    [anon_sym_function] = ACTIONS(4548),
    [anon_sym_static] = ACTIONS(4548),
    [anon_sym_constraint] = ACTIONS(4548),
    [anon_sym_if] = ACTIONS(4548),
    [anon_sym_else] = ACTIONS(4548),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_localparam] = ACTIONS(4548),
    [anon_sym_parameter] = ACTIONS(4548),
    [anon_sym_var] = ACTIONS(4548),
    [anon_sym_import] = ACTIONS(4548),
    [anon_sym_export] = ACTIONS(4548),
    [anon_sym_genvar] = ACTIONS(4548),
    [anon_sym_interconnect] = ACTIONS(4548),
    [anon_sym_typedef] = ACTIONS(4548),
    [anon_sym_enum] = ACTIONS(4548),
    [anon_sym_struct] = ACTIONS(4548),
    [anon_sym_union] = ACTIONS(4548),
    [anon_sym_nettype] = ACTIONS(4548),
    [anon_sym_automatic] = ACTIONS(4548),
    [anon_sym_string] = ACTIONS(4548),
    [anon_sym_chandle] = ACTIONS(4548),
    [anon_sym_event] = ACTIONS(4548),
    [anon_sym_byte] = ACTIONS(4548),
    [anon_sym_shortint] = ACTIONS(4548),
    [anon_sym_int] = ACTIONS(4548),
    [anon_sym_longint] = ACTIONS(4548),
    [anon_sym_integer] = ACTIONS(4548),
    [anon_sym_time] = ACTIONS(4548),
    [anon_sym_bit] = ACTIONS(4548),
    [anon_sym_logic] = ACTIONS(4548),
    [anon_sym_reg] = ACTIONS(4548),
    [anon_sym_shortreal] = ACTIONS(4548),
    [anon_sym_real] = ACTIONS(4548),
    [anon_sym_realtime] = ACTIONS(4548),
    [anon_sym_supply0] = ACTIONS(4548),
    [anon_sym_supply1] = ACTIONS(4548),
    [anon_sym_signed] = ACTIONS(4548),
    [anon_sym_unsigned] = ACTIONS(4548),
    [anon_sym_task] = ACTIONS(4548),
    [anon_sym_assert] = ACTIONS(4548),
    [anon_sym_property] = ACTIONS(4548),
    [anon_sym_assume] = ACTIONS(4548),
    [anon_sym_cover] = ACTIONS(4548),
    [anon_sym_sequence] = ACTIONS(4548),
    [anon_sym_restrict] = ACTIONS(4548),
    [anon_sym_not] = ACTIONS(4548),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_and] = ACTIONS(4548),
    [anon_sym_case] = ACTIONS(4548),
    [anon_sym_always] = ACTIONS(4548),
    [anon_sym_covergroup] = ACTIONS(4548),
    [anon_sym_end] = ACTIONS(4548),
    [anon_sym_let] = ACTIONS(4548),
    [anon_sym_pulldown] = ACTIONS(4548),
    [anon_sym_pullup] = ACTIONS(4548),
    [anon_sym_cmos] = ACTIONS(4548),
    [anon_sym_rcmos] = ACTIONS(4548),
    [anon_sym_bufif0] = ACTIONS(4548),
    [anon_sym_bufif1] = ACTIONS(4548),
    [anon_sym_notif0] = ACTIONS(4548),
    [anon_sym_notif1] = ACTIONS(4548),
    [anon_sym_nmos] = ACTIONS(4548),
    [anon_sym_pmos] = ACTIONS(4548),
    [anon_sym_rnmos] = ACTIONS(4548),
    [anon_sym_rpmos] = ACTIONS(4548),
    [anon_sym_nand] = ACTIONS(4548),
    [anon_sym_nor] = ACTIONS(4548),
    [anon_sym_xor] = ACTIONS(4548),
    [anon_sym_xnor] = ACTIONS(4548),
    [anon_sym_buf] = ACTIONS(4548),
    [anon_sym_tranif0] = ACTIONS(4548),
    [anon_sym_tranif1] = ACTIONS(4548),
    [anon_sym_rtranif1] = ACTIONS(4548),
    [anon_sym_rtranif0] = ACTIONS(4548),
    [anon_sym_tran] = ACTIONS(4548),
    [anon_sym_rtran] = ACTIONS(4548),
    [anon_sym_generate] = ACTIONS(4548),
    [anon_sym_for] = ACTIONS(4548),
    [anon_sym_initial] = ACTIONS(4548),
    [anon_sym_assign] = ACTIONS(4548),
    [anon_sym_alias] = ACTIONS(4548),
    [anon_sym_always_comb] = ACTIONS(4548),
    [anon_sym_always_latch] = ACTIONS(4548),
    [anon_sym_always_ff] = ACTIONS(4548),
    [anon_sym_final] = ACTIONS(4548),
    [anon_sym_global] = ACTIONS(4548),
    [anon_sym_LPAREN_STAR] = ACTIONS(4546),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4546),
    [anon_sym_DOLLARunit] = ACTIONS(4546),
  },
  [4525] = {
    [sym_simple_identifier] = ACTIONS(4466),
    [anon_sym_wire] = ACTIONS(4466),
    [anon_sym_tri] = ACTIONS(4466),
    [anon_sym_tri0] = ACTIONS(4466),
    [anon_sym_tri1] = ACTIONS(4466),
    [anon_sym_wand] = ACTIONS(4466),
    [anon_sym_triand] = ACTIONS(4466),
    [anon_sym_wor] = ACTIONS(4466),
    [anon_sym_trior] = ACTIONS(4466),
    [anon_sym_trireg] = ACTIONS(4466),
    [anon_sym_uwire] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(10767),
    [anon_sym_extern] = ACTIONS(4466),
    [anon_sym_interface] = ACTIONS(4466),
    [anon_sym_checker] = ACTIONS(4466),
    [anon_sym_virtual] = ACTIONS(4466),
    [anon_sym_class] = ACTIONS(4466),
    [anon_sym_type] = ACTIONS(4466),
    [anon_sym_DOLLARfatal] = ACTIONS(4464),
    [anon_sym_DOLLARerror] = ACTIONS(4464),
    [anon_sym_DOLLARwarning] = ACTIONS(4464),
    [anon_sym_DOLLARinfo] = ACTIONS(4464),
    [anon_sym_default] = ACTIONS(4466),
    [anon_sym_clocking] = ACTIONS(4466),
    [anon_sym_defparam] = ACTIONS(4466),
    [anon_sym_bind] = ACTIONS(4466),
    [anon_sym_rand] = ACTIONS(4466),
    [anon_sym_const] = ACTIONS(4466),
    [anon_sym_function] = ACTIONS(4466),
    [anon_sym_static] = ACTIONS(4466),
    [anon_sym_constraint] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_else] = ACTIONS(4466),
    [anon_sym_LBRACK] = ACTIONS(4464),
    [anon_sym_localparam] = ACTIONS(4466),
    [anon_sym_parameter] = ACTIONS(4466),
    [anon_sym_var] = ACTIONS(4466),
    [anon_sym_import] = ACTIONS(4466),
    [anon_sym_export] = ACTIONS(4466),
    [anon_sym_genvar] = ACTIONS(4466),
    [anon_sym_interconnect] = ACTIONS(4466),
    [anon_sym_typedef] = ACTIONS(4466),
    [anon_sym_enum] = ACTIONS(4466),
    [anon_sym_struct] = ACTIONS(4466),
    [anon_sym_union] = ACTIONS(4466),
    [anon_sym_nettype] = ACTIONS(4466),
    [anon_sym_automatic] = ACTIONS(4466),
    [anon_sym_string] = ACTIONS(4466),
    [anon_sym_chandle] = ACTIONS(4466),
    [anon_sym_event] = ACTIONS(4466),
    [anon_sym_byte] = ACTIONS(4466),
    [anon_sym_shortint] = ACTIONS(4466),
    [anon_sym_int] = ACTIONS(4466),
    [anon_sym_longint] = ACTIONS(4466),
    [anon_sym_integer] = ACTIONS(4466),
    [anon_sym_time] = ACTIONS(4466),
    [anon_sym_bit] = ACTIONS(4466),
    [anon_sym_logic] = ACTIONS(4466),
    [anon_sym_reg] = ACTIONS(4466),
    [anon_sym_shortreal] = ACTIONS(4466),
    [anon_sym_real] = ACTIONS(4466),
    [anon_sym_realtime] = ACTIONS(4466),
    [anon_sym_supply0] = ACTIONS(4466),
    [anon_sym_supply1] = ACTIONS(4466),
    [anon_sym_signed] = ACTIONS(4466),
    [anon_sym_unsigned] = ACTIONS(4466),
    [anon_sym_task] = ACTIONS(4466),
    [anon_sym_assert] = ACTIONS(4466),
    [anon_sym_property] = ACTIONS(4466),
    [anon_sym_assume] = ACTIONS(4466),
    [anon_sym_cover] = ACTIONS(4466),
    [anon_sym_sequence] = ACTIONS(4466),
    [anon_sym_restrict] = ACTIONS(4466),
    [anon_sym_not] = ACTIONS(4466),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_and] = ACTIONS(4466),
    [anon_sym_case] = ACTIONS(4466),
    [anon_sym_always] = ACTIONS(4466),
    [anon_sym_covergroup] = ACTIONS(4466),
    [anon_sym_end] = ACTIONS(4466),
    [anon_sym_let] = ACTIONS(4466),
    [anon_sym_pulldown] = ACTIONS(4466),
    [anon_sym_pullup] = ACTIONS(4466),
    [anon_sym_cmos] = ACTIONS(4466),
    [anon_sym_rcmos] = ACTIONS(4466),
    [anon_sym_bufif0] = ACTIONS(4466),
    [anon_sym_bufif1] = ACTIONS(4466),
    [anon_sym_notif0] = ACTIONS(4466),
    [anon_sym_notif1] = ACTIONS(4466),
    [anon_sym_nmos] = ACTIONS(4466),
    [anon_sym_pmos] = ACTIONS(4466),
    [anon_sym_rnmos] = ACTIONS(4466),
    [anon_sym_rpmos] = ACTIONS(4466),
    [anon_sym_nand] = ACTIONS(4466),
    [anon_sym_nor] = ACTIONS(4466),
    [anon_sym_xor] = ACTIONS(4466),
    [anon_sym_xnor] = ACTIONS(4466),
    [anon_sym_buf] = ACTIONS(4466),
    [anon_sym_tranif0] = ACTIONS(4466),
    [anon_sym_tranif1] = ACTIONS(4466),
    [anon_sym_rtranif1] = ACTIONS(4466),
    [anon_sym_rtranif0] = ACTIONS(4466),
    [anon_sym_tran] = ACTIONS(4466),
    [anon_sym_rtran] = ACTIONS(4466),
    [anon_sym_generate] = ACTIONS(4466),
    [anon_sym_for] = ACTIONS(4466),
    [anon_sym_initial] = ACTIONS(4466),
    [anon_sym_assign] = ACTIONS(4466),
    [anon_sym_alias] = ACTIONS(4466),
    [anon_sym_always_comb] = ACTIONS(4466),
    [anon_sym_always_latch] = ACTIONS(4466),
    [anon_sym_always_ff] = ACTIONS(4466),
    [anon_sym_final] = ACTIONS(4466),
    [anon_sym_global] = ACTIONS(4466),
    [anon_sym_LPAREN_STAR] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4464),
    [anon_sym_DOLLARunit] = ACTIONS(4464),
  },
  [4526] = {
    [sym_simple_identifier] = ACTIONS(5588),
    [anon_sym_wire] = ACTIONS(5588),
    [anon_sym_tri] = ACTIONS(5588),
    [anon_sym_tri0] = ACTIONS(5588),
    [anon_sym_tri1] = ACTIONS(5588),
    [anon_sym_wand] = ACTIONS(5588),
    [anon_sym_triand] = ACTIONS(5588),
    [anon_sym_wor] = ACTIONS(5588),
    [anon_sym_trior] = ACTIONS(5588),
    [anon_sym_trireg] = ACTIONS(5588),
    [anon_sym_uwire] = ACTIONS(5588),
    [anon_sym_SEMI] = ACTIONS(5590),
    [anon_sym_COLON] = ACTIONS(10769),
    [anon_sym_extern] = ACTIONS(5588),
    [anon_sym_interface] = ACTIONS(5588),
    [anon_sym_checker] = ACTIONS(5588),
    [anon_sym_virtual] = ACTIONS(5588),
    [anon_sym_class] = ACTIONS(5588),
    [anon_sym_type] = ACTIONS(5588),
    [anon_sym_DOLLARfatal] = ACTIONS(5590),
    [anon_sym_DOLLARerror] = ACTIONS(5590),
    [anon_sym_DOLLARwarning] = ACTIONS(5590),
    [anon_sym_DOLLARinfo] = ACTIONS(5590),
    [anon_sym_default] = ACTIONS(5588),
    [anon_sym_clocking] = ACTIONS(5588),
    [anon_sym_defparam] = ACTIONS(5588),
    [anon_sym_bind] = ACTIONS(5588),
    [anon_sym_rand] = ACTIONS(5588),
    [anon_sym_const] = ACTIONS(5588),
    [anon_sym_function] = ACTIONS(5588),
    [anon_sym_static] = ACTIONS(5588),
    [anon_sym_constraint] = ACTIONS(5588),
    [anon_sym_if] = ACTIONS(5588),
    [anon_sym_else] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5590),
    [anon_sym_localparam] = ACTIONS(5588),
    [anon_sym_parameter] = ACTIONS(5588),
    [anon_sym_var] = ACTIONS(5588),
    [anon_sym_import] = ACTIONS(5588),
    [anon_sym_export] = ACTIONS(5588),
    [anon_sym_genvar] = ACTIONS(5588),
    [anon_sym_interconnect] = ACTIONS(5588),
    [anon_sym_typedef] = ACTIONS(5588),
    [anon_sym_enum] = ACTIONS(5588),
    [anon_sym_struct] = ACTIONS(5588),
    [anon_sym_union] = ACTIONS(5588),
    [anon_sym_nettype] = ACTIONS(5588),
    [anon_sym_automatic] = ACTIONS(5588),
    [anon_sym_string] = ACTIONS(5588),
    [anon_sym_chandle] = ACTIONS(5588),
    [anon_sym_event] = ACTIONS(5588),
    [anon_sym_byte] = ACTIONS(5588),
    [anon_sym_shortint] = ACTIONS(5588),
    [anon_sym_int] = ACTIONS(5588),
    [anon_sym_longint] = ACTIONS(5588),
    [anon_sym_integer] = ACTIONS(5588),
    [anon_sym_time] = ACTIONS(5588),
    [anon_sym_bit] = ACTIONS(5588),
    [anon_sym_logic] = ACTIONS(5588),
    [anon_sym_reg] = ACTIONS(5588),
    [anon_sym_shortreal] = ACTIONS(5588),
    [anon_sym_real] = ACTIONS(5588),
    [anon_sym_realtime] = ACTIONS(5588),
    [anon_sym_supply0] = ACTIONS(5588),
    [anon_sym_supply1] = ACTIONS(5588),
    [anon_sym_signed] = ACTIONS(5588),
    [anon_sym_unsigned] = ACTIONS(5588),
    [anon_sym_task] = ACTIONS(5588),
    [anon_sym_assert] = ACTIONS(5588),
    [anon_sym_property] = ACTIONS(5588),
    [anon_sym_assume] = ACTIONS(5588),
    [anon_sym_cover] = ACTIONS(5588),
    [anon_sym_sequence] = ACTIONS(5588),
    [anon_sym_restrict] = ACTIONS(5588),
    [anon_sym_not] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_case] = ACTIONS(5588),
    [anon_sym_always] = ACTIONS(5588),
    [anon_sym_covergroup] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_pulldown] = ACTIONS(5588),
    [anon_sym_pullup] = ACTIONS(5588),
    [anon_sym_cmos] = ACTIONS(5588),
    [anon_sym_rcmos] = ACTIONS(5588),
    [anon_sym_bufif0] = ACTIONS(5588),
    [anon_sym_bufif1] = ACTIONS(5588),
    [anon_sym_notif0] = ACTIONS(5588),
    [anon_sym_notif1] = ACTIONS(5588),
    [anon_sym_nmos] = ACTIONS(5588),
    [anon_sym_pmos] = ACTIONS(5588),
    [anon_sym_rnmos] = ACTIONS(5588),
    [anon_sym_rpmos] = ACTIONS(5588),
    [anon_sym_nand] = ACTIONS(5588),
    [anon_sym_nor] = ACTIONS(5588),
    [anon_sym_xor] = ACTIONS(5588),
    [anon_sym_xnor] = ACTIONS(5588),
    [anon_sym_buf] = ACTIONS(5588),
    [anon_sym_tranif0] = ACTIONS(5588),
    [anon_sym_tranif1] = ACTIONS(5588),
    [anon_sym_rtranif1] = ACTIONS(5588),
    [anon_sym_rtranif0] = ACTIONS(5588),
    [anon_sym_tran] = ACTIONS(5588),
    [anon_sym_rtran] = ACTIONS(5588),
    [anon_sym_generate] = ACTIONS(5588),
    [anon_sym_endgenerate] = ACTIONS(5588),
    [anon_sym_for] = ACTIONS(5588),
    [anon_sym_initial] = ACTIONS(5588),
    [anon_sym_assign] = ACTIONS(5588),
    [anon_sym_alias] = ACTIONS(5588),
    [anon_sym_always_comb] = ACTIONS(5588),
    [anon_sym_always_latch] = ACTIONS(5588),
    [anon_sym_always_ff] = ACTIONS(5588),
    [anon_sym_final] = ACTIONS(5588),
    [anon_sym_global] = ACTIONS(5588),
    [anon_sym_LPAREN_STAR] = ACTIONS(5590),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5590),
    [anon_sym_DOLLARunit] = ACTIONS(5590),
  },
  [4527] = {
    [sym_simple_identifier] = ACTIONS(5612),
    [anon_sym_wire] = ACTIONS(5612),
    [anon_sym_tri] = ACTIONS(5612),
    [anon_sym_tri0] = ACTIONS(5612),
    [anon_sym_tri1] = ACTIONS(5612),
    [anon_sym_wand] = ACTIONS(5612),
    [anon_sym_triand] = ACTIONS(5612),
    [anon_sym_wor] = ACTIONS(5612),
    [anon_sym_trior] = ACTIONS(5612),
    [anon_sym_trireg] = ACTIONS(5612),
    [anon_sym_uwire] = ACTIONS(5612),
    [anon_sym_SEMI] = ACTIONS(5614),
    [anon_sym_COLON] = ACTIONS(10771),
    [anon_sym_extern] = ACTIONS(5612),
    [anon_sym_interface] = ACTIONS(5612),
    [anon_sym_checker] = ACTIONS(5612),
    [anon_sym_virtual] = ACTIONS(5612),
    [anon_sym_class] = ACTIONS(5612),
    [anon_sym_type] = ACTIONS(5612),
    [anon_sym_DOLLARfatal] = ACTIONS(5614),
    [anon_sym_DOLLARerror] = ACTIONS(5614),
    [anon_sym_DOLLARwarning] = ACTIONS(5614),
    [anon_sym_DOLLARinfo] = ACTIONS(5614),
    [anon_sym_default] = ACTIONS(5612),
    [anon_sym_clocking] = ACTIONS(5612),
    [anon_sym_defparam] = ACTIONS(5612),
    [anon_sym_bind] = ACTIONS(5612),
    [anon_sym_rand] = ACTIONS(5612),
    [anon_sym_const] = ACTIONS(5612),
    [anon_sym_function] = ACTIONS(5612),
    [anon_sym_static] = ACTIONS(5612),
    [anon_sym_constraint] = ACTIONS(5612),
    [anon_sym_if] = ACTIONS(5612),
    [anon_sym_else] = ACTIONS(5612),
    [anon_sym_LBRACK] = ACTIONS(5614),
    [anon_sym_localparam] = ACTIONS(5612),
    [anon_sym_parameter] = ACTIONS(5612),
    [anon_sym_var] = ACTIONS(5612),
    [anon_sym_import] = ACTIONS(5612),
    [anon_sym_export] = ACTIONS(5612),
    [anon_sym_genvar] = ACTIONS(5612),
    [anon_sym_interconnect] = ACTIONS(5612),
    [anon_sym_typedef] = ACTIONS(5612),
    [anon_sym_enum] = ACTIONS(5612),
    [anon_sym_struct] = ACTIONS(5612),
    [anon_sym_union] = ACTIONS(5612),
    [anon_sym_nettype] = ACTIONS(5612),
    [anon_sym_automatic] = ACTIONS(5612),
    [anon_sym_string] = ACTIONS(5612),
    [anon_sym_chandle] = ACTIONS(5612),
    [anon_sym_event] = ACTIONS(5612),
    [anon_sym_byte] = ACTIONS(5612),
    [anon_sym_shortint] = ACTIONS(5612),
    [anon_sym_int] = ACTIONS(5612),
    [anon_sym_longint] = ACTIONS(5612),
    [anon_sym_integer] = ACTIONS(5612),
    [anon_sym_time] = ACTIONS(5612),
    [anon_sym_bit] = ACTIONS(5612),
    [anon_sym_logic] = ACTIONS(5612),
    [anon_sym_reg] = ACTIONS(5612),
    [anon_sym_shortreal] = ACTIONS(5612),
    [anon_sym_real] = ACTIONS(5612),
    [anon_sym_realtime] = ACTIONS(5612),
    [anon_sym_supply0] = ACTIONS(5612),
    [anon_sym_supply1] = ACTIONS(5612),
    [anon_sym_signed] = ACTIONS(5612),
    [anon_sym_unsigned] = ACTIONS(5612),
    [anon_sym_task] = ACTIONS(5612),
    [anon_sym_assert] = ACTIONS(5612),
    [anon_sym_property] = ACTIONS(5612),
    [anon_sym_assume] = ACTIONS(5612),
    [anon_sym_cover] = ACTIONS(5612),
    [anon_sym_sequence] = ACTIONS(5612),
    [anon_sym_restrict] = ACTIONS(5612),
    [anon_sym_not] = ACTIONS(5612),
    [anon_sym_or] = ACTIONS(5612),
    [anon_sym_and] = ACTIONS(5612),
    [anon_sym_case] = ACTIONS(5612),
    [anon_sym_always] = ACTIONS(5612),
    [anon_sym_covergroup] = ACTIONS(5612),
    [anon_sym_let] = ACTIONS(5612),
    [anon_sym_pulldown] = ACTIONS(5612),
    [anon_sym_pullup] = ACTIONS(5612),
    [anon_sym_cmos] = ACTIONS(5612),
    [anon_sym_rcmos] = ACTIONS(5612),
    [anon_sym_bufif0] = ACTIONS(5612),
    [anon_sym_bufif1] = ACTIONS(5612),
    [anon_sym_notif0] = ACTIONS(5612),
    [anon_sym_notif1] = ACTIONS(5612),
    [anon_sym_nmos] = ACTIONS(5612),
    [anon_sym_pmos] = ACTIONS(5612),
    [anon_sym_rnmos] = ACTIONS(5612),
    [anon_sym_rpmos] = ACTIONS(5612),
    [anon_sym_nand] = ACTIONS(5612),
    [anon_sym_nor] = ACTIONS(5612),
    [anon_sym_xor] = ACTIONS(5612),
    [anon_sym_xnor] = ACTIONS(5612),
    [anon_sym_buf] = ACTIONS(5612),
    [anon_sym_tranif0] = ACTIONS(5612),
    [anon_sym_tranif1] = ACTIONS(5612),
    [anon_sym_rtranif1] = ACTIONS(5612),
    [anon_sym_rtranif0] = ACTIONS(5612),
    [anon_sym_tran] = ACTIONS(5612),
    [anon_sym_rtran] = ACTIONS(5612),
    [anon_sym_generate] = ACTIONS(5612),
    [anon_sym_endgenerate] = ACTIONS(5612),
    [anon_sym_for] = ACTIONS(5612),
    [anon_sym_initial] = ACTIONS(5612),
    [anon_sym_assign] = ACTIONS(5612),
    [anon_sym_alias] = ACTIONS(5612),
    [anon_sym_always_comb] = ACTIONS(5612),
    [anon_sym_always_latch] = ACTIONS(5612),
    [anon_sym_always_ff] = ACTIONS(5612),
    [anon_sym_final] = ACTIONS(5612),
    [anon_sym_global] = ACTIONS(5612),
    [anon_sym_LPAREN_STAR] = ACTIONS(5614),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5614),
    [anon_sym_DOLLARunit] = ACTIONS(5614),
  },
  [4528] = {
    [sym_simple_identifier] = ACTIONS(4512),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_COLON] = ACTIONS(10773),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_rand] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_end] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [4529] = {
    [sym_simple_identifier] = ACTIONS(4322),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_COLON] = ACTIONS(10775),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_rand] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_end] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [4530] = {
    [sym_simple_identifier] = ACTIONS(4364),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_COLON] = ACTIONS(10777),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_rand] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_end] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [4531] = {
    [sym_simple_identifier] = ACTIONS(4334),
    [anon_sym_wire] = ACTIONS(4334),
    [anon_sym_tri] = ACTIONS(4334),
    [anon_sym_tri0] = ACTIONS(4334),
    [anon_sym_tri1] = ACTIONS(4334),
    [anon_sym_wand] = ACTIONS(4334),
    [anon_sym_triand] = ACTIONS(4334),
    [anon_sym_wor] = ACTIONS(4334),
    [anon_sym_trior] = ACTIONS(4334),
    [anon_sym_trireg] = ACTIONS(4334),
    [anon_sym_uwire] = ACTIONS(4334),
    [anon_sym_SEMI] = ACTIONS(4332),
    [anon_sym_COLON] = ACTIONS(10779),
    [anon_sym_extern] = ACTIONS(4334),
    [anon_sym_interface] = ACTIONS(4334),
    [anon_sym_checker] = ACTIONS(4334),
    [anon_sym_virtual] = ACTIONS(4334),
    [anon_sym_class] = ACTIONS(4334),
    [anon_sym_type] = ACTIONS(4334),
    [anon_sym_DOLLARfatal] = ACTIONS(4332),
    [anon_sym_DOLLARerror] = ACTIONS(4332),
    [anon_sym_DOLLARwarning] = ACTIONS(4332),
    [anon_sym_DOLLARinfo] = ACTIONS(4332),
    [anon_sym_default] = ACTIONS(4334),
    [anon_sym_clocking] = ACTIONS(4334),
    [anon_sym_defparam] = ACTIONS(4334),
    [anon_sym_bind] = ACTIONS(4334),
    [anon_sym_rand] = ACTIONS(4334),
    [anon_sym_const] = ACTIONS(4334),
    [anon_sym_function] = ACTIONS(4334),
    [anon_sym_static] = ACTIONS(4334),
    [anon_sym_constraint] = ACTIONS(4334),
    [anon_sym_if] = ACTIONS(4334),
    [anon_sym_else] = ACTIONS(4334),
    [anon_sym_LBRACK] = ACTIONS(4332),
    [anon_sym_localparam] = ACTIONS(4334),
    [anon_sym_parameter] = ACTIONS(4334),
    [anon_sym_var] = ACTIONS(4334),
    [anon_sym_import] = ACTIONS(4334),
    [anon_sym_export] = ACTIONS(4334),
    [anon_sym_genvar] = ACTIONS(4334),
    [anon_sym_interconnect] = ACTIONS(4334),
    [anon_sym_typedef] = ACTIONS(4334),
    [anon_sym_enum] = ACTIONS(4334),
    [anon_sym_struct] = ACTIONS(4334),
    [anon_sym_union] = ACTIONS(4334),
    [anon_sym_nettype] = ACTIONS(4334),
    [anon_sym_automatic] = ACTIONS(4334),
    [anon_sym_string] = ACTIONS(4334),
    [anon_sym_chandle] = ACTIONS(4334),
    [anon_sym_event] = ACTIONS(4334),
    [anon_sym_byte] = ACTIONS(4334),
    [anon_sym_shortint] = ACTIONS(4334),
    [anon_sym_int] = ACTIONS(4334),
    [anon_sym_longint] = ACTIONS(4334),
    [anon_sym_integer] = ACTIONS(4334),
    [anon_sym_time] = ACTIONS(4334),
    [anon_sym_bit] = ACTIONS(4334),
    [anon_sym_logic] = ACTIONS(4334),
    [anon_sym_reg] = ACTIONS(4334),
    [anon_sym_shortreal] = ACTIONS(4334),
    [anon_sym_real] = ACTIONS(4334),
    [anon_sym_realtime] = ACTIONS(4334),
    [anon_sym_supply0] = ACTIONS(4334),
    [anon_sym_supply1] = ACTIONS(4334),
    [anon_sym_signed] = ACTIONS(4334),
    [anon_sym_unsigned] = ACTIONS(4334),
    [anon_sym_task] = ACTIONS(4334),
    [anon_sym_assert] = ACTIONS(4334),
    [anon_sym_property] = ACTIONS(4334),
    [anon_sym_assume] = ACTIONS(4334),
    [anon_sym_cover] = ACTIONS(4334),
    [anon_sym_sequence] = ACTIONS(4334),
    [anon_sym_restrict] = ACTIONS(4334),
    [anon_sym_not] = ACTIONS(4334),
    [anon_sym_or] = ACTIONS(4334),
    [anon_sym_and] = ACTIONS(4334),
    [anon_sym_case] = ACTIONS(4334),
    [anon_sym_always] = ACTIONS(4334),
    [anon_sym_covergroup] = ACTIONS(4334),
    [anon_sym_let] = ACTIONS(4334),
    [anon_sym_pulldown] = ACTIONS(4334),
    [anon_sym_pullup] = ACTIONS(4334),
    [anon_sym_cmos] = ACTIONS(4334),
    [anon_sym_rcmos] = ACTIONS(4334),
    [anon_sym_bufif0] = ACTIONS(4334),
    [anon_sym_bufif1] = ACTIONS(4334),
    [anon_sym_notif0] = ACTIONS(4334),
    [anon_sym_notif1] = ACTIONS(4334),
    [anon_sym_nmos] = ACTIONS(4334),
    [anon_sym_pmos] = ACTIONS(4334),
    [anon_sym_rnmos] = ACTIONS(4334),
    [anon_sym_rpmos] = ACTIONS(4334),
    [anon_sym_nand] = ACTIONS(4334),
    [anon_sym_nor] = ACTIONS(4334),
    [anon_sym_xor] = ACTIONS(4334),
    [anon_sym_xnor] = ACTIONS(4334),
    [anon_sym_buf] = ACTIONS(4334),
    [anon_sym_tranif0] = ACTIONS(4334),
    [anon_sym_tranif1] = ACTIONS(4334),
    [anon_sym_rtranif1] = ACTIONS(4334),
    [anon_sym_rtranif0] = ACTIONS(4334),
    [anon_sym_tran] = ACTIONS(4334),
    [anon_sym_rtran] = ACTIONS(4334),
    [anon_sym_generate] = ACTIONS(4334),
    [anon_sym_endgenerate] = ACTIONS(4334),
    [anon_sym_for] = ACTIONS(4334),
    [anon_sym_initial] = ACTIONS(4334),
    [anon_sym_assign] = ACTIONS(4334),
    [anon_sym_alias] = ACTIONS(4334),
    [anon_sym_always_comb] = ACTIONS(4334),
    [anon_sym_always_latch] = ACTIONS(4334),
    [anon_sym_always_ff] = ACTIONS(4334),
    [anon_sym_final] = ACTIONS(4334),
    [anon_sym_global] = ACTIONS(4334),
    [anon_sym_LPAREN_STAR] = ACTIONS(4332),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4332),
    [anon_sym_DOLLARunit] = ACTIONS(4332),
  },
  [4532] = {
    [sym_simple_identifier] = ACTIONS(4132),
    [anon_sym_wire] = ACTIONS(4132),
    [anon_sym_tri] = ACTIONS(4132),
    [anon_sym_tri0] = ACTIONS(4132),
    [anon_sym_tri1] = ACTIONS(4132),
    [anon_sym_wand] = ACTIONS(4132),
    [anon_sym_triand] = ACTIONS(4132),
    [anon_sym_wor] = ACTIONS(4132),
    [anon_sym_trior] = ACTIONS(4132),
    [anon_sym_trireg] = ACTIONS(4132),
    [anon_sym_uwire] = ACTIONS(4132),
    [anon_sym_SEMI] = ACTIONS(4130),
    [anon_sym_COLON] = ACTIONS(10781),
    [anon_sym_extern] = ACTIONS(4132),
    [anon_sym_interface] = ACTIONS(4132),
    [anon_sym_checker] = ACTIONS(4132),
    [anon_sym_virtual] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4132),
    [anon_sym_type] = ACTIONS(4132),
    [anon_sym_DOLLARfatal] = ACTIONS(4130),
    [anon_sym_DOLLARerror] = ACTIONS(4130),
    [anon_sym_DOLLARwarning] = ACTIONS(4130),
    [anon_sym_DOLLARinfo] = ACTIONS(4130),
    [anon_sym_default] = ACTIONS(4132),
    [anon_sym_clocking] = ACTIONS(4132),
    [anon_sym_defparam] = ACTIONS(4132),
    [anon_sym_bind] = ACTIONS(4132),
    [anon_sym_rand] = ACTIONS(4132),
    [anon_sym_const] = ACTIONS(4132),
    [anon_sym_function] = ACTIONS(4132),
    [anon_sym_static] = ACTIONS(4132),
    [anon_sym_constraint] = ACTIONS(4132),
    [anon_sym_if] = ACTIONS(4132),
    [anon_sym_else] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4130),
    [anon_sym_localparam] = ACTIONS(4132),
    [anon_sym_parameter] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4132),
    [anon_sym_import] = ACTIONS(4132),
    [anon_sym_export] = ACTIONS(4132),
    [anon_sym_genvar] = ACTIONS(4132),
    [anon_sym_interconnect] = ACTIONS(4132),
    [anon_sym_typedef] = ACTIONS(4132),
    [anon_sym_enum] = ACTIONS(4132),
    [anon_sym_struct] = ACTIONS(4132),
    [anon_sym_union] = ACTIONS(4132),
    [anon_sym_nettype] = ACTIONS(4132),
    [anon_sym_automatic] = ACTIONS(4132),
    [anon_sym_string] = ACTIONS(4132),
    [anon_sym_chandle] = ACTIONS(4132),
    [anon_sym_event] = ACTIONS(4132),
    [anon_sym_byte] = ACTIONS(4132),
    [anon_sym_shortint] = ACTIONS(4132),
    [anon_sym_int] = ACTIONS(4132),
    [anon_sym_longint] = ACTIONS(4132),
    [anon_sym_integer] = ACTIONS(4132),
    [anon_sym_time] = ACTIONS(4132),
    [anon_sym_bit] = ACTIONS(4132),
    [anon_sym_logic] = ACTIONS(4132),
    [anon_sym_reg] = ACTIONS(4132),
    [anon_sym_shortreal] = ACTIONS(4132),
    [anon_sym_real] = ACTIONS(4132),
    [anon_sym_realtime] = ACTIONS(4132),
    [anon_sym_supply0] = ACTIONS(4132),
    [anon_sym_supply1] = ACTIONS(4132),
    [anon_sym_signed] = ACTIONS(4132),
    [anon_sym_unsigned] = ACTIONS(4132),
    [anon_sym_task] = ACTIONS(4132),
    [anon_sym_assert] = ACTIONS(4132),
    [anon_sym_property] = ACTIONS(4132),
    [anon_sym_assume] = ACTIONS(4132),
    [anon_sym_cover] = ACTIONS(4132),
    [anon_sym_sequence] = ACTIONS(4132),
    [anon_sym_restrict] = ACTIONS(4132),
    [anon_sym_not] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_case] = ACTIONS(4132),
    [anon_sym_always] = ACTIONS(4132),
    [anon_sym_covergroup] = ACTIONS(4132),
    [anon_sym_end] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_pulldown] = ACTIONS(4132),
    [anon_sym_pullup] = ACTIONS(4132),
    [anon_sym_cmos] = ACTIONS(4132),
    [anon_sym_rcmos] = ACTIONS(4132),
    [anon_sym_bufif0] = ACTIONS(4132),
    [anon_sym_bufif1] = ACTIONS(4132),
    [anon_sym_notif0] = ACTIONS(4132),
    [anon_sym_notif1] = ACTIONS(4132),
    [anon_sym_nmos] = ACTIONS(4132),
    [anon_sym_pmos] = ACTIONS(4132),
    [anon_sym_rnmos] = ACTIONS(4132),
    [anon_sym_rpmos] = ACTIONS(4132),
    [anon_sym_nand] = ACTIONS(4132),
    [anon_sym_nor] = ACTIONS(4132),
    [anon_sym_xor] = ACTIONS(4132),
    [anon_sym_xnor] = ACTIONS(4132),
    [anon_sym_buf] = ACTIONS(4132),
    [anon_sym_tranif0] = ACTIONS(4132),
    [anon_sym_tranif1] = ACTIONS(4132),
    [anon_sym_rtranif1] = ACTIONS(4132),
    [anon_sym_rtranif0] = ACTIONS(4132),
    [anon_sym_tran] = ACTIONS(4132),
    [anon_sym_rtran] = ACTIONS(4132),
    [anon_sym_generate] = ACTIONS(4132),
    [anon_sym_for] = ACTIONS(4132),
    [anon_sym_initial] = ACTIONS(4132),
    [anon_sym_assign] = ACTIONS(4132),
    [anon_sym_alias] = ACTIONS(4132),
    [anon_sym_always_comb] = ACTIONS(4132),
    [anon_sym_always_latch] = ACTIONS(4132),
    [anon_sym_always_ff] = ACTIONS(4132),
    [anon_sym_final] = ACTIONS(4132),
    [anon_sym_global] = ACTIONS(4132),
    [anon_sym_LPAREN_STAR] = ACTIONS(4130),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4130),
    [anon_sym_DOLLARunit] = ACTIONS(4130),
  },
  [4533] = {
    [sym_simple_identifier] = ACTIONS(4560),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_COLON] = ACTIONS(10783),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_rand] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_end] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [4534] = {
    [sym_simple_identifier] = ACTIONS(4618),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_COLON] = ACTIONS(10785),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_rand] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_end] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [4535] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_COLON] = ACTIONS(10787),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_rand] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_end] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [4536] = {
    [sym_simple_identifier] = ACTIONS(4280),
    [anon_sym_wire] = ACTIONS(4280),
    [anon_sym_tri] = ACTIONS(4280),
    [anon_sym_tri0] = ACTIONS(4280),
    [anon_sym_tri1] = ACTIONS(4280),
    [anon_sym_wand] = ACTIONS(4280),
    [anon_sym_triand] = ACTIONS(4280),
    [anon_sym_wor] = ACTIONS(4280),
    [anon_sym_trior] = ACTIONS(4280),
    [anon_sym_trireg] = ACTIONS(4280),
    [anon_sym_uwire] = ACTIONS(4280),
    [anon_sym_SEMI] = ACTIONS(4278),
    [anon_sym_COLON] = ACTIONS(10789),
    [anon_sym_extern] = ACTIONS(4280),
    [anon_sym_interface] = ACTIONS(4280),
    [anon_sym_checker] = ACTIONS(4280),
    [anon_sym_virtual] = ACTIONS(4280),
    [anon_sym_class] = ACTIONS(4280),
    [anon_sym_type] = ACTIONS(4280),
    [anon_sym_DOLLARfatal] = ACTIONS(4278),
    [anon_sym_DOLLARerror] = ACTIONS(4278),
    [anon_sym_DOLLARwarning] = ACTIONS(4278),
    [anon_sym_DOLLARinfo] = ACTIONS(4278),
    [anon_sym_default] = ACTIONS(4280),
    [anon_sym_clocking] = ACTIONS(4280),
    [anon_sym_defparam] = ACTIONS(4280),
    [anon_sym_bind] = ACTIONS(4280),
    [anon_sym_rand] = ACTIONS(4280),
    [anon_sym_const] = ACTIONS(4280),
    [anon_sym_function] = ACTIONS(4280),
    [anon_sym_static] = ACTIONS(4280),
    [anon_sym_constraint] = ACTIONS(4280),
    [anon_sym_if] = ACTIONS(4280),
    [anon_sym_else] = ACTIONS(4280),
    [anon_sym_LBRACK] = ACTIONS(4278),
    [anon_sym_localparam] = ACTIONS(4280),
    [anon_sym_parameter] = ACTIONS(4280),
    [anon_sym_var] = ACTIONS(4280),
    [anon_sym_import] = ACTIONS(4280),
    [anon_sym_export] = ACTIONS(4280),
    [anon_sym_genvar] = ACTIONS(4280),
    [anon_sym_interconnect] = ACTIONS(4280),
    [anon_sym_typedef] = ACTIONS(4280),
    [anon_sym_enum] = ACTIONS(4280),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_union] = ACTIONS(4280),
    [anon_sym_nettype] = ACTIONS(4280),
    [anon_sym_automatic] = ACTIONS(4280),
    [anon_sym_string] = ACTIONS(4280),
    [anon_sym_chandle] = ACTIONS(4280),
    [anon_sym_event] = ACTIONS(4280),
    [anon_sym_byte] = ACTIONS(4280),
    [anon_sym_shortint] = ACTIONS(4280),
    [anon_sym_int] = ACTIONS(4280),
    [anon_sym_longint] = ACTIONS(4280),
    [anon_sym_integer] = ACTIONS(4280),
    [anon_sym_time] = ACTIONS(4280),
    [anon_sym_bit] = ACTIONS(4280),
    [anon_sym_logic] = ACTIONS(4280),
    [anon_sym_reg] = ACTIONS(4280),
    [anon_sym_shortreal] = ACTIONS(4280),
    [anon_sym_real] = ACTIONS(4280),
    [anon_sym_realtime] = ACTIONS(4280),
    [anon_sym_supply0] = ACTIONS(4280),
    [anon_sym_supply1] = ACTIONS(4280),
    [anon_sym_signed] = ACTIONS(4280),
    [anon_sym_unsigned] = ACTIONS(4280),
    [anon_sym_task] = ACTIONS(4280),
    [anon_sym_assert] = ACTIONS(4280),
    [anon_sym_property] = ACTIONS(4280),
    [anon_sym_assume] = ACTIONS(4280),
    [anon_sym_cover] = ACTIONS(4280),
    [anon_sym_sequence] = ACTIONS(4280),
    [anon_sym_restrict] = ACTIONS(4280),
    [anon_sym_not] = ACTIONS(4280),
    [anon_sym_or] = ACTIONS(4280),
    [anon_sym_and] = ACTIONS(4280),
    [anon_sym_case] = ACTIONS(4280),
    [anon_sym_always] = ACTIONS(4280),
    [anon_sym_covergroup] = ACTIONS(4280),
    [anon_sym_end] = ACTIONS(4280),
    [anon_sym_let] = ACTIONS(4280),
    [anon_sym_pulldown] = ACTIONS(4280),
    [anon_sym_pullup] = ACTIONS(4280),
    [anon_sym_cmos] = ACTIONS(4280),
    [anon_sym_rcmos] = ACTIONS(4280),
    [anon_sym_bufif0] = ACTIONS(4280),
    [anon_sym_bufif1] = ACTIONS(4280),
    [anon_sym_notif0] = ACTIONS(4280),
    [anon_sym_notif1] = ACTIONS(4280),
    [anon_sym_nmos] = ACTIONS(4280),
    [anon_sym_pmos] = ACTIONS(4280),
    [anon_sym_rnmos] = ACTIONS(4280),
    [anon_sym_rpmos] = ACTIONS(4280),
    [anon_sym_nand] = ACTIONS(4280),
    [anon_sym_nor] = ACTIONS(4280),
    [anon_sym_xor] = ACTIONS(4280),
    [anon_sym_xnor] = ACTIONS(4280),
    [anon_sym_buf] = ACTIONS(4280),
    [anon_sym_tranif0] = ACTIONS(4280),
    [anon_sym_tranif1] = ACTIONS(4280),
    [anon_sym_rtranif1] = ACTIONS(4280),
    [anon_sym_rtranif0] = ACTIONS(4280),
    [anon_sym_tran] = ACTIONS(4280),
    [anon_sym_rtran] = ACTIONS(4280),
    [anon_sym_generate] = ACTIONS(4280),
    [anon_sym_for] = ACTIONS(4280),
    [anon_sym_initial] = ACTIONS(4280),
    [anon_sym_assign] = ACTIONS(4280),
    [anon_sym_alias] = ACTIONS(4280),
    [anon_sym_always_comb] = ACTIONS(4280),
    [anon_sym_always_latch] = ACTIONS(4280),
    [anon_sym_always_ff] = ACTIONS(4280),
    [anon_sym_final] = ACTIONS(4280),
    [anon_sym_global] = ACTIONS(4280),
    [anon_sym_LPAREN_STAR] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4278),
    [anon_sym_DOLLARunit] = ACTIONS(4278),
  },
  [4537] = {
    [sym_simple_identifier] = ACTIONS(4346),
    [anon_sym_wire] = ACTIONS(4346),
    [anon_sym_tri] = ACTIONS(4346),
    [anon_sym_tri0] = ACTIONS(4346),
    [anon_sym_tri1] = ACTIONS(4346),
    [anon_sym_wand] = ACTIONS(4346),
    [anon_sym_triand] = ACTIONS(4346),
    [anon_sym_wor] = ACTIONS(4346),
    [anon_sym_trior] = ACTIONS(4346),
    [anon_sym_trireg] = ACTIONS(4346),
    [anon_sym_uwire] = ACTIONS(4346),
    [anon_sym_SEMI] = ACTIONS(4344),
    [anon_sym_COLON] = ACTIONS(10791),
    [anon_sym_extern] = ACTIONS(4346),
    [anon_sym_interface] = ACTIONS(4346),
    [anon_sym_checker] = ACTIONS(4346),
    [anon_sym_virtual] = ACTIONS(4346),
    [anon_sym_class] = ACTIONS(4346),
    [anon_sym_type] = ACTIONS(4346),
    [anon_sym_DOLLARfatal] = ACTIONS(4344),
    [anon_sym_DOLLARerror] = ACTIONS(4344),
    [anon_sym_DOLLARwarning] = ACTIONS(4344),
    [anon_sym_DOLLARinfo] = ACTIONS(4344),
    [anon_sym_default] = ACTIONS(4346),
    [anon_sym_clocking] = ACTIONS(4346),
    [anon_sym_defparam] = ACTIONS(4346),
    [anon_sym_bind] = ACTIONS(4346),
    [anon_sym_rand] = ACTIONS(4346),
    [anon_sym_const] = ACTIONS(4346),
    [anon_sym_function] = ACTIONS(4346),
    [anon_sym_static] = ACTIONS(4346),
    [anon_sym_constraint] = ACTIONS(4346),
    [anon_sym_if] = ACTIONS(4346),
    [anon_sym_else] = ACTIONS(4346),
    [anon_sym_LBRACK] = ACTIONS(4344),
    [anon_sym_localparam] = ACTIONS(4346),
    [anon_sym_parameter] = ACTIONS(4346),
    [anon_sym_var] = ACTIONS(4346),
    [anon_sym_import] = ACTIONS(4346),
    [anon_sym_export] = ACTIONS(4346),
    [anon_sym_genvar] = ACTIONS(4346),
    [anon_sym_interconnect] = ACTIONS(4346),
    [anon_sym_typedef] = ACTIONS(4346),
    [anon_sym_enum] = ACTIONS(4346),
    [anon_sym_struct] = ACTIONS(4346),
    [anon_sym_union] = ACTIONS(4346),
    [anon_sym_nettype] = ACTIONS(4346),
    [anon_sym_automatic] = ACTIONS(4346),
    [anon_sym_string] = ACTIONS(4346),
    [anon_sym_chandle] = ACTIONS(4346),
    [anon_sym_event] = ACTIONS(4346),
    [anon_sym_byte] = ACTIONS(4346),
    [anon_sym_shortint] = ACTIONS(4346),
    [anon_sym_int] = ACTIONS(4346),
    [anon_sym_longint] = ACTIONS(4346),
    [anon_sym_integer] = ACTIONS(4346),
    [anon_sym_time] = ACTIONS(4346),
    [anon_sym_bit] = ACTIONS(4346),
    [anon_sym_logic] = ACTIONS(4346),
    [anon_sym_reg] = ACTIONS(4346),
    [anon_sym_shortreal] = ACTIONS(4346),
    [anon_sym_real] = ACTIONS(4346),
    [anon_sym_realtime] = ACTIONS(4346),
    [anon_sym_supply0] = ACTIONS(4346),
    [anon_sym_supply1] = ACTIONS(4346),
    [anon_sym_signed] = ACTIONS(4346),
    [anon_sym_unsigned] = ACTIONS(4346),
    [anon_sym_task] = ACTIONS(4346),
    [anon_sym_assert] = ACTIONS(4346),
    [anon_sym_property] = ACTIONS(4346),
    [anon_sym_assume] = ACTIONS(4346),
    [anon_sym_cover] = ACTIONS(4346),
    [anon_sym_sequence] = ACTIONS(4346),
    [anon_sym_restrict] = ACTIONS(4346),
    [anon_sym_not] = ACTIONS(4346),
    [anon_sym_or] = ACTIONS(4346),
    [anon_sym_and] = ACTIONS(4346),
    [anon_sym_case] = ACTIONS(4346),
    [anon_sym_always] = ACTIONS(4346),
    [anon_sym_covergroup] = ACTIONS(4346),
    [anon_sym_let] = ACTIONS(4346),
    [anon_sym_pulldown] = ACTIONS(4346),
    [anon_sym_pullup] = ACTIONS(4346),
    [anon_sym_cmos] = ACTIONS(4346),
    [anon_sym_rcmos] = ACTIONS(4346),
    [anon_sym_bufif0] = ACTIONS(4346),
    [anon_sym_bufif1] = ACTIONS(4346),
    [anon_sym_notif0] = ACTIONS(4346),
    [anon_sym_notif1] = ACTIONS(4346),
    [anon_sym_nmos] = ACTIONS(4346),
    [anon_sym_pmos] = ACTIONS(4346),
    [anon_sym_rnmos] = ACTIONS(4346),
    [anon_sym_rpmos] = ACTIONS(4346),
    [anon_sym_nand] = ACTIONS(4346),
    [anon_sym_nor] = ACTIONS(4346),
    [anon_sym_xor] = ACTIONS(4346),
    [anon_sym_xnor] = ACTIONS(4346),
    [anon_sym_buf] = ACTIONS(4346),
    [anon_sym_tranif0] = ACTIONS(4346),
    [anon_sym_tranif1] = ACTIONS(4346),
    [anon_sym_rtranif1] = ACTIONS(4346),
    [anon_sym_rtranif0] = ACTIONS(4346),
    [anon_sym_tran] = ACTIONS(4346),
    [anon_sym_rtran] = ACTIONS(4346),
    [anon_sym_generate] = ACTIONS(4346),
    [anon_sym_endgenerate] = ACTIONS(4346),
    [anon_sym_for] = ACTIONS(4346),
    [anon_sym_initial] = ACTIONS(4346),
    [anon_sym_assign] = ACTIONS(4346),
    [anon_sym_alias] = ACTIONS(4346),
    [anon_sym_always_comb] = ACTIONS(4346),
    [anon_sym_always_latch] = ACTIONS(4346),
    [anon_sym_always_ff] = ACTIONS(4346),
    [anon_sym_final] = ACTIONS(4346),
    [anon_sym_global] = ACTIONS(4346),
    [anon_sym_LPAREN_STAR] = ACTIONS(4344),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4344),
    [anon_sym_DOLLARunit] = ACTIONS(4344),
  },
  [4538] = {
    [sym_simple_identifier] = ACTIONS(4376),
    [anon_sym_wire] = ACTIONS(4376),
    [anon_sym_tri] = ACTIONS(4376),
    [anon_sym_tri0] = ACTIONS(4376),
    [anon_sym_tri1] = ACTIONS(4376),
    [anon_sym_wand] = ACTIONS(4376),
    [anon_sym_triand] = ACTIONS(4376),
    [anon_sym_wor] = ACTIONS(4376),
    [anon_sym_trior] = ACTIONS(4376),
    [anon_sym_trireg] = ACTIONS(4376),
    [anon_sym_uwire] = ACTIONS(4376),
    [anon_sym_SEMI] = ACTIONS(4374),
    [anon_sym_COLON] = ACTIONS(10793),
    [anon_sym_extern] = ACTIONS(4376),
    [anon_sym_interface] = ACTIONS(4376),
    [anon_sym_checker] = ACTIONS(4376),
    [anon_sym_virtual] = ACTIONS(4376),
    [anon_sym_class] = ACTIONS(4376),
    [anon_sym_type] = ACTIONS(4376),
    [anon_sym_DOLLARfatal] = ACTIONS(4374),
    [anon_sym_DOLLARerror] = ACTIONS(4374),
    [anon_sym_DOLLARwarning] = ACTIONS(4374),
    [anon_sym_DOLLARinfo] = ACTIONS(4374),
    [anon_sym_default] = ACTIONS(4376),
    [anon_sym_clocking] = ACTIONS(4376),
    [anon_sym_defparam] = ACTIONS(4376),
    [anon_sym_bind] = ACTIONS(4376),
    [anon_sym_rand] = ACTIONS(4376),
    [anon_sym_const] = ACTIONS(4376),
    [anon_sym_function] = ACTIONS(4376),
    [anon_sym_static] = ACTIONS(4376),
    [anon_sym_constraint] = ACTIONS(4376),
    [anon_sym_if] = ACTIONS(4376),
    [anon_sym_else] = ACTIONS(4376),
    [anon_sym_LBRACK] = ACTIONS(4374),
    [anon_sym_localparam] = ACTIONS(4376),
    [anon_sym_parameter] = ACTIONS(4376),
    [anon_sym_var] = ACTIONS(4376),
    [anon_sym_import] = ACTIONS(4376),
    [anon_sym_export] = ACTIONS(4376),
    [anon_sym_genvar] = ACTIONS(4376),
    [anon_sym_interconnect] = ACTIONS(4376),
    [anon_sym_typedef] = ACTIONS(4376),
    [anon_sym_enum] = ACTIONS(4376),
    [anon_sym_struct] = ACTIONS(4376),
    [anon_sym_union] = ACTIONS(4376),
    [anon_sym_nettype] = ACTIONS(4376),
    [anon_sym_automatic] = ACTIONS(4376),
    [anon_sym_string] = ACTIONS(4376),
    [anon_sym_chandle] = ACTIONS(4376),
    [anon_sym_event] = ACTIONS(4376),
    [anon_sym_byte] = ACTIONS(4376),
    [anon_sym_shortint] = ACTIONS(4376),
    [anon_sym_int] = ACTIONS(4376),
    [anon_sym_longint] = ACTIONS(4376),
    [anon_sym_integer] = ACTIONS(4376),
    [anon_sym_time] = ACTIONS(4376),
    [anon_sym_bit] = ACTIONS(4376),
    [anon_sym_logic] = ACTIONS(4376),
    [anon_sym_reg] = ACTIONS(4376),
    [anon_sym_shortreal] = ACTIONS(4376),
    [anon_sym_real] = ACTIONS(4376),
    [anon_sym_realtime] = ACTIONS(4376),
    [anon_sym_supply0] = ACTIONS(4376),
    [anon_sym_supply1] = ACTIONS(4376),
    [anon_sym_signed] = ACTIONS(4376),
    [anon_sym_unsigned] = ACTIONS(4376),
    [anon_sym_task] = ACTIONS(4376),
    [anon_sym_assert] = ACTIONS(4376),
    [anon_sym_property] = ACTIONS(4376),
    [anon_sym_assume] = ACTIONS(4376),
    [anon_sym_cover] = ACTIONS(4376),
    [anon_sym_sequence] = ACTIONS(4376),
    [anon_sym_restrict] = ACTIONS(4376),
    [anon_sym_not] = ACTIONS(4376),
    [anon_sym_or] = ACTIONS(4376),
    [anon_sym_and] = ACTIONS(4376),
    [anon_sym_case] = ACTIONS(4376),
    [anon_sym_always] = ACTIONS(4376),
    [anon_sym_covergroup] = ACTIONS(4376),
    [anon_sym_let] = ACTIONS(4376),
    [anon_sym_pulldown] = ACTIONS(4376),
    [anon_sym_pullup] = ACTIONS(4376),
    [anon_sym_cmos] = ACTIONS(4376),
    [anon_sym_rcmos] = ACTIONS(4376),
    [anon_sym_bufif0] = ACTIONS(4376),
    [anon_sym_bufif1] = ACTIONS(4376),
    [anon_sym_notif0] = ACTIONS(4376),
    [anon_sym_notif1] = ACTIONS(4376),
    [anon_sym_nmos] = ACTIONS(4376),
    [anon_sym_pmos] = ACTIONS(4376),
    [anon_sym_rnmos] = ACTIONS(4376),
    [anon_sym_rpmos] = ACTIONS(4376),
    [anon_sym_nand] = ACTIONS(4376),
    [anon_sym_nor] = ACTIONS(4376),
    [anon_sym_xor] = ACTIONS(4376),
    [anon_sym_xnor] = ACTIONS(4376),
    [anon_sym_buf] = ACTIONS(4376),
    [anon_sym_tranif0] = ACTIONS(4376),
    [anon_sym_tranif1] = ACTIONS(4376),
    [anon_sym_rtranif1] = ACTIONS(4376),
    [anon_sym_rtranif0] = ACTIONS(4376),
    [anon_sym_tran] = ACTIONS(4376),
    [anon_sym_rtran] = ACTIONS(4376),
    [anon_sym_generate] = ACTIONS(4376),
    [anon_sym_endgenerate] = ACTIONS(4376),
    [anon_sym_for] = ACTIONS(4376),
    [anon_sym_initial] = ACTIONS(4376),
    [anon_sym_assign] = ACTIONS(4376),
    [anon_sym_alias] = ACTIONS(4376),
    [anon_sym_always_comb] = ACTIONS(4376),
    [anon_sym_always_latch] = ACTIONS(4376),
    [anon_sym_always_ff] = ACTIONS(4376),
    [anon_sym_final] = ACTIONS(4376),
    [anon_sym_global] = ACTIONS(4376),
    [anon_sym_LPAREN_STAR] = ACTIONS(4374),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4374),
    [anon_sym_DOLLARunit] = ACTIONS(4374),
  },
  [4539] = {
    [sym_simple_identifier] = ACTIONS(4394),
    [anon_sym_wire] = ACTIONS(4394),
    [anon_sym_tri] = ACTIONS(4394),
    [anon_sym_tri0] = ACTIONS(4394),
    [anon_sym_tri1] = ACTIONS(4394),
    [anon_sym_wand] = ACTIONS(4394),
    [anon_sym_triand] = ACTIONS(4394),
    [anon_sym_wor] = ACTIONS(4394),
    [anon_sym_trior] = ACTIONS(4394),
    [anon_sym_trireg] = ACTIONS(4394),
    [anon_sym_uwire] = ACTIONS(4394),
    [anon_sym_SEMI] = ACTIONS(4392),
    [anon_sym_COLON] = ACTIONS(10795),
    [anon_sym_extern] = ACTIONS(4394),
    [anon_sym_interface] = ACTIONS(4394),
    [anon_sym_checker] = ACTIONS(4394),
    [anon_sym_virtual] = ACTIONS(4394),
    [anon_sym_class] = ACTIONS(4394),
    [anon_sym_type] = ACTIONS(4394),
    [anon_sym_DOLLARfatal] = ACTIONS(4392),
    [anon_sym_DOLLARerror] = ACTIONS(4392),
    [anon_sym_DOLLARwarning] = ACTIONS(4392),
    [anon_sym_DOLLARinfo] = ACTIONS(4392),
    [anon_sym_default] = ACTIONS(4394),
    [anon_sym_clocking] = ACTIONS(4394),
    [anon_sym_defparam] = ACTIONS(4394),
    [anon_sym_bind] = ACTIONS(4394),
    [anon_sym_rand] = ACTIONS(4394),
    [anon_sym_const] = ACTIONS(4394),
    [anon_sym_function] = ACTIONS(4394),
    [anon_sym_static] = ACTIONS(4394),
    [anon_sym_constraint] = ACTIONS(4394),
    [anon_sym_if] = ACTIONS(4394),
    [anon_sym_else] = ACTIONS(4394),
    [anon_sym_LBRACK] = ACTIONS(4392),
    [anon_sym_localparam] = ACTIONS(4394),
    [anon_sym_parameter] = ACTIONS(4394),
    [anon_sym_var] = ACTIONS(4394),
    [anon_sym_import] = ACTIONS(4394),
    [anon_sym_export] = ACTIONS(4394),
    [anon_sym_genvar] = ACTIONS(4394),
    [anon_sym_interconnect] = ACTIONS(4394),
    [anon_sym_typedef] = ACTIONS(4394),
    [anon_sym_enum] = ACTIONS(4394),
    [anon_sym_struct] = ACTIONS(4394),
    [anon_sym_union] = ACTIONS(4394),
    [anon_sym_nettype] = ACTIONS(4394),
    [anon_sym_automatic] = ACTIONS(4394),
    [anon_sym_string] = ACTIONS(4394),
    [anon_sym_chandle] = ACTIONS(4394),
    [anon_sym_event] = ACTIONS(4394),
    [anon_sym_byte] = ACTIONS(4394),
    [anon_sym_shortint] = ACTIONS(4394),
    [anon_sym_int] = ACTIONS(4394),
    [anon_sym_longint] = ACTIONS(4394),
    [anon_sym_integer] = ACTIONS(4394),
    [anon_sym_time] = ACTIONS(4394),
    [anon_sym_bit] = ACTIONS(4394),
    [anon_sym_logic] = ACTIONS(4394),
    [anon_sym_reg] = ACTIONS(4394),
    [anon_sym_shortreal] = ACTIONS(4394),
    [anon_sym_real] = ACTIONS(4394),
    [anon_sym_realtime] = ACTIONS(4394),
    [anon_sym_supply0] = ACTIONS(4394),
    [anon_sym_supply1] = ACTIONS(4394),
    [anon_sym_signed] = ACTIONS(4394),
    [anon_sym_unsigned] = ACTIONS(4394),
    [anon_sym_task] = ACTIONS(4394),
    [anon_sym_assert] = ACTIONS(4394),
    [anon_sym_property] = ACTIONS(4394),
    [anon_sym_assume] = ACTIONS(4394),
    [anon_sym_cover] = ACTIONS(4394),
    [anon_sym_sequence] = ACTIONS(4394),
    [anon_sym_restrict] = ACTIONS(4394),
    [anon_sym_not] = ACTIONS(4394),
    [anon_sym_or] = ACTIONS(4394),
    [anon_sym_and] = ACTIONS(4394),
    [anon_sym_case] = ACTIONS(4394),
    [anon_sym_always] = ACTIONS(4394),
    [anon_sym_covergroup] = ACTIONS(4394),
    [anon_sym_let] = ACTIONS(4394),
    [anon_sym_pulldown] = ACTIONS(4394),
    [anon_sym_pullup] = ACTIONS(4394),
    [anon_sym_cmos] = ACTIONS(4394),
    [anon_sym_rcmos] = ACTIONS(4394),
    [anon_sym_bufif0] = ACTIONS(4394),
    [anon_sym_bufif1] = ACTIONS(4394),
    [anon_sym_notif0] = ACTIONS(4394),
    [anon_sym_notif1] = ACTIONS(4394),
    [anon_sym_nmos] = ACTIONS(4394),
    [anon_sym_pmos] = ACTIONS(4394),
    [anon_sym_rnmos] = ACTIONS(4394),
    [anon_sym_rpmos] = ACTIONS(4394),
    [anon_sym_nand] = ACTIONS(4394),
    [anon_sym_nor] = ACTIONS(4394),
    [anon_sym_xor] = ACTIONS(4394),
    [anon_sym_xnor] = ACTIONS(4394),
    [anon_sym_buf] = ACTIONS(4394),
    [anon_sym_tranif0] = ACTIONS(4394),
    [anon_sym_tranif1] = ACTIONS(4394),
    [anon_sym_rtranif1] = ACTIONS(4394),
    [anon_sym_rtranif0] = ACTIONS(4394),
    [anon_sym_tran] = ACTIONS(4394),
    [anon_sym_rtran] = ACTIONS(4394),
    [anon_sym_generate] = ACTIONS(4394),
    [anon_sym_endgenerate] = ACTIONS(4394),
    [anon_sym_for] = ACTIONS(4394),
    [anon_sym_initial] = ACTIONS(4394),
    [anon_sym_assign] = ACTIONS(4394),
    [anon_sym_alias] = ACTIONS(4394),
    [anon_sym_always_comb] = ACTIONS(4394),
    [anon_sym_always_latch] = ACTIONS(4394),
    [anon_sym_always_ff] = ACTIONS(4394),
    [anon_sym_final] = ACTIONS(4394),
    [anon_sym_global] = ACTIONS(4394),
    [anon_sym_LPAREN_STAR] = ACTIONS(4392),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4392),
    [anon_sym_DOLLARunit] = ACTIONS(4392),
  },
  [4540] = {
    [sym_simple_identifier] = ACTIONS(4346),
    [anon_sym_wire] = ACTIONS(4346),
    [anon_sym_tri] = ACTIONS(4346),
    [anon_sym_tri0] = ACTIONS(4346),
    [anon_sym_tri1] = ACTIONS(4346),
    [anon_sym_wand] = ACTIONS(4346),
    [anon_sym_triand] = ACTIONS(4346),
    [anon_sym_wor] = ACTIONS(4346),
    [anon_sym_trior] = ACTIONS(4346),
    [anon_sym_trireg] = ACTIONS(4346),
    [anon_sym_uwire] = ACTIONS(4346),
    [anon_sym_SEMI] = ACTIONS(4344),
    [anon_sym_COLON] = ACTIONS(10797),
    [anon_sym_extern] = ACTIONS(4346),
    [anon_sym_interface] = ACTIONS(4346),
    [anon_sym_checker] = ACTIONS(4346),
    [anon_sym_virtual] = ACTIONS(4346),
    [anon_sym_class] = ACTIONS(4346),
    [anon_sym_type] = ACTIONS(4346),
    [anon_sym_DOLLARfatal] = ACTIONS(4344),
    [anon_sym_DOLLARerror] = ACTIONS(4344),
    [anon_sym_DOLLARwarning] = ACTIONS(4344),
    [anon_sym_DOLLARinfo] = ACTIONS(4344),
    [anon_sym_default] = ACTIONS(4346),
    [anon_sym_clocking] = ACTIONS(4346),
    [anon_sym_defparam] = ACTIONS(4346),
    [anon_sym_bind] = ACTIONS(4346),
    [anon_sym_rand] = ACTIONS(4346),
    [anon_sym_const] = ACTIONS(4346),
    [anon_sym_function] = ACTIONS(4346),
    [anon_sym_static] = ACTIONS(4346),
    [anon_sym_constraint] = ACTIONS(4346),
    [anon_sym_if] = ACTIONS(4346),
    [anon_sym_else] = ACTIONS(4346),
    [anon_sym_LBRACK] = ACTIONS(4344),
    [anon_sym_localparam] = ACTIONS(4346),
    [anon_sym_parameter] = ACTIONS(4346),
    [anon_sym_var] = ACTIONS(4346),
    [anon_sym_import] = ACTIONS(4346),
    [anon_sym_export] = ACTIONS(4346),
    [anon_sym_genvar] = ACTIONS(4346),
    [anon_sym_interconnect] = ACTIONS(4346),
    [anon_sym_typedef] = ACTIONS(4346),
    [anon_sym_enum] = ACTIONS(4346),
    [anon_sym_struct] = ACTIONS(4346),
    [anon_sym_union] = ACTIONS(4346),
    [anon_sym_nettype] = ACTIONS(4346),
    [anon_sym_automatic] = ACTIONS(4346),
    [anon_sym_string] = ACTIONS(4346),
    [anon_sym_chandle] = ACTIONS(4346),
    [anon_sym_event] = ACTIONS(4346),
    [anon_sym_byte] = ACTIONS(4346),
    [anon_sym_shortint] = ACTIONS(4346),
    [anon_sym_int] = ACTIONS(4346),
    [anon_sym_longint] = ACTIONS(4346),
    [anon_sym_integer] = ACTIONS(4346),
    [anon_sym_time] = ACTIONS(4346),
    [anon_sym_bit] = ACTIONS(4346),
    [anon_sym_logic] = ACTIONS(4346),
    [anon_sym_reg] = ACTIONS(4346),
    [anon_sym_shortreal] = ACTIONS(4346),
    [anon_sym_real] = ACTIONS(4346),
    [anon_sym_realtime] = ACTIONS(4346),
    [anon_sym_supply0] = ACTIONS(4346),
    [anon_sym_supply1] = ACTIONS(4346),
    [anon_sym_signed] = ACTIONS(4346),
    [anon_sym_unsigned] = ACTIONS(4346),
    [anon_sym_task] = ACTIONS(4346),
    [anon_sym_assert] = ACTIONS(4346),
    [anon_sym_property] = ACTIONS(4346),
    [anon_sym_assume] = ACTIONS(4346),
    [anon_sym_cover] = ACTIONS(4346),
    [anon_sym_sequence] = ACTIONS(4346),
    [anon_sym_restrict] = ACTIONS(4346),
    [anon_sym_not] = ACTIONS(4346),
    [anon_sym_or] = ACTIONS(4346),
    [anon_sym_and] = ACTIONS(4346),
    [anon_sym_case] = ACTIONS(4346),
    [anon_sym_always] = ACTIONS(4346),
    [anon_sym_covergroup] = ACTIONS(4346),
    [anon_sym_end] = ACTIONS(4346),
    [anon_sym_let] = ACTIONS(4346),
    [anon_sym_pulldown] = ACTIONS(4346),
    [anon_sym_pullup] = ACTIONS(4346),
    [anon_sym_cmos] = ACTIONS(4346),
    [anon_sym_rcmos] = ACTIONS(4346),
    [anon_sym_bufif0] = ACTIONS(4346),
    [anon_sym_bufif1] = ACTIONS(4346),
    [anon_sym_notif0] = ACTIONS(4346),
    [anon_sym_notif1] = ACTIONS(4346),
    [anon_sym_nmos] = ACTIONS(4346),
    [anon_sym_pmos] = ACTIONS(4346),
    [anon_sym_rnmos] = ACTIONS(4346),
    [anon_sym_rpmos] = ACTIONS(4346),
    [anon_sym_nand] = ACTIONS(4346),
    [anon_sym_nor] = ACTIONS(4346),
    [anon_sym_xor] = ACTIONS(4346),
    [anon_sym_xnor] = ACTIONS(4346),
    [anon_sym_buf] = ACTIONS(4346),
    [anon_sym_tranif0] = ACTIONS(4346),
    [anon_sym_tranif1] = ACTIONS(4346),
    [anon_sym_rtranif1] = ACTIONS(4346),
    [anon_sym_rtranif0] = ACTIONS(4346),
    [anon_sym_tran] = ACTIONS(4346),
    [anon_sym_rtran] = ACTIONS(4346),
    [anon_sym_generate] = ACTIONS(4346),
    [anon_sym_for] = ACTIONS(4346),
    [anon_sym_initial] = ACTIONS(4346),
    [anon_sym_assign] = ACTIONS(4346),
    [anon_sym_alias] = ACTIONS(4346),
    [anon_sym_always_comb] = ACTIONS(4346),
    [anon_sym_always_latch] = ACTIONS(4346),
    [anon_sym_always_ff] = ACTIONS(4346),
    [anon_sym_final] = ACTIONS(4346),
    [anon_sym_global] = ACTIONS(4346),
    [anon_sym_LPAREN_STAR] = ACTIONS(4344),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4344),
    [anon_sym_DOLLARunit] = ACTIONS(4344),
  },
  [4541] = {
    [sym_simple_identifier] = ACTIONS(4376),
    [anon_sym_wire] = ACTIONS(4376),
    [anon_sym_tri] = ACTIONS(4376),
    [anon_sym_tri0] = ACTIONS(4376),
    [anon_sym_tri1] = ACTIONS(4376),
    [anon_sym_wand] = ACTIONS(4376),
    [anon_sym_triand] = ACTIONS(4376),
    [anon_sym_wor] = ACTIONS(4376),
    [anon_sym_trior] = ACTIONS(4376),
    [anon_sym_trireg] = ACTIONS(4376),
    [anon_sym_uwire] = ACTIONS(4376),
    [anon_sym_SEMI] = ACTIONS(4374),
    [anon_sym_COLON] = ACTIONS(10799),
    [anon_sym_extern] = ACTIONS(4376),
    [anon_sym_interface] = ACTIONS(4376),
    [anon_sym_checker] = ACTIONS(4376),
    [anon_sym_virtual] = ACTIONS(4376),
    [anon_sym_class] = ACTIONS(4376),
    [anon_sym_type] = ACTIONS(4376),
    [anon_sym_DOLLARfatal] = ACTIONS(4374),
    [anon_sym_DOLLARerror] = ACTIONS(4374),
    [anon_sym_DOLLARwarning] = ACTIONS(4374),
    [anon_sym_DOLLARinfo] = ACTIONS(4374),
    [anon_sym_default] = ACTIONS(4376),
    [anon_sym_clocking] = ACTIONS(4376),
    [anon_sym_defparam] = ACTIONS(4376),
    [anon_sym_bind] = ACTIONS(4376),
    [anon_sym_rand] = ACTIONS(4376),
    [anon_sym_const] = ACTIONS(4376),
    [anon_sym_function] = ACTIONS(4376),
    [anon_sym_static] = ACTIONS(4376),
    [anon_sym_constraint] = ACTIONS(4376),
    [anon_sym_if] = ACTIONS(4376),
    [anon_sym_else] = ACTIONS(4376),
    [anon_sym_LBRACK] = ACTIONS(4374),
    [anon_sym_localparam] = ACTIONS(4376),
    [anon_sym_parameter] = ACTIONS(4376),
    [anon_sym_var] = ACTIONS(4376),
    [anon_sym_import] = ACTIONS(4376),
    [anon_sym_export] = ACTIONS(4376),
    [anon_sym_genvar] = ACTIONS(4376),
    [anon_sym_interconnect] = ACTIONS(4376),
    [anon_sym_typedef] = ACTIONS(4376),
    [anon_sym_enum] = ACTIONS(4376),
    [anon_sym_struct] = ACTIONS(4376),
    [anon_sym_union] = ACTIONS(4376),
    [anon_sym_nettype] = ACTIONS(4376),
    [anon_sym_automatic] = ACTIONS(4376),
    [anon_sym_string] = ACTIONS(4376),
    [anon_sym_chandle] = ACTIONS(4376),
    [anon_sym_event] = ACTIONS(4376),
    [anon_sym_byte] = ACTIONS(4376),
    [anon_sym_shortint] = ACTIONS(4376),
    [anon_sym_int] = ACTIONS(4376),
    [anon_sym_longint] = ACTIONS(4376),
    [anon_sym_integer] = ACTIONS(4376),
    [anon_sym_time] = ACTIONS(4376),
    [anon_sym_bit] = ACTIONS(4376),
    [anon_sym_logic] = ACTIONS(4376),
    [anon_sym_reg] = ACTIONS(4376),
    [anon_sym_shortreal] = ACTIONS(4376),
    [anon_sym_real] = ACTIONS(4376),
    [anon_sym_realtime] = ACTIONS(4376),
    [anon_sym_supply0] = ACTIONS(4376),
    [anon_sym_supply1] = ACTIONS(4376),
    [anon_sym_signed] = ACTIONS(4376),
    [anon_sym_unsigned] = ACTIONS(4376),
    [anon_sym_task] = ACTIONS(4376),
    [anon_sym_assert] = ACTIONS(4376),
    [anon_sym_property] = ACTIONS(4376),
    [anon_sym_assume] = ACTIONS(4376),
    [anon_sym_cover] = ACTIONS(4376),
    [anon_sym_sequence] = ACTIONS(4376),
    [anon_sym_restrict] = ACTIONS(4376),
    [anon_sym_not] = ACTIONS(4376),
    [anon_sym_or] = ACTIONS(4376),
    [anon_sym_and] = ACTIONS(4376),
    [anon_sym_case] = ACTIONS(4376),
    [anon_sym_always] = ACTIONS(4376),
    [anon_sym_covergroup] = ACTIONS(4376),
    [anon_sym_end] = ACTIONS(4376),
    [anon_sym_let] = ACTIONS(4376),
    [anon_sym_pulldown] = ACTIONS(4376),
    [anon_sym_pullup] = ACTIONS(4376),
    [anon_sym_cmos] = ACTIONS(4376),
    [anon_sym_rcmos] = ACTIONS(4376),
    [anon_sym_bufif0] = ACTIONS(4376),
    [anon_sym_bufif1] = ACTIONS(4376),
    [anon_sym_notif0] = ACTIONS(4376),
    [anon_sym_notif1] = ACTIONS(4376),
    [anon_sym_nmos] = ACTIONS(4376),
    [anon_sym_pmos] = ACTIONS(4376),
    [anon_sym_rnmos] = ACTIONS(4376),
    [anon_sym_rpmos] = ACTIONS(4376),
    [anon_sym_nand] = ACTIONS(4376),
    [anon_sym_nor] = ACTIONS(4376),
    [anon_sym_xor] = ACTIONS(4376),
    [anon_sym_xnor] = ACTIONS(4376),
    [anon_sym_buf] = ACTIONS(4376),
    [anon_sym_tranif0] = ACTIONS(4376),
    [anon_sym_tranif1] = ACTIONS(4376),
    [anon_sym_rtranif1] = ACTIONS(4376),
    [anon_sym_rtranif0] = ACTIONS(4376),
    [anon_sym_tran] = ACTIONS(4376),
    [anon_sym_rtran] = ACTIONS(4376),
    [anon_sym_generate] = ACTIONS(4376),
    [anon_sym_for] = ACTIONS(4376),
    [anon_sym_initial] = ACTIONS(4376),
    [anon_sym_assign] = ACTIONS(4376),
    [anon_sym_alias] = ACTIONS(4376),
    [anon_sym_always_comb] = ACTIONS(4376),
    [anon_sym_always_latch] = ACTIONS(4376),
    [anon_sym_always_ff] = ACTIONS(4376),
    [anon_sym_final] = ACTIONS(4376),
    [anon_sym_global] = ACTIONS(4376),
    [anon_sym_LPAREN_STAR] = ACTIONS(4374),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4374),
    [anon_sym_DOLLARunit] = ACTIONS(4374),
  },
  [4542] = {
    [sym_simple_identifier] = ACTIONS(4460),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_COLON] = ACTIONS(10801),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_rand] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_endgenerate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [4543] = {
    [sym_simple_identifier] = ACTIONS(4394),
    [anon_sym_wire] = ACTIONS(4394),
    [anon_sym_tri] = ACTIONS(4394),
    [anon_sym_tri0] = ACTIONS(4394),
    [anon_sym_tri1] = ACTIONS(4394),
    [anon_sym_wand] = ACTIONS(4394),
    [anon_sym_triand] = ACTIONS(4394),
    [anon_sym_wor] = ACTIONS(4394),
    [anon_sym_trior] = ACTIONS(4394),
    [anon_sym_trireg] = ACTIONS(4394),
    [anon_sym_uwire] = ACTIONS(4394),
    [anon_sym_SEMI] = ACTIONS(4392),
    [anon_sym_COLON] = ACTIONS(10803),
    [anon_sym_extern] = ACTIONS(4394),
    [anon_sym_interface] = ACTIONS(4394),
    [anon_sym_checker] = ACTIONS(4394),
    [anon_sym_virtual] = ACTIONS(4394),
    [anon_sym_class] = ACTIONS(4394),
    [anon_sym_type] = ACTIONS(4394),
    [anon_sym_DOLLARfatal] = ACTIONS(4392),
    [anon_sym_DOLLARerror] = ACTIONS(4392),
    [anon_sym_DOLLARwarning] = ACTIONS(4392),
    [anon_sym_DOLLARinfo] = ACTIONS(4392),
    [anon_sym_default] = ACTIONS(4394),
    [anon_sym_clocking] = ACTIONS(4394),
    [anon_sym_defparam] = ACTIONS(4394),
    [anon_sym_bind] = ACTIONS(4394),
    [anon_sym_rand] = ACTIONS(4394),
    [anon_sym_const] = ACTIONS(4394),
    [anon_sym_function] = ACTIONS(4394),
    [anon_sym_static] = ACTIONS(4394),
    [anon_sym_constraint] = ACTIONS(4394),
    [anon_sym_if] = ACTIONS(4394),
    [anon_sym_else] = ACTIONS(4394),
    [anon_sym_LBRACK] = ACTIONS(4392),
    [anon_sym_localparam] = ACTIONS(4394),
    [anon_sym_parameter] = ACTIONS(4394),
    [anon_sym_var] = ACTIONS(4394),
    [anon_sym_import] = ACTIONS(4394),
    [anon_sym_export] = ACTIONS(4394),
    [anon_sym_genvar] = ACTIONS(4394),
    [anon_sym_interconnect] = ACTIONS(4394),
    [anon_sym_typedef] = ACTIONS(4394),
    [anon_sym_enum] = ACTIONS(4394),
    [anon_sym_struct] = ACTIONS(4394),
    [anon_sym_union] = ACTIONS(4394),
    [anon_sym_nettype] = ACTIONS(4394),
    [anon_sym_automatic] = ACTIONS(4394),
    [anon_sym_string] = ACTIONS(4394),
    [anon_sym_chandle] = ACTIONS(4394),
    [anon_sym_event] = ACTIONS(4394),
    [anon_sym_byte] = ACTIONS(4394),
    [anon_sym_shortint] = ACTIONS(4394),
    [anon_sym_int] = ACTIONS(4394),
    [anon_sym_longint] = ACTIONS(4394),
    [anon_sym_integer] = ACTIONS(4394),
    [anon_sym_time] = ACTIONS(4394),
    [anon_sym_bit] = ACTIONS(4394),
    [anon_sym_logic] = ACTIONS(4394),
    [anon_sym_reg] = ACTIONS(4394),
    [anon_sym_shortreal] = ACTIONS(4394),
    [anon_sym_real] = ACTIONS(4394),
    [anon_sym_realtime] = ACTIONS(4394),
    [anon_sym_supply0] = ACTIONS(4394),
    [anon_sym_supply1] = ACTIONS(4394),
    [anon_sym_signed] = ACTIONS(4394),
    [anon_sym_unsigned] = ACTIONS(4394),
    [anon_sym_task] = ACTIONS(4394),
    [anon_sym_assert] = ACTIONS(4394),
    [anon_sym_property] = ACTIONS(4394),
    [anon_sym_assume] = ACTIONS(4394),
    [anon_sym_cover] = ACTIONS(4394),
    [anon_sym_sequence] = ACTIONS(4394),
    [anon_sym_restrict] = ACTIONS(4394),
    [anon_sym_not] = ACTIONS(4394),
    [anon_sym_or] = ACTIONS(4394),
    [anon_sym_and] = ACTIONS(4394),
    [anon_sym_case] = ACTIONS(4394),
    [anon_sym_always] = ACTIONS(4394),
    [anon_sym_covergroup] = ACTIONS(4394),
    [anon_sym_end] = ACTIONS(4394),
    [anon_sym_let] = ACTIONS(4394),
    [anon_sym_pulldown] = ACTIONS(4394),
    [anon_sym_pullup] = ACTIONS(4394),
    [anon_sym_cmos] = ACTIONS(4394),
    [anon_sym_rcmos] = ACTIONS(4394),
    [anon_sym_bufif0] = ACTIONS(4394),
    [anon_sym_bufif1] = ACTIONS(4394),
    [anon_sym_notif0] = ACTIONS(4394),
    [anon_sym_notif1] = ACTIONS(4394),
    [anon_sym_nmos] = ACTIONS(4394),
    [anon_sym_pmos] = ACTIONS(4394),
    [anon_sym_rnmos] = ACTIONS(4394),
    [anon_sym_rpmos] = ACTIONS(4394),
    [anon_sym_nand] = ACTIONS(4394),
    [anon_sym_nor] = ACTIONS(4394),
    [anon_sym_xor] = ACTIONS(4394),
    [anon_sym_xnor] = ACTIONS(4394),
    [anon_sym_buf] = ACTIONS(4394),
    [anon_sym_tranif0] = ACTIONS(4394),
    [anon_sym_tranif1] = ACTIONS(4394),
    [anon_sym_rtranif1] = ACTIONS(4394),
    [anon_sym_rtranif0] = ACTIONS(4394),
    [anon_sym_tran] = ACTIONS(4394),
    [anon_sym_rtran] = ACTIONS(4394),
    [anon_sym_generate] = ACTIONS(4394),
    [anon_sym_for] = ACTIONS(4394),
    [anon_sym_initial] = ACTIONS(4394),
    [anon_sym_assign] = ACTIONS(4394),
    [anon_sym_alias] = ACTIONS(4394),
    [anon_sym_always_comb] = ACTIONS(4394),
    [anon_sym_always_latch] = ACTIONS(4394),
    [anon_sym_always_ff] = ACTIONS(4394),
    [anon_sym_final] = ACTIONS(4394),
    [anon_sym_global] = ACTIONS(4394),
    [anon_sym_LPAREN_STAR] = ACTIONS(4392),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4392),
    [anon_sym_DOLLARunit] = ACTIONS(4392),
  },
  [4544] = {
    [sym_simple_identifier] = ACTIONS(4494),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_COLON] = ACTIONS(10805),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_rand] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_endgenerate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [4545] = {
    [sym_simple_identifier] = ACTIONS(4668),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(10807),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_rand] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_endgenerate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [4546] = {
    [sym_simple_identifier] = ACTIONS(4460),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_COLON] = ACTIONS(10809),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_rand] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_end] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [4547] = {
    [sym_simple_identifier] = ACTIONS(4206),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_COLON] = ACTIONS(10811),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_rand] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_endgenerate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [4548] = {
    [sym_simple_identifier] = ACTIONS(4224),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_COLON] = ACTIONS(10813),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_rand] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_end] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [4549] = {
    [sym_simple_identifier] = ACTIONS(4224),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_COLON] = ACTIONS(10815),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_rand] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_endgenerate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [4550] = {
    [sym_simple_identifier] = ACTIONS(4236),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_COLON] = ACTIONS(10817),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_rand] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_end] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [4551] = {
    [sym_simple_identifier] = ACTIONS(4236),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_COLON] = ACTIONS(10819),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_rand] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_endgenerate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [4552] = {
    [sym_simple_identifier] = ACTIONS(4174),
    [anon_sym_wire] = ACTIONS(4174),
    [anon_sym_tri] = ACTIONS(4174),
    [anon_sym_tri0] = ACTIONS(4174),
    [anon_sym_tri1] = ACTIONS(4174),
    [anon_sym_wand] = ACTIONS(4174),
    [anon_sym_triand] = ACTIONS(4174),
    [anon_sym_wor] = ACTIONS(4174),
    [anon_sym_trior] = ACTIONS(4174),
    [anon_sym_trireg] = ACTIONS(4174),
    [anon_sym_uwire] = ACTIONS(4174),
    [anon_sym_SEMI] = ACTIONS(4172),
    [anon_sym_COLON] = ACTIONS(10821),
    [anon_sym_extern] = ACTIONS(4174),
    [anon_sym_interface] = ACTIONS(4174),
    [anon_sym_checker] = ACTIONS(4174),
    [anon_sym_virtual] = ACTIONS(4174),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_DOLLARfatal] = ACTIONS(4172),
    [anon_sym_DOLLARerror] = ACTIONS(4172),
    [anon_sym_DOLLARwarning] = ACTIONS(4172),
    [anon_sym_DOLLARinfo] = ACTIONS(4172),
    [anon_sym_default] = ACTIONS(4174),
    [anon_sym_clocking] = ACTIONS(4174),
    [anon_sym_defparam] = ACTIONS(4174),
    [anon_sym_bind] = ACTIONS(4174),
    [anon_sym_rand] = ACTIONS(4174),
    [anon_sym_const] = ACTIONS(4174),
    [anon_sym_function] = ACTIONS(4174),
    [anon_sym_static] = ACTIONS(4174),
    [anon_sym_constraint] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_else] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4172),
    [anon_sym_localparam] = ACTIONS(4174),
    [anon_sym_parameter] = ACTIONS(4174),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_import] = ACTIONS(4174),
    [anon_sym_export] = ACTIONS(4174),
    [anon_sym_genvar] = ACTIONS(4174),
    [anon_sym_interconnect] = ACTIONS(4174),
    [anon_sym_typedef] = ACTIONS(4174),
    [anon_sym_enum] = ACTIONS(4174),
    [anon_sym_struct] = ACTIONS(4174),
    [anon_sym_union] = ACTIONS(4174),
    [anon_sym_nettype] = ACTIONS(4174),
    [anon_sym_automatic] = ACTIONS(4174),
    [anon_sym_string] = ACTIONS(4174),
    [anon_sym_chandle] = ACTIONS(4174),
    [anon_sym_event] = ACTIONS(4174),
    [anon_sym_byte] = ACTIONS(4174),
    [anon_sym_shortint] = ACTIONS(4174),
    [anon_sym_int] = ACTIONS(4174),
    [anon_sym_longint] = ACTIONS(4174),
    [anon_sym_integer] = ACTIONS(4174),
    [anon_sym_time] = ACTIONS(4174),
    [anon_sym_bit] = ACTIONS(4174),
    [anon_sym_logic] = ACTIONS(4174),
    [anon_sym_reg] = ACTIONS(4174),
    [anon_sym_shortreal] = ACTIONS(4174),
    [anon_sym_real] = ACTIONS(4174),
    [anon_sym_realtime] = ACTIONS(4174),
    [anon_sym_supply0] = ACTIONS(4174),
    [anon_sym_supply1] = ACTIONS(4174),
    [anon_sym_signed] = ACTIONS(4174),
    [anon_sym_unsigned] = ACTIONS(4174),
    [anon_sym_task] = ACTIONS(4174),
    [anon_sym_assert] = ACTIONS(4174),
    [anon_sym_property] = ACTIONS(4174),
    [anon_sym_assume] = ACTIONS(4174),
    [anon_sym_cover] = ACTIONS(4174),
    [anon_sym_sequence] = ACTIONS(4174),
    [anon_sym_restrict] = ACTIONS(4174),
    [anon_sym_not] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_always] = ACTIONS(4174),
    [anon_sym_covergroup] = ACTIONS(4174),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_pulldown] = ACTIONS(4174),
    [anon_sym_pullup] = ACTIONS(4174),
    [anon_sym_cmos] = ACTIONS(4174),
    [anon_sym_rcmos] = ACTIONS(4174),
    [anon_sym_bufif0] = ACTIONS(4174),
    [anon_sym_bufif1] = ACTIONS(4174),
    [anon_sym_notif0] = ACTIONS(4174),
    [anon_sym_notif1] = ACTIONS(4174),
    [anon_sym_nmos] = ACTIONS(4174),
    [anon_sym_pmos] = ACTIONS(4174),
    [anon_sym_rnmos] = ACTIONS(4174),
    [anon_sym_rpmos] = ACTIONS(4174),
    [anon_sym_nand] = ACTIONS(4174),
    [anon_sym_nor] = ACTIONS(4174),
    [anon_sym_xor] = ACTIONS(4174),
    [anon_sym_xnor] = ACTIONS(4174),
    [anon_sym_buf] = ACTIONS(4174),
    [anon_sym_tranif0] = ACTIONS(4174),
    [anon_sym_tranif1] = ACTIONS(4174),
    [anon_sym_rtranif1] = ACTIONS(4174),
    [anon_sym_rtranif0] = ACTIONS(4174),
    [anon_sym_tran] = ACTIONS(4174),
    [anon_sym_rtran] = ACTIONS(4174),
    [anon_sym_generate] = ACTIONS(4174),
    [anon_sym_endgenerate] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_initial] = ACTIONS(4174),
    [anon_sym_assign] = ACTIONS(4174),
    [anon_sym_alias] = ACTIONS(4174),
    [anon_sym_always_comb] = ACTIONS(4174),
    [anon_sym_always_latch] = ACTIONS(4174),
    [anon_sym_always_ff] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_global] = ACTIONS(4174),
    [anon_sym_LPAREN_STAR] = ACTIONS(4172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4172),
    [anon_sym_DOLLARunit] = ACTIONS(4172),
  },
  [4553] = {
    [sym_simple_identifier] = ACTIONS(4270),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_COLON] = ACTIONS(10823),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_rand] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_endgenerate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [4554] = {
    [sym_simple_identifier] = ACTIONS(4230),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_COLON] = ACTIONS(10825),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_rand] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_end] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [4555] = {
    [sym_simple_identifier] = ACTIONS(4294),
    [anon_sym_wire] = ACTIONS(4294),
    [anon_sym_tri] = ACTIONS(4294),
    [anon_sym_tri0] = ACTIONS(4294),
    [anon_sym_tri1] = ACTIONS(4294),
    [anon_sym_wand] = ACTIONS(4294),
    [anon_sym_triand] = ACTIONS(4294),
    [anon_sym_wor] = ACTIONS(4294),
    [anon_sym_trior] = ACTIONS(4294),
    [anon_sym_trireg] = ACTIONS(4294),
    [anon_sym_uwire] = ACTIONS(4294),
    [anon_sym_SEMI] = ACTIONS(4292),
    [anon_sym_COLON] = ACTIONS(10827),
    [anon_sym_extern] = ACTIONS(4294),
    [anon_sym_interface] = ACTIONS(4294),
    [anon_sym_checker] = ACTIONS(4294),
    [anon_sym_virtual] = ACTIONS(4294),
    [anon_sym_class] = ACTIONS(4294),
    [anon_sym_type] = ACTIONS(4294),
    [anon_sym_DOLLARfatal] = ACTIONS(4292),
    [anon_sym_DOLLARerror] = ACTIONS(4292),
    [anon_sym_DOLLARwarning] = ACTIONS(4292),
    [anon_sym_DOLLARinfo] = ACTIONS(4292),
    [anon_sym_default] = ACTIONS(4294),
    [anon_sym_clocking] = ACTIONS(4294),
    [anon_sym_defparam] = ACTIONS(4294),
    [anon_sym_bind] = ACTIONS(4294),
    [anon_sym_rand] = ACTIONS(4294),
    [anon_sym_const] = ACTIONS(4294),
    [anon_sym_function] = ACTIONS(4294),
    [anon_sym_static] = ACTIONS(4294),
    [anon_sym_constraint] = ACTIONS(4294),
    [anon_sym_if] = ACTIONS(4294),
    [anon_sym_else] = ACTIONS(4294),
    [anon_sym_LBRACK] = ACTIONS(4292),
    [anon_sym_localparam] = ACTIONS(4294),
    [anon_sym_parameter] = ACTIONS(4294),
    [anon_sym_var] = ACTIONS(4294),
    [anon_sym_import] = ACTIONS(4294),
    [anon_sym_export] = ACTIONS(4294),
    [anon_sym_genvar] = ACTIONS(4294),
    [anon_sym_interconnect] = ACTIONS(4294),
    [anon_sym_typedef] = ACTIONS(4294),
    [anon_sym_enum] = ACTIONS(4294),
    [anon_sym_struct] = ACTIONS(4294),
    [anon_sym_union] = ACTIONS(4294),
    [anon_sym_nettype] = ACTIONS(4294),
    [anon_sym_automatic] = ACTIONS(4294),
    [anon_sym_string] = ACTIONS(4294),
    [anon_sym_chandle] = ACTIONS(4294),
    [anon_sym_event] = ACTIONS(4294),
    [anon_sym_byte] = ACTIONS(4294),
    [anon_sym_shortint] = ACTIONS(4294),
    [anon_sym_int] = ACTIONS(4294),
    [anon_sym_longint] = ACTIONS(4294),
    [anon_sym_integer] = ACTIONS(4294),
    [anon_sym_time] = ACTIONS(4294),
    [anon_sym_bit] = ACTIONS(4294),
    [anon_sym_logic] = ACTIONS(4294),
    [anon_sym_reg] = ACTIONS(4294),
    [anon_sym_shortreal] = ACTIONS(4294),
    [anon_sym_real] = ACTIONS(4294),
    [anon_sym_realtime] = ACTIONS(4294),
    [anon_sym_supply0] = ACTIONS(4294),
    [anon_sym_supply1] = ACTIONS(4294),
    [anon_sym_signed] = ACTIONS(4294),
    [anon_sym_unsigned] = ACTIONS(4294),
    [anon_sym_task] = ACTIONS(4294),
    [anon_sym_assert] = ACTIONS(4294),
    [anon_sym_property] = ACTIONS(4294),
    [anon_sym_assume] = ACTIONS(4294),
    [anon_sym_cover] = ACTIONS(4294),
    [anon_sym_sequence] = ACTIONS(4294),
    [anon_sym_restrict] = ACTIONS(4294),
    [anon_sym_not] = ACTIONS(4294),
    [anon_sym_or] = ACTIONS(4294),
    [anon_sym_and] = ACTIONS(4294),
    [anon_sym_case] = ACTIONS(4294),
    [anon_sym_always] = ACTIONS(4294),
    [anon_sym_covergroup] = ACTIONS(4294),
    [anon_sym_let] = ACTIONS(4294),
    [anon_sym_pulldown] = ACTIONS(4294),
    [anon_sym_pullup] = ACTIONS(4294),
    [anon_sym_cmos] = ACTIONS(4294),
    [anon_sym_rcmos] = ACTIONS(4294),
    [anon_sym_bufif0] = ACTIONS(4294),
    [anon_sym_bufif1] = ACTIONS(4294),
    [anon_sym_notif0] = ACTIONS(4294),
    [anon_sym_notif1] = ACTIONS(4294),
    [anon_sym_nmos] = ACTIONS(4294),
    [anon_sym_pmos] = ACTIONS(4294),
    [anon_sym_rnmos] = ACTIONS(4294),
    [anon_sym_rpmos] = ACTIONS(4294),
    [anon_sym_nand] = ACTIONS(4294),
    [anon_sym_nor] = ACTIONS(4294),
    [anon_sym_xor] = ACTIONS(4294),
    [anon_sym_xnor] = ACTIONS(4294),
    [anon_sym_buf] = ACTIONS(4294),
    [anon_sym_tranif0] = ACTIONS(4294),
    [anon_sym_tranif1] = ACTIONS(4294),
    [anon_sym_rtranif1] = ACTIONS(4294),
    [anon_sym_rtranif0] = ACTIONS(4294),
    [anon_sym_tran] = ACTIONS(4294),
    [anon_sym_rtran] = ACTIONS(4294),
    [anon_sym_generate] = ACTIONS(4294),
    [anon_sym_endgenerate] = ACTIONS(4294),
    [anon_sym_for] = ACTIONS(4294),
    [anon_sym_initial] = ACTIONS(4294),
    [anon_sym_assign] = ACTIONS(4294),
    [anon_sym_alias] = ACTIONS(4294),
    [anon_sym_always_comb] = ACTIONS(4294),
    [anon_sym_always_latch] = ACTIONS(4294),
    [anon_sym_always_ff] = ACTIONS(4294),
    [anon_sym_final] = ACTIONS(4294),
    [anon_sym_global] = ACTIONS(4294),
    [anon_sym_LPAREN_STAR] = ACTIONS(4292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4292),
    [anon_sym_DOLLARunit] = ACTIONS(4292),
  },
  [4556] = {
    [sym_simple_identifier] = ACTIONS(4168),
    [anon_sym_wire] = ACTIONS(4168),
    [anon_sym_tri] = ACTIONS(4168),
    [anon_sym_tri0] = ACTIONS(4168),
    [anon_sym_tri1] = ACTIONS(4168),
    [anon_sym_wand] = ACTIONS(4168),
    [anon_sym_triand] = ACTIONS(4168),
    [anon_sym_wor] = ACTIONS(4168),
    [anon_sym_trior] = ACTIONS(4168),
    [anon_sym_trireg] = ACTIONS(4168),
    [anon_sym_uwire] = ACTIONS(4168),
    [anon_sym_SEMI] = ACTIONS(4166),
    [anon_sym_COLON] = ACTIONS(10829),
    [anon_sym_extern] = ACTIONS(4168),
    [anon_sym_interface] = ACTIONS(4168),
    [anon_sym_checker] = ACTIONS(4168),
    [anon_sym_virtual] = ACTIONS(4168),
    [anon_sym_class] = ACTIONS(4168),
    [anon_sym_type] = ACTIONS(4168),
    [anon_sym_DOLLARfatal] = ACTIONS(4166),
    [anon_sym_DOLLARerror] = ACTIONS(4166),
    [anon_sym_DOLLARwarning] = ACTIONS(4166),
    [anon_sym_DOLLARinfo] = ACTIONS(4166),
    [anon_sym_default] = ACTIONS(4168),
    [anon_sym_clocking] = ACTIONS(4168),
    [anon_sym_defparam] = ACTIONS(4168),
    [anon_sym_bind] = ACTIONS(4168),
    [anon_sym_rand] = ACTIONS(4168),
    [anon_sym_const] = ACTIONS(4168),
    [anon_sym_function] = ACTIONS(4168),
    [anon_sym_static] = ACTIONS(4168),
    [anon_sym_constraint] = ACTIONS(4168),
    [anon_sym_if] = ACTIONS(4168),
    [anon_sym_else] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4166),
    [anon_sym_localparam] = ACTIONS(4168),
    [anon_sym_parameter] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4168),
    [anon_sym_import] = ACTIONS(4168),
    [anon_sym_export] = ACTIONS(4168),
    [anon_sym_genvar] = ACTIONS(4168),
    [anon_sym_interconnect] = ACTIONS(4168),
    [anon_sym_typedef] = ACTIONS(4168),
    [anon_sym_enum] = ACTIONS(4168),
    [anon_sym_struct] = ACTIONS(4168),
    [anon_sym_union] = ACTIONS(4168),
    [anon_sym_nettype] = ACTIONS(4168),
    [anon_sym_automatic] = ACTIONS(4168),
    [anon_sym_string] = ACTIONS(4168),
    [anon_sym_chandle] = ACTIONS(4168),
    [anon_sym_event] = ACTIONS(4168),
    [anon_sym_byte] = ACTIONS(4168),
    [anon_sym_shortint] = ACTIONS(4168),
    [anon_sym_int] = ACTIONS(4168),
    [anon_sym_longint] = ACTIONS(4168),
    [anon_sym_integer] = ACTIONS(4168),
    [anon_sym_time] = ACTIONS(4168),
    [anon_sym_bit] = ACTIONS(4168),
    [anon_sym_logic] = ACTIONS(4168),
    [anon_sym_reg] = ACTIONS(4168),
    [anon_sym_shortreal] = ACTIONS(4168),
    [anon_sym_real] = ACTIONS(4168),
    [anon_sym_realtime] = ACTIONS(4168),
    [anon_sym_supply0] = ACTIONS(4168),
    [anon_sym_supply1] = ACTIONS(4168),
    [anon_sym_signed] = ACTIONS(4168),
    [anon_sym_unsigned] = ACTIONS(4168),
    [anon_sym_task] = ACTIONS(4168),
    [anon_sym_assert] = ACTIONS(4168),
    [anon_sym_property] = ACTIONS(4168),
    [anon_sym_assume] = ACTIONS(4168),
    [anon_sym_cover] = ACTIONS(4168),
    [anon_sym_sequence] = ACTIONS(4168),
    [anon_sym_restrict] = ACTIONS(4168),
    [anon_sym_not] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_case] = ACTIONS(4168),
    [anon_sym_always] = ACTIONS(4168),
    [anon_sym_covergroup] = ACTIONS(4168),
    [anon_sym_let] = ACTIONS(4168),
    [anon_sym_pulldown] = ACTIONS(4168),
    [anon_sym_pullup] = ACTIONS(4168),
    [anon_sym_cmos] = ACTIONS(4168),
    [anon_sym_rcmos] = ACTIONS(4168),
    [anon_sym_bufif0] = ACTIONS(4168),
    [anon_sym_bufif1] = ACTIONS(4168),
    [anon_sym_notif0] = ACTIONS(4168),
    [anon_sym_notif1] = ACTIONS(4168),
    [anon_sym_nmos] = ACTIONS(4168),
    [anon_sym_pmos] = ACTIONS(4168),
    [anon_sym_rnmos] = ACTIONS(4168),
    [anon_sym_rpmos] = ACTIONS(4168),
    [anon_sym_nand] = ACTIONS(4168),
    [anon_sym_nor] = ACTIONS(4168),
    [anon_sym_xor] = ACTIONS(4168),
    [anon_sym_xnor] = ACTIONS(4168),
    [anon_sym_buf] = ACTIONS(4168),
    [anon_sym_tranif0] = ACTIONS(4168),
    [anon_sym_tranif1] = ACTIONS(4168),
    [anon_sym_rtranif1] = ACTIONS(4168),
    [anon_sym_rtranif0] = ACTIONS(4168),
    [anon_sym_tran] = ACTIONS(4168),
    [anon_sym_rtran] = ACTIONS(4168),
    [anon_sym_generate] = ACTIONS(4168),
    [anon_sym_endgenerate] = ACTIONS(4168),
    [anon_sym_for] = ACTIONS(4168),
    [anon_sym_initial] = ACTIONS(4168),
    [anon_sym_assign] = ACTIONS(4168),
    [anon_sym_alias] = ACTIONS(4168),
    [anon_sym_always_comb] = ACTIONS(4168),
    [anon_sym_always_latch] = ACTIONS(4168),
    [anon_sym_always_ff] = ACTIONS(4168),
    [anon_sym_final] = ACTIONS(4168),
    [anon_sym_global] = ACTIONS(4168),
    [anon_sym_LPAREN_STAR] = ACTIONS(4166),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4166),
    [anon_sym_DOLLARunit] = ACTIONS(4166),
  },
  [4557] = {
    [sym_simple_identifier] = ACTIONS(4646),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_COLON] = ACTIONS(10831),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_rand] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_endgenerate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [4558] = {
    [sym_simple_identifier] = ACTIONS(4174),
    [anon_sym_wire] = ACTIONS(4174),
    [anon_sym_tri] = ACTIONS(4174),
    [anon_sym_tri0] = ACTIONS(4174),
    [anon_sym_tri1] = ACTIONS(4174),
    [anon_sym_wand] = ACTIONS(4174),
    [anon_sym_triand] = ACTIONS(4174),
    [anon_sym_wor] = ACTIONS(4174),
    [anon_sym_trior] = ACTIONS(4174),
    [anon_sym_trireg] = ACTIONS(4174),
    [anon_sym_uwire] = ACTIONS(4174),
    [anon_sym_SEMI] = ACTIONS(4172),
    [anon_sym_COLON] = ACTIONS(10833),
    [anon_sym_extern] = ACTIONS(4174),
    [anon_sym_interface] = ACTIONS(4174),
    [anon_sym_checker] = ACTIONS(4174),
    [anon_sym_virtual] = ACTIONS(4174),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_DOLLARfatal] = ACTIONS(4172),
    [anon_sym_DOLLARerror] = ACTIONS(4172),
    [anon_sym_DOLLARwarning] = ACTIONS(4172),
    [anon_sym_DOLLARinfo] = ACTIONS(4172),
    [anon_sym_default] = ACTIONS(4174),
    [anon_sym_clocking] = ACTIONS(4174),
    [anon_sym_defparam] = ACTIONS(4174),
    [anon_sym_bind] = ACTIONS(4174),
    [anon_sym_rand] = ACTIONS(4174),
    [anon_sym_const] = ACTIONS(4174),
    [anon_sym_function] = ACTIONS(4174),
    [anon_sym_static] = ACTIONS(4174),
    [anon_sym_constraint] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_else] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4172),
    [anon_sym_localparam] = ACTIONS(4174),
    [anon_sym_parameter] = ACTIONS(4174),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_import] = ACTIONS(4174),
    [anon_sym_export] = ACTIONS(4174),
    [anon_sym_genvar] = ACTIONS(4174),
    [anon_sym_interconnect] = ACTIONS(4174),
    [anon_sym_typedef] = ACTIONS(4174),
    [anon_sym_enum] = ACTIONS(4174),
    [anon_sym_struct] = ACTIONS(4174),
    [anon_sym_union] = ACTIONS(4174),
    [anon_sym_nettype] = ACTIONS(4174),
    [anon_sym_automatic] = ACTIONS(4174),
    [anon_sym_string] = ACTIONS(4174),
    [anon_sym_chandle] = ACTIONS(4174),
    [anon_sym_event] = ACTIONS(4174),
    [anon_sym_byte] = ACTIONS(4174),
    [anon_sym_shortint] = ACTIONS(4174),
    [anon_sym_int] = ACTIONS(4174),
    [anon_sym_longint] = ACTIONS(4174),
    [anon_sym_integer] = ACTIONS(4174),
    [anon_sym_time] = ACTIONS(4174),
    [anon_sym_bit] = ACTIONS(4174),
    [anon_sym_logic] = ACTIONS(4174),
    [anon_sym_reg] = ACTIONS(4174),
    [anon_sym_shortreal] = ACTIONS(4174),
    [anon_sym_real] = ACTIONS(4174),
    [anon_sym_realtime] = ACTIONS(4174),
    [anon_sym_supply0] = ACTIONS(4174),
    [anon_sym_supply1] = ACTIONS(4174),
    [anon_sym_signed] = ACTIONS(4174),
    [anon_sym_unsigned] = ACTIONS(4174),
    [anon_sym_task] = ACTIONS(4174),
    [anon_sym_assert] = ACTIONS(4174),
    [anon_sym_property] = ACTIONS(4174),
    [anon_sym_assume] = ACTIONS(4174),
    [anon_sym_cover] = ACTIONS(4174),
    [anon_sym_sequence] = ACTIONS(4174),
    [anon_sym_restrict] = ACTIONS(4174),
    [anon_sym_not] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_always] = ACTIONS(4174),
    [anon_sym_covergroup] = ACTIONS(4174),
    [anon_sym_end] = ACTIONS(4174),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_pulldown] = ACTIONS(4174),
    [anon_sym_pullup] = ACTIONS(4174),
    [anon_sym_cmos] = ACTIONS(4174),
    [anon_sym_rcmos] = ACTIONS(4174),
    [anon_sym_bufif0] = ACTIONS(4174),
    [anon_sym_bufif1] = ACTIONS(4174),
    [anon_sym_notif0] = ACTIONS(4174),
    [anon_sym_notif1] = ACTIONS(4174),
    [anon_sym_nmos] = ACTIONS(4174),
    [anon_sym_pmos] = ACTIONS(4174),
    [anon_sym_rnmos] = ACTIONS(4174),
    [anon_sym_rpmos] = ACTIONS(4174),
    [anon_sym_nand] = ACTIONS(4174),
    [anon_sym_nor] = ACTIONS(4174),
    [anon_sym_xor] = ACTIONS(4174),
    [anon_sym_xnor] = ACTIONS(4174),
    [anon_sym_buf] = ACTIONS(4174),
    [anon_sym_tranif0] = ACTIONS(4174),
    [anon_sym_tranif1] = ACTIONS(4174),
    [anon_sym_rtranif1] = ACTIONS(4174),
    [anon_sym_rtranif0] = ACTIONS(4174),
    [anon_sym_tran] = ACTIONS(4174),
    [anon_sym_rtran] = ACTIONS(4174),
    [anon_sym_generate] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_initial] = ACTIONS(4174),
    [anon_sym_assign] = ACTIONS(4174),
    [anon_sym_alias] = ACTIONS(4174),
    [anon_sym_always_comb] = ACTIONS(4174),
    [anon_sym_always_latch] = ACTIONS(4174),
    [anon_sym_always_ff] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_global] = ACTIONS(4174),
    [anon_sym_LPAREN_STAR] = ACTIONS(4172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4172),
    [anon_sym_DOLLARunit] = ACTIONS(4172),
  },
  [4559] = {
    [sym_simple_identifier] = ACTIONS(4270),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_COLON] = ACTIONS(10835),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_rand] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_end] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [4560] = {
    [sym_simple_identifier] = ACTIONS(4280),
    [anon_sym_wire] = ACTIONS(4280),
    [anon_sym_tri] = ACTIONS(4280),
    [anon_sym_tri0] = ACTIONS(4280),
    [anon_sym_tri1] = ACTIONS(4280),
    [anon_sym_wand] = ACTIONS(4280),
    [anon_sym_triand] = ACTIONS(4280),
    [anon_sym_wor] = ACTIONS(4280),
    [anon_sym_trior] = ACTIONS(4280),
    [anon_sym_trireg] = ACTIONS(4280),
    [anon_sym_uwire] = ACTIONS(4280),
    [anon_sym_SEMI] = ACTIONS(4278),
    [anon_sym_COLON] = ACTIONS(10837),
    [anon_sym_extern] = ACTIONS(4280),
    [anon_sym_interface] = ACTIONS(4280),
    [anon_sym_checker] = ACTIONS(4280),
    [anon_sym_virtual] = ACTIONS(4280),
    [anon_sym_class] = ACTIONS(4280),
    [anon_sym_type] = ACTIONS(4280),
    [anon_sym_DOLLARfatal] = ACTIONS(4278),
    [anon_sym_DOLLARerror] = ACTIONS(4278),
    [anon_sym_DOLLARwarning] = ACTIONS(4278),
    [anon_sym_DOLLARinfo] = ACTIONS(4278),
    [anon_sym_default] = ACTIONS(4280),
    [anon_sym_clocking] = ACTIONS(4280),
    [anon_sym_defparam] = ACTIONS(4280),
    [anon_sym_bind] = ACTIONS(4280),
    [anon_sym_rand] = ACTIONS(4280),
    [anon_sym_const] = ACTIONS(4280),
    [anon_sym_function] = ACTIONS(4280),
    [anon_sym_static] = ACTIONS(4280),
    [anon_sym_constraint] = ACTIONS(4280),
    [anon_sym_if] = ACTIONS(4280),
    [anon_sym_else] = ACTIONS(4280),
    [anon_sym_LBRACK] = ACTIONS(4278),
    [anon_sym_localparam] = ACTIONS(4280),
    [anon_sym_parameter] = ACTIONS(4280),
    [anon_sym_var] = ACTIONS(4280),
    [anon_sym_import] = ACTIONS(4280),
    [anon_sym_export] = ACTIONS(4280),
    [anon_sym_genvar] = ACTIONS(4280),
    [anon_sym_interconnect] = ACTIONS(4280),
    [anon_sym_typedef] = ACTIONS(4280),
    [anon_sym_enum] = ACTIONS(4280),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_union] = ACTIONS(4280),
    [anon_sym_nettype] = ACTIONS(4280),
    [anon_sym_automatic] = ACTIONS(4280),
    [anon_sym_string] = ACTIONS(4280),
    [anon_sym_chandle] = ACTIONS(4280),
    [anon_sym_event] = ACTIONS(4280),
    [anon_sym_byte] = ACTIONS(4280),
    [anon_sym_shortint] = ACTIONS(4280),
    [anon_sym_int] = ACTIONS(4280),
    [anon_sym_longint] = ACTIONS(4280),
    [anon_sym_integer] = ACTIONS(4280),
    [anon_sym_time] = ACTIONS(4280),
    [anon_sym_bit] = ACTIONS(4280),
    [anon_sym_logic] = ACTIONS(4280),
    [anon_sym_reg] = ACTIONS(4280),
    [anon_sym_shortreal] = ACTIONS(4280),
    [anon_sym_real] = ACTIONS(4280),
    [anon_sym_realtime] = ACTIONS(4280),
    [anon_sym_supply0] = ACTIONS(4280),
    [anon_sym_supply1] = ACTIONS(4280),
    [anon_sym_signed] = ACTIONS(4280),
    [anon_sym_unsigned] = ACTIONS(4280),
    [anon_sym_task] = ACTIONS(4280),
    [anon_sym_assert] = ACTIONS(4280),
    [anon_sym_property] = ACTIONS(4280),
    [anon_sym_assume] = ACTIONS(4280),
    [anon_sym_cover] = ACTIONS(4280),
    [anon_sym_sequence] = ACTIONS(4280),
    [anon_sym_restrict] = ACTIONS(4280),
    [anon_sym_not] = ACTIONS(4280),
    [anon_sym_or] = ACTIONS(4280),
    [anon_sym_and] = ACTIONS(4280),
    [anon_sym_case] = ACTIONS(4280),
    [anon_sym_always] = ACTIONS(4280),
    [anon_sym_covergroup] = ACTIONS(4280),
    [anon_sym_let] = ACTIONS(4280),
    [anon_sym_pulldown] = ACTIONS(4280),
    [anon_sym_pullup] = ACTIONS(4280),
    [anon_sym_cmos] = ACTIONS(4280),
    [anon_sym_rcmos] = ACTIONS(4280),
    [anon_sym_bufif0] = ACTIONS(4280),
    [anon_sym_bufif1] = ACTIONS(4280),
    [anon_sym_notif0] = ACTIONS(4280),
    [anon_sym_notif1] = ACTIONS(4280),
    [anon_sym_nmos] = ACTIONS(4280),
    [anon_sym_pmos] = ACTIONS(4280),
    [anon_sym_rnmos] = ACTIONS(4280),
    [anon_sym_rpmos] = ACTIONS(4280),
    [anon_sym_nand] = ACTIONS(4280),
    [anon_sym_nor] = ACTIONS(4280),
    [anon_sym_xor] = ACTIONS(4280),
    [anon_sym_xnor] = ACTIONS(4280),
    [anon_sym_buf] = ACTIONS(4280),
    [anon_sym_tranif0] = ACTIONS(4280),
    [anon_sym_tranif1] = ACTIONS(4280),
    [anon_sym_rtranif1] = ACTIONS(4280),
    [anon_sym_rtranif0] = ACTIONS(4280),
    [anon_sym_tran] = ACTIONS(4280),
    [anon_sym_rtran] = ACTIONS(4280),
    [anon_sym_generate] = ACTIONS(4280),
    [anon_sym_endgenerate] = ACTIONS(4280),
    [anon_sym_for] = ACTIONS(4280),
    [anon_sym_initial] = ACTIONS(4280),
    [anon_sym_assign] = ACTIONS(4280),
    [anon_sym_alias] = ACTIONS(4280),
    [anon_sym_always_comb] = ACTIONS(4280),
    [anon_sym_always_latch] = ACTIONS(4280),
    [anon_sym_always_ff] = ACTIONS(4280),
    [anon_sym_final] = ACTIONS(4280),
    [anon_sym_global] = ACTIONS(4280),
    [anon_sym_LPAREN_STAR] = ACTIONS(4278),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4278),
    [anon_sym_DOLLARunit] = ACTIONS(4278),
  },
  [4561] = {
    [sym_simple_identifier] = ACTIONS(4352),
    [anon_sym_wire] = ACTIONS(4352),
    [anon_sym_tri] = ACTIONS(4352),
    [anon_sym_tri0] = ACTIONS(4352),
    [anon_sym_tri1] = ACTIONS(4352),
    [anon_sym_wand] = ACTIONS(4352),
    [anon_sym_triand] = ACTIONS(4352),
    [anon_sym_wor] = ACTIONS(4352),
    [anon_sym_trior] = ACTIONS(4352),
    [anon_sym_trireg] = ACTIONS(4352),
    [anon_sym_uwire] = ACTIONS(4352),
    [anon_sym_SEMI] = ACTIONS(4350),
    [anon_sym_COLON] = ACTIONS(10839),
    [anon_sym_extern] = ACTIONS(4352),
    [anon_sym_interface] = ACTIONS(4352),
    [anon_sym_checker] = ACTIONS(4352),
    [anon_sym_virtual] = ACTIONS(4352),
    [anon_sym_class] = ACTIONS(4352),
    [anon_sym_type] = ACTIONS(4352),
    [anon_sym_DOLLARfatal] = ACTIONS(4350),
    [anon_sym_DOLLARerror] = ACTIONS(4350),
    [anon_sym_DOLLARwarning] = ACTIONS(4350),
    [anon_sym_DOLLARinfo] = ACTIONS(4350),
    [anon_sym_default] = ACTIONS(4352),
    [anon_sym_clocking] = ACTIONS(4352),
    [anon_sym_defparam] = ACTIONS(4352),
    [anon_sym_bind] = ACTIONS(4352),
    [anon_sym_rand] = ACTIONS(4352),
    [anon_sym_const] = ACTIONS(4352),
    [anon_sym_function] = ACTIONS(4352),
    [anon_sym_static] = ACTIONS(4352),
    [anon_sym_constraint] = ACTIONS(4352),
    [anon_sym_if] = ACTIONS(4352),
    [anon_sym_else] = ACTIONS(4352),
    [anon_sym_LBRACK] = ACTIONS(4350),
    [anon_sym_localparam] = ACTIONS(4352),
    [anon_sym_parameter] = ACTIONS(4352),
    [anon_sym_var] = ACTIONS(4352),
    [anon_sym_import] = ACTIONS(4352),
    [anon_sym_export] = ACTIONS(4352),
    [anon_sym_genvar] = ACTIONS(4352),
    [anon_sym_interconnect] = ACTIONS(4352),
    [anon_sym_typedef] = ACTIONS(4352),
    [anon_sym_enum] = ACTIONS(4352),
    [anon_sym_struct] = ACTIONS(4352),
    [anon_sym_union] = ACTIONS(4352),
    [anon_sym_nettype] = ACTIONS(4352),
    [anon_sym_automatic] = ACTIONS(4352),
    [anon_sym_string] = ACTIONS(4352),
    [anon_sym_chandle] = ACTIONS(4352),
    [anon_sym_event] = ACTIONS(4352),
    [anon_sym_byte] = ACTIONS(4352),
    [anon_sym_shortint] = ACTIONS(4352),
    [anon_sym_int] = ACTIONS(4352),
    [anon_sym_longint] = ACTIONS(4352),
    [anon_sym_integer] = ACTIONS(4352),
    [anon_sym_time] = ACTIONS(4352),
    [anon_sym_bit] = ACTIONS(4352),
    [anon_sym_logic] = ACTIONS(4352),
    [anon_sym_reg] = ACTIONS(4352),
    [anon_sym_shortreal] = ACTIONS(4352),
    [anon_sym_real] = ACTIONS(4352),
    [anon_sym_realtime] = ACTIONS(4352),
    [anon_sym_supply0] = ACTIONS(4352),
    [anon_sym_supply1] = ACTIONS(4352),
    [anon_sym_signed] = ACTIONS(4352),
    [anon_sym_unsigned] = ACTIONS(4352),
    [anon_sym_task] = ACTIONS(4352),
    [anon_sym_assert] = ACTIONS(4352),
    [anon_sym_property] = ACTIONS(4352),
    [anon_sym_assume] = ACTIONS(4352),
    [anon_sym_cover] = ACTIONS(4352),
    [anon_sym_sequence] = ACTIONS(4352),
    [anon_sym_restrict] = ACTIONS(4352),
    [anon_sym_not] = ACTIONS(4352),
    [anon_sym_or] = ACTIONS(4352),
    [anon_sym_and] = ACTIONS(4352),
    [anon_sym_case] = ACTIONS(4352),
    [anon_sym_always] = ACTIONS(4352),
    [anon_sym_covergroup] = ACTIONS(4352),
    [anon_sym_let] = ACTIONS(4352),
    [anon_sym_pulldown] = ACTIONS(4352),
    [anon_sym_pullup] = ACTIONS(4352),
    [anon_sym_cmos] = ACTIONS(4352),
    [anon_sym_rcmos] = ACTIONS(4352),
    [anon_sym_bufif0] = ACTIONS(4352),
    [anon_sym_bufif1] = ACTIONS(4352),
    [anon_sym_notif0] = ACTIONS(4352),
    [anon_sym_notif1] = ACTIONS(4352),
    [anon_sym_nmos] = ACTIONS(4352),
    [anon_sym_pmos] = ACTIONS(4352),
    [anon_sym_rnmos] = ACTIONS(4352),
    [anon_sym_rpmos] = ACTIONS(4352),
    [anon_sym_nand] = ACTIONS(4352),
    [anon_sym_nor] = ACTIONS(4352),
    [anon_sym_xor] = ACTIONS(4352),
    [anon_sym_xnor] = ACTIONS(4352),
    [anon_sym_buf] = ACTIONS(4352),
    [anon_sym_tranif0] = ACTIONS(4352),
    [anon_sym_tranif1] = ACTIONS(4352),
    [anon_sym_rtranif1] = ACTIONS(4352),
    [anon_sym_rtranif0] = ACTIONS(4352),
    [anon_sym_tran] = ACTIONS(4352),
    [anon_sym_rtran] = ACTIONS(4352),
    [anon_sym_generate] = ACTIONS(4352),
    [anon_sym_endgenerate] = ACTIONS(4352),
    [anon_sym_for] = ACTIONS(4352),
    [anon_sym_initial] = ACTIONS(4352),
    [anon_sym_assign] = ACTIONS(4352),
    [anon_sym_alias] = ACTIONS(4352),
    [anon_sym_always_comb] = ACTIONS(4352),
    [anon_sym_always_latch] = ACTIONS(4352),
    [anon_sym_always_ff] = ACTIONS(4352),
    [anon_sym_final] = ACTIONS(4352),
    [anon_sym_global] = ACTIONS(4352),
    [anon_sym_LPAREN_STAR] = ACTIONS(4350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4350),
    [anon_sym_DOLLARunit] = ACTIONS(4350),
  },
  [4562] = {
    [sym_simple_identifier] = ACTIONS(4358),
    [anon_sym_wire] = ACTIONS(4358),
    [anon_sym_tri] = ACTIONS(4358),
    [anon_sym_tri0] = ACTIONS(4358),
    [anon_sym_tri1] = ACTIONS(4358),
    [anon_sym_wand] = ACTIONS(4358),
    [anon_sym_triand] = ACTIONS(4358),
    [anon_sym_wor] = ACTIONS(4358),
    [anon_sym_trior] = ACTIONS(4358),
    [anon_sym_trireg] = ACTIONS(4358),
    [anon_sym_uwire] = ACTIONS(4358),
    [anon_sym_SEMI] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(10841),
    [anon_sym_extern] = ACTIONS(4358),
    [anon_sym_interface] = ACTIONS(4358),
    [anon_sym_checker] = ACTIONS(4358),
    [anon_sym_virtual] = ACTIONS(4358),
    [anon_sym_class] = ACTIONS(4358),
    [anon_sym_type] = ACTIONS(4358),
    [anon_sym_DOLLARfatal] = ACTIONS(4356),
    [anon_sym_DOLLARerror] = ACTIONS(4356),
    [anon_sym_DOLLARwarning] = ACTIONS(4356),
    [anon_sym_DOLLARinfo] = ACTIONS(4356),
    [anon_sym_default] = ACTIONS(4358),
    [anon_sym_clocking] = ACTIONS(4358),
    [anon_sym_defparam] = ACTIONS(4358),
    [anon_sym_bind] = ACTIONS(4358),
    [anon_sym_rand] = ACTIONS(4358),
    [anon_sym_const] = ACTIONS(4358),
    [anon_sym_function] = ACTIONS(4358),
    [anon_sym_static] = ACTIONS(4358),
    [anon_sym_constraint] = ACTIONS(4358),
    [anon_sym_if] = ACTIONS(4358),
    [anon_sym_else] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_localparam] = ACTIONS(4358),
    [anon_sym_parameter] = ACTIONS(4358),
    [anon_sym_var] = ACTIONS(4358),
    [anon_sym_import] = ACTIONS(4358),
    [anon_sym_export] = ACTIONS(4358),
    [anon_sym_genvar] = ACTIONS(4358),
    [anon_sym_interconnect] = ACTIONS(4358),
    [anon_sym_typedef] = ACTIONS(4358),
    [anon_sym_enum] = ACTIONS(4358),
    [anon_sym_struct] = ACTIONS(4358),
    [anon_sym_union] = ACTIONS(4358),
    [anon_sym_nettype] = ACTIONS(4358),
    [anon_sym_automatic] = ACTIONS(4358),
    [anon_sym_string] = ACTIONS(4358),
    [anon_sym_chandle] = ACTIONS(4358),
    [anon_sym_event] = ACTIONS(4358),
    [anon_sym_byte] = ACTIONS(4358),
    [anon_sym_shortint] = ACTIONS(4358),
    [anon_sym_int] = ACTIONS(4358),
    [anon_sym_longint] = ACTIONS(4358),
    [anon_sym_integer] = ACTIONS(4358),
    [anon_sym_time] = ACTIONS(4358),
    [anon_sym_bit] = ACTIONS(4358),
    [anon_sym_logic] = ACTIONS(4358),
    [anon_sym_reg] = ACTIONS(4358),
    [anon_sym_shortreal] = ACTIONS(4358),
    [anon_sym_real] = ACTIONS(4358),
    [anon_sym_realtime] = ACTIONS(4358),
    [anon_sym_supply0] = ACTIONS(4358),
    [anon_sym_supply1] = ACTIONS(4358),
    [anon_sym_signed] = ACTIONS(4358),
    [anon_sym_unsigned] = ACTIONS(4358),
    [anon_sym_task] = ACTIONS(4358),
    [anon_sym_assert] = ACTIONS(4358),
    [anon_sym_property] = ACTIONS(4358),
    [anon_sym_assume] = ACTIONS(4358),
    [anon_sym_cover] = ACTIONS(4358),
    [anon_sym_sequence] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym_not] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4358),
    [anon_sym_and] = ACTIONS(4358),
    [anon_sym_case] = ACTIONS(4358),
    [anon_sym_always] = ACTIONS(4358),
    [anon_sym_covergroup] = ACTIONS(4358),
    [anon_sym_end] = ACTIONS(4358),
    [anon_sym_let] = ACTIONS(4358),
    [anon_sym_pulldown] = ACTIONS(4358),
    [anon_sym_pullup] = ACTIONS(4358),
    [anon_sym_cmos] = ACTIONS(4358),
    [anon_sym_rcmos] = ACTIONS(4358),
    [anon_sym_bufif0] = ACTIONS(4358),
    [anon_sym_bufif1] = ACTIONS(4358),
    [anon_sym_notif0] = ACTIONS(4358),
    [anon_sym_notif1] = ACTIONS(4358),
    [anon_sym_nmos] = ACTIONS(4358),
    [anon_sym_pmos] = ACTIONS(4358),
    [anon_sym_rnmos] = ACTIONS(4358),
    [anon_sym_rpmos] = ACTIONS(4358),
    [anon_sym_nand] = ACTIONS(4358),
    [anon_sym_nor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4358),
    [anon_sym_xnor] = ACTIONS(4358),
    [anon_sym_buf] = ACTIONS(4358),
    [anon_sym_tranif0] = ACTIONS(4358),
    [anon_sym_tranif1] = ACTIONS(4358),
    [anon_sym_rtranif1] = ACTIONS(4358),
    [anon_sym_rtranif0] = ACTIONS(4358),
    [anon_sym_tran] = ACTIONS(4358),
    [anon_sym_rtran] = ACTIONS(4358),
    [anon_sym_generate] = ACTIONS(4358),
    [anon_sym_for] = ACTIONS(4358),
    [anon_sym_initial] = ACTIONS(4358),
    [anon_sym_assign] = ACTIONS(4358),
    [anon_sym_alias] = ACTIONS(4358),
    [anon_sym_always_comb] = ACTIONS(4358),
    [anon_sym_always_latch] = ACTIONS(4358),
    [anon_sym_always_ff] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_global] = ACTIONS(4358),
    [anon_sym_LPAREN_STAR] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4356),
    [anon_sym_DOLLARunit] = ACTIONS(4356),
  },
  [4563] = {
    [sym_simple_identifier] = ACTIONS(4370),
    [anon_sym_wire] = ACTIONS(4370),
    [anon_sym_tri] = ACTIONS(4370),
    [anon_sym_tri0] = ACTIONS(4370),
    [anon_sym_tri1] = ACTIONS(4370),
    [anon_sym_wand] = ACTIONS(4370),
    [anon_sym_triand] = ACTIONS(4370),
    [anon_sym_wor] = ACTIONS(4370),
    [anon_sym_trior] = ACTIONS(4370),
    [anon_sym_trireg] = ACTIONS(4370),
    [anon_sym_uwire] = ACTIONS(4370),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym_COLON] = ACTIONS(10843),
    [anon_sym_extern] = ACTIONS(4370),
    [anon_sym_interface] = ACTIONS(4370),
    [anon_sym_checker] = ACTIONS(4370),
    [anon_sym_virtual] = ACTIONS(4370),
    [anon_sym_class] = ACTIONS(4370),
    [anon_sym_type] = ACTIONS(4370),
    [anon_sym_DOLLARfatal] = ACTIONS(4368),
    [anon_sym_DOLLARerror] = ACTIONS(4368),
    [anon_sym_DOLLARwarning] = ACTIONS(4368),
    [anon_sym_DOLLARinfo] = ACTIONS(4368),
    [anon_sym_default] = ACTIONS(4370),
    [anon_sym_clocking] = ACTIONS(4370),
    [anon_sym_defparam] = ACTIONS(4370),
    [anon_sym_bind] = ACTIONS(4370),
    [anon_sym_rand] = ACTIONS(4370),
    [anon_sym_const] = ACTIONS(4370),
    [anon_sym_function] = ACTIONS(4370),
    [anon_sym_static] = ACTIONS(4370),
    [anon_sym_constraint] = ACTIONS(4370),
    [anon_sym_if] = ACTIONS(4370),
    [anon_sym_else] = ACTIONS(4370),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_localparam] = ACTIONS(4370),
    [anon_sym_parameter] = ACTIONS(4370),
    [anon_sym_var] = ACTIONS(4370),
    [anon_sym_import] = ACTIONS(4370),
    [anon_sym_export] = ACTIONS(4370),
    [anon_sym_genvar] = ACTIONS(4370),
    [anon_sym_interconnect] = ACTIONS(4370),
    [anon_sym_typedef] = ACTIONS(4370),
    [anon_sym_enum] = ACTIONS(4370),
    [anon_sym_struct] = ACTIONS(4370),
    [anon_sym_union] = ACTIONS(4370),
    [anon_sym_nettype] = ACTIONS(4370),
    [anon_sym_automatic] = ACTIONS(4370),
    [anon_sym_string] = ACTIONS(4370),
    [anon_sym_chandle] = ACTIONS(4370),
    [anon_sym_event] = ACTIONS(4370),
    [anon_sym_byte] = ACTIONS(4370),
    [anon_sym_shortint] = ACTIONS(4370),
    [anon_sym_int] = ACTIONS(4370),
    [anon_sym_longint] = ACTIONS(4370),
    [anon_sym_integer] = ACTIONS(4370),
    [anon_sym_time] = ACTIONS(4370),
    [anon_sym_bit] = ACTIONS(4370),
    [anon_sym_logic] = ACTIONS(4370),
    [anon_sym_reg] = ACTIONS(4370),
    [anon_sym_shortreal] = ACTIONS(4370),
    [anon_sym_real] = ACTIONS(4370),
    [anon_sym_realtime] = ACTIONS(4370),
    [anon_sym_supply0] = ACTIONS(4370),
    [anon_sym_supply1] = ACTIONS(4370),
    [anon_sym_signed] = ACTIONS(4370),
    [anon_sym_unsigned] = ACTIONS(4370),
    [anon_sym_task] = ACTIONS(4370),
    [anon_sym_assert] = ACTIONS(4370),
    [anon_sym_property] = ACTIONS(4370),
    [anon_sym_assume] = ACTIONS(4370),
    [anon_sym_cover] = ACTIONS(4370),
    [anon_sym_sequence] = ACTIONS(4370),
    [anon_sym_restrict] = ACTIONS(4370),
    [anon_sym_not] = ACTIONS(4370),
    [anon_sym_or] = ACTIONS(4370),
    [anon_sym_and] = ACTIONS(4370),
    [anon_sym_case] = ACTIONS(4370),
    [anon_sym_always] = ACTIONS(4370),
    [anon_sym_covergroup] = ACTIONS(4370),
    [anon_sym_end] = ACTIONS(4370),
    [anon_sym_let] = ACTIONS(4370),
    [anon_sym_pulldown] = ACTIONS(4370),
    [anon_sym_pullup] = ACTIONS(4370),
    [anon_sym_cmos] = ACTIONS(4370),
    [anon_sym_rcmos] = ACTIONS(4370),
    [anon_sym_bufif0] = ACTIONS(4370),
    [anon_sym_bufif1] = ACTIONS(4370),
    [anon_sym_notif0] = ACTIONS(4370),
    [anon_sym_notif1] = ACTIONS(4370),
    [anon_sym_nmos] = ACTIONS(4370),
    [anon_sym_pmos] = ACTIONS(4370),
    [anon_sym_rnmos] = ACTIONS(4370),
    [anon_sym_rpmos] = ACTIONS(4370),
    [anon_sym_nand] = ACTIONS(4370),
    [anon_sym_nor] = ACTIONS(4370),
    [anon_sym_xor] = ACTIONS(4370),
    [anon_sym_xnor] = ACTIONS(4370),
    [anon_sym_buf] = ACTIONS(4370),
    [anon_sym_tranif0] = ACTIONS(4370),
    [anon_sym_tranif1] = ACTIONS(4370),
    [anon_sym_rtranif1] = ACTIONS(4370),
    [anon_sym_rtranif0] = ACTIONS(4370),
    [anon_sym_tran] = ACTIONS(4370),
    [anon_sym_rtran] = ACTIONS(4370),
    [anon_sym_generate] = ACTIONS(4370),
    [anon_sym_for] = ACTIONS(4370),
    [anon_sym_initial] = ACTIONS(4370),
    [anon_sym_assign] = ACTIONS(4370),
    [anon_sym_alias] = ACTIONS(4370),
    [anon_sym_always_comb] = ACTIONS(4370),
    [anon_sym_always_latch] = ACTIONS(4370),
    [anon_sym_always_ff] = ACTIONS(4370),
    [anon_sym_final] = ACTIONS(4370),
    [anon_sym_global] = ACTIONS(4370),
    [anon_sym_LPAREN_STAR] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4368),
    [anon_sym_DOLLARunit] = ACTIONS(4368),
  },
  [4564] = {
    [sym_simple_identifier] = ACTIONS(4382),
    [anon_sym_wire] = ACTIONS(4382),
    [anon_sym_tri] = ACTIONS(4382),
    [anon_sym_tri0] = ACTIONS(4382),
    [anon_sym_tri1] = ACTIONS(4382),
    [anon_sym_wand] = ACTIONS(4382),
    [anon_sym_triand] = ACTIONS(4382),
    [anon_sym_wor] = ACTIONS(4382),
    [anon_sym_trior] = ACTIONS(4382),
    [anon_sym_trireg] = ACTIONS(4382),
    [anon_sym_uwire] = ACTIONS(4382),
    [anon_sym_SEMI] = ACTIONS(4380),
    [anon_sym_COLON] = ACTIONS(10845),
    [anon_sym_extern] = ACTIONS(4382),
    [anon_sym_interface] = ACTIONS(4382),
    [anon_sym_checker] = ACTIONS(4382),
    [anon_sym_virtual] = ACTIONS(4382),
    [anon_sym_class] = ACTIONS(4382),
    [anon_sym_type] = ACTIONS(4382),
    [anon_sym_DOLLARfatal] = ACTIONS(4380),
    [anon_sym_DOLLARerror] = ACTIONS(4380),
    [anon_sym_DOLLARwarning] = ACTIONS(4380),
    [anon_sym_DOLLARinfo] = ACTIONS(4380),
    [anon_sym_default] = ACTIONS(4382),
    [anon_sym_clocking] = ACTIONS(4382),
    [anon_sym_defparam] = ACTIONS(4382),
    [anon_sym_bind] = ACTIONS(4382),
    [anon_sym_rand] = ACTIONS(4382),
    [anon_sym_const] = ACTIONS(4382),
    [anon_sym_function] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(4382),
    [anon_sym_constraint] = ACTIONS(4382),
    [anon_sym_if] = ACTIONS(4382),
    [anon_sym_else] = ACTIONS(4382),
    [anon_sym_LBRACK] = ACTIONS(4380),
    [anon_sym_localparam] = ACTIONS(4382),
    [anon_sym_parameter] = ACTIONS(4382),
    [anon_sym_var] = ACTIONS(4382),
    [anon_sym_import] = ACTIONS(4382),
    [anon_sym_export] = ACTIONS(4382),
    [anon_sym_genvar] = ACTIONS(4382),
    [anon_sym_interconnect] = ACTIONS(4382),
    [anon_sym_typedef] = ACTIONS(4382),
    [anon_sym_enum] = ACTIONS(4382),
    [anon_sym_struct] = ACTIONS(4382),
    [anon_sym_union] = ACTIONS(4382),
    [anon_sym_nettype] = ACTIONS(4382),
    [anon_sym_automatic] = ACTIONS(4382),
    [anon_sym_string] = ACTIONS(4382),
    [anon_sym_chandle] = ACTIONS(4382),
    [anon_sym_event] = ACTIONS(4382),
    [anon_sym_byte] = ACTIONS(4382),
    [anon_sym_shortint] = ACTIONS(4382),
    [anon_sym_int] = ACTIONS(4382),
    [anon_sym_longint] = ACTIONS(4382),
    [anon_sym_integer] = ACTIONS(4382),
    [anon_sym_time] = ACTIONS(4382),
    [anon_sym_bit] = ACTIONS(4382),
    [anon_sym_logic] = ACTIONS(4382),
    [anon_sym_reg] = ACTIONS(4382),
    [anon_sym_shortreal] = ACTIONS(4382),
    [anon_sym_real] = ACTIONS(4382),
    [anon_sym_realtime] = ACTIONS(4382),
    [anon_sym_supply0] = ACTIONS(4382),
    [anon_sym_supply1] = ACTIONS(4382),
    [anon_sym_signed] = ACTIONS(4382),
    [anon_sym_unsigned] = ACTIONS(4382),
    [anon_sym_task] = ACTIONS(4382),
    [anon_sym_assert] = ACTIONS(4382),
    [anon_sym_property] = ACTIONS(4382),
    [anon_sym_assume] = ACTIONS(4382),
    [anon_sym_cover] = ACTIONS(4382),
    [anon_sym_sequence] = ACTIONS(4382),
    [anon_sym_restrict] = ACTIONS(4382),
    [anon_sym_not] = ACTIONS(4382),
    [anon_sym_or] = ACTIONS(4382),
    [anon_sym_and] = ACTIONS(4382),
    [anon_sym_case] = ACTIONS(4382),
    [anon_sym_always] = ACTIONS(4382),
    [anon_sym_covergroup] = ACTIONS(4382),
    [anon_sym_end] = ACTIONS(4382),
    [anon_sym_let] = ACTIONS(4382),
    [anon_sym_pulldown] = ACTIONS(4382),
    [anon_sym_pullup] = ACTIONS(4382),
    [anon_sym_cmos] = ACTIONS(4382),
    [anon_sym_rcmos] = ACTIONS(4382),
    [anon_sym_bufif0] = ACTIONS(4382),
    [anon_sym_bufif1] = ACTIONS(4382),
    [anon_sym_notif0] = ACTIONS(4382),
    [anon_sym_notif1] = ACTIONS(4382),
    [anon_sym_nmos] = ACTIONS(4382),
    [anon_sym_pmos] = ACTIONS(4382),
    [anon_sym_rnmos] = ACTIONS(4382),
    [anon_sym_rpmos] = ACTIONS(4382),
    [anon_sym_nand] = ACTIONS(4382),
    [anon_sym_nor] = ACTIONS(4382),
    [anon_sym_xor] = ACTIONS(4382),
    [anon_sym_xnor] = ACTIONS(4382),
    [anon_sym_buf] = ACTIONS(4382),
    [anon_sym_tranif0] = ACTIONS(4382),
    [anon_sym_tranif1] = ACTIONS(4382),
    [anon_sym_rtranif1] = ACTIONS(4382),
    [anon_sym_rtranif0] = ACTIONS(4382),
    [anon_sym_tran] = ACTIONS(4382),
    [anon_sym_rtran] = ACTIONS(4382),
    [anon_sym_generate] = ACTIONS(4382),
    [anon_sym_for] = ACTIONS(4382),
    [anon_sym_initial] = ACTIONS(4382),
    [anon_sym_assign] = ACTIONS(4382),
    [anon_sym_alias] = ACTIONS(4382),
    [anon_sym_always_comb] = ACTIONS(4382),
    [anon_sym_always_latch] = ACTIONS(4382),
    [anon_sym_always_ff] = ACTIONS(4382),
    [anon_sym_final] = ACTIONS(4382),
    [anon_sym_global] = ACTIONS(4382),
    [anon_sym_LPAREN_STAR] = ACTIONS(4380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4380),
    [anon_sym_DOLLARunit] = ACTIONS(4380),
  },
  [4565] = {
    [sym_simple_identifier] = ACTIONS(4424),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_COLON] = ACTIONS(10847),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_rand] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_end] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [4566] = {
    [sym_simple_identifier] = ACTIONS(4412),
    [anon_sym_wire] = ACTIONS(4412),
    [anon_sym_tri] = ACTIONS(4412),
    [anon_sym_tri0] = ACTIONS(4412),
    [anon_sym_tri1] = ACTIONS(4412),
    [anon_sym_wand] = ACTIONS(4412),
    [anon_sym_triand] = ACTIONS(4412),
    [anon_sym_wor] = ACTIONS(4412),
    [anon_sym_trior] = ACTIONS(4412),
    [anon_sym_trireg] = ACTIONS(4412),
    [anon_sym_uwire] = ACTIONS(4412),
    [anon_sym_SEMI] = ACTIONS(4410),
    [anon_sym_COLON] = ACTIONS(10849),
    [anon_sym_extern] = ACTIONS(4412),
    [anon_sym_interface] = ACTIONS(4412),
    [anon_sym_checker] = ACTIONS(4412),
    [anon_sym_virtual] = ACTIONS(4412),
    [anon_sym_class] = ACTIONS(4412),
    [anon_sym_type] = ACTIONS(4412),
    [anon_sym_DOLLARfatal] = ACTIONS(4410),
    [anon_sym_DOLLARerror] = ACTIONS(4410),
    [anon_sym_DOLLARwarning] = ACTIONS(4410),
    [anon_sym_DOLLARinfo] = ACTIONS(4410),
    [anon_sym_default] = ACTIONS(4412),
    [anon_sym_clocking] = ACTIONS(4412),
    [anon_sym_defparam] = ACTIONS(4412),
    [anon_sym_bind] = ACTIONS(4412),
    [anon_sym_rand] = ACTIONS(4412),
    [anon_sym_const] = ACTIONS(4412),
    [anon_sym_function] = ACTIONS(4412),
    [anon_sym_static] = ACTIONS(4412),
    [anon_sym_constraint] = ACTIONS(4412),
    [anon_sym_if] = ACTIONS(4412),
    [anon_sym_else] = ACTIONS(4412),
    [anon_sym_LBRACK] = ACTIONS(4410),
    [anon_sym_localparam] = ACTIONS(4412),
    [anon_sym_parameter] = ACTIONS(4412),
    [anon_sym_var] = ACTIONS(4412),
    [anon_sym_import] = ACTIONS(4412),
    [anon_sym_export] = ACTIONS(4412),
    [anon_sym_genvar] = ACTIONS(4412),
    [anon_sym_interconnect] = ACTIONS(4412),
    [anon_sym_typedef] = ACTIONS(4412),
    [anon_sym_enum] = ACTIONS(4412),
    [anon_sym_struct] = ACTIONS(4412),
    [anon_sym_union] = ACTIONS(4412),
    [anon_sym_nettype] = ACTIONS(4412),
    [anon_sym_automatic] = ACTIONS(4412),
    [anon_sym_string] = ACTIONS(4412),
    [anon_sym_chandle] = ACTIONS(4412),
    [anon_sym_event] = ACTIONS(4412),
    [anon_sym_byte] = ACTIONS(4412),
    [anon_sym_shortint] = ACTIONS(4412),
    [anon_sym_int] = ACTIONS(4412),
    [anon_sym_longint] = ACTIONS(4412),
    [anon_sym_integer] = ACTIONS(4412),
    [anon_sym_time] = ACTIONS(4412),
    [anon_sym_bit] = ACTIONS(4412),
    [anon_sym_logic] = ACTIONS(4412),
    [anon_sym_reg] = ACTIONS(4412),
    [anon_sym_shortreal] = ACTIONS(4412),
    [anon_sym_real] = ACTIONS(4412),
    [anon_sym_realtime] = ACTIONS(4412),
    [anon_sym_supply0] = ACTIONS(4412),
    [anon_sym_supply1] = ACTIONS(4412),
    [anon_sym_signed] = ACTIONS(4412),
    [anon_sym_unsigned] = ACTIONS(4412),
    [anon_sym_task] = ACTIONS(4412),
    [anon_sym_assert] = ACTIONS(4412),
    [anon_sym_property] = ACTIONS(4412),
    [anon_sym_assume] = ACTIONS(4412),
    [anon_sym_cover] = ACTIONS(4412),
    [anon_sym_sequence] = ACTIONS(4412),
    [anon_sym_restrict] = ACTIONS(4412),
    [anon_sym_not] = ACTIONS(4412),
    [anon_sym_or] = ACTIONS(4412),
    [anon_sym_and] = ACTIONS(4412),
    [anon_sym_case] = ACTIONS(4412),
    [anon_sym_always] = ACTIONS(4412),
    [anon_sym_covergroup] = ACTIONS(4412),
    [anon_sym_end] = ACTIONS(4412),
    [anon_sym_let] = ACTIONS(4412),
    [anon_sym_pulldown] = ACTIONS(4412),
    [anon_sym_pullup] = ACTIONS(4412),
    [anon_sym_cmos] = ACTIONS(4412),
    [anon_sym_rcmos] = ACTIONS(4412),
    [anon_sym_bufif0] = ACTIONS(4412),
    [anon_sym_bufif1] = ACTIONS(4412),
    [anon_sym_notif0] = ACTIONS(4412),
    [anon_sym_notif1] = ACTIONS(4412),
    [anon_sym_nmos] = ACTIONS(4412),
    [anon_sym_pmos] = ACTIONS(4412),
    [anon_sym_rnmos] = ACTIONS(4412),
    [anon_sym_rpmos] = ACTIONS(4412),
    [anon_sym_nand] = ACTIONS(4412),
    [anon_sym_nor] = ACTIONS(4412),
    [anon_sym_xor] = ACTIONS(4412),
    [anon_sym_xnor] = ACTIONS(4412),
    [anon_sym_buf] = ACTIONS(4412),
    [anon_sym_tranif0] = ACTIONS(4412),
    [anon_sym_tranif1] = ACTIONS(4412),
    [anon_sym_rtranif1] = ACTIONS(4412),
    [anon_sym_rtranif0] = ACTIONS(4412),
    [anon_sym_tran] = ACTIONS(4412),
    [anon_sym_rtran] = ACTIONS(4412),
    [anon_sym_generate] = ACTIONS(4412),
    [anon_sym_for] = ACTIONS(4412),
    [anon_sym_initial] = ACTIONS(4412),
    [anon_sym_assign] = ACTIONS(4412),
    [anon_sym_alias] = ACTIONS(4412),
    [anon_sym_always_comb] = ACTIONS(4412),
    [anon_sym_always_latch] = ACTIONS(4412),
    [anon_sym_always_ff] = ACTIONS(4412),
    [anon_sym_final] = ACTIONS(4412),
    [anon_sym_global] = ACTIONS(4412),
    [anon_sym_LPAREN_STAR] = ACTIONS(4410),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4410),
    [anon_sym_DOLLARunit] = ACTIONS(4410),
  },
  [4567] = {
    [sym_simple_identifier] = ACTIONS(4518),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_COLON] = ACTIONS(10851),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_rand] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_end] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [4568] = {
    [sym_simple_identifier] = ACTIONS(4762),
    [anon_sym_wire] = ACTIONS(4762),
    [anon_sym_tri] = ACTIONS(4762),
    [anon_sym_tri0] = ACTIONS(4762),
    [anon_sym_tri1] = ACTIONS(4762),
    [anon_sym_wand] = ACTIONS(4762),
    [anon_sym_triand] = ACTIONS(4762),
    [anon_sym_wor] = ACTIONS(4762),
    [anon_sym_trior] = ACTIONS(4762),
    [anon_sym_trireg] = ACTIONS(4762),
    [anon_sym_uwire] = ACTIONS(4762),
    [anon_sym_SEMI] = ACTIONS(4760),
    [anon_sym_COLON] = ACTIONS(10853),
    [anon_sym_extern] = ACTIONS(4762),
    [anon_sym_interface] = ACTIONS(4762),
    [anon_sym_checker] = ACTIONS(4762),
    [anon_sym_virtual] = ACTIONS(4762),
    [anon_sym_class] = ACTIONS(4762),
    [anon_sym_type] = ACTIONS(4762),
    [anon_sym_DOLLARfatal] = ACTIONS(4760),
    [anon_sym_DOLLARerror] = ACTIONS(4760),
    [anon_sym_DOLLARwarning] = ACTIONS(4760),
    [anon_sym_DOLLARinfo] = ACTIONS(4760),
    [anon_sym_default] = ACTIONS(4762),
    [anon_sym_clocking] = ACTIONS(4762),
    [anon_sym_defparam] = ACTIONS(4762),
    [anon_sym_bind] = ACTIONS(4762),
    [anon_sym_rand] = ACTIONS(4762),
    [anon_sym_const] = ACTIONS(4762),
    [anon_sym_function] = ACTIONS(4762),
    [anon_sym_static] = ACTIONS(4762),
    [anon_sym_constraint] = ACTIONS(4762),
    [anon_sym_if] = ACTIONS(4762),
    [anon_sym_else] = ACTIONS(4762),
    [anon_sym_LBRACK] = ACTIONS(4760),
    [anon_sym_localparam] = ACTIONS(4762),
    [anon_sym_parameter] = ACTIONS(4762),
    [anon_sym_var] = ACTIONS(4762),
    [anon_sym_import] = ACTIONS(4762),
    [anon_sym_export] = ACTIONS(4762),
    [anon_sym_genvar] = ACTIONS(4762),
    [anon_sym_interconnect] = ACTIONS(4762),
    [anon_sym_typedef] = ACTIONS(4762),
    [anon_sym_enum] = ACTIONS(4762),
    [anon_sym_struct] = ACTIONS(4762),
    [anon_sym_union] = ACTIONS(4762),
    [anon_sym_nettype] = ACTIONS(4762),
    [anon_sym_automatic] = ACTIONS(4762),
    [anon_sym_string] = ACTIONS(4762),
    [anon_sym_chandle] = ACTIONS(4762),
    [anon_sym_event] = ACTIONS(4762),
    [anon_sym_byte] = ACTIONS(4762),
    [anon_sym_shortint] = ACTIONS(4762),
    [anon_sym_int] = ACTIONS(4762),
    [anon_sym_longint] = ACTIONS(4762),
    [anon_sym_integer] = ACTIONS(4762),
    [anon_sym_time] = ACTIONS(4762),
    [anon_sym_bit] = ACTIONS(4762),
    [anon_sym_logic] = ACTIONS(4762),
    [anon_sym_reg] = ACTIONS(4762),
    [anon_sym_shortreal] = ACTIONS(4762),
    [anon_sym_real] = ACTIONS(4762),
    [anon_sym_realtime] = ACTIONS(4762),
    [anon_sym_supply0] = ACTIONS(4762),
    [anon_sym_supply1] = ACTIONS(4762),
    [anon_sym_signed] = ACTIONS(4762),
    [anon_sym_unsigned] = ACTIONS(4762),
    [anon_sym_task] = ACTIONS(4762),
    [anon_sym_assert] = ACTIONS(4762),
    [anon_sym_property] = ACTIONS(4762),
    [anon_sym_assume] = ACTIONS(4762),
    [anon_sym_cover] = ACTIONS(4762),
    [anon_sym_sequence] = ACTIONS(4762),
    [anon_sym_restrict] = ACTIONS(4762),
    [anon_sym_not] = ACTIONS(4762),
    [anon_sym_or] = ACTIONS(4762),
    [anon_sym_and] = ACTIONS(4762),
    [anon_sym_case] = ACTIONS(4762),
    [anon_sym_always] = ACTIONS(4762),
    [anon_sym_covergroup] = ACTIONS(4762),
    [anon_sym_end] = ACTIONS(4762),
    [anon_sym_let] = ACTIONS(4762),
    [anon_sym_pulldown] = ACTIONS(4762),
    [anon_sym_pullup] = ACTIONS(4762),
    [anon_sym_cmos] = ACTIONS(4762),
    [anon_sym_rcmos] = ACTIONS(4762),
    [anon_sym_bufif0] = ACTIONS(4762),
    [anon_sym_bufif1] = ACTIONS(4762),
    [anon_sym_notif0] = ACTIONS(4762),
    [anon_sym_notif1] = ACTIONS(4762),
    [anon_sym_nmos] = ACTIONS(4762),
    [anon_sym_pmos] = ACTIONS(4762),
    [anon_sym_rnmos] = ACTIONS(4762),
    [anon_sym_rpmos] = ACTIONS(4762),
    [anon_sym_nand] = ACTIONS(4762),
    [anon_sym_nor] = ACTIONS(4762),
    [anon_sym_xor] = ACTIONS(4762),
    [anon_sym_xnor] = ACTIONS(4762),
    [anon_sym_buf] = ACTIONS(4762),
    [anon_sym_tranif0] = ACTIONS(4762),
    [anon_sym_tranif1] = ACTIONS(4762),
    [anon_sym_rtranif1] = ACTIONS(4762),
    [anon_sym_rtranif0] = ACTIONS(4762),
    [anon_sym_tran] = ACTIONS(4762),
    [anon_sym_rtran] = ACTIONS(4762),
    [anon_sym_generate] = ACTIONS(4762),
    [anon_sym_for] = ACTIONS(4762),
    [anon_sym_initial] = ACTIONS(4762),
    [anon_sym_assign] = ACTIONS(4762),
    [anon_sym_alias] = ACTIONS(4762),
    [anon_sym_always_comb] = ACTIONS(4762),
    [anon_sym_always_latch] = ACTIONS(4762),
    [anon_sym_always_ff] = ACTIONS(4762),
    [anon_sym_final] = ACTIONS(4762),
    [anon_sym_global] = ACTIONS(4762),
    [anon_sym_LPAREN_STAR] = ACTIONS(4760),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4760),
    [anon_sym_DOLLARunit] = ACTIONS(4760),
  },
  [4569] = {
    [sym_simple_identifier] = ACTIONS(4358),
    [anon_sym_wire] = ACTIONS(4358),
    [anon_sym_tri] = ACTIONS(4358),
    [anon_sym_tri0] = ACTIONS(4358),
    [anon_sym_tri1] = ACTIONS(4358),
    [anon_sym_wand] = ACTIONS(4358),
    [anon_sym_triand] = ACTIONS(4358),
    [anon_sym_wor] = ACTIONS(4358),
    [anon_sym_trior] = ACTIONS(4358),
    [anon_sym_trireg] = ACTIONS(4358),
    [anon_sym_uwire] = ACTIONS(4358),
    [anon_sym_SEMI] = ACTIONS(4356),
    [anon_sym_COLON] = ACTIONS(10855),
    [anon_sym_extern] = ACTIONS(4358),
    [anon_sym_interface] = ACTIONS(4358),
    [anon_sym_checker] = ACTIONS(4358),
    [anon_sym_virtual] = ACTIONS(4358),
    [anon_sym_class] = ACTIONS(4358),
    [anon_sym_type] = ACTIONS(4358),
    [anon_sym_DOLLARfatal] = ACTIONS(4356),
    [anon_sym_DOLLARerror] = ACTIONS(4356),
    [anon_sym_DOLLARwarning] = ACTIONS(4356),
    [anon_sym_DOLLARinfo] = ACTIONS(4356),
    [anon_sym_default] = ACTIONS(4358),
    [anon_sym_clocking] = ACTIONS(4358),
    [anon_sym_defparam] = ACTIONS(4358),
    [anon_sym_bind] = ACTIONS(4358),
    [anon_sym_rand] = ACTIONS(4358),
    [anon_sym_const] = ACTIONS(4358),
    [anon_sym_function] = ACTIONS(4358),
    [anon_sym_static] = ACTIONS(4358),
    [anon_sym_constraint] = ACTIONS(4358),
    [anon_sym_if] = ACTIONS(4358),
    [anon_sym_else] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4356),
    [anon_sym_localparam] = ACTIONS(4358),
    [anon_sym_parameter] = ACTIONS(4358),
    [anon_sym_var] = ACTIONS(4358),
    [anon_sym_import] = ACTIONS(4358),
    [anon_sym_export] = ACTIONS(4358),
    [anon_sym_genvar] = ACTIONS(4358),
    [anon_sym_interconnect] = ACTIONS(4358),
    [anon_sym_typedef] = ACTIONS(4358),
    [anon_sym_enum] = ACTIONS(4358),
    [anon_sym_struct] = ACTIONS(4358),
    [anon_sym_union] = ACTIONS(4358),
    [anon_sym_nettype] = ACTIONS(4358),
    [anon_sym_automatic] = ACTIONS(4358),
    [anon_sym_string] = ACTIONS(4358),
    [anon_sym_chandle] = ACTIONS(4358),
    [anon_sym_event] = ACTIONS(4358),
    [anon_sym_byte] = ACTIONS(4358),
    [anon_sym_shortint] = ACTIONS(4358),
    [anon_sym_int] = ACTIONS(4358),
    [anon_sym_longint] = ACTIONS(4358),
    [anon_sym_integer] = ACTIONS(4358),
    [anon_sym_time] = ACTIONS(4358),
    [anon_sym_bit] = ACTIONS(4358),
    [anon_sym_logic] = ACTIONS(4358),
    [anon_sym_reg] = ACTIONS(4358),
    [anon_sym_shortreal] = ACTIONS(4358),
    [anon_sym_real] = ACTIONS(4358),
    [anon_sym_realtime] = ACTIONS(4358),
    [anon_sym_supply0] = ACTIONS(4358),
    [anon_sym_supply1] = ACTIONS(4358),
    [anon_sym_signed] = ACTIONS(4358),
    [anon_sym_unsigned] = ACTIONS(4358),
    [anon_sym_task] = ACTIONS(4358),
    [anon_sym_assert] = ACTIONS(4358),
    [anon_sym_property] = ACTIONS(4358),
    [anon_sym_assume] = ACTIONS(4358),
    [anon_sym_cover] = ACTIONS(4358),
    [anon_sym_sequence] = ACTIONS(4358),
    [anon_sym_restrict] = ACTIONS(4358),
    [anon_sym_not] = ACTIONS(4358),
    [anon_sym_or] = ACTIONS(4358),
    [anon_sym_and] = ACTIONS(4358),
    [anon_sym_case] = ACTIONS(4358),
    [anon_sym_always] = ACTIONS(4358),
    [anon_sym_covergroup] = ACTIONS(4358),
    [anon_sym_let] = ACTIONS(4358),
    [anon_sym_pulldown] = ACTIONS(4358),
    [anon_sym_pullup] = ACTIONS(4358),
    [anon_sym_cmos] = ACTIONS(4358),
    [anon_sym_rcmos] = ACTIONS(4358),
    [anon_sym_bufif0] = ACTIONS(4358),
    [anon_sym_bufif1] = ACTIONS(4358),
    [anon_sym_notif0] = ACTIONS(4358),
    [anon_sym_notif1] = ACTIONS(4358),
    [anon_sym_nmos] = ACTIONS(4358),
    [anon_sym_pmos] = ACTIONS(4358),
    [anon_sym_rnmos] = ACTIONS(4358),
    [anon_sym_rpmos] = ACTIONS(4358),
    [anon_sym_nand] = ACTIONS(4358),
    [anon_sym_nor] = ACTIONS(4358),
    [anon_sym_xor] = ACTIONS(4358),
    [anon_sym_xnor] = ACTIONS(4358),
    [anon_sym_buf] = ACTIONS(4358),
    [anon_sym_tranif0] = ACTIONS(4358),
    [anon_sym_tranif1] = ACTIONS(4358),
    [anon_sym_rtranif1] = ACTIONS(4358),
    [anon_sym_rtranif0] = ACTIONS(4358),
    [anon_sym_tran] = ACTIONS(4358),
    [anon_sym_rtran] = ACTIONS(4358),
    [anon_sym_generate] = ACTIONS(4358),
    [anon_sym_endgenerate] = ACTIONS(4358),
    [anon_sym_for] = ACTIONS(4358),
    [anon_sym_initial] = ACTIONS(4358),
    [anon_sym_assign] = ACTIONS(4358),
    [anon_sym_alias] = ACTIONS(4358),
    [anon_sym_always_comb] = ACTIONS(4358),
    [anon_sym_always_latch] = ACTIONS(4358),
    [anon_sym_always_ff] = ACTIONS(4358),
    [anon_sym_final] = ACTIONS(4358),
    [anon_sym_global] = ACTIONS(4358),
    [anon_sym_LPAREN_STAR] = ACTIONS(4356),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4356),
    [anon_sym_DOLLARunit] = ACTIONS(4356),
  },
  [4570] = {
    [sym_simple_identifier] = ACTIONS(4370),
    [anon_sym_wire] = ACTIONS(4370),
    [anon_sym_tri] = ACTIONS(4370),
    [anon_sym_tri0] = ACTIONS(4370),
    [anon_sym_tri1] = ACTIONS(4370),
    [anon_sym_wand] = ACTIONS(4370),
    [anon_sym_triand] = ACTIONS(4370),
    [anon_sym_wor] = ACTIONS(4370),
    [anon_sym_trior] = ACTIONS(4370),
    [anon_sym_trireg] = ACTIONS(4370),
    [anon_sym_uwire] = ACTIONS(4370),
    [anon_sym_SEMI] = ACTIONS(4368),
    [anon_sym_COLON] = ACTIONS(10857),
    [anon_sym_extern] = ACTIONS(4370),
    [anon_sym_interface] = ACTIONS(4370),
    [anon_sym_checker] = ACTIONS(4370),
    [anon_sym_virtual] = ACTIONS(4370),
    [anon_sym_class] = ACTIONS(4370),
    [anon_sym_type] = ACTIONS(4370),
    [anon_sym_DOLLARfatal] = ACTIONS(4368),
    [anon_sym_DOLLARerror] = ACTIONS(4368),
    [anon_sym_DOLLARwarning] = ACTIONS(4368),
    [anon_sym_DOLLARinfo] = ACTIONS(4368),
    [anon_sym_default] = ACTIONS(4370),
    [anon_sym_clocking] = ACTIONS(4370),
    [anon_sym_defparam] = ACTIONS(4370),
    [anon_sym_bind] = ACTIONS(4370),
    [anon_sym_rand] = ACTIONS(4370),
    [anon_sym_const] = ACTIONS(4370),
    [anon_sym_function] = ACTIONS(4370),
    [anon_sym_static] = ACTIONS(4370),
    [anon_sym_constraint] = ACTIONS(4370),
    [anon_sym_if] = ACTIONS(4370),
    [anon_sym_else] = ACTIONS(4370),
    [anon_sym_LBRACK] = ACTIONS(4368),
    [anon_sym_localparam] = ACTIONS(4370),
    [anon_sym_parameter] = ACTIONS(4370),
    [anon_sym_var] = ACTIONS(4370),
    [anon_sym_import] = ACTIONS(4370),
    [anon_sym_export] = ACTIONS(4370),
    [anon_sym_genvar] = ACTIONS(4370),
    [anon_sym_interconnect] = ACTIONS(4370),
    [anon_sym_typedef] = ACTIONS(4370),
    [anon_sym_enum] = ACTIONS(4370),
    [anon_sym_struct] = ACTIONS(4370),
    [anon_sym_union] = ACTIONS(4370),
    [anon_sym_nettype] = ACTIONS(4370),
    [anon_sym_automatic] = ACTIONS(4370),
    [anon_sym_string] = ACTIONS(4370),
    [anon_sym_chandle] = ACTIONS(4370),
    [anon_sym_event] = ACTIONS(4370),
    [anon_sym_byte] = ACTIONS(4370),
    [anon_sym_shortint] = ACTIONS(4370),
    [anon_sym_int] = ACTIONS(4370),
    [anon_sym_longint] = ACTIONS(4370),
    [anon_sym_integer] = ACTIONS(4370),
    [anon_sym_time] = ACTIONS(4370),
    [anon_sym_bit] = ACTIONS(4370),
    [anon_sym_logic] = ACTIONS(4370),
    [anon_sym_reg] = ACTIONS(4370),
    [anon_sym_shortreal] = ACTIONS(4370),
    [anon_sym_real] = ACTIONS(4370),
    [anon_sym_realtime] = ACTIONS(4370),
    [anon_sym_supply0] = ACTIONS(4370),
    [anon_sym_supply1] = ACTIONS(4370),
    [anon_sym_signed] = ACTIONS(4370),
    [anon_sym_unsigned] = ACTIONS(4370),
    [anon_sym_task] = ACTIONS(4370),
    [anon_sym_assert] = ACTIONS(4370),
    [anon_sym_property] = ACTIONS(4370),
    [anon_sym_assume] = ACTIONS(4370),
    [anon_sym_cover] = ACTIONS(4370),
    [anon_sym_sequence] = ACTIONS(4370),
    [anon_sym_restrict] = ACTIONS(4370),
    [anon_sym_not] = ACTIONS(4370),
    [anon_sym_or] = ACTIONS(4370),
    [anon_sym_and] = ACTIONS(4370),
    [anon_sym_case] = ACTIONS(4370),
    [anon_sym_always] = ACTIONS(4370),
    [anon_sym_covergroup] = ACTIONS(4370),
    [anon_sym_let] = ACTIONS(4370),
    [anon_sym_pulldown] = ACTIONS(4370),
    [anon_sym_pullup] = ACTIONS(4370),
    [anon_sym_cmos] = ACTIONS(4370),
    [anon_sym_rcmos] = ACTIONS(4370),
    [anon_sym_bufif0] = ACTIONS(4370),
    [anon_sym_bufif1] = ACTIONS(4370),
    [anon_sym_notif0] = ACTIONS(4370),
    [anon_sym_notif1] = ACTIONS(4370),
    [anon_sym_nmos] = ACTIONS(4370),
    [anon_sym_pmos] = ACTIONS(4370),
    [anon_sym_rnmos] = ACTIONS(4370),
    [anon_sym_rpmos] = ACTIONS(4370),
    [anon_sym_nand] = ACTIONS(4370),
    [anon_sym_nor] = ACTIONS(4370),
    [anon_sym_xor] = ACTIONS(4370),
    [anon_sym_xnor] = ACTIONS(4370),
    [anon_sym_buf] = ACTIONS(4370),
    [anon_sym_tranif0] = ACTIONS(4370),
    [anon_sym_tranif1] = ACTIONS(4370),
    [anon_sym_rtranif1] = ACTIONS(4370),
    [anon_sym_rtranif0] = ACTIONS(4370),
    [anon_sym_tran] = ACTIONS(4370),
    [anon_sym_rtran] = ACTIONS(4370),
    [anon_sym_generate] = ACTIONS(4370),
    [anon_sym_endgenerate] = ACTIONS(4370),
    [anon_sym_for] = ACTIONS(4370),
    [anon_sym_initial] = ACTIONS(4370),
    [anon_sym_assign] = ACTIONS(4370),
    [anon_sym_alias] = ACTIONS(4370),
    [anon_sym_always_comb] = ACTIONS(4370),
    [anon_sym_always_latch] = ACTIONS(4370),
    [anon_sym_always_ff] = ACTIONS(4370),
    [anon_sym_final] = ACTIONS(4370),
    [anon_sym_global] = ACTIONS(4370),
    [anon_sym_LPAREN_STAR] = ACTIONS(4368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4368),
    [anon_sym_DOLLARunit] = ACTIONS(4368),
  },
  [4571] = {
    [sym_simple_identifier] = ACTIONS(4524),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_COLON] = ACTIONS(10859),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_rand] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_end] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [4572] = {
    [sym_simple_identifier] = ACTIONS(4382),
    [anon_sym_wire] = ACTIONS(4382),
    [anon_sym_tri] = ACTIONS(4382),
    [anon_sym_tri0] = ACTIONS(4382),
    [anon_sym_tri1] = ACTIONS(4382),
    [anon_sym_wand] = ACTIONS(4382),
    [anon_sym_triand] = ACTIONS(4382),
    [anon_sym_wor] = ACTIONS(4382),
    [anon_sym_trior] = ACTIONS(4382),
    [anon_sym_trireg] = ACTIONS(4382),
    [anon_sym_uwire] = ACTIONS(4382),
    [anon_sym_SEMI] = ACTIONS(4380),
    [anon_sym_COLON] = ACTIONS(10861),
    [anon_sym_extern] = ACTIONS(4382),
    [anon_sym_interface] = ACTIONS(4382),
    [anon_sym_checker] = ACTIONS(4382),
    [anon_sym_virtual] = ACTIONS(4382),
    [anon_sym_class] = ACTIONS(4382),
    [anon_sym_type] = ACTIONS(4382),
    [anon_sym_DOLLARfatal] = ACTIONS(4380),
    [anon_sym_DOLLARerror] = ACTIONS(4380),
    [anon_sym_DOLLARwarning] = ACTIONS(4380),
    [anon_sym_DOLLARinfo] = ACTIONS(4380),
    [anon_sym_default] = ACTIONS(4382),
    [anon_sym_clocking] = ACTIONS(4382),
    [anon_sym_defparam] = ACTIONS(4382),
    [anon_sym_bind] = ACTIONS(4382),
    [anon_sym_rand] = ACTIONS(4382),
    [anon_sym_const] = ACTIONS(4382),
    [anon_sym_function] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(4382),
    [anon_sym_constraint] = ACTIONS(4382),
    [anon_sym_if] = ACTIONS(4382),
    [anon_sym_else] = ACTIONS(4382),
    [anon_sym_LBRACK] = ACTIONS(4380),
    [anon_sym_localparam] = ACTIONS(4382),
    [anon_sym_parameter] = ACTIONS(4382),
    [anon_sym_var] = ACTIONS(4382),
    [anon_sym_import] = ACTIONS(4382),
    [anon_sym_export] = ACTIONS(4382),
    [anon_sym_genvar] = ACTIONS(4382),
    [anon_sym_interconnect] = ACTIONS(4382),
    [anon_sym_typedef] = ACTIONS(4382),
    [anon_sym_enum] = ACTIONS(4382),
    [anon_sym_struct] = ACTIONS(4382),
    [anon_sym_union] = ACTIONS(4382),
    [anon_sym_nettype] = ACTIONS(4382),
    [anon_sym_automatic] = ACTIONS(4382),
    [anon_sym_string] = ACTIONS(4382),
    [anon_sym_chandle] = ACTIONS(4382),
    [anon_sym_event] = ACTIONS(4382),
    [anon_sym_byte] = ACTIONS(4382),
    [anon_sym_shortint] = ACTIONS(4382),
    [anon_sym_int] = ACTIONS(4382),
    [anon_sym_longint] = ACTIONS(4382),
    [anon_sym_integer] = ACTIONS(4382),
    [anon_sym_time] = ACTIONS(4382),
    [anon_sym_bit] = ACTIONS(4382),
    [anon_sym_logic] = ACTIONS(4382),
    [anon_sym_reg] = ACTIONS(4382),
    [anon_sym_shortreal] = ACTIONS(4382),
    [anon_sym_real] = ACTIONS(4382),
    [anon_sym_realtime] = ACTIONS(4382),
    [anon_sym_supply0] = ACTIONS(4382),
    [anon_sym_supply1] = ACTIONS(4382),
    [anon_sym_signed] = ACTIONS(4382),
    [anon_sym_unsigned] = ACTIONS(4382),
    [anon_sym_task] = ACTIONS(4382),
    [anon_sym_assert] = ACTIONS(4382),
    [anon_sym_property] = ACTIONS(4382),
    [anon_sym_assume] = ACTIONS(4382),
    [anon_sym_cover] = ACTIONS(4382),
    [anon_sym_sequence] = ACTIONS(4382),
    [anon_sym_restrict] = ACTIONS(4382),
    [anon_sym_not] = ACTIONS(4382),
    [anon_sym_or] = ACTIONS(4382),
    [anon_sym_and] = ACTIONS(4382),
    [anon_sym_case] = ACTIONS(4382),
    [anon_sym_always] = ACTIONS(4382),
    [anon_sym_covergroup] = ACTIONS(4382),
    [anon_sym_let] = ACTIONS(4382),
    [anon_sym_pulldown] = ACTIONS(4382),
    [anon_sym_pullup] = ACTIONS(4382),
    [anon_sym_cmos] = ACTIONS(4382),
    [anon_sym_rcmos] = ACTIONS(4382),
    [anon_sym_bufif0] = ACTIONS(4382),
    [anon_sym_bufif1] = ACTIONS(4382),
    [anon_sym_notif0] = ACTIONS(4382),
    [anon_sym_notif1] = ACTIONS(4382),
    [anon_sym_nmos] = ACTIONS(4382),
    [anon_sym_pmos] = ACTIONS(4382),
    [anon_sym_rnmos] = ACTIONS(4382),
    [anon_sym_rpmos] = ACTIONS(4382),
    [anon_sym_nand] = ACTIONS(4382),
    [anon_sym_nor] = ACTIONS(4382),
    [anon_sym_xor] = ACTIONS(4382),
    [anon_sym_xnor] = ACTIONS(4382),
    [anon_sym_buf] = ACTIONS(4382),
    [anon_sym_tranif0] = ACTIONS(4382),
    [anon_sym_tranif1] = ACTIONS(4382),
    [anon_sym_rtranif1] = ACTIONS(4382),
    [anon_sym_rtranif0] = ACTIONS(4382),
    [anon_sym_tran] = ACTIONS(4382),
    [anon_sym_rtran] = ACTIONS(4382),
    [anon_sym_generate] = ACTIONS(4382),
    [anon_sym_endgenerate] = ACTIONS(4382),
    [anon_sym_for] = ACTIONS(4382),
    [anon_sym_initial] = ACTIONS(4382),
    [anon_sym_assign] = ACTIONS(4382),
    [anon_sym_alias] = ACTIONS(4382),
    [anon_sym_always_comb] = ACTIONS(4382),
    [anon_sym_always_latch] = ACTIONS(4382),
    [anon_sym_always_ff] = ACTIONS(4382),
    [anon_sym_final] = ACTIONS(4382),
    [anon_sym_global] = ACTIONS(4382),
    [anon_sym_LPAREN_STAR] = ACTIONS(4380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4380),
    [anon_sym_DOLLARunit] = ACTIONS(4380),
  },
  [4573] = {
    [sym_simple_identifier] = ACTIONS(4424),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_COLON] = ACTIONS(10863),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_rand] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_endgenerate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [4574] = {
    [sym_simple_identifier] = ACTIONS(4594),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_COLON] = ACTIONS(10865),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_rand] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_end] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [4575] = {
    [sym_simple_identifier] = ACTIONS(4168),
    [anon_sym_wire] = ACTIONS(4168),
    [anon_sym_tri] = ACTIONS(4168),
    [anon_sym_tri0] = ACTIONS(4168),
    [anon_sym_tri1] = ACTIONS(4168),
    [anon_sym_wand] = ACTIONS(4168),
    [anon_sym_triand] = ACTIONS(4168),
    [anon_sym_wor] = ACTIONS(4168),
    [anon_sym_trior] = ACTIONS(4168),
    [anon_sym_trireg] = ACTIONS(4168),
    [anon_sym_uwire] = ACTIONS(4168),
    [anon_sym_SEMI] = ACTIONS(4166),
    [anon_sym_COLON] = ACTIONS(10867),
    [anon_sym_extern] = ACTIONS(4168),
    [anon_sym_interface] = ACTIONS(4168),
    [anon_sym_checker] = ACTIONS(4168),
    [anon_sym_virtual] = ACTIONS(4168),
    [anon_sym_class] = ACTIONS(4168),
    [anon_sym_type] = ACTIONS(4168),
    [anon_sym_DOLLARfatal] = ACTIONS(4166),
    [anon_sym_DOLLARerror] = ACTIONS(4166),
    [anon_sym_DOLLARwarning] = ACTIONS(4166),
    [anon_sym_DOLLARinfo] = ACTIONS(4166),
    [anon_sym_default] = ACTIONS(4168),
    [anon_sym_clocking] = ACTIONS(4168),
    [anon_sym_defparam] = ACTIONS(4168),
    [anon_sym_bind] = ACTIONS(4168),
    [anon_sym_rand] = ACTIONS(4168),
    [anon_sym_const] = ACTIONS(4168),
    [anon_sym_function] = ACTIONS(4168),
    [anon_sym_static] = ACTIONS(4168),
    [anon_sym_constraint] = ACTIONS(4168),
    [anon_sym_if] = ACTIONS(4168),
    [anon_sym_else] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4166),
    [anon_sym_localparam] = ACTIONS(4168),
    [anon_sym_parameter] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4168),
    [anon_sym_import] = ACTIONS(4168),
    [anon_sym_export] = ACTIONS(4168),
    [anon_sym_genvar] = ACTIONS(4168),
    [anon_sym_interconnect] = ACTIONS(4168),
    [anon_sym_typedef] = ACTIONS(4168),
    [anon_sym_enum] = ACTIONS(4168),
    [anon_sym_struct] = ACTIONS(4168),
    [anon_sym_union] = ACTIONS(4168),
    [anon_sym_nettype] = ACTIONS(4168),
    [anon_sym_automatic] = ACTIONS(4168),
    [anon_sym_string] = ACTIONS(4168),
    [anon_sym_chandle] = ACTIONS(4168),
    [anon_sym_event] = ACTIONS(4168),
    [anon_sym_byte] = ACTIONS(4168),
    [anon_sym_shortint] = ACTIONS(4168),
    [anon_sym_int] = ACTIONS(4168),
    [anon_sym_longint] = ACTIONS(4168),
    [anon_sym_integer] = ACTIONS(4168),
    [anon_sym_time] = ACTIONS(4168),
    [anon_sym_bit] = ACTIONS(4168),
    [anon_sym_logic] = ACTIONS(4168),
    [anon_sym_reg] = ACTIONS(4168),
    [anon_sym_shortreal] = ACTIONS(4168),
    [anon_sym_real] = ACTIONS(4168),
    [anon_sym_realtime] = ACTIONS(4168),
    [anon_sym_supply0] = ACTIONS(4168),
    [anon_sym_supply1] = ACTIONS(4168),
    [anon_sym_signed] = ACTIONS(4168),
    [anon_sym_unsigned] = ACTIONS(4168),
    [anon_sym_task] = ACTIONS(4168),
    [anon_sym_assert] = ACTIONS(4168),
    [anon_sym_property] = ACTIONS(4168),
    [anon_sym_assume] = ACTIONS(4168),
    [anon_sym_cover] = ACTIONS(4168),
    [anon_sym_sequence] = ACTIONS(4168),
    [anon_sym_restrict] = ACTIONS(4168),
    [anon_sym_not] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_case] = ACTIONS(4168),
    [anon_sym_always] = ACTIONS(4168),
    [anon_sym_covergroup] = ACTIONS(4168),
    [anon_sym_end] = ACTIONS(4168),
    [anon_sym_let] = ACTIONS(4168),
    [anon_sym_pulldown] = ACTIONS(4168),
    [anon_sym_pullup] = ACTIONS(4168),
    [anon_sym_cmos] = ACTIONS(4168),
    [anon_sym_rcmos] = ACTIONS(4168),
    [anon_sym_bufif0] = ACTIONS(4168),
    [anon_sym_bufif1] = ACTIONS(4168),
    [anon_sym_notif0] = ACTIONS(4168),
    [anon_sym_notif1] = ACTIONS(4168),
    [anon_sym_nmos] = ACTIONS(4168),
    [anon_sym_pmos] = ACTIONS(4168),
    [anon_sym_rnmos] = ACTIONS(4168),
    [anon_sym_rpmos] = ACTIONS(4168),
    [anon_sym_nand] = ACTIONS(4168),
    [anon_sym_nor] = ACTIONS(4168),
    [anon_sym_xor] = ACTIONS(4168),
    [anon_sym_xnor] = ACTIONS(4168),
    [anon_sym_buf] = ACTIONS(4168),
    [anon_sym_tranif0] = ACTIONS(4168),
    [anon_sym_tranif1] = ACTIONS(4168),
    [anon_sym_rtranif1] = ACTIONS(4168),
    [anon_sym_rtranif0] = ACTIONS(4168),
    [anon_sym_tran] = ACTIONS(4168),
    [anon_sym_rtran] = ACTIONS(4168),
    [anon_sym_generate] = ACTIONS(4168),
    [anon_sym_for] = ACTIONS(4168),
    [anon_sym_initial] = ACTIONS(4168),
    [anon_sym_assign] = ACTIONS(4168),
    [anon_sym_alias] = ACTIONS(4168),
    [anon_sym_always_comb] = ACTIONS(4168),
    [anon_sym_always_latch] = ACTIONS(4168),
    [anon_sym_always_ff] = ACTIONS(4168),
    [anon_sym_final] = ACTIONS(4168),
    [anon_sym_global] = ACTIONS(4168),
    [anon_sym_LPAREN_STAR] = ACTIONS(4166),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4166),
    [anon_sym_DOLLARunit] = ACTIONS(4166),
  },
  [4576] = {
    [sym_simple_identifier] = ACTIONS(4542),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_COLON] = ACTIONS(10869),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_rand] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_end] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [4577] = {
    [sym_simple_identifier] = ACTIONS(4454),
    [anon_sym_wire] = ACTIONS(4454),
    [anon_sym_tri] = ACTIONS(4454),
    [anon_sym_tri0] = ACTIONS(4454),
    [anon_sym_tri1] = ACTIONS(4454),
    [anon_sym_wand] = ACTIONS(4454),
    [anon_sym_triand] = ACTIONS(4454),
    [anon_sym_wor] = ACTIONS(4454),
    [anon_sym_trior] = ACTIONS(4454),
    [anon_sym_trireg] = ACTIONS(4454),
    [anon_sym_uwire] = ACTIONS(4454),
    [anon_sym_SEMI] = ACTIONS(4452),
    [anon_sym_COLON] = ACTIONS(10871),
    [anon_sym_extern] = ACTIONS(4454),
    [anon_sym_interface] = ACTIONS(4454),
    [anon_sym_checker] = ACTIONS(4454),
    [anon_sym_virtual] = ACTIONS(4454),
    [anon_sym_class] = ACTIONS(4454),
    [anon_sym_type] = ACTIONS(4454),
    [anon_sym_DOLLARfatal] = ACTIONS(4452),
    [anon_sym_DOLLARerror] = ACTIONS(4452),
    [anon_sym_DOLLARwarning] = ACTIONS(4452),
    [anon_sym_DOLLARinfo] = ACTIONS(4452),
    [anon_sym_default] = ACTIONS(4454),
    [anon_sym_clocking] = ACTIONS(4454),
    [anon_sym_defparam] = ACTIONS(4454),
    [anon_sym_bind] = ACTIONS(4454),
    [anon_sym_rand] = ACTIONS(4454),
    [anon_sym_const] = ACTIONS(4454),
    [anon_sym_function] = ACTIONS(4454),
    [anon_sym_static] = ACTIONS(4454),
    [anon_sym_constraint] = ACTIONS(4454),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_else] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4452),
    [anon_sym_localparam] = ACTIONS(4454),
    [anon_sym_parameter] = ACTIONS(4454),
    [anon_sym_var] = ACTIONS(4454),
    [anon_sym_import] = ACTIONS(4454),
    [anon_sym_export] = ACTIONS(4454),
    [anon_sym_genvar] = ACTIONS(4454),
    [anon_sym_interconnect] = ACTIONS(4454),
    [anon_sym_typedef] = ACTIONS(4454),
    [anon_sym_enum] = ACTIONS(4454),
    [anon_sym_struct] = ACTIONS(4454),
    [anon_sym_union] = ACTIONS(4454),
    [anon_sym_nettype] = ACTIONS(4454),
    [anon_sym_automatic] = ACTIONS(4454),
    [anon_sym_string] = ACTIONS(4454),
    [anon_sym_chandle] = ACTIONS(4454),
    [anon_sym_event] = ACTIONS(4454),
    [anon_sym_byte] = ACTIONS(4454),
    [anon_sym_shortint] = ACTIONS(4454),
    [anon_sym_int] = ACTIONS(4454),
    [anon_sym_longint] = ACTIONS(4454),
    [anon_sym_integer] = ACTIONS(4454),
    [anon_sym_time] = ACTIONS(4454),
    [anon_sym_bit] = ACTIONS(4454),
    [anon_sym_logic] = ACTIONS(4454),
    [anon_sym_reg] = ACTIONS(4454),
    [anon_sym_shortreal] = ACTIONS(4454),
    [anon_sym_real] = ACTIONS(4454),
    [anon_sym_realtime] = ACTIONS(4454),
    [anon_sym_supply0] = ACTIONS(4454),
    [anon_sym_supply1] = ACTIONS(4454),
    [anon_sym_signed] = ACTIONS(4454),
    [anon_sym_unsigned] = ACTIONS(4454),
    [anon_sym_task] = ACTIONS(4454),
    [anon_sym_assert] = ACTIONS(4454),
    [anon_sym_property] = ACTIONS(4454),
    [anon_sym_assume] = ACTIONS(4454),
    [anon_sym_cover] = ACTIONS(4454),
    [anon_sym_sequence] = ACTIONS(4454),
    [anon_sym_restrict] = ACTIONS(4454),
    [anon_sym_not] = ACTIONS(4454),
    [anon_sym_or] = ACTIONS(4454),
    [anon_sym_and] = ACTIONS(4454),
    [anon_sym_case] = ACTIONS(4454),
    [anon_sym_always] = ACTIONS(4454),
    [anon_sym_covergroup] = ACTIONS(4454),
    [anon_sym_end] = ACTIONS(4454),
    [anon_sym_let] = ACTIONS(4454),
    [anon_sym_pulldown] = ACTIONS(4454),
    [anon_sym_pullup] = ACTIONS(4454),
    [anon_sym_cmos] = ACTIONS(4454),
    [anon_sym_rcmos] = ACTIONS(4454),
    [anon_sym_bufif0] = ACTIONS(4454),
    [anon_sym_bufif1] = ACTIONS(4454),
    [anon_sym_notif0] = ACTIONS(4454),
    [anon_sym_notif1] = ACTIONS(4454),
    [anon_sym_nmos] = ACTIONS(4454),
    [anon_sym_pmos] = ACTIONS(4454),
    [anon_sym_rnmos] = ACTIONS(4454),
    [anon_sym_rpmos] = ACTIONS(4454),
    [anon_sym_nand] = ACTIONS(4454),
    [anon_sym_nor] = ACTIONS(4454),
    [anon_sym_xor] = ACTIONS(4454),
    [anon_sym_xnor] = ACTIONS(4454),
    [anon_sym_buf] = ACTIONS(4454),
    [anon_sym_tranif0] = ACTIONS(4454),
    [anon_sym_tranif1] = ACTIONS(4454),
    [anon_sym_rtranif1] = ACTIONS(4454),
    [anon_sym_rtranif0] = ACTIONS(4454),
    [anon_sym_tran] = ACTIONS(4454),
    [anon_sym_rtran] = ACTIONS(4454),
    [anon_sym_generate] = ACTIONS(4454),
    [anon_sym_for] = ACTIONS(4454),
    [anon_sym_initial] = ACTIONS(4454),
    [anon_sym_assign] = ACTIONS(4454),
    [anon_sym_alias] = ACTIONS(4454),
    [anon_sym_always_comb] = ACTIONS(4454),
    [anon_sym_always_latch] = ACTIONS(4454),
    [anon_sym_always_ff] = ACTIONS(4454),
    [anon_sym_final] = ACTIONS(4454),
    [anon_sym_global] = ACTIONS(4454),
    [anon_sym_LPAREN_STAR] = ACTIONS(4452),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4452),
    [anon_sym_DOLLARunit] = ACTIONS(4452),
  },
  [4578] = {
    [sym_simple_identifier] = ACTIONS(4554),
    [anon_sym_wire] = ACTIONS(4554),
    [anon_sym_tri] = ACTIONS(4554),
    [anon_sym_tri0] = ACTIONS(4554),
    [anon_sym_tri1] = ACTIONS(4554),
    [anon_sym_wand] = ACTIONS(4554),
    [anon_sym_triand] = ACTIONS(4554),
    [anon_sym_wor] = ACTIONS(4554),
    [anon_sym_trior] = ACTIONS(4554),
    [anon_sym_trireg] = ACTIONS(4554),
    [anon_sym_uwire] = ACTIONS(4554),
    [anon_sym_SEMI] = ACTIONS(4552),
    [anon_sym_COLON] = ACTIONS(10873),
    [anon_sym_extern] = ACTIONS(4554),
    [anon_sym_interface] = ACTIONS(4554),
    [anon_sym_checker] = ACTIONS(4554),
    [anon_sym_virtual] = ACTIONS(4554),
    [anon_sym_class] = ACTIONS(4554),
    [anon_sym_type] = ACTIONS(4554),
    [anon_sym_DOLLARfatal] = ACTIONS(4552),
    [anon_sym_DOLLARerror] = ACTIONS(4552),
    [anon_sym_DOLLARwarning] = ACTIONS(4552),
    [anon_sym_DOLLARinfo] = ACTIONS(4552),
    [anon_sym_default] = ACTIONS(4554),
    [anon_sym_clocking] = ACTIONS(4554),
    [anon_sym_defparam] = ACTIONS(4554),
    [anon_sym_bind] = ACTIONS(4554),
    [anon_sym_rand] = ACTIONS(4554),
    [anon_sym_const] = ACTIONS(4554),
    [anon_sym_function] = ACTIONS(4554),
    [anon_sym_static] = ACTIONS(4554),
    [anon_sym_constraint] = ACTIONS(4554),
    [anon_sym_if] = ACTIONS(4554),
    [anon_sym_else] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4552),
    [anon_sym_localparam] = ACTIONS(4554),
    [anon_sym_parameter] = ACTIONS(4554),
    [anon_sym_var] = ACTIONS(4554),
    [anon_sym_import] = ACTIONS(4554),
    [anon_sym_export] = ACTIONS(4554),
    [anon_sym_genvar] = ACTIONS(4554),
    [anon_sym_interconnect] = ACTIONS(4554),
    [anon_sym_typedef] = ACTIONS(4554),
    [anon_sym_enum] = ACTIONS(4554),
    [anon_sym_struct] = ACTIONS(4554),
    [anon_sym_union] = ACTIONS(4554),
    [anon_sym_nettype] = ACTIONS(4554),
    [anon_sym_automatic] = ACTIONS(4554),
    [anon_sym_string] = ACTIONS(4554),
    [anon_sym_chandle] = ACTIONS(4554),
    [anon_sym_event] = ACTIONS(4554),
    [anon_sym_byte] = ACTIONS(4554),
    [anon_sym_shortint] = ACTIONS(4554),
    [anon_sym_int] = ACTIONS(4554),
    [anon_sym_longint] = ACTIONS(4554),
    [anon_sym_integer] = ACTIONS(4554),
    [anon_sym_time] = ACTIONS(4554),
    [anon_sym_bit] = ACTIONS(4554),
    [anon_sym_logic] = ACTIONS(4554),
    [anon_sym_reg] = ACTIONS(4554),
    [anon_sym_shortreal] = ACTIONS(4554),
    [anon_sym_real] = ACTIONS(4554),
    [anon_sym_realtime] = ACTIONS(4554),
    [anon_sym_supply0] = ACTIONS(4554),
    [anon_sym_supply1] = ACTIONS(4554),
    [anon_sym_signed] = ACTIONS(4554),
    [anon_sym_unsigned] = ACTIONS(4554),
    [anon_sym_task] = ACTIONS(4554),
    [anon_sym_assert] = ACTIONS(4554),
    [anon_sym_property] = ACTIONS(4554),
    [anon_sym_assume] = ACTIONS(4554),
    [anon_sym_cover] = ACTIONS(4554),
    [anon_sym_sequence] = ACTIONS(4554),
    [anon_sym_restrict] = ACTIONS(4554),
    [anon_sym_not] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_case] = ACTIONS(4554),
    [anon_sym_always] = ACTIONS(4554),
    [anon_sym_covergroup] = ACTIONS(4554),
    [anon_sym_end] = ACTIONS(4554),
    [anon_sym_let] = ACTIONS(4554),
    [anon_sym_pulldown] = ACTIONS(4554),
    [anon_sym_pullup] = ACTIONS(4554),
    [anon_sym_cmos] = ACTIONS(4554),
    [anon_sym_rcmos] = ACTIONS(4554),
    [anon_sym_bufif0] = ACTIONS(4554),
    [anon_sym_bufif1] = ACTIONS(4554),
    [anon_sym_notif0] = ACTIONS(4554),
    [anon_sym_notif1] = ACTIONS(4554),
    [anon_sym_nmos] = ACTIONS(4554),
    [anon_sym_pmos] = ACTIONS(4554),
    [anon_sym_rnmos] = ACTIONS(4554),
    [anon_sym_rpmos] = ACTIONS(4554),
    [anon_sym_nand] = ACTIONS(4554),
    [anon_sym_nor] = ACTIONS(4554),
    [anon_sym_xor] = ACTIONS(4554),
    [anon_sym_xnor] = ACTIONS(4554),
    [anon_sym_buf] = ACTIONS(4554),
    [anon_sym_tranif0] = ACTIONS(4554),
    [anon_sym_tranif1] = ACTIONS(4554),
    [anon_sym_rtranif1] = ACTIONS(4554),
    [anon_sym_rtranif0] = ACTIONS(4554),
    [anon_sym_tran] = ACTIONS(4554),
    [anon_sym_rtran] = ACTIONS(4554),
    [anon_sym_generate] = ACTIONS(4554),
    [anon_sym_for] = ACTIONS(4554),
    [anon_sym_initial] = ACTIONS(4554),
    [anon_sym_assign] = ACTIONS(4554),
    [anon_sym_alias] = ACTIONS(4554),
    [anon_sym_always_comb] = ACTIONS(4554),
    [anon_sym_always_latch] = ACTIONS(4554),
    [anon_sym_always_ff] = ACTIONS(4554),
    [anon_sym_final] = ACTIONS(4554),
    [anon_sym_global] = ACTIONS(4554),
    [anon_sym_LPAREN_STAR] = ACTIONS(4552),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4552),
    [anon_sym_DOLLARunit] = ACTIONS(4552),
  },
  [4579] = {
    [sym_simple_identifier] = ACTIONS(4566),
    [anon_sym_wire] = ACTIONS(4566),
    [anon_sym_tri] = ACTIONS(4566),
    [anon_sym_tri0] = ACTIONS(4566),
    [anon_sym_tri1] = ACTIONS(4566),
    [anon_sym_wand] = ACTIONS(4566),
    [anon_sym_triand] = ACTIONS(4566),
    [anon_sym_wor] = ACTIONS(4566),
    [anon_sym_trior] = ACTIONS(4566),
    [anon_sym_trireg] = ACTIONS(4566),
    [anon_sym_uwire] = ACTIONS(4566),
    [anon_sym_SEMI] = ACTIONS(4564),
    [anon_sym_COLON] = ACTIONS(10875),
    [anon_sym_extern] = ACTIONS(4566),
    [anon_sym_interface] = ACTIONS(4566),
    [anon_sym_checker] = ACTIONS(4566),
    [anon_sym_virtual] = ACTIONS(4566),
    [anon_sym_class] = ACTIONS(4566),
    [anon_sym_type] = ACTIONS(4566),
    [anon_sym_DOLLARfatal] = ACTIONS(4564),
    [anon_sym_DOLLARerror] = ACTIONS(4564),
    [anon_sym_DOLLARwarning] = ACTIONS(4564),
    [anon_sym_DOLLARinfo] = ACTIONS(4564),
    [anon_sym_default] = ACTIONS(4566),
    [anon_sym_clocking] = ACTIONS(4566),
    [anon_sym_defparam] = ACTIONS(4566),
    [anon_sym_bind] = ACTIONS(4566),
    [anon_sym_rand] = ACTIONS(4566),
    [anon_sym_const] = ACTIONS(4566),
    [anon_sym_function] = ACTIONS(4566),
    [anon_sym_static] = ACTIONS(4566),
    [anon_sym_constraint] = ACTIONS(4566),
    [anon_sym_if] = ACTIONS(4566),
    [anon_sym_else] = ACTIONS(4566),
    [anon_sym_LBRACK] = ACTIONS(4564),
    [anon_sym_localparam] = ACTIONS(4566),
    [anon_sym_parameter] = ACTIONS(4566),
    [anon_sym_var] = ACTIONS(4566),
    [anon_sym_import] = ACTIONS(4566),
    [anon_sym_export] = ACTIONS(4566),
    [anon_sym_genvar] = ACTIONS(4566),
    [anon_sym_interconnect] = ACTIONS(4566),
    [anon_sym_typedef] = ACTIONS(4566),
    [anon_sym_enum] = ACTIONS(4566),
    [anon_sym_struct] = ACTIONS(4566),
    [anon_sym_union] = ACTIONS(4566),
    [anon_sym_nettype] = ACTIONS(4566),
    [anon_sym_automatic] = ACTIONS(4566),
    [anon_sym_string] = ACTIONS(4566),
    [anon_sym_chandle] = ACTIONS(4566),
    [anon_sym_event] = ACTIONS(4566),
    [anon_sym_byte] = ACTIONS(4566),
    [anon_sym_shortint] = ACTIONS(4566),
    [anon_sym_int] = ACTIONS(4566),
    [anon_sym_longint] = ACTIONS(4566),
    [anon_sym_integer] = ACTIONS(4566),
    [anon_sym_time] = ACTIONS(4566),
    [anon_sym_bit] = ACTIONS(4566),
    [anon_sym_logic] = ACTIONS(4566),
    [anon_sym_reg] = ACTIONS(4566),
    [anon_sym_shortreal] = ACTIONS(4566),
    [anon_sym_real] = ACTIONS(4566),
    [anon_sym_realtime] = ACTIONS(4566),
    [anon_sym_supply0] = ACTIONS(4566),
    [anon_sym_supply1] = ACTIONS(4566),
    [anon_sym_signed] = ACTIONS(4566),
    [anon_sym_unsigned] = ACTIONS(4566),
    [anon_sym_task] = ACTIONS(4566),
    [anon_sym_assert] = ACTIONS(4566),
    [anon_sym_property] = ACTIONS(4566),
    [anon_sym_assume] = ACTIONS(4566),
    [anon_sym_cover] = ACTIONS(4566),
    [anon_sym_sequence] = ACTIONS(4566),
    [anon_sym_restrict] = ACTIONS(4566),
    [anon_sym_not] = ACTIONS(4566),
    [anon_sym_or] = ACTIONS(4566),
    [anon_sym_and] = ACTIONS(4566),
    [anon_sym_case] = ACTIONS(4566),
    [anon_sym_always] = ACTIONS(4566),
    [anon_sym_covergroup] = ACTIONS(4566),
    [anon_sym_end] = ACTIONS(4566),
    [anon_sym_let] = ACTIONS(4566),
    [anon_sym_pulldown] = ACTIONS(4566),
    [anon_sym_pullup] = ACTIONS(4566),
    [anon_sym_cmos] = ACTIONS(4566),
    [anon_sym_rcmos] = ACTIONS(4566),
    [anon_sym_bufif0] = ACTIONS(4566),
    [anon_sym_bufif1] = ACTIONS(4566),
    [anon_sym_notif0] = ACTIONS(4566),
    [anon_sym_notif1] = ACTIONS(4566),
    [anon_sym_nmos] = ACTIONS(4566),
    [anon_sym_pmos] = ACTIONS(4566),
    [anon_sym_rnmos] = ACTIONS(4566),
    [anon_sym_rpmos] = ACTIONS(4566),
    [anon_sym_nand] = ACTIONS(4566),
    [anon_sym_nor] = ACTIONS(4566),
    [anon_sym_xor] = ACTIONS(4566),
    [anon_sym_xnor] = ACTIONS(4566),
    [anon_sym_buf] = ACTIONS(4566),
    [anon_sym_tranif0] = ACTIONS(4566),
    [anon_sym_tranif1] = ACTIONS(4566),
    [anon_sym_rtranif1] = ACTIONS(4566),
    [anon_sym_rtranif0] = ACTIONS(4566),
    [anon_sym_tran] = ACTIONS(4566),
    [anon_sym_rtran] = ACTIONS(4566),
    [anon_sym_generate] = ACTIONS(4566),
    [anon_sym_for] = ACTIONS(4566),
    [anon_sym_initial] = ACTIONS(4566),
    [anon_sym_assign] = ACTIONS(4566),
    [anon_sym_alias] = ACTIONS(4566),
    [anon_sym_always_comb] = ACTIONS(4566),
    [anon_sym_always_latch] = ACTIONS(4566),
    [anon_sym_always_ff] = ACTIONS(4566),
    [anon_sym_final] = ACTIONS(4566),
    [anon_sym_global] = ACTIONS(4566),
    [anon_sym_LPAREN_STAR] = ACTIONS(4564),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4564),
    [anon_sym_DOLLARunit] = ACTIONS(4564),
  },
  [4580] = {
    [sym_simple_identifier] = ACTIONS(4572),
    [anon_sym_wire] = ACTIONS(4572),
    [anon_sym_tri] = ACTIONS(4572),
    [anon_sym_tri0] = ACTIONS(4572),
    [anon_sym_tri1] = ACTIONS(4572),
    [anon_sym_wand] = ACTIONS(4572),
    [anon_sym_triand] = ACTIONS(4572),
    [anon_sym_wor] = ACTIONS(4572),
    [anon_sym_trior] = ACTIONS(4572),
    [anon_sym_trireg] = ACTIONS(4572),
    [anon_sym_uwire] = ACTIONS(4572),
    [anon_sym_SEMI] = ACTIONS(4570),
    [anon_sym_COLON] = ACTIONS(10877),
    [anon_sym_extern] = ACTIONS(4572),
    [anon_sym_interface] = ACTIONS(4572),
    [anon_sym_checker] = ACTIONS(4572),
    [anon_sym_virtual] = ACTIONS(4572),
    [anon_sym_class] = ACTIONS(4572),
    [anon_sym_type] = ACTIONS(4572),
    [anon_sym_DOLLARfatal] = ACTIONS(4570),
    [anon_sym_DOLLARerror] = ACTIONS(4570),
    [anon_sym_DOLLARwarning] = ACTIONS(4570),
    [anon_sym_DOLLARinfo] = ACTIONS(4570),
    [anon_sym_default] = ACTIONS(4572),
    [anon_sym_clocking] = ACTIONS(4572),
    [anon_sym_defparam] = ACTIONS(4572),
    [anon_sym_bind] = ACTIONS(4572),
    [anon_sym_rand] = ACTIONS(4572),
    [anon_sym_const] = ACTIONS(4572),
    [anon_sym_function] = ACTIONS(4572),
    [anon_sym_static] = ACTIONS(4572),
    [anon_sym_constraint] = ACTIONS(4572),
    [anon_sym_if] = ACTIONS(4572),
    [anon_sym_else] = ACTIONS(4572),
    [anon_sym_LBRACK] = ACTIONS(4570),
    [anon_sym_localparam] = ACTIONS(4572),
    [anon_sym_parameter] = ACTIONS(4572),
    [anon_sym_var] = ACTIONS(4572),
    [anon_sym_import] = ACTIONS(4572),
    [anon_sym_export] = ACTIONS(4572),
    [anon_sym_genvar] = ACTIONS(4572),
    [anon_sym_interconnect] = ACTIONS(4572),
    [anon_sym_typedef] = ACTIONS(4572),
    [anon_sym_enum] = ACTIONS(4572),
    [anon_sym_struct] = ACTIONS(4572),
    [anon_sym_union] = ACTIONS(4572),
    [anon_sym_nettype] = ACTIONS(4572),
    [anon_sym_automatic] = ACTIONS(4572),
    [anon_sym_string] = ACTIONS(4572),
    [anon_sym_chandle] = ACTIONS(4572),
    [anon_sym_event] = ACTIONS(4572),
    [anon_sym_byte] = ACTIONS(4572),
    [anon_sym_shortint] = ACTIONS(4572),
    [anon_sym_int] = ACTIONS(4572),
    [anon_sym_longint] = ACTIONS(4572),
    [anon_sym_integer] = ACTIONS(4572),
    [anon_sym_time] = ACTIONS(4572),
    [anon_sym_bit] = ACTIONS(4572),
    [anon_sym_logic] = ACTIONS(4572),
    [anon_sym_reg] = ACTIONS(4572),
    [anon_sym_shortreal] = ACTIONS(4572),
    [anon_sym_real] = ACTIONS(4572),
    [anon_sym_realtime] = ACTIONS(4572),
    [anon_sym_supply0] = ACTIONS(4572),
    [anon_sym_supply1] = ACTIONS(4572),
    [anon_sym_signed] = ACTIONS(4572),
    [anon_sym_unsigned] = ACTIONS(4572),
    [anon_sym_task] = ACTIONS(4572),
    [anon_sym_assert] = ACTIONS(4572),
    [anon_sym_property] = ACTIONS(4572),
    [anon_sym_assume] = ACTIONS(4572),
    [anon_sym_cover] = ACTIONS(4572),
    [anon_sym_sequence] = ACTIONS(4572),
    [anon_sym_restrict] = ACTIONS(4572),
    [anon_sym_not] = ACTIONS(4572),
    [anon_sym_or] = ACTIONS(4572),
    [anon_sym_and] = ACTIONS(4572),
    [anon_sym_case] = ACTIONS(4572),
    [anon_sym_always] = ACTIONS(4572),
    [anon_sym_covergroup] = ACTIONS(4572),
    [anon_sym_end] = ACTIONS(4572),
    [anon_sym_let] = ACTIONS(4572),
    [anon_sym_pulldown] = ACTIONS(4572),
    [anon_sym_pullup] = ACTIONS(4572),
    [anon_sym_cmos] = ACTIONS(4572),
    [anon_sym_rcmos] = ACTIONS(4572),
    [anon_sym_bufif0] = ACTIONS(4572),
    [anon_sym_bufif1] = ACTIONS(4572),
    [anon_sym_notif0] = ACTIONS(4572),
    [anon_sym_notif1] = ACTIONS(4572),
    [anon_sym_nmos] = ACTIONS(4572),
    [anon_sym_pmos] = ACTIONS(4572),
    [anon_sym_rnmos] = ACTIONS(4572),
    [anon_sym_rpmos] = ACTIONS(4572),
    [anon_sym_nand] = ACTIONS(4572),
    [anon_sym_nor] = ACTIONS(4572),
    [anon_sym_xor] = ACTIONS(4572),
    [anon_sym_xnor] = ACTIONS(4572),
    [anon_sym_buf] = ACTIONS(4572),
    [anon_sym_tranif0] = ACTIONS(4572),
    [anon_sym_tranif1] = ACTIONS(4572),
    [anon_sym_rtranif1] = ACTIONS(4572),
    [anon_sym_rtranif0] = ACTIONS(4572),
    [anon_sym_tran] = ACTIONS(4572),
    [anon_sym_rtran] = ACTIONS(4572),
    [anon_sym_generate] = ACTIONS(4572),
    [anon_sym_for] = ACTIONS(4572),
    [anon_sym_initial] = ACTIONS(4572),
    [anon_sym_assign] = ACTIONS(4572),
    [anon_sym_alias] = ACTIONS(4572),
    [anon_sym_always_comb] = ACTIONS(4572),
    [anon_sym_always_latch] = ACTIONS(4572),
    [anon_sym_always_ff] = ACTIONS(4572),
    [anon_sym_final] = ACTIONS(4572),
    [anon_sym_global] = ACTIONS(4572),
    [anon_sym_LPAREN_STAR] = ACTIONS(4570),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4570),
    [anon_sym_DOLLARunit] = ACTIONS(4570),
  },
  [4581] = {
    [sym_simple_identifier] = ACTIONS(4630),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_COLON] = ACTIONS(10879),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_rand] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_endgenerate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [4582] = {
    [sym_simple_identifier] = ACTIONS(4200),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_COLON] = ACTIONS(10881),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_rand] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_endgenerate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [4583] = {
    [sym_simple_identifier] = ACTIONS(6417),
    [anon_sym_wire] = ACTIONS(6417),
    [anon_sym_tri] = ACTIONS(6417),
    [anon_sym_tri0] = ACTIONS(6417),
    [anon_sym_tri1] = ACTIONS(6417),
    [anon_sym_wand] = ACTIONS(6417),
    [anon_sym_triand] = ACTIONS(6417),
    [anon_sym_wor] = ACTIONS(6417),
    [anon_sym_trior] = ACTIONS(6417),
    [anon_sym_trireg] = ACTIONS(6417),
    [anon_sym_uwire] = ACTIONS(6417),
    [anon_sym_SEMI] = ACTIONS(6419),
    [anon_sym_extern] = ACTIONS(6417),
    [anon_sym_interface] = ACTIONS(6417),
    [anon_sym_checker] = ACTIONS(6417),
    [anon_sym_virtual] = ACTIONS(6417),
    [anon_sym_class] = ACTIONS(6417),
    [anon_sym_type] = ACTIONS(6417),
    [anon_sym_DOLLARfatal] = ACTIONS(6419),
    [anon_sym_DOLLARerror] = ACTIONS(6419),
    [anon_sym_DOLLARwarning] = ACTIONS(6419),
    [anon_sym_DOLLARinfo] = ACTIONS(6419),
    [anon_sym_default] = ACTIONS(6417),
    [anon_sym_clocking] = ACTIONS(6417),
    [anon_sym_defparam] = ACTIONS(6417),
    [anon_sym_bind] = ACTIONS(6417),
    [anon_sym_rand] = ACTIONS(6417),
    [anon_sym_const] = ACTIONS(6417),
    [anon_sym_function] = ACTIONS(6417),
    [anon_sym_static] = ACTIONS(6417),
    [anon_sym_constraint] = ACTIONS(6417),
    [anon_sym_if] = ACTIONS(6417),
    [anon_sym_else] = ACTIONS(6417),
    [anon_sym_LBRACK] = ACTIONS(6419),
    [anon_sym_localparam] = ACTIONS(6417),
    [anon_sym_parameter] = ACTIONS(6417),
    [anon_sym_var] = ACTIONS(6417),
    [anon_sym_import] = ACTIONS(6417),
    [anon_sym_export] = ACTIONS(6417),
    [anon_sym_genvar] = ACTIONS(6417),
    [anon_sym_interconnect] = ACTIONS(6417),
    [anon_sym_typedef] = ACTIONS(6417),
    [anon_sym_enum] = ACTIONS(6417),
    [anon_sym_struct] = ACTIONS(6417),
    [anon_sym_union] = ACTIONS(6417),
    [anon_sym_nettype] = ACTIONS(6417),
    [anon_sym_automatic] = ACTIONS(6417),
    [anon_sym_string] = ACTIONS(6417),
    [anon_sym_chandle] = ACTIONS(6417),
    [anon_sym_event] = ACTIONS(6417),
    [anon_sym_byte] = ACTIONS(6417),
    [anon_sym_shortint] = ACTIONS(6417),
    [anon_sym_int] = ACTIONS(6417),
    [anon_sym_longint] = ACTIONS(6417),
    [anon_sym_integer] = ACTIONS(6417),
    [anon_sym_time] = ACTIONS(6417),
    [anon_sym_bit] = ACTIONS(6417),
    [anon_sym_logic] = ACTIONS(6417),
    [anon_sym_reg] = ACTIONS(6417),
    [anon_sym_shortreal] = ACTIONS(6417),
    [anon_sym_real] = ACTIONS(6417),
    [anon_sym_realtime] = ACTIONS(6417),
    [anon_sym_supply0] = ACTIONS(6417),
    [anon_sym_supply1] = ACTIONS(6417),
    [anon_sym_signed] = ACTIONS(6417),
    [anon_sym_unsigned] = ACTIONS(6417),
    [anon_sym_task] = ACTIONS(6417),
    [anon_sym_assert] = ACTIONS(6417),
    [anon_sym_property] = ACTIONS(6417),
    [anon_sym_assume] = ACTIONS(6417),
    [anon_sym_cover] = ACTIONS(6417),
    [anon_sym_sequence] = ACTIONS(6417),
    [anon_sym_restrict] = ACTIONS(6417),
    [anon_sym_not] = ACTIONS(6417),
    [anon_sym_or] = ACTIONS(6417),
    [anon_sym_and] = ACTIONS(6417),
    [anon_sym_case] = ACTIONS(6417),
    [anon_sym_always] = ACTIONS(6417),
    [anon_sym_covergroup] = ACTIONS(6417),
    [anon_sym_end] = ACTIONS(6417),
    [anon_sym_let] = ACTIONS(6417),
    [anon_sym_pulldown] = ACTIONS(6417),
    [anon_sym_pullup] = ACTIONS(6417),
    [anon_sym_cmos] = ACTIONS(6417),
    [anon_sym_rcmos] = ACTIONS(6417),
    [anon_sym_bufif0] = ACTIONS(6417),
    [anon_sym_bufif1] = ACTIONS(6417),
    [anon_sym_notif0] = ACTIONS(6417),
    [anon_sym_notif1] = ACTIONS(6417),
    [anon_sym_nmos] = ACTIONS(6417),
    [anon_sym_pmos] = ACTIONS(6417),
    [anon_sym_rnmos] = ACTIONS(6417),
    [anon_sym_rpmos] = ACTIONS(6417),
    [anon_sym_nand] = ACTIONS(6417),
    [anon_sym_nor] = ACTIONS(6417),
    [anon_sym_xor] = ACTIONS(6417),
    [anon_sym_xnor] = ACTIONS(6417),
    [anon_sym_buf] = ACTIONS(6417),
    [anon_sym_tranif0] = ACTIONS(6417),
    [anon_sym_tranif1] = ACTIONS(6417),
    [anon_sym_rtranif1] = ACTIONS(6417),
    [anon_sym_rtranif0] = ACTIONS(6417),
    [anon_sym_tran] = ACTIONS(6417),
    [anon_sym_rtran] = ACTIONS(6417),
    [anon_sym_generate] = ACTIONS(6417),
    [anon_sym_for] = ACTIONS(6417),
    [anon_sym_initial] = ACTIONS(6417),
    [anon_sym_assign] = ACTIONS(6417),
    [anon_sym_alias] = ACTIONS(6417),
    [anon_sym_always_comb] = ACTIONS(6417),
    [anon_sym_always_latch] = ACTIONS(6417),
    [anon_sym_always_ff] = ACTIONS(6417),
    [anon_sym_final] = ACTIONS(6417),
    [anon_sym_global] = ACTIONS(6417),
    [anon_sym_LPAREN_STAR] = ACTIONS(6419),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6419),
    [anon_sym_DOLLARunit] = ACTIONS(6419),
  },
  [4584] = {
    [sym_simple_identifier] = ACTIONS(6245),
    [anon_sym_wire] = ACTIONS(6245),
    [anon_sym_tri] = ACTIONS(6245),
    [anon_sym_tri0] = ACTIONS(6245),
    [anon_sym_tri1] = ACTIONS(6245),
    [anon_sym_wand] = ACTIONS(6245),
    [anon_sym_triand] = ACTIONS(6245),
    [anon_sym_wor] = ACTIONS(6245),
    [anon_sym_trior] = ACTIONS(6245),
    [anon_sym_trireg] = ACTIONS(6245),
    [anon_sym_uwire] = ACTIONS(6245),
    [anon_sym_SEMI] = ACTIONS(6247),
    [anon_sym_extern] = ACTIONS(6245),
    [anon_sym_interface] = ACTIONS(6245),
    [anon_sym_checker] = ACTIONS(6245),
    [anon_sym_virtual] = ACTIONS(6245),
    [anon_sym_class] = ACTIONS(6245),
    [anon_sym_type] = ACTIONS(6245),
    [anon_sym_DOLLARfatal] = ACTIONS(6247),
    [anon_sym_DOLLARerror] = ACTIONS(6247),
    [anon_sym_DOLLARwarning] = ACTIONS(6247),
    [anon_sym_DOLLARinfo] = ACTIONS(6247),
    [anon_sym_default] = ACTIONS(6245),
    [anon_sym_clocking] = ACTIONS(6245),
    [anon_sym_defparam] = ACTIONS(6245),
    [anon_sym_bind] = ACTIONS(6245),
    [anon_sym_rand] = ACTIONS(6245),
    [anon_sym_const] = ACTIONS(6245),
    [anon_sym_function] = ACTIONS(6245),
    [anon_sym_static] = ACTIONS(6245),
    [anon_sym_constraint] = ACTIONS(6245),
    [anon_sym_if] = ACTIONS(6245),
    [anon_sym_else] = ACTIONS(6245),
    [anon_sym_LBRACK] = ACTIONS(6247),
    [anon_sym_localparam] = ACTIONS(6245),
    [anon_sym_parameter] = ACTIONS(6245),
    [anon_sym_var] = ACTIONS(6245),
    [anon_sym_import] = ACTIONS(6245),
    [anon_sym_export] = ACTIONS(6245),
    [anon_sym_genvar] = ACTIONS(6245),
    [anon_sym_interconnect] = ACTIONS(6245),
    [anon_sym_typedef] = ACTIONS(6245),
    [anon_sym_enum] = ACTIONS(6245),
    [anon_sym_struct] = ACTIONS(6245),
    [anon_sym_union] = ACTIONS(6245),
    [anon_sym_nettype] = ACTIONS(6245),
    [anon_sym_automatic] = ACTIONS(6245),
    [anon_sym_string] = ACTIONS(6245),
    [anon_sym_chandle] = ACTIONS(6245),
    [anon_sym_event] = ACTIONS(6245),
    [anon_sym_byte] = ACTIONS(6245),
    [anon_sym_shortint] = ACTIONS(6245),
    [anon_sym_int] = ACTIONS(6245),
    [anon_sym_longint] = ACTIONS(6245),
    [anon_sym_integer] = ACTIONS(6245),
    [anon_sym_time] = ACTIONS(6245),
    [anon_sym_bit] = ACTIONS(6245),
    [anon_sym_logic] = ACTIONS(6245),
    [anon_sym_reg] = ACTIONS(6245),
    [anon_sym_shortreal] = ACTIONS(6245),
    [anon_sym_real] = ACTIONS(6245),
    [anon_sym_realtime] = ACTIONS(6245),
    [anon_sym_supply0] = ACTIONS(6245),
    [anon_sym_supply1] = ACTIONS(6245),
    [anon_sym_signed] = ACTIONS(6245),
    [anon_sym_unsigned] = ACTIONS(6245),
    [anon_sym_task] = ACTIONS(6245),
    [anon_sym_assert] = ACTIONS(6245),
    [anon_sym_property] = ACTIONS(6245),
    [anon_sym_assume] = ACTIONS(6245),
    [anon_sym_cover] = ACTIONS(6245),
    [anon_sym_sequence] = ACTIONS(6245),
    [anon_sym_restrict] = ACTIONS(6245),
    [anon_sym_not] = ACTIONS(6245),
    [anon_sym_or] = ACTIONS(6245),
    [anon_sym_and] = ACTIONS(6245),
    [anon_sym_case] = ACTIONS(6245),
    [anon_sym_always] = ACTIONS(6245),
    [anon_sym_covergroup] = ACTIONS(6245),
    [anon_sym_let] = ACTIONS(6245),
    [anon_sym_pulldown] = ACTIONS(6245),
    [anon_sym_pullup] = ACTIONS(6245),
    [anon_sym_cmos] = ACTIONS(6245),
    [anon_sym_rcmos] = ACTIONS(6245),
    [anon_sym_bufif0] = ACTIONS(6245),
    [anon_sym_bufif1] = ACTIONS(6245),
    [anon_sym_notif0] = ACTIONS(6245),
    [anon_sym_notif1] = ACTIONS(6245),
    [anon_sym_nmos] = ACTIONS(6245),
    [anon_sym_pmos] = ACTIONS(6245),
    [anon_sym_rnmos] = ACTIONS(6245),
    [anon_sym_rpmos] = ACTIONS(6245),
    [anon_sym_nand] = ACTIONS(6245),
    [anon_sym_nor] = ACTIONS(6245),
    [anon_sym_xor] = ACTIONS(6245),
    [anon_sym_xnor] = ACTIONS(6245),
    [anon_sym_buf] = ACTIONS(6245),
    [anon_sym_tranif0] = ACTIONS(6245),
    [anon_sym_tranif1] = ACTIONS(6245),
    [anon_sym_rtranif1] = ACTIONS(6245),
    [anon_sym_rtranif0] = ACTIONS(6245),
    [anon_sym_tran] = ACTIONS(6245),
    [anon_sym_rtran] = ACTIONS(6245),
    [anon_sym_generate] = ACTIONS(6245),
    [anon_sym_endgenerate] = ACTIONS(6245),
    [anon_sym_for] = ACTIONS(6245),
    [anon_sym_initial] = ACTIONS(6245),
    [anon_sym_assign] = ACTIONS(6245),
    [anon_sym_alias] = ACTIONS(6245),
    [anon_sym_always_comb] = ACTIONS(6245),
    [anon_sym_always_latch] = ACTIONS(6245),
    [anon_sym_always_ff] = ACTIONS(6245),
    [anon_sym_final] = ACTIONS(6245),
    [anon_sym_global] = ACTIONS(6245),
    [anon_sym_LPAREN_STAR] = ACTIONS(6247),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6247),
    [anon_sym_DOLLARunit] = ACTIONS(6247),
  },
  [4585] = {
    [sym_simple_identifier] = ACTIONS(4824),
    [anon_sym_wire] = ACTIONS(4824),
    [anon_sym_tri] = ACTIONS(4824),
    [anon_sym_tri0] = ACTIONS(4824),
    [anon_sym_tri1] = ACTIONS(4824),
    [anon_sym_wand] = ACTIONS(4824),
    [anon_sym_triand] = ACTIONS(4824),
    [anon_sym_wor] = ACTIONS(4824),
    [anon_sym_trior] = ACTIONS(4824),
    [anon_sym_trireg] = ACTIONS(4824),
    [anon_sym_uwire] = ACTIONS(4824),
    [anon_sym_SEMI] = ACTIONS(4822),
    [anon_sym_extern] = ACTIONS(4824),
    [anon_sym_interface] = ACTIONS(4824),
    [anon_sym_checker] = ACTIONS(4824),
    [anon_sym_virtual] = ACTIONS(4824),
    [anon_sym_class] = ACTIONS(4824),
    [anon_sym_type] = ACTIONS(4824),
    [anon_sym_DOLLARfatal] = ACTIONS(4822),
    [anon_sym_DOLLARerror] = ACTIONS(4822),
    [anon_sym_DOLLARwarning] = ACTIONS(4822),
    [anon_sym_DOLLARinfo] = ACTIONS(4822),
    [anon_sym_default] = ACTIONS(4824),
    [anon_sym_clocking] = ACTIONS(4824),
    [anon_sym_defparam] = ACTIONS(4824),
    [anon_sym_bind] = ACTIONS(4824),
    [anon_sym_rand] = ACTIONS(4824),
    [anon_sym_const] = ACTIONS(4824),
    [anon_sym_function] = ACTIONS(4824),
    [anon_sym_static] = ACTIONS(4824),
    [anon_sym_constraint] = ACTIONS(4824),
    [anon_sym_if] = ACTIONS(4824),
    [anon_sym_else] = ACTIONS(4824),
    [anon_sym_LBRACK] = ACTIONS(4822),
    [anon_sym_localparam] = ACTIONS(4824),
    [anon_sym_parameter] = ACTIONS(4824),
    [anon_sym_var] = ACTIONS(4824),
    [anon_sym_import] = ACTIONS(4824),
    [anon_sym_export] = ACTIONS(4824),
    [anon_sym_genvar] = ACTIONS(4824),
    [anon_sym_interconnect] = ACTIONS(4824),
    [anon_sym_typedef] = ACTIONS(4824),
    [anon_sym_enum] = ACTIONS(4824),
    [anon_sym_struct] = ACTIONS(4824),
    [anon_sym_union] = ACTIONS(4824),
    [anon_sym_nettype] = ACTIONS(4824),
    [anon_sym_automatic] = ACTIONS(4824),
    [anon_sym_string] = ACTIONS(4824),
    [anon_sym_chandle] = ACTIONS(4824),
    [anon_sym_event] = ACTIONS(4824),
    [anon_sym_byte] = ACTIONS(4824),
    [anon_sym_shortint] = ACTIONS(4824),
    [anon_sym_int] = ACTIONS(4824),
    [anon_sym_longint] = ACTIONS(4824),
    [anon_sym_integer] = ACTIONS(4824),
    [anon_sym_time] = ACTIONS(4824),
    [anon_sym_bit] = ACTIONS(4824),
    [anon_sym_logic] = ACTIONS(4824),
    [anon_sym_reg] = ACTIONS(4824),
    [anon_sym_shortreal] = ACTIONS(4824),
    [anon_sym_real] = ACTIONS(4824),
    [anon_sym_realtime] = ACTIONS(4824),
    [anon_sym_supply0] = ACTIONS(4824),
    [anon_sym_supply1] = ACTIONS(4824),
    [anon_sym_signed] = ACTIONS(4824),
    [anon_sym_unsigned] = ACTIONS(4824),
    [anon_sym_task] = ACTIONS(4824),
    [anon_sym_assert] = ACTIONS(4824),
    [anon_sym_property] = ACTIONS(4824),
    [anon_sym_assume] = ACTIONS(4824),
    [anon_sym_cover] = ACTIONS(4824),
    [anon_sym_sequence] = ACTIONS(4824),
    [anon_sym_restrict] = ACTIONS(4824),
    [anon_sym_not] = ACTIONS(4824),
    [anon_sym_or] = ACTIONS(4824),
    [anon_sym_and] = ACTIONS(4824),
    [anon_sym_case] = ACTIONS(4824),
    [anon_sym_always] = ACTIONS(4824),
    [anon_sym_covergroup] = ACTIONS(4824),
    [anon_sym_let] = ACTIONS(4824),
    [anon_sym_pulldown] = ACTIONS(4824),
    [anon_sym_pullup] = ACTIONS(4824),
    [anon_sym_cmos] = ACTIONS(4824),
    [anon_sym_rcmos] = ACTIONS(4824),
    [anon_sym_bufif0] = ACTIONS(4824),
    [anon_sym_bufif1] = ACTIONS(4824),
    [anon_sym_notif0] = ACTIONS(4824),
    [anon_sym_notif1] = ACTIONS(4824),
    [anon_sym_nmos] = ACTIONS(4824),
    [anon_sym_pmos] = ACTIONS(4824),
    [anon_sym_rnmos] = ACTIONS(4824),
    [anon_sym_rpmos] = ACTIONS(4824),
    [anon_sym_nand] = ACTIONS(4824),
    [anon_sym_nor] = ACTIONS(4824),
    [anon_sym_xor] = ACTIONS(4824),
    [anon_sym_xnor] = ACTIONS(4824),
    [anon_sym_buf] = ACTIONS(4824),
    [anon_sym_tranif0] = ACTIONS(4824),
    [anon_sym_tranif1] = ACTIONS(4824),
    [anon_sym_rtranif1] = ACTIONS(4824),
    [anon_sym_rtranif0] = ACTIONS(4824),
    [anon_sym_tran] = ACTIONS(4824),
    [anon_sym_rtran] = ACTIONS(4824),
    [anon_sym_generate] = ACTIONS(4824),
    [anon_sym_endgenerate] = ACTIONS(4824),
    [anon_sym_for] = ACTIONS(4824),
    [anon_sym_initial] = ACTIONS(4824),
    [anon_sym_assign] = ACTIONS(4824),
    [anon_sym_alias] = ACTIONS(4824),
    [anon_sym_always_comb] = ACTIONS(4824),
    [anon_sym_always_latch] = ACTIONS(4824),
    [anon_sym_always_ff] = ACTIONS(4824),
    [anon_sym_final] = ACTIONS(4824),
    [anon_sym_global] = ACTIONS(4824),
    [anon_sym_LPAREN_STAR] = ACTIONS(4822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4822),
    [anon_sym_DOLLARunit] = ACTIONS(4822),
  },
  [4586] = {
    [sym_simple_identifier] = ACTIONS(4904),
    [anon_sym_wire] = ACTIONS(4904),
    [anon_sym_tri] = ACTIONS(4904),
    [anon_sym_tri0] = ACTIONS(4904),
    [anon_sym_tri1] = ACTIONS(4904),
    [anon_sym_wand] = ACTIONS(4904),
    [anon_sym_triand] = ACTIONS(4904),
    [anon_sym_wor] = ACTIONS(4904),
    [anon_sym_trior] = ACTIONS(4904),
    [anon_sym_trireg] = ACTIONS(4904),
    [anon_sym_uwire] = ACTIONS(4904),
    [anon_sym_SEMI] = ACTIONS(4902),
    [anon_sym_extern] = ACTIONS(4904),
    [anon_sym_interface] = ACTIONS(4904),
    [anon_sym_checker] = ACTIONS(4904),
    [anon_sym_virtual] = ACTIONS(4904),
    [anon_sym_class] = ACTIONS(4904),
    [anon_sym_type] = ACTIONS(4904),
    [anon_sym_DOLLARfatal] = ACTIONS(4902),
    [anon_sym_DOLLARerror] = ACTIONS(4902),
    [anon_sym_DOLLARwarning] = ACTIONS(4902),
    [anon_sym_DOLLARinfo] = ACTIONS(4902),
    [anon_sym_default] = ACTIONS(4904),
    [anon_sym_clocking] = ACTIONS(4904),
    [anon_sym_defparam] = ACTIONS(4904),
    [anon_sym_bind] = ACTIONS(4904),
    [anon_sym_rand] = ACTIONS(4904),
    [anon_sym_const] = ACTIONS(4904),
    [anon_sym_function] = ACTIONS(4904),
    [anon_sym_static] = ACTIONS(4904),
    [anon_sym_constraint] = ACTIONS(4904),
    [anon_sym_if] = ACTIONS(4904),
    [anon_sym_else] = ACTIONS(4904),
    [anon_sym_LBRACK] = ACTIONS(4902),
    [anon_sym_localparam] = ACTIONS(4904),
    [anon_sym_parameter] = ACTIONS(4904),
    [anon_sym_var] = ACTIONS(4904),
    [anon_sym_import] = ACTIONS(4904),
    [anon_sym_export] = ACTIONS(4904),
    [anon_sym_genvar] = ACTIONS(4904),
    [anon_sym_interconnect] = ACTIONS(4904),
    [anon_sym_typedef] = ACTIONS(4904),
    [anon_sym_enum] = ACTIONS(4904),
    [anon_sym_struct] = ACTIONS(4904),
    [anon_sym_union] = ACTIONS(4904),
    [anon_sym_nettype] = ACTIONS(4904),
    [anon_sym_automatic] = ACTIONS(4904),
    [anon_sym_string] = ACTIONS(4904),
    [anon_sym_chandle] = ACTIONS(4904),
    [anon_sym_event] = ACTIONS(4904),
    [anon_sym_byte] = ACTIONS(4904),
    [anon_sym_shortint] = ACTIONS(4904),
    [anon_sym_int] = ACTIONS(4904),
    [anon_sym_longint] = ACTIONS(4904),
    [anon_sym_integer] = ACTIONS(4904),
    [anon_sym_time] = ACTIONS(4904),
    [anon_sym_bit] = ACTIONS(4904),
    [anon_sym_logic] = ACTIONS(4904),
    [anon_sym_reg] = ACTIONS(4904),
    [anon_sym_shortreal] = ACTIONS(4904),
    [anon_sym_real] = ACTIONS(4904),
    [anon_sym_realtime] = ACTIONS(4904),
    [anon_sym_supply0] = ACTIONS(4904),
    [anon_sym_supply1] = ACTIONS(4904),
    [anon_sym_signed] = ACTIONS(4904),
    [anon_sym_unsigned] = ACTIONS(4904),
    [anon_sym_task] = ACTIONS(4904),
    [anon_sym_assert] = ACTIONS(4904),
    [anon_sym_property] = ACTIONS(4904),
    [anon_sym_assume] = ACTIONS(4904),
    [anon_sym_cover] = ACTIONS(4904),
    [anon_sym_sequence] = ACTIONS(4904),
    [anon_sym_restrict] = ACTIONS(4904),
    [anon_sym_not] = ACTIONS(4904),
    [anon_sym_or] = ACTIONS(4904),
    [anon_sym_and] = ACTIONS(4904),
    [anon_sym_case] = ACTIONS(4904),
    [anon_sym_always] = ACTIONS(4904),
    [anon_sym_covergroup] = ACTIONS(4904),
    [anon_sym_end] = ACTIONS(4904),
    [anon_sym_let] = ACTIONS(4904),
    [anon_sym_pulldown] = ACTIONS(4904),
    [anon_sym_pullup] = ACTIONS(4904),
    [anon_sym_cmos] = ACTIONS(4904),
    [anon_sym_rcmos] = ACTIONS(4904),
    [anon_sym_bufif0] = ACTIONS(4904),
    [anon_sym_bufif1] = ACTIONS(4904),
    [anon_sym_notif0] = ACTIONS(4904),
    [anon_sym_notif1] = ACTIONS(4904),
    [anon_sym_nmos] = ACTIONS(4904),
    [anon_sym_pmos] = ACTIONS(4904),
    [anon_sym_rnmos] = ACTIONS(4904),
    [anon_sym_rpmos] = ACTIONS(4904),
    [anon_sym_nand] = ACTIONS(4904),
    [anon_sym_nor] = ACTIONS(4904),
    [anon_sym_xor] = ACTIONS(4904),
    [anon_sym_xnor] = ACTIONS(4904),
    [anon_sym_buf] = ACTIONS(4904),
    [anon_sym_tranif0] = ACTIONS(4904),
    [anon_sym_tranif1] = ACTIONS(4904),
    [anon_sym_rtranif1] = ACTIONS(4904),
    [anon_sym_rtranif0] = ACTIONS(4904),
    [anon_sym_tran] = ACTIONS(4904),
    [anon_sym_rtran] = ACTIONS(4904),
    [anon_sym_generate] = ACTIONS(4904),
    [anon_sym_for] = ACTIONS(4904),
    [anon_sym_initial] = ACTIONS(4904),
    [anon_sym_assign] = ACTIONS(4904),
    [anon_sym_alias] = ACTIONS(4904),
    [anon_sym_always_comb] = ACTIONS(4904),
    [anon_sym_always_latch] = ACTIONS(4904),
    [anon_sym_always_ff] = ACTIONS(4904),
    [anon_sym_final] = ACTIONS(4904),
    [anon_sym_global] = ACTIONS(4904),
    [anon_sym_LPAREN_STAR] = ACTIONS(4902),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4902),
    [anon_sym_DOLLARunit] = ACTIONS(4902),
  },
  [4587] = {
    [sym_simple_identifier] = ACTIONS(5222),
    [anon_sym_wire] = ACTIONS(5222),
    [anon_sym_tri] = ACTIONS(5222),
    [anon_sym_tri0] = ACTIONS(5222),
    [anon_sym_tri1] = ACTIONS(5222),
    [anon_sym_wand] = ACTIONS(5222),
    [anon_sym_triand] = ACTIONS(5222),
    [anon_sym_wor] = ACTIONS(5222),
    [anon_sym_trior] = ACTIONS(5222),
    [anon_sym_trireg] = ACTIONS(5222),
    [anon_sym_uwire] = ACTIONS(5222),
    [anon_sym_SEMI] = ACTIONS(5220),
    [anon_sym_extern] = ACTIONS(5222),
    [anon_sym_interface] = ACTIONS(5222),
    [anon_sym_checker] = ACTIONS(5222),
    [anon_sym_virtual] = ACTIONS(5222),
    [anon_sym_class] = ACTIONS(5222),
    [anon_sym_type] = ACTIONS(5222),
    [anon_sym_DOLLARfatal] = ACTIONS(5220),
    [anon_sym_DOLLARerror] = ACTIONS(5220),
    [anon_sym_DOLLARwarning] = ACTIONS(5220),
    [anon_sym_DOLLARinfo] = ACTIONS(5220),
    [anon_sym_default] = ACTIONS(5222),
    [anon_sym_clocking] = ACTIONS(5222),
    [anon_sym_defparam] = ACTIONS(5222),
    [anon_sym_bind] = ACTIONS(5222),
    [anon_sym_rand] = ACTIONS(5222),
    [anon_sym_const] = ACTIONS(5222),
    [anon_sym_function] = ACTIONS(5222),
    [anon_sym_static] = ACTIONS(5222),
    [anon_sym_constraint] = ACTIONS(5222),
    [anon_sym_if] = ACTIONS(5222),
    [anon_sym_else] = ACTIONS(5222),
    [anon_sym_LBRACK] = ACTIONS(5220),
    [anon_sym_localparam] = ACTIONS(5222),
    [anon_sym_parameter] = ACTIONS(5222),
    [anon_sym_var] = ACTIONS(5222),
    [anon_sym_import] = ACTIONS(5222),
    [anon_sym_export] = ACTIONS(5222),
    [anon_sym_genvar] = ACTIONS(5222),
    [anon_sym_interconnect] = ACTIONS(5222),
    [anon_sym_typedef] = ACTIONS(5222),
    [anon_sym_enum] = ACTIONS(5222),
    [anon_sym_struct] = ACTIONS(5222),
    [anon_sym_union] = ACTIONS(5222),
    [anon_sym_nettype] = ACTIONS(5222),
    [anon_sym_automatic] = ACTIONS(5222),
    [anon_sym_string] = ACTIONS(5222),
    [anon_sym_chandle] = ACTIONS(5222),
    [anon_sym_event] = ACTIONS(5222),
    [anon_sym_byte] = ACTIONS(5222),
    [anon_sym_shortint] = ACTIONS(5222),
    [anon_sym_int] = ACTIONS(5222),
    [anon_sym_longint] = ACTIONS(5222),
    [anon_sym_integer] = ACTIONS(5222),
    [anon_sym_time] = ACTIONS(5222),
    [anon_sym_bit] = ACTIONS(5222),
    [anon_sym_logic] = ACTIONS(5222),
    [anon_sym_reg] = ACTIONS(5222),
    [anon_sym_shortreal] = ACTIONS(5222),
    [anon_sym_real] = ACTIONS(5222),
    [anon_sym_realtime] = ACTIONS(5222),
    [anon_sym_supply0] = ACTIONS(5222),
    [anon_sym_supply1] = ACTIONS(5222),
    [anon_sym_signed] = ACTIONS(5222),
    [anon_sym_unsigned] = ACTIONS(5222),
    [anon_sym_task] = ACTIONS(5222),
    [anon_sym_assert] = ACTIONS(5222),
    [anon_sym_property] = ACTIONS(5222),
    [anon_sym_assume] = ACTIONS(5222),
    [anon_sym_cover] = ACTIONS(5222),
    [anon_sym_sequence] = ACTIONS(5222),
    [anon_sym_restrict] = ACTIONS(5222),
    [anon_sym_not] = ACTIONS(5222),
    [anon_sym_or] = ACTIONS(5222),
    [anon_sym_and] = ACTIONS(5222),
    [anon_sym_case] = ACTIONS(5222),
    [anon_sym_always] = ACTIONS(5222),
    [anon_sym_covergroup] = ACTIONS(5222),
    [anon_sym_end] = ACTIONS(5222),
    [anon_sym_let] = ACTIONS(5222),
    [anon_sym_pulldown] = ACTIONS(5222),
    [anon_sym_pullup] = ACTIONS(5222),
    [anon_sym_cmos] = ACTIONS(5222),
    [anon_sym_rcmos] = ACTIONS(5222),
    [anon_sym_bufif0] = ACTIONS(5222),
    [anon_sym_bufif1] = ACTIONS(5222),
    [anon_sym_notif0] = ACTIONS(5222),
    [anon_sym_notif1] = ACTIONS(5222),
    [anon_sym_nmos] = ACTIONS(5222),
    [anon_sym_pmos] = ACTIONS(5222),
    [anon_sym_rnmos] = ACTIONS(5222),
    [anon_sym_rpmos] = ACTIONS(5222),
    [anon_sym_nand] = ACTIONS(5222),
    [anon_sym_nor] = ACTIONS(5222),
    [anon_sym_xor] = ACTIONS(5222),
    [anon_sym_xnor] = ACTIONS(5222),
    [anon_sym_buf] = ACTIONS(5222),
    [anon_sym_tranif0] = ACTIONS(5222),
    [anon_sym_tranif1] = ACTIONS(5222),
    [anon_sym_rtranif1] = ACTIONS(5222),
    [anon_sym_rtranif0] = ACTIONS(5222),
    [anon_sym_tran] = ACTIONS(5222),
    [anon_sym_rtran] = ACTIONS(5222),
    [anon_sym_generate] = ACTIONS(5222),
    [anon_sym_for] = ACTIONS(5222),
    [anon_sym_initial] = ACTIONS(5222),
    [anon_sym_assign] = ACTIONS(5222),
    [anon_sym_alias] = ACTIONS(5222),
    [anon_sym_always_comb] = ACTIONS(5222),
    [anon_sym_always_latch] = ACTIONS(5222),
    [anon_sym_always_ff] = ACTIONS(5222),
    [anon_sym_final] = ACTIONS(5222),
    [anon_sym_global] = ACTIONS(5222),
    [anon_sym_LPAREN_STAR] = ACTIONS(5220),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5220),
    [anon_sym_DOLLARunit] = ACTIONS(5220),
  },
  [4588] = {
    [sym_simple_identifier] = ACTIONS(4828),
    [anon_sym_wire] = ACTIONS(4828),
    [anon_sym_tri] = ACTIONS(4828),
    [anon_sym_tri0] = ACTIONS(4828),
    [anon_sym_tri1] = ACTIONS(4828),
    [anon_sym_wand] = ACTIONS(4828),
    [anon_sym_triand] = ACTIONS(4828),
    [anon_sym_wor] = ACTIONS(4828),
    [anon_sym_trior] = ACTIONS(4828),
    [anon_sym_trireg] = ACTIONS(4828),
    [anon_sym_uwire] = ACTIONS(4828),
    [anon_sym_SEMI] = ACTIONS(4826),
    [anon_sym_extern] = ACTIONS(4828),
    [anon_sym_interface] = ACTIONS(4828),
    [anon_sym_checker] = ACTIONS(4828),
    [anon_sym_virtual] = ACTIONS(4828),
    [anon_sym_class] = ACTIONS(4828),
    [anon_sym_type] = ACTIONS(4828),
    [anon_sym_DOLLARfatal] = ACTIONS(4826),
    [anon_sym_DOLLARerror] = ACTIONS(4826),
    [anon_sym_DOLLARwarning] = ACTIONS(4826),
    [anon_sym_DOLLARinfo] = ACTIONS(4826),
    [anon_sym_default] = ACTIONS(4828),
    [anon_sym_clocking] = ACTIONS(4828),
    [anon_sym_defparam] = ACTIONS(4828),
    [anon_sym_bind] = ACTIONS(4828),
    [anon_sym_rand] = ACTIONS(4828),
    [anon_sym_const] = ACTIONS(4828),
    [anon_sym_function] = ACTIONS(4828),
    [anon_sym_static] = ACTIONS(4828),
    [anon_sym_constraint] = ACTIONS(4828),
    [anon_sym_if] = ACTIONS(4828),
    [anon_sym_else] = ACTIONS(4828),
    [anon_sym_LBRACK] = ACTIONS(4826),
    [anon_sym_localparam] = ACTIONS(4828),
    [anon_sym_parameter] = ACTIONS(4828),
    [anon_sym_var] = ACTIONS(4828),
    [anon_sym_import] = ACTIONS(4828),
    [anon_sym_export] = ACTIONS(4828),
    [anon_sym_genvar] = ACTIONS(4828),
    [anon_sym_interconnect] = ACTIONS(4828),
    [anon_sym_typedef] = ACTIONS(4828),
    [anon_sym_enum] = ACTIONS(4828),
    [anon_sym_struct] = ACTIONS(4828),
    [anon_sym_union] = ACTIONS(4828),
    [anon_sym_nettype] = ACTIONS(4828),
    [anon_sym_automatic] = ACTIONS(4828),
    [anon_sym_string] = ACTIONS(4828),
    [anon_sym_chandle] = ACTIONS(4828),
    [anon_sym_event] = ACTIONS(4828),
    [anon_sym_byte] = ACTIONS(4828),
    [anon_sym_shortint] = ACTIONS(4828),
    [anon_sym_int] = ACTIONS(4828),
    [anon_sym_longint] = ACTIONS(4828),
    [anon_sym_integer] = ACTIONS(4828),
    [anon_sym_time] = ACTIONS(4828),
    [anon_sym_bit] = ACTIONS(4828),
    [anon_sym_logic] = ACTIONS(4828),
    [anon_sym_reg] = ACTIONS(4828),
    [anon_sym_shortreal] = ACTIONS(4828),
    [anon_sym_real] = ACTIONS(4828),
    [anon_sym_realtime] = ACTIONS(4828),
    [anon_sym_supply0] = ACTIONS(4828),
    [anon_sym_supply1] = ACTIONS(4828),
    [anon_sym_signed] = ACTIONS(4828),
    [anon_sym_unsigned] = ACTIONS(4828),
    [anon_sym_task] = ACTIONS(4828),
    [anon_sym_assert] = ACTIONS(4828),
    [anon_sym_property] = ACTIONS(4828),
    [anon_sym_assume] = ACTIONS(4828),
    [anon_sym_cover] = ACTIONS(4828),
    [anon_sym_sequence] = ACTIONS(4828),
    [anon_sym_restrict] = ACTIONS(4828),
    [anon_sym_not] = ACTIONS(4828),
    [anon_sym_or] = ACTIONS(4828),
    [anon_sym_and] = ACTIONS(4828),
    [anon_sym_case] = ACTIONS(4828),
    [anon_sym_always] = ACTIONS(4828),
    [anon_sym_covergroup] = ACTIONS(4828),
    [anon_sym_let] = ACTIONS(4828),
    [anon_sym_pulldown] = ACTIONS(4828),
    [anon_sym_pullup] = ACTIONS(4828),
    [anon_sym_cmos] = ACTIONS(4828),
    [anon_sym_rcmos] = ACTIONS(4828),
    [anon_sym_bufif0] = ACTIONS(4828),
    [anon_sym_bufif1] = ACTIONS(4828),
    [anon_sym_notif0] = ACTIONS(4828),
    [anon_sym_notif1] = ACTIONS(4828),
    [anon_sym_nmos] = ACTIONS(4828),
    [anon_sym_pmos] = ACTIONS(4828),
    [anon_sym_rnmos] = ACTIONS(4828),
    [anon_sym_rpmos] = ACTIONS(4828),
    [anon_sym_nand] = ACTIONS(4828),
    [anon_sym_nor] = ACTIONS(4828),
    [anon_sym_xor] = ACTIONS(4828),
    [anon_sym_xnor] = ACTIONS(4828),
    [anon_sym_buf] = ACTIONS(4828),
    [anon_sym_tranif0] = ACTIONS(4828),
    [anon_sym_tranif1] = ACTIONS(4828),
    [anon_sym_rtranif1] = ACTIONS(4828),
    [anon_sym_rtranif0] = ACTIONS(4828),
    [anon_sym_tran] = ACTIONS(4828),
    [anon_sym_rtran] = ACTIONS(4828),
    [anon_sym_generate] = ACTIONS(4828),
    [anon_sym_endgenerate] = ACTIONS(4828),
    [anon_sym_for] = ACTIONS(4828),
    [anon_sym_initial] = ACTIONS(4828),
    [anon_sym_assign] = ACTIONS(4828),
    [anon_sym_alias] = ACTIONS(4828),
    [anon_sym_always_comb] = ACTIONS(4828),
    [anon_sym_always_latch] = ACTIONS(4828),
    [anon_sym_always_ff] = ACTIONS(4828),
    [anon_sym_final] = ACTIONS(4828),
    [anon_sym_global] = ACTIONS(4828),
    [anon_sym_LPAREN_STAR] = ACTIONS(4826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4826),
    [anon_sym_DOLLARunit] = ACTIONS(4826),
  },
  [4589] = {
    [sym_simple_identifier] = ACTIONS(6401),
    [anon_sym_wire] = ACTIONS(6401),
    [anon_sym_tri] = ACTIONS(6401),
    [anon_sym_tri0] = ACTIONS(6401),
    [anon_sym_tri1] = ACTIONS(6401),
    [anon_sym_wand] = ACTIONS(6401),
    [anon_sym_triand] = ACTIONS(6401),
    [anon_sym_wor] = ACTIONS(6401),
    [anon_sym_trior] = ACTIONS(6401),
    [anon_sym_trireg] = ACTIONS(6401),
    [anon_sym_uwire] = ACTIONS(6401),
    [anon_sym_SEMI] = ACTIONS(6403),
    [anon_sym_extern] = ACTIONS(6401),
    [anon_sym_interface] = ACTIONS(6401),
    [anon_sym_checker] = ACTIONS(6401),
    [anon_sym_virtual] = ACTIONS(6401),
    [anon_sym_class] = ACTIONS(6401),
    [anon_sym_type] = ACTIONS(6401),
    [anon_sym_DOLLARfatal] = ACTIONS(6403),
    [anon_sym_DOLLARerror] = ACTIONS(6403),
    [anon_sym_DOLLARwarning] = ACTIONS(6403),
    [anon_sym_DOLLARinfo] = ACTIONS(6403),
    [anon_sym_default] = ACTIONS(6401),
    [anon_sym_clocking] = ACTIONS(6401),
    [anon_sym_defparam] = ACTIONS(6401),
    [anon_sym_bind] = ACTIONS(6401),
    [anon_sym_rand] = ACTIONS(6401),
    [anon_sym_const] = ACTIONS(6401),
    [anon_sym_function] = ACTIONS(6401),
    [anon_sym_static] = ACTIONS(6401),
    [anon_sym_constraint] = ACTIONS(6401),
    [anon_sym_if] = ACTIONS(6401),
    [anon_sym_else] = ACTIONS(6401),
    [anon_sym_LBRACK] = ACTIONS(6403),
    [anon_sym_localparam] = ACTIONS(6401),
    [anon_sym_parameter] = ACTIONS(6401),
    [anon_sym_var] = ACTIONS(6401),
    [anon_sym_import] = ACTIONS(6401),
    [anon_sym_export] = ACTIONS(6401),
    [anon_sym_genvar] = ACTIONS(6401),
    [anon_sym_interconnect] = ACTIONS(6401),
    [anon_sym_typedef] = ACTIONS(6401),
    [anon_sym_enum] = ACTIONS(6401),
    [anon_sym_struct] = ACTIONS(6401),
    [anon_sym_union] = ACTIONS(6401),
    [anon_sym_nettype] = ACTIONS(6401),
    [anon_sym_automatic] = ACTIONS(6401),
    [anon_sym_string] = ACTIONS(6401),
    [anon_sym_chandle] = ACTIONS(6401),
    [anon_sym_event] = ACTIONS(6401),
    [anon_sym_byte] = ACTIONS(6401),
    [anon_sym_shortint] = ACTIONS(6401),
    [anon_sym_int] = ACTIONS(6401),
    [anon_sym_longint] = ACTIONS(6401),
    [anon_sym_integer] = ACTIONS(6401),
    [anon_sym_time] = ACTIONS(6401),
    [anon_sym_bit] = ACTIONS(6401),
    [anon_sym_logic] = ACTIONS(6401),
    [anon_sym_reg] = ACTIONS(6401),
    [anon_sym_shortreal] = ACTIONS(6401),
    [anon_sym_real] = ACTIONS(6401),
    [anon_sym_realtime] = ACTIONS(6401),
    [anon_sym_supply0] = ACTIONS(6401),
    [anon_sym_supply1] = ACTIONS(6401),
    [anon_sym_signed] = ACTIONS(6401),
    [anon_sym_unsigned] = ACTIONS(6401),
    [anon_sym_task] = ACTIONS(6401),
    [anon_sym_assert] = ACTIONS(6401),
    [anon_sym_property] = ACTIONS(6401),
    [anon_sym_assume] = ACTIONS(6401),
    [anon_sym_cover] = ACTIONS(6401),
    [anon_sym_sequence] = ACTIONS(6401),
    [anon_sym_restrict] = ACTIONS(6401),
    [anon_sym_not] = ACTIONS(6401),
    [anon_sym_or] = ACTIONS(6401),
    [anon_sym_and] = ACTIONS(6401),
    [anon_sym_case] = ACTIONS(6401),
    [anon_sym_always] = ACTIONS(6401),
    [anon_sym_covergroup] = ACTIONS(6401),
    [anon_sym_end] = ACTIONS(6401),
    [anon_sym_let] = ACTIONS(6401),
    [anon_sym_pulldown] = ACTIONS(6401),
    [anon_sym_pullup] = ACTIONS(6401),
    [anon_sym_cmos] = ACTIONS(6401),
    [anon_sym_rcmos] = ACTIONS(6401),
    [anon_sym_bufif0] = ACTIONS(6401),
    [anon_sym_bufif1] = ACTIONS(6401),
    [anon_sym_notif0] = ACTIONS(6401),
    [anon_sym_notif1] = ACTIONS(6401),
    [anon_sym_nmos] = ACTIONS(6401),
    [anon_sym_pmos] = ACTIONS(6401),
    [anon_sym_rnmos] = ACTIONS(6401),
    [anon_sym_rpmos] = ACTIONS(6401),
    [anon_sym_nand] = ACTIONS(6401),
    [anon_sym_nor] = ACTIONS(6401),
    [anon_sym_xor] = ACTIONS(6401),
    [anon_sym_xnor] = ACTIONS(6401),
    [anon_sym_buf] = ACTIONS(6401),
    [anon_sym_tranif0] = ACTIONS(6401),
    [anon_sym_tranif1] = ACTIONS(6401),
    [anon_sym_rtranif1] = ACTIONS(6401),
    [anon_sym_rtranif0] = ACTIONS(6401),
    [anon_sym_tran] = ACTIONS(6401),
    [anon_sym_rtran] = ACTIONS(6401),
    [anon_sym_generate] = ACTIONS(6401),
    [anon_sym_for] = ACTIONS(6401),
    [anon_sym_initial] = ACTIONS(6401),
    [anon_sym_assign] = ACTIONS(6401),
    [anon_sym_alias] = ACTIONS(6401),
    [anon_sym_always_comb] = ACTIONS(6401),
    [anon_sym_always_latch] = ACTIONS(6401),
    [anon_sym_always_ff] = ACTIONS(6401),
    [anon_sym_final] = ACTIONS(6401),
    [anon_sym_global] = ACTIONS(6401),
    [anon_sym_LPAREN_STAR] = ACTIONS(6403),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6403),
    [anon_sym_DOLLARunit] = ACTIONS(6403),
  },
  [4590] = {
    [sym_simple_identifier] = ACTIONS(5958),
    [anon_sym_wire] = ACTIONS(5958),
    [anon_sym_tri] = ACTIONS(5958),
    [anon_sym_tri0] = ACTIONS(5958),
    [anon_sym_tri1] = ACTIONS(5958),
    [anon_sym_wand] = ACTIONS(5958),
    [anon_sym_triand] = ACTIONS(5958),
    [anon_sym_wor] = ACTIONS(5958),
    [anon_sym_trior] = ACTIONS(5958),
    [anon_sym_trireg] = ACTIONS(5958),
    [anon_sym_uwire] = ACTIONS(5958),
    [anon_sym_SEMI] = ACTIONS(5960),
    [anon_sym_extern] = ACTIONS(5958),
    [anon_sym_interface] = ACTIONS(5958),
    [anon_sym_checker] = ACTIONS(5958),
    [anon_sym_virtual] = ACTIONS(5958),
    [anon_sym_class] = ACTIONS(5958),
    [anon_sym_type] = ACTIONS(5958),
    [anon_sym_DOLLARfatal] = ACTIONS(5960),
    [anon_sym_DOLLARerror] = ACTIONS(5960),
    [anon_sym_DOLLARwarning] = ACTIONS(5960),
    [anon_sym_DOLLARinfo] = ACTIONS(5960),
    [anon_sym_default] = ACTIONS(5958),
    [anon_sym_clocking] = ACTIONS(5958),
    [anon_sym_defparam] = ACTIONS(5958),
    [anon_sym_bind] = ACTIONS(5958),
    [anon_sym_rand] = ACTIONS(5958),
    [anon_sym_const] = ACTIONS(5958),
    [anon_sym_function] = ACTIONS(5958),
    [anon_sym_static] = ACTIONS(5958),
    [anon_sym_constraint] = ACTIONS(5958),
    [anon_sym_if] = ACTIONS(5958),
    [anon_sym_else] = ACTIONS(5958),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_localparam] = ACTIONS(5958),
    [anon_sym_parameter] = ACTIONS(5958),
    [anon_sym_var] = ACTIONS(5958),
    [anon_sym_import] = ACTIONS(5958),
    [anon_sym_export] = ACTIONS(5958),
    [anon_sym_genvar] = ACTIONS(5958),
    [anon_sym_interconnect] = ACTIONS(5958),
    [anon_sym_typedef] = ACTIONS(5958),
    [anon_sym_enum] = ACTIONS(5958),
    [anon_sym_struct] = ACTIONS(5958),
    [anon_sym_union] = ACTIONS(5958),
    [anon_sym_nettype] = ACTIONS(5958),
    [anon_sym_automatic] = ACTIONS(5958),
    [anon_sym_string] = ACTIONS(5958),
    [anon_sym_chandle] = ACTIONS(5958),
    [anon_sym_event] = ACTIONS(5958),
    [anon_sym_byte] = ACTIONS(5958),
    [anon_sym_shortint] = ACTIONS(5958),
    [anon_sym_int] = ACTIONS(5958),
    [anon_sym_longint] = ACTIONS(5958),
    [anon_sym_integer] = ACTIONS(5958),
    [anon_sym_time] = ACTIONS(5958),
    [anon_sym_bit] = ACTIONS(5958),
    [anon_sym_logic] = ACTIONS(5958),
    [anon_sym_reg] = ACTIONS(5958),
    [anon_sym_shortreal] = ACTIONS(5958),
    [anon_sym_real] = ACTIONS(5958),
    [anon_sym_realtime] = ACTIONS(5958),
    [anon_sym_supply0] = ACTIONS(5958),
    [anon_sym_supply1] = ACTIONS(5958),
    [anon_sym_signed] = ACTIONS(5958),
    [anon_sym_unsigned] = ACTIONS(5958),
    [anon_sym_task] = ACTIONS(5958),
    [anon_sym_assert] = ACTIONS(5958),
    [anon_sym_property] = ACTIONS(5958),
    [anon_sym_assume] = ACTIONS(5958),
    [anon_sym_cover] = ACTIONS(5958),
    [anon_sym_sequence] = ACTIONS(5958),
    [anon_sym_restrict] = ACTIONS(5958),
    [anon_sym_not] = ACTIONS(5958),
    [anon_sym_or] = ACTIONS(5958),
    [anon_sym_and] = ACTIONS(5958),
    [anon_sym_case] = ACTIONS(5958),
    [anon_sym_always] = ACTIONS(5958),
    [anon_sym_covergroup] = ACTIONS(5958),
    [anon_sym_end] = ACTIONS(5958),
    [anon_sym_let] = ACTIONS(5958),
    [anon_sym_pulldown] = ACTIONS(5958),
    [anon_sym_pullup] = ACTIONS(5958),
    [anon_sym_cmos] = ACTIONS(5958),
    [anon_sym_rcmos] = ACTIONS(5958),
    [anon_sym_bufif0] = ACTIONS(5958),
    [anon_sym_bufif1] = ACTIONS(5958),
    [anon_sym_notif0] = ACTIONS(5958),
    [anon_sym_notif1] = ACTIONS(5958),
    [anon_sym_nmos] = ACTIONS(5958),
    [anon_sym_pmos] = ACTIONS(5958),
    [anon_sym_rnmos] = ACTIONS(5958),
    [anon_sym_rpmos] = ACTIONS(5958),
    [anon_sym_nand] = ACTIONS(5958),
    [anon_sym_nor] = ACTIONS(5958),
    [anon_sym_xor] = ACTIONS(5958),
    [anon_sym_xnor] = ACTIONS(5958),
    [anon_sym_buf] = ACTIONS(5958),
    [anon_sym_tranif0] = ACTIONS(5958),
    [anon_sym_tranif1] = ACTIONS(5958),
    [anon_sym_rtranif1] = ACTIONS(5958),
    [anon_sym_rtranif0] = ACTIONS(5958),
    [anon_sym_tran] = ACTIONS(5958),
    [anon_sym_rtran] = ACTIONS(5958),
    [anon_sym_generate] = ACTIONS(5958),
    [anon_sym_for] = ACTIONS(5958),
    [anon_sym_initial] = ACTIONS(5958),
    [anon_sym_assign] = ACTIONS(5958),
    [anon_sym_alias] = ACTIONS(5958),
    [anon_sym_always_comb] = ACTIONS(5958),
    [anon_sym_always_latch] = ACTIONS(5958),
    [anon_sym_always_ff] = ACTIONS(5958),
    [anon_sym_final] = ACTIONS(5958),
    [anon_sym_global] = ACTIONS(5958),
    [anon_sym_LPAREN_STAR] = ACTIONS(5960),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5960),
    [anon_sym_DOLLARunit] = ACTIONS(5960),
  },
  [4591] = {
    [sym_simple_identifier] = ACTIONS(6249),
    [anon_sym_wire] = ACTIONS(6249),
    [anon_sym_tri] = ACTIONS(6249),
    [anon_sym_tri0] = ACTIONS(6249),
    [anon_sym_tri1] = ACTIONS(6249),
    [anon_sym_wand] = ACTIONS(6249),
    [anon_sym_triand] = ACTIONS(6249),
    [anon_sym_wor] = ACTIONS(6249),
    [anon_sym_trior] = ACTIONS(6249),
    [anon_sym_trireg] = ACTIONS(6249),
    [anon_sym_uwire] = ACTIONS(6249),
    [anon_sym_SEMI] = ACTIONS(6251),
    [anon_sym_extern] = ACTIONS(6249),
    [anon_sym_interface] = ACTIONS(6249),
    [anon_sym_checker] = ACTIONS(6249),
    [anon_sym_virtual] = ACTIONS(6249),
    [anon_sym_class] = ACTIONS(6249),
    [anon_sym_type] = ACTIONS(6249),
    [anon_sym_DOLLARfatal] = ACTIONS(6251),
    [anon_sym_DOLLARerror] = ACTIONS(6251),
    [anon_sym_DOLLARwarning] = ACTIONS(6251),
    [anon_sym_DOLLARinfo] = ACTIONS(6251),
    [anon_sym_default] = ACTIONS(6249),
    [anon_sym_clocking] = ACTIONS(6249),
    [anon_sym_defparam] = ACTIONS(6249),
    [anon_sym_bind] = ACTIONS(6249),
    [anon_sym_rand] = ACTIONS(6249),
    [anon_sym_const] = ACTIONS(6249),
    [anon_sym_function] = ACTIONS(6249),
    [anon_sym_static] = ACTIONS(6249),
    [anon_sym_constraint] = ACTIONS(6249),
    [anon_sym_if] = ACTIONS(6249),
    [anon_sym_else] = ACTIONS(6249),
    [anon_sym_LBRACK] = ACTIONS(6251),
    [anon_sym_localparam] = ACTIONS(6249),
    [anon_sym_parameter] = ACTIONS(6249),
    [anon_sym_var] = ACTIONS(6249),
    [anon_sym_import] = ACTIONS(6249),
    [anon_sym_export] = ACTIONS(6249),
    [anon_sym_genvar] = ACTIONS(6249),
    [anon_sym_interconnect] = ACTIONS(6249),
    [anon_sym_typedef] = ACTIONS(6249),
    [anon_sym_enum] = ACTIONS(6249),
    [anon_sym_struct] = ACTIONS(6249),
    [anon_sym_union] = ACTIONS(6249),
    [anon_sym_nettype] = ACTIONS(6249),
    [anon_sym_automatic] = ACTIONS(6249),
    [anon_sym_string] = ACTIONS(6249),
    [anon_sym_chandle] = ACTIONS(6249),
    [anon_sym_event] = ACTIONS(6249),
    [anon_sym_byte] = ACTIONS(6249),
    [anon_sym_shortint] = ACTIONS(6249),
    [anon_sym_int] = ACTIONS(6249),
    [anon_sym_longint] = ACTIONS(6249),
    [anon_sym_integer] = ACTIONS(6249),
    [anon_sym_time] = ACTIONS(6249),
    [anon_sym_bit] = ACTIONS(6249),
    [anon_sym_logic] = ACTIONS(6249),
    [anon_sym_reg] = ACTIONS(6249),
    [anon_sym_shortreal] = ACTIONS(6249),
    [anon_sym_real] = ACTIONS(6249),
    [anon_sym_realtime] = ACTIONS(6249),
    [anon_sym_supply0] = ACTIONS(6249),
    [anon_sym_supply1] = ACTIONS(6249),
    [anon_sym_signed] = ACTIONS(6249),
    [anon_sym_unsigned] = ACTIONS(6249),
    [anon_sym_task] = ACTIONS(6249),
    [anon_sym_assert] = ACTIONS(6249),
    [anon_sym_property] = ACTIONS(6249),
    [anon_sym_assume] = ACTIONS(6249),
    [anon_sym_cover] = ACTIONS(6249),
    [anon_sym_sequence] = ACTIONS(6249),
    [anon_sym_restrict] = ACTIONS(6249),
    [anon_sym_not] = ACTIONS(6249),
    [anon_sym_or] = ACTIONS(6249),
    [anon_sym_and] = ACTIONS(6249),
    [anon_sym_case] = ACTIONS(6249),
    [anon_sym_always] = ACTIONS(6249),
    [anon_sym_covergroup] = ACTIONS(6249),
    [anon_sym_let] = ACTIONS(6249),
    [anon_sym_pulldown] = ACTIONS(6249),
    [anon_sym_pullup] = ACTIONS(6249),
    [anon_sym_cmos] = ACTIONS(6249),
    [anon_sym_rcmos] = ACTIONS(6249),
    [anon_sym_bufif0] = ACTIONS(6249),
    [anon_sym_bufif1] = ACTIONS(6249),
    [anon_sym_notif0] = ACTIONS(6249),
    [anon_sym_notif1] = ACTIONS(6249),
    [anon_sym_nmos] = ACTIONS(6249),
    [anon_sym_pmos] = ACTIONS(6249),
    [anon_sym_rnmos] = ACTIONS(6249),
    [anon_sym_rpmos] = ACTIONS(6249),
    [anon_sym_nand] = ACTIONS(6249),
    [anon_sym_nor] = ACTIONS(6249),
    [anon_sym_xor] = ACTIONS(6249),
    [anon_sym_xnor] = ACTIONS(6249),
    [anon_sym_buf] = ACTIONS(6249),
    [anon_sym_tranif0] = ACTIONS(6249),
    [anon_sym_tranif1] = ACTIONS(6249),
    [anon_sym_rtranif1] = ACTIONS(6249),
    [anon_sym_rtranif0] = ACTIONS(6249),
    [anon_sym_tran] = ACTIONS(6249),
    [anon_sym_rtran] = ACTIONS(6249),
    [anon_sym_generate] = ACTIONS(6249),
    [anon_sym_endgenerate] = ACTIONS(6249),
    [anon_sym_for] = ACTIONS(6249),
    [anon_sym_initial] = ACTIONS(6249),
    [anon_sym_assign] = ACTIONS(6249),
    [anon_sym_alias] = ACTIONS(6249),
    [anon_sym_always_comb] = ACTIONS(6249),
    [anon_sym_always_latch] = ACTIONS(6249),
    [anon_sym_always_ff] = ACTIONS(6249),
    [anon_sym_final] = ACTIONS(6249),
    [anon_sym_global] = ACTIONS(6249),
    [anon_sym_LPAREN_STAR] = ACTIONS(6251),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6251),
    [anon_sym_DOLLARunit] = ACTIONS(6251),
  },
  [4592] = {
    [sym_simple_identifier] = ACTIONS(6549),
    [anon_sym_wire] = ACTIONS(6549),
    [anon_sym_tri] = ACTIONS(6549),
    [anon_sym_tri0] = ACTIONS(6549),
    [anon_sym_tri1] = ACTIONS(6549),
    [anon_sym_wand] = ACTIONS(6549),
    [anon_sym_triand] = ACTIONS(6549),
    [anon_sym_wor] = ACTIONS(6549),
    [anon_sym_trior] = ACTIONS(6549),
    [anon_sym_trireg] = ACTIONS(6549),
    [anon_sym_uwire] = ACTIONS(6549),
    [anon_sym_SEMI] = ACTIONS(6551),
    [anon_sym_extern] = ACTIONS(6549),
    [anon_sym_interface] = ACTIONS(6549),
    [anon_sym_checker] = ACTIONS(6549),
    [anon_sym_virtual] = ACTIONS(6549),
    [anon_sym_class] = ACTIONS(6549),
    [anon_sym_type] = ACTIONS(6549),
    [anon_sym_DOLLARfatal] = ACTIONS(6551),
    [anon_sym_DOLLARerror] = ACTIONS(6551),
    [anon_sym_DOLLARwarning] = ACTIONS(6551),
    [anon_sym_DOLLARinfo] = ACTIONS(6551),
    [anon_sym_default] = ACTIONS(6549),
    [anon_sym_clocking] = ACTIONS(6549),
    [anon_sym_defparam] = ACTIONS(6549),
    [anon_sym_bind] = ACTIONS(6549),
    [anon_sym_rand] = ACTIONS(6549),
    [anon_sym_const] = ACTIONS(6549),
    [anon_sym_function] = ACTIONS(6549),
    [anon_sym_static] = ACTIONS(6549),
    [anon_sym_constraint] = ACTIONS(6549),
    [anon_sym_if] = ACTIONS(6549),
    [anon_sym_else] = ACTIONS(6549),
    [anon_sym_LBRACK] = ACTIONS(6551),
    [anon_sym_localparam] = ACTIONS(6549),
    [anon_sym_parameter] = ACTIONS(6549),
    [anon_sym_var] = ACTIONS(6549),
    [anon_sym_import] = ACTIONS(6549),
    [anon_sym_export] = ACTIONS(6549),
    [anon_sym_genvar] = ACTIONS(6549),
    [anon_sym_interconnect] = ACTIONS(6549),
    [anon_sym_typedef] = ACTIONS(6549),
    [anon_sym_enum] = ACTIONS(6549),
    [anon_sym_struct] = ACTIONS(6549),
    [anon_sym_union] = ACTIONS(6549),
    [anon_sym_nettype] = ACTIONS(6549),
    [anon_sym_automatic] = ACTIONS(6549),
    [anon_sym_string] = ACTIONS(6549),
    [anon_sym_chandle] = ACTIONS(6549),
    [anon_sym_event] = ACTIONS(6549),
    [anon_sym_byte] = ACTIONS(6549),
    [anon_sym_shortint] = ACTIONS(6549),
    [anon_sym_int] = ACTIONS(6549),
    [anon_sym_longint] = ACTIONS(6549),
    [anon_sym_integer] = ACTIONS(6549),
    [anon_sym_time] = ACTIONS(6549),
    [anon_sym_bit] = ACTIONS(6549),
    [anon_sym_logic] = ACTIONS(6549),
    [anon_sym_reg] = ACTIONS(6549),
    [anon_sym_shortreal] = ACTIONS(6549),
    [anon_sym_real] = ACTIONS(6549),
    [anon_sym_realtime] = ACTIONS(6549),
    [anon_sym_supply0] = ACTIONS(6549),
    [anon_sym_supply1] = ACTIONS(6549),
    [anon_sym_signed] = ACTIONS(6549),
    [anon_sym_unsigned] = ACTIONS(6549),
    [anon_sym_task] = ACTIONS(6549),
    [anon_sym_assert] = ACTIONS(6549),
    [anon_sym_property] = ACTIONS(6549),
    [anon_sym_assume] = ACTIONS(6549),
    [anon_sym_cover] = ACTIONS(6549),
    [anon_sym_sequence] = ACTIONS(6549),
    [anon_sym_restrict] = ACTIONS(6549),
    [anon_sym_not] = ACTIONS(6549),
    [anon_sym_or] = ACTIONS(6549),
    [anon_sym_and] = ACTIONS(6549),
    [anon_sym_case] = ACTIONS(6549),
    [anon_sym_always] = ACTIONS(6549),
    [anon_sym_covergroup] = ACTIONS(6549),
    [anon_sym_let] = ACTIONS(6549),
    [anon_sym_pulldown] = ACTIONS(6549),
    [anon_sym_pullup] = ACTIONS(6549),
    [anon_sym_cmos] = ACTIONS(6549),
    [anon_sym_rcmos] = ACTIONS(6549),
    [anon_sym_bufif0] = ACTIONS(6549),
    [anon_sym_bufif1] = ACTIONS(6549),
    [anon_sym_notif0] = ACTIONS(6549),
    [anon_sym_notif1] = ACTIONS(6549),
    [anon_sym_nmos] = ACTIONS(6549),
    [anon_sym_pmos] = ACTIONS(6549),
    [anon_sym_rnmos] = ACTIONS(6549),
    [anon_sym_rpmos] = ACTIONS(6549),
    [anon_sym_nand] = ACTIONS(6549),
    [anon_sym_nor] = ACTIONS(6549),
    [anon_sym_xor] = ACTIONS(6549),
    [anon_sym_xnor] = ACTIONS(6549),
    [anon_sym_buf] = ACTIONS(6549),
    [anon_sym_tranif0] = ACTIONS(6549),
    [anon_sym_tranif1] = ACTIONS(6549),
    [anon_sym_rtranif1] = ACTIONS(6549),
    [anon_sym_rtranif0] = ACTIONS(6549),
    [anon_sym_tran] = ACTIONS(6549),
    [anon_sym_rtran] = ACTIONS(6549),
    [anon_sym_generate] = ACTIONS(6549),
    [anon_sym_endgenerate] = ACTIONS(6549),
    [anon_sym_for] = ACTIONS(6549),
    [anon_sym_initial] = ACTIONS(6549),
    [anon_sym_assign] = ACTIONS(6549),
    [anon_sym_alias] = ACTIONS(6549),
    [anon_sym_always_comb] = ACTIONS(6549),
    [anon_sym_always_latch] = ACTIONS(6549),
    [anon_sym_always_ff] = ACTIONS(6549),
    [anon_sym_final] = ACTIONS(6549),
    [anon_sym_global] = ACTIONS(6549),
    [anon_sym_LPAREN_STAR] = ACTIONS(6551),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6551),
    [anon_sym_DOLLARunit] = ACTIONS(6551),
  },
  [4593] = {
    [sym_simple_identifier] = ACTIONS(6641),
    [anon_sym_wire] = ACTIONS(6641),
    [anon_sym_tri] = ACTIONS(6641),
    [anon_sym_tri0] = ACTIONS(6641),
    [anon_sym_tri1] = ACTIONS(6641),
    [anon_sym_wand] = ACTIONS(6641),
    [anon_sym_triand] = ACTIONS(6641),
    [anon_sym_wor] = ACTIONS(6641),
    [anon_sym_trior] = ACTIONS(6641),
    [anon_sym_trireg] = ACTIONS(6641),
    [anon_sym_uwire] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_extern] = ACTIONS(6641),
    [anon_sym_interface] = ACTIONS(6641),
    [anon_sym_checker] = ACTIONS(6641),
    [anon_sym_virtual] = ACTIONS(6641),
    [anon_sym_class] = ACTIONS(6641),
    [anon_sym_type] = ACTIONS(6641),
    [anon_sym_DOLLARfatal] = ACTIONS(6643),
    [anon_sym_DOLLARerror] = ACTIONS(6643),
    [anon_sym_DOLLARwarning] = ACTIONS(6643),
    [anon_sym_DOLLARinfo] = ACTIONS(6643),
    [anon_sym_default] = ACTIONS(6641),
    [anon_sym_clocking] = ACTIONS(6641),
    [anon_sym_defparam] = ACTIONS(6641),
    [anon_sym_bind] = ACTIONS(6641),
    [anon_sym_rand] = ACTIONS(6641),
    [anon_sym_const] = ACTIONS(6641),
    [anon_sym_function] = ACTIONS(6641),
    [anon_sym_static] = ACTIONS(6641),
    [anon_sym_constraint] = ACTIONS(6641),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_else] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [anon_sym_localparam] = ACTIONS(6641),
    [anon_sym_parameter] = ACTIONS(6641),
    [anon_sym_var] = ACTIONS(6641),
    [anon_sym_import] = ACTIONS(6641),
    [anon_sym_export] = ACTIONS(6641),
    [anon_sym_genvar] = ACTIONS(6641),
    [anon_sym_interconnect] = ACTIONS(6641),
    [anon_sym_typedef] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_struct] = ACTIONS(6641),
    [anon_sym_union] = ACTIONS(6641),
    [anon_sym_nettype] = ACTIONS(6641),
    [anon_sym_automatic] = ACTIONS(6641),
    [anon_sym_string] = ACTIONS(6641),
    [anon_sym_chandle] = ACTIONS(6641),
    [anon_sym_event] = ACTIONS(6641),
    [anon_sym_byte] = ACTIONS(6641),
    [anon_sym_shortint] = ACTIONS(6641),
    [anon_sym_int] = ACTIONS(6641),
    [anon_sym_longint] = ACTIONS(6641),
    [anon_sym_integer] = ACTIONS(6641),
    [anon_sym_time] = ACTIONS(6641),
    [anon_sym_bit] = ACTIONS(6641),
    [anon_sym_logic] = ACTIONS(6641),
    [anon_sym_reg] = ACTIONS(6641),
    [anon_sym_shortreal] = ACTIONS(6641),
    [anon_sym_real] = ACTIONS(6641),
    [anon_sym_realtime] = ACTIONS(6641),
    [anon_sym_supply0] = ACTIONS(6641),
    [anon_sym_supply1] = ACTIONS(6641),
    [anon_sym_signed] = ACTIONS(6641),
    [anon_sym_unsigned] = ACTIONS(6641),
    [anon_sym_task] = ACTIONS(6641),
    [anon_sym_assert] = ACTIONS(6641),
    [anon_sym_property] = ACTIONS(6641),
    [anon_sym_assume] = ACTIONS(6641),
    [anon_sym_cover] = ACTIONS(6641),
    [anon_sym_sequence] = ACTIONS(6641),
    [anon_sym_restrict] = ACTIONS(6641),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_or] = ACTIONS(6641),
    [anon_sym_and] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_always] = ACTIONS(6641),
    [anon_sym_covergroup] = ACTIONS(6641),
    [anon_sym_let] = ACTIONS(6641),
    [anon_sym_pulldown] = ACTIONS(6641),
    [anon_sym_pullup] = ACTIONS(6641),
    [anon_sym_cmos] = ACTIONS(6641),
    [anon_sym_rcmos] = ACTIONS(6641),
    [anon_sym_bufif0] = ACTIONS(6641),
    [anon_sym_bufif1] = ACTIONS(6641),
    [anon_sym_notif0] = ACTIONS(6641),
    [anon_sym_notif1] = ACTIONS(6641),
    [anon_sym_nmos] = ACTIONS(6641),
    [anon_sym_pmos] = ACTIONS(6641),
    [anon_sym_rnmos] = ACTIONS(6641),
    [anon_sym_rpmos] = ACTIONS(6641),
    [anon_sym_nand] = ACTIONS(6641),
    [anon_sym_nor] = ACTIONS(6641),
    [anon_sym_xor] = ACTIONS(6641),
    [anon_sym_xnor] = ACTIONS(6641),
    [anon_sym_buf] = ACTIONS(6641),
    [anon_sym_tranif0] = ACTIONS(6641),
    [anon_sym_tranif1] = ACTIONS(6641),
    [anon_sym_rtranif1] = ACTIONS(6641),
    [anon_sym_rtranif0] = ACTIONS(6641),
    [anon_sym_tran] = ACTIONS(6641),
    [anon_sym_rtran] = ACTIONS(6641),
    [anon_sym_generate] = ACTIONS(6641),
    [anon_sym_endgenerate] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_initial] = ACTIONS(6641),
    [anon_sym_assign] = ACTIONS(6641),
    [anon_sym_alias] = ACTIONS(6641),
    [anon_sym_always_comb] = ACTIONS(6641),
    [anon_sym_always_latch] = ACTIONS(6641),
    [anon_sym_always_ff] = ACTIONS(6641),
    [anon_sym_final] = ACTIONS(6641),
    [anon_sym_global] = ACTIONS(6641),
    [anon_sym_LPAREN_STAR] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6643),
    [anon_sym_DOLLARunit] = ACTIONS(6643),
  },
  [4594] = {
    [sym_simple_identifier] = ACTIONS(6233),
    [anon_sym_wire] = ACTIONS(6233),
    [anon_sym_tri] = ACTIONS(6233),
    [anon_sym_tri0] = ACTIONS(6233),
    [anon_sym_tri1] = ACTIONS(6233),
    [anon_sym_wand] = ACTIONS(6233),
    [anon_sym_triand] = ACTIONS(6233),
    [anon_sym_wor] = ACTIONS(6233),
    [anon_sym_trior] = ACTIONS(6233),
    [anon_sym_trireg] = ACTIONS(6233),
    [anon_sym_uwire] = ACTIONS(6233),
    [anon_sym_SEMI] = ACTIONS(6235),
    [anon_sym_extern] = ACTIONS(6233),
    [anon_sym_interface] = ACTIONS(6233),
    [anon_sym_checker] = ACTIONS(6233),
    [anon_sym_virtual] = ACTIONS(6233),
    [anon_sym_class] = ACTIONS(6233),
    [anon_sym_type] = ACTIONS(6233),
    [anon_sym_DOLLARfatal] = ACTIONS(6235),
    [anon_sym_DOLLARerror] = ACTIONS(6235),
    [anon_sym_DOLLARwarning] = ACTIONS(6235),
    [anon_sym_DOLLARinfo] = ACTIONS(6235),
    [anon_sym_default] = ACTIONS(6233),
    [anon_sym_clocking] = ACTIONS(6233),
    [anon_sym_defparam] = ACTIONS(6233),
    [anon_sym_bind] = ACTIONS(6233),
    [anon_sym_rand] = ACTIONS(6233),
    [anon_sym_const] = ACTIONS(6233),
    [anon_sym_function] = ACTIONS(6233),
    [anon_sym_static] = ACTIONS(6233),
    [anon_sym_constraint] = ACTIONS(6233),
    [anon_sym_if] = ACTIONS(6233),
    [anon_sym_else] = ACTIONS(6233),
    [anon_sym_LBRACK] = ACTIONS(6235),
    [anon_sym_localparam] = ACTIONS(6233),
    [anon_sym_parameter] = ACTIONS(6233),
    [anon_sym_var] = ACTIONS(6233),
    [anon_sym_import] = ACTIONS(6233),
    [anon_sym_export] = ACTIONS(6233),
    [anon_sym_genvar] = ACTIONS(6233),
    [anon_sym_interconnect] = ACTIONS(6233),
    [anon_sym_typedef] = ACTIONS(6233),
    [anon_sym_enum] = ACTIONS(6233),
    [anon_sym_struct] = ACTIONS(6233),
    [anon_sym_union] = ACTIONS(6233),
    [anon_sym_nettype] = ACTIONS(6233),
    [anon_sym_automatic] = ACTIONS(6233),
    [anon_sym_string] = ACTIONS(6233),
    [anon_sym_chandle] = ACTIONS(6233),
    [anon_sym_event] = ACTIONS(6233),
    [anon_sym_byte] = ACTIONS(6233),
    [anon_sym_shortint] = ACTIONS(6233),
    [anon_sym_int] = ACTIONS(6233),
    [anon_sym_longint] = ACTIONS(6233),
    [anon_sym_integer] = ACTIONS(6233),
    [anon_sym_time] = ACTIONS(6233),
    [anon_sym_bit] = ACTIONS(6233),
    [anon_sym_logic] = ACTIONS(6233),
    [anon_sym_reg] = ACTIONS(6233),
    [anon_sym_shortreal] = ACTIONS(6233),
    [anon_sym_real] = ACTIONS(6233),
    [anon_sym_realtime] = ACTIONS(6233),
    [anon_sym_supply0] = ACTIONS(6233),
    [anon_sym_supply1] = ACTIONS(6233),
    [anon_sym_signed] = ACTIONS(6233),
    [anon_sym_unsigned] = ACTIONS(6233),
    [anon_sym_task] = ACTIONS(6233),
    [anon_sym_assert] = ACTIONS(6233),
    [anon_sym_property] = ACTIONS(6233),
    [anon_sym_assume] = ACTIONS(6233),
    [anon_sym_cover] = ACTIONS(6233),
    [anon_sym_sequence] = ACTIONS(6233),
    [anon_sym_restrict] = ACTIONS(6233),
    [anon_sym_not] = ACTIONS(6233),
    [anon_sym_or] = ACTIONS(6233),
    [anon_sym_and] = ACTIONS(6233),
    [anon_sym_case] = ACTIONS(6233),
    [anon_sym_always] = ACTIONS(6233),
    [anon_sym_covergroup] = ACTIONS(6233),
    [anon_sym_let] = ACTIONS(6233),
    [anon_sym_pulldown] = ACTIONS(6233),
    [anon_sym_pullup] = ACTIONS(6233),
    [anon_sym_cmos] = ACTIONS(6233),
    [anon_sym_rcmos] = ACTIONS(6233),
    [anon_sym_bufif0] = ACTIONS(6233),
    [anon_sym_bufif1] = ACTIONS(6233),
    [anon_sym_notif0] = ACTIONS(6233),
    [anon_sym_notif1] = ACTIONS(6233),
    [anon_sym_nmos] = ACTIONS(6233),
    [anon_sym_pmos] = ACTIONS(6233),
    [anon_sym_rnmos] = ACTIONS(6233),
    [anon_sym_rpmos] = ACTIONS(6233),
    [anon_sym_nand] = ACTIONS(6233),
    [anon_sym_nor] = ACTIONS(6233),
    [anon_sym_xor] = ACTIONS(6233),
    [anon_sym_xnor] = ACTIONS(6233),
    [anon_sym_buf] = ACTIONS(6233),
    [anon_sym_tranif0] = ACTIONS(6233),
    [anon_sym_tranif1] = ACTIONS(6233),
    [anon_sym_rtranif1] = ACTIONS(6233),
    [anon_sym_rtranif0] = ACTIONS(6233),
    [anon_sym_tran] = ACTIONS(6233),
    [anon_sym_rtran] = ACTIONS(6233),
    [anon_sym_generate] = ACTIONS(6233),
    [anon_sym_endgenerate] = ACTIONS(6233),
    [anon_sym_for] = ACTIONS(6233),
    [anon_sym_initial] = ACTIONS(6233),
    [anon_sym_assign] = ACTIONS(6233),
    [anon_sym_alias] = ACTIONS(6233),
    [anon_sym_always_comb] = ACTIONS(6233),
    [anon_sym_always_latch] = ACTIONS(6233),
    [anon_sym_always_ff] = ACTIONS(6233),
    [anon_sym_final] = ACTIONS(6233),
    [anon_sym_global] = ACTIONS(6233),
    [anon_sym_LPAREN_STAR] = ACTIONS(6235),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6235),
    [anon_sym_DOLLARunit] = ACTIONS(6235),
  },
  [4595] = {
    [sym_simple_identifier] = ACTIONS(6441),
    [anon_sym_wire] = ACTIONS(6441),
    [anon_sym_tri] = ACTIONS(6441),
    [anon_sym_tri0] = ACTIONS(6441),
    [anon_sym_tri1] = ACTIONS(6441),
    [anon_sym_wand] = ACTIONS(6441),
    [anon_sym_triand] = ACTIONS(6441),
    [anon_sym_wor] = ACTIONS(6441),
    [anon_sym_trior] = ACTIONS(6441),
    [anon_sym_trireg] = ACTIONS(6441),
    [anon_sym_uwire] = ACTIONS(6441),
    [anon_sym_SEMI] = ACTIONS(6445),
    [anon_sym_extern] = ACTIONS(6441),
    [anon_sym_interface] = ACTIONS(6441),
    [anon_sym_checker] = ACTIONS(6441),
    [anon_sym_virtual] = ACTIONS(6441),
    [anon_sym_class] = ACTIONS(6441),
    [anon_sym_type] = ACTIONS(6441),
    [anon_sym_DOLLARfatal] = ACTIONS(6445),
    [anon_sym_DOLLARerror] = ACTIONS(6445),
    [anon_sym_DOLLARwarning] = ACTIONS(6445),
    [anon_sym_DOLLARinfo] = ACTIONS(6445),
    [anon_sym_default] = ACTIONS(6441),
    [anon_sym_clocking] = ACTIONS(6441),
    [anon_sym_defparam] = ACTIONS(6441),
    [anon_sym_bind] = ACTIONS(6441),
    [anon_sym_rand] = ACTIONS(6441),
    [anon_sym_const] = ACTIONS(6441),
    [anon_sym_function] = ACTIONS(6441),
    [anon_sym_static] = ACTIONS(6441),
    [anon_sym_constraint] = ACTIONS(6441),
    [anon_sym_if] = ACTIONS(6441),
    [anon_sym_else] = ACTIONS(6441),
    [anon_sym_LBRACK] = ACTIONS(6445),
    [anon_sym_localparam] = ACTIONS(6441),
    [anon_sym_parameter] = ACTIONS(6441),
    [anon_sym_var] = ACTIONS(6441),
    [anon_sym_import] = ACTIONS(6441),
    [anon_sym_export] = ACTIONS(6441),
    [anon_sym_genvar] = ACTIONS(6441),
    [anon_sym_interconnect] = ACTIONS(6441),
    [anon_sym_typedef] = ACTIONS(6441),
    [anon_sym_enum] = ACTIONS(6441),
    [anon_sym_struct] = ACTIONS(6441),
    [anon_sym_union] = ACTIONS(6441),
    [anon_sym_nettype] = ACTIONS(6441),
    [anon_sym_automatic] = ACTIONS(6441),
    [anon_sym_string] = ACTIONS(6441),
    [anon_sym_chandle] = ACTIONS(6441),
    [anon_sym_event] = ACTIONS(6441),
    [anon_sym_byte] = ACTIONS(6441),
    [anon_sym_shortint] = ACTIONS(6441),
    [anon_sym_int] = ACTIONS(6441),
    [anon_sym_longint] = ACTIONS(6441),
    [anon_sym_integer] = ACTIONS(6441),
    [anon_sym_time] = ACTIONS(6441),
    [anon_sym_bit] = ACTIONS(6441),
    [anon_sym_logic] = ACTIONS(6441),
    [anon_sym_reg] = ACTIONS(6441),
    [anon_sym_shortreal] = ACTIONS(6441),
    [anon_sym_real] = ACTIONS(6441),
    [anon_sym_realtime] = ACTIONS(6441),
    [anon_sym_supply0] = ACTIONS(6441),
    [anon_sym_supply1] = ACTIONS(6441),
    [anon_sym_signed] = ACTIONS(6441),
    [anon_sym_unsigned] = ACTIONS(6441),
    [anon_sym_task] = ACTIONS(6441),
    [anon_sym_assert] = ACTIONS(6441),
    [anon_sym_property] = ACTIONS(6441),
    [anon_sym_assume] = ACTIONS(6441),
    [anon_sym_cover] = ACTIONS(6441),
    [anon_sym_sequence] = ACTIONS(6441),
    [anon_sym_restrict] = ACTIONS(6441),
    [anon_sym_not] = ACTIONS(6441),
    [anon_sym_or] = ACTIONS(6441),
    [anon_sym_and] = ACTIONS(6441),
    [anon_sym_case] = ACTIONS(6441),
    [anon_sym_always] = ACTIONS(6441),
    [anon_sym_covergroup] = ACTIONS(6441),
    [anon_sym_let] = ACTIONS(6441),
    [anon_sym_pulldown] = ACTIONS(6441),
    [anon_sym_pullup] = ACTIONS(6441),
    [anon_sym_cmos] = ACTIONS(6441),
    [anon_sym_rcmos] = ACTIONS(6441),
    [anon_sym_bufif0] = ACTIONS(6441),
    [anon_sym_bufif1] = ACTIONS(6441),
    [anon_sym_notif0] = ACTIONS(6441),
    [anon_sym_notif1] = ACTIONS(6441),
    [anon_sym_nmos] = ACTIONS(6441),
    [anon_sym_pmos] = ACTIONS(6441),
    [anon_sym_rnmos] = ACTIONS(6441),
    [anon_sym_rpmos] = ACTIONS(6441),
    [anon_sym_nand] = ACTIONS(6441),
    [anon_sym_nor] = ACTIONS(6441),
    [anon_sym_xor] = ACTIONS(6441),
    [anon_sym_xnor] = ACTIONS(6441),
    [anon_sym_buf] = ACTIONS(6441),
    [anon_sym_tranif0] = ACTIONS(6441),
    [anon_sym_tranif1] = ACTIONS(6441),
    [anon_sym_rtranif1] = ACTIONS(6441),
    [anon_sym_rtranif0] = ACTIONS(6441),
    [anon_sym_tran] = ACTIONS(6441),
    [anon_sym_rtran] = ACTIONS(6441),
    [anon_sym_generate] = ACTIONS(6441),
    [anon_sym_endgenerate] = ACTIONS(6441),
    [anon_sym_for] = ACTIONS(6441),
    [anon_sym_initial] = ACTIONS(6441),
    [anon_sym_assign] = ACTIONS(6441),
    [anon_sym_alias] = ACTIONS(6441),
    [anon_sym_always_comb] = ACTIONS(6441),
    [anon_sym_always_latch] = ACTIONS(6441),
    [anon_sym_always_ff] = ACTIONS(6441),
    [anon_sym_final] = ACTIONS(6441),
    [anon_sym_global] = ACTIONS(6441),
    [anon_sym_LPAREN_STAR] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6445),
    [anon_sym_DOLLARunit] = ACTIONS(6445),
  },
  [4596] = {
    [sym_simple_identifier] = ACTIONS(6271),
    [anon_sym_wire] = ACTIONS(6271),
    [anon_sym_tri] = ACTIONS(6271),
    [anon_sym_tri0] = ACTIONS(6271),
    [anon_sym_tri1] = ACTIONS(6271),
    [anon_sym_wand] = ACTIONS(6271),
    [anon_sym_triand] = ACTIONS(6271),
    [anon_sym_wor] = ACTIONS(6271),
    [anon_sym_trior] = ACTIONS(6271),
    [anon_sym_trireg] = ACTIONS(6271),
    [anon_sym_uwire] = ACTIONS(6271),
    [anon_sym_SEMI] = ACTIONS(6273),
    [anon_sym_extern] = ACTIONS(6271),
    [anon_sym_interface] = ACTIONS(6271),
    [anon_sym_checker] = ACTIONS(6271),
    [anon_sym_virtual] = ACTIONS(6271),
    [anon_sym_class] = ACTIONS(6271),
    [anon_sym_type] = ACTIONS(6271),
    [anon_sym_DOLLARfatal] = ACTIONS(6273),
    [anon_sym_DOLLARerror] = ACTIONS(6273),
    [anon_sym_DOLLARwarning] = ACTIONS(6273),
    [anon_sym_DOLLARinfo] = ACTIONS(6273),
    [anon_sym_default] = ACTIONS(6271),
    [anon_sym_clocking] = ACTIONS(6271),
    [anon_sym_defparam] = ACTIONS(6271),
    [anon_sym_bind] = ACTIONS(6271),
    [anon_sym_rand] = ACTIONS(6271),
    [anon_sym_const] = ACTIONS(6271),
    [anon_sym_function] = ACTIONS(6271),
    [anon_sym_static] = ACTIONS(6271),
    [anon_sym_constraint] = ACTIONS(6271),
    [anon_sym_if] = ACTIONS(6271),
    [anon_sym_else] = ACTIONS(6271),
    [anon_sym_LBRACK] = ACTIONS(6273),
    [anon_sym_localparam] = ACTIONS(6271),
    [anon_sym_parameter] = ACTIONS(6271),
    [anon_sym_var] = ACTIONS(6271),
    [anon_sym_import] = ACTIONS(6271),
    [anon_sym_export] = ACTIONS(6271),
    [anon_sym_genvar] = ACTIONS(6271),
    [anon_sym_interconnect] = ACTIONS(6271),
    [anon_sym_typedef] = ACTIONS(6271),
    [anon_sym_enum] = ACTIONS(6271),
    [anon_sym_struct] = ACTIONS(6271),
    [anon_sym_union] = ACTIONS(6271),
    [anon_sym_nettype] = ACTIONS(6271),
    [anon_sym_automatic] = ACTIONS(6271),
    [anon_sym_string] = ACTIONS(6271),
    [anon_sym_chandle] = ACTIONS(6271),
    [anon_sym_event] = ACTIONS(6271),
    [anon_sym_byte] = ACTIONS(6271),
    [anon_sym_shortint] = ACTIONS(6271),
    [anon_sym_int] = ACTIONS(6271),
    [anon_sym_longint] = ACTIONS(6271),
    [anon_sym_integer] = ACTIONS(6271),
    [anon_sym_time] = ACTIONS(6271),
    [anon_sym_bit] = ACTIONS(6271),
    [anon_sym_logic] = ACTIONS(6271),
    [anon_sym_reg] = ACTIONS(6271),
    [anon_sym_shortreal] = ACTIONS(6271),
    [anon_sym_real] = ACTIONS(6271),
    [anon_sym_realtime] = ACTIONS(6271),
    [anon_sym_supply0] = ACTIONS(6271),
    [anon_sym_supply1] = ACTIONS(6271),
    [anon_sym_signed] = ACTIONS(6271),
    [anon_sym_unsigned] = ACTIONS(6271),
    [anon_sym_task] = ACTIONS(6271),
    [anon_sym_assert] = ACTIONS(6271),
    [anon_sym_property] = ACTIONS(6271),
    [anon_sym_assume] = ACTIONS(6271),
    [anon_sym_cover] = ACTIONS(6271),
    [anon_sym_sequence] = ACTIONS(6271),
    [anon_sym_restrict] = ACTIONS(6271),
    [anon_sym_not] = ACTIONS(6271),
    [anon_sym_or] = ACTIONS(6271),
    [anon_sym_and] = ACTIONS(6271),
    [anon_sym_case] = ACTIONS(6271),
    [anon_sym_always] = ACTIONS(6271),
    [anon_sym_covergroup] = ACTIONS(6271),
    [anon_sym_let] = ACTIONS(6271),
    [anon_sym_pulldown] = ACTIONS(6271),
    [anon_sym_pullup] = ACTIONS(6271),
    [anon_sym_cmos] = ACTIONS(6271),
    [anon_sym_rcmos] = ACTIONS(6271),
    [anon_sym_bufif0] = ACTIONS(6271),
    [anon_sym_bufif1] = ACTIONS(6271),
    [anon_sym_notif0] = ACTIONS(6271),
    [anon_sym_notif1] = ACTIONS(6271),
    [anon_sym_nmos] = ACTIONS(6271),
    [anon_sym_pmos] = ACTIONS(6271),
    [anon_sym_rnmos] = ACTIONS(6271),
    [anon_sym_rpmos] = ACTIONS(6271),
    [anon_sym_nand] = ACTIONS(6271),
    [anon_sym_nor] = ACTIONS(6271),
    [anon_sym_xor] = ACTIONS(6271),
    [anon_sym_xnor] = ACTIONS(6271),
    [anon_sym_buf] = ACTIONS(6271),
    [anon_sym_tranif0] = ACTIONS(6271),
    [anon_sym_tranif1] = ACTIONS(6271),
    [anon_sym_rtranif1] = ACTIONS(6271),
    [anon_sym_rtranif0] = ACTIONS(6271),
    [anon_sym_tran] = ACTIONS(6271),
    [anon_sym_rtran] = ACTIONS(6271),
    [anon_sym_generate] = ACTIONS(6271),
    [anon_sym_endgenerate] = ACTIONS(6271),
    [anon_sym_for] = ACTIONS(6271),
    [anon_sym_initial] = ACTIONS(6271),
    [anon_sym_assign] = ACTIONS(6271),
    [anon_sym_alias] = ACTIONS(6271),
    [anon_sym_always_comb] = ACTIONS(6271),
    [anon_sym_always_latch] = ACTIONS(6271),
    [anon_sym_always_ff] = ACTIONS(6271),
    [anon_sym_final] = ACTIONS(6271),
    [anon_sym_global] = ACTIONS(6271),
    [anon_sym_LPAREN_STAR] = ACTIONS(6273),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6273),
    [anon_sym_DOLLARunit] = ACTIONS(6273),
  },
  [4597] = {
    [sym_simple_identifier] = ACTIONS(4852),
    [anon_sym_wire] = ACTIONS(4852),
    [anon_sym_tri] = ACTIONS(4852),
    [anon_sym_tri0] = ACTIONS(4852),
    [anon_sym_tri1] = ACTIONS(4852),
    [anon_sym_wand] = ACTIONS(4852),
    [anon_sym_triand] = ACTIONS(4852),
    [anon_sym_wor] = ACTIONS(4852),
    [anon_sym_trior] = ACTIONS(4852),
    [anon_sym_trireg] = ACTIONS(4852),
    [anon_sym_uwire] = ACTIONS(4852),
    [anon_sym_SEMI] = ACTIONS(4850),
    [anon_sym_extern] = ACTIONS(4852),
    [anon_sym_interface] = ACTIONS(4852),
    [anon_sym_checker] = ACTIONS(4852),
    [anon_sym_virtual] = ACTIONS(4852),
    [anon_sym_class] = ACTIONS(4852),
    [anon_sym_type] = ACTIONS(4852),
    [anon_sym_DOLLARfatal] = ACTIONS(4850),
    [anon_sym_DOLLARerror] = ACTIONS(4850),
    [anon_sym_DOLLARwarning] = ACTIONS(4850),
    [anon_sym_DOLLARinfo] = ACTIONS(4850),
    [anon_sym_default] = ACTIONS(4852),
    [anon_sym_clocking] = ACTIONS(4852),
    [anon_sym_defparam] = ACTIONS(4852),
    [anon_sym_bind] = ACTIONS(4852),
    [anon_sym_rand] = ACTIONS(4852),
    [anon_sym_const] = ACTIONS(4852),
    [anon_sym_function] = ACTIONS(4852),
    [anon_sym_static] = ACTIONS(4852),
    [anon_sym_constraint] = ACTIONS(4852),
    [anon_sym_if] = ACTIONS(4852),
    [anon_sym_else] = ACTIONS(4852),
    [anon_sym_LBRACK] = ACTIONS(4850),
    [anon_sym_localparam] = ACTIONS(4852),
    [anon_sym_parameter] = ACTIONS(4852),
    [anon_sym_var] = ACTIONS(4852),
    [anon_sym_import] = ACTIONS(4852),
    [anon_sym_export] = ACTIONS(4852),
    [anon_sym_genvar] = ACTIONS(4852),
    [anon_sym_interconnect] = ACTIONS(4852),
    [anon_sym_typedef] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4852),
    [anon_sym_struct] = ACTIONS(4852),
    [anon_sym_union] = ACTIONS(4852),
    [anon_sym_nettype] = ACTIONS(4852),
    [anon_sym_automatic] = ACTIONS(4852),
    [anon_sym_string] = ACTIONS(4852),
    [anon_sym_chandle] = ACTIONS(4852),
    [anon_sym_event] = ACTIONS(4852),
    [anon_sym_byte] = ACTIONS(4852),
    [anon_sym_shortint] = ACTIONS(4852),
    [anon_sym_int] = ACTIONS(4852),
    [anon_sym_longint] = ACTIONS(4852),
    [anon_sym_integer] = ACTIONS(4852),
    [anon_sym_time] = ACTIONS(4852),
    [anon_sym_bit] = ACTIONS(4852),
    [anon_sym_logic] = ACTIONS(4852),
    [anon_sym_reg] = ACTIONS(4852),
    [anon_sym_shortreal] = ACTIONS(4852),
    [anon_sym_real] = ACTIONS(4852),
    [anon_sym_realtime] = ACTIONS(4852),
    [anon_sym_supply0] = ACTIONS(4852),
    [anon_sym_supply1] = ACTIONS(4852),
    [anon_sym_signed] = ACTIONS(4852),
    [anon_sym_unsigned] = ACTIONS(4852),
    [anon_sym_task] = ACTIONS(4852),
    [anon_sym_assert] = ACTIONS(4852),
    [anon_sym_property] = ACTIONS(4852),
    [anon_sym_assume] = ACTIONS(4852),
    [anon_sym_cover] = ACTIONS(4852),
    [anon_sym_sequence] = ACTIONS(4852),
    [anon_sym_restrict] = ACTIONS(4852),
    [anon_sym_not] = ACTIONS(4852),
    [anon_sym_or] = ACTIONS(4852),
    [anon_sym_and] = ACTIONS(4852),
    [anon_sym_case] = ACTIONS(4852),
    [anon_sym_always] = ACTIONS(4852),
    [anon_sym_covergroup] = ACTIONS(4852),
    [anon_sym_let] = ACTIONS(4852),
    [anon_sym_pulldown] = ACTIONS(4852),
    [anon_sym_pullup] = ACTIONS(4852),
    [anon_sym_cmos] = ACTIONS(4852),
    [anon_sym_rcmos] = ACTIONS(4852),
    [anon_sym_bufif0] = ACTIONS(4852),
    [anon_sym_bufif1] = ACTIONS(4852),
    [anon_sym_notif0] = ACTIONS(4852),
    [anon_sym_notif1] = ACTIONS(4852),
    [anon_sym_nmos] = ACTIONS(4852),
    [anon_sym_pmos] = ACTIONS(4852),
    [anon_sym_rnmos] = ACTIONS(4852),
    [anon_sym_rpmos] = ACTIONS(4852),
    [anon_sym_nand] = ACTIONS(4852),
    [anon_sym_nor] = ACTIONS(4852),
    [anon_sym_xor] = ACTIONS(4852),
    [anon_sym_xnor] = ACTIONS(4852),
    [anon_sym_buf] = ACTIONS(4852),
    [anon_sym_tranif0] = ACTIONS(4852),
    [anon_sym_tranif1] = ACTIONS(4852),
    [anon_sym_rtranif1] = ACTIONS(4852),
    [anon_sym_rtranif0] = ACTIONS(4852),
    [anon_sym_tran] = ACTIONS(4852),
    [anon_sym_rtran] = ACTIONS(4852),
    [anon_sym_generate] = ACTIONS(4852),
    [anon_sym_endgenerate] = ACTIONS(4852),
    [anon_sym_for] = ACTIONS(4852),
    [anon_sym_initial] = ACTIONS(4852),
    [anon_sym_assign] = ACTIONS(4852),
    [anon_sym_alias] = ACTIONS(4852),
    [anon_sym_always_comb] = ACTIONS(4852),
    [anon_sym_always_latch] = ACTIONS(4852),
    [anon_sym_always_ff] = ACTIONS(4852),
    [anon_sym_final] = ACTIONS(4852),
    [anon_sym_global] = ACTIONS(4852),
    [anon_sym_LPAREN_STAR] = ACTIONS(4850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4850),
    [anon_sym_DOLLARunit] = ACTIONS(4850),
  },
  [4598] = {
    [sym_simple_identifier] = ACTIONS(5770),
    [anon_sym_wire] = ACTIONS(5770),
    [anon_sym_tri] = ACTIONS(5770),
    [anon_sym_tri0] = ACTIONS(5770),
    [anon_sym_tri1] = ACTIONS(5770),
    [anon_sym_wand] = ACTIONS(5770),
    [anon_sym_triand] = ACTIONS(5770),
    [anon_sym_wor] = ACTIONS(5770),
    [anon_sym_trior] = ACTIONS(5770),
    [anon_sym_trireg] = ACTIONS(5770),
    [anon_sym_uwire] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym_extern] = ACTIONS(5770),
    [anon_sym_interface] = ACTIONS(5770),
    [anon_sym_checker] = ACTIONS(5770),
    [anon_sym_virtual] = ACTIONS(5770),
    [anon_sym_class] = ACTIONS(5770),
    [anon_sym_type] = ACTIONS(5770),
    [anon_sym_DOLLARfatal] = ACTIONS(5772),
    [anon_sym_DOLLARerror] = ACTIONS(5772),
    [anon_sym_DOLLARwarning] = ACTIONS(5772),
    [anon_sym_DOLLARinfo] = ACTIONS(5772),
    [anon_sym_default] = ACTIONS(5770),
    [anon_sym_clocking] = ACTIONS(5770),
    [anon_sym_defparam] = ACTIONS(5770),
    [anon_sym_bind] = ACTIONS(5770),
    [anon_sym_rand] = ACTIONS(5770),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_function] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5770),
    [anon_sym_constraint] = ACTIONS(5770),
    [anon_sym_if] = ACTIONS(5770),
    [anon_sym_else] = ACTIONS(5770),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_localparam] = ACTIONS(5770),
    [anon_sym_parameter] = ACTIONS(5770),
    [anon_sym_var] = ACTIONS(5770),
    [anon_sym_import] = ACTIONS(5770),
    [anon_sym_export] = ACTIONS(5770),
    [anon_sym_genvar] = ACTIONS(5770),
    [anon_sym_interconnect] = ACTIONS(5770),
    [anon_sym_typedef] = ACTIONS(5770),
    [anon_sym_enum] = ACTIONS(5770),
    [anon_sym_struct] = ACTIONS(5770),
    [anon_sym_union] = ACTIONS(5770),
    [anon_sym_nettype] = ACTIONS(5770),
    [anon_sym_automatic] = ACTIONS(5770),
    [anon_sym_string] = ACTIONS(5770),
    [anon_sym_chandle] = ACTIONS(5770),
    [anon_sym_event] = ACTIONS(5770),
    [anon_sym_byte] = ACTIONS(5770),
    [anon_sym_shortint] = ACTIONS(5770),
    [anon_sym_int] = ACTIONS(5770),
    [anon_sym_longint] = ACTIONS(5770),
    [anon_sym_integer] = ACTIONS(5770),
    [anon_sym_time] = ACTIONS(5770),
    [anon_sym_bit] = ACTIONS(5770),
    [anon_sym_logic] = ACTIONS(5770),
    [anon_sym_reg] = ACTIONS(5770),
    [anon_sym_shortreal] = ACTIONS(5770),
    [anon_sym_real] = ACTIONS(5770),
    [anon_sym_realtime] = ACTIONS(5770),
    [anon_sym_supply0] = ACTIONS(5770),
    [anon_sym_supply1] = ACTIONS(5770),
    [anon_sym_signed] = ACTIONS(5770),
    [anon_sym_unsigned] = ACTIONS(5770),
    [anon_sym_task] = ACTIONS(5770),
    [anon_sym_assert] = ACTIONS(5770),
    [anon_sym_property] = ACTIONS(5770),
    [anon_sym_assume] = ACTIONS(5770),
    [anon_sym_cover] = ACTIONS(5770),
    [anon_sym_sequence] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym_not] = ACTIONS(5770),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_case] = ACTIONS(5770),
    [anon_sym_always] = ACTIONS(5770),
    [anon_sym_covergroup] = ACTIONS(5770),
    [anon_sym_end] = ACTIONS(5770),
    [anon_sym_let] = ACTIONS(5770),
    [anon_sym_pulldown] = ACTIONS(5770),
    [anon_sym_pullup] = ACTIONS(5770),
    [anon_sym_cmos] = ACTIONS(5770),
    [anon_sym_rcmos] = ACTIONS(5770),
    [anon_sym_bufif0] = ACTIONS(5770),
    [anon_sym_bufif1] = ACTIONS(5770),
    [anon_sym_notif0] = ACTIONS(5770),
    [anon_sym_notif1] = ACTIONS(5770),
    [anon_sym_nmos] = ACTIONS(5770),
    [anon_sym_pmos] = ACTIONS(5770),
    [anon_sym_rnmos] = ACTIONS(5770),
    [anon_sym_rpmos] = ACTIONS(5770),
    [anon_sym_nand] = ACTIONS(5770),
    [anon_sym_nor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_xnor] = ACTIONS(5770),
    [anon_sym_buf] = ACTIONS(5770),
    [anon_sym_tranif0] = ACTIONS(5770),
    [anon_sym_tranif1] = ACTIONS(5770),
    [anon_sym_rtranif1] = ACTIONS(5770),
    [anon_sym_rtranif0] = ACTIONS(5770),
    [anon_sym_tran] = ACTIONS(5770),
    [anon_sym_rtran] = ACTIONS(5770),
    [anon_sym_generate] = ACTIONS(5770),
    [anon_sym_for] = ACTIONS(5770),
    [anon_sym_initial] = ACTIONS(5770),
    [anon_sym_assign] = ACTIONS(5770),
    [anon_sym_alias] = ACTIONS(5770),
    [anon_sym_always_comb] = ACTIONS(5770),
    [anon_sym_always_latch] = ACTIONS(5770),
    [anon_sym_always_ff] = ACTIONS(5770),
    [anon_sym_final] = ACTIONS(5770),
    [anon_sym_global] = ACTIONS(5770),
    [anon_sym_LPAREN_STAR] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5772),
    [anon_sym_DOLLARunit] = ACTIONS(5772),
  },
  [4599] = {
    [sym_simple_identifier] = ACTIONS(4856),
    [anon_sym_wire] = ACTIONS(4856),
    [anon_sym_tri] = ACTIONS(4856),
    [anon_sym_tri0] = ACTIONS(4856),
    [anon_sym_tri1] = ACTIONS(4856),
    [anon_sym_wand] = ACTIONS(4856),
    [anon_sym_triand] = ACTIONS(4856),
    [anon_sym_wor] = ACTIONS(4856),
    [anon_sym_trior] = ACTIONS(4856),
    [anon_sym_trireg] = ACTIONS(4856),
    [anon_sym_uwire] = ACTIONS(4856),
    [anon_sym_SEMI] = ACTIONS(4854),
    [anon_sym_extern] = ACTIONS(4856),
    [anon_sym_interface] = ACTIONS(4856),
    [anon_sym_checker] = ACTIONS(4856),
    [anon_sym_virtual] = ACTIONS(4856),
    [anon_sym_class] = ACTIONS(4856),
    [anon_sym_type] = ACTIONS(4856),
    [anon_sym_DOLLARfatal] = ACTIONS(4854),
    [anon_sym_DOLLARerror] = ACTIONS(4854),
    [anon_sym_DOLLARwarning] = ACTIONS(4854),
    [anon_sym_DOLLARinfo] = ACTIONS(4854),
    [anon_sym_default] = ACTIONS(4856),
    [anon_sym_clocking] = ACTIONS(4856),
    [anon_sym_defparam] = ACTIONS(4856),
    [anon_sym_bind] = ACTIONS(4856),
    [anon_sym_rand] = ACTIONS(4856),
    [anon_sym_const] = ACTIONS(4856),
    [anon_sym_function] = ACTIONS(4856),
    [anon_sym_static] = ACTIONS(4856),
    [anon_sym_constraint] = ACTIONS(4856),
    [anon_sym_if] = ACTIONS(4856),
    [anon_sym_else] = ACTIONS(4856),
    [anon_sym_LBRACK] = ACTIONS(4854),
    [anon_sym_localparam] = ACTIONS(4856),
    [anon_sym_parameter] = ACTIONS(4856),
    [anon_sym_var] = ACTIONS(4856),
    [anon_sym_import] = ACTIONS(4856),
    [anon_sym_export] = ACTIONS(4856),
    [anon_sym_genvar] = ACTIONS(4856),
    [anon_sym_interconnect] = ACTIONS(4856),
    [anon_sym_typedef] = ACTIONS(4856),
    [anon_sym_enum] = ACTIONS(4856),
    [anon_sym_struct] = ACTIONS(4856),
    [anon_sym_union] = ACTIONS(4856),
    [anon_sym_nettype] = ACTIONS(4856),
    [anon_sym_automatic] = ACTIONS(4856),
    [anon_sym_string] = ACTIONS(4856),
    [anon_sym_chandle] = ACTIONS(4856),
    [anon_sym_event] = ACTIONS(4856),
    [anon_sym_byte] = ACTIONS(4856),
    [anon_sym_shortint] = ACTIONS(4856),
    [anon_sym_int] = ACTIONS(4856),
    [anon_sym_longint] = ACTIONS(4856),
    [anon_sym_integer] = ACTIONS(4856),
    [anon_sym_time] = ACTIONS(4856),
    [anon_sym_bit] = ACTIONS(4856),
    [anon_sym_logic] = ACTIONS(4856),
    [anon_sym_reg] = ACTIONS(4856),
    [anon_sym_shortreal] = ACTIONS(4856),
    [anon_sym_real] = ACTIONS(4856),
    [anon_sym_realtime] = ACTIONS(4856),
    [anon_sym_supply0] = ACTIONS(4856),
    [anon_sym_supply1] = ACTIONS(4856),
    [anon_sym_signed] = ACTIONS(4856),
    [anon_sym_unsigned] = ACTIONS(4856),
    [anon_sym_task] = ACTIONS(4856),
    [anon_sym_assert] = ACTIONS(4856),
    [anon_sym_property] = ACTIONS(4856),
    [anon_sym_assume] = ACTIONS(4856),
    [anon_sym_cover] = ACTIONS(4856),
    [anon_sym_sequence] = ACTIONS(4856),
    [anon_sym_restrict] = ACTIONS(4856),
    [anon_sym_not] = ACTIONS(4856),
    [anon_sym_or] = ACTIONS(4856),
    [anon_sym_and] = ACTIONS(4856),
    [anon_sym_case] = ACTIONS(4856),
    [anon_sym_always] = ACTIONS(4856),
    [anon_sym_covergroup] = ACTIONS(4856),
    [anon_sym_let] = ACTIONS(4856),
    [anon_sym_pulldown] = ACTIONS(4856),
    [anon_sym_pullup] = ACTIONS(4856),
    [anon_sym_cmos] = ACTIONS(4856),
    [anon_sym_rcmos] = ACTIONS(4856),
    [anon_sym_bufif0] = ACTIONS(4856),
    [anon_sym_bufif1] = ACTIONS(4856),
    [anon_sym_notif0] = ACTIONS(4856),
    [anon_sym_notif1] = ACTIONS(4856),
    [anon_sym_nmos] = ACTIONS(4856),
    [anon_sym_pmos] = ACTIONS(4856),
    [anon_sym_rnmos] = ACTIONS(4856),
    [anon_sym_rpmos] = ACTIONS(4856),
    [anon_sym_nand] = ACTIONS(4856),
    [anon_sym_nor] = ACTIONS(4856),
    [anon_sym_xor] = ACTIONS(4856),
    [anon_sym_xnor] = ACTIONS(4856),
    [anon_sym_buf] = ACTIONS(4856),
    [anon_sym_tranif0] = ACTIONS(4856),
    [anon_sym_tranif1] = ACTIONS(4856),
    [anon_sym_rtranif1] = ACTIONS(4856),
    [anon_sym_rtranif0] = ACTIONS(4856),
    [anon_sym_tran] = ACTIONS(4856),
    [anon_sym_rtran] = ACTIONS(4856),
    [anon_sym_generate] = ACTIONS(4856),
    [anon_sym_endgenerate] = ACTIONS(4856),
    [anon_sym_for] = ACTIONS(4856),
    [anon_sym_initial] = ACTIONS(4856),
    [anon_sym_assign] = ACTIONS(4856),
    [anon_sym_alias] = ACTIONS(4856),
    [anon_sym_always_comb] = ACTIONS(4856),
    [anon_sym_always_latch] = ACTIONS(4856),
    [anon_sym_always_ff] = ACTIONS(4856),
    [anon_sym_final] = ACTIONS(4856),
    [anon_sym_global] = ACTIONS(4856),
    [anon_sym_LPAREN_STAR] = ACTIONS(4854),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4854),
    [anon_sym_DOLLARunit] = ACTIONS(4854),
  },
  [4600] = {
    [sym_simple_identifier] = ACTIONS(4816),
    [anon_sym_wire] = ACTIONS(4816),
    [anon_sym_tri] = ACTIONS(4816),
    [anon_sym_tri0] = ACTIONS(4816),
    [anon_sym_tri1] = ACTIONS(4816),
    [anon_sym_wand] = ACTIONS(4816),
    [anon_sym_triand] = ACTIONS(4816),
    [anon_sym_wor] = ACTIONS(4816),
    [anon_sym_trior] = ACTIONS(4816),
    [anon_sym_trireg] = ACTIONS(4816),
    [anon_sym_uwire] = ACTIONS(4816),
    [anon_sym_SEMI] = ACTIONS(4814),
    [anon_sym_extern] = ACTIONS(4816),
    [anon_sym_interface] = ACTIONS(4816),
    [anon_sym_checker] = ACTIONS(4816),
    [anon_sym_virtual] = ACTIONS(4816),
    [anon_sym_class] = ACTIONS(4816),
    [anon_sym_type] = ACTIONS(4816),
    [anon_sym_DOLLARfatal] = ACTIONS(4814),
    [anon_sym_DOLLARerror] = ACTIONS(4814),
    [anon_sym_DOLLARwarning] = ACTIONS(4814),
    [anon_sym_DOLLARinfo] = ACTIONS(4814),
    [anon_sym_default] = ACTIONS(4816),
    [anon_sym_clocking] = ACTIONS(4816),
    [anon_sym_defparam] = ACTIONS(4816),
    [anon_sym_bind] = ACTIONS(4816),
    [anon_sym_rand] = ACTIONS(4816),
    [anon_sym_const] = ACTIONS(4816),
    [anon_sym_function] = ACTIONS(4816),
    [anon_sym_static] = ACTIONS(4816),
    [anon_sym_constraint] = ACTIONS(4816),
    [anon_sym_if] = ACTIONS(4816),
    [anon_sym_else] = ACTIONS(4816),
    [anon_sym_LBRACK] = ACTIONS(4814),
    [anon_sym_localparam] = ACTIONS(4816),
    [anon_sym_parameter] = ACTIONS(4816),
    [anon_sym_var] = ACTIONS(4816),
    [anon_sym_import] = ACTIONS(4816),
    [anon_sym_export] = ACTIONS(4816),
    [anon_sym_genvar] = ACTIONS(4816),
    [anon_sym_interconnect] = ACTIONS(4816),
    [anon_sym_typedef] = ACTIONS(4816),
    [anon_sym_enum] = ACTIONS(4816),
    [anon_sym_struct] = ACTIONS(4816),
    [anon_sym_union] = ACTIONS(4816),
    [anon_sym_nettype] = ACTIONS(4816),
    [anon_sym_automatic] = ACTIONS(4816),
    [anon_sym_string] = ACTIONS(4816),
    [anon_sym_chandle] = ACTIONS(4816),
    [anon_sym_event] = ACTIONS(4816),
    [anon_sym_byte] = ACTIONS(4816),
    [anon_sym_shortint] = ACTIONS(4816),
    [anon_sym_int] = ACTIONS(4816),
    [anon_sym_longint] = ACTIONS(4816),
    [anon_sym_integer] = ACTIONS(4816),
    [anon_sym_time] = ACTIONS(4816),
    [anon_sym_bit] = ACTIONS(4816),
    [anon_sym_logic] = ACTIONS(4816),
    [anon_sym_reg] = ACTIONS(4816),
    [anon_sym_shortreal] = ACTIONS(4816),
    [anon_sym_real] = ACTIONS(4816),
    [anon_sym_realtime] = ACTIONS(4816),
    [anon_sym_supply0] = ACTIONS(4816),
    [anon_sym_supply1] = ACTIONS(4816),
    [anon_sym_signed] = ACTIONS(4816),
    [anon_sym_unsigned] = ACTIONS(4816),
    [anon_sym_task] = ACTIONS(4816),
    [anon_sym_assert] = ACTIONS(4816),
    [anon_sym_property] = ACTIONS(4816),
    [anon_sym_assume] = ACTIONS(4816),
    [anon_sym_cover] = ACTIONS(4816),
    [anon_sym_sequence] = ACTIONS(4816),
    [anon_sym_restrict] = ACTIONS(4816),
    [anon_sym_not] = ACTIONS(4816),
    [anon_sym_or] = ACTIONS(4816),
    [anon_sym_and] = ACTIONS(4816),
    [anon_sym_case] = ACTIONS(4816),
    [anon_sym_always] = ACTIONS(4816),
    [anon_sym_covergroup] = ACTIONS(4816),
    [anon_sym_end] = ACTIONS(4816),
    [anon_sym_let] = ACTIONS(4816),
    [anon_sym_pulldown] = ACTIONS(4816),
    [anon_sym_pullup] = ACTIONS(4816),
    [anon_sym_cmos] = ACTIONS(4816),
    [anon_sym_rcmos] = ACTIONS(4816),
    [anon_sym_bufif0] = ACTIONS(4816),
    [anon_sym_bufif1] = ACTIONS(4816),
    [anon_sym_notif0] = ACTIONS(4816),
    [anon_sym_notif1] = ACTIONS(4816),
    [anon_sym_nmos] = ACTIONS(4816),
    [anon_sym_pmos] = ACTIONS(4816),
    [anon_sym_rnmos] = ACTIONS(4816),
    [anon_sym_rpmos] = ACTIONS(4816),
    [anon_sym_nand] = ACTIONS(4816),
    [anon_sym_nor] = ACTIONS(4816),
    [anon_sym_xor] = ACTIONS(4816),
    [anon_sym_xnor] = ACTIONS(4816),
    [anon_sym_buf] = ACTIONS(4816),
    [anon_sym_tranif0] = ACTIONS(4816),
    [anon_sym_tranif1] = ACTIONS(4816),
    [anon_sym_rtranif1] = ACTIONS(4816),
    [anon_sym_rtranif0] = ACTIONS(4816),
    [anon_sym_tran] = ACTIONS(4816),
    [anon_sym_rtran] = ACTIONS(4816),
    [anon_sym_generate] = ACTIONS(4816),
    [anon_sym_for] = ACTIONS(4816),
    [anon_sym_initial] = ACTIONS(4816),
    [anon_sym_assign] = ACTIONS(4816),
    [anon_sym_alias] = ACTIONS(4816),
    [anon_sym_always_comb] = ACTIONS(4816),
    [anon_sym_always_latch] = ACTIONS(4816),
    [anon_sym_always_ff] = ACTIONS(4816),
    [anon_sym_final] = ACTIONS(4816),
    [anon_sym_global] = ACTIONS(4816),
    [anon_sym_LPAREN_STAR] = ACTIONS(4814),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4814),
    [anon_sym_DOLLARunit] = ACTIONS(4814),
  },
  [4601] = {
    [sym_simple_identifier] = ACTIONS(4142),
    [anon_sym_wire] = ACTIONS(4142),
    [anon_sym_tri] = ACTIONS(4142),
    [anon_sym_tri0] = ACTIONS(4142),
    [anon_sym_tri1] = ACTIONS(4142),
    [anon_sym_wand] = ACTIONS(4142),
    [anon_sym_triand] = ACTIONS(4142),
    [anon_sym_wor] = ACTIONS(4142),
    [anon_sym_trior] = ACTIONS(4142),
    [anon_sym_trireg] = ACTIONS(4142),
    [anon_sym_uwire] = ACTIONS(4142),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_extern] = ACTIONS(4142),
    [anon_sym_interface] = ACTIONS(4142),
    [anon_sym_checker] = ACTIONS(4142),
    [anon_sym_virtual] = ACTIONS(4142),
    [anon_sym_class] = ACTIONS(4142),
    [anon_sym_type] = ACTIONS(4142),
    [anon_sym_DOLLARfatal] = ACTIONS(4140),
    [anon_sym_DOLLARerror] = ACTIONS(4140),
    [anon_sym_DOLLARwarning] = ACTIONS(4140),
    [anon_sym_DOLLARinfo] = ACTIONS(4140),
    [anon_sym_default] = ACTIONS(4142),
    [anon_sym_clocking] = ACTIONS(4142),
    [anon_sym_defparam] = ACTIONS(4142),
    [anon_sym_bind] = ACTIONS(4142),
    [anon_sym_rand] = ACTIONS(4142),
    [anon_sym_const] = ACTIONS(4142),
    [anon_sym_function] = ACTIONS(4142),
    [anon_sym_static] = ACTIONS(4142),
    [anon_sym_constraint] = ACTIONS(4142),
    [anon_sym_if] = ACTIONS(4142),
    [anon_sym_else] = ACTIONS(4142),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_localparam] = ACTIONS(4142),
    [anon_sym_parameter] = ACTIONS(4142),
    [anon_sym_var] = ACTIONS(4142),
    [anon_sym_import] = ACTIONS(4142),
    [anon_sym_export] = ACTIONS(4142),
    [anon_sym_genvar] = ACTIONS(4142),
    [anon_sym_interconnect] = ACTIONS(4142),
    [anon_sym_typedef] = ACTIONS(4142),
    [anon_sym_enum] = ACTIONS(4142),
    [anon_sym_struct] = ACTIONS(4142),
    [anon_sym_union] = ACTIONS(4142),
    [anon_sym_nettype] = ACTIONS(4142),
    [anon_sym_automatic] = ACTIONS(4142),
    [anon_sym_string] = ACTIONS(4142),
    [anon_sym_chandle] = ACTIONS(4142),
    [anon_sym_event] = ACTIONS(4142),
    [anon_sym_byte] = ACTIONS(4142),
    [anon_sym_shortint] = ACTIONS(4142),
    [anon_sym_int] = ACTIONS(4142),
    [anon_sym_longint] = ACTIONS(4142),
    [anon_sym_integer] = ACTIONS(4142),
    [anon_sym_time] = ACTIONS(4142),
    [anon_sym_bit] = ACTIONS(4142),
    [anon_sym_logic] = ACTIONS(4142),
    [anon_sym_reg] = ACTIONS(4142),
    [anon_sym_shortreal] = ACTIONS(4142),
    [anon_sym_real] = ACTIONS(4142),
    [anon_sym_realtime] = ACTIONS(4142),
    [anon_sym_supply0] = ACTIONS(4142),
    [anon_sym_supply1] = ACTIONS(4142),
    [anon_sym_signed] = ACTIONS(4142),
    [anon_sym_unsigned] = ACTIONS(4142),
    [anon_sym_task] = ACTIONS(4142),
    [anon_sym_assert] = ACTIONS(4142),
    [anon_sym_property] = ACTIONS(4142),
    [anon_sym_assume] = ACTIONS(4142),
    [anon_sym_cover] = ACTIONS(4142),
    [anon_sym_sequence] = ACTIONS(4142),
    [anon_sym_restrict] = ACTIONS(4142),
    [anon_sym_not] = ACTIONS(4142),
    [anon_sym_or] = ACTIONS(4142),
    [anon_sym_and] = ACTIONS(4142),
    [anon_sym_case] = ACTIONS(4142),
    [anon_sym_always] = ACTIONS(4142),
    [anon_sym_covergroup] = ACTIONS(4142),
    [anon_sym_let] = ACTIONS(4142),
    [anon_sym_pulldown] = ACTIONS(4142),
    [anon_sym_pullup] = ACTIONS(4142),
    [anon_sym_cmos] = ACTIONS(4142),
    [anon_sym_rcmos] = ACTIONS(4142),
    [anon_sym_bufif0] = ACTIONS(4142),
    [anon_sym_bufif1] = ACTIONS(4142),
    [anon_sym_notif0] = ACTIONS(4142),
    [anon_sym_notif1] = ACTIONS(4142),
    [anon_sym_nmos] = ACTIONS(4142),
    [anon_sym_pmos] = ACTIONS(4142),
    [anon_sym_rnmos] = ACTIONS(4142),
    [anon_sym_rpmos] = ACTIONS(4142),
    [anon_sym_nand] = ACTIONS(4142),
    [anon_sym_nor] = ACTIONS(4142),
    [anon_sym_xor] = ACTIONS(4142),
    [anon_sym_xnor] = ACTIONS(4142),
    [anon_sym_buf] = ACTIONS(4142),
    [anon_sym_tranif0] = ACTIONS(4142),
    [anon_sym_tranif1] = ACTIONS(4142),
    [anon_sym_rtranif1] = ACTIONS(4142),
    [anon_sym_rtranif0] = ACTIONS(4142),
    [anon_sym_tran] = ACTIONS(4142),
    [anon_sym_rtran] = ACTIONS(4142),
    [anon_sym_generate] = ACTIONS(4142),
    [anon_sym_endgenerate] = ACTIONS(4142),
    [anon_sym_for] = ACTIONS(4142),
    [anon_sym_initial] = ACTIONS(4142),
    [anon_sym_assign] = ACTIONS(4142),
    [anon_sym_alias] = ACTIONS(4142),
    [anon_sym_always_comb] = ACTIONS(4142),
    [anon_sym_always_latch] = ACTIONS(4142),
    [anon_sym_always_ff] = ACTIONS(4142),
    [anon_sym_final] = ACTIONS(4142),
    [anon_sym_global] = ACTIONS(4142),
    [anon_sym_LPAREN_STAR] = ACTIONS(4140),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4140),
    [anon_sym_DOLLARunit] = ACTIONS(4140),
  },
  [4602] = {
    [sym_simple_identifier] = ACTIONS(4612),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_rand] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_end] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [4603] = {
    [sym_simple_identifier] = ACTIONS(6177),
    [anon_sym_wire] = ACTIONS(6177),
    [anon_sym_tri] = ACTIONS(6177),
    [anon_sym_tri0] = ACTIONS(6177),
    [anon_sym_tri1] = ACTIONS(6177),
    [anon_sym_wand] = ACTIONS(6177),
    [anon_sym_triand] = ACTIONS(6177),
    [anon_sym_wor] = ACTIONS(6177),
    [anon_sym_trior] = ACTIONS(6177),
    [anon_sym_trireg] = ACTIONS(6177),
    [anon_sym_uwire] = ACTIONS(6177),
    [anon_sym_SEMI] = ACTIONS(6179),
    [anon_sym_extern] = ACTIONS(6177),
    [anon_sym_interface] = ACTIONS(6177),
    [anon_sym_checker] = ACTIONS(6177),
    [anon_sym_virtual] = ACTIONS(6177),
    [anon_sym_class] = ACTIONS(6177),
    [anon_sym_type] = ACTIONS(6177),
    [anon_sym_DOLLARfatal] = ACTIONS(6179),
    [anon_sym_DOLLARerror] = ACTIONS(6179),
    [anon_sym_DOLLARwarning] = ACTIONS(6179),
    [anon_sym_DOLLARinfo] = ACTIONS(6179),
    [anon_sym_default] = ACTIONS(6177),
    [anon_sym_clocking] = ACTIONS(6177),
    [anon_sym_defparam] = ACTIONS(6177),
    [anon_sym_bind] = ACTIONS(6177),
    [anon_sym_rand] = ACTIONS(6177),
    [anon_sym_const] = ACTIONS(6177),
    [anon_sym_function] = ACTIONS(6177),
    [anon_sym_static] = ACTIONS(6177),
    [anon_sym_constraint] = ACTIONS(6177),
    [anon_sym_if] = ACTIONS(6177),
    [anon_sym_else] = ACTIONS(6177),
    [anon_sym_LBRACK] = ACTIONS(6179),
    [anon_sym_localparam] = ACTIONS(6177),
    [anon_sym_parameter] = ACTIONS(6177),
    [anon_sym_var] = ACTIONS(6177),
    [anon_sym_import] = ACTIONS(6177),
    [anon_sym_export] = ACTIONS(6177),
    [anon_sym_genvar] = ACTIONS(6177),
    [anon_sym_interconnect] = ACTIONS(6177),
    [anon_sym_typedef] = ACTIONS(6177),
    [anon_sym_enum] = ACTIONS(6177),
    [anon_sym_struct] = ACTIONS(6177),
    [anon_sym_union] = ACTIONS(6177),
    [anon_sym_nettype] = ACTIONS(6177),
    [anon_sym_automatic] = ACTIONS(6177),
    [anon_sym_string] = ACTIONS(6177),
    [anon_sym_chandle] = ACTIONS(6177),
    [anon_sym_event] = ACTIONS(6177),
    [anon_sym_byte] = ACTIONS(6177),
    [anon_sym_shortint] = ACTIONS(6177),
    [anon_sym_int] = ACTIONS(6177),
    [anon_sym_longint] = ACTIONS(6177),
    [anon_sym_integer] = ACTIONS(6177),
    [anon_sym_time] = ACTIONS(6177),
    [anon_sym_bit] = ACTIONS(6177),
    [anon_sym_logic] = ACTIONS(6177),
    [anon_sym_reg] = ACTIONS(6177),
    [anon_sym_shortreal] = ACTIONS(6177),
    [anon_sym_real] = ACTIONS(6177),
    [anon_sym_realtime] = ACTIONS(6177),
    [anon_sym_supply0] = ACTIONS(6177),
    [anon_sym_supply1] = ACTIONS(6177),
    [anon_sym_signed] = ACTIONS(6177),
    [anon_sym_unsigned] = ACTIONS(6177),
    [anon_sym_task] = ACTIONS(6177),
    [anon_sym_assert] = ACTIONS(6177),
    [anon_sym_property] = ACTIONS(6177),
    [anon_sym_assume] = ACTIONS(6177),
    [anon_sym_cover] = ACTIONS(6177),
    [anon_sym_sequence] = ACTIONS(6177),
    [anon_sym_restrict] = ACTIONS(6177),
    [anon_sym_not] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6177),
    [anon_sym_and] = ACTIONS(6177),
    [anon_sym_case] = ACTIONS(6177),
    [anon_sym_always] = ACTIONS(6177),
    [anon_sym_covergroup] = ACTIONS(6177),
    [anon_sym_end] = ACTIONS(6177),
    [anon_sym_let] = ACTIONS(6177),
    [anon_sym_pulldown] = ACTIONS(6177),
    [anon_sym_pullup] = ACTIONS(6177),
    [anon_sym_cmos] = ACTIONS(6177),
    [anon_sym_rcmos] = ACTIONS(6177),
    [anon_sym_bufif0] = ACTIONS(6177),
    [anon_sym_bufif1] = ACTIONS(6177),
    [anon_sym_notif0] = ACTIONS(6177),
    [anon_sym_notif1] = ACTIONS(6177),
    [anon_sym_nmos] = ACTIONS(6177),
    [anon_sym_pmos] = ACTIONS(6177),
    [anon_sym_rnmos] = ACTIONS(6177),
    [anon_sym_rpmos] = ACTIONS(6177),
    [anon_sym_nand] = ACTIONS(6177),
    [anon_sym_nor] = ACTIONS(6177),
    [anon_sym_xor] = ACTIONS(6177),
    [anon_sym_xnor] = ACTIONS(6177),
    [anon_sym_buf] = ACTIONS(6177),
    [anon_sym_tranif0] = ACTIONS(6177),
    [anon_sym_tranif1] = ACTIONS(6177),
    [anon_sym_rtranif1] = ACTIONS(6177),
    [anon_sym_rtranif0] = ACTIONS(6177),
    [anon_sym_tran] = ACTIONS(6177),
    [anon_sym_rtran] = ACTIONS(6177),
    [anon_sym_generate] = ACTIONS(6177),
    [anon_sym_for] = ACTIONS(6177),
    [anon_sym_initial] = ACTIONS(6177),
    [anon_sym_assign] = ACTIONS(6177),
    [anon_sym_alias] = ACTIONS(6177),
    [anon_sym_always_comb] = ACTIONS(6177),
    [anon_sym_always_latch] = ACTIONS(6177),
    [anon_sym_always_ff] = ACTIONS(6177),
    [anon_sym_final] = ACTIONS(6177),
    [anon_sym_global] = ACTIONS(6177),
    [anon_sym_LPAREN_STAR] = ACTIONS(6179),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6179),
    [anon_sym_DOLLARunit] = ACTIONS(6179),
  },
  [4604] = {
    [sym_simple_identifier] = ACTIONS(5348),
    [anon_sym_wire] = ACTIONS(5348),
    [anon_sym_tri] = ACTIONS(5348),
    [anon_sym_tri0] = ACTIONS(5348),
    [anon_sym_tri1] = ACTIONS(5348),
    [anon_sym_wand] = ACTIONS(5348),
    [anon_sym_triand] = ACTIONS(5348),
    [anon_sym_wor] = ACTIONS(5348),
    [anon_sym_trior] = ACTIONS(5348),
    [anon_sym_trireg] = ACTIONS(5348),
    [anon_sym_uwire] = ACTIONS(5348),
    [anon_sym_SEMI] = ACTIONS(5346),
    [anon_sym_extern] = ACTIONS(5348),
    [anon_sym_interface] = ACTIONS(5348),
    [anon_sym_checker] = ACTIONS(5348),
    [anon_sym_virtual] = ACTIONS(5348),
    [anon_sym_class] = ACTIONS(5348),
    [anon_sym_type] = ACTIONS(5348),
    [anon_sym_DOLLARfatal] = ACTIONS(5346),
    [anon_sym_DOLLARerror] = ACTIONS(5346),
    [anon_sym_DOLLARwarning] = ACTIONS(5346),
    [anon_sym_DOLLARinfo] = ACTIONS(5346),
    [anon_sym_default] = ACTIONS(5348),
    [anon_sym_clocking] = ACTIONS(5348),
    [anon_sym_defparam] = ACTIONS(5348),
    [anon_sym_bind] = ACTIONS(5348),
    [anon_sym_rand] = ACTIONS(5348),
    [anon_sym_const] = ACTIONS(5348),
    [anon_sym_function] = ACTIONS(5348),
    [anon_sym_static] = ACTIONS(5348),
    [anon_sym_constraint] = ACTIONS(5348),
    [anon_sym_if] = ACTIONS(5348),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_LBRACK] = ACTIONS(5346),
    [anon_sym_localparam] = ACTIONS(5348),
    [anon_sym_parameter] = ACTIONS(5348),
    [anon_sym_var] = ACTIONS(5348),
    [anon_sym_import] = ACTIONS(5348),
    [anon_sym_export] = ACTIONS(5348),
    [anon_sym_genvar] = ACTIONS(5348),
    [anon_sym_interconnect] = ACTIONS(5348),
    [anon_sym_typedef] = ACTIONS(5348),
    [anon_sym_enum] = ACTIONS(5348),
    [anon_sym_struct] = ACTIONS(5348),
    [anon_sym_union] = ACTIONS(5348),
    [anon_sym_nettype] = ACTIONS(5348),
    [anon_sym_automatic] = ACTIONS(5348),
    [anon_sym_string] = ACTIONS(5348),
    [anon_sym_chandle] = ACTIONS(5348),
    [anon_sym_event] = ACTIONS(5348),
    [anon_sym_byte] = ACTIONS(5348),
    [anon_sym_shortint] = ACTIONS(5348),
    [anon_sym_int] = ACTIONS(5348),
    [anon_sym_longint] = ACTIONS(5348),
    [anon_sym_integer] = ACTIONS(5348),
    [anon_sym_time] = ACTIONS(5348),
    [anon_sym_bit] = ACTIONS(5348),
    [anon_sym_logic] = ACTIONS(5348),
    [anon_sym_reg] = ACTIONS(5348),
    [anon_sym_shortreal] = ACTIONS(5348),
    [anon_sym_real] = ACTIONS(5348),
    [anon_sym_realtime] = ACTIONS(5348),
    [anon_sym_supply0] = ACTIONS(5348),
    [anon_sym_supply1] = ACTIONS(5348),
    [anon_sym_signed] = ACTIONS(5348),
    [anon_sym_unsigned] = ACTIONS(5348),
    [anon_sym_task] = ACTIONS(5348),
    [anon_sym_assert] = ACTIONS(5348),
    [anon_sym_property] = ACTIONS(5348),
    [anon_sym_assume] = ACTIONS(5348),
    [anon_sym_cover] = ACTIONS(5348),
    [anon_sym_sequence] = ACTIONS(5348),
    [anon_sym_restrict] = ACTIONS(5348),
    [anon_sym_not] = ACTIONS(5348),
    [anon_sym_or] = ACTIONS(5348),
    [anon_sym_and] = ACTIONS(5348),
    [anon_sym_case] = ACTIONS(5348),
    [anon_sym_always] = ACTIONS(5348),
    [anon_sym_covergroup] = ACTIONS(5348),
    [anon_sym_end] = ACTIONS(5348),
    [anon_sym_let] = ACTIONS(5348),
    [anon_sym_pulldown] = ACTIONS(5348),
    [anon_sym_pullup] = ACTIONS(5348),
    [anon_sym_cmos] = ACTIONS(5348),
    [anon_sym_rcmos] = ACTIONS(5348),
    [anon_sym_bufif0] = ACTIONS(5348),
    [anon_sym_bufif1] = ACTIONS(5348),
    [anon_sym_notif0] = ACTIONS(5348),
    [anon_sym_notif1] = ACTIONS(5348),
    [anon_sym_nmos] = ACTIONS(5348),
    [anon_sym_pmos] = ACTIONS(5348),
    [anon_sym_rnmos] = ACTIONS(5348),
    [anon_sym_rpmos] = ACTIONS(5348),
    [anon_sym_nand] = ACTIONS(5348),
    [anon_sym_nor] = ACTIONS(5348),
    [anon_sym_xor] = ACTIONS(5348),
    [anon_sym_xnor] = ACTIONS(5348),
    [anon_sym_buf] = ACTIONS(5348),
    [anon_sym_tranif0] = ACTIONS(5348),
    [anon_sym_tranif1] = ACTIONS(5348),
    [anon_sym_rtranif1] = ACTIONS(5348),
    [anon_sym_rtranif0] = ACTIONS(5348),
    [anon_sym_tran] = ACTIONS(5348),
    [anon_sym_rtran] = ACTIONS(5348),
    [anon_sym_generate] = ACTIONS(5348),
    [anon_sym_for] = ACTIONS(5348),
    [anon_sym_initial] = ACTIONS(5348),
    [anon_sym_assign] = ACTIONS(5348),
    [anon_sym_alias] = ACTIONS(5348),
    [anon_sym_always_comb] = ACTIONS(5348),
    [anon_sym_always_latch] = ACTIONS(5348),
    [anon_sym_always_ff] = ACTIONS(5348),
    [anon_sym_final] = ACTIONS(5348),
    [anon_sym_global] = ACTIONS(5348),
    [anon_sym_LPAREN_STAR] = ACTIONS(5346),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5346),
    [anon_sym_DOLLARunit] = ACTIONS(5346),
  },
  [4605] = {
    [sym_simple_identifier] = ACTIONS(4494),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_rand] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_end] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [4606] = {
    [sym_simple_identifier] = ACTIONS(6743),
    [anon_sym_wire] = ACTIONS(6743),
    [anon_sym_tri] = ACTIONS(6743),
    [anon_sym_tri0] = ACTIONS(6743),
    [anon_sym_tri1] = ACTIONS(6743),
    [anon_sym_wand] = ACTIONS(6743),
    [anon_sym_triand] = ACTIONS(6743),
    [anon_sym_wor] = ACTIONS(6743),
    [anon_sym_trior] = ACTIONS(6743),
    [anon_sym_trireg] = ACTIONS(6743),
    [anon_sym_uwire] = ACTIONS(6743),
    [anon_sym_SEMI] = ACTIONS(6745),
    [anon_sym_extern] = ACTIONS(6743),
    [anon_sym_interface] = ACTIONS(6743),
    [anon_sym_checker] = ACTIONS(6743),
    [anon_sym_virtual] = ACTIONS(6743),
    [anon_sym_class] = ACTIONS(6743),
    [anon_sym_type] = ACTIONS(6743),
    [anon_sym_DOLLARfatal] = ACTIONS(6745),
    [anon_sym_DOLLARerror] = ACTIONS(6745),
    [anon_sym_DOLLARwarning] = ACTIONS(6745),
    [anon_sym_DOLLARinfo] = ACTIONS(6745),
    [anon_sym_default] = ACTIONS(6743),
    [anon_sym_clocking] = ACTIONS(6743),
    [anon_sym_defparam] = ACTIONS(6743),
    [anon_sym_bind] = ACTIONS(6743),
    [anon_sym_rand] = ACTIONS(6743),
    [anon_sym_const] = ACTIONS(6743),
    [anon_sym_function] = ACTIONS(6743),
    [anon_sym_static] = ACTIONS(6743),
    [anon_sym_constraint] = ACTIONS(6743),
    [anon_sym_if] = ACTIONS(6743),
    [anon_sym_else] = ACTIONS(6743),
    [anon_sym_LBRACK] = ACTIONS(6745),
    [anon_sym_localparam] = ACTIONS(6743),
    [anon_sym_parameter] = ACTIONS(6743),
    [anon_sym_var] = ACTIONS(6743),
    [anon_sym_import] = ACTIONS(6743),
    [anon_sym_export] = ACTIONS(6743),
    [anon_sym_genvar] = ACTIONS(6743),
    [anon_sym_interconnect] = ACTIONS(6743),
    [anon_sym_typedef] = ACTIONS(6743),
    [anon_sym_enum] = ACTIONS(6743),
    [anon_sym_struct] = ACTIONS(6743),
    [anon_sym_union] = ACTIONS(6743),
    [anon_sym_nettype] = ACTIONS(6743),
    [anon_sym_automatic] = ACTIONS(6743),
    [anon_sym_string] = ACTIONS(6743),
    [anon_sym_chandle] = ACTIONS(6743),
    [anon_sym_event] = ACTIONS(6743),
    [anon_sym_byte] = ACTIONS(6743),
    [anon_sym_shortint] = ACTIONS(6743),
    [anon_sym_int] = ACTIONS(6743),
    [anon_sym_longint] = ACTIONS(6743),
    [anon_sym_integer] = ACTIONS(6743),
    [anon_sym_time] = ACTIONS(6743),
    [anon_sym_bit] = ACTIONS(6743),
    [anon_sym_logic] = ACTIONS(6743),
    [anon_sym_reg] = ACTIONS(6743),
    [anon_sym_shortreal] = ACTIONS(6743),
    [anon_sym_real] = ACTIONS(6743),
    [anon_sym_realtime] = ACTIONS(6743),
    [anon_sym_supply0] = ACTIONS(6743),
    [anon_sym_supply1] = ACTIONS(6743),
    [anon_sym_signed] = ACTIONS(6743),
    [anon_sym_unsigned] = ACTIONS(6743),
    [anon_sym_task] = ACTIONS(6743),
    [anon_sym_assert] = ACTIONS(6743),
    [anon_sym_property] = ACTIONS(6743),
    [anon_sym_assume] = ACTIONS(6743),
    [anon_sym_cover] = ACTIONS(6743),
    [anon_sym_sequence] = ACTIONS(6743),
    [anon_sym_restrict] = ACTIONS(6743),
    [anon_sym_not] = ACTIONS(6743),
    [anon_sym_or] = ACTIONS(6743),
    [anon_sym_and] = ACTIONS(6743),
    [anon_sym_case] = ACTIONS(6743),
    [anon_sym_always] = ACTIONS(6743),
    [anon_sym_covergroup] = ACTIONS(6743),
    [anon_sym_let] = ACTIONS(6743),
    [anon_sym_pulldown] = ACTIONS(6743),
    [anon_sym_pullup] = ACTIONS(6743),
    [anon_sym_cmos] = ACTIONS(6743),
    [anon_sym_rcmos] = ACTIONS(6743),
    [anon_sym_bufif0] = ACTIONS(6743),
    [anon_sym_bufif1] = ACTIONS(6743),
    [anon_sym_notif0] = ACTIONS(6743),
    [anon_sym_notif1] = ACTIONS(6743),
    [anon_sym_nmos] = ACTIONS(6743),
    [anon_sym_pmos] = ACTIONS(6743),
    [anon_sym_rnmos] = ACTIONS(6743),
    [anon_sym_rpmos] = ACTIONS(6743),
    [anon_sym_nand] = ACTIONS(6743),
    [anon_sym_nor] = ACTIONS(6743),
    [anon_sym_xor] = ACTIONS(6743),
    [anon_sym_xnor] = ACTIONS(6743),
    [anon_sym_buf] = ACTIONS(6743),
    [anon_sym_tranif0] = ACTIONS(6743),
    [anon_sym_tranif1] = ACTIONS(6743),
    [anon_sym_rtranif1] = ACTIONS(6743),
    [anon_sym_rtranif0] = ACTIONS(6743),
    [anon_sym_tran] = ACTIONS(6743),
    [anon_sym_rtran] = ACTIONS(6743),
    [anon_sym_generate] = ACTIONS(6743),
    [anon_sym_endgenerate] = ACTIONS(6743),
    [anon_sym_for] = ACTIONS(6743),
    [anon_sym_initial] = ACTIONS(6743),
    [anon_sym_assign] = ACTIONS(6743),
    [anon_sym_alias] = ACTIONS(6743),
    [anon_sym_always_comb] = ACTIONS(6743),
    [anon_sym_always_latch] = ACTIONS(6743),
    [anon_sym_always_ff] = ACTIONS(6743),
    [anon_sym_final] = ACTIONS(6743),
    [anon_sym_global] = ACTIONS(6743),
    [anon_sym_LPAREN_STAR] = ACTIONS(6745),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6745),
    [anon_sym_DOLLARunit] = ACTIONS(6745),
  },
  [4607] = {
    [sym_simple_identifier] = ACTIONS(6661),
    [anon_sym_wire] = ACTIONS(6661),
    [anon_sym_tri] = ACTIONS(6661),
    [anon_sym_tri0] = ACTIONS(6661),
    [anon_sym_tri1] = ACTIONS(6661),
    [anon_sym_wand] = ACTIONS(6661),
    [anon_sym_triand] = ACTIONS(6661),
    [anon_sym_wor] = ACTIONS(6661),
    [anon_sym_trior] = ACTIONS(6661),
    [anon_sym_trireg] = ACTIONS(6661),
    [anon_sym_uwire] = ACTIONS(6661),
    [anon_sym_SEMI] = ACTIONS(6663),
    [anon_sym_extern] = ACTIONS(6661),
    [anon_sym_interface] = ACTIONS(6661),
    [anon_sym_checker] = ACTIONS(6661),
    [anon_sym_virtual] = ACTIONS(6661),
    [anon_sym_class] = ACTIONS(6661),
    [anon_sym_type] = ACTIONS(6661),
    [anon_sym_DOLLARfatal] = ACTIONS(6663),
    [anon_sym_DOLLARerror] = ACTIONS(6663),
    [anon_sym_DOLLARwarning] = ACTIONS(6663),
    [anon_sym_DOLLARinfo] = ACTIONS(6663),
    [anon_sym_default] = ACTIONS(6661),
    [anon_sym_clocking] = ACTIONS(6661),
    [anon_sym_defparam] = ACTIONS(6661),
    [anon_sym_bind] = ACTIONS(6661),
    [anon_sym_rand] = ACTIONS(6661),
    [anon_sym_const] = ACTIONS(6661),
    [anon_sym_function] = ACTIONS(6661),
    [anon_sym_static] = ACTIONS(6661),
    [anon_sym_constraint] = ACTIONS(6661),
    [anon_sym_if] = ACTIONS(6661),
    [anon_sym_else] = ACTIONS(6661),
    [anon_sym_LBRACK] = ACTIONS(6663),
    [anon_sym_localparam] = ACTIONS(6661),
    [anon_sym_parameter] = ACTIONS(6661),
    [anon_sym_var] = ACTIONS(6661),
    [anon_sym_import] = ACTIONS(6661),
    [anon_sym_export] = ACTIONS(6661),
    [anon_sym_genvar] = ACTIONS(6661),
    [anon_sym_interconnect] = ACTIONS(6661),
    [anon_sym_typedef] = ACTIONS(6661),
    [anon_sym_enum] = ACTIONS(6661),
    [anon_sym_struct] = ACTIONS(6661),
    [anon_sym_union] = ACTIONS(6661),
    [anon_sym_nettype] = ACTIONS(6661),
    [anon_sym_automatic] = ACTIONS(6661),
    [anon_sym_string] = ACTIONS(6661),
    [anon_sym_chandle] = ACTIONS(6661),
    [anon_sym_event] = ACTIONS(6661),
    [anon_sym_byte] = ACTIONS(6661),
    [anon_sym_shortint] = ACTIONS(6661),
    [anon_sym_int] = ACTIONS(6661),
    [anon_sym_longint] = ACTIONS(6661),
    [anon_sym_integer] = ACTIONS(6661),
    [anon_sym_time] = ACTIONS(6661),
    [anon_sym_bit] = ACTIONS(6661),
    [anon_sym_logic] = ACTIONS(6661),
    [anon_sym_reg] = ACTIONS(6661),
    [anon_sym_shortreal] = ACTIONS(6661),
    [anon_sym_real] = ACTIONS(6661),
    [anon_sym_realtime] = ACTIONS(6661),
    [anon_sym_supply0] = ACTIONS(6661),
    [anon_sym_supply1] = ACTIONS(6661),
    [anon_sym_signed] = ACTIONS(6661),
    [anon_sym_unsigned] = ACTIONS(6661),
    [anon_sym_task] = ACTIONS(6661),
    [anon_sym_assert] = ACTIONS(6661),
    [anon_sym_property] = ACTIONS(6661),
    [anon_sym_assume] = ACTIONS(6661),
    [anon_sym_cover] = ACTIONS(6661),
    [anon_sym_sequence] = ACTIONS(6661),
    [anon_sym_restrict] = ACTIONS(6661),
    [anon_sym_not] = ACTIONS(6661),
    [anon_sym_or] = ACTIONS(6661),
    [anon_sym_and] = ACTIONS(6661),
    [anon_sym_case] = ACTIONS(6661),
    [anon_sym_always] = ACTIONS(6661),
    [anon_sym_covergroup] = ACTIONS(6661),
    [anon_sym_end] = ACTIONS(6661),
    [anon_sym_let] = ACTIONS(6661),
    [anon_sym_pulldown] = ACTIONS(6661),
    [anon_sym_pullup] = ACTIONS(6661),
    [anon_sym_cmos] = ACTIONS(6661),
    [anon_sym_rcmos] = ACTIONS(6661),
    [anon_sym_bufif0] = ACTIONS(6661),
    [anon_sym_bufif1] = ACTIONS(6661),
    [anon_sym_notif0] = ACTIONS(6661),
    [anon_sym_notif1] = ACTIONS(6661),
    [anon_sym_nmos] = ACTIONS(6661),
    [anon_sym_pmos] = ACTIONS(6661),
    [anon_sym_rnmos] = ACTIONS(6661),
    [anon_sym_rpmos] = ACTIONS(6661),
    [anon_sym_nand] = ACTIONS(6661),
    [anon_sym_nor] = ACTIONS(6661),
    [anon_sym_xor] = ACTIONS(6661),
    [anon_sym_xnor] = ACTIONS(6661),
    [anon_sym_buf] = ACTIONS(6661),
    [anon_sym_tranif0] = ACTIONS(6661),
    [anon_sym_tranif1] = ACTIONS(6661),
    [anon_sym_rtranif1] = ACTIONS(6661),
    [anon_sym_rtranif0] = ACTIONS(6661),
    [anon_sym_tran] = ACTIONS(6661),
    [anon_sym_rtran] = ACTIONS(6661),
    [anon_sym_generate] = ACTIONS(6661),
    [anon_sym_for] = ACTIONS(6661),
    [anon_sym_initial] = ACTIONS(6661),
    [anon_sym_assign] = ACTIONS(6661),
    [anon_sym_alias] = ACTIONS(6661),
    [anon_sym_always_comb] = ACTIONS(6661),
    [anon_sym_always_latch] = ACTIONS(6661),
    [anon_sym_always_ff] = ACTIONS(6661),
    [anon_sym_final] = ACTIONS(6661),
    [anon_sym_global] = ACTIONS(6661),
    [anon_sym_LPAREN_STAR] = ACTIONS(6663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6663),
    [anon_sym_DOLLARunit] = ACTIONS(6663),
  },
  [4608] = {
    [sym_simple_identifier] = ACTIONS(5806),
    [anon_sym_wire] = ACTIONS(5806),
    [anon_sym_tri] = ACTIONS(5806),
    [anon_sym_tri0] = ACTIONS(5806),
    [anon_sym_tri1] = ACTIONS(5806),
    [anon_sym_wand] = ACTIONS(5806),
    [anon_sym_triand] = ACTIONS(5806),
    [anon_sym_wor] = ACTIONS(5806),
    [anon_sym_trior] = ACTIONS(5806),
    [anon_sym_trireg] = ACTIONS(5806),
    [anon_sym_uwire] = ACTIONS(5806),
    [anon_sym_SEMI] = ACTIONS(5808),
    [anon_sym_extern] = ACTIONS(5806),
    [anon_sym_interface] = ACTIONS(5806),
    [anon_sym_checker] = ACTIONS(5806),
    [anon_sym_virtual] = ACTIONS(5806),
    [anon_sym_class] = ACTIONS(5806),
    [anon_sym_type] = ACTIONS(5806),
    [anon_sym_DOLLARfatal] = ACTIONS(5808),
    [anon_sym_DOLLARerror] = ACTIONS(5808),
    [anon_sym_DOLLARwarning] = ACTIONS(5808),
    [anon_sym_DOLLARinfo] = ACTIONS(5808),
    [anon_sym_default] = ACTIONS(5806),
    [anon_sym_clocking] = ACTIONS(5806),
    [anon_sym_defparam] = ACTIONS(5806),
    [anon_sym_bind] = ACTIONS(5806),
    [anon_sym_rand] = ACTIONS(5806),
    [anon_sym_const] = ACTIONS(5806),
    [anon_sym_function] = ACTIONS(5806),
    [anon_sym_static] = ACTIONS(5806),
    [anon_sym_constraint] = ACTIONS(5806),
    [anon_sym_if] = ACTIONS(5806),
    [anon_sym_else] = ACTIONS(5806),
    [anon_sym_LBRACK] = ACTIONS(5808),
    [anon_sym_localparam] = ACTIONS(5806),
    [anon_sym_parameter] = ACTIONS(5806),
    [anon_sym_var] = ACTIONS(5806),
    [anon_sym_import] = ACTIONS(5806),
    [anon_sym_export] = ACTIONS(5806),
    [anon_sym_genvar] = ACTIONS(5806),
    [anon_sym_interconnect] = ACTIONS(5806),
    [anon_sym_typedef] = ACTIONS(5806),
    [anon_sym_enum] = ACTIONS(5806),
    [anon_sym_struct] = ACTIONS(5806),
    [anon_sym_union] = ACTIONS(5806),
    [anon_sym_nettype] = ACTIONS(5806),
    [anon_sym_automatic] = ACTIONS(5806),
    [anon_sym_string] = ACTIONS(5806),
    [anon_sym_chandle] = ACTIONS(5806),
    [anon_sym_event] = ACTIONS(5806),
    [anon_sym_byte] = ACTIONS(5806),
    [anon_sym_shortint] = ACTIONS(5806),
    [anon_sym_int] = ACTIONS(5806),
    [anon_sym_longint] = ACTIONS(5806),
    [anon_sym_integer] = ACTIONS(5806),
    [anon_sym_time] = ACTIONS(5806),
    [anon_sym_bit] = ACTIONS(5806),
    [anon_sym_logic] = ACTIONS(5806),
    [anon_sym_reg] = ACTIONS(5806),
    [anon_sym_shortreal] = ACTIONS(5806),
    [anon_sym_real] = ACTIONS(5806),
    [anon_sym_realtime] = ACTIONS(5806),
    [anon_sym_supply0] = ACTIONS(5806),
    [anon_sym_supply1] = ACTIONS(5806),
    [anon_sym_signed] = ACTIONS(5806),
    [anon_sym_unsigned] = ACTIONS(5806),
    [anon_sym_task] = ACTIONS(5806),
    [anon_sym_assert] = ACTIONS(5806),
    [anon_sym_property] = ACTIONS(5806),
    [anon_sym_assume] = ACTIONS(5806),
    [anon_sym_cover] = ACTIONS(5806),
    [anon_sym_sequence] = ACTIONS(5806),
    [anon_sym_restrict] = ACTIONS(5806),
    [anon_sym_not] = ACTIONS(5806),
    [anon_sym_or] = ACTIONS(5806),
    [anon_sym_and] = ACTIONS(5806),
    [anon_sym_case] = ACTIONS(5806),
    [anon_sym_always] = ACTIONS(5806),
    [anon_sym_covergroup] = ACTIONS(5806),
    [anon_sym_let] = ACTIONS(5806),
    [anon_sym_pulldown] = ACTIONS(5806),
    [anon_sym_pullup] = ACTIONS(5806),
    [anon_sym_cmos] = ACTIONS(5806),
    [anon_sym_rcmos] = ACTIONS(5806),
    [anon_sym_bufif0] = ACTIONS(5806),
    [anon_sym_bufif1] = ACTIONS(5806),
    [anon_sym_notif0] = ACTIONS(5806),
    [anon_sym_notif1] = ACTIONS(5806),
    [anon_sym_nmos] = ACTIONS(5806),
    [anon_sym_pmos] = ACTIONS(5806),
    [anon_sym_rnmos] = ACTIONS(5806),
    [anon_sym_rpmos] = ACTIONS(5806),
    [anon_sym_nand] = ACTIONS(5806),
    [anon_sym_nor] = ACTIONS(5806),
    [anon_sym_xor] = ACTIONS(5806),
    [anon_sym_xnor] = ACTIONS(5806),
    [anon_sym_buf] = ACTIONS(5806),
    [anon_sym_tranif0] = ACTIONS(5806),
    [anon_sym_tranif1] = ACTIONS(5806),
    [anon_sym_rtranif1] = ACTIONS(5806),
    [anon_sym_rtranif0] = ACTIONS(5806),
    [anon_sym_tran] = ACTIONS(5806),
    [anon_sym_rtran] = ACTIONS(5806),
    [anon_sym_generate] = ACTIONS(5806),
    [anon_sym_endgenerate] = ACTIONS(5806),
    [anon_sym_for] = ACTIONS(5806),
    [anon_sym_initial] = ACTIONS(5806),
    [anon_sym_assign] = ACTIONS(5806),
    [anon_sym_alias] = ACTIONS(5806),
    [anon_sym_always_comb] = ACTIONS(5806),
    [anon_sym_always_latch] = ACTIONS(5806),
    [anon_sym_always_ff] = ACTIONS(5806),
    [anon_sym_final] = ACTIONS(5806),
    [anon_sym_global] = ACTIONS(5806),
    [anon_sym_LPAREN_STAR] = ACTIONS(5808),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5808),
    [anon_sym_DOLLARunit] = ACTIONS(5808),
  },
  [4609] = {
    [sym_simple_identifier] = ACTIONS(6669),
    [anon_sym_wire] = ACTIONS(6669),
    [anon_sym_tri] = ACTIONS(6669),
    [anon_sym_tri0] = ACTIONS(6669),
    [anon_sym_tri1] = ACTIONS(6669),
    [anon_sym_wand] = ACTIONS(6669),
    [anon_sym_triand] = ACTIONS(6669),
    [anon_sym_wor] = ACTIONS(6669),
    [anon_sym_trior] = ACTIONS(6669),
    [anon_sym_trireg] = ACTIONS(6669),
    [anon_sym_uwire] = ACTIONS(6669),
    [anon_sym_SEMI] = ACTIONS(6671),
    [anon_sym_extern] = ACTIONS(6669),
    [anon_sym_interface] = ACTIONS(6669),
    [anon_sym_checker] = ACTIONS(6669),
    [anon_sym_virtual] = ACTIONS(6669),
    [anon_sym_class] = ACTIONS(6669),
    [anon_sym_type] = ACTIONS(6669),
    [anon_sym_DOLLARfatal] = ACTIONS(6671),
    [anon_sym_DOLLARerror] = ACTIONS(6671),
    [anon_sym_DOLLARwarning] = ACTIONS(6671),
    [anon_sym_DOLLARinfo] = ACTIONS(6671),
    [anon_sym_default] = ACTIONS(6669),
    [anon_sym_clocking] = ACTIONS(6669),
    [anon_sym_defparam] = ACTIONS(6669),
    [anon_sym_bind] = ACTIONS(6669),
    [anon_sym_rand] = ACTIONS(6669),
    [anon_sym_const] = ACTIONS(6669),
    [anon_sym_function] = ACTIONS(6669),
    [anon_sym_static] = ACTIONS(6669),
    [anon_sym_constraint] = ACTIONS(6669),
    [anon_sym_if] = ACTIONS(6669),
    [anon_sym_else] = ACTIONS(6669),
    [anon_sym_LBRACK] = ACTIONS(6671),
    [anon_sym_localparam] = ACTIONS(6669),
    [anon_sym_parameter] = ACTIONS(6669),
    [anon_sym_var] = ACTIONS(6669),
    [anon_sym_import] = ACTIONS(6669),
    [anon_sym_export] = ACTIONS(6669),
    [anon_sym_genvar] = ACTIONS(6669),
    [anon_sym_interconnect] = ACTIONS(6669),
    [anon_sym_typedef] = ACTIONS(6669),
    [anon_sym_enum] = ACTIONS(6669),
    [anon_sym_struct] = ACTIONS(6669),
    [anon_sym_union] = ACTIONS(6669),
    [anon_sym_nettype] = ACTIONS(6669),
    [anon_sym_automatic] = ACTIONS(6669),
    [anon_sym_string] = ACTIONS(6669),
    [anon_sym_chandle] = ACTIONS(6669),
    [anon_sym_event] = ACTIONS(6669),
    [anon_sym_byte] = ACTIONS(6669),
    [anon_sym_shortint] = ACTIONS(6669),
    [anon_sym_int] = ACTIONS(6669),
    [anon_sym_longint] = ACTIONS(6669),
    [anon_sym_integer] = ACTIONS(6669),
    [anon_sym_time] = ACTIONS(6669),
    [anon_sym_bit] = ACTIONS(6669),
    [anon_sym_logic] = ACTIONS(6669),
    [anon_sym_reg] = ACTIONS(6669),
    [anon_sym_shortreal] = ACTIONS(6669),
    [anon_sym_real] = ACTIONS(6669),
    [anon_sym_realtime] = ACTIONS(6669),
    [anon_sym_supply0] = ACTIONS(6669),
    [anon_sym_supply1] = ACTIONS(6669),
    [anon_sym_signed] = ACTIONS(6669),
    [anon_sym_unsigned] = ACTIONS(6669),
    [anon_sym_task] = ACTIONS(6669),
    [anon_sym_assert] = ACTIONS(6669),
    [anon_sym_property] = ACTIONS(6669),
    [anon_sym_assume] = ACTIONS(6669),
    [anon_sym_cover] = ACTIONS(6669),
    [anon_sym_sequence] = ACTIONS(6669),
    [anon_sym_restrict] = ACTIONS(6669),
    [anon_sym_not] = ACTIONS(6669),
    [anon_sym_or] = ACTIONS(6669),
    [anon_sym_and] = ACTIONS(6669),
    [anon_sym_case] = ACTIONS(6669),
    [anon_sym_always] = ACTIONS(6669),
    [anon_sym_covergroup] = ACTIONS(6669),
    [anon_sym_end] = ACTIONS(6669),
    [anon_sym_let] = ACTIONS(6669),
    [anon_sym_pulldown] = ACTIONS(6669),
    [anon_sym_pullup] = ACTIONS(6669),
    [anon_sym_cmos] = ACTIONS(6669),
    [anon_sym_rcmos] = ACTIONS(6669),
    [anon_sym_bufif0] = ACTIONS(6669),
    [anon_sym_bufif1] = ACTIONS(6669),
    [anon_sym_notif0] = ACTIONS(6669),
    [anon_sym_notif1] = ACTIONS(6669),
    [anon_sym_nmos] = ACTIONS(6669),
    [anon_sym_pmos] = ACTIONS(6669),
    [anon_sym_rnmos] = ACTIONS(6669),
    [anon_sym_rpmos] = ACTIONS(6669),
    [anon_sym_nand] = ACTIONS(6669),
    [anon_sym_nor] = ACTIONS(6669),
    [anon_sym_xor] = ACTIONS(6669),
    [anon_sym_xnor] = ACTIONS(6669),
    [anon_sym_buf] = ACTIONS(6669),
    [anon_sym_tranif0] = ACTIONS(6669),
    [anon_sym_tranif1] = ACTIONS(6669),
    [anon_sym_rtranif1] = ACTIONS(6669),
    [anon_sym_rtranif0] = ACTIONS(6669),
    [anon_sym_tran] = ACTIONS(6669),
    [anon_sym_rtran] = ACTIONS(6669),
    [anon_sym_generate] = ACTIONS(6669),
    [anon_sym_for] = ACTIONS(6669),
    [anon_sym_initial] = ACTIONS(6669),
    [anon_sym_assign] = ACTIONS(6669),
    [anon_sym_alias] = ACTIONS(6669),
    [anon_sym_always_comb] = ACTIONS(6669),
    [anon_sym_always_latch] = ACTIONS(6669),
    [anon_sym_always_ff] = ACTIONS(6669),
    [anon_sym_final] = ACTIONS(6669),
    [anon_sym_global] = ACTIONS(6669),
    [anon_sym_LPAREN_STAR] = ACTIONS(6671),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6671),
    [anon_sym_DOLLARunit] = ACTIONS(6671),
  },
  [4610] = {
    [sym_simple_identifier] = ACTIONS(4836),
    [anon_sym_wire] = ACTIONS(4836),
    [anon_sym_tri] = ACTIONS(4836),
    [anon_sym_tri0] = ACTIONS(4836),
    [anon_sym_tri1] = ACTIONS(4836),
    [anon_sym_wand] = ACTIONS(4836),
    [anon_sym_triand] = ACTIONS(4836),
    [anon_sym_wor] = ACTIONS(4836),
    [anon_sym_trior] = ACTIONS(4836),
    [anon_sym_trireg] = ACTIONS(4836),
    [anon_sym_uwire] = ACTIONS(4836),
    [anon_sym_SEMI] = ACTIONS(4834),
    [anon_sym_extern] = ACTIONS(4836),
    [anon_sym_interface] = ACTIONS(4836),
    [anon_sym_checker] = ACTIONS(4836),
    [anon_sym_virtual] = ACTIONS(4836),
    [anon_sym_class] = ACTIONS(4836),
    [anon_sym_type] = ACTIONS(4836),
    [anon_sym_DOLLARfatal] = ACTIONS(4834),
    [anon_sym_DOLLARerror] = ACTIONS(4834),
    [anon_sym_DOLLARwarning] = ACTIONS(4834),
    [anon_sym_DOLLARinfo] = ACTIONS(4834),
    [anon_sym_default] = ACTIONS(4836),
    [anon_sym_clocking] = ACTIONS(4836),
    [anon_sym_defparam] = ACTIONS(4836),
    [anon_sym_bind] = ACTIONS(4836),
    [anon_sym_rand] = ACTIONS(4836),
    [anon_sym_const] = ACTIONS(4836),
    [anon_sym_function] = ACTIONS(4836),
    [anon_sym_static] = ACTIONS(4836),
    [anon_sym_constraint] = ACTIONS(4836),
    [anon_sym_if] = ACTIONS(4836),
    [anon_sym_else] = ACTIONS(4836),
    [anon_sym_LBRACK] = ACTIONS(4834),
    [anon_sym_localparam] = ACTIONS(4836),
    [anon_sym_parameter] = ACTIONS(4836),
    [anon_sym_var] = ACTIONS(4836),
    [anon_sym_import] = ACTIONS(4836),
    [anon_sym_export] = ACTIONS(4836),
    [anon_sym_genvar] = ACTIONS(4836),
    [anon_sym_interconnect] = ACTIONS(4836),
    [anon_sym_typedef] = ACTIONS(4836),
    [anon_sym_enum] = ACTIONS(4836),
    [anon_sym_struct] = ACTIONS(4836),
    [anon_sym_union] = ACTIONS(4836),
    [anon_sym_nettype] = ACTIONS(4836),
    [anon_sym_automatic] = ACTIONS(4836),
    [anon_sym_string] = ACTIONS(4836),
    [anon_sym_chandle] = ACTIONS(4836),
    [anon_sym_event] = ACTIONS(4836),
    [anon_sym_byte] = ACTIONS(4836),
    [anon_sym_shortint] = ACTIONS(4836),
    [anon_sym_int] = ACTIONS(4836),
    [anon_sym_longint] = ACTIONS(4836),
    [anon_sym_integer] = ACTIONS(4836),
    [anon_sym_time] = ACTIONS(4836),
    [anon_sym_bit] = ACTIONS(4836),
    [anon_sym_logic] = ACTIONS(4836),
    [anon_sym_reg] = ACTIONS(4836),
    [anon_sym_shortreal] = ACTIONS(4836),
    [anon_sym_real] = ACTIONS(4836),
    [anon_sym_realtime] = ACTIONS(4836),
    [anon_sym_supply0] = ACTIONS(4836),
    [anon_sym_supply1] = ACTIONS(4836),
    [anon_sym_signed] = ACTIONS(4836),
    [anon_sym_unsigned] = ACTIONS(4836),
    [anon_sym_task] = ACTIONS(4836),
    [anon_sym_assert] = ACTIONS(4836),
    [anon_sym_property] = ACTIONS(4836),
    [anon_sym_assume] = ACTIONS(4836),
    [anon_sym_cover] = ACTIONS(4836),
    [anon_sym_sequence] = ACTIONS(4836),
    [anon_sym_restrict] = ACTIONS(4836),
    [anon_sym_not] = ACTIONS(4836),
    [anon_sym_or] = ACTIONS(4836),
    [anon_sym_and] = ACTIONS(4836),
    [anon_sym_case] = ACTIONS(4836),
    [anon_sym_always] = ACTIONS(4836),
    [anon_sym_covergroup] = ACTIONS(4836),
    [anon_sym_let] = ACTIONS(4836),
    [anon_sym_pulldown] = ACTIONS(4836),
    [anon_sym_pullup] = ACTIONS(4836),
    [anon_sym_cmos] = ACTIONS(4836),
    [anon_sym_rcmos] = ACTIONS(4836),
    [anon_sym_bufif0] = ACTIONS(4836),
    [anon_sym_bufif1] = ACTIONS(4836),
    [anon_sym_notif0] = ACTIONS(4836),
    [anon_sym_notif1] = ACTIONS(4836),
    [anon_sym_nmos] = ACTIONS(4836),
    [anon_sym_pmos] = ACTIONS(4836),
    [anon_sym_rnmos] = ACTIONS(4836),
    [anon_sym_rpmos] = ACTIONS(4836),
    [anon_sym_nand] = ACTIONS(4836),
    [anon_sym_nor] = ACTIONS(4836),
    [anon_sym_xor] = ACTIONS(4836),
    [anon_sym_xnor] = ACTIONS(4836),
    [anon_sym_buf] = ACTIONS(4836),
    [anon_sym_tranif0] = ACTIONS(4836),
    [anon_sym_tranif1] = ACTIONS(4836),
    [anon_sym_rtranif1] = ACTIONS(4836),
    [anon_sym_rtranif0] = ACTIONS(4836),
    [anon_sym_tran] = ACTIONS(4836),
    [anon_sym_rtran] = ACTIONS(4836),
    [anon_sym_generate] = ACTIONS(4836),
    [anon_sym_endgenerate] = ACTIONS(4836),
    [anon_sym_for] = ACTIONS(4836),
    [anon_sym_initial] = ACTIONS(4836),
    [anon_sym_assign] = ACTIONS(4836),
    [anon_sym_alias] = ACTIONS(4836),
    [anon_sym_always_comb] = ACTIONS(4836),
    [anon_sym_always_latch] = ACTIONS(4836),
    [anon_sym_always_ff] = ACTIONS(4836),
    [anon_sym_final] = ACTIONS(4836),
    [anon_sym_global] = ACTIONS(4836),
    [anon_sym_LPAREN_STAR] = ACTIONS(4834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4834),
    [anon_sym_DOLLARunit] = ACTIONS(4834),
  },
  [4611] = {
    [sym_simple_identifier] = ACTIONS(6627),
    [anon_sym_wire] = ACTIONS(6627),
    [anon_sym_tri] = ACTIONS(6627),
    [anon_sym_tri0] = ACTIONS(6627),
    [anon_sym_tri1] = ACTIONS(6627),
    [anon_sym_wand] = ACTIONS(6627),
    [anon_sym_triand] = ACTIONS(6627),
    [anon_sym_wor] = ACTIONS(6627),
    [anon_sym_trior] = ACTIONS(6627),
    [anon_sym_trireg] = ACTIONS(6627),
    [anon_sym_uwire] = ACTIONS(6627),
    [anon_sym_SEMI] = ACTIONS(6629),
    [anon_sym_extern] = ACTIONS(6627),
    [anon_sym_interface] = ACTIONS(6627),
    [anon_sym_checker] = ACTIONS(6627),
    [anon_sym_virtual] = ACTIONS(6627),
    [anon_sym_class] = ACTIONS(6627),
    [anon_sym_type] = ACTIONS(6627),
    [anon_sym_DOLLARfatal] = ACTIONS(6629),
    [anon_sym_DOLLARerror] = ACTIONS(6629),
    [anon_sym_DOLLARwarning] = ACTIONS(6629),
    [anon_sym_DOLLARinfo] = ACTIONS(6629),
    [anon_sym_default] = ACTIONS(6627),
    [anon_sym_clocking] = ACTIONS(6627),
    [anon_sym_defparam] = ACTIONS(6627),
    [anon_sym_bind] = ACTIONS(6627),
    [anon_sym_rand] = ACTIONS(6627),
    [anon_sym_const] = ACTIONS(6627),
    [anon_sym_function] = ACTIONS(6627),
    [anon_sym_static] = ACTIONS(6627),
    [anon_sym_constraint] = ACTIONS(6627),
    [anon_sym_if] = ACTIONS(6627),
    [anon_sym_else] = ACTIONS(6627),
    [anon_sym_LBRACK] = ACTIONS(6629),
    [anon_sym_localparam] = ACTIONS(6627),
    [anon_sym_parameter] = ACTIONS(6627),
    [anon_sym_var] = ACTIONS(6627),
    [anon_sym_import] = ACTIONS(6627),
    [anon_sym_export] = ACTIONS(6627),
    [anon_sym_genvar] = ACTIONS(6627),
    [anon_sym_interconnect] = ACTIONS(6627),
    [anon_sym_typedef] = ACTIONS(6627),
    [anon_sym_enum] = ACTIONS(6627),
    [anon_sym_struct] = ACTIONS(6627),
    [anon_sym_union] = ACTIONS(6627),
    [anon_sym_nettype] = ACTIONS(6627),
    [anon_sym_automatic] = ACTIONS(6627),
    [anon_sym_string] = ACTIONS(6627),
    [anon_sym_chandle] = ACTIONS(6627),
    [anon_sym_event] = ACTIONS(6627),
    [anon_sym_byte] = ACTIONS(6627),
    [anon_sym_shortint] = ACTIONS(6627),
    [anon_sym_int] = ACTIONS(6627),
    [anon_sym_longint] = ACTIONS(6627),
    [anon_sym_integer] = ACTIONS(6627),
    [anon_sym_time] = ACTIONS(6627),
    [anon_sym_bit] = ACTIONS(6627),
    [anon_sym_logic] = ACTIONS(6627),
    [anon_sym_reg] = ACTIONS(6627),
    [anon_sym_shortreal] = ACTIONS(6627),
    [anon_sym_real] = ACTIONS(6627),
    [anon_sym_realtime] = ACTIONS(6627),
    [anon_sym_supply0] = ACTIONS(6627),
    [anon_sym_supply1] = ACTIONS(6627),
    [anon_sym_signed] = ACTIONS(6627),
    [anon_sym_unsigned] = ACTIONS(6627),
    [anon_sym_task] = ACTIONS(6627),
    [anon_sym_assert] = ACTIONS(6627),
    [anon_sym_property] = ACTIONS(6627),
    [anon_sym_assume] = ACTIONS(6627),
    [anon_sym_cover] = ACTIONS(6627),
    [anon_sym_sequence] = ACTIONS(6627),
    [anon_sym_restrict] = ACTIONS(6627),
    [anon_sym_not] = ACTIONS(6627),
    [anon_sym_or] = ACTIONS(6627),
    [anon_sym_and] = ACTIONS(6627),
    [anon_sym_case] = ACTIONS(6627),
    [anon_sym_always] = ACTIONS(6627),
    [anon_sym_covergroup] = ACTIONS(6627),
    [anon_sym_end] = ACTIONS(6627),
    [anon_sym_let] = ACTIONS(6627),
    [anon_sym_pulldown] = ACTIONS(6627),
    [anon_sym_pullup] = ACTIONS(6627),
    [anon_sym_cmos] = ACTIONS(6627),
    [anon_sym_rcmos] = ACTIONS(6627),
    [anon_sym_bufif0] = ACTIONS(6627),
    [anon_sym_bufif1] = ACTIONS(6627),
    [anon_sym_notif0] = ACTIONS(6627),
    [anon_sym_notif1] = ACTIONS(6627),
    [anon_sym_nmos] = ACTIONS(6627),
    [anon_sym_pmos] = ACTIONS(6627),
    [anon_sym_rnmos] = ACTIONS(6627),
    [anon_sym_rpmos] = ACTIONS(6627),
    [anon_sym_nand] = ACTIONS(6627),
    [anon_sym_nor] = ACTIONS(6627),
    [anon_sym_xor] = ACTIONS(6627),
    [anon_sym_xnor] = ACTIONS(6627),
    [anon_sym_buf] = ACTIONS(6627),
    [anon_sym_tranif0] = ACTIONS(6627),
    [anon_sym_tranif1] = ACTIONS(6627),
    [anon_sym_rtranif1] = ACTIONS(6627),
    [anon_sym_rtranif0] = ACTIONS(6627),
    [anon_sym_tran] = ACTIONS(6627),
    [anon_sym_rtran] = ACTIONS(6627),
    [anon_sym_generate] = ACTIONS(6627),
    [anon_sym_for] = ACTIONS(6627),
    [anon_sym_initial] = ACTIONS(6627),
    [anon_sym_assign] = ACTIONS(6627),
    [anon_sym_alias] = ACTIONS(6627),
    [anon_sym_always_comb] = ACTIONS(6627),
    [anon_sym_always_latch] = ACTIONS(6627),
    [anon_sym_always_ff] = ACTIONS(6627),
    [anon_sym_final] = ACTIONS(6627),
    [anon_sym_global] = ACTIONS(6627),
    [anon_sym_LPAREN_STAR] = ACTIONS(6629),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6629),
    [anon_sym_DOLLARunit] = ACTIONS(6629),
  },
  [4612] = {
    [sym_simple_identifier] = ACTIONS(4578),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_rand] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_endgenerate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [4613] = {
    [sym_simple_identifier] = ACTIONS(4928),
    [anon_sym_wire] = ACTIONS(4928),
    [anon_sym_tri] = ACTIONS(4928),
    [anon_sym_tri0] = ACTIONS(4928),
    [anon_sym_tri1] = ACTIONS(4928),
    [anon_sym_wand] = ACTIONS(4928),
    [anon_sym_triand] = ACTIONS(4928),
    [anon_sym_wor] = ACTIONS(4928),
    [anon_sym_trior] = ACTIONS(4928),
    [anon_sym_trireg] = ACTIONS(4928),
    [anon_sym_uwire] = ACTIONS(4928),
    [anon_sym_SEMI] = ACTIONS(4926),
    [anon_sym_extern] = ACTIONS(4928),
    [anon_sym_interface] = ACTIONS(4928),
    [anon_sym_checker] = ACTIONS(4928),
    [anon_sym_virtual] = ACTIONS(4928),
    [anon_sym_class] = ACTIONS(4928),
    [anon_sym_type] = ACTIONS(4928),
    [anon_sym_DOLLARfatal] = ACTIONS(4926),
    [anon_sym_DOLLARerror] = ACTIONS(4926),
    [anon_sym_DOLLARwarning] = ACTIONS(4926),
    [anon_sym_DOLLARinfo] = ACTIONS(4926),
    [anon_sym_default] = ACTIONS(4928),
    [anon_sym_clocking] = ACTIONS(4928),
    [anon_sym_defparam] = ACTIONS(4928),
    [anon_sym_bind] = ACTIONS(4928),
    [anon_sym_rand] = ACTIONS(4928),
    [anon_sym_const] = ACTIONS(4928),
    [anon_sym_function] = ACTIONS(4928),
    [anon_sym_static] = ACTIONS(4928),
    [anon_sym_constraint] = ACTIONS(4928),
    [anon_sym_if] = ACTIONS(4928),
    [anon_sym_else] = ACTIONS(4928),
    [anon_sym_LBRACK] = ACTIONS(4926),
    [anon_sym_localparam] = ACTIONS(4928),
    [anon_sym_parameter] = ACTIONS(4928),
    [anon_sym_var] = ACTIONS(4928),
    [anon_sym_import] = ACTIONS(4928),
    [anon_sym_export] = ACTIONS(4928),
    [anon_sym_genvar] = ACTIONS(4928),
    [anon_sym_interconnect] = ACTIONS(4928),
    [anon_sym_typedef] = ACTIONS(4928),
    [anon_sym_enum] = ACTIONS(4928),
    [anon_sym_struct] = ACTIONS(4928),
    [anon_sym_union] = ACTIONS(4928),
    [anon_sym_nettype] = ACTIONS(4928),
    [anon_sym_automatic] = ACTIONS(4928),
    [anon_sym_string] = ACTIONS(4928),
    [anon_sym_chandle] = ACTIONS(4928),
    [anon_sym_event] = ACTIONS(4928),
    [anon_sym_byte] = ACTIONS(4928),
    [anon_sym_shortint] = ACTIONS(4928),
    [anon_sym_int] = ACTIONS(4928),
    [anon_sym_longint] = ACTIONS(4928),
    [anon_sym_integer] = ACTIONS(4928),
    [anon_sym_time] = ACTIONS(4928),
    [anon_sym_bit] = ACTIONS(4928),
    [anon_sym_logic] = ACTIONS(4928),
    [anon_sym_reg] = ACTIONS(4928),
    [anon_sym_shortreal] = ACTIONS(4928),
    [anon_sym_real] = ACTIONS(4928),
    [anon_sym_realtime] = ACTIONS(4928),
    [anon_sym_supply0] = ACTIONS(4928),
    [anon_sym_supply1] = ACTIONS(4928),
    [anon_sym_signed] = ACTIONS(4928),
    [anon_sym_unsigned] = ACTIONS(4928),
    [anon_sym_task] = ACTIONS(4928),
    [anon_sym_assert] = ACTIONS(4928),
    [anon_sym_property] = ACTIONS(4928),
    [anon_sym_assume] = ACTIONS(4928),
    [anon_sym_cover] = ACTIONS(4928),
    [anon_sym_sequence] = ACTIONS(4928),
    [anon_sym_restrict] = ACTIONS(4928),
    [anon_sym_not] = ACTIONS(4928),
    [anon_sym_or] = ACTIONS(4928),
    [anon_sym_and] = ACTIONS(4928),
    [anon_sym_case] = ACTIONS(4928),
    [anon_sym_always] = ACTIONS(4928),
    [anon_sym_covergroup] = ACTIONS(4928),
    [anon_sym_let] = ACTIONS(4928),
    [anon_sym_pulldown] = ACTIONS(4928),
    [anon_sym_pullup] = ACTIONS(4928),
    [anon_sym_cmos] = ACTIONS(4928),
    [anon_sym_rcmos] = ACTIONS(4928),
    [anon_sym_bufif0] = ACTIONS(4928),
    [anon_sym_bufif1] = ACTIONS(4928),
    [anon_sym_notif0] = ACTIONS(4928),
    [anon_sym_notif1] = ACTIONS(4928),
    [anon_sym_nmos] = ACTIONS(4928),
    [anon_sym_pmos] = ACTIONS(4928),
    [anon_sym_rnmos] = ACTIONS(4928),
    [anon_sym_rpmos] = ACTIONS(4928),
    [anon_sym_nand] = ACTIONS(4928),
    [anon_sym_nor] = ACTIONS(4928),
    [anon_sym_xor] = ACTIONS(4928),
    [anon_sym_xnor] = ACTIONS(4928),
    [anon_sym_buf] = ACTIONS(4928),
    [anon_sym_tranif0] = ACTIONS(4928),
    [anon_sym_tranif1] = ACTIONS(4928),
    [anon_sym_rtranif1] = ACTIONS(4928),
    [anon_sym_rtranif0] = ACTIONS(4928),
    [anon_sym_tran] = ACTIONS(4928),
    [anon_sym_rtran] = ACTIONS(4928),
    [anon_sym_generate] = ACTIONS(4928),
    [anon_sym_endgenerate] = ACTIONS(4928),
    [anon_sym_for] = ACTIONS(4928),
    [anon_sym_initial] = ACTIONS(4928),
    [anon_sym_assign] = ACTIONS(4928),
    [anon_sym_alias] = ACTIONS(4928),
    [anon_sym_always_comb] = ACTIONS(4928),
    [anon_sym_always_latch] = ACTIONS(4928),
    [anon_sym_always_ff] = ACTIONS(4928),
    [anon_sym_final] = ACTIONS(4928),
    [anon_sym_global] = ACTIONS(4928),
    [anon_sym_LPAREN_STAR] = ACTIONS(4926),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4926),
    [anon_sym_DOLLARunit] = ACTIONS(4926),
  },
  [4614] = {
    [sym_simple_identifier] = ACTIONS(4768),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_rand] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_end] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [4615] = {
    [sym_simple_identifier] = ACTIONS(6237),
    [anon_sym_wire] = ACTIONS(6237),
    [anon_sym_tri] = ACTIONS(6237),
    [anon_sym_tri0] = ACTIONS(6237),
    [anon_sym_tri1] = ACTIONS(6237),
    [anon_sym_wand] = ACTIONS(6237),
    [anon_sym_triand] = ACTIONS(6237),
    [anon_sym_wor] = ACTIONS(6237),
    [anon_sym_trior] = ACTIONS(6237),
    [anon_sym_trireg] = ACTIONS(6237),
    [anon_sym_uwire] = ACTIONS(6237),
    [anon_sym_SEMI] = ACTIONS(6239),
    [anon_sym_extern] = ACTIONS(6237),
    [anon_sym_interface] = ACTIONS(6237),
    [anon_sym_checker] = ACTIONS(6237),
    [anon_sym_virtual] = ACTIONS(6237),
    [anon_sym_class] = ACTIONS(6237),
    [anon_sym_type] = ACTIONS(6237),
    [anon_sym_DOLLARfatal] = ACTIONS(6239),
    [anon_sym_DOLLARerror] = ACTIONS(6239),
    [anon_sym_DOLLARwarning] = ACTIONS(6239),
    [anon_sym_DOLLARinfo] = ACTIONS(6239),
    [anon_sym_default] = ACTIONS(6237),
    [anon_sym_clocking] = ACTIONS(6237),
    [anon_sym_defparam] = ACTIONS(6237),
    [anon_sym_bind] = ACTIONS(6237),
    [anon_sym_rand] = ACTIONS(6237),
    [anon_sym_const] = ACTIONS(6237),
    [anon_sym_function] = ACTIONS(6237),
    [anon_sym_static] = ACTIONS(6237),
    [anon_sym_constraint] = ACTIONS(6237),
    [anon_sym_if] = ACTIONS(6237),
    [anon_sym_else] = ACTIONS(6237),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [anon_sym_localparam] = ACTIONS(6237),
    [anon_sym_parameter] = ACTIONS(6237),
    [anon_sym_var] = ACTIONS(6237),
    [anon_sym_import] = ACTIONS(6237),
    [anon_sym_export] = ACTIONS(6237),
    [anon_sym_genvar] = ACTIONS(6237),
    [anon_sym_interconnect] = ACTIONS(6237),
    [anon_sym_typedef] = ACTIONS(6237),
    [anon_sym_enum] = ACTIONS(6237),
    [anon_sym_struct] = ACTIONS(6237),
    [anon_sym_union] = ACTIONS(6237),
    [anon_sym_nettype] = ACTIONS(6237),
    [anon_sym_automatic] = ACTIONS(6237),
    [anon_sym_string] = ACTIONS(6237),
    [anon_sym_chandle] = ACTIONS(6237),
    [anon_sym_event] = ACTIONS(6237),
    [anon_sym_byte] = ACTIONS(6237),
    [anon_sym_shortint] = ACTIONS(6237),
    [anon_sym_int] = ACTIONS(6237),
    [anon_sym_longint] = ACTIONS(6237),
    [anon_sym_integer] = ACTIONS(6237),
    [anon_sym_time] = ACTIONS(6237),
    [anon_sym_bit] = ACTIONS(6237),
    [anon_sym_logic] = ACTIONS(6237),
    [anon_sym_reg] = ACTIONS(6237),
    [anon_sym_shortreal] = ACTIONS(6237),
    [anon_sym_real] = ACTIONS(6237),
    [anon_sym_realtime] = ACTIONS(6237),
    [anon_sym_supply0] = ACTIONS(6237),
    [anon_sym_supply1] = ACTIONS(6237),
    [anon_sym_signed] = ACTIONS(6237),
    [anon_sym_unsigned] = ACTIONS(6237),
    [anon_sym_task] = ACTIONS(6237),
    [anon_sym_assert] = ACTIONS(6237),
    [anon_sym_property] = ACTIONS(6237),
    [anon_sym_assume] = ACTIONS(6237),
    [anon_sym_cover] = ACTIONS(6237),
    [anon_sym_sequence] = ACTIONS(6237),
    [anon_sym_restrict] = ACTIONS(6237),
    [anon_sym_not] = ACTIONS(6237),
    [anon_sym_or] = ACTIONS(6237),
    [anon_sym_and] = ACTIONS(6237),
    [anon_sym_case] = ACTIONS(6237),
    [anon_sym_always] = ACTIONS(6237),
    [anon_sym_covergroup] = ACTIONS(6237),
    [anon_sym_end] = ACTIONS(6237),
    [anon_sym_let] = ACTIONS(6237),
    [anon_sym_pulldown] = ACTIONS(6237),
    [anon_sym_pullup] = ACTIONS(6237),
    [anon_sym_cmos] = ACTIONS(6237),
    [anon_sym_rcmos] = ACTIONS(6237),
    [anon_sym_bufif0] = ACTIONS(6237),
    [anon_sym_bufif1] = ACTIONS(6237),
    [anon_sym_notif0] = ACTIONS(6237),
    [anon_sym_notif1] = ACTIONS(6237),
    [anon_sym_nmos] = ACTIONS(6237),
    [anon_sym_pmos] = ACTIONS(6237),
    [anon_sym_rnmos] = ACTIONS(6237),
    [anon_sym_rpmos] = ACTIONS(6237),
    [anon_sym_nand] = ACTIONS(6237),
    [anon_sym_nor] = ACTIONS(6237),
    [anon_sym_xor] = ACTIONS(6237),
    [anon_sym_xnor] = ACTIONS(6237),
    [anon_sym_buf] = ACTIONS(6237),
    [anon_sym_tranif0] = ACTIONS(6237),
    [anon_sym_tranif1] = ACTIONS(6237),
    [anon_sym_rtranif1] = ACTIONS(6237),
    [anon_sym_rtranif0] = ACTIONS(6237),
    [anon_sym_tran] = ACTIONS(6237),
    [anon_sym_rtran] = ACTIONS(6237),
    [anon_sym_generate] = ACTIONS(6237),
    [anon_sym_for] = ACTIONS(6237),
    [anon_sym_initial] = ACTIONS(6237),
    [anon_sym_assign] = ACTIONS(6237),
    [anon_sym_alias] = ACTIONS(6237),
    [anon_sym_always_comb] = ACTIONS(6237),
    [anon_sym_always_latch] = ACTIONS(6237),
    [anon_sym_always_ff] = ACTIONS(6237),
    [anon_sym_final] = ACTIONS(6237),
    [anon_sym_global] = ACTIONS(6237),
    [anon_sym_LPAREN_STAR] = ACTIONS(6239),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6239),
    [anon_sym_DOLLARunit] = ACTIONS(6239),
  },
  [4616] = {
    [sym_simple_identifier] = ACTIONS(4594),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_rand] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_endgenerate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [4617] = {
    [sym_simple_identifier] = ACTIONS(4668),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_rand] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_end] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [4618] = {
    [sym_simple_identifier] = ACTIONS(5214),
    [anon_sym_wire] = ACTIONS(5214),
    [anon_sym_tri] = ACTIONS(5214),
    [anon_sym_tri0] = ACTIONS(5214),
    [anon_sym_tri1] = ACTIONS(5214),
    [anon_sym_wand] = ACTIONS(5214),
    [anon_sym_triand] = ACTIONS(5214),
    [anon_sym_wor] = ACTIONS(5214),
    [anon_sym_trior] = ACTIONS(5214),
    [anon_sym_trireg] = ACTIONS(5214),
    [anon_sym_uwire] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5212),
    [anon_sym_extern] = ACTIONS(5214),
    [anon_sym_interface] = ACTIONS(5214),
    [anon_sym_checker] = ACTIONS(5214),
    [anon_sym_virtual] = ACTIONS(5214),
    [anon_sym_class] = ACTIONS(5214),
    [anon_sym_type] = ACTIONS(5214),
    [anon_sym_DOLLARfatal] = ACTIONS(5212),
    [anon_sym_DOLLARerror] = ACTIONS(5212),
    [anon_sym_DOLLARwarning] = ACTIONS(5212),
    [anon_sym_DOLLARinfo] = ACTIONS(5212),
    [anon_sym_default] = ACTIONS(5214),
    [anon_sym_clocking] = ACTIONS(5214),
    [anon_sym_defparam] = ACTIONS(5214),
    [anon_sym_bind] = ACTIONS(5214),
    [anon_sym_rand] = ACTIONS(5214),
    [anon_sym_const] = ACTIONS(5214),
    [anon_sym_function] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(5214),
    [anon_sym_constraint] = ACTIONS(5214),
    [anon_sym_if] = ACTIONS(5214),
    [anon_sym_else] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5212),
    [anon_sym_localparam] = ACTIONS(5214),
    [anon_sym_parameter] = ACTIONS(5214),
    [anon_sym_var] = ACTIONS(5214),
    [anon_sym_import] = ACTIONS(5214),
    [anon_sym_export] = ACTIONS(5214),
    [anon_sym_genvar] = ACTIONS(5214),
    [anon_sym_interconnect] = ACTIONS(5214),
    [anon_sym_typedef] = ACTIONS(5214),
    [anon_sym_enum] = ACTIONS(5214),
    [anon_sym_struct] = ACTIONS(5214),
    [anon_sym_union] = ACTIONS(5214),
    [anon_sym_nettype] = ACTIONS(5214),
    [anon_sym_automatic] = ACTIONS(5214),
    [anon_sym_string] = ACTIONS(5214),
    [anon_sym_chandle] = ACTIONS(5214),
    [anon_sym_event] = ACTIONS(5214),
    [anon_sym_byte] = ACTIONS(5214),
    [anon_sym_shortint] = ACTIONS(5214),
    [anon_sym_int] = ACTIONS(5214),
    [anon_sym_longint] = ACTIONS(5214),
    [anon_sym_integer] = ACTIONS(5214),
    [anon_sym_time] = ACTIONS(5214),
    [anon_sym_bit] = ACTIONS(5214),
    [anon_sym_logic] = ACTIONS(5214),
    [anon_sym_reg] = ACTIONS(5214),
    [anon_sym_shortreal] = ACTIONS(5214),
    [anon_sym_real] = ACTIONS(5214),
    [anon_sym_realtime] = ACTIONS(5214),
    [anon_sym_supply0] = ACTIONS(5214),
    [anon_sym_supply1] = ACTIONS(5214),
    [anon_sym_signed] = ACTIONS(5214),
    [anon_sym_unsigned] = ACTIONS(5214),
    [anon_sym_task] = ACTIONS(5214),
    [anon_sym_assert] = ACTIONS(5214),
    [anon_sym_property] = ACTIONS(5214),
    [anon_sym_assume] = ACTIONS(5214),
    [anon_sym_cover] = ACTIONS(5214),
    [anon_sym_sequence] = ACTIONS(5214),
    [anon_sym_restrict] = ACTIONS(5214),
    [anon_sym_not] = ACTIONS(5214),
    [anon_sym_or] = ACTIONS(5214),
    [anon_sym_and] = ACTIONS(5214),
    [anon_sym_case] = ACTIONS(5214),
    [anon_sym_always] = ACTIONS(5214),
    [anon_sym_covergroup] = ACTIONS(5214),
    [anon_sym_let] = ACTIONS(5214),
    [anon_sym_pulldown] = ACTIONS(5214),
    [anon_sym_pullup] = ACTIONS(5214),
    [anon_sym_cmos] = ACTIONS(5214),
    [anon_sym_rcmos] = ACTIONS(5214),
    [anon_sym_bufif0] = ACTIONS(5214),
    [anon_sym_bufif1] = ACTIONS(5214),
    [anon_sym_notif0] = ACTIONS(5214),
    [anon_sym_notif1] = ACTIONS(5214),
    [anon_sym_nmos] = ACTIONS(5214),
    [anon_sym_pmos] = ACTIONS(5214),
    [anon_sym_rnmos] = ACTIONS(5214),
    [anon_sym_rpmos] = ACTIONS(5214),
    [anon_sym_nand] = ACTIONS(5214),
    [anon_sym_nor] = ACTIONS(5214),
    [anon_sym_xor] = ACTIONS(5214),
    [anon_sym_xnor] = ACTIONS(5214),
    [anon_sym_buf] = ACTIONS(5214),
    [anon_sym_tranif0] = ACTIONS(5214),
    [anon_sym_tranif1] = ACTIONS(5214),
    [anon_sym_rtranif1] = ACTIONS(5214),
    [anon_sym_rtranif0] = ACTIONS(5214),
    [anon_sym_tran] = ACTIONS(5214),
    [anon_sym_rtran] = ACTIONS(5214),
    [anon_sym_generate] = ACTIONS(5214),
    [anon_sym_endgenerate] = ACTIONS(5214),
    [anon_sym_for] = ACTIONS(5214),
    [anon_sym_initial] = ACTIONS(5214),
    [anon_sym_assign] = ACTIONS(5214),
    [anon_sym_alias] = ACTIONS(5214),
    [anon_sym_always_comb] = ACTIONS(5214),
    [anon_sym_always_latch] = ACTIONS(5214),
    [anon_sym_always_ff] = ACTIONS(5214),
    [anon_sym_final] = ACTIONS(5214),
    [anon_sym_global] = ACTIONS(5214),
    [anon_sym_LPAREN_STAR] = ACTIONS(5212),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5212),
    [anon_sym_DOLLARunit] = ACTIONS(5212),
  },
  [4619] = {
    [sym_simple_identifier] = ACTIONS(5310),
    [anon_sym_wire] = ACTIONS(5310),
    [anon_sym_tri] = ACTIONS(5310),
    [anon_sym_tri0] = ACTIONS(5310),
    [anon_sym_tri1] = ACTIONS(5310),
    [anon_sym_wand] = ACTIONS(5310),
    [anon_sym_triand] = ACTIONS(5310),
    [anon_sym_wor] = ACTIONS(5310),
    [anon_sym_trior] = ACTIONS(5310),
    [anon_sym_trireg] = ACTIONS(5310),
    [anon_sym_uwire] = ACTIONS(5310),
    [anon_sym_SEMI] = ACTIONS(5308),
    [anon_sym_extern] = ACTIONS(5310),
    [anon_sym_interface] = ACTIONS(5310),
    [anon_sym_checker] = ACTIONS(5310),
    [anon_sym_virtual] = ACTIONS(5310),
    [anon_sym_class] = ACTIONS(5310),
    [anon_sym_type] = ACTIONS(5310),
    [anon_sym_DOLLARfatal] = ACTIONS(5308),
    [anon_sym_DOLLARerror] = ACTIONS(5308),
    [anon_sym_DOLLARwarning] = ACTIONS(5308),
    [anon_sym_DOLLARinfo] = ACTIONS(5308),
    [anon_sym_default] = ACTIONS(5310),
    [anon_sym_clocking] = ACTIONS(5310),
    [anon_sym_defparam] = ACTIONS(5310),
    [anon_sym_bind] = ACTIONS(5310),
    [anon_sym_rand] = ACTIONS(5310),
    [anon_sym_const] = ACTIONS(5310),
    [anon_sym_function] = ACTIONS(5310),
    [anon_sym_static] = ACTIONS(5310),
    [anon_sym_constraint] = ACTIONS(5310),
    [anon_sym_if] = ACTIONS(5310),
    [anon_sym_else] = ACTIONS(5310),
    [anon_sym_LBRACK] = ACTIONS(5308),
    [anon_sym_localparam] = ACTIONS(5310),
    [anon_sym_parameter] = ACTIONS(5310),
    [anon_sym_var] = ACTIONS(5310),
    [anon_sym_import] = ACTIONS(5310),
    [anon_sym_export] = ACTIONS(5310),
    [anon_sym_genvar] = ACTIONS(5310),
    [anon_sym_interconnect] = ACTIONS(5310),
    [anon_sym_typedef] = ACTIONS(5310),
    [anon_sym_enum] = ACTIONS(5310),
    [anon_sym_struct] = ACTIONS(5310),
    [anon_sym_union] = ACTIONS(5310),
    [anon_sym_nettype] = ACTIONS(5310),
    [anon_sym_automatic] = ACTIONS(5310),
    [anon_sym_string] = ACTIONS(5310),
    [anon_sym_chandle] = ACTIONS(5310),
    [anon_sym_event] = ACTIONS(5310),
    [anon_sym_byte] = ACTIONS(5310),
    [anon_sym_shortint] = ACTIONS(5310),
    [anon_sym_int] = ACTIONS(5310),
    [anon_sym_longint] = ACTIONS(5310),
    [anon_sym_integer] = ACTIONS(5310),
    [anon_sym_time] = ACTIONS(5310),
    [anon_sym_bit] = ACTIONS(5310),
    [anon_sym_logic] = ACTIONS(5310),
    [anon_sym_reg] = ACTIONS(5310),
    [anon_sym_shortreal] = ACTIONS(5310),
    [anon_sym_real] = ACTIONS(5310),
    [anon_sym_realtime] = ACTIONS(5310),
    [anon_sym_supply0] = ACTIONS(5310),
    [anon_sym_supply1] = ACTIONS(5310),
    [anon_sym_signed] = ACTIONS(5310),
    [anon_sym_unsigned] = ACTIONS(5310),
    [anon_sym_task] = ACTIONS(5310),
    [anon_sym_assert] = ACTIONS(5310),
    [anon_sym_property] = ACTIONS(5310),
    [anon_sym_assume] = ACTIONS(5310),
    [anon_sym_cover] = ACTIONS(5310),
    [anon_sym_sequence] = ACTIONS(5310),
    [anon_sym_restrict] = ACTIONS(5310),
    [anon_sym_not] = ACTIONS(5310),
    [anon_sym_or] = ACTIONS(5310),
    [anon_sym_and] = ACTIONS(5310),
    [anon_sym_case] = ACTIONS(5310),
    [anon_sym_always] = ACTIONS(5310),
    [anon_sym_covergroup] = ACTIONS(5310),
    [anon_sym_end] = ACTIONS(5310),
    [anon_sym_let] = ACTIONS(5310),
    [anon_sym_pulldown] = ACTIONS(5310),
    [anon_sym_pullup] = ACTIONS(5310),
    [anon_sym_cmos] = ACTIONS(5310),
    [anon_sym_rcmos] = ACTIONS(5310),
    [anon_sym_bufif0] = ACTIONS(5310),
    [anon_sym_bufif1] = ACTIONS(5310),
    [anon_sym_notif0] = ACTIONS(5310),
    [anon_sym_notif1] = ACTIONS(5310),
    [anon_sym_nmos] = ACTIONS(5310),
    [anon_sym_pmos] = ACTIONS(5310),
    [anon_sym_rnmos] = ACTIONS(5310),
    [anon_sym_rpmos] = ACTIONS(5310),
    [anon_sym_nand] = ACTIONS(5310),
    [anon_sym_nor] = ACTIONS(5310),
    [anon_sym_xor] = ACTIONS(5310),
    [anon_sym_xnor] = ACTIONS(5310),
    [anon_sym_buf] = ACTIONS(5310),
    [anon_sym_tranif0] = ACTIONS(5310),
    [anon_sym_tranif1] = ACTIONS(5310),
    [anon_sym_rtranif1] = ACTIONS(5310),
    [anon_sym_rtranif0] = ACTIONS(5310),
    [anon_sym_tran] = ACTIONS(5310),
    [anon_sym_rtran] = ACTIONS(5310),
    [anon_sym_generate] = ACTIONS(5310),
    [anon_sym_for] = ACTIONS(5310),
    [anon_sym_initial] = ACTIONS(5310),
    [anon_sym_assign] = ACTIONS(5310),
    [anon_sym_alias] = ACTIONS(5310),
    [anon_sym_always_comb] = ACTIONS(5310),
    [anon_sym_always_latch] = ACTIONS(5310),
    [anon_sym_always_ff] = ACTIONS(5310),
    [anon_sym_final] = ACTIONS(5310),
    [anon_sym_global] = ACTIONS(5310),
    [anon_sym_LPAREN_STAR] = ACTIONS(5308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5308),
    [anon_sym_DOLLARunit] = ACTIONS(5308),
  },
  [4620] = {
    [sym_simple_identifier] = ACTIONS(6241),
    [anon_sym_wire] = ACTIONS(6241),
    [anon_sym_tri] = ACTIONS(6241),
    [anon_sym_tri0] = ACTIONS(6241),
    [anon_sym_tri1] = ACTIONS(6241),
    [anon_sym_wand] = ACTIONS(6241),
    [anon_sym_triand] = ACTIONS(6241),
    [anon_sym_wor] = ACTIONS(6241),
    [anon_sym_trior] = ACTIONS(6241),
    [anon_sym_trireg] = ACTIONS(6241),
    [anon_sym_uwire] = ACTIONS(6241),
    [anon_sym_SEMI] = ACTIONS(6243),
    [anon_sym_extern] = ACTIONS(6241),
    [anon_sym_interface] = ACTIONS(6241),
    [anon_sym_checker] = ACTIONS(6241),
    [anon_sym_virtual] = ACTIONS(6241),
    [anon_sym_class] = ACTIONS(6241),
    [anon_sym_type] = ACTIONS(6241),
    [anon_sym_DOLLARfatal] = ACTIONS(6243),
    [anon_sym_DOLLARerror] = ACTIONS(6243),
    [anon_sym_DOLLARwarning] = ACTIONS(6243),
    [anon_sym_DOLLARinfo] = ACTIONS(6243),
    [anon_sym_default] = ACTIONS(6241),
    [anon_sym_clocking] = ACTIONS(6241),
    [anon_sym_defparam] = ACTIONS(6241),
    [anon_sym_bind] = ACTIONS(6241),
    [anon_sym_rand] = ACTIONS(6241),
    [anon_sym_const] = ACTIONS(6241),
    [anon_sym_function] = ACTIONS(6241),
    [anon_sym_static] = ACTIONS(6241),
    [anon_sym_constraint] = ACTIONS(6241),
    [anon_sym_if] = ACTIONS(6241),
    [anon_sym_else] = ACTIONS(6241),
    [anon_sym_LBRACK] = ACTIONS(6243),
    [anon_sym_localparam] = ACTIONS(6241),
    [anon_sym_parameter] = ACTIONS(6241),
    [anon_sym_var] = ACTIONS(6241),
    [anon_sym_import] = ACTIONS(6241),
    [anon_sym_export] = ACTIONS(6241),
    [anon_sym_genvar] = ACTIONS(6241),
    [anon_sym_interconnect] = ACTIONS(6241),
    [anon_sym_typedef] = ACTIONS(6241),
    [anon_sym_enum] = ACTIONS(6241),
    [anon_sym_struct] = ACTIONS(6241),
    [anon_sym_union] = ACTIONS(6241),
    [anon_sym_nettype] = ACTIONS(6241),
    [anon_sym_automatic] = ACTIONS(6241),
    [anon_sym_string] = ACTIONS(6241),
    [anon_sym_chandle] = ACTIONS(6241),
    [anon_sym_event] = ACTIONS(6241),
    [anon_sym_byte] = ACTIONS(6241),
    [anon_sym_shortint] = ACTIONS(6241),
    [anon_sym_int] = ACTIONS(6241),
    [anon_sym_longint] = ACTIONS(6241),
    [anon_sym_integer] = ACTIONS(6241),
    [anon_sym_time] = ACTIONS(6241),
    [anon_sym_bit] = ACTIONS(6241),
    [anon_sym_logic] = ACTIONS(6241),
    [anon_sym_reg] = ACTIONS(6241),
    [anon_sym_shortreal] = ACTIONS(6241),
    [anon_sym_real] = ACTIONS(6241),
    [anon_sym_realtime] = ACTIONS(6241),
    [anon_sym_supply0] = ACTIONS(6241),
    [anon_sym_supply1] = ACTIONS(6241),
    [anon_sym_signed] = ACTIONS(6241),
    [anon_sym_unsigned] = ACTIONS(6241),
    [anon_sym_task] = ACTIONS(6241),
    [anon_sym_assert] = ACTIONS(6241),
    [anon_sym_property] = ACTIONS(6241),
    [anon_sym_assume] = ACTIONS(6241),
    [anon_sym_cover] = ACTIONS(6241),
    [anon_sym_sequence] = ACTIONS(6241),
    [anon_sym_restrict] = ACTIONS(6241),
    [anon_sym_not] = ACTIONS(6241),
    [anon_sym_or] = ACTIONS(6241),
    [anon_sym_and] = ACTIONS(6241),
    [anon_sym_case] = ACTIONS(6241),
    [anon_sym_always] = ACTIONS(6241),
    [anon_sym_covergroup] = ACTIONS(6241),
    [anon_sym_end] = ACTIONS(6241),
    [anon_sym_let] = ACTIONS(6241),
    [anon_sym_pulldown] = ACTIONS(6241),
    [anon_sym_pullup] = ACTIONS(6241),
    [anon_sym_cmos] = ACTIONS(6241),
    [anon_sym_rcmos] = ACTIONS(6241),
    [anon_sym_bufif0] = ACTIONS(6241),
    [anon_sym_bufif1] = ACTIONS(6241),
    [anon_sym_notif0] = ACTIONS(6241),
    [anon_sym_notif1] = ACTIONS(6241),
    [anon_sym_nmos] = ACTIONS(6241),
    [anon_sym_pmos] = ACTIONS(6241),
    [anon_sym_rnmos] = ACTIONS(6241),
    [anon_sym_rpmos] = ACTIONS(6241),
    [anon_sym_nand] = ACTIONS(6241),
    [anon_sym_nor] = ACTIONS(6241),
    [anon_sym_xor] = ACTIONS(6241),
    [anon_sym_xnor] = ACTIONS(6241),
    [anon_sym_buf] = ACTIONS(6241),
    [anon_sym_tranif0] = ACTIONS(6241),
    [anon_sym_tranif1] = ACTIONS(6241),
    [anon_sym_rtranif1] = ACTIONS(6241),
    [anon_sym_rtranif0] = ACTIONS(6241),
    [anon_sym_tran] = ACTIONS(6241),
    [anon_sym_rtran] = ACTIONS(6241),
    [anon_sym_generate] = ACTIONS(6241),
    [anon_sym_for] = ACTIONS(6241),
    [anon_sym_initial] = ACTIONS(6241),
    [anon_sym_assign] = ACTIONS(6241),
    [anon_sym_alias] = ACTIONS(6241),
    [anon_sym_always_comb] = ACTIONS(6241),
    [anon_sym_always_latch] = ACTIONS(6241),
    [anon_sym_always_ff] = ACTIONS(6241),
    [anon_sym_final] = ACTIONS(6241),
    [anon_sym_global] = ACTIONS(6241),
    [anon_sym_LPAREN_STAR] = ACTIONS(6243),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6243),
    [anon_sym_DOLLARunit] = ACTIONS(6243),
  },
  [4621] = {
    [sym_simple_identifier] = ACTIONS(6751),
    [anon_sym_wire] = ACTIONS(6751),
    [anon_sym_tri] = ACTIONS(6751),
    [anon_sym_tri0] = ACTIONS(6751),
    [anon_sym_tri1] = ACTIONS(6751),
    [anon_sym_wand] = ACTIONS(6751),
    [anon_sym_triand] = ACTIONS(6751),
    [anon_sym_wor] = ACTIONS(6751),
    [anon_sym_trior] = ACTIONS(6751),
    [anon_sym_trireg] = ACTIONS(6751),
    [anon_sym_uwire] = ACTIONS(6751),
    [anon_sym_SEMI] = ACTIONS(6753),
    [anon_sym_extern] = ACTIONS(6751),
    [anon_sym_interface] = ACTIONS(6751),
    [anon_sym_checker] = ACTIONS(6751),
    [anon_sym_virtual] = ACTIONS(6751),
    [anon_sym_class] = ACTIONS(6751),
    [anon_sym_type] = ACTIONS(6751),
    [anon_sym_DOLLARfatal] = ACTIONS(6753),
    [anon_sym_DOLLARerror] = ACTIONS(6753),
    [anon_sym_DOLLARwarning] = ACTIONS(6753),
    [anon_sym_DOLLARinfo] = ACTIONS(6753),
    [anon_sym_default] = ACTIONS(6751),
    [anon_sym_clocking] = ACTIONS(6751),
    [anon_sym_defparam] = ACTIONS(6751),
    [anon_sym_bind] = ACTIONS(6751),
    [anon_sym_rand] = ACTIONS(6751),
    [anon_sym_const] = ACTIONS(6751),
    [anon_sym_function] = ACTIONS(6751),
    [anon_sym_static] = ACTIONS(6751),
    [anon_sym_constraint] = ACTIONS(6751),
    [anon_sym_if] = ACTIONS(6751),
    [anon_sym_else] = ACTIONS(6751),
    [anon_sym_LBRACK] = ACTIONS(6753),
    [anon_sym_localparam] = ACTIONS(6751),
    [anon_sym_parameter] = ACTIONS(6751),
    [anon_sym_var] = ACTIONS(6751),
    [anon_sym_import] = ACTIONS(6751),
    [anon_sym_export] = ACTIONS(6751),
    [anon_sym_genvar] = ACTIONS(6751),
    [anon_sym_interconnect] = ACTIONS(6751),
    [anon_sym_typedef] = ACTIONS(6751),
    [anon_sym_enum] = ACTIONS(6751),
    [anon_sym_struct] = ACTIONS(6751),
    [anon_sym_union] = ACTIONS(6751),
    [anon_sym_nettype] = ACTIONS(6751),
    [anon_sym_automatic] = ACTIONS(6751),
    [anon_sym_string] = ACTIONS(6751),
    [anon_sym_chandle] = ACTIONS(6751),
    [anon_sym_event] = ACTIONS(6751),
    [anon_sym_byte] = ACTIONS(6751),
    [anon_sym_shortint] = ACTIONS(6751),
    [anon_sym_int] = ACTIONS(6751),
    [anon_sym_longint] = ACTIONS(6751),
    [anon_sym_integer] = ACTIONS(6751),
    [anon_sym_time] = ACTIONS(6751),
    [anon_sym_bit] = ACTIONS(6751),
    [anon_sym_logic] = ACTIONS(6751),
    [anon_sym_reg] = ACTIONS(6751),
    [anon_sym_shortreal] = ACTIONS(6751),
    [anon_sym_real] = ACTIONS(6751),
    [anon_sym_realtime] = ACTIONS(6751),
    [anon_sym_supply0] = ACTIONS(6751),
    [anon_sym_supply1] = ACTIONS(6751),
    [anon_sym_signed] = ACTIONS(6751),
    [anon_sym_unsigned] = ACTIONS(6751),
    [anon_sym_task] = ACTIONS(6751),
    [anon_sym_assert] = ACTIONS(6751),
    [anon_sym_property] = ACTIONS(6751),
    [anon_sym_assume] = ACTIONS(6751),
    [anon_sym_cover] = ACTIONS(6751),
    [anon_sym_sequence] = ACTIONS(6751),
    [anon_sym_restrict] = ACTIONS(6751),
    [anon_sym_not] = ACTIONS(6751),
    [anon_sym_or] = ACTIONS(6751),
    [anon_sym_and] = ACTIONS(6751),
    [anon_sym_case] = ACTIONS(6751),
    [anon_sym_always] = ACTIONS(6751),
    [anon_sym_covergroup] = ACTIONS(6751),
    [anon_sym_end] = ACTIONS(6751),
    [anon_sym_let] = ACTIONS(6751),
    [anon_sym_pulldown] = ACTIONS(6751),
    [anon_sym_pullup] = ACTIONS(6751),
    [anon_sym_cmos] = ACTIONS(6751),
    [anon_sym_rcmos] = ACTIONS(6751),
    [anon_sym_bufif0] = ACTIONS(6751),
    [anon_sym_bufif1] = ACTIONS(6751),
    [anon_sym_notif0] = ACTIONS(6751),
    [anon_sym_notif1] = ACTIONS(6751),
    [anon_sym_nmos] = ACTIONS(6751),
    [anon_sym_pmos] = ACTIONS(6751),
    [anon_sym_rnmos] = ACTIONS(6751),
    [anon_sym_rpmos] = ACTIONS(6751),
    [anon_sym_nand] = ACTIONS(6751),
    [anon_sym_nor] = ACTIONS(6751),
    [anon_sym_xor] = ACTIONS(6751),
    [anon_sym_xnor] = ACTIONS(6751),
    [anon_sym_buf] = ACTIONS(6751),
    [anon_sym_tranif0] = ACTIONS(6751),
    [anon_sym_tranif1] = ACTIONS(6751),
    [anon_sym_rtranif1] = ACTIONS(6751),
    [anon_sym_rtranif0] = ACTIONS(6751),
    [anon_sym_tran] = ACTIONS(6751),
    [anon_sym_rtran] = ACTIONS(6751),
    [anon_sym_generate] = ACTIONS(6751),
    [anon_sym_for] = ACTIONS(6751),
    [anon_sym_initial] = ACTIONS(6751),
    [anon_sym_assign] = ACTIONS(6751),
    [anon_sym_alias] = ACTIONS(6751),
    [anon_sym_always_comb] = ACTIONS(6751),
    [anon_sym_always_latch] = ACTIONS(6751),
    [anon_sym_always_ff] = ACTIONS(6751),
    [anon_sym_final] = ACTIONS(6751),
    [anon_sym_global] = ACTIONS(6751),
    [anon_sym_LPAREN_STAR] = ACTIONS(6753),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6753),
    [anon_sym_DOLLARunit] = ACTIONS(6753),
  },
  [4622] = {
    [sym_simple_identifier] = ACTIONS(4138),
    [anon_sym_wire] = ACTIONS(4138),
    [anon_sym_tri] = ACTIONS(4138),
    [anon_sym_tri0] = ACTIONS(4138),
    [anon_sym_tri1] = ACTIONS(4138),
    [anon_sym_wand] = ACTIONS(4138),
    [anon_sym_triand] = ACTIONS(4138),
    [anon_sym_wor] = ACTIONS(4138),
    [anon_sym_trior] = ACTIONS(4138),
    [anon_sym_trireg] = ACTIONS(4138),
    [anon_sym_uwire] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_extern] = ACTIONS(4138),
    [anon_sym_interface] = ACTIONS(4138),
    [anon_sym_checker] = ACTIONS(4138),
    [anon_sym_virtual] = ACTIONS(4138),
    [anon_sym_class] = ACTIONS(4138),
    [anon_sym_type] = ACTIONS(4138),
    [anon_sym_DOLLARfatal] = ACTIONS(4136),
    [anon_sym_DOLLARerror] = ACTIONS(4136),
    [anon_sym_DOLLARwarning] = ACTIONS(4136),
    [anon_sym_DOLLARinfo] = ACTIONS(4136),
    [anon_sym_default] = ACTIONS(4138),
    [anon_sym_clocking] = ACTIONS(4138),
    [anon_sym_defparam] = ACTIONS(4138),
    [anon_sym_bind] = ACTIONS(4138),
    [anon_sym_rand] = ACTIONS(4138),
    [anon_sym_const] = ACTIONS(4138),
    [anon_sym_function] = ACTIONS(4138),
    [anon_sym_static] = ACTIONS(4138),
    [anon_sym_constraint] = ACTIONS(4138),
    [anon_sym_if] = ACTIONS(4138),
    [anon_sym_else] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_localparam] = ACTIONS(4138),
    [anon_sym_parameter] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_import] = ACTIONS(4138),
    [anon_sym_export] = ACTIONS(4138),
    [anon_sym_genvar] = ACTIONS(4138),
    [anon_sym_interconnect] = ACTIONS(4138),
    [anon_sym_typedef] = ACTIONS(4138),
    [anon_sym_enum] = ACTIONS(4138),
    [anon_sym_struct] = ACTIONS(4138),
    [anon_sym_union] = ACTIONS(4138),
    [anon_sym_nettype] = ACTIONS(4138),
    [anon_sym_automatic] = ACTIONS(4138),
    [anon_sym_string] = ACTIONS(4138),
    [anon_sym_chandle] = ACTIONS(4138),
    [anon_sym_event] = ACTIONS(4138),
    [anon_sym_byte] = ACTIONS(4138),
    [anon_sym_shortint] = ACTIONS(4138),
    [anon_sym_int] = ACTIONS(4138),
    [anon_sym_longint] = ACTIONS(4138),
    [anon_sym_integer] = ACTIONS(4138),
    [anon_sym_time] = ACTIONS(4138),
    [anon_sym_bit] = ACTIONS(4138),
    [anon_sym_logic] = ACTIONS(4138),
    [anon_sym_reg] = ACTIONS(4138),
    [anon_sym_shortreal] = ACTIONS(4138),
    [anon_sym_real] = ACTIONS(4138),
    [anon_sym_realtime] = ACTIONS(4138),
    [anon_sym_supply0] = ACTIONS(4138),
    [anon_sym_supply1] = ACTIONS(4138),
    [anon_sym_signed] = ACTIONS(4138),
    [anon_sym_unsigned] = ACTIONS(4138),
    [anon_sym_task] = ACTIONS(4138),
    [anon_sym_assert] = ACTIONS(4138),
    [anon_sym_property] = ACTIONS(4138),
    [anon_sym_assume] = ACTIONS(4138),
    [anon_sym_cover] = ACTIONS(4138),
    [anon_sym_sequence] = ACTIONS(4138),
    [anon_sym_restrict] = ACTIONS(4138),
    [anon_sym_not] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_case] = ACTIONS(4138),
    [anon_sym_always] = ACTIONS(4138),
    [anon_sym_covergroup] = ACTIONS(4138),
    [anon_sym_end] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_pulldown] = ACTIONS(4138),
    [anon_sym_pullup] = ACTIONS(4138),
    [anon_sym_cmos] = ACTIONS(4138),
    [anon_sym_rcmos] = ACTIONS(4138),
    [anon_sym_bufif0] = ACTIONS(4138),
    [anon_sym_bufif1] = ACTIONS(4138),
    [anon_sym_notif0] = ACTIONS(4138),
    [anon_sym_notif1] = ACTIONS(4138),
    [anon_sym_nmos] = ACTIONS(4138),
    [anon_sym_pmos] = ACTIONS(4138),
    [anon_sym_rnmos] = ACTIONS(4138),
    [anon_sym_rpmos] = ACTIONS(4138),
    [anon_sym_nand] = ACTIONS(4138),
    [anon_sym_nor] = ACTIONS(4138),
    [anon_sym_xor] = ACTIONS(4138),
    [anon_sym_xnor] = ACTIONS(4138),
    [anon_sym_buf] = ACTIONS(4138),
    [anon_sym_tranif0] = ACTIONS(4138),
    [anon_sym_tranif1] = ACTIONS(4138),
    [anon_sym_rtranif1] = ACTIONS(4138),
    [anon_sym_rtranif0] = ACTIONS(4138),
    [anon_sym_tran] = ACTIONS(4138),
    [anon_sym_rtran] = ACTIONS(4138),
    [anon_sym_generate] = ACTIONS(4138),
    [anon_sym_for] = ACTIONS(4138),
    [anon_sym_initial] = ACTIONS(4138),
    [anon_sym_assign] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_always_comb] = ACTIONS(4138),
    [anon_sym_always_latch] = ACTIONS(4138),
    [anon_sym_always_ff] = ACTIONS(4138),
    [anon_sym_final] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LPAREN_STAR] = ACTIONS(4136),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4136),
    [anon_sym_DOLLARunit] = ACTIONS(4136),
  },
  [4623] = {
    [sym_simple_identifier] = ACTIONS(6039),
    [anon_sym_wire] = ACTIONS(6039),
    [anon_sym_tri] = ACTIONS(6039),
    [anon_sym_tri0] = ACTIONS(6039),
    [anon_sym_tri1] = ACTIONS(6039),
    [anon_sym_wand] = ACTIONS(6039),
    [anon_sym_triand] = ACTIONS(6039),
    [anon_sym_wor] = ACTIONS(6039),
    [anon_sym_trior] = ACTIONS(6039),
    [anon_sym_trireg] = ACTIONS(6039),
    [anon_sym_uwire] = ACTIONS(6039),
    [anon_sym_SEMI] = ACTIONS(6041),
    [anon_sym_extern] = ACTIONS(6039),
    [anon_sym_interface] = ACTIONS(6039),
    [anon_sym_checker] = ACTIONS(6039),
    [anon_sym_virtual] = ACTIONS(6039),
    [anon_sym_class] = ACTIONS(6039),
    [anon_sym_type] = ACTIONS(6039),
    [anon_sym_DOLLARfatal] = ACTIONS(6041),
    [anon_sym_DOLLARerror] = ACTIONS(6041),
    [anon_sym_DOLLARwarning] = ACTIONS(6041),
    [anon_sym_DOLLARinfo] = ACTIONS(6041),
    [anon_sym_default] = ACTIONS(6039),
    [anon_sym_clocking] = ACTIONS(6039),
    [anon_sym_defparam] = ACTIONS(6039),
    [anon_sym_bind] = ACTIONS(6039),
    [anon_sym_rand] = ACTIONS(6039),
    [anon_sym_const] = ACTIONS(6039),
    [anon_sym_function] = ACTIONS(6039),
    [anon_sym_static] = ACTIONS(6039),
    [anon_sym_constraint] = ACTIONS(6039),
    [anon_sym_if] = ACTIONS(6039),
    [anon_sym_else] = ACTIONS(6039),
    [anon_sym_LBRACK] = ACTIONS(6041),
    [anon_sym_localparam] = ACTIONS(6039),
    [anon_sym_parameter] = ACTIONS(6039),
    [anon_sym_var] = ACTIONS(6039),
    [anon_sym_import] = ACTIONS(6039),
    [anon_sym_export] = ACTIONS(6039),
    [anon_sym_genvar] = ACTIONS(6039),
    [anon_sym_interconnect] = ACTIONS(6039),
    [anon_sym_typedef] = ACTIONS(6039),
    [anon_sym_enum] = ACTIONS(6039),
    [anon_sym_struct] = ACTIONS(6039),
    [anon_sym_union] = ACTIONS(6039),
    [anon_sym_nettype] = ACTIONS(6039),
    [anon_sym_automatic] = ACTIONS(6039),
    [anon_sym_string] = ACTIONS(6039),
    [anon_sym_chandle] = ACTIONS(6039),
    [anon_sym_event] = ACTIONS(6039),
    [anon_sym_byte] = ACTIONS(6039),
    [anon_sym_shortint] = ACTIONS(6039),
    [anon_sym_int] = ACTIONS(6039),
    [anon_sym_longint] = ACTIONS(6039),
    [anon_sym_integer] = ACTIONS(6039),
    [anon_sym_time] = ACTIONS(6039),
    [anon_sym_bit] = ACTIONS(6039),
    [anon_sym_logic] = ACTIONS(6039),
    [anon_sym_reg] = ACTIONS(6039),
    [anon_sym_shortreal] = ACTIONS(6039),
    [anon_sym_real] = ACTIONS(6039),
    [anon_sym_realtime] = ACTIONS(6039),
    [anon_sym_supply0] = ACTIONS(6039),
    [anon_sym_supply1] = ACTIONS(6039),
    [anon_sym_signed] = ACTIONS(6039),
    [anon_sym_unsigned] = ACTIONS(6039),
    [anon_sym_task] = ACTIONS(6039),
    [anon_sym_assert] = ACTIONS(6039),
    [anon_sym_property] = ACTIONS(6039),
    [anon_sym_assume] = ACTIONS(6039),
    [anon_sym_cover] = ACTIONS(6039),
    [anon_sym_sequence] = ACTIONS(6039),
    [anon_sym_restrict] = ACTIONS(6039),
    [anon_sym_not] = ACTIONS(6039),
    [anon_sym_or] = ACTIONS(6039),
    [anon_sym_and] = ACTIONS(6039),
    [anon_sym_case] = ACTIONS(6039),
    [anon_sym_always] = ACTIONS(6039),
    [anon_sym_covergroup] = ACTIONS(6039),
    [anon_sym_end] = ACTIONS(6039),
    [anon_sym_let] = ACTIONS(6039),
    [anon_sym_pulldown] = ACTIONS(6039),
    [anon_sym_pullup] = ACTIONS(6039),
    [anon_sym_cmos] = ACTIONS(6039),
    [anon_sym_rcmos] = ACTIONS(6039),
    [anon_sym_bufif0] = ACTIONS(6039),
    [anon_sym_bufif1] = ACTIONS(6039),
    [anon_sym_notif0] = ACTIONS(6039),
    [anon_sym_notif1] = ACTIONS(6039),
    [anon_sym_nmos] = ACTIONS(6039),
    [anon_sym_pmos] = ACTIONS(6039),
    [anon_sym_rnmos] = ACTIONS(6039),
    [anon_sym_rpmos] = ACTIONS(6039),
    [anon_sym_nand] = ACTIONS(6039),
    [anon_sym_nor] = ACTIONS(6039),
    [anon_sym_xor] = ACTIONS(6039),
    [anon_sym_xnor] = ACTIONS(6039),
    [anon_sym_buf] = ACTIONS(6039),
    [anon_sym_tranif0] = ACTIONS(6039),
    [anon_sym_tranif1] = ACTIONS(6039),
    [anon_sym_rtranif1] = ACTIONS(6039),
    [anon_sym_rtranif0] = ACTIONS(6039),
    [anon_sym_tran] = ACTIONS(6039),
    [anon_sym_rtran] = ACTIONS(6039),
    [anon_sym_generate] = ACTIONS(6039),
    [anon_sym_for] = ACTIONS(6039),
    [anon_sym_initial] = ACTIONS(6039),
    [anon_sym_assign] = ACTIONS(6039),
    [anon_sym_alias] = ACTIONS(6039),
    [anon_sym_always_comb] = ACTIONS(6039),
    [anon_sym_always_latch] = ACTIONS(6039),
    [anon_sym_always_ff] = ACTIONS(6039),
    [anon_sym_final] = ACTIONS(6039),
    [anon_sym_global] = ACTIONS(6039),
    [anon_sym_LPAREN_STAR] = ACTIONS(6041),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6041),
    [anon_sym_DOLLARunit] = ACTIONS(6041),
  },
  [4624] = {
    [sym_simple_identifier] = ACTIONS(6245),
    [anon_sym_wire] = ACTIONS(6245),
    [anon_sym_tri] = ACTIONS(6245),
    [anon_sym_tri0] = ACTIONS(6245),
    [anon_sym_tri1] = ACTIONS(6245),
    [anon_sym_wand] = ACTIONS(6245),
    [anon_sym_triand] = ACTIONS(6245),
    [anon_sym_wor] = ACTIONS(6245),
    [anon_sym_trior] = ACTIONS(6245),
    [anon_sym_trireg] = ACTIONS(6245),
    [anon_sym_uwire] = ACTIONS(6245),
    [anon_sym_SEMI] = ACTIONS(6247),
    [anon_sym_extern] = ACTIONS(6245),
    [anon_sym_interface] = ACTIONS(6245),
    [anon_sym_checker] = ACTIONS(6245),
    [anon_sym_virtual] = ACTIONS(6245),
    [anon_sym_class] = ACTIONS(6245),
    [anon_sym_type] = ACTIONS(6245),
    [anon_sym_DOLLARfatal] = ACTIONS(6247),
    [anon_sym_DOLLARerror] = ACTIONS(6247),
    [anon_sym_DOLLARwarning] = ACTIONS(6247),
    [anon_sym_DOLLARinfo] = ACTIONS(6247),
    [anon_sym_default] = ACTIONS(6245),
    [anon_sym_clocking] = ACTIONS(6245),
    [anon_sym_defparam] = ACTIONS(6245),
    [anon_sym_bind] = ACTIONS(6245),
    [anon_sym_rand] = ACTIONS(6245),
    [anon_sym_const] = ACTIONS(6245),
    [anon_sym_function] = ACTIONS(6245),
    [anon_sym_static] = ACTIONS(6245),
    [anon_sym_constraint] = ACTIONS(6245),
    [anon_sym_if] = ACTIONS(6245),
    [anon_sym_else] = ACTIONS(6245),
    [anon_sym_LBRACK] = ACTIONS(6247),
    [anon_sym_localparam] = ACTIONS(6245),
    [anon_sym_parameter] = ACTIONS(6245),
    [anon_sym_var] = ACTIONS(6245),
    [anon_sym_import] = ACTIONS(6245),
    [anon_sym_export] = ACTIONS(6245),
    [anon_sym_genvar] = ACTIONS(6245),
    [anon_sym_interconnect] = ACTIONS(6245),
    [anon_sym_typedef] = ACTIONS(6245),
    [anon_sym_enum] = ACTIONS(6245),
    [anon_sym_struct] = ACTIONS(6245),
    [anon_sym_union] = ACTIONS(6245),
    [anon_sym_nettype] = ACTIONS(6245),
    [anon_sym_automatic] = ACTIONS(6245),
    [anon_sym_string] = ACTIONS(6245),
    [anon_sym_chandle] = ACTIONS(6245),
    [anon_sym_event] = ACTIONS(6245),
    [anon_sym_byte] = ACTIONS(6245),
    [anon_sym_shortint] = ACTIONS(6245),
    [anon_sym_int] = ACTIONS(6245),
    [anon_sym_longint] = ACTIONS(6245),
    [anon_sym_integer] = ACTIONS(6245),
    [anon_sym_time] = ACTIONS(6245),
    [anon_sym_bit] = ACTIONS(6245),
    [anon_sym_logic] = ACTIONS(6245),
    [anon_sym_reg] = ACTIONS(6245),
    [anon_sym_shortreal] = ACTIONS(6245),
    [anon_sym_real] = ACTIONS(6245),
    [anon_sym_realtime] = ACTIONS(6245),
    [anon_sym_supply0] = ACTIONS(6245),
    [anon_sym_supply1] = ACTIONS(6245),
    [anon_sym_signed] = ACTIONS(6245),
    [anon_sym_unsigned] = ACTIONS(6245),
    [anon_sym_task] = ACTIONS(6245),
    [anon_sym_assert] = ACTIONS(6245),
    [anon_sym_property] = ACTIONS(6245),
    [anon_sym_assume] = ACTIONS(6245),
    [anon_sym_cover] = ACTIONS(6245),
    [anon_sym_sequence] = ACTIONS(6245),
    [anon_sym_restrict] = ACTIONS(6245),
    [anon_sym_not] = ACTIONS(6245),
    [anon_sym_or] = ACTIONS(6245),
    [anon_sym_and] = ACTIONS(6245),
    [anon_sym_case] = ACTIONS(6245),
    [anon_sym_always] = ACTIONS(6245),
    [anon_sym_covergroup] = ACTIONS(6245),
    [anon_sym_end] = ACTIONS(6245),
    [anon_sym_let] = ACTIONS(6245),
    [anon_sym_pulldown] = ACTIONS(6245),
    [anon_sym_pullup] = ACTIONS(6245),
    [anon_sym_cmos] = ACTIONS(6245),
    [anon_sym_rcmos] = ACTIONS(6245),
    [anon_sym_bufif0] = ACTIONS(6245),
    [anon_sym_bufif1] = ACTIONS(6245),
    [anon_sym_notif0] = ACTIONS(6245),
    [anon_sym_notif1] = ACTIONS(6245),
    [anon_sym_nmos] = ACTIONS(6245),
    [anon_sym_pmos] = ACTIONS(6245),
    [anon_sym_rnmos] = ACTIONS(6245),
    [anon_sym_rpmos] = ACTIONS(6245),
    [anon_sym_nand] = ACTIONS(6245),
    [anon_sym_nor] = ACTIONS(6245),
    [anon_sym_xor] = ACTIONS(6245),
    [anon_sym_xnor] = ACTIONS(6245),
    [anon_sym_buf] = ACTIONS(6245),
    [anon_sym_tranif0] = ACTIONS(6245),
    [anon_sym_tranif1] = ACTIONS(6245),
    [anon_sym_rtranif1] = ACTIONS(6245),
    [anon_sym_rtranif0] = ACTIONS(6245),
    [anon_sym_tran] = ACTIONS(6245),
    [anon_sym_rtran] = ACTIONS(6245),
    [anon_sym_generate] = ACTIONS(6245),
    [anon_sym_for] = ACTIONS(6245),
    [anon_sym_initial] = ACTIONS(6245),
    [anon_sym_assign] = ACTIONS(6245),
    [anon_sym_alias] = ACTIONS(6245),
    [anon_sym_always_comb] = ACTIONS(6245),
    [anon_sym_always_latch] = ACTIONS(6245),
    [anon_sym_always_ff] = ACTIONS(6245),
    [anon_sym_final] = ACTIONS(6245),
    [anon_sym_global] = ACTIONS(6245),
    [anon_sym_LPAREN_STAR] = ACTIONS(6247),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6247),
    [anon_sym_DOLLARunit] = ACTIONS(6247),
  },
  [4625] = {
    [sym_simple_identifier] = ACTIONS(6043),
    [anon_sym_wire] = ACTIONS(6043),
    [anon_sym_tri] = ACTIONS(6043),
    [anon_sym_tri0] = ACTIONS(6043),
    [anon_sym_tri1] = ACTIONS(6043),
    [anon_sym_wand] = ACTIONS(6043),
    [anon_sym_triand] = ACTIONS(6043),
    [anon_sym_wor] = ACTIONS(6043),
    [anon_sym_trior] = ACTIONS(6043),
    [anon_sym_trireg] = ACTIONS(6043),
    [anon_sym_uwire] = ACTIONS(6043),
    [anon_sym_SEMI] = ACTIONS(6045),
    [anon_sym_extern] = ACTIONS(6043),
    [anon_sym_interface] = ACTIONS(6043),
    [anon_sym_checker] = ACTIONS(6043),
    [anon_sym_virtual] = ACTIONS(6043),
    [anon_sym_class] = ACTIONS(6043),
    [anon_sym_type] = ACTIONS(6043),
    [anon_sym_DOLLARfatal] = ACTIONS(6045),
    [anon_sym_DOLLARerror] = ACTIONS(6045),
    [anon_sym_DOLLARwarning] = ACTIONS(6045),
    [anon_sym_DOLLARinfo] = ACTIONS(6045),
    [anon_sym_default] = ACTIONS(6043),
    [anon_sym_clocking] = ACTIONS(6043),
    [anon_sym_defparam] = ACTIONS(6043),
    [anon_sym_bind] = ACTIONS(6043),
    [anon_sym_rand] = ACTIONS(6043),
    [anon_sym_const] = ACTIONS(6043),
    [anon_sym_function] = ACTIONS(6043),
    [anon_sym_static] = ACTIONS(6043),
    [anon_sym_constraint] = ACTIONS(6043),
    [anon_sym_if] = ACTIONS(6043),
    [anon_sym_else] = ACTIONS(6043),
    [anon_sym_LBRACK] = ACTIONS(6045),
    [anon_sym_localparam] = ACTIONS(6043),
    [anon_sym_parameter] = ACTIONS(6043),
    [anon_sym_var] = ACTIONS(6043),
    [anon_sym_import] = ACTIONS(6043),
    [anon_sym_export] = ACTIONS(6043),
    [anon_sym_genvar] = ACTIONS(6043),
    [anon_sym_interconnect] = ACTIONS(6043),
    [anon_sym_typedef] = ACTIONS(6043),
    [anon_sym_enum] = ACTIONS(6043),
    [anon_sym_struct] = ACTIONS(6043),
    [anon_sym_union] = ACTIONS(6043),
    [anon_sym_nettype] = ACTIONS(6043),
    [anon_sym_automatic] = ACTIONS(6043),
    [anon_sym_string] = ACTIONS(6043),
    [anon_sym_chandle] = ACTIONS(6043),
    [anon_sym_event] = ACTIONS(6043),
    [anon_sym_byte] = ACTIONS(6043),
    [anon_sym_shortint] = ACTIONS(6043),
    [anon_sym_int] = ACTIONS(6043),
    [anon_sym_longint] = ACTIONS(6043),
    [anon_sym_integer] = ACTIONS(6043),
    [anon_sym_time] = ACTIONS(6043),
    [anon_sym_bit] = ACTIONS(6043),
    [anon_sym_logic] = ACTIONS(6043),
    [anon_sym_reg] = ACTIONS(6043),
    [anon_sym_shortreal] = ACTIONS(6043),
    [anon_sym_real] = ACTIONS(6043),
    [anon_sym_realtime] = ACTIONS(6043),
    [anon_sym_supply0] = ACTIONS(6043),
    [anon_sym_supply1] = ACTIONS(6043),
    [anon_sym_signed] = ACTIONS(6043),
    [anon_sym_unsigned] = ACTIONS(6043),
    [anon_sym_task] = ACTIONS(6043),
    [anon_sym_assert] = ACTIONS(6043),
    [anon_sym_property] = ACTIONS(6043),
    [anon_sym_assume] = ACTIONS(6043),
    [anon_sym_cover] = ACTIONS(6043),
    [anon_sym_sequence] = ACTIONS(6043),
    [anon_sym_restrict] = ACTIONS(6043),
    [anon_sym_not] = ACTIONS(6043),
    [anon_sym_or] = ACTIONS(6043),
    [anon_sym_and] = ACTIONS(6043),
    [anon_sym_case] = ACTIONS(6043),
    [anon_sym_always] = ACTIONS(6043),
    [anon_sym_covergroup] = ACTIONS(6043),
    [anon_sym_end] = ACTIONS(6043),
    [anon_sym_let] = ACTIONS(6043),
    [anon_sym_pulldown] = ACTIONS(6043),
    [anon_sym_pullup] = ACTIONS(6043),
    [anon_sym_cmos] = ACTIONS(6043),
    [anon_sym_rcmos] = ACTIONS(6043),
    [anon_sym_bufif0] = ACTIONS(6043),
    [anon_sym_bufif1] = ACTIONS(6043),
    [anon_sym_notif0] = ACTIONS(6043),
    [anon_sym_notif1] = ACTIONS(6043),
    [anon_sym_nmos] = ACTIONS(6043),
    [anon_sym_pmos] = ACTIONS(6043),
    [anon_sym_rnmos] = ACTIONS(6043),
    [anon_sym_rpmos] = ACTIONS(6043),
    [anon_sym_nand] = ACTIONS(6043),
    [anon_sym_nor] = ACTIONS(6043),
    [anon_sym_xor] = ACTIONS(6043),
    [anon_sym_xnor] = ACTIONS(6043),
    [anon_sym_buf] = ACTIONS(6043),
    [anon_sym_tranif0] = ACTIONS(6043),
    [anon_sym_tranif1] = ACTIONS(6043),
    [anon_sym_rtranif1] = ACTIONS(6043),
    [anon_sym_rtranif0] = ACTIONS(6043),
    [anon_sym_tran] = ACTIONS(6043),
    [anon_sym_rtran] = ACTIONS(6043),
    [anon_sym_generate] = ACTIONS(6043),
    [anon_sym_for] = ACTIONS(6043),
    [anon_sym_initial] = ACTIONS(6043),
    [anon_sym_assign] = ACTIONS(6043),
    [anon_sym_alias] = ACTIONS(6043),
    [anon_sym_always_comb] = ACTIONS(6043),
    [anon_sym_always_latch] = ACTIONS(6043),
    [anon_sym_always_ff] = ACTIONS(6043),
    [anon_sym_final] = ACTIONS(6043),
    [anon_sym_global] = ACTIONS(6043),
    [anon_sym_LPAREN_STAR] = ACTIONS(6045),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6045),
    [anon_sym_DOLLARunit] = ACTIONS(6045),
  },
  [4626] = {
    [sym_simple_identifier] = ACTIONS(5454),
    [anon_sym_wire] = ACTIONS(5454),
    [anon_sym_tri] = ACTIONS(5454),
    [anon_sym_tri0] = ACTIONS(5454),
    [anon_sym_tri1] = ACTIONS(5454),
    [anon_sym_wand] = ACTIONS(5454),
    [anon_sym_triand] = ACTIONS(5454),
    [anon_sym_wor] = ACTIONS(5454),
    [anon_sym_trior] = ACTIONS(5454),
    [anon_sym_trireg] = ACTIONS(5454),
    [anon_sym_uwire] = ACTIONS(5454),
    [anon_sym_SEMI] = ACTIONS(5456),
    [anon_sym_extern] = ACTIONS(5454),
    [anon_sym_interface] = ACTIONS(5454),
    [anon_sym_checker] = ACTIONS(5454),
    [anon_sym_virtual] = ACTIONS(5454),
    [anon_sym_class] = ACTIONS(5454),
    [anon_sym_type] = ACTIONS(5454),
    [anon_sym_DOLLARfatal] = ACTIONS(5456),
    [anon_sym_DOLLARerror] = ACTIONS(5456),
    [anon_sym_DOLLARwarning] = ACTIONS(5456),
    [anon_sym_DOLLARinfo] = ACTIONS(5456),
    [anon_sym_default] = ACTIONS(5454),
    [anon_sym_clocking] = ACTIONS(5454),
    [anon_sym_defparam] = ACTIONS(5454),
    [anon_sym_bind] = ACTIONS(5454),
    [anon_sym_rand] = ACTIONS(5454),
    [anon_sym_const] = ACTIONS(5454),
    [anon_sym_function] = ACTIONS(5454),
    [anon_sym_static] = ACTIONS(5454),
    [anon_sym_constraint] = ACTIONS(5454),
    [anon_sym_if] = ACTIONS(5454),
    [anon_sym_else] = ACTIONS(5454),
    [anon_sym_LBRACK] = ACTIONS(5456),
    [anon_sym_localparam] = ACTIONS(5454),
    [anon_sym_parameter] = ACTIONS(5454),
    [anon_sym_var] = ACTIONS(5454),
    [anon_sym_import] = ACTIONS(5454),
    [anon_sym_export] = ACTIONS(5454),
    [anon_sym_genvar] = ACTIONS(5454),
    [anon_sym_interconnect] = ACTIONS(5454),
    [anon_sym_typedef] = ACTIONS(5454),
    [anon_sym_enum] = ACTIONS(5454),
    [anon_sym_struct] = ACTIONS(5454),
    [anon_sym_union] = ACTIONS(5454),
    [anon_sym_nettype] = ACTIONS(5454),
    [anon_sym_automatic] = ACTIONS(5454),
    [anon_sym_string] = ACTIONS(5454),
    [anon_sym_chandle] = ACTIONS(5454),
    [anon_sym_event] = ACTIONS(5454),
    [anon_sym_byte] = ACTIONS(5454),
    [anon_sym_shortint] = ACTIONS(5454),
    [anon_sym_int] = ACTIONS(5454),
    [anon_sym_longint] = ACTIONS(5454),
    [anon_sym_integer] = ACTIONS(5454),
    [anon_sym_time] = ACTIONS(5454),
    [anon_sym_bit] = ACTIONS(5454),
    [anon_sym_logic] = ACTIONS(5454),
    [anon_sym_reg] = ACTIONS(5454),
    [anon_sym_shortreal] = ACTIONS(5454),
    [anon_sym_real] = ACTIONS(5454),
    [anon_sym_realtime] = ACTIONS(5454),
    [anon_sym_supply0] = ACTIONS(5454),
    [anon_sym_supply1] = ACTIONS(5454),
    [anon_sym_signed] = ACTIONS(5454),
    [anon_sym_unsigned] = ACTIONS(5454),
    [anon_sym_task] = ACTIONS(5454),
    [anon_sym_assert] = ACTIONS(5454),
    [anon_sym_property] = ACTIONS(5454),
    [anon_sym_assume] = ACTIONS(5454),
    [anon_sym_cover] = ACTIONS(5454),
    [anon_sym_sequence] = ACTIONS(5454),
    [anon_sym_restrict] = ACTIONS(5454),
    [anon_sym_not] = ACTIONS(5454),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_and] = ACTIONS(5454),
    [anon_sym_case] = ACTIONS(5454),
    [anon_sym_always] = ACTIONS(5454),
    [anon_sym_covergroup] = ACTIONS(5454),
    [anon_sym_end] = ACTIONS(5454),
    [anon_sym_let] = ACTIONS(5454),
    [anon_sym_pulldown] = ACTIONS(5454),
    [anon_sym_pullup] = ACTIONS(5454),
    [anon_sym_cmos] = ACTIONS(5454),
    [anon_sym_rcmos] = ACTIONS(5454),
    [anon_sym_bufif0] = ACTIONS(5454),
    [anon_sym_bufif1] = ACTIONS(5454),
    [anon_sym_notif0] = ACTIONS(5454),
    [anon_sym_notif1] = ACTIONS(5454),
    [anon_sym_nmos] = ACTIONS(5454),
    [anon_sym_pmos] = ACTIONS(5454),
    [anon_sym_rnmos] = ACTIONS(5454),
    [anon_sym_rpmos] = ACTIONS(5454),
    [anon_sym_nand] = ACTIONS(5454),
    [anon_sym_nor] = ACTIONS(5454),
    [anon_sym_xor] = ACTIONS(5454),
    [anon_sym_xnor] = ACTIONS(5454),
    [anon_sym_buf] = ACTIONS(5454),
    [anon_sym_tranif0] = ACTIONS(5454),
    [anon_sym_tranif1] = ACTIONS(5454),
    [anon_sym_rtranif1] = ACTIONS(5454),
    [anon_sym_rtranif0] = ACTIONS(5454),
    [anon_sym_tran] = ACTIONS(5454),
    [anon_sym_rtran] = ACTIONS(5454),
    [anon_sym_generate] = ACTIONS(5454),
    [anon_sym_for] = ACTIONS(5454),
    [anon_sym_initial] = ACTIONS(5454),
    [anon_sym_assign] = ACTIONS(5454),
    [anon_sym_alias] = ACTIONS(5454),
    [anon_sym_always_comb] = ACTIONS(5454),
    [anon_sym_always_latch] = ACTIONS(5454),
    [anon_sym_always_ff] = ACTIONS(5454),
    [anon_sym_final] = ACTIONS(5454),
    [anon_sym_global] = ACTIONS(5454),
    [anon_sym_LPAREN_STAR] = ACTIONS(5456),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5456),
    [anon_sym_DOLLARunit] = ACTIONS(5456),
  },
  [4627] = {
    [sym_simple_identifier] = ACTIONS(6683),
    [anon_sym_wire] = ACTIONS(6683),
    [anon_sym_tri] = ACTIONS(6683),
    [anon_sym_tri0] = ACTIONS(6683),
    [anon_sym_tri1] = ACTIONS(6683),
    [anon_sym_wand] = ACTIONS(6683),
    [anon_sym_triand] = ACTIONS(6683),
    [anon_sym_wor] = ACTIONS(6683),
    [anon_sym_trior] = ACTIONS(6683),
    [anon_sym_trireg] = ACTIONS(6683),
    [anon_sym_uwire] = ACTIONS(6683),
    [anon_sym_SEMI] = ACTIONS(6685),
    [anon_sym_extern] = ACTIONS(6683),
    [anon_sym_interface] = ACTIONS(6683),
    [anon_sym_checker] = ACTIONS(6683),
    [anon_sym_virtual] = ACTIONS(6683),
    [anon_sym_class] = ACTIONS(6683),
    [anon_sym_type] = ACTIONS(6683),
    [anon_sym_DOLLARfatal] = ACTIONS(6685),
    [anon_sym_DOLLARerror] = ACTIONS(6685),
    [anon_sym_DOLLARwarning] = ACTIONS(6685),
    [anon_sym_DOLLARinfo] = ACTIONS(6685),
    [anon_sym_default] = ACTIONS(6683),
    [anon_sym_clocking] = ACTIONS(6683),
    [anon_sym_defparam] = ACTIONS(6683),
    [anon_sym_bind] = ACTIONS(6683),
    [anon_sym_rand] = ACTIONS(6683),
    [anon_sym_const] = ACTIONS(6683),
    [anon_sym_function] = ACTIONS(6683),
    [anon_sym_static] = ACTIONS(6683),
    [anon_sym_constraint] = ACTIONS(6683),
    [anon_sym_if] = ACTIONS(6683),
    [anon_sym_else] = ACTIONS(6683),
    [anon_sym_LBRACK] = ACTIONS(6685),
    [anon_sym_localparam] = ACTIONS(6683),
    [anon_sym_parameter] = ACTIONS(6683),
    [anon_sym_var] = ACTIONS(6683),
    [anon_sym_import] = ACTIONS(6683),
    [anon_sym_export] = ACTIONS(6683),
    [anon_sym_genvar] = ACTIONS(6683),
    [anon_sym_interconnect] = ACTIONS(6683),
    [anon_sym_typedef] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_struct] = ACTIONS(6683),
    [anon_sym_union] = ACTIONS(6683),
    [anon_sym_nettype] = ACTIONS(6683),
    [anon_sym_automatic] = ACTIONS(6683),
    [anon_sym_string] = ACTIONS(6683),
    [anon_sym_chandle] = ACTIONS(6683),
    [anon_sym_event] = ACTIONS(6683),
    [anon_sym_byte] = ACTIONS(6683),
    [anon_sym_shortint] = ACTIONS(6683),
    [anon_sym_int] = ACTIONS(6683),
    [anon_sym_longint] = ACTIONS(6683),
    [anon_sym_integer] = ACTIONS(6683),
    [anon_sym_time] = ACTIONS(6683),
    [anon_sym_bit] = ACTIONS(6683),
    [anon_sym_logic] = ACTIONS(6683),
    [anon_sym_reg] = ACTIONS(6683),
    [anon_sym_shortreal] = ACTIONS(6683),
    [anon_sym_real] = ACTIONS(6683),
    [anon_sym_realtime] = ACTIONS(6683),
    [anon_sym_supply0] = ACTIONS(6683),
    [anon_sym_supply1] = ACTIONS(6683),
    [anon_sym_signed] = ACTIONS(6683),
    [anon_sym_unsigned] = ACTIONS(6683),
    [anon_sym_task] = ACTIONS(6683),
    [anon_sym_assert] = ACTIONS(6683),
    [anon_sym_property] = ACTIONS(6683),
    [anon_sym_assume] = ACTIONS(6683),
    [anon_sym_cover] = ACTIONS(6683),
    [anon_sym_sequence] = ACTIONS(6683),
    [anon_sym_restrict] = ACTIONS(6683),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_or] = ACTIONS(6683),
    [anon_sym_and] = ACTIONS(6683),
    [anon_sym_case] = ACTIONS(6683),
    [anon_sym_always] = ACTIONS(6683),
    [anon_sym_covergroup] = ACTIONS(6683),
    [anon_sym_let] = ACTIONS(6683),
    [anon_sym_pulldown] = ACTIONS(6683),
    [anon_sym_pullup] = ACTIONS(6683),
    [anon_sym_cmos] = ACTIONS(6683),
    [anon_sym_rcmos] = ACTIONS(6683),
    [anon_sym_bufif0] = ACTIONS(6683),
    [anon_sym_bufif1] = ACTIONS(6683),
    [anon_sym_notif0] = ACTIONS(6683),
    [anon_sym_notif1] = ACTIONS(6683),
    [anon_sym_nmos] = ACTIONS(6683),
    [anon_sym_pmos] = ACTIONS(6683),
    [anon_sym_rnmos] = ACTIONS(6683),
    [anon_sym_rpmos] = ACTIONS(6683),
    [anon_sym_nand] = ACTIONS(6683),
    [anon_sym_nor] = ACTIONS(6683),
    [anon_sym_xor] = ACTIONS(6683),
    [anon_sym_xnor] = ACTIONS(6683),
    [anon_sym_buf] = ACTIONS(6683),
    [anon_sym_tranif0] = ACTIONS(6683),
    [anon_sym_tranif1] = ACTIONS(6683),
    [anon_sym_rtranif1] = ACTIONS(6683),
    [anon_sym_rtranif0] = ACTIONS(6683),
    [anon_sym_tran] = ACTIONS(6683),
    [anon_sym_rtran] = ACTIONS(6683),
    [anon_sym_generate] = ACTIONS(6683),
    [anon_sym_endgenerate] = ACTIONS(6683),
    [anon_sym_for] = ACTIONS(6683),
    [anon_sym_initial] = ACTIONS(6683),
    [anon_sym_assign] = ACTIONS(6683),
    [anon_sym_alias] = ACTIONS(6683),
    [anon_sym_always_comb] = ACTIONS(6683),
    [anon_sym_always_latch] = ACTIONS(6683),
    [anon_sym_always_ff] = ACTIONS(6683),
    [anon_sym_final] = ACTIONS(6683),
    [anon_sym_global] = ACTIONS(6683),
    [anon_sym_LPAREN_STAR] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6685),
    [anon_sym_DOLLARunit] = ACTIONS(6685),
  },
  [4628] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(10883),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_endgenerate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [4629] = {
    [sym_simple_identifier] = ACTIONS(6589),
    [anon_sym_wire] = ACTIONS(6589),
    [anon_sym_tri] = ACTIONS(6589),
    [anon_sym_tri0] = ACTIONS(6589),
    [anon_sym_tri1] = ACTIONS(6589),
    [anon_sym_wand] = ACTIONS(6589),
    [anon_sym_triand] = ACTIONS(6589),
    [anon_sym_wor] = ACTIONS(6589),
    [anon_sym_trior] = ACTIONS(6589),
    [anon_sym_trireg] = ACTIONS(6589),
    [anon_sym_uwire] = ACTIONS(6589),
    [anon_sym_SEMI] = ACTIONS(6591),
    [anon_sym_extern] = ACTIONS(6589),
    [anon_sym_interface] = ACTIONS(6589),
    [anon_sym_checker] = ACTIONS(6589),
    [anon_sym_virtual] = ACTIONS(6589),
    [anon_sym_class] = ACTIONS(6589),
    [anon_sym_type] = ACTIONS(6589),
    [anon_sym_DOLLARfatal] = ACTIONS(6591),
    [anon_sym_DOLLARerror] = ACTIONS(6591),
    [anon_sym_DOLLARwarning] = ACTIONS(6591),
    [anon_sym_DOLLARinfo] = ACTIONS(6591),
    [anon_sym_default] = ACTIONS(6589),
    [anon_sym_clocking] = ACTIONS(6589),
    [anon_sym_defparam] = ACTIONS(6589),
    [anon_sym_bind] = ACTIONS(6589),
    [anon_sym_rand] = ACTIONS(6589),
    [anon_sym_const] = ACTIONS(6589),
    [anon_sym_function] = ACTIONS(6589),
    [anon_sym_static] = ACTIONS(6589),
    [anon_sym_constraint] = ACTIONS(6589),
    [anon_sym_if] = ACTIONS(6589),
    [anon_sym_else] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6591),
    [anon_sym_localparam] = ACTIONS(6589),
    [anon_sym_parameter] = ACTIONS(6589),
    [anon_sym_var] = ACTIONS(6589),
    [anon_sym_import] = ACTIONS(6589),
    [anon_sym_export] = ACTIONS(6589),
    [anon_sym_genvar] = ACTIONS(6589),
    [anon_sym_interconnect] = ACTIONS(6589),
    [anon_sym_typedef] = ACTIONS(6589),
    [anon_sym_enum] = ACTIONS(6589),
    [anon_sym_struct] = ACTIONS(6589),
    [anon_sym_union] = ACTIONS(6589),
    [anon_sym_nettype] = ACTIONS(6589),
    [anon_sym_automatic] = ACTIONS(6589),
    [anon_sym_string] = ACTIONS(6589),
    [anon_sym_chandle] = ACTIONS(6589),
    [anon_sym_event] = ACTIONS(6589),
    [anon_sym_byte] = ACTIONS(6589),
    [anon_sym_shortint] = ACTIONS(6589),
    [anon_sym_int] = ACTIONS(6589),
    [anon_sym_longint] = ACTIONS(6589),
    [anon_sym_integer] = ACTIONS(6589),
    [anon_sym_time] = ACTIONS(6589),
    [anon_sym_bit] = ACTIONS(6589),
    [anon_sym_logic] = ACTIONS(6589),
    [anon_sym_reg] = ACTIONS(6589),
    [anon_sym_shortreal] = ACTIONS(6589),
    [anon_sym_real] = ACTIONS(6589),
    [anon_sym_realtime] = ACTIONS(6589),
    [anon_sym_supply0] = ACTIONS(6589),
    [anon_sym_supply1] = ACTIONS(6589),
    [anon_sym_signed] = ACTIONS(6589),
    [anon_sym_unsigned] = ACTIONS(6589),
    [anon_sym_task] = ACTIONS(6589),
    [anon_sym_assert] = ACTIONS(6589),
    [anon_sym_property] = ACTIONS(6589),
    [anon_sym_assume] = ACTIONS(6589),
    [anon_sym_cover] = ACTIONS(6589),
    [anon_sym_sequence] = ACTIONS(6589),
    [anon_sym_restrict] = ACTIONS(6589),
    [anon_sym_not] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_case] = ACTIONS(6589),
    [anon_sym_always] = ACTIONS(6589),
    [anon_sym_covergroup] = ACTIONS(6589),
    [anon_sym_end] = ACTIONS(6589),
    [anon_sym_let] = ACTIONS(6589),
    [anon_sym_pulldown] = ACTIONS(6589),
    [anon_sym_pullup] = ACTIONS(6589),
    [anon_sym_cmos] = ACTIONS(6589),
    [anon_sym_rcmos] = ACTIONS(6589),
    [anon_sym_bufif0] = ACTIONS(6589),
    [anon_sym_bufif1] = ACTIONS(6589),
    [anon_sym_notif0] = ACTIONS(6589),
    [anon_sym_notif1] = ACTIONS(6589),
    [anon_sym_nmos] = ACTIONS(6589),
    [anon_sym_pmos] = ACTIONS(6589),
    [anon_sym_rnmos] = ACTIONS(6589),
    [anon_sym_rpmos] = ACTIONS(6589),
    [anon_sym_nand] = ACTIONS(6589),
    [anon_sym_nor] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_xnor] = ACTIONS(6589),
    [anon_sym_buf] = ACTIONS(6589),
    [anon_sym_tranif0] = ACTIONS(6589),
    [anon_sym_tranif1] = ACTIONS(6589),
    [anon_sym_rtranif1] = ACTIONS(6589),
    [anon_sym_rtranif0] = ACTIONS(6589),
    [anon_sym_tran] = ACTIONS(6589),
    [anon_sym_rtran] = ACTIONS(6589),
    [anon_sym_generate] = ACTIONS(6589),
    [anon_sym_for] = ACTIONS(6589),
    [anon_sym_initial] = ACTIONS(6589),
    [anon_sym_assign] = ACTIONS(6589),
    [anon_sym_alias] = ACTIONS(6589),
    [anon_sym_always_comb] = ACTIONS(6589),
    [anon_sym_always_latch] = ACTIONS(6589),
    [anon_sym_always_ff] = ACTIONS(6589),
    [anon_sym_final] = ACTIONS(6589),
    [anon_sym_global] = ACTIONS(6589),
    [anon_sym_LPAREN_STAR] = ACTIONS(6591),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6591),
    [anon_sym_DOLLARunit] = ACTIONS(6591),
  },
  [4630] = {
    [sym_simple_identifier] = ACTIONS(4206),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_rand] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_end] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [4631] = {
    [sym_simple_identifier] = ACTIONS(5352),
    [anon_sym_wire] = ACTIONS(5352),
    [anon_sym_tri] = ACTIONS(5352),
    [anon_sym_tri0] = ACTIONS(5352),
    [anon_sym_tri1] = ACTIONS(5352),
    [anon_sym_wand] = ACTIONS(5352),
    [anon_sym_triand] = ACTIONS(5352),
    [anon_sym_wor] = ACTIONS(5352),
    [anon_sym_trior] = ACTIONS(5352),
    [anon_sym_trireg] = ACTIONS(5352),
    [anon_sym_uwire] = ACTIONS(5352),
    [anon_sym_SEMI] = ACTIONS(5350),
    [anon_sym_extern] = ACTIONS(5352),
    [anon_sym_interface] = ACTIONS(5352),
    [anon_sym_checker] = ACTIONS(5352),
    [anon_sym_virtual] = ACTIONS(5352),
    [anon_sym_class] = ACTIONS(5352),
    [anon_sym_type] = ACTIONS(5352),
    [anon_sym_DOLLARfatal] = ACTIONS(5350),
    [anon_sym_DOLLARerror] = ACTIONS(5350),
    [anon_sym_DOLLARwarning] = ACTIONS(5350),
    [anon_sym_DOLLARinfo] = ACTIONS(5350),
    [anon_sym_default] = ACTIONS(5352),
    [anon_sym_clocking] = ACTIONS(5352),
    [anon_sym_defparam] = ACTIONS(5352),
    [anon_sym_bind] = ACTIONS(5352),
    [anon_sym_rand] = ACTIONS(5352),
    [anon_sym_const] = ACTIONS(5352),
    [anon_sym_function] = ACTIONS(5352),
    [anon_sym_static] = ACTIONS(5352),
    [anon_sym_constraint] = ACTIONS(5352),
    [anon_sym_if] = ACTIONS(5352),
    [anon_sym_else] = ACTIONS(5352),
    [anon_sym_LBRACK] = ACTIONS(5350),
    [anon_sym_localparam] = ACTIONS(5352),
    [anon_sym_parameter] = ACTIONS(5352),
    [anon_sym_var] = ACTIONS(5352),
    [anon_sym_import] = ACTIONS(5352),
    [anon_sym_export] = ACTIONS(5352),
    [anon_sym_genvar] = ACTIONS(5352),
    [anon_sym_interconnect] = ACTIONS(5352),
    [anon_sym_typedef] = ACTIONS(5352),
    [anon_sym_enum] = ACTIONS(5352),
    [anon_sym_struct] = ACTIONS(5352),
    [anon_sym_union] = ACTIONS(5352),
    [anon_sym_nettype] = ACTIONS(5352),
    [anon_sym_automatic] = ACTIONS(5352),
    [anon_sym_string] = ACTIONS(5352),
    [anon_sym_chandle] = ACTIONS(5352),
    [anon_sym_event] = ACTIONS(5352),
    [anon_sym_byte] = ACTIONS(5352),
    [anon_sym_shortint] = ACTIONS(5352),
    [anon_sym_int] = ACTIONS(5352),
    [anon_sym_longint] = ACTIONS(5352),
    [anon_sym_integer] = ACTIONS(5352),
    [anon_sym_time] = ACTIONS(5352),
    [anon_sym_bit] = ACTIONS(5352),
    [anon_sym_logic] = ACTIONS(5352),
    [anon_sym_reg] = ACTIONS(5352),
    [anon_sym_shortreal] = ACTIONS(5352),
    [anon_sym_real] = ACTIONS(5352),
    [anon_sym_realtime] = ACTIONS(5352),
    [anon_sym_supply0] = ACTIONS(5352),
    [anon_sym_supply1] = ACTIONS(5352),
    [anon_sym_signed] = ACTIONS(5352),
    [anon_sym_unsigned] = ACTIONS(5352),
    [anon_sym_task] = ACTIONS(5352),
    [anon_sym_assert] = ACTIONS(5352),
    [anon_sym_property] = ACTIONS(5352),
    [anon_sym_assume] = ACTIONS(5352),
    [anon_sym_cover] = ACTIONS(5352),
    [anon_sym_sequence] = ACTIONS(5352),
    [anon_sym_restrict] = ACTIONS(5352),
    [anon_sym_not] = ACTIONS(5352),
    [anon_sym_or] = ACTIONS(5352),
    [anon_sym_and] = ACTIONS(5352),
    [anon_sym_case] = ACTIONS(5352),
    [anon_sym_always] = ACTIONS(5352),
    [anon_sym_covergroup] = ACTIONS(5352),
    [anon_sym_end] = ACTIONS(5352),
    [anon_sym_let] = ACTIONS(5352),
    [anon_sym_pulldown] = ACTIONS(5352),
    [anon_sym_pullup] = ACTIONS(5352),
    [anon_sym_cmos] = ACTIONS(5352),
    [anon_sym_rcmos] = ACTIONS(5352),
    [anon_sym_bufif0] = ACTIONS(5352),
    [anon_sym_bufif1] = ACTIONS(5352),
    [anon_sym_notif0] = ACTIONS(5352),
    [anon_sym_notif1] = ACTIONS(5352),
    [anon_sym_nmos] = ACTIONS(5352),
    [anon_sym_pmos] = ACTIONS(5352),
    [anon_sym_rnmos] = ACTIONS(5352),
    [anon_sym_rpmos] = ACTIONS(5352),
    [anon_sym_nand] = ACTIONS(5352),
    [anon_sym_nor] = ACTIONS(5352),
    [anon_sym_xor] = ACTIONS(5352),
    [anon_sym_xnor] = ACTIONS(5352),
    [anon_sym_buf] = ACTIONS(5352),
    [anon_sym_tranif0] = ACTIONS(5352),
    [anon_sym_tranif1] = ACTIONS(5352),
    [anon_sym_rtranif1] = ACTIONS(5352),
    [anon_sym_rtranif0] = ACTIONS(5352),
    [anon_sym_tran] = ACTIONS(5352),
    [anon_sym_rtran] = ACTIONS(5352),
    [anon_sym_generate] = ACTIONS(5352),
    [anon_sym_for] = ACTIONS(5352),
    [anon_sym_initial] = ACTIONS(5352),
    [anon_sym_assign] = ACTIONS(5352),
    [anon_sym_alias] = ACTIONS(5352),
    [anon_sym_always_comb] = ACTIONS(5352),
    [anon_sym_always_latch] = ACTIONS(5352),
    [anon_sym_always_ff] = ACTIONS(5352),
    [anon_sym_final] = ACTIONS(5352),
    [anon_sym_global] = ACTIONS(5352),
    [anon_sym_LPAREN_STAR] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5350),
    [anon_sym_DOLLARunit] = ACTIONS(5350),
  },
  [4632] = {
    [sym_simple_identifier] = ACTIONS(6789),
    [anon_sym_wire] = ACTIONS(6789),
    [anon_sym_tri] = ACTIONS(6789),
    [anon_sym_tri0] = ACTIONS(6789),
    [anon_sym_tri1] = ACTIONS(6789),
    [anon_sym_wand] = ACTIONS(6789),
    [anon_sym_triand] = ACTIONS(6789),
    [anon_sym_wor] = ACTIONS(6789),
    [anon_sym_trior] = ACTIONS(6789),
    [anon_sym_trireg] = ACTIONS(6789),
    [anon_sym_uwire] = ACTIONS(6789),
    [anon_sym_SEMI] = ACTIONS(6791),
    [anon_sym_extern] = ACTIONS(6789),
    [anon_sym_interface] = ACTIONS(6789),
    [anon_sym_checker] = ACTIONS(6789),
    [anon_sym_virtual] = ACTIONS(6789),
    [anon_sym_class] = ACTIONS(6789),
    [anon_sym_type] = ACTIONS(6789),
    [anon_sym_DOLLARfatal] = ACTIONS(6791),
    [anon_sym_DOLLARerror] = ACTIONS(6791),
    [anon_sym_DOLLARwarning] = ACTIONS(6791),
    [anon_sym_DOLLARinfo] = ACTIONS(6791),
    [anon_sym_default] = ACTIONS(6789),
    [anon_sym_clocking] = ACTIONS(6789),
    [anon_sym_defparam] = ACTIONS(6789),
    [anon_sym_bind] = ACTIONS(6789),
    [anon_sym_rand] = ACTIONS(6789),
    [anon_sym_const] = ACTIONS(6789),
    [anon_sym_function] = ACTIONS(6789),
    [anon_sym_static] = ACTIONS(6789),
    [anon_sym_constraint] = ACTIONS(6789),
    [anon_sym_if] = ACTIONS(6789),
    [anon_sym_else] = ACTIONS(6789),
    [anon_sym_LBRACK] = ACTIONS(6791),
    [anon_sym_localparam] = ACTIONS(6789),
    [anon_sym_parameter] = ACTIONS(6789),
    [anon_sym_var] = ACTIONS(6789),
    [anon_sym_import] = ACTIONS(6789),
    [anon_sym_export] = ACTIONS(6789),
    [anon_sym_genvar] = ACTIONS(6789),
    [anon_sym_interconnect] = ACTIONS(6789),
    [anon_sym_typedef] = ACTIONS(6789),
    [anon_sym_enum] = ACTIONS(6789),
    [anon_sym_struct] = ACTIONS(6789),
    [anon_sym_union] = ACTIONS(6789),
    [anon_sym_nettype] = ACTIONS(6789),
    [anon_sym_automatic] = ACTIONS(6789),
    [anon_sym_string] = ACTIONS(6789),
    [anon_sym_chandle] = ACTIONS(6789),
    [anon_sym_event] = ACTIONS(6789),
    [anon_sym_byte] = ACTIONS(6789),
    [anon_sym_shortint] = ACTIONS(6789),
    [anon_sym_int] = ACTIONS(6789),
    [anon_sym_longint] = ACTIONS(6789),
    [anon_sym_integer] = ACTIONS(6789),
    [anon_sym_time] = ACTIONS(6789),
    [anon_sym_bit] = ACTIONS(6789),
    [anon_sym_logic] = ACTIONS(6789),
    [anon_sym_reg] = ACTIONS(6789),
    [anon_sym_shortreal] = ACTIONS(6789),
    [anon_sym_real] = ACTIONS(6789),
    [anon_sym_realtime] = ACTIONS(6789),
    [anon_sym_supply0] = ACTIONS(6789),
    [anon_sym_supply1] = ACTIONS(6789),
    [anon_sym_signed] = ACTIONS(6789),
    [anon_sym_unsigned] = ACTIONS(6789),
    [anon_sym_task] = ACTIONS(6789),
    [anon_sym_assert] = ACTIONS(6789),
    [anon_sym_property] = ACTIONS(6789),
    [anon_sym_assume] = ACTIONS(6789),
    [anon_sym_cover] = ACTIONS(6789),
    [anon_sym_sequence] = ACTIONS(6789),
    [anon_sym_restrict] = ACTIONS(6789),
    [anon_sym_not] = ACTIONS(6789),
    [anon_sym_or] = ACTIONS(6789),
    [anon_sym_and] = ACTIONS(6789),
    [anon_sym_case] = ACTIONS(6789),
    [anon_sym_always] = ACTIONS(6789),
    [anon_sym_covergroup] = ACTIONS(6789),
    [anon_sym_end] = ACTIONS(6789),
    [anon_sym_let] = ACTIONS(6789),
    [anon_sym_pulldown] = ACTIONS(6789),
    [anon_sym_pullup] = ACTIONS(6789),
    [anon_sym_cmos] = ACTIONS(6789),
    [anon_sym_rcmos] = ACTIONS(6789),
    [anon_sym_bufif0] = ACTIONS(6789),
    [anon_sym_bufif1] = ACTIONS(6789),
    [anon_sym_notif0] = ACTIONS(6789),
    [anon_sym_notif1] = ACTIONS(6789),
    [anon_sym_nmos] = ACTIONS(6789),
    [anon_sym_pmos] = ACTIONS(6789),
    [anon_sym_rnmos] = ACTIONS(6789),
    [anon_sym_rpmos] = ACTIONS(6789),
    [anon_sym_nand] = ACTIONS(6789),
    [anon_sym_nor] = ACTIONS(6789),
    [anon_sym_xor] = ACTIONS(6789),
    [anon_sym_xnor] = ACTIONS(6789),
    [anon_sym_buf] = ACTIONS(6789),
    [anon_sym_tranif0] = ACTIONS(6789),
    [anon_sym_tranif1] = ACTIONS(6789),
    [anon_sym_rtranif1] = ACTIONS(6789),
    [anon_sym_rtranif0] = ACTIONS(6789),
    [anon_sym_tran] = ACTIONS(6789),
    [anon_sym_rtran] = ACTIONS(6789),
    [anon_sym_generate] = ACTIONS(6789),
    [anon_sym_for] = ACTIONS(6789),
    [anon_sym_initial] = ACTIONS(6789),
    [anon_sym_assign] = ACTIONS(6789),
    [anon_sym_alias] = ACTIONS(6789),
    [anon_sym_always_comb] = ACTIONS(6789),
    [anon_sym_always_latch] = ACTIONS(6789),
    [anon_sym_always_ff] = ACTIONS(6789),
    [anon_sym_final] = ACTIONS(6789),
    [anon_sym_global] = ACTIONS(6789),
    [anon_sym_LPAREN_STAR] = ACTIONS(6791),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6791),
    [anon_sym_DOLLARunit] = ACTIONS(6791),
  },
  [4633] = {
    [sym_simple_identifier] = ACTIONS(4584),
    [anon_sym_wire] = ACTIONS(4584),
    [anon_sym_tri] = ACTIONS(4584),
    [anon_sym_tri0] = ACTIONS(4584),
    [anon_sym_tri1] = ACTIONS(4584),
    [anon_sym_wand] = ACTIONS(4584),
    [anon_sym_triand] = ACTIONS(4584),
    [anon_sym_wor] = ACTIONS(4584),
    [anon_sym_trior] = ACTIONS(4584),
    [anon_sym_trireg] = ACTIONS(4584),
    [anon_sym_uwire] = ACTIONS(4584),
    [anon_sym_SEMI] = ACTIONS(4582),
    [anon_sym_extern] = ACTIONS(4584),
    [anon_sym_interface] = ACTIONS(4584),
    [anon_sym_checker] = ACTIONS(4584),
    [anon_sym_virtual] = ACTIONS(4584),
    [anon_sym_class] = ACTIONS(4584),
    [anon_sym_type] = ACTIONS(4584),
    [anon_sym_DOLLARfatal] = ACTIONS(4582),
    [anon_sym_DOLLARerror] = ACTIONS(4582),
    [anon_sym_DOLLARwarning] = ACTIONS(4582),
    [anon_sym_DOLLARinfo] = ACTIONS(4582),
    [anon_sym_default] = ACTIONS(4584),
    [anon_sym_clocking] = ACTIONS(4584),
    [anon_sym_defparam] = ACTIONS(4584),
    [anon_sym_bind] = ACTIONS(4584),
    [anon_sym_rand] = ACTIONS(4584),
    [anon_sym_const] = ACTIONS(4584),
    [anon_sym_function] = ACTIONS(4584),
    [anon_sym_static] = ACTIONS(4584),
    [anon_sym_constraint] = ACTIONS(4584),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4582),
    [anon_sym_localparam] = ACTIONS(4584),
    [anon_sym_parameter] = ACTIONS(4584),
    [anon_sym_var] = ACTIONS(4584),
    [anon_sym_import] = ACTIONS(4584),
    [anon_sym_export] = ACTIONS(4584),
    [anon_sym_genvar] = ACTIONS(4584),
    [anon_sym_interconnect] = ACTIONS(4584),
    [anon_sym_typedef] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_struct] = ACTIONS(4584),
    [anon_sym_union] = ACTIONS(4584),
    [anon_sym_nettype] = ACTIONS(4584),
    [anon_sym_automatic] = ACTIONS(4584),
    [anon_sym_string] = ACTIONS(4584),
    [anon_sym_chandle] = ACTIONS(4584),
    [anon_sym_event] = ACTIONS(4584),
    [anon_sym_byte] = ACTIONS(4584),
    [anon_sym_shortint] = ACTIONS(4584),
    [anon_sym_int] = ACTIONS(4584),
    [anon_sym_longint] = ACTIONS(4584),
    [anon_sym_integer] = ACTIONS(4584),
    [anon_sym_time] = ACTIONS(4584),
    [anon_sym_bit] = ACTIONS(4584),
    [anon_sym_logic] = ACTIONS(4584),
    [anon_sym_reg] = ACTIONS(4584),
    [anon_sym_shortreal] = ACTIONS(4584),
    [anon_sym_real] = ACTIONS(4584),
    [anon_sym_realtime] = ACTIONS(4584),
    [anon_sym_supply0] = ACTIONS(4584),
    [anon_sym_supply1] = ACTIONS(4584),
    [anon_sym_signed] = ACTIONS(4584),
    [anon_sym_unsigned] = ACTIONS(4584),
    [anon_sym_task] = ACTIONS(4584),
    [anon_sym_assert] = ACTIONS(4584),
    [anon_sym_property] = ACTIONS(4584),
    [anon_sym_assume] = ACTIONS(4584),
    [anon_sym_cover] = ACTIONS(4584),
    [anon_sym_sequence] = ACTIONS(4584),
    [anon_sym_restrict] = ACTIONS(4584),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_or] = ACTIONS(4584),
    [anon_sym_and] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_always] = ACTIONS(4584),
    [anon_sym_covergroup] = ACTIONS(4584),
    [anon_sym_end] = ACTIONS(4584),
    [anon_sym_let] = ACTIONS(4584),
    [anon_sym_pulldown] = ACTIONS(4584),
    [anon_sym_pullup] = ACTIONS(4584),
    [anon_sym_cmos] = ACTIONS(4584),
    [anon_sym_rcmos] = ACTIONS(4584),
    [anon_sym_bufif0] = ACTIONS(4584),
    [anon_sym_bufif1] = ACTIONS(4584),
    [anon_sym_notif0] = ACTIONS(4584),
    [anon_sym_notif1] = ACTIONS(4584),
    [anon_sym_nmos] = ACTIONS(4584),
    [anon_sym_pmos] = ACTIONS(4584),
    [anon_sym_rnmos] = ACTIONS(4584),
    [anon_sym_rpmos] = ACTIONS(4584),
    [anon_sym_nand] = ACTIONS(4584),
    [anon_sym_nor] = ACTIONS(4584),
    [anon_sym_xor] = ACTIONS(4584),
    [anon_sym_xnor] = ACTIONS(4584),
    [anon_sym_buf] = ACTIONS(4584),
    [anon_sym_tranif0] = ACTIONS(4584),
    [anon_sym_tranif1] = ACTIONS(4584),
    [anon_sym_rtranif1] = ACTIONS(4584),
    [anon_sym_rtranif0] = ACTIONS(4584),
    [anon_sym_tran] = ACTIONS(4584),
    [anon_sym_rtran] = ACTIONS(4584),
    [anon_sym_generate] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_initial] = ACTIONS(4584),
    [anon_sym_assign] = ACTIONS(4584),
    [anon_sym_alias] = ACTIONS(4584),
    [anon_sym_always_comb] = ACTIONS(4584),
    [anon_sym_always_latch] = ACTIONS(4584),
    [anon_sym_always_ff] = ACTIONS(4584),
    [anon_sym_final] = ACTIONS(4584),
    [anon_sym_global] = ACTIONS(4584),
    [anon_sym_LPAREN_STAR] = ACTIONS(4582),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4582),
    [anon_sym_DOLLARunit] = ACTIONS(4582),
  },
  [4634] = {
    [sym_simple_identifier] = ACTIONS(4600),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_rand] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_endgenerate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [4635] = {
    [sym_simple_identifier] = ACTIONS(6545),
    [anon_sym_wire] = ACTIONS(6545),
    [anon_sym_tri] = ACTIONS(6545),
    [anon_sym_tri0] = ACTIONS(6545),
    [anon_sym_tri1] = ACTIONS(6545),
    [anon_sym_wand] = ACTIONS(6545),
    [anon_sym_triand] = ACTIONS(6545),
    [anon_sym_wor] = ACTIONS(6545),
    [anon_sym_trior] = ACTIONS(6545),
    [anon_sym_trireg] = ACTIONS(6545),
    [anon_sym_uwire] = ACTIONS(6545),
    [anon_sym_SEMI] = ACTIONS(6547),
    [anon_sym_extern] = ACTIONS(6545),
    [anon_sym_interface] = ACTIONS(6545),
    [anon_sym_checker] = ACTIONS(6545),
    [anon_sym_virtual] = ACTIONS(6545),
    [anon_sym_class] = ACTIONS(6545),
    [anon_sym_type] = ACTIONS(6545),
    [anon_sym_DOLLARfatal] = ACTIONS(6547),
    [anon_sym_DOLLARerror] = ACTIONS(6547),
    [anon_sym_DOLLARwarning] = ACTIONS(6547),
    [anon_sym_DOLLARinfo] = ACTIONS(6547),
    [anon_sym_default] = ACTIONS(6545),
    [anon_sym_clocking] = ACTIONS(6545),
    [anon_sym_defparam] = ACTIONS(6545),
    [anon_sym_bind] = ACTIONS(6545),
    [anon_sym_rand] = ACTIONS(6545),
    [anon_sym_const] = ACTIONS(6545),
    [anon_sym_function] = ACTIONS(6545),
    [anon_sym_static] = ACTIONS(6545),
    [anon_sym_constraint] = ACTIONS(6545),
    [anon_sym_if] = ACTIONS(6545),
    [anon_sym_else] = ACTIONS(6545),
    [anon_sym_LBRACK] = ACTIONS(6547),
    [anon_sym_localparam] = ACTIONS(6545),
    [anon_sym_parameter] = ACTIONS(6545),
    [anon_sym_var] = ACTIONS(6545),
    [anon_sym_import] = ACTIONS(6545),
    [anon_sym_export] = ACTIONS(6545),
    [anon_sym_genvar] = ACTIONS(6545),
    [anon_sym_interconnect] = ACTIONS(6545),
    [anon_sym_typedef] = ACTIONS(6545),
    [anon_sym_enum] = ACTIONS(6545),
    [anon_sym_struct] = ACTIONS(6545),
    [anon_sym_union] = ACTIONS(6545),
    [anon_sym_nettype] = ACTIONS(6545),
    [anon_sym_automatic] = ACTIONS(6545),
    [anon_sym_string] = ACTIONS(6545),
    [anon_sym_chandle] = ACTIONS(6545),
    [anon_sym_event] = ACTIONS(6545),
    [anon_sym_byte] = ACTIONS(6545),
    [anon_sym_shortint] = ACTIONS(6545),
    [anon_sym_int] = ACTIONS(6545),
    [anon_sym_longint] = ACTIONS(6545),
    [anon_sym_integer] = ACTIONS(6545),
    [anon_sym_time] = ACTIONS(6545),
    [anon_sym_bit] = ACTIONS(6545),
    [anon_sym_logic] = ACTIONS(6545),
    [anon_sym_reg] = ACTIONS(6545),
    [anon_sym_shortreal] = ACTIONS(6545),
    [anon_sym_real] = ACTIONS(6545),
    [anon_sym_realtime] = ACTIONS(6545),
    [anon_sym_supply0] = ACTIONS(6545),
    [anon_sym_supply1] = ACTIONS(6545),
    [anon_sym_signed] = ACTIONS(6545),
    [anon_sym_unsigned] = ACTIONS(6545),
    [anon_sym_task] = ACTIONS(6545),
    [anon_sym_assert] = ACTIONS(6545),
    [anon_sym_property] = ACTIONS(6545),
    [anon_sym_assume] = ACTIONS(6545),
    [anon_sym_cover] = ACTIONS(6545),
    [anon_sym_sequence] = ACTIONS(6545),
    [anon_sym_restrict] = ACTIONS(6545),
    [anon_sym_not] = ACTIONS(6545),
    [anon_sym_or] = ACTIONS(6545),
    [anon_sym_and] = ACTIONS(6545),
    [anon_sym_case] = ACTIONS(6545),
    [anon_sym_always] = ACTIONS(6545),
    [anon_sym_covergroup] = ACTIONS(6545),
    [anon_sym_end] = ACTIONS(6545),
    [anon_sym_let] = ACTIONS(6545),
    [anon_sym_pulldown] = ACTIONS(6545),
    [anon_sym_pullup] = ACTIONS(6545),
    [anon_sym_cmos] = ACTIONS(6545),
    [anon_sym_rcmos] = ACTIONS(6545),
    [anon_sym_bufif0] = ACTIONS(6545),
    [anon_sym_bufif1] = ACTIONS(6545),
    [anon_sym_notif0] = ACTIONS(6545),
    [anon_sym_notif1] = ACTIONS(6545),
    [anon_sym_nmos] = ACTIONS(6545),
    [anon_sym_pmos] = ACTIONS(6545),
    [anon_sym_rnmos] = ACTIONS(6545),
    [anon_sym_rpmos] = ACTIONS(6545),
    [anon_sym_nand] = ACTIONS(6545),
    [anon_sym_nor] = ACTIONS(6545),
    [anon_sym_xor] = ACTIONS(6545),
    [anon_sym_xnor] = ACTIONS(6545),
    [anon_sym_buf] = ACTIONS(6545),
    [anon_sym_tranif0] = ACTIONS(6545),
    [anon_sym_tranif1] = ACTIONS(6545),
    [anon_sym_rtranif1] = ACTIONS(6545),
    [anon_sym_rtranif0] = ACTIONS(6545),
    [anon_sym_tran] = ACTIONS(6545),
    [anon_sym_rtran] = ACTIONS(6545),
    [anon_sym_generate] = ACTIONS(6545),
    [anon_sym_for] = ACTIONS(6545),
    [anon_sym_initial] = ACTIONS(6545),
    [anon_sym_assign] = ACTIONS(6545),
    [anon_sym_alias] = ACTIONS(6545),
    [anon_sym_always_comb] = ACTIONS(6545),
    [anon_sym_always_latch] = ACTIONS(6545),
    [anon_sym_always_ff] = ACTIONS(6545),
    [anon_sym_final] = ACTIONS(6545),
    [anon_sym_global] = ACTIONS(6545),
    [anon_sym_LPAREN_STAR] = ACTIONS(6547),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6547),
    [anon_sym_DOLLARunit] = ACTIONS(6547),
  },
  [4636] = {
    [sym_simple_identifier] = ACTIONS(6053),
    [anon_sym_wire] = ACTIONS(6053),
    [anon_sym_tri] = ACTIONS(6053),
    [anon_sym_tri0] = ACTIONS(6053),
    [anon_sym_tri1] = ACTIONS(6053),
    [anon_sym_wand] = ACTIONS(6053),
    [anon_sym_triand] = ACTIONS(6053),
    [anon_sym_wor] = ACTIONS(6053),
    [anon_sym_trior] = ACTIONS(6053),
    [anon_sym_trireg] = ACTIONS(6053),
    [anon_sym_uwire] = ACTIONS(6053),
    [anon_sym_SEMI] = ACTIONS(6055),
    [anon_sym_extern] = ACTIONS(6053),
    [anon_sym_interface] = ACTIONS(6053),
    [anon_sym_checker] = ACTIONS(6053),
    [anon_sym_virtual] = ACTIONS(6053),
    [anon_sym_class] = ACTIONS(6053),
    [anon_sym_type] = ACTIONS(6053),
    [anon_sym_DOLLARfatal] = ACTIONS(6055),
    [anon_sym_DOLLARerror] = ACTIONS(6055),
    [anon_sym_DOLLARwarning] = ACTIONS(6055),
    [anon_sym_DOLLARinfo] = ACTIONS(6055),
    [anon_sym_default] = ACTIONS(6053),
    [anon_sym_clocking] = ACTIONS(6053),
    [anon_sym_defparam] = ACTIONS(6053),
    [anon_sym_bind] = ACTIONS(6053),
    [anon_sym_rand] = ACTIONS(6053),
    [anon_sym_const] = ACTIONS(6053),
    [anon_sym_function] = ACTIONS(6053),
    [anon_sym_static] = ACTIONS(6053),
    [anon_sym_constraint] = ACTIONS(6053),
    [anon_sym_if] = ACTIONS(6053),
    [anon_sym_else] = ACTIONS(6053),
    [anon_sym_LBRACK] = ACTIONS(6055),
    [anon_sym_localparam] = ACTIONS(6053),
    [anon_sym_parameter] = ACTIONS(6053),
    [anon_sym_var] = ACTIONS(6053),
    [anon_sym_import] = ACTIONS(6053),
    [anon_sym_export] = ACTIONS(6053),
    [anon_sym_genvar] = ACTIONS(6053),
    [anon_sym_interconnect] = ACTIONS(6053),
    [anon_sym_typedef] = ACTIONS(6053),
    [anon_sym_enum] = ACTIONS(6053),
    [anon_sym_struct] = ACTIONS(6053),
    [anon_sym_union] = ACTIONS(6053),
    [anon_sym_nettype] = ACTIONS(6053),
    [anon_sym_automatic] = ACTIONS(6053),
    [anon_sym_string] = ACTIONS(6053),
    [anon_sym_chandle] = ACTIONS(6053),
    [anon_sym_event] = ACTIONS(6053),
    [anon_sym_byte] = ACTIONS(6053),
    [anon_sym_shortint] = ACTIONS(6053),
    [anon_sym_int] = ACTIONS(6053),
    [anon_sym_longint] = ACTIONS(6053),
    [anon_sym_integer] = ACTIONS(6053),
    [anon_sym_time] = ACTIONS(6053),
    [anon_sym_bit] = ACTIONS(6053),
    [anon_sym_logic] = ACTIONS(6053),
    [anon_sym_reg] = ACTIONS(6053),
    [anon_sym_shortreal] = ACTIONS(6053),
    [anon_sym_real] = ACTIONS(6053),
    [anon_sym_realtime] = ACTIONS(6053),
    [anon_sym_supply0] = ACTIONS(6053),
    [anon_sym_supply1] = ACTIONS(6053),
    [anon_sym_signed] = ACTIONS(6053),
    [anon_sym_unsigned] = ACTIONS(6053),
    [anon_sym_task] = ACTIONS(6053),
    [anon_sym_assert] = ACTIONS(6053),
    [anon_sym_property] = ACTIONS(6053),
    [anon_sym_assume] = ACTIONS(6053),
    [anon_sym_cover] = ACTIONS(6053),
    [anon_sym_sequence] = ACTIONS(6053),
    [anon_sym_restrict] = ACTIONS(6053),
    [anon_sym_not] = ACTIONS(6053),
    [anon_sym_or] = ACTIONS(6053),
    [anon_sym_and] = ACTIONS(6053),
    [anon_sym_case] = ACTIONS(6053),
    [anon_sym_always] = ACTIONS(6053),
    [anon_sym_covergroup] = ACTIONS(6053),
    [anon_sym_end] = ACTIONS(6053),
    [anon_sym_let] = ACTIONS(6053),
    [anon_sym_pulldown] = ACTIONS(6053),
    [anon_sym_pullup] = ACTIONS(6053),
    [anon_sym_cmos] = ACTIONS(6053),
    [anon_sym_rcmos] = ACTIONS(6053),
    [anon_sym_bufif0] = ACTIONS(6053),
    [anon_sym_bufif1] = ACTIONS(6053),
    [anon_sym_notif0] = ACTIONS(6053),
    [anon_sym_notif1] = ACTIONS(6053),
    [anon_sym_nmos] = ACTIONS(6053),
    [anon_sym_pmos] = ACTIONS(6053),
    [anon_sym_rnmos] = ACTIONS(6053),
    [anon_sym_rpmos] = ACTIONS(6053),
    [anon_sym_nand] = ACTIONS(6053),
    [anon_sym_nor] = ACTIONS(6053),
    [anon_sym_xor] = ACTIONS(6053),
    [anon_sym_xnor] = ACTIONS(6053),
    [anon_sym_buf] = ACTIONS(6053),
    [anon_sym_tranif0] = ACTIONS(6053),
    [anon_sym_tranif1] = ACTIONS(6053),
    [anon_sym_rtranif1] = ACTIONS(6053),
    [anon_sym_rtranif0] = ACTIONS(6053),
    [anon_sym_tran] = ACTIONS(6053),
    [anon_sym_rtran] = ACTIONS(6053),
    [anon_sym_generate] = ACTIONS(6053),
    [anon_sym_for] = ACTIONS(6053),
    [anon_sym_initial] = ACTIONS(6053),
    [anon_sym_assign] = ACTIONS(6053),
    [anon_sym_alias] = ACTIONS(6053),
    [anon_sym_always_comb] = ACTIONS(6053),
    [anon_sym_always_latch] = ACTIONS(6053),
    [anon_sym_always_ff] = ACTIONS(6053),
    [anon_sym_final] = ACTIONS(6053),
    [anon_sym_global] = ACTIONS(6053),
    [anon_sym_LPAREN_STAR] = ACTIONS(6055),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6055),
    [anon_sym_DOLLARunit] = ACTIONS(6055),
  },
  [4637] = {
    [sym_simple_identifier] = ACTIONS(5270),
    [anon_sym_wire] = ACTIONS(5270),
    [anon_sym_tri] = ACTIONS(5270),
    [anon_sym_tri0] = ACTIONS(5270),
    [anon_sym_tri1] = ACTIONS(5270),
    [anon_sym_wand] = ACTIONS(5270),
    [anon_sym_triand] = ACTIONS(5270),
    [anon_sym_wor] = ACTIONS(5270),
    [anon_sym_trior] = ACTIONS(5270),
    [anon_sym_trireg] = ACTIONS(5270),
    [anon_sym_uwire] = ACTIONS(5270),
    [anon_sym_SEMI] = ACTIONS(5268),
    [anon_sym_extern] = ACTIONS(5270),
    [anon_sym_interface] = ACTIONS(5270),
    [anon_sym_checker] = ACTIONS(5270),
    [anon_sym_virtual] = ACTIONS(5270),
    [anon_sym_class] = ACTIONS(5270),
    [anon_sym_type] = ACTIONS(5270),
    [anon_sym_DOLLARfatal] = ACTIONS(5268),
    [anon_sym_DOLLARerror] = ACTIONS(5268),
    [anon_sym_DOLLARwarning] = ACTIONS(5268),
    [anon_sym_DOLLARinfo] = ACTIONS(5268),
    [anon_sym_default] = ACTIONS(5270),
    [anon_sym_clocking] = ACTIONS(5270),
    [anon_sym_defparam] = ACTIONS(5270),
    [anon_sym_bind] = ACTIONS(5270),
    [anon_sym_rand] = ACTIONS(5270),
    [anon_sym_const] = ACTIONS(5270),
    [anon_sym_function] = ACTIONS(5270),
    [anon_sym_static] = ACTIONS(5270),
    [anon_sym_constraint] = ACTIONS(5270),
    [anon_sym_if] = ACTIONS(5270),
    [anon_sym_else] = ACTIONS(5270),
    [anon_sym_LBRACK] = ACTIONS(5268),
    [anon_sym_localparam] = ACTIONS(5270),
    [anon_sym_parameter] = ACTIONS(5270),
    [anon_sym_var] = ACTIONS(5270),
    [anon_sym_import] = ACTIONS(5270),
    [anon_sym_export] = ACTIONS(5270),
    [anon_sym_genvar] = ACTIONS(5270),
    [anon_sym_interconnect] = ACTIONS(5270),
    [anon_sym_typedef] = ACTIONS(5270),
    [anon_sym_enum] = ACTIONS(5270),
    [anon_sym_struct] = ACTIONS(5270),
    [anon_sym_union] = ACTIONS(5270),
    [anon_sym_nettype] = ACTIONS(5270),
    [anon_sym_automatic] = ACTIONS(5270),
    [anon_sym_string] = ACTIONS(5270),
    [anon_sym_chandle] = ACTIONS(5270),
    [anon_sym_event] = ACTIONS(5270),
    [anon_sym_byte] = ACTIONS(5270),
    [anon_sym_shortint] = ACTIONS(5270),
    [anon_sym_int] = ACTIONS(5270),
    [anon_sym_longint] = ACTIONS(5270),
    [anon_sym_integer] = ACTIONS(5270),
    [anon_sym_time] = ACTIONS(5270),
    [anon_sym_bit] = ACTIONS(5270),
    [anon_sym_logic] = ACTIONS(5270),
    [anon_sym_reg] = ACTIONS(5270),
    [anon_sym_shortreal] = ACTIONS(5270),
    [anon_sym_real] = ACTIONS(5270),
    [anon_sym_realtime] = ACTIONS(5270),
    [anon_sym_supply0] = ACTIONS(5270),
    [anon_sym_supply1] = ACTIONS(5270),
    [anon_sym_signed] = ACTIONS(5270),
    [anon_sym_unsigned] = ACTIONS(5270),
    [anon_sym_task] = ACTIONS(5270),
    [anon_sym_assert] = ACTIONS(5270),
    [anon_sym_property] = ACTIONS(5270),
    [anon_sym_assume] = ACTIONS(5270),
    [anon_sym_cover] = ACTIONS(5270),
    [anon_sym_sequence] = ACTIONS(5270),
    [anon_sym_restrict] = ACTIONS(5270),
    [anon_sym_not] = ACTIONS(5270),
    [anon_sym_or] = ACTIONS(5270),
    [anon_sym_and] = ACTIONS(5270),
    [anon_sym_case] = ACTIONS(5270),
    [anon_sym_always] = ACTIONS(5270),
    [anon_sym_covergroup] = ACTIONS(5270),
    [anon_sym_end] = ACTIONS(5270),
    [anon_sym_let] = ACTIONS(5270),
    [anon_sym_pulldown] = ACTIONS(5270),
    [anon_sym_pullup] = ACTIONS(5270),
    [anon_sym_cmos] = ACTIONS(5270),
    [anon_sym_rcmos] = ACTIONS(5270),
    [anon_sym_bufif0] = ACTIONS(5270),
    [anon_sym_bufif1] = ACTIONS(5270),
    [anon_sym_notif0] = ACTIONS(5270),
    [anon_sym_notif1] = ACTIONS(5270),
    [anon_sym_nmos] = ACTIONS(5270),
    [anon_sym_pmos] = ACTIONS(5270),
    [anon_sym_rnmos] = ACTIONS(5270),
    [anon_sym_rpmos] = ACTIONS(5270),
    [anon_sym_nand] = ACTIONS(5270),
    [anon_sym_nor] = ACTIONS(5270),
    [anon_sym_xor] = ACTIONS(5270),
    [anon_sym_xnor] = ACTIONS(5270),
    [anon_sym_buf] = ACTIONS(5270),
    [anon_sym_tranif0] = ACTIONS(5270),
    [anon_sym_tranif1] = ACTIONS(5270),
    [anon_sym_rtranif1] = ACTIONS(5270),
    [anon_sym_rtranif0] = ACTIONS(5270),
    [anon_sym_tran] = ACTIONS(5270),
    [anon_sym_rtran] = ACTIONS(5270),
    [anon_sym_generate] = ACTIONS(5270),
    [anon_sym_for] = ACTIONS(5270),
    [anon_sym_initial] = ACTIONS(5270),
    [anon_sym_assign] = ACTIONS(5270),
    [anon_sym_alias] = ACTIONS(5270),
    [anon_sym_always_comb] = ACTIONS(5270),
    [anon_sym_always_latch] = ACTIONS(5270),
    [anon_sym_always_ff] = ACTIONS(5270),
    [anon_sym_final] = ACTIONS(5270),
    [anon_sym_global] = ACTIONS(5270),
    [anon_sym_LPAREN_STAR] = ACTIONS(5268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5268),
    [anon_sym_DOLLARunit] = ACTIONS(5268),
  },
  [4638] = {
    [sym_simple_identifier] = ACTIONS(4932),
    [anon_sym_wire] = ACTIONS(4932),
    [anon_sym_tri] = ACTIONS(4932),
    [anon_sym_tri0] = ACTIONS(4932),
    [anon_sym_tri1] = ACTIONS(4932),
    [anon_sym_wand] = ACTIONS(4932),
    [anon_sym_triand] = ACTIONS(4932),
    [anon_sym_wor] = ACTIONS(4932),
    [anon_sym_trior] = ACTIONS(4932),
    [anon_sym_trireg] = ACTIONS(4932),
    [anon_sym_uwire] = ACTIONS(4932),
    [anon_sym_SEMI] = ACTIONS(4930),
    [anon_sym_extern] = ACTIONS(4932),
    [anon_sym_interface] = ACTIONS(4932),
    [anon_sym_checker] = ACTIONS(4932),
    [anon_sym_virtual] = ACTIONS(4932),
    [anon_sym_class] = ACTIONS(4932),
    [anon_sym_type] = ACTIONS(4932),
    [anon_sym_DOLLARfatal] = ACTIONS(4930),
    [anon_sym_DOLLARerror] = ACTIONS(4930),
    [anon_sym_DOLLARwarning] = ACTIONS(4930),
    [anon_sym_DOLLARinfo] = ACTIONS(4930),
    [anon_sym_default] = ACTIONS(4932),
    [anon_sym_clocking] = ACTIONS(4932),
    [anon_sym_defparam] = ACTIONS(4932),
    [anon_sym_bind] = ACTIONS(4932),
    [anon_sym_rand] = ACTIONS(4932),
    [anon_sym_const] = ACTIONS(4932),
    [anon_sym_function] = ACTIONS(4932),
    [anon_sym_static] = ACTIONS(4932),
    [anon_sym_constraint] = ACTIONS(4932),
    [anon_sym_if] = ACTIONS(4932),
    [anon_sym_else] = ACTIONS(4932),
    [anon_sym_LBRACK] = ACTIONS(4930),
    [anon_sym_localparam] = ACTIONS(4932),
    [anon_sym_parameter] = ACTIONS(4932),
    [anon_sym_var] = ACTIONS(4932),
    [anon_sym_import] = ACTIONS(4932),
    [anon_sym_export] = ACTIONS(4932),
    [anon_sym_genvar] = ACTIONS(4932),
    [anon_sym_interconnect] = ACTIONS(4932),
    [anon_sym_typedef] = ACTIONS(4932),
    [anon_sym_enum] = ACTIONS(4932),
    [anon_sym_struct] = ACTIONS(4932),
    [anon_sym_union] = ACTIONS(4932),
    [anon_sym_nettype] = ACTIONS(4932),
    [anon_sym_automatic] = ACTIONS(4932),
    [anon_sym_string] = ACTIONS(4932),
    [anon_sym_chandle] = ACTIONS(4932),
    [anon_sym_event] = ACTIONS(4932),
    [anon_sym_byte] = ACTIONS(4932),
    [anon_sym_shortint] = ACTIONS(4932),
    [anon_sym_int] = ACTIONS(4932),
    [anon_sym_longint] = ACTIONS(4932),
    [anon_sym_integer] = ACTIONS(4932),
    [anon_sym_time] = ACTIONS(4932),
    [anon_sym_bit] = ACTIONS(4932),
    [anon_sym_logic] = ACTIONS(4932),
    [anon_sym_reg] = ACTIONS(4932),
    [anon_sym_shortreal] = ACTIONS(4932),
    [anon_sym_real] = ACTIONS(4932),
    [anon_sym_realtime] = ACTIONS(4932),
    [anon_sym_supply0] = ACTIONS(4932),
    [anon_sym_supply1] = ACTIONS(4932),
    [anon_sym_signed] = ACTIONS(4932),
    [anon_sym_unsigned] = ACTIONS(4932),
    [anon_sym_task] = ACTIONS(4932),
    [anon_sym_assert] = ACTIONS(4932),
    [anon_sym_property] = ACTIONS(4932),
    [anon_sym_assume] = ACTIONS(4932),
    [anon_sym_cover] = ACTIONS(4932),
    [anon_sym_sequence] = ACTIONS(4932),
    [anon_sym_restrict] = ACTIONS(4932),
    [anon_sym_not] = ACTIONS(4932),
    [anon_sym_or] = ACTIONS(4932),
    [anon_sym_and] = ACTIONS(4932),
    [anon_sym_case] = ACTIONS(4932),
    [anon_sym_always] = ACTIONS(4932),
    [anon_sym_covergroup] = ACTIONS(4932),
    [anon_sym_let] = ACTIONS(4932),
    [anon_sym_pulldown] = ACTIONS(4932),
    [anon_sym_pullup] = ACTIONS(4932),
    [anon_sym_cmos] = ACTIONS(4932),
    [anon_sym_rcmos] = ACTIONS(4932),
    [anon_sym_bufif0] = ACTIONS(4932),
    [anon_sym_bufif1] = ACTIONS(4932),
    [anon_sym_notif0] = ACTIONS(4932),
    [anon_sym_notif1] = ACTIONS(4932),
    [anon_sym_nmos] = ACTIONS(4932),
    [anon_sym_pmos] = ACTIONS(4932),
    [anon_sym_rnmos] = ACTIONS(4932),
    [anon_sym_rpmos] = ACTIONS(4932),
    [anon_sym_nand] = ACTIONS(4932),
    [anon_sym_nor] = ACTIONS(4932),
    [anon_sym_xor] = ACTIONS(4932),
    [anon_sym_xnor] = ACTIONS(4932),
    [anon_sym_buf] = ACTIONS(4932),
    [anon_sym_tranif0] = ACTIONS(4932),
    [anon_sym_tranif1] = ACTIONS(4932),
    [anon_sym_rtranif1] = ACTIONS(4932),
    [anon_sym_rtranif0] = ACTIONS(4932),
    [anon_sym_tran] = ACTIONS(4932),
    [anon_sym_rtran] = ACTIONS(4932),
    [anon_sym_generate] = ACTIONS(4932),
    [anon_sym_endgenerate] = ACTIONS(4932),
    [anon_sym_for] = ACTIONS(4932),
    [anon_sym_initial] = ACTIONS(4932),
    [anon_sym_assign] = ACTIONS(4932),
    [anon_sym_alias] = ACTIONS(4932),
    [anon_sym_always_comb] = ACTIONS(4932),
    [anon_sym_always_latch] = ACTIONS(4932),
    [anon_sym_always_ff] = ACTIONS(4932),
    [anon_sym_final] = ACTIONS(4932),
    [anon_sym_global] = ACTIONS(4932),
    [anon_sym_LPAREN_STAR] = ACTIONS(4930),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4930),
    [anon_sym_DOLLARunit] = ACTIONS(4930),
  },
  [4639] = {
    [sym_simple_identifier] = ACTIONS(4518),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_rand] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_endgenerate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [4640] = {
    [sym_simple_identifier] = ACTIONS(6687),
    [anon_sym_wire] = ACTIONS(6687),
    [anon_sym_tri] = ACTIONS(6687),
    [anon_sym_tri0] = ACTIONS(6687),
    [anon_sym_tri1] = ACTIONS(6687),
    [anon_sym_wand] = ACTIONS(6687),
    [anon_sym_triand] = ACTIONS(6687),
    [anon_sym_wor] = ACTIONS(6687),
    [anon_sym_trior] = ACTIONS(6687),
    [anon_sym_trireg] = ACTIONS(6687),
    [anon_sym_uwire] = ACTIONS(6687),
    [anon_sym_SEMI] = ACTIONS(6689),
    [anon_sym_extern] = ACTIONS(6687),
    [anon_sym_interface] = ACTIONS(6687),
    [anon_sym_checker] = ACTIONS(6687),
    [anon_sym_virtual] = ACTIONS(6687),
    [anon_sym_class] = ACTIONS(6687),
    [anon_sym_type] = ACTIONS(6687),
    [anon_sym_DOLLARfatal] = ACTIONS(6689),
    [anon_sym_DOLLARerror] = ACTIONS(6689),
    [anon_sym_DOLLARwarning] = ACTIONS(6689),
    [anon_sym_DOLLARinfo] = ACTIONS(6689),
    [anon_sym_default] = ACTIONS(6687),
    [anon_sym_clocking] = ACTIONS(6687),
    [anon_sym_defparam] = ACTIONS(6687),
    [anon_sym_bind] = ACTIONS(6687),
    [anon_sym_rand] = ACTIONS(6687),
    [anon_sym_const] = ACTIONS(6687),
    [anon_sym_function] = ACTIONS(6687),
    [anon_sym_static] = ACTIONS(6687),
    [anon_sym_constraint] = ACTIONS(6687),
    [anon_sym_if] = ACTIONS(6687),
    [anon_sym_else] = ACTIONS(6687),
    [anon_sym_LBRACK] = ACTIONS(6689),
    [anon_sym_localparam] = ACTIONS(6687),
    [anon_sym_parameter] = ACTIONS(6687),
    [anon_sym_var] = ACTIONS(6687),
    [anon_sym_import] = ACTIONS(6687),
    [anon_sym_export] = ACTIONS(6687),
    [anon_sym_genvar] = ACTIONS(6687),
    [anon_sym_interconnect] = ACTIONS(6687),
    [anon_sym_typedef] = ACTIONS(6687),
    [anon_sym_enum] = ACTIONS(6687),
    [anon_sym_struct] = ACTIONS(6687),
    [anon_sym_union] = ACTIONS(6687),
    [anon_sym_nettype] = ACTIONS(6687),
    [anon_sym_automatic] = ACTIONS(6687),
    [anon_sym_string] = ACTIONS(6687),
    [anon_sym_chandle] = ACTIONS(6687),
    [anon_sym_event] = ACTIONS(6687),
    [anon_sym_byte] = ACTIONS(6687),
    [anon_sym_shortint] = ACTIONS(6687),
    [anon_sym_int] = ACTIONS(6687),
    [anon_sym_longint] = ACTIONS(6687),
    [anon_sym_integer] = ACTIONS(6687),
    [anon_sym_time] = ACTIONS(6687),
    [anon_sym_bit] = ACTIONS(6687),
    [anon_sym_logic] = ACTIONS(6687),
    [anon_sym_reg] = ACTIONS(6687),
    [anon_sym_shortreal] = ACTIONS(6687),
    [anon_sym_real] = ACTIONS(6687),
    [anon_sym_realtime] = ACTIONS(6687),
    [anon_sym_supply0] = ACTIONS(6687),
    [anon_sym_supply1] = ACTIONS(6687),
    [anon_sym_signed] = ACTIONS(6687),
    [anon_sym_unsigned] = ACTIONS(6687),
    [anon_sym_task] = ACTIONS(6687),
    [anon_sym_assert] = ACTIONS(6687),
    [anon_sym_property] = ACTIONS(6687),
    [anon_sym_assume] = ACTIONS(6687),
    [anon_sym_cover] = ACTIONS(6687),
    [anon_sym_sequence] = ACTIONS(6687),
    [anon_sym_restrict] = ACTIONS(6687),
    [anon_sym_not] = ACTIONS(6687),
    [anon_sym_or] = ACTIONS(6687),
    [anon_sym_and] = ACTIONS(6687),
    [anon_sym_case] = ACTIONS(6687),
    [anon_sym_always] = ACTIONS(6687),
    [anon_sym_covergroup] = ACTIONS(6687),
    [anon_sym_let] = ACTIONS(6687),
    [anon_sym_pulldown] = ACTIONS(6687),
    [anon_sym_pullup] = ACTIONS(6687),
    [anon_sym_cmos] = ACTIONS(6687),
    [anon_sym_rcmos] = ACTIONS(6687),
    [anon_sym_bufif0] = ACTIONS(6687),
    [anon_sym_bufif1] = ACTIONS(6687),
    [anon_sym_notif0] = ACTIONS(6687),
    [anon_sym_notif1] = ACTIONS(6687),
    [anon_sym_nmos] = ACTIONS(6687),
    [anon_sym_pmos] = ACTIONS(6687),
    [anon_sym_rnmos] = ACTIONS(6687),
    [anon_sym_rpmos] = ACTIONS(6687),
    [anon_sym_nand] = ACTIONS(6687),
    [anon_sym_nor] = ACTIONS(6687),
    [anon_sym_xor] = ACTIONS(6687),
    [anon_sym_xnor] = ACTIONS(6687),
    [anon_sym_buf] = ACTIONS(6687),
    [anon_sym_tranif0] = ACTIONS(6687),
    [anon_sym_tranif1] = ACTIONS(6687),
    [anon_sym_rtranif1] = ACTIONS(6687),
    [anon_sym_rtranif0] = ACTIONS(6687),
    [anon_sym_tran] = ACTIONS(6687),
    [anon_sym_rtran] = ACTIONS(6687),
    [anon_sym_generate] = ACTIONS(6687),
    [anon_sym_endgenerate] = ACTIONS(6687),
    [anon_sym_for] = ACTIONS(6687),
    [anon_sym_initial] = ACTIONS(6687),
    [anon_sym_assign] = ACTIONS(6687),
    [anon_sym_alias] = ACTIONS(6687),
    [anon_sym_always_comb] = ACTIONS(6687),
    [anon_sym_always_latch] = ACTIONS(6687),
    [anon_sym_always_ff] = ACTIONS(6687),
    [anon_sym_final] = ACTIONS(6687),
    [anon_sym_global] = ACTIONS(6687),
    [anon_sym_LPAREN_STAR] = ACTIONS(6689),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6689),
    [anon_sym_DOLLARunit] = ACTIONS(6689),
  },
  [4641] = {
    [sym_simple_identifier] = ACTIONS(6627),
    [anon_sym_wire] = ACTIONS(6627),
    [anon_sym_tri] = ACTIONS(6627),
    [anon_sym_tri0] = ACTIONS(6627),
    [anon_sym_tri1] = ACTIONS(6627),
    [anon_sym_wand] = ACTIONS(6627),
    [anon_sym_triand] = ACTIONS(6627),
    [anon_sym_wor] = ACTIONS(6627),
    [anon_sym_trior] = ACTIONS(6627),
    [anon_sym_trireg] = ACTIONS(6627),
    [anon_sym_uwire] = ACTIONS(6627),
    [anon_sym_SEMI] = ACTIONS(6629),
    [anon_sym_extern] = ACTIONS(6627),
    [anon_sym_interface] = ACTIONS(6627),
    [anon_sym_checker] = ACTIONS(6627),
    [anon_sym_virtual] = ACTIONS(6627),
    [anon_sym_class] = ACTIONS(6627),
    [anon_sym_type] = ACTIONS(6627),
    [anon_sym_DOLLARfatal] = ACTIONS(6629),
    [anon_sym_DOLLARerror] = ACTIONS(6629),
    [anon_sym_DOLLARwarning] = ACTIONS(6629),
    [anon_sym_DOLLARinfo] = ACTIONS(6629),
    [anon_sym_default] = ACTIONS(6627),
    [anon_sym_clocking] = ACTIONS(6627),
    [anon_sym_defparam] = ACTIONS(6627),
    [anon_sym_bind] = ACTIONS(6627),
    [anon_sym_rand] = ACTIONS(6627),
    [anon_sym_const] = ACTIONS(6627),
    [anon_sym_function] = ACTIONS(6627),
    [anon_sym_static] = ACTIONS(6627),
    [anon_sym_constraint] = ACTIONS(6627),
    [anon_sym_if] = ACTIONS(6627),
    [anon_sym_else] = ACTIONS(6627),
    [anon_sym_LBRACK] = ACTIONS(6629),
    [anon_sym_localparam] = ACTIONS(6627),
    [anon_sym_parameter] = ACTIONS(6627),
    [anon_sym_var] = ACTIONS(6627),
    [anon_sym_import] = ACTIONS(6627),
    [anon_sym_export] = ACTIONS(6627),
    [anon_sym_genvar] = ACTIONS(6627),
    [anon_sym_interconnect] = ACTIONS(6627),
    [anon_sym_typedef] = ACTIONS(6627),
    [anon_sym_enum] = ACTIONS(6627),
    [anon_sym_struct] = ACTIONS(6627),
    [anon_sym_union] = ACTIONS(6627),
    [anon_sym_nettype] = ACTIONS(6627),
    [anon_sym_automatic] = ACTIONS(6627),
    [anon_sym_string] = ACTIONS(6627),
    [anon_sym_chandle] = ACTIONS(6627),
    [anon_sym_event] = ACTIONS(6627),
    [anon_sym_byte] = ACTIONS(6627),
    [anon_sym_shortint] = ACTIONS(6627),
    [anon_sym_int] = ACTIONS(6627),
    [anon_sym_longint] = ACTIONS(6627),
    [anon_sym_integer] = ACTIONS(6627),
    [anon_sym_time] = ACTIONS(6627),
    [anon_sym_bit] = ACTIONS(6627),
    [anon_sym_logic] = ACTIONS(6627),
    [anon_sym_reg] = ACTIONS(6627),
    [anon_sym_shortreal] = ACTIONS(6627),
    [anon_sym_real] = ACTIONS(6627),
    [anon_sym_realtime] = ACTIONS(6627),
    [anon_sym_supply0] = ACTIONS(6627),
    [anon_sym_supply1] = ACTIONS(6627),
    [anon_sym_signed] = ACTIONS(6627),
    [anon_sym_unsigned] = ACTIONS(6627),
    [anon_sym_task] = ACTIONS(6627),
    [anon_sym_assert] = ACTIONS(6627),
    [anon_sym_property] = ACTIONS(6627),
    [anon_sym_assume] = ACTIONS(6627),
    [anon_sym_cover] = ACTIONS(6627),
    [anon_sym_sequence] = ACTIONS(6627),
    [anon_sym_restrict] = ACTIONS(6627),
    [anon_sym_not] = ACTIONS(6627),
    [anon_sym_or] = ACTIONS(6627),
    [anon_sym_and] = ACTIONS(6627),
    [anon_sym_case] = ACTIONS(6627),
    [anon_sym_always] = ACTIONS(6627),
    [anon_sym_covergroup] = ACTIONS(6627),
    [anon_sym_let] = ACTIONS(6627),
    [anon_sym_pulldown] = ACTIONS(6627),
    [anon_sym_pullup] = ACTIONS(6627),
    [anon_sym_cmos] = ACTIONS(6627),
    [anon_sym_rcmos] = ACTIONS(6627),
    [anon_sym_bufif0] = ACTIONS(6627),
    [anon_sym_bufif1] = ACTIONS(6627),
    [anon_sym_notif0] = ACTIONS(6627),
    [anon_sym_notif1] = ACTIONS(6627),
    [anon_sym_nmos] = ACTIONS(6627),
    [anon_sym_pmos] = ACTIONS(6627),
    [anon_sym_rnmos] = ACTIONS(6627),
    [anon_sym_rpmos] = ACTIONS(6627),
    [anon_sym_nand] = ACTIONS(6627),
    [anon_sym_nor] = ACTIONS(6627),
    [anon_sym_xor] = ACTIONS(6627),
    [anon_sym_xnor] = ACTIONS(6627),
    [anon_sym_buf] = ACTIONS(6627),
    [anon_sym_tranif0] = ACTIONS(6627),
    [anon_sym_tranif1] = ACTIONS(6627),
    [anon_sym_rtranif1] = ACTIONS(6627),
    [anon_sym_rtranif0] = ACTIONS(6627),
    [anon_sym_tran] = ACTIONS(6627),
    [anon_sym_rtran] = ACTIONS(6627),
    [anon_sym_generate] = ACTIONS(6627),
    [anon_sym_endgenerate] = ACTIONS(6627),
    [anon_sym_for] = ACTIONS(6627),
    [anon_sym_initial] = ACTIONS(6627),
    [anon_sym_assign] = ACTIONS(6627),
    [anon_sym_alias] = ACTIONS(6627),
    [anon_sym_always_comb] = ACTIONS(6627),
    [anon_sym_always_latch] = ACTIONS(6627),
    [anon_sym_always_ff] = ACTIONS(6627),
    [anon_sym_final] = ACTIONS(6627),
    [anon_sym_global] = ACTIONS(6627),
    [anon_sym_LPAREN_STAR] = ACTIONS(6629),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6629),
    [anon_sym_DOLLARunit] = ACTIONS(6629),
  },
  [4642] = {
    [sym_simple_identifier] = ACTIONS(5844),
    [anon_sym_wire] = ACTIONS(5844),
    [anon_sym_tri] = ACTIONS(5844),
    [anon_sym_tri0] = ACTIONS(5844),
    [anon_sym_tri1] = ACTIONS(5844),
    [anon_sym_wand] = ACTIONS(5844),
    [anon_sym_triand] = ACTIONS(5844),
    [anon_sym_wor] = ACTIONS(5844),
    [anon_sym_trior] = ACTIONS(5844),
    [anon_sym_trireg] = ACTIONS(5844),
    [anon_sym_uwire] = ACTIONS(5844),
    [anon_sym_SEMI] = ACTIONS(5846),
    [anon_sym_extern] = ACTIONS(5844),
    [anon_sym_interface] = ACTIONS(5844),
    [anon_sym_checker] = ACTIONS(5844),
    [anon_sym_virtual] = ACTIONS(5844),
    [anon_sym_class] = ACTIONS(5844),
    [anon_sym_type] = ACTIONS(5844),
    [anon_sym_DOLLARfatal] = ACTIONS(5846),
    [anon_sym_DOLLARerror] = ACTIONS(5846),
    [anon_sym_DOLLARwarning] = ACTIONS(5846),
    [anon_sym_DOLLARinfo] = ACTIONS(5846),
    [anon_sym_default] = ACTIONS(5844),
    [anon_sym_clocking] = ACTIONS(5844),
    [anon_sym_defparam] = ACTIONS(5844),
    [anon_sym_bind] = ACTIONS(5844),
    [anon_sym_rand] = ACTIONS(5844),
    [anon_sym_const] = ACTIONS(5844),
    [anon_sym_function] = ACTIONS(5844),
    [anon_sym_static] = ACTIONS(5844),
    [anon_sym_constraint] = ACTIONS(5844),
    [anon_sym_if] = ACTIONS(5844),
    [anon_sym_else] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_localparam] = ACTIONS(5844),
    [anon_sym_parameter] = ACTIONS(5844),
    [anon_sym_var] = ACTIONS(5844),
    [anon_sym_import] = ACTIONS(5844),
    [anon_sym_export] = ACTIONS(5844),
    [anon_sym_genvar] = ACTIONS(5844),
    [anon_sym_interconnect] = ACTIONS(5844),
    [anon_sym_typedef] = ACTIONS(5844),
    [anon_sym_enum] = ACTIONS(5844),
    [anon_sym_struct] = ACTIONS(5844),
    [anon_sym_union] = ACTIONS(5844),
    [anon_sym_nettype] = ACTIONS(5844),
    [anon_sym_automatic] = ACTIONS(5844),
    [anon_sym_string] = ACTIONS(5844),
    [anon_sym_chandle] = ACTIONS(5844),
    [anon_sym_event] = ACTIONS(5844),
    [anon_sym_byte] = ACTIONS(5844),
    [anon_sym_shortint] = ACTIONS(5844),
    [anon_sym_int] = ACTIONS(5844),
    [anon_sym_longint] = ACTIONS(5844),
    [anon_sym_integer] = ACTIONS(5844),
    [anon_sym_time] = ACTIONS(5844),
    [anon_sym_bit] = ACTIONS(5844),
    [anon_sym_logic] = ACTIONS(5844),
    [anon_sym_reg] = ACTIONS(5844),
    [anon_sym_shortreal] = ACTIONS(5844),
    [anon_sym_real] = ACTIONS(5844),
    [anon_sym_realtime] = ACTIONS(5844),
    [anon_sym_supply0] = ACTIONS(5844),
    [anon_sym_supply1] = ACTIONS(5844),
    [anon_sym_signed] = ACTIONS(5844),
    [anon_sym_unsigned] = ACTIONS(5844),
    [anon_sym_task] = ACTIONS(5844),
    [anon_sym_assert] = ACTIONS(5844),
    [anon_sym_property] = ACTIONS(5844),
    [anon_sym_assume] = ACTIONS(5844),
    [anon_sym_cover] = ACTIONS(5844),
    [anon_sym_sequence] = ACTIONS(5844),
    [anon_sym_restrict] = ACTIONS(5844),
    [anon_sym_not] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5844),
    [anon_sym_and] = ACTIONS(5844),
    [anon_sym_case] = ACTIONS(5844),
    [anon_sym_always] = ACTIONS(5844),
    [anon_sym_covergroup] = ACTIONS(5844),
    [anon_sym_let] = ACTIONS(5844),
    [anon_sym_pulldown] = ACTIONS(5844),
    [anon_sym_pullup] = ACTIONS(5844),
    [anon_sym_cmos] = ACTIONS(5844),
    [anon_sym_rcmos] = ACTIONS(5844),
    [anon_sym_bufif0] = ACTIONS(5844),
    [anon_sym_bufif1] = ACTIONS(5844),
    [anon_sym_notif0] = ACTIONS(5844),
    [anon_sym_notif1] = ACTIONS(5844),
    [anon_sym_nmos] = ACTIONS(5844),
    [anon_sym_pmos] = ACTIONS(5844),
    [anon_sym_rnmos] = ACTIONS(5844),
    [anon_sym_rpmos] = ACTIONS(5844),
    [anon_sym_nand] = ACTIONS(5844),
    [anon_sym_nor] = ACTIONS(5844),
    [anon_sym_xor] = ACTIONS(5844),
    [anon_sym_xnor] = ACTIONS(5844),
    [anon_sym_buf] = ACTIONS(5844),
    [anon_sym_tranif0] = ACTIONS(5844),
    [anon_sym_tranif1] = ACTIONS(5844),
    [anon_sym_rtranif1] = ACTIONS(5844),
    [anon_sym_rtranif0] = ACTIONS(5844),
    [anon_sym_tran] = ACTIONS(5844),
    [anon_sym_rtran] = ACTIONS(5844),
    [anon_sym_generate] = ACTIONS(5844),
    [anon_sym_endgenerate] = ACTIONS(5844),
    [anon_sym_for] = ACTIONS(5844),
    [anon_sym_initial] = ACTIONS(5844),
    [anon_sym_assign] = ACTIONS(5844),
    [anon_sym_alias] = ACTIONS(5844),
    [anon_sym_always_comb] = ACTIONS(5844),
    [anon_sym_always_latch] = ACTIONS(5844),
    [anon_sym_always_ff] = ACTIONS(5844),
    [anon_sym_final] = ACTIONS(5844),
    [anon_sym_global] = ACTIONS(5844),
    [anon_sym_LPAREN_STAR] = ACTIONS(5846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5846),
    [anon_sym_DOLLARunit] = ACTIONS(5846),
  },
  [4643] = {
    [sym_simple_identifier] = ACTIONS(4612),
    [anon_sym_wire] = ACTIONS(4612),
    [anon_sym_tri] = ACTIONS(4612),
    [anon_sym_tri0] = ACTIONS(4612),
    [anon_sym_tri1] = ACTIONS(4612),
    [anon_sym_wand] = ACTIONS(4612),
    [anon_sym_triand] = ACTIONS(4612),
    [anon_sym_wor] = ACTIONS(4612),
    [anon_sym_trior] = ACTIONS(4612),
    [anon_sym_trireg] = ACTIONS(4612),
    [anon_sym_uwire] = ACTIONS(4612),
    [anon_sym_SEMI] = ACTIONS(4610),
    [anon_sym_extern] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4612),
    [anon_sym_checker] = ACTIONS(4612),
    [anon_sym_virtual] = ACTIONS(4612),
    [anon_sym_class] = ACTIONS(4612),
    [anon_sym_type] = ACTIONS(4612),
    [anon_sym_DOLLARfatal] = ACTIONS(4610),
    [anon_sym_DOLLARerror] = ACTIONS(4610),
    [anon_sym_DOLLARwarning] = ACTIONS(4610),
    [anon_sym_DOLLARinfo] = ACTIONS(4610),
    [anon_sym_default] = ACTIONS(4612),
    [anon_sym_clocking] = ACTIONS(4612),
    [anon_sym_defparam] = ACTIONS(4612),
    [anon_sym_bind] = ACTIONS(4612),
    [anon_sym_rand] = ACTIONS(4612),
    [anon_sym_const] = ACTIONS(4612),
    [anon_sym_function] = ACTIONS(4612),
    [anon_sym_static] = ACTIONS(4612),
    [anon_sym_constraint] = ACTIONS(4612),
    [anon_sym_if] = ACTIONS(4612),
    [anon_sym_else] = ACTIONS(4612),
    [anon_sym_LBRACK] = ACTIONS(4610),
    [anon_sym_localparam] = ACTIONS(4612),
    [anon_sym_parameter] = ACTIONS(4612),
    [anon_sym_var] = ACTIONS(4612),
    [anon_sym_import] = ACTIONS(4612),
    [anon_sym_export] = ACTIONS(4612),
    [anon_sym_genvar] = ACTIONS(4612),
    [anon_sym_interconnect] = ACTIONS(4612),
    [anon_sym_typedef] = ACTIONS(4612),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_struct] = ACTIONS(4612),
    [anon_sym_union] = ACTIONS(4612),
    [anon_sym_nettype] = ACTIONS(4612),
    [anon_sym_automatic] = ACTIONS(4612),
    [anon_sym_string] = ACTIONS(4612),
    [anon_sym_chandle] = ACTIONS(4612),
    [anon_sym_event] = ACTIONS(4612),
    [anon_sym_byte] = ACTIONS(4612),
    [anon_sym_shortint] = ACTIONS(4612),
    [anon_sym_int] = ACTIONS(4612),
    [anon_sym_longint] = ACTIONS(4612),
    [anon_sym_integer] = ACTIONS(4612),
    [anon_sym_time] = ACTIONS(4612),
    [anon_sym_bit] = ACTIONS(4612),
    [anon_sym_logic] = ACTIONS(4612),
    [anon_sym_reg] = ACTIONS(4612),
    [anon_sym_shortreal] = ACTIONS(4612),
    [anon_sym_real] = ACTIONS(4612),
    [anon_sym_realtime] = ACTIONS(4612),
    [anon_sym_supply0] = ACTIONS(4612),
    [anon_sym_supply1] = ACTIONS(4612),
    [anon_sym_signed] = ACTIONS(4612),
    [anon_sym_unsigned] = ACTIONS(4612),
    [anon_sym_task] = ACTIONS(4612),
    [anon_sym_assert] = ACTIONS(4612),
    [anon_sym_property] = ACTIONS(4612),
    [anon_sym_assume] = ACTIONS(4612),
    [anon_sym_cover] = ACTIONS(4612),
    [anon_sym_sequence] = ACTIONS(4612),
    [anon_sym_restrict] = ACTIONS(4612),
    [anon_sym_not] = ACTIONS(4612),
    [anon_sym_or] = ACTIONS(4612),
    [anon_sym_and] = ACTIONS(4612),
    [anon_sym_case] = ACTIONS(4612),
    [anon_sym_always] = ACTIONS(4612),
    [anon_sym_covergroup] = ACTIONS(4612),
    [anon_sym_let] = ACTIONS(4612),
    [anon_sym_pulldown] = ACTIONS(4612),
    [anon_sym_pullup] = ACTIONS(4612),
    [anon_sym_cmos] = ACTIONS(4612),
    [anon_sym_rcmos] = ACTIONS(4612),
    [anon_sym_bufif0] = ACTIONS(4612),
    [anon_sym_bufif1] = ACTIONS(4612),
    [anon_sym_notif0] = ACTIONS(4612),
    [anon_sym_notif1] = ACTIONS(4612),
    [anon_sym_nmos] = ACTIONS(4612),
    [anon_sym_pmos] = ACTIONS(4612),
    [anon_sym_rnmos] = ACTIONS(4612),
    [anon_sym_rpmos] = ACTIONS(4612),
    [anon_sym_nand] = ACTIONS(4612),
    [anon_sym_nor] = ACTIONS(4612),
    [anon_sym_xor] = ACTIONS(4612),
    [anon_sym_xnor] = ACTIONS(4612),
    [anon_sym_buf] = ACTIONS(4612),
    [anon_sym_tranif0] = ACTIONS(4612),
    [anon_sym_tranif1] = ACTIONS(4612),
    [anon_sym_rtranif1] = ACTIONS(4612),
    [anon_sym_rtranif0] = ACTIONS(4612),
    [anon_sym_tran] = ACTIONS(4612),
    [anon_sym_rtran] = ACTIONS(4612),
    [anon_sym_generate] = ACTIONS(4612),
    [anon_sym_endgenerate] = ACTIONS(4612),
    [anon_sym_for] = ACTIONS(4612),
    [anon_sym_initial] = ACTIONS(4612),
    [anon_sym_assign] = ACTIONS(4612),
    [anon_sym_alias] = ACTIONS(4612),
    [anon_sym_always_comb] = ACTIONS(4612),
    [anon_sym_always_latch] = ACTIONS(4612),
    [anon_sym_always_ff] = ACTIONS(4612),
    [anon_sym_final] = ACTIONS(4612),
    [anon_sym_global] = ACTIONS(4612),
    [anon_sym_LPAREN_STAR] = ACTIONS(4610),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4610),
    [anon_sym_DOLLARunit] = ACTIONS(4610),
  },
  [4644] = {
    [sym_simple_identifier] = ACTIONS(4908),
    [anon_sym_wire] = ACTIONS(4908),
    [anon_sym_tri] = ACTIONS(4908),
    [anon_sym_tri0] = ACTIONS(4908),
    [anon_sym_tri1] = ACTIONS(4908),
    [anon_sym_wand] = ACTIONS(4908),
    [anon_sym_triand] = ACTIONS(4908),
    [anon_sym_wor] = ACTIONS(4908),
    [anon_sym_trior] = ACTIONS(4908),
    [anon_sym_trireg] = ACTIONS(4908),
    [anon_sym_uwire] = ACTIONS(4908),
    [anon_sym_SEMI] = ACTIONS(4906),
    [anon_sym_extern] = ACTIONS(4908),
    [anon_sym_interface] = ACTIONS(4908),
    [anon_sym_checker] = ACTIONS(4908),
    [anon_sym_virtual] = ACTIONS(4908),
    [anon_sym_class] = ACTIONS(4908),
    [anon_sym_type] = ACTIONS(4908),
    [anon_sym_DOLLARfatal] = ACTIONS(4906),
    [anon_sym_DOLLARerror] = ACTIONS(4906),
    [anon_sym_DOLLARwarning] = ACTIONS(4906),
    [anon_sym_DOLLARinfo] = ACTIONS(4906),
    [anon_sym_default] = ACTIONS(4908),
    [anon_sym_clocking] = ACTIONS(4908),
    [anon_sym_defparam] = ACTIONS(4908),
    [anon_sym_bind] = ACTIONS(4908),
    [anon_sym_rand] = ACTIONS(4908),
    [anon_sym_const] = ACTIONS(4908),
    [anon_sym_function] = ACTIONS(4908),
    [anon_sym_static] = ACTIONS(4908),
    [anon_sym_constraint] = ACTIONS(4908),
    [anon_sym_if] = ACTIONS(4908),
    [anon_sym_else] = ACTIONS(4908),
    [anon_sym_LBRACK] = ACTIONS(4906),
    [anon_sym_localparam] = ACTIONS(4908),
    [anon_sym_parameter] = ACTIONS(4908),
    [anon_sym_var] = ACTIONS(4908),
    [anon_sym_import] = ACTIONS(4908),
    [anon_sym_export] = ACTIONS(4908),
    [anon_sym_genvar] = ACTIONS(4908),
    [anon_sym_interconnect] = ACTIONS(4908),
    [anon_sym_typedef] = ACTIONS(4908),
    [anon_sym_enum] = ACTIONS(4908),
    [anon_sym_struct] = ACTIONS(4908),
    [anon_sym_union] = ACTIONS(4908),
    [anon_sym_nettype] = ACTIONS(4908),
    [anon_sym_automatic] = ACTIONS(4908),
    [anon_sym_string] = ACTIONS(4908),
    [anon_sym_chandle] = ACTIONS(4908),
    [anon_sym_event] = ACTIONS(4908),
    [anon_sym_byte] = ACTIONS(4908),
    [anon_sym_shortint] = ACTIONS(4908),
    [anon_sym_int] = ACTIONS(4908),
    [anon_sym_longint] = ACTIONS(4908),
    [anon_sym_integer] = ACTIONS(4908),
    [anon_sym_time] = ACTIONS(4908),
    [anon_sym_bit] = ACTIONS(4908),
    [anon_sym_logic] = ACTIONS(4908),
    [anon_sym_reg] = ACTIONS(4908),
    [anon_sym_shortreal] = ACTIONS(4908),
    [anon_sym_real] = ACTIONS(4908),
    [anon_sym_realtime] = ACTIONS(4908),
    [anon_sym_supply0] = ACTIONS(4908),
    [anon_sym_supply1] = ACTIONS(4908),
    [anon_sym_signed] = ACTIONS(4908),
    [anon_sym_unsigned] = ACTIONS(4908),
    [anon_sym_task] = ACTIONS(4908),
    [anon_sym_assert] = ACTIONS(4908),
    [anon_sym_property] = ACTIONS(4908),
    [anon_sym_assume] = ACTIONS(4908),
    [anon_sym_cover] = ACTIONS(4908),
    [anon_sym_sequence] = ACTIONS(4908),
    [anon_sym_restrict] = ACTIONS(4908),
    [anon_sym_not] = ACTIONS(4908),
    [anon_sym_or] = ACTIONS(4908),
    [anon_sym_and] = ACTIONS(4908),
    [anon_sym_case] = ACTIONS(4908),
    [anon_sym_always] = ACTIONS(4908),
    [anon_sym_covergroup] = ACTIONS(4908),
    [anon_sym_let] = ACTIONS(4908),
    [anon_sym_pulldown] = ACTIONS(4908),
    [anon_sym_pullup] = ACTIONS(4908),
    [anon_sym_cmos] = ACTIONS(4908),
    [anon_sym_rcmos] = ACTIONS(4908),
    [anon_sym_bufif0] = ACTIONS(4908),
    [anon_sym_bufif1] = ACTIONS(4908),
    [anon_sym_notif0] = ACTIONS(4908),
    [anon_sym_notif1] = ACTIONS(4908),
    [anon_sym_nmos] = ACTIONS(4908),
    [anon_sym_pmos] = ACTIONS(4908),
    [anon_sym_rnmos] = ACTIONS(4908),
    [anon_sym_rpmos] = ACTIONS(4908),
    [anon_sym_nand] = ACTIONS(4908),
    [anon_sym_nor] = ACTIONS(4908),
    [anon_sym_xor] = ACTIONS(4908),
    [anon_sym_xnor] = ACTIONS(4908),
    [anon_sym_buf] = ACTIONS(4908),
    [anon_sym_tranif0] = ACTIONS(4908),
    [anon_sym_tranif1] = ACTIONS(4908),
    [anon_sym_rtranif1] = ACTIONS(4908),
    [anon_sym_rtranif0] = ACTIONS(4908),
    [anon_sym_tran] = ACTIONS(4908),
    [anon_sym_rtran] = ACTIONS(4908),
    [anon_sym_generate] = ACTIONS(4908),
    [anon_sym_endgenerate] = ACTIONS(4908),
    [anon_sym_for] = ACTIONS(4908),
    [anon_sym_initial] = ACTIONS(4908),
    [anon_sym_assign] = ACTIONS(4908),
    [anon_sym_alias] = ACTIONS(4908),
    [anon_sym_always_comb] = ACTIONS(4908),
    [anon_sym_always_latch] = ACTIONS(4908),
    [anon_sym_always_ff] = ACTIONS(4908),
    [anon_sym_final] = ACTIONS(4908),
    [anon_sym_global] = ACTIONS(4908),
    [anon_sym_LPAREN_STAR] = ACTIONS(4906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4906),
    [anon_sym_DOLLARunit] = ACTIONS(4906),
  },
  [4645] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_rand] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_end] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [4646] = {
    [sym_simple_identifier] = ACTIONS(6723),
    [anon_sym_wire] = ACTIONS(6723),
    [anon_sym_tri] = ACTIONS(6723),
    [anon_sym_tri0] = ACTIONS(6723),
    [anon_sym_tri1] = ACTIONS(6723),
    [anon_sym_wand] = ACTIONS(6723),
    [anon_sym_triand] = ACTIONS(6723),
    [anon_sym_wor] = ACTIONS(6723),
    [anon_sym_trior] = ACTIONS(6723),
    [anon_sym_trireg] = ACTIONS(6723),
    [anon_sym_uwire] = ACTIONS(6723),
    [anon_sym_SEMI] = ACTIONS(6725),
    [anon_sym_extern] = ACTIONS(6723),
    [anon_sym_interface] = ACTIONS(6723),
    [anon_sym_checker] = ACTIONS(6723),
    [anon_sym_virtual] = ACTIONS(6723),
    [anon_sym_class] = ACTIONS(6723),
    [anon_sym_type] = ACTIONS(6723),
    [anon_sym_DOLLARfatal] = ACTIONS(6725),
    [anon_sym_DOLLARerror] = ACTIONS(6725),
    [anon_sym_DOLLARwarning] = ACTIONS(6725),
    [anon_sym_DOLLARinfo] = ACTIONS(6725),
    [anon_sym_default] = ACTIONS(6723),
    [anon_sym_clocking] = ACTIONS(6723),
    [anon_sym_defparam] = ACTIONS(6723),
    [anon_sym_bind] = ACTIONS(6723),
    [anon_sym_rand] = ACTIONS(6723),
    [anon_sym_const] = ACTIONS(6723),
    [anon_sym_function] = ACTIONS(6723),
    [anon_sym_static] = ACTIONS(6723),
    [anon_sym_constraint] = ACTIONS(6723),
    [anon_sym_if] = ACTIONS(6723),
    [anon_sym_else] = ACTIONS(6723),
    [anon_sym_LBRACK] = ACTIONS(6725),
    [anon_sym_localparam] = ACTIONS(6723),
    [anon_sym_parameter] = ACTIONS(6723),
    [anon_sym_var] = ACTIONS(6723),
    [anon_sym_import] = ACTIONS(6723),
    [anon_sym_export] = ACTIONS(6723),
    [anon_sym_genvar] = ACTIONS(6723),
    [anon_sym_interconnect] = ACTIONS(6723),
    [anon_sym_typedef] = ACTIONS(6723),
    [anon_sym_enum] = ACTIONS(6723),
    [anon_sym_struct] = ACTIONS(6723),
    [anon_sym_union] = ACTIONS(6723),
    [anon_sym_nettype] = ACTIONS(6723),
    [anon_sym_automatic] = ACTIONS(6723),
    [anon_sym_string] = ACTIONS(6723),
    [anon_sym_chandle] = ACTIONS(6723),
    [anon_sym_event] = ACTIONS(6723),
    [anon_sym_byte] = ACTIONS(6723),
    [anon_sym_shortint] = ACTIONS(6723),
    [anon_sym_int] = ACTIONS(6723),
    [anon_sym_longint] = ACTIONS(6723),
    [anon_sym_integer] = ACTIONS(6723),
    [anon_sym_time] = ACTIONS(6723),
    [anon_sym_bit] = ACTIONS(6723),
    [anon_sym_logic] = ACTIONS(6723),
    [anon_sym_reg] = ACTIONS(6723),
    [anon_sym_shortreal] = ACTIONS(6723),
    [anon_sym_real] = ACTIONS(6723),
    [anon_sym_realtime] = ACTIONS(6723),
    [anon_sym_supply0] = ACTIONS(6723),
    [anon_sym_supply1] = ACTIONS(6723),
    [anon_sym_signed] = ACTIONS(6723),
    [anon_sym_unsigned] = ACTIONS(6723),
    [anon_sym_task] = ACTIONS(6723),
    [anon_sym_assert] = ACTIONS(6723),
    [anon_sym_property] = ACTIONS(6723),
    [anon_sym_assume] = ACTIONS(6723),
    [anon_sym_cover] = ACTIONS(6723),
    [anon_sym_sequence] = ACTIONS(6723),
    [anon_sym_restrict] = ACTIONS(6723),
    [anon_sym_not] = ACTIONS(6723),
    [anon_sym_or] = ACTIONS(6723),
    [anon_sym_and] = ACTIONS(6723),
    [anon_sym_case] = ACTIONS(6723),
    [anon_sym_always] = ACTIONS(6723),
    [anon_sym_covergroup] = ACTIONS(6723),
    [anon_sym_end] = ACTIONS(6723),
    [anon_sym_let] = ACTIONS(6723),
    [anon_sym_pulldown] = ACTIONS(6723),
    [anon_sym_pullup] = ACTIONS(6723),
    [anon_sym_cmos] = ACTIONS(6723),
    [anon_sym_rcmos] = ACTIONS(6723),
    [anon_sym_bufif0] = ACTIONS(6723),
    [anon_sym_bufif1] = ACTIONS(6723),
    [anon_sym_notif0] = ACTIONS(6723),
    [anon_sym_notif1] = ACTIONS(6723),
    [anon_sym_nmos] = ACTIONS(6723),
    [anon_sym_pmos] = ACTIONS(6723),
    [anon_sym_rnmos] = ACTIONS(6723),
    [anon_sym_rpmos] = ACTIONS(6723),
    [anon_sym_nand] = ACTIONS(6723),
    [anon_sym_nor] = ACTIONS(6723),
    [anon_sym_xor] = ACTIONS(6723),
    [anon_sym_xnor] = ACTIONS(6723),
    [anon_sym_buf] = ACTIONS(6723),
    [anon_sym_tranif0] = ACTIONS(6723),
    [anon_sym_tranif1] = ACTIONS(6723),
    [anon_sym_rtranif1] = ACTIONS(6723),
    [anon_sym_rtranif0] = ACTIONS(6723),
    [anon_sym_tran] = ACTIONS(6723),
    [anon_sym_rtran] = ACTIONS(6723),
    [anon_sym_generate] = ACTIONS(6723),
    [anon_sym_for] = ACTIONS(6723),
    [anon_sym_initial] = ACTIONS(6723),
    [anon_sym_assign] = ACTIONS(6723),
    [anon_sym_alias] = ACTIONS(6723),
    [anon_sym_always_comb] = ACTIONS(6723),
    [anon_sym_always_latch] = ACTIONS(6723),
    [anon_sym_always_ff] = ACTIONS(6723),
    [anon_sym_final] = ACTIONS(6723),
    [anon_sym_global] = ACTIONS(6723),
    [anon_sym_LPAREN_STAR] = ACTIONS(6725),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6725),
    [anon_sym_DOLLARunit] = ACTIONS(6725),
  },
  [4647] = {
    [sym_simple_identifier] = ACTIONS(6061),
    [anon_sym_wire] = ACTIONS(6061),
    [anon_sym_tri] = ACTIONS(6061),
    [anon_sym_tri0] = ACTIONS(6061),
    [anon_sym_tri1] = ACTIONS(6061),
    [anon_sym_wand] = ACTIONS(6061),
    [anon_sym_triand] = ACTIONS(6061),
    [anon_sym_wor] = ACTIONS(6061),
    [anon_sym_trior] = ACTIONS(6061),
    [anon_sym_trireg] = ACTIONS(6061),
    [anon_sym_uwire] = ACTIONS(6061),
    [anon_sym_SEMI] = ACTIONS(6063),
    [anon_sym_extern] = ACTIONS(6061),
    [anon_sym_interface] = ACTIONS(6061),
    [anon_sym_checker] = ACTIONS(6061),
    [anon_sym_virtual] = ACTIONS(6061),
    [anon_sym_class] = ACTIONS(6061),
    [anon_sym_type] = ACTIONS(6061),
    [anon_sym_DOLLARfatal] = ACTIONS(6063),
    [anon_sym_DOLLARerror] = ACTIONS(6063),
    [anon_sym_DOLLARwarning] = ACTIONS(6063),
    [anon_sym_DOLLARinfo] = ACTIONS(6063),
    [anon_sym_default] = ACTIONS(6061),
    [anon_sym_clocking] = ACTIONS(6061),
    [anon_sym_defparam] = ACTIONS(6061),
    [anon_sym_bind] = ACTIONS(6061),
    [anon_sym_rand] = ACTIONS(6061),
    [anon_sym_const] = ACTIONS(6061),
    [anon_sym_function] = ACTIONS(6061),
    [anon_sym_static] = ACTIONS(6061),
    [anon_sym_constraint] = ACTIONS(6061),
    [anon_sym_if] = ACTIONS(6061),
    [anon_sym_else] = ACTIONS(6061),
    [anon_sym_LBRACK] = ACTIONS(6063),
    [anon_sym_localparam] = ACTIONS(6061),
    [anon_sym_parameter] = ACTIONS(6061),
    [anon_sym_var] = ACTIONS(6061),
    [anon_sym_import] = ACTIONS(6061),
    [anon_sym_export] = ACTIONS(6061),
    [anon_sym_genvar] = ACTIONS(6061),
    [anon_sym_interconnect] = ACTIONS(6061),
    [anon_sym_typedef] = ACTIONS(6061),
    [anon_sym_enum] = ACTIONS(6061),
    [anon_sym_struct] = ACTIONS(6061),
    [anon_sym_union] = ACTIONS(6061),
    [anon_sym_nettype] = ACTIONS(6061),
    [anon_sym_automatic] = ACTIONS(6061),
    [anon_sym_string] = ACTIONS(6061),
    [anon_sym_chandle] = ACTIONS(6061),
    [anon_sym_event] = ACTIONS(6061),
    [anon_sym_byte] = ACTIONS(6061),
    [anon_sym_shortint] = ACTIONS(6061),
    [anon_sym_int] = ACTIONS(6061),
    [anon_sym_longint] = ACTIONS(6061),
    [anon_sym_integer] = ACTIONS(6061),
    [anon_sym_time] = ACTIONS(6061),
    [anon_sym_bit] = ACTIONS(6061),
    [anon_sym_logic] = ACTIONS(6061),
    [anon_sym_reg] = ACTIONS(6061),
    [anon_sym_shortreal] = ACTIONS(6061),
    [anon_sym_real] = ACTIONS(6061),
    [anon_sym_realtime] = ACTIONS(6061),
    [anon_sym_supply0] = ACTIONS(6061),
    [anon_sym_supply1] = ACTIONS(6061),
    [anon_sym_signed] = ACTIONS(6061),
    [anon_sym_unsigned] = ACTIONS(6061),
    [anon_sym_task] = ACTIONS(6061),
    [anon_sym_assert] = ACTIONS(6061),
    [anon_sym_property] = ACTIONS(6061),
    [anon_sym_assume] = ACTIONS(6061),
    [anon_sym_cover] = ACTIONS(6061),
    [anon_sym_sequence] = ACTIONS(6061),
    [anon_sym_restrict] = ACTIONS(6061),
    [anon_sym_not] = ACTIONS(6061),
    [anon_sym_or] = ACTIONS(6061),
    [anon_sym_and] = ACTIONS(6061),
    [anon_sym_case] = ACTIONS(6061),
    [anon_sym_always] = ACTIONS(6061),
    [anon_sym_covergroup] = ACTIONS(6061),
    [anon_sym_end] = ACTIONS(6061),
    [anon_sym_let] = ACTIONS(6061),
    [anon_sym_pulldown] = ACTIONS(6061),
    [anon_sym_pullup] = ACTIONS(6061),
    [anon_sym_cmos] = ACTIONS(6061),
    [anon_sym_rcmos] = ACTIONS(6061),
    [anon_sym_bufif0] = ACTIONS(6061),
    [anon_sym_bufif1] = ACTIONS(6061),
    [anon_sym_notif0] = ACTIONS(6061),
    [anon_sym_notif1] = ACTIONS(6061),
    [anon_sym_nmos] = ACTIONS(6061),
    [anon_sym_pmos] = ACTIONS(6061),
    [anon_sym_rnmos] = ACTIONS(6061),
    [anon_sym_rpmos] = ACTIONS(6061),
    [anon_sym_nand] = ACTIONS(6061),
    [anon_sym_nor] = ACTIONS(6061),
    [anon_sym_xor] = ACTIONS(6061),
    [anon_sym_xnor] = ACTIONS(6061),
    [anon_sym_buf] = ACTIONS(6061),
    [anon_sym_tranif0] = ACTIONS(6061),
    [anon_sym_tranif1] = ACTIONS(6061),
    [anon_sym_rtranif1] = ACTIONS(6061),
    [anon_sym_rtranif0] = ACTIONS(6061),
    [anon_sym_tran] = ACTIONS(6061),
    [anon_sym_rtran] = ACTIONS(6061),
    [anon_sym_generate] = ACTIONS(6061),
    [anon_sym_for] = ACTIONS(6061),
    [anon_sym_initial] = ACTIONS(6061),
    [anon_sym_assign] = ACTIONS(6061),
    [anon_sym_alias] = ACTIONS(6061),
    [anon_sym_always_comb] = ACTIONS(6061),
    [anon_sym_always_latch] = ACTIONS(6061),
    [anon_sym_always_ff] = ACTIONS(6061),
    [anon_sym_final] = ACTIONS(6061),
    [anon_sym_global] = ACTIONS(6061),
    [anon_sym_LPAREN_STAR] = ACTIONS(6063),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6063),
    [anon_sym_DOLLARunit] = ACTIONS(6063),
  },
  [4648] = {
    [sym_simple_identifier] = ACTIONS(6719),
    [anon_sym_wire] = ACTIONS(6719),
    [anon_sym_tri] = ACTIONS(6719),
    [anon_sym_tri0] = ACTIONS(6719),
    [anon_sym_tri1] = ACTIONS(6719),
    [anon_sym_wand] = ACTIONS(6719),
    [anon_sym_triand] = ACTIONS(6719),
    [anon_sym_wor] = ACTIONS(6719),
    [anon_sym_trior] = ACTIONS(6719),
    [anon_sym_trireg] = ACTIONS(6719),
    [anon_sym_uwire] = ACTIONS(6719),
    [anon_sym_SEMI] = ACTIONS(6721),
    [anon_sym_extern] = ACTIONS(6719),
    [anon_sym_interface] = ACTIONS(6719),
    [anon_sym_checker] = ACTIONS(6719),
    [anon_sym_virtual] = ACTIONS(6719),
    [anon_sym_class] = ACTIONS(6719),
    [anon_sym_type] = ACTIONS(6719),
    [anon_sym_DOLLARfatal] = ACTIONS(6721),
    [anon_sym_DOLLARerror] = ACTIONS(6721),
    [anon_sym_DOLLARwarning] = ACTIONS(6721),
    [anon_sym_DOLLARinfo] = ACTIONS(6721),
    [anon_sym_default] = ACTIONS(6719),
    [anon_sym_clocking] = ACTIONS(6719),
    [anon_sym_defparam] = ACTIONS(6719),
    [anon_sym_bind] = ACTIONS(6719),
    [anon_sym_rand] = ACTIONS(6719),
    [anon_sym_const] = ACTIONS(6719),
    [anon_sym_function] = ACTIONS(6719),
    [anon_sym_static] = ACTIONS(6719),
    [anon_sym_constraint] = ACTIONS(6719),
    [anon_sym_if] = ACTIONS(6719),
    [anon_sym_else] = ACTIONS(6719),
    [anon_sym_LBRACK] = ACTIONS(6721),
    [anon_sym_localparam] = ACTIONS(6719),
    [anon_sym_parameter] = ACTIONS(6719),
    [anon_sym_var] = ACTIONS(6719),
    [anon_sym_import] = ACTIONS(6719),
    [anon_sym_export] = ACTIONS(6719),
    [anon_sym_genvar] = ACTIONS(6719),
    [anon_sym_interconnect] = ACTIONS(6719),
    [anon_sym_typedef] = ACTIONS(6719),
    [anon_sym_enum] = ACTIONS(6719),
    [anon_sym_struct] = ACTIONS(6719),
    [anon_sym_union] = ACTIONS(6719),
    [anon_sym_nettype] = ACTIONS(6719),
    [anon_sym_automatic] = ACTIONS(6719),
    [anon_sym_string] = ACTIONS(6719),
    [anon_sym_chandle] = ACTIONS(6719),
    [anon_sym_event] = ACTIONS(6719),
    [anon_sym_byte] = ACTIONS(6719),
    [anon_sym_shortint] = ACTIONS(6719),
    [anon_sym_int] = ACTIONS(6719),
    [anon_sym_longint] = ACTIONS(6719),
    [anon_sym_integer] = ACTIONS(6719),
    [anon_sym_time] = ACTIONS(6719),
    [anon_sym_bit] = ACTIONS(6719),
    [anon_sym_logic] = ACTIONS(6719),
    [anon_sym_reg] = ACTIONS(6719),
    [anon_sym_shortreal] = ACTIONS(6719),
    [anon_sym_real] = ACTIONS(6719),
    [anon_sym_realtime] = ACTIONS(6719),
    [anon_sym_supply0] = ACTIONS(6719),
    [anon_sym_supply1] = ACTIONS(6719),
    [anon_sym_signed] = ACTIONS(6719),
    [anon_sym_unsigned] = ACTIONS(6719),
    [anon_sym_task] = ACTIONS(6719),
    [anon_sym_assert] = ACTIONS(6719),
    [anon_sym_property] = ACTIONS(6719),
    [anon_sym_assume] = ACTIONS(6719),
    [anon_sym_cover] = ACTIONS(6719),
    [anon_sym_sequence] = ACTIONS(6719),
    [anon_sym_restrict] = ACTIONS(6719),
    [anon_sym_not] = ACTIONS(6719),
    [anon_sym_or] = ACTIONS(6719),
    [anon_sym_and] = ACTIONS(6719),
    [anon_sym_case] = ACTIONS(6719),
    [anon_sym_always] = ACTIONS(6719),
    [anon_sym_covergroup] = ACTIONS(6719),
    [anon_sym_end] = ACTIONS(6719),
    [anon_sym_let] = ACTIONS(6719),
    [anon_sym_pulldown] = ACTIONS(6719),
    [anon_sym_pullup] = ACTIONS(6719),
    [anon_sym_cmos] = ACTIONS(6719),
    [anon_sym_rcmos] = ACTIONS(6719),
    [anon_sym_bufif0] = ACTIONS(6719),
    [anon_sym_bufif1] = ACTIONS(6719),
    [anon_sym_notif0] = ACTIONS(6719),
    [anon_sym_notif1] = ACTIONS(6719),
    [anon_sym_nmos] = ACTIONS(6719),
    [anon_sym_pmos] = ACTIONS(6719),
    [anon_sym_rnmos] = ACTIONS(6719),
    [anon_sym_rpmos] = ACTIONS(6719),
    [anon_sym_nand] = ACTIONS(6719),
    [anon_sym_nor] = ACTIONS(6719),
    [anon_sym_xor] = ACTIONS(6719),
    [anon_sym_xnor] = ACTIONS(6719),
    [anon_sym_buf] = ACTIONS(6719),
    [anon_sym_tranif0] = ACTIONS(6719),
    [anon_sym_tranif1] = ACTIONS(6719),
    [anon_sym_rtranif1] = ACTIONS(6719),
    [anon_sym_rtranif0] = ACTIONS(6719),
    [anon_sym_tran] = ACTIONS(6719),
    [anon_sym_rtran] = ACTIONS(6719),
    [anon_sym_generate] = ACTIONS(6719),
    [anon_sym_for] = ACTIONS(6719),
    [anon_sym_initial] = ACTIONS(6719),
    [anon_sym_assign] = ACTIONS(6719),
    [anon_sym_alias] = ACTIONS(6719),
    [anon_sym_always_comb] = ACTIONS(6719),
    [anon_sym_always_latch] = ACTIONS(6719),
    [anon_sym_always_ff] = ACTIONS(6719),
    [anon_sym_final] = ACTIONS(6719),
    [anon_sym_global] = ACTIONS(6719),
    [anon_sym_LPAREN_STAR] = ACTIONS(6721),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6721),
    [anon_sym_DOLLARunit] = ACTIONS(6721),
  },
  [4649] = {
    [sym_simple_identifier] = ACTIONS(4800),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_rand] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_endgenerate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [4650] = {
    [sym_simple_identifier] = ACTIONS(5802),
    [anon_sym_wire] = ACTIONS(5802),
    [anon_sym_tri] = ACTIONS(5802),
    [anon_sym_tri0] = ACTIONS(5802),
    [anon_sym_tri1] = ACTIONS(5802),
    [anon_sym_wand] = ACTIONS(5802),
    [anon_sym_triand] = ACTIONS(5802),
    [anon_sym_wor] = ACTIONS(5802),
    [anon_sym_trior] = ACTIONS(5802),
    [anon_sym_trireg] = ACTIONS(5802),
    [anon_sym_uwire] = ACTIONS(5802),
    [anon_sym_SEMI] = ACTIONS(5804),
    [anon_sym_extern] = ACTIONS(5802),
    [anon_sym_interface] = ACTIONS(5802),
    [anon_sym_checker] = ACTIONS(5802),
    [anon_sym_virtual] = ACTIONS(5802),
    [anon_sym_class] = ACTIONS(5802),
    [anon_sym_type] = ACTIONS(5802),
    [anon_sym_DOLLARfatal] = ACTIONS(5804),
    [anon_sym_DOLLARerror] = ACTIONS(5804),
    [anon_sym_DOLLARwarning] = ACTIONS(5804),
    [anon_sym_DOLLARinfo] = ACTIONS(5804),
    [anon_sym_default] = ACTIONS(5802),
    [anon_sym_clocking] = ACTIONS(5802),
    [anon_sym_defparam] = ACTIONS(5802),
    [anon_sym_bind] = ACTIONS(5802),
    [anon_sym_rand] = ACTIONS(5802),
    [anon_sym_const] = ACTIONS(5802),
    [anon_sym_function] = ACTIONS(5802),
    [anon_sym_static] = ACTIONS(5802),
    [anon_sym_constraint] = ACTIONS(5802),
    [anon_sym_if] = ACTIONS(5802),
    [anon_sym_else] = ACTIONS(5802),
    [anon_sym_LBRACK] = ACTIONS(5804),
    [anon_sym_localparam] = ACTIONS(5802),
    [anon_sym_parameter] = ACTIONS(5802),
    [anon_sym_var] = ACTIONS(5802),
    [anon_sym_import] = ACTIONS(5802),
    [anon_sym_export] = ACTIONS(5802),
    [anon_sym_genvar] = ACTIONS(5802),
    [anon_sym_interconnect] = ACTIONS(5802),
    [anon_sym_typedef] = ACTIONS(5802),
    [anon_sym_enum] = ACTIONS(5802),
    [anon_sym_struct] = ACTIONS(5802),
    [anon_sym_union] = ACTIONS(5802),
    [anon_sym_nettype] = ACTIONS(5802),
    [anon_sym_automatic] = ACTIONS(5802),
    [anon_sym_string] = ACTIONS(5802),
    [anon_sym_chandle] = ACTIONS(5802),
    [anon_sym_event] = ACTIONS(5802),
    [anon_sym_byte] = ACTIONS(5802),
    [anon_sym_shortint] = ACTIONS(5802),
    [anon_sym_int] = ACTIONS(5802),
    [anon_sym_longint] = ACTIONS(5802),
    [anon_sym_integer] = ACTIONS(5802),
    [anon_sym_time] = ACTIONS(5802),
    [anon_sym_bit] = ACTIONS(5802),
    [anon_sym_logic] = ACTIONS(5802),
    [anon_sym_reg] = ACTIONS(5802),
    [anon_sym_shortreal] = ACTIONS(5802),
    [anon_sym_real] = ACTIONS(5802),
    [anon_sym_realtime] = ACTIONS(5802),
    [anon_sym_supply0] = ACTIONS(5802),
    [anon_sym_supply1] = ACTIONS(5802),
    [anon_sym_signed] = ACTIONS(5802),
    [anon_sym_unsigned] = ACTIONS(5802),
    [anon_sym_task] = ACTIONS(5802),
    [anon_sym_assert] = ACTIONS(5802),
    [anon_sym_property] = ACTIONS(5802),
    [anon_sym_assume] = ACTIONS(5802),
    [anon_sym_cover] = ACTIONS(5802),
    [anon_sym_sequence] = ACTIONS(5802),
    [anon_sym_restrict] = ACTIONS(5802),
    [anon_sym_not] = ACTIONS(5802),
    [anon_sym_or] = ACTIONS(5802),
    [anon_sym_and] = ACTIONS(5802),
    [anon_sym_case] = ACTIONS(5802),
    [anon_sym_always] = ACTIONS(5802),
    [anon_sym_covergroup] = ACTIONS(5802),
    [anon_sym_end] = ACTIONS(5802),
    [anon_sym_let] = ACTIONS(5802),
    [anon_sym_pulldown] = ACTIONS(5802),
    [anon_sym_pullup] = ACTIONS(5802),
    [anon_sym_cmos] = ACTIONS(5802),
    [anon_sym_rcmos] = ACTIONS(5802),
    [anon_sym_bufif0] = ACTIONS(5802),
    [anon_sym_bufif1] = ACTIONS(5802),
    [anon_sym_notif0] = ACTIONS(5802),
    [anon_sym_notif1] = ACTIONS(5802),
    [anon_sym_nmos] = ACTIONS(5802),
    [anon_sym_pmos] = ACTIONS(5802),
    [anon_sym_rnmos] = ACTIONS(5802),
    [anon_sym_rpmos] = ACTIONS(5802),
    [anon_sym_nand] = ACTIONS(5802),
    [anon_sym_nor] = ACTIONS(5802),
    [anon_sym_xor] = ACTIONS(5802),
    [anon_sym_xnor] = ACTIONS(5802),
    [anon_sym_buf] = ACTIONS(5802),
    [anon_sym_tranif0] = ACTIONS(5802),
    [anon_sym_tranif1] = ACTIONS(5802),
    [anon_sym_rtranif1] = ACTIONS(5802),
    [anon_sym_rtranif0] = ACTIONS(5802),
    [anon_sym_tran] = ACTIONS(5802),
    [anon_sym_rtran] = ACTIONS(5802),
    [anon_sym_generate] = ACTIONS(5802),
    [anon_sym_for] = ACTIONS(5802),
    [anon_sym_initial] = ACTIONS(5802),
    [anon_sym_assign] = ACTIONS(5802),
    [anon_sym_alias] = ACTIONS(5802),
    [anon_sym_always_comb] = ACTIONS(5802),
    [anon_sym_always_latch] = ACTIONS(5802),
    [anon_sym_always_ff] = ACTIONS(5802),
    [anon_sym_final] = ACTIONS(5802),
    [anon_sym_global] = ACTIONS(5802),
    [anon_sym_LPAREN_STAR] = ACTIONS(5804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5804),
    [anon_sym_DOLLARunit] = ACTIONS(5804),
  },
  [4651] = {
    [sym_simple_identifier] = ACTIONS(5806),
    [anon_sym_wire] = ACTIONS(5806),
    [anon_sym_tri] = ACTIONS(5806),
    [anon_sym_tri0] = ACTIONS(5806),
    [anon_sym_tri1] = ACTIONS(5806),
    [anon_sym_wand] = ACTIONS(5806),
    [anon_sym_triand] = ACTIONS(5806),
    [anon_sym_wor] = ACTIONS(5806),
    [anon_sym_trior] = ACTIONS(5806),
    [anon_sym_trireg] = ACTIONS(5806),
    [anon_sym_uwire] = ACTIONS(5806),
    [anon_sym_SEMI] = ACTIONS(5808),
    [anon_sym_extern] = ACTIONS(5806),
    [anon_sym_interface] = ACTIONS(5806),
    [anon_sym_checker] = ACTIONS(5806),
    [anon_sym_virtual] = ACTIONS(5806),
    [anon_sym_class] = ACTIONS(5806),
    [anon_sym_type] = ACTIONS(5806),
    [anon_sym_DOLLARfatal] = ACTIONS(5808),
    [anon_sym_DOLLARerror] = ACTIONS(5808),
    [anon_sym_DOLLARwarning] = ACTIONS(5808),
    [anon_sym_DOLLARinfo] = ACTIONS(5808),
    [anon_sym_default] = ACTIONS(5806),
    [anon_sym_clocking] = ACTIONS(5806),
    [anon_sym_defparam] = ACTIONS(5806),
    [anon_sym_bind] = ACTIONS(5806),
    [anon_sym_rand] = ACTIONS(5806),
    [anon_sym_const] = ACTIONS(5806),
    [anon_sym_function] = ACTIONS(5806),
    [anon_sym_static] = ACTIONS(5806),
    [anon_sym_constraint] = ACTIONS(5806),
    [anon_sym_if] = ACTIONS(5806),
    [anon_sym_else] = ACTIONS(5806),
    [anon_sym_LBRACK] = ACTIONS(5808),
    [anon_sym_localparam] = ACTIONS(5806),
    [anon_sym_parameter] = ACTIONS(5806),
    [anon_sym_var] = ACTIONS(5806),
    [anon_sym_import] = ACTIONS(5806),
    [anon_sym_export] = ACTIONS(5806),
    [anon_sym_genvar] = ACTIONS(5806),
    [anon_sym_interconnect] = ACTIONS(5806),
    [anon_sym_typedef] = ACTIONS(5806),
    [anon_sym_enum] = ACTIONS(5806),
    [anon_sym_struct] = ACTIONS(5806),
    [anon_sym_union] = ACTIONS(5806),
    [anon_sym_nettype] = ACTIONS(5806),
    [anon_sym_automatic] = ACTIONS(5806),
    [anon_sym_string] = ACTIONS(5806),
    [anon_sym_chandle] = ACTIONS(5806),
    [anon_sym_event] = ACTIONS(5806),
    [anon_sym_byte] = ACTIONS(5806),
    [anon_sym_shortint] = ACTIONS(5806),
    [anon_sym_int] = ACTIONS(5806),
    [anon_sym_longint] = ACTIONS(5806),
    [anon_sym_integer] = ACTIONS(5806),
    [anon_sym_time] = ACTIONS(5806),
    [anon_sym_bit] = ACTIONS(5806),
    [anon_sym_logic] = ACTIONS(5806),
    [anon_sym_reg] = ACTIONS(5806),
    [anon_sym_shortreal] = ACTIONS(5806),
    [anon_sym_real] = ACTIONS(5806),
    [anon_sym_realtime] = ACTIONS(5806),
    [anon_sym_supply0] = ACTIONS(5806),
    [anon_sym_supply1] = ACTIONS(5806),
    [anon_sym_signed] = ACTIONS(5806),
    [anon_sym_unsigned] = ACTIONS(5806),
    [anon_sym_task] = ACTIONS(5806),
    [anon_sym_assert] = ACTIONS(5806),
    [anon_sym_property] = ACTIONS(5806),
    [anon_sym_assume] = ACTIONS(5806),
    [anon_sym_cover] = ACTIONS(5806),
    [anon_sym_sequence] = ACTIONS(5806),
    [anon_sym_restrict] = ACTIONS(5806),
    [anon_sym_not] = ACTIONS(5806),
    [anon_sym_or] = ACTIONS(5806),
    [anon_sym_and] = ACTIONS(5806),
    [anon_sym_case] = ACTIONS(5806),
    [anon_sym_always] = ACTIONS(5806),
    [anon_sym_covergroup] = ACTIONS(5806),
    [anon_sym_end] = ACTIONS(5806),
    [anon_sym_let] = ACTIONS(5806),
    [anon_sym_pulldown] = ACTIONS(5806),
    [anon_sym_pullup] = ACTIONS(5806),
    [anon_sym_cmos] = ACTIONS(5806),
    [anon_sym_rcmos] = ACTIONS(5806),
    [anon_sym_bufif0] = ACTIONS(5806),
    [anon_sym_bufif1] = ACTIONS(5806),
    [anon_sym_notif0] = ACTIONS(5806),
    [anon_sym_notif1] = ACTIONS(5806),
    [anon_sym_nmos] = ACTIONS(5806),
    [anon_sym_pmos] = ACTIONS(5806),
    [anon_sym_rnmos] = ACTIONS(5806),
    [anon_sym_rpmos] = ACTIONS(5806),
    [anon_sym_nand] = ACTIONS(5806),
    [anon_sym_nor] = ACTIONS(5806),
    [anon_sym_xor] = ACTIONS(5806),
    [anon_sym_xnor] = ACTIONS(5806),
    [anon_sym_buf] = ACTIONS(5806),
    [anon_sym_tranif0] = ACTIONS(5806),
    [anon_sym_tranif1] = ACTIONS(5806),
    [anon_sym_rtranif1] = ACTIONS(5806),
    [anon_sym_rtranif0] = ACTIONS(5806),
    [anon_sym_tran] = ACTIONS(5806),
    [anon_sym_rtran] = ACTIONS(5806),
    [anon_sym_generate] = ACTIONS(5806),
    [anon_sym_for] = ACTIONS(5806),
    [anon_sym_initial] = ACTIONS(5806),
    [anon_sym_assign] = ACTIONS(5806),
    [anon_sym_alias] = ACTIONS(5806),
    [anon_sym_always_comb] = ACTIONS(5806),
    [anon_sym_always_latch] = ACTIONS(5806),
    [anon_sym_always_ff] = ACTIONS(5806),
    [anon_sym_final] = ACTIONS(5806),
    [anon_sym_global] = ACTIONS(5806),
    [anon_sym_LPAREN_STAR] = ACTIONS(5808),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5808),
    [anon_sym_DOLLARunit] = ACTIONS(5808),
  },
  [4652] = {
    [sym_simple_identifier] = ACTIONS(6065),
    [anon_sym_wire] = ACTIONS(6065),
    [anon_sym_tri] = ACTIONS(6065),
    [anon_sym_tri0] = ACTIONS(6065),
    [anon_sym_tri1] = ACTIONS(6065),
    [anon_sym_wand] = ACTIONS(6065),
    [anon_sym_triand] = ACTIONS(6065),
    [anon_sym_wor] = ACTIONS(6065),
    [anon_sym_trior] = ACTIONS(6065),
    [anon_sym_trireg] = ACTIONS(6065),
    [anon_sym_uwire] = ACTIONS(6065),
    [anon_sym_SEMI] = ACTIONS(6067),
    [anon_sym_extern] = ACTIONS(6065),
    [anon_sym_interface] = ACTIONS(6065),
    [anon_sym_checker] = ACTIONS(6065),
    [anon_sym_virtual] = ACTIONS(6065),
    [anon_sym_class] = ACTIONS(6065),
    [anon_sym_type] = ACTIONS(6065),
    [anon_sym_DOLLARfatal] = ACTIONS(6067),
    [anon_sym_DOLLARerror] = ACTIONS(6067),
    [anon_sym_DOLLARwarning] = ACTIONS(6067),
    [anon_sym_DOLLARinfo] = ACTIONS(6067),
    [anon_sym_default] = ACTIONS(6065),
    [anon_sym_clocking] = ACTIONS(6065),
    [anon_sym_defparam] = ACTIONS(6065),
    [anon_sym_bind] = ACTIONS(6065),
    [anon_sym_rand] = ACTIONS(6065),
    [anon_sym_const] = ACTIONS(6065),
    [anon_sym_function] = ACTIONS(6065),
    [anon_sym_static] = ACTIONS(6065),
    [anon_sym_constraint] = ACTIONS(6065),
    [anon_sym_if] = ACTIONS(6065),
    [anon_sym_else] = ACTIONS(6065),
    [anon_sym_LBRACK] = ACTIONS(6067),
    [anon_sym_localparam] = ACTIONS(6065),
    [anon_sym_parameter] = ACTIONS(6065),
    [anon_sym_var] = ACTIONS(6065),
    [anon_sym_import] = ACTIONS(6065),
    [anon_sym_export] = ACTIONS(6065),
    [anon_sym_genvar] = ACTIONS(6065),
    [anon_sym_interconnect] = ACTIONS(6065),
    [anon_sym_typedef] = ACTIONS(6065),
    [anon_sym_enum] = ACTIONS(6065),
    [anon_sym_struct] = ACTIONS(6065),
    [anon_sym_union] = ACTIONS(6065),
    [anon_sym_nettype] = ACTIONS(6065),
    [anon_sym_automatic] = ACTIONS(6065),
    [anon_sym_string] = ACTIONS(6065),
    [anon_sym_chandle] = ACTIONS(6065),
    [anon_sym_event] = ACTIONS(6065),
    [anon_sym_byte] = ACTIONS(6065),
    [anon_sym_shortint] = ACTIONS(6065),
    [anon_sym_int] = ACTIONS(6065),
    [anon_sym_longint] = ACTIONS(6065),
    [anon_sym_integer] = ACTIONS(6065),
    [anon_sym_time] = ACTIONS(6065),
    [anon_sym_bit] = ACTIONS(6065),
    [anon_sym_logic] = ACTIONS(6065),
    [anon_sym_reg] = ACTIONS(6065),
    [anon_sym_shortreal] = ACTIONS(6065),
    [anon_sym_real] = ACTIONS(6065),
    [anon_sym_realtime] = ACTIONS(6065),
    [anon_sym_supply0] = ACTIONS(6065),
    [anon_sym_supply1] = ACTIONS(6065),
    [anon_sym_signed] = ACTIONS(6065),
    [anon_sym_unsigned] = ACTIONS(6065),
    [anon_sym_task] = ACTIONS(6065),
    [anon_sym_assert] = ACTIONS(6065),
    [anon_sym_property] = ACTIONS(6065),
    [anon_sym_assume] = ACTIONS(6065),
    [anon_sym_cover] = ACTIONS(6065),
    [anon_sym_sequence] = ACTIONS(6065),
    [anon_sym_restrict] = ACTIONS(6065),
    [anon_sym_not] = ACTIONS(6065),
    [anon_sym_or] = ACTIONS(6065),
    [anon_sym_and] = ACTIONS(6065),
    [anon_sym_case] = ACTIONS(6065),
    [anon_sym_always] = ACTIONS(6065),
    [anon_sym_covergroup] = ACTIONS(6065),
    [anon_sym_end] = ACTIONS(6065),
    [anon_sym_let] = ACTIONS(6065),
    [anon_sym_pulldown] = ACTIONS(6065),
    [anon_sym_pullup] = ACTIONS(6065),
    [anon_sym_cmos] = ACTIONS(6065),
    [anon_sym_rcmos] = ACTIONS(6065),
    [anon_sym_bufif0] = ACTIONS(6065),
    [anon_sym_bufif1] = ACTIONS(6065),
    [anon_sym_notif0] = ACTIONS(6065),
    [anon_sym_notif1] = ACTIONS(6065),
    [anon_sym_nmos] = ACTIONS(6065),
    [anon_sym_pmos] = ACTIONS(6065),
    [anon_sym_rnmos] = ACTIONS(6065),
    [anon_sym_rpmos] = ACTIONS(6065),
    [anon_sym_nand] = ACTIONS(6065),
    [anon_sym_nor] = ACTIONS(6065),
    [anon_sym_xor] = ACTIONS(6065),
    [anon_sym_xnor] = ACTIONS(6065),
    [anon_sym_buf] = ACTIONS(6065),
    [anon_sym_tranif0] = ACTIONS(6065),
    [anon_sym_tranif1] = ACTIONS(6065),
    [anon_sym_rtranif1] = ACTIONS(6065),
    [anon_sym_rtranif0] = ACTIONS(6065),
    [anon_sym_tran] = ACTIONS(6065),
    [anon_sym_rtran] = ACTIONS(6065),
    [anon_sym_generate] = ACTIONS(6065),
    [anon_sym_for] = ACTIONS(6065),
    [anon_sym_initial] = ACTIONS(6065),
    [anon_sym_assign] = ACTIONS(6065),
    [anon_sym_alias] = ACTIONS(6065),
    [anon_sym_always_comb] = ACTIONS(6065),
    [anon_sym_always_latch] = ACTIONS(6065),
    [anon_sym_always_ff] = ACTIONS(6065),
    [anon_sym_final] = ACTIONS(6065),
    [anon_sym_global] = ACTIONS(6065),
    [anon_sym_LPAREN_STAR] = ACTIONS(6067),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6067),
    [anon_sym_DOLLARunit] = ACTIONS(6067),
  },
  [4653] = {
    [sym_simple_identifier] = ACTIONS(4936),
    [anon_sym_wire] = ACTIONS(4936),
    [anon_sym_tri] = ACTIONS(4936),
    [anon_sym_tri0] = ACTIONS(4936),
    [anon_sym_tri1] = ACTIONS(4936),
    [anon_sym_wand] = ACTIONS(4936),
    [anon_sym_triand] = ACTIONS(4936),
    [anon_sym_wor] = ACTIONS(4936),
    [anon_sym_trior] = ACTIONS(4936),
    [anon_sym_trireg] = ACTIONS(4936),
    [anon_sym_uwire] = ACTIONS(4936),
    [anon_sym_SEMI] = ACTIONS(4934),
    [anon_sym_extern] = ACTIONS(4936),
    [anon_sym_interface] = ACTIONS(4936),
    [anon_sym_checker] = ACTIONS(4936),
    [anon_sym_virtual] = ACTIONS(4936),
    [anon_sym_class] = ACTIONS(4936),
    [anon_sym_type] = ACTIONS(4936),
    [anon_sym_DOLLARfatal] = ACTIONS(4934),
    [anon_sym_DOLLARerror] = ACTIONS(4934),
    [anon_sym_DOLLARwarning] = ACTIONS(4934),
    [anon_sym_DOLLARinfo] = ACTIONS(4934),
    [anon_sym_default] = ACTIONS(4936),
    [anon_sym_clocking] = ACTIONS(4936),
    [anon_sym_defparam] = ACTIONS(4936),
    [anon_sym_bind] = ACTIONS(4936),
    [anon_sym_rand] = ACTIONS(4936),
    [anon_sym_const] = ACTIONS(4936),
    [anon_sym_function] = ACTIONS(4936),
    [anon_sym_static] = ACTIONS(4936),
    [anon_sym_constraint] = ACTIONS(4936),
    [anon_sym_if] = ACTIONS(4936),
    [anon_sym_else] = ACTIONS(4936),
    [anon_sym_LBRACK] = ACTIONS(4934),
    [anon_sym_localparam] = ACTIONS(4936),
    [anon_sym_parameter] = ACTIONS(4936),
    [anon_sym_var] = ACTIONS(4936),
    [anon_sym_import] = ACTIONS(4936),
    [anon_sym_export] = ACTIONS(4936),
    [anon_sym_genvar] = ACTIONS(4936),
    [anon_sym_interconnect] = ACTIONS(4936),
    [anon_sym_typedef] = ACTIONS(4936),
    [anon_sym_enum] = ACTIONS(4936),
    [anon_sym_struct] = ACTIONS(4936),
    [anon_sym_union] = ACTIONS(4936),
    [anon_sym_nettype] = ACTIONS(4936),
    [anon_sym_automatic] = ACTIONS(4936),
    [anon_sym_string] = ACTIONS(4936),
    [anon_sym_chandle] = ACTIONS(4936),
    [anon_sym_event] = ACTIONS(4936),
    [anon_sym_byte] = ACTIONS(4936),
    [anon_sym_shortint] = ACTIONS(4936),
    [anon_sym_int] = ACTIONS(4936),
    [anon_sym_longint] = ACTIONS(4936),
    [anon_sym_integer] = ACTIONS(4936),
    [anon_sym_time] = ACTIONS(4936),
    [anon_sym_bit] = ACTIONS(4936),
    [anon_sym_logic] = ACTIONS(4936),
    [anon_sym_reg] = ACTIONS(4936),
    [anon_sym_shortreal] = ACTIONS(4936),
    [anon_sym_real] = ACTIONS(4936),
    [anon_sym_realtime] = ACTIONS(4936),
    [anon_sym_supply0] = ACTIONS(4936),
    [anon_sym_supply1] = ACTIONS(4936),
    [anon_sym_signed] = ACTIONS(4936),
    [anon_sym_unsigned] = ACTIONS(4936),
    [anon_sym_task] = ACTIONS(4936),
    [anon_sym_assert] = ACTIONS(4936),
    [anon_sym_property] = ACTIONS(4936),
    [anon_sym_assume] = ACTIONS(4936),
    [anon_sym_cover] = ACTIONS(4936),
    [anon_sym_sequence] = ACTIONS(4936),
    [anon_sym_restrict] = ACTIONS(4936),
    [anon_sym_not] = ACTIONS(4936),
    [anon_sym_or] = ACTIONS(4936),
    [anon_sym_and] = ACTIONS(4936),
    [anon_sym_case] = ACTIONS(4936),
    [anon_sym_always] = ACTIONS(4936),
    [anon_sym_covergroup] = ACTIONS(4936),
    [anon_sym_let] = ACTIONS(4936),
    [anon_sym_pulldown] = ACTIONS(4936),
    [anon_sym_pullup] = ACTIONS(4936),
    [anon_sym_cmos] = ACTIONS(4936),
    [anon_sym_rcmos] = ACTIONS(4936),
    [anon_sym_bufif0] = ACTIONS(4936),
    [anon_sym_bufif1] = ACTIONS(4936),
    [anon_sym_notif0] = ACTIONS(4936),
    [anon_sym_notif1] = ACTIONS(4936),
    [anon_sym_nmos] = ACTIONS(4936),
    [anon_sym_pmos] = ACTIONS(4936),
    [anon_sym_rnmos] = ACTIONS(4936),
    [anon_sym_rpmos] = ACTIONS(4936),
    [anon_sym_nand] = ACTIONS(4936),
    [anon_sym_nor] = ACTIONS(4936),
    [anon_sym_xor] = ACTIONS(4936),
    [anon_sym_xnor] = ACTIONS(4936),
    [anon_sym_buf] = ACTIONS(4936),
    [anon_sym_tranif0] = ACTIONS(4936),
    [anon_sym_tranif1] = ACTIONS(4936),
    [anon_sym_rtranif1] = ACTIONS(4936),
    [anon_sym_rtranif0] = ACTIONS(4936),
    [anon_sym_tran] = ACTIONS(4936),
    [anon_sym_rtran] = ACTIONS(4936),
    [anon_sym_generate] = ACTIONS(4936),
    [anon_sym_endgenerate] = ACTIONS(4936),
    [anon_sym_for] = ACTIONS(4936),
    [anon_sym_initial] = ACTIONS(4936),
    [anon_sym_assign] = ACTIONS(4936),
    [anon_sym_alias] = ACTIONS(4936),
    [anon_sym_always_comb] = ACTIONS(4936),
    [anon_sym_always_latch] = ACTIONS(4936),
    [anon_sym_always_ff] = ACTIONS(4936),
    [anon_sym_final] = ACTIONS(4936),
    [anon_sym_global] = ACTIONS(4936),
    [anon_sym_LPAREN_STAR] = ACTIONS(4934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4934),
    [anon_sym_DOLLARunit] = ACTIONS(4934),
  },
  [4654] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_rand] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(10885),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_endgenerate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [4655] = {
    [sym_simple_identifier] = ACTIONS(4860),
    [anon_sym_wire] = ACTIONS(4860),
    [anon_sym_tri] = ACTIONS(4860),
    [anon_sym_tri0] = ACTIONS(4860),
    [anon_sym_tri1] = ACTIONS(4860),
    [anon_sym_wand] = ACTIONS(4860),
    [anon_sym_triand] = ACTIONS(4860),
    [anon_sym_wor] = ACTIONS(4860),
    [anon_sym_trior] = ACTIONS(4860),
    [anon_sym_trireg] = ACTIONS(4860),
    [anon_sym_uwire] = ACTIONS(4860),
    [anon_sym_SEMI] = ACTIONS(4858),
    [anon_sym_extern] = ACTIONS(4860),
    [anon_sym_interface] = ACTIONS(4860),
    [anon_sym_checker] = ACTIONS(4860),
    [anon_sym_virtual] = ACTIONS(4860),
    [anon_sym_class] = ACTIONS(4860),
    [anon_sym_type] = ACTIONS(4860),
    [anon_sym_DOLLARfatal] = ACTIONS(4858),
    [anon_sym_DOLLARerror] = ACTIONS(4858),
    [anon_sym_DOLLARwarning] = ACTIONS(4858),
    [anon_sym_DOLLARinfo] = ACTIONS(4858),
    [anon_sym_default] = ACTIONS(4860),
    [anon_sym_clocking] = ACTIONS(4860),
    [anon_sym_defparam] = ACTIONS(4860),
    [anon_sym_bind] = ACTIONS(4860),
    [anon_sym_rand] = ACTIONS(4860),
    [anon_sym_const] = ACTIONS(4860),
    [anon_sym_function] = ACTIONS(4860),
    [anon_sym_static] = ACTIONS(4860),
    [anon_sym_constraint] = ACTIONS(4860),
    [anon_sym_if] = ACTIONS(4860),
    [anon_sym_else] = ACTIONS(4860),
    [anon_sym_LBRACK] = ACTIONS(4858),
    [anon_sym_localparam] = ACTIONS(4860),
    [anon_sym_parameter] = ACTIONS(4860),
    [anon_sym_var] = ACTIONS(4860),
    [anon_sym_import] = ACTIONS(4860),
    [anon_sym_export] = ACTIONS(4860),
    [anon_sym_genvar] = ACTIONS(4860),
    [anon_sym_interconnect] = ACTIONS(4860),
    [anon_sym_typedef] = ACTIONS(4860),
    [anon_sym_enum] = ACTIONS(4860),
    [anon_sym_struct] = ACTIONS(4860),
    [anon_sym_union] = ACTIONS(4860),
    [anon_sym_nettype] = ACTIONS(4860),
    [anon_sym_automatic] = ACTIONS(4860),
    [anon_sym_string] = ACTIONS(4860),
    [anon_sym_chandle] = ACTIONS(4860),
    [anon_sym_event] = ACTIONS(4860),
    [anon_sym_byte] = ACTIONS(4860),
    [anon_sym_shortint] = ACTIONS(4860),
    [anon_sym_int] = ACTIONS(4860),
    [anon_sym_longint] = ACTIONS(4860),
    [anon_sym_integer] = ACTIONS(4860),
    [anon_sym_time] = ACTIONS(4860),
    [anon_sym_bit] = ACTIONS(4860),
    [anon_sym_logic] = ACTIONS(4860),
    [anon_sym_reg] = ACTIONS(4860),
    [anon_sym_shortreal] = ACTIONS(4860),
    [anon_sym_real] = ACTIONS(4860),
    [anon_sym_realtime] = ACTIONS(4860),
    [anon_sym_supply0] = ACTIONS(4860),
    [anon_sym_supply1] = ACTIONS(4860),
    [anon_sym_signed] = ACTIONS(4860),
    [anon_sym_unsigned] = ACTIONS(4860),
    [anon_sym_task] = ACTIONS(4860),
    [anon_sym_assert] = ACTIONS(4860),
    [anon_sym_property] = ACTIONS(4860),
    [anon_sym_assume] = ACTIONS(4860),
    [anon_sym_cover] = ACTIONS(4860),
    [anon_sym_sequence] = ACTIONS(4860),
    [anon_sym_restrict] = ACTIONS(4860),
    [anon_sym_not] = ACTIONS(4860),
    [anon_sym_or] = ACTIONS(4860),
    [anon_sym_and] = ACTIONS(4860),
    [anon_sym_case] = ACTIONS(4860),
    [anon_sym_always] = ACTIONS(4860),
    [anon_sym_covergroup] = ACTIONS(4860),
    [anon_sym_let] = ACTIONS(4860),
    [anon_sym_pulldown] = ACTIONS(4860),
    [anon_sym_pullup] = ACTIONS(4860),
    [anon_sym_cmos] = ACTIONS(4860),
    [anon_sym_rcmos] = ACTIONS(4860),
    [anon_sym_bufif0] = ACTIONS(4860),
    [anon_sym_bufif1] = ACTIONS(4860),
    [anon_sym_notif0] = ACTIONS(4860),
    [anon_sym_notif1] = ACTIONS(4860),
    [anon_sym_nmos] = ACTIONS(4860),
    [anon_sym_pmos] = ACTIONS(4860),
    [anon_sym_rnmos] = ACTIONS(4860),
    [anon_sym_rpmos] = ACTIONS(4860),
    [anon_sym_nand] = ACTIONS(4860),
    [anon_sym_nor] = ACTIONS(4860),
    [anon_sym_xor] = ACTIONS(4860),
    [anon_sym_xnor] = ACTIONS(4860),
    [anon_sym_buf] = ACTIONS(4860),
    [anon_sym_tranif0] = ACTIONS(4860),
    [anon_sym_tranif1] = ACTIONS(4860),
    [anon_sym_rtranif1] = ACTIONS(4860),
    [anon_sym_rtranif0] = ACTIONS(4860),
    [anon_sym_tran] = ACTIONS(4860),
    [anon_sym_rtran] = ACTIONS(4860),
    [anon_sym_generate] = ACTIONS(4860),
    [anon_sym_endgenerate] = ACTIONS(4860),
    [anon_sym_for] = ACTIONS(4860),
    [anon_sym_initial] = ACTIONS(4860),
    [anon_sym_assign] = ACTIONS(4860),
    [anon_sym_alias] = ACTIONS(4860),
    [anon_sym_always_comb] = ACTIONS(4860),
    [anon_sym_always_latch] = ACTIONS(4860),
    [anon_sym_always_ff] = ACTIONS(4860),
    [anon_sym_final] = ACTIONS(4860),
    [anon_sym_global] = ACTIONS(4860),
    [anon_sym_LPAREN_STAR] = ACTIONS(4858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4858),
    [anon_sym_DOLLARunit] = ACTIONS(4858),
  },
  [4656] = {
    [sym_simple_identifier] = ACTIONS(4624),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_rand] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_endgenerate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [4657] = {
    [sym_simple_identifier] = ACTIONS(5816),
    [anon_sym_wire] = ACTIONS(5816),
    [anon_sym_tri] = ACTIONS(5816),
    [anon_sym_tri0] = ACTIONS(5816),
    [anon_sym_tri1] = ACTIONS(5816),
    [anon_sym_wand] = ACTIONS(5816),
    [anon_sym_triand] = ACTIONS(5816),
    [anon_sym_wor] = ACTIONS(5816),
    [anon_sym_trior] = ACTIONS(5816),
    [anon_sym_trireg] = ACTIONS(5816),
    [anon_sym_uwire] = ACTIONS(5816),
    [anon_sym_SEMI] = ACTIONS(5818),
    [anon_sym_extern] = ACTIONS(5816),
    [anon_sym_interface] = ACTIONS(5816),
    [anon_sym_checker] = ACTIONS(5816),
    [anon_sym_virtual] = ACTIONS(5816),
    [anon_sym_class] = ACTIONS(5816),
    [anon_sym_type] = ACTIONS(5816),
    [anon_sym_DOLLARfatal] = ACTIONS(5818),
    [anon_sym_DOLLARerror] = ACTIONS(5818),
    [anon_sym_DOLLARwarning] = ACTIONS(5818),
    [anon_sym_DOLLARinfo] = ACTIONS(5818),
    [anon_sym_default] = ACTIONS(5816),
    [anon_sym_clocking] = ACTIONS(5816),
    [anon_sym_defparam] = ACTIONS(5816),
    [anon_sym_bind] = ACTIONS(5816),
    [anon_sym_rand] = ACTIONS(5816),
    [anon_sym_const] = ACTIONS(5816),
    [anon_sym_function] = ACTIONS(5816),
    [anon_sym_static] = ACTIONS(5816),
    [anon_sym_constraint] = ACTIONS(5816),
    [anon_sym_if] = ACTIONS(5816),
    [anon_sym_else] = ACTIONS(5816),
    [anon_sym_LBRACK] = ACTIONS(5818),
    [anon_sym_localparam] = ACTIONS(5816),
    [anon_sym_parameter] = ACTIONS(5816),
    [anon_sym_var] = ACTIONS(5816),
    [anon_sym_import] = ACTIONS(5816),
    [anon_sym_export] = ACTIONS(5816),
    [anon_sym_genvar] = ACTIONS(5816),
    [anon_sym_interconnect] = ACTIONS(5816),
    [anon_sym_typedef] = ACTIONS(5816),
    [anon_sym_enum] = ACTIONS(5816),
    [anon_sym_struct] = ACTIONS(5816),
    [anon_sym_union] = ACTIONS(5816),
    [anon_sym_nettype] = ACTIONS(5816),
    [anon_sym_automatic] = ACTIONS(5816),
    [anon_sym_string] = ACTIONS(5816),
    [anon_sym_chandle] = ACTIONS(5816),
    [anon_sym_event] = ACTIONS(5816),
    [anon_sym_byte] = ACTIONS(5816),
    [anon_sym_shortint] = ACTIONS(5816),
    [anon_sym_int] = ACTIONS(5816),
    [anon_sym_longint] = ACTIONS(5816),
    [anon_sym_integer] = ACTIONS(5816),
    [anon_sym_time] = ACTIONS(5816),
    [anon_sym_bit] = ACTIONS(5816),
    [anon_sym_logic] = ACTIONS(5816),
    [anon_sym_reg] = ACTIONS(5816),
    [anon_sym_shortreal] = ACTIONS(5816),
    [anon_sym_real] = ACTIONS(5816),
    [anon_sym_realtime] = ACTIONS(5816),
    [anon_sym_supply0] = ACTIONS(5816),
    [anon_sym_supply1] = ACTIONS(5816),
    [anon_sym_signed] = ACTIONS(5816),
    [anon_sym_unsigned] = ACTIONS(5816),
    [anon_sym_task] = ACTIONS(5816),
    [anon_sym_assert] = ACTIONS(5816),
    [anon_sym_property] = ACTIONS(5816),
    [anon_sym_assume] = ACTIONS(5816),
    [anon_sym_cover] = ACTIONS(5816),
    [anon_sym_sequence] = ACTIONS(5816),
    [anon_sym_restrict] = ACTIONS(5816),
    [anon_sym_not] = ACTIONS(5816),
    [anon_sym_or] = ACTIONS(5816),
    [anon_sym_and] = ACTIONS(5816),
    [anon_sym_case] = ACTIONS(5816),
    [anon_sym_always] = ACTIONS(5816),
    [anon_sym_covergroup] = ACTIONS(5816),
    [anon_sym_end] = ACTIONS(5816),
    [anon_sym_let] = ACTIONS(5816),
    [anon_sym_pulldown] = ACTIONS(5816),
    [anon_sym_pullup] = ACTIONS(5816),
    [anon_sym_cmos] = ACTIONS(5816),
    [anon_sym_rcmos] = ACTIONS(5816),
    [anon_sym_bufif0] = ACTIONS(5816),
    [anon_sym_bufif1] = ACTIONS(5816),
    [anon_sym_notif0] = ACTIONS(5816),
    [anon_sym_notif1] = ACTIONS(5816),
    [anon_sym_nmos] = ACTIONS(5816),
    [anon_sym_pmos] = ACTIONS(5816),
    [anon_sym_rnmos] = ACTIONS(5816),
    [anon_sym_rpmos] = ACTIONS(5816),
    [anon_sym_nand] = ACTIONS(5816),
    [anon_sym_nor] = ACTIONS(5816),
    [anon_sym_xor] = ACTIONS(5816),
    [anon_sym_xnor] = ACTIONS(5816),
    [anon_sym_buf] = ACTIONS(5816),
    [anon_sym_tranif0] = ACTIONS(5816),
    [anon_sym_tranif1] = ACTIONS(5816),
    [anon_sym_rtranif1] = ACTIONS(5816),
    [anon_sym_rtranif0] = ACTIONS(5816),
    [anon_sym_tran] = ACTIONS(5816),
    [anon_sym_rtran] = ACTIONS(5816),
    [anon_sym_generate] = ACTIONS(5816),
    [anon_sym_for] = ACTIONS(5816),
    [anon_sym_initial] = ACTIONS(5816),
    [anon_sym_assign] = ACTIONS(5816),
    [anon_sym_alias] = ACTIONS(5816),
    [anon_sym_always_comb] = ACTIONS(5816),
    [anon_sym_always_latch] = ACTIONS(5816),
    [anon_sym_always_ff] = ACTIONS(5816),
    [anon_sym_final] = ACTIONS(5816),
    [anon_sym_global] = ACTIONS(5816),
    [anon_sym_LPAREN_STAR] = ACTIONS(5818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5818),
    [anon_sym_DOLLARunit] = ACTIONS(5818),
  },
  [4658] = {
    [sym_simple_identifier] = ACTIONS(6691),
    [anon_sym_wire] = ACTIONS(6691),
    [anon_sym_tri] = ACTIONS(6691),
    [anon_sym_tri0] = ACTIONS(6691),
    [anon_sym_tri1] = ACTIONS(6691),
    [anon_sym_wand] = ACTIONS(6691),
    [anon_sym_triand] = ACTIONS(6691),
    [anon_sym_wor] = ACTIONS(6691),
    [anon_sym_trior] = ACTIONS(6691),
    [anon_sym_trireg] = ACTIONS(6691),
    [anon_sym_uwire] = ACTIONS(6691),
    [anon_sym_SEMI] = ACTIONS(6693),
    [anon_sym_extern] = ACTIONS(6691),
    [anon_sym_interface] = ACTIONS(6691),
    [anon_sym_checker] = ACTIONS(6691),
    [anon_sym_virtual] = ACTIONS(6691),
    [anon_sym_class] = ACTIONS(6691),
    [anon_sym_type] = ACTIONS(6691),
    [anon_sym_DOLLARfatal] = ACTIONS(6693),
    [anon_sym_DOLLARerror] = ACTIONS(6693),
    [anon_sym_DOLLARwarning] = ACTIONS(6693),
    [anon_sym_DOLLARinfo] = ACTIONS(6693),
    [anon_sym_default] = ACTIONS(6691),
    [anon_sym_clocking] = ACTIONS(6691),
    [anon_sym_defparam] = ACTIONS(6691),
    [anon_sym_bind] = ACTIONS(6691),
    [anon_sym_rand] = ACTIONS(6691),
    [anon_sym_const] = ACTIONS(6691),
    [anon_sym_function] = ACTIONS(6691),
    [anon_sym_static] = ACTIONS(6691),
    [anon_sym_constraint] = ACTIONS(6691),
    [anon_sym_if] = ACTIONS(6691),
    [anon_sym_else] = ACTIONS(6691),
    [anon_sym_LBRACK] = ACTIONS(6693),
    [anon_sym_localparam] = ACTIONS(6691),
    [anon_sym_parameter] = ACTIONS(6691),
    [anon_sym_var] = ACTIONS(6691),
    [anon_sym_import] = ACTIONS(6691),
    [anon_sym_export] = ACTIONS(6691),
    [anon_sym_genvar] = ACTIONS(6691),
    [anon_sym_interconnect] = ACTIONS(6691),
    [anon_sym_typedef] = ACTIONS(6691),
    [anon_sym_enum] = ACTIONS(6691),
    [anon_sym_struct] = ACTIONS(6691),
    [anon_sym_union] = ACTIONS(6691),
    [anon_sym_nettype] = ACTIONS(6691),
    [anon_sym_automatic] = ACTIONS(6691),
    [anon_sym_string] = ACTIONS(6691),
    [anon_sym_chandle] = ACTIONS(6691),
    [anon_sym_event] = ACTIONS(6691),
    [anon_sym_byte] = ACTIONS(6691),
    [anon_sym_shortint] = ACTIONS(6691),
    [anon_sym_int] = ACTIONS(6691),
    [anon_sym_longint] = ACTIONS(6691),
    [anon_sym_integer] = ACTIONS(6691),
    [anon_sym_time] = ACTIONS(6691),
    [anon_sym_bit] = ACTIONS(6691),
    [anon_sym_logic] = ACTIONS(6691),
    [anon_sym_reg] = ACTIONS(6691),
    [anon_sym_shortreal] = ACTIONS(6691),
    [anon_sym_real] = ACTIONS(6691),
    [anon_sym_realtime] = ACTIONS(6691),
    [anon_sym_supply0] = ACTIONS(6691),
    [anon_sym_supply1] = ACTIONS(6691),
    [anon_sym_signed] = ACTIONS(6691),
    [anon_sym_unsigned] = ACTIONS(6691),
    [anon_sym_task] = ACTIONS(6691),
    [anon_sym_assert] = ACTIONS(6691),
    [anon_sym_property] = ACTIONS(6691),
    [anon_sym_assume] = ACTIONS(6691),
    [anon_sym_cover] = ACTIONS(6691),
    [anon_sym_sequence] = ACTIONS(6691),
    [anon_sym_restrict] = ACTIONS(6691),
    [anon_sym_not] = ACTIONS(6691),
    [anon_sym_or] = ACTIONS(6691),
    [anon_sym_and] = ACTIONS(6691),
    [anon_sym_case] = ACTIONS(6691),
    [anon_sym_always] = ACTIONS(6691),
    [anon_sym_covergroup] = ACTIONS(6691),
    [anon_sym_let] = ACTIONS(6691),
    [anon_sym_pulldown] = ACTIONS(6691),
    [anon_sym_pullup] = ACTIONS(6691),
    [anon_sym_cmos] = ACTIONS(6691),
    [anon_sym_rcmos] = ACTIONS(6691),
    [anon_sym_bufif0] = ACTIONS(6691),
    [anon_sym_bufif1] = ACTIONS(6691),
    [anon_sym_notif0] = ACTIONS(6691),
    [anon_sym_notif1] = ACTIONS(6691),
    [anon_sym_nmos] = ACTIONS(6691),
    [anon_sym_pmos] = ACTIONS(6691),
    [anon_sym_rnmos] = ACTIONS(6691),
    [anon_sym_rpmos] = ACTIONS(6691),
    [anon_sym_nand] = ACTIONS(6691),
    [anon_sym_nor] = ACTIONS(6691),
    [anon_sym_xor] = ACTIONS(6691),
    [anon_sym_xnor] = ACTIONS(6691),
    [anon_sym_buf] = ACTIONS(6691),
    [anon_sym_tranif0] = ACTIONS(6691),
    [anon_sym_tranif1] = ACTIONS(6691),
    [anon_sym_rtranif1] = ACTIONS(6691),
    [anon_sym_rtranif0] = ACTIONS(6691),
    [anon_sym_tran] = ACTIONS(6691),
    [anon_sym_rtran] = ACTIONS(6691),
    [anon_sym_generate] = ACTIONS(6691),
    [anon_sym_endgenerate] = ACTIONS(6691),
    [anon_sym_for] = ACTIONS(6691),
    [anon_sym_initial] = ACTIONS(6691),
    [anon_sym_assign] = ACTIONS(6691),
    [anon_sym_alias] = ACTIONS(6691),
    [anon_sym_always_comb] = ACTIONS(6691),
    [anon_sym_always_latch] = ACTIONS(6691),
    [anon_sym_always_ff] = ACTIONS(6691),
    [anon_sym_final] = ACTIONS(6691),
    [anon_sym_global] = ACTIONS(6691),
    [anon_sym_LPAREN_STAR] = ACTIONS(6693),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6693),
    [anon_sym_DOLLARunit] = ACTIONS(6693),
  },
  [4659] = {
    [sym_simple_identifier] = ACTIONS(5820),
    [anon_sym_wire] = ACTIONS(5820),
    [anon_sym_tri] = ACTIONS(5820),
    [anon_sym_tri0] = ACTIONS(5820),
    [anon_sym_tri1] = ACTIONS(5820),
    [anon_sym_wand] = ACTIONS(5820),
    [anon_sym_triand] = ACTIONS(5820),
    [anon_sym_wor] = ACTIONS(5820),
    [anon_sym_trior] = ACTIONS(5820),
    [anon_sym_trireg] = ACTIONS(5820),
    [anon_sym_uwire] = ACTIONS(5820),
    [anon_sym_SEMI] = ACTIONS(5822),
    [anon_sym_extern] = ACTIONS(5820),
    [anon_sym_interface] = ACTIONS(5820),
    [anon_sym_checker] = ACTIONS(5820),
    [anon_sym_virtual] = ACTIONS(5820),
    [anon_sym_class] = ACTIONS(5820),
    [anon_sym_type] = ACTIONS(5820),
    [anon_sym_DOLLARfatal] = ACTIONS(5822),
    [anon_sym_DOLLARerror] = ACTIONS(5822),
    [anon_sym_DOLLARwarning] = ACTIONS(5822),
    [anon_sym_DOLLARinfo] = ACTIONS(5822),
    [anon_sym_default] = ACTIONS(5820),
    [anon_sym_clocking] = ACTIONS(5820),
    [anon_sym_defparam] = ACTIONS(5820),
    [anon_sym_bind] = ACTIONS(5820),
    [anon_sym_rand] = ACTIONS(5820),
    [anon_sym_const] = ACTIONS(5820),
    [anon_sym_function] = ACTIONS(5820),
    [anon_sym_static] = ACTIONS(5820),
    [anon_sym_constraint] = ACTIONS(5820),
    [anon_sym_if] = ACTIONS(5820),
    [anon_sym_else] = ACTIONS(5820),
    [anon_sym_LBRACK] = ACTIONS(5822),
    [anon_sym_localparam] = ACTIONS(5820),
    [anon_sym_parameter] = ACTIONS(5820),
    [anon_sym_var] = ACTIONS(5820),
    [anon_sym_import] = ACTIONS(5820),
    [anon_sym_export] = ACTIONS(5820),
    [anon_sym_genvar] = ACTIONS(5820),
    [anon_sym_interconnect] = ACTIONS(5820),
    [anon_sym_typedef] = ACTIONS(5820),
    [anon_sym_enum] = ACTIONS(5820),
    [anon_sym_struct] = ACTIONS(5820),
    [anon_sym_union] = ACTIONS(5820),
    [anon_sym_nettype] = ACTIONS(5820),
    [anon_sym_automatic] = ACTIONS(5820),
    [anon_sym_string] = ACTIONS(5820),
    [anon_sym_chandle] = ACTIONS(5820),
    [anon_sym_event] = ACTIONS(5820),
    [anon_sym_byte] = ACTIONS(5820),
    [anon_sym_shortint] = ACTIONS(5820),
    [anon_sym_int] = ACTIONS(5820),
    [anon_sym_longint] = ACTIONS(5820),
    [anon_sym_integer] = ACTIONS(5820),
    [anon_sym_time] = ACTIONS(5820),
    [anon_sym_bit] = ACTIONS(5820),
    [anon_sym_logic] = ACTIONS(5820),
    [anon_sym_reg] = ACTIONS(5820),
    [anon_sym_shortreal] = ACTIONS(5820),
    [anon_sym_real] = ACTIONS(5820),
    [anon_sym_realtime] = ACTIONS(5820),
    [anon_sym_supply0] = ACTIONS(5820),
    [anon_sym_supply1] = ACTIONS(5820),
    [anon_sym_signed] = ACTIONS(5820),
    [anon_sym_unsigned] = ACTIONS(5820),
    [anon_sym_task] = ACTIONS(5820),
    [anon_sym_assert] = ACTIONS(5820),
    [anon_sym_property] = ACTIONS(5820),
    [anon_sym_assume] = ACTIONS(5820),
    [anon_sym_cover] = ACTIONS(5820),
    [anon_sym_sequence] = ACTIONS(5820),
    [anon_sym_restrict] = ACTIONS(5820),
    [anon_sym_not] = ACTIONS(5820),
    [anon_sym_or] = ACTIONS(5820),
    [anon_sym_and] = ACTIONS(5820),
    [anon_sym_case] = ACTIONS(5820),
    [anon_sym_always] = ACTIONS(5820),
    [anon_sym_covergroup] = ACTIONS(5820),
    [anon_sym_end] = ACTIONS(5820),
    [anon_sym_let] = ACTIONS(5820),
    [anon_sym_pulldown] = ACTIONS(5820),
    [anon_sym_pullup] = ACTIONS(5820),
    [anon_sym_cmos] = ACTIONS(5820),
    [anon_sym_rcmos] = ACTIONS(5820),
    [anon_sym_bufif0] = ACTIONS(5820),
    [anon_sym_bufif1] = ACTIONS(5820),
    [anon_sym_notif0] = ACTIONS(5820),
    [anon_sym_notif1] = ACTIONS(5820),
    [anon_sym_nmos] = ACTIONS(5820),
    [anon_sym_pmos] = ACTIONS(5820),
    [anon_sym_rnmos] = ACTIONS(5820),
    [anon_sym_rpmos] = ACTIONS(5820),
    [anon_sym_nand] = ACTIONS(5820),
    [anon_sym_nor] = ACTIONS(5820),
    [anon_sym_xor] = ACTIONS(5820),
    [anon_sym_xnor] = ACTIONS(5820),
    [anon_sym_buf] = ACTIONS(5820),
    [anon_sym_tranif0] = ACTIONS(5820),
    [anon_sym_tranif1] = ACTIONS(5820),
    [anon_sym_rtranif1] = ACTIONS(5820),
    [anon_sym_rtranif0] = ACTIONS(5820),
    [anon_sym_tran] = ACTIONS(5820),
    [anon_sym_rtran] = ACTIONS(5820),
    [anon_sym_generate] = ACTIONS(5820),
    [anon_sym_for] = ACTIONS(5820),
    [anon_sym_initial] = ACTIONS(5820),
    [anon_sym_assign] = ACTIONS(5820),
    [anon_sym_alias] = ACTIONS(5820),
    [anon_sym_always_comb] = ACTIONS(5820),
    [anon_sym_always_latch] = ACTIONS(5820),
    [anon_sym_always_ff] = ACTIONS(5820),
    [anon_sym_final] = ACTIONS(5820),
    [anon_sym_global] = ACTIONS(5820),
    [anon_sym_LPAREN_STAR] = ACTIONS(5822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5822),
    [anon_sym_DOLLARunit] = ACTIONS(5822),
  },
  [4660] = {
    [sym_simple_identifier] = ACTIONS(4908),
    [anon_sym_wire] = ACTIONS(4908),
    [anon_sym_tri] = ACTIONS(4908),
    [anon_sym_tri0] = ACTIONS(4908),
    [anon_sym_tri1] = ACTIONS(4908),
    [anon_sym_wand] = ACTIONS(4908),
    [anon_sym_triand] = ACTIONS(4908),
    [anon_sym_wor] = ACTIONS(4908),
    [anon_sym_trior] = ACTIONS(4908),
    [anon_sym_trireg] = ACTIONS(4908),
    [anon_sym_uwire] = ACTIONS(4908),
    [anon_sym_SEMI] = ACTIONS(4906),
    [anon_sym_extern] = ACTIONS(4908),
    [anon_sym_interface] = ACTIONS(4908),
    [anon_sym_checker] = ACTIONS(4908),
    [anon_sym_virtual] = ACTIONS(4908),
    [anon_sym_class] = ACTIONS(4908),
    [anon_sym_type] = ACTIONS(4908),
    [anon_sym_DOLLARfatal] = ACTIONS(4906),
    [anon_sym_DOLLARerror] = ACTIONS(4906),
    [anon_sym_DOLLARwarning] = ACTIONS(4906),
    [anon_sym_DOLLARinfo] = ACTIONS(4906),
    [anon_sym_default] = ACTIONS(4908),
    [anon_sym_clocking] = ACTIONS(4908),
    [anon_sym_defparam] = ACTIONS(4908),
    [anon_sym_bind] = ACTIONS(4908),
    [anon_sym_rand] = ACTIONS(4908),
    [anon_sym_const] = ACTIONS(4908),
    [anon_sym_function] = ACTIONS(4908),
    [anon_sym_static] = ACTIONS(4908),
    [anon_sym_constraint] = ACTIONS(4908),
    [anon_sym_if] = ACTIONS(4908),
    [anon_sym_else] = ACTIONS(4908),
    [anon_sym_LBRACK] = ACTIONS(4906),
    [anon_sym_localparam] = ACTIONS(4908),
    [anon_sym_parameter] = ACTIONS(4908),
    [anon_sym_var] = ACTIONS(4908),
    [anon_sym_import] = ACTIONS(4908),
    [anon_sym_export] = ACTIONS(4908),
    [anon_sym_genvar] = ACTIONS(4908),
    [anon_sym_interconnect] = ACTIONS(4908),
    [anon_sym_typedef] = ACTIONS(4908),
    [anon_sym_enum] = ACTIONS(4908),
    [anon_sym_struct] = ACTIONS(4908),
    [anon_sym_union] = ACTIONS(4908),
    [anon_sym_nettype] = ACTIONS(4908),
    [anon_sym_automatic] = ACTIONS(4908),
    [anon_sym_string] = ACTIONS(4908),
    [anon_sym_chandle] = ACTIONS(4908),
    [anon_sym_event] = ACTIONS(4908),
    [anon_sym_byte] = ACTIONS(4908),
    [anon_sym_shortint] = ACTIONS(4908),
    [anon_sym_int] = ACTIONS(4908),
    [anon_sym_longint] = ACTIONS(4908),
    [anon_sym_integer] = ACTIONS(4908),
    [anon_sym_time] = ACTIONS(4908),
    [anon_sym_bit] = ACTIONS(4908),
    [anon_sym_logic] = ACTIONS(4908),
    [anon_sym_reg] = ACTIONS(4908),
    [anon_sym_shortreal] = ACTIONS(4908),
    [anon_sym_real] = ACTIONS(4908),
    [anon_sym_realtime] = ACTIONS(4908),
    [anon_sym_supply0] = ACTIONS(4908),
    [anon_sym_supply1] = ACTIONS(4908),
    [anon_sym_signed] = ACTIONS(4908),
    [anon_sym_unsigned] = ACTIONS(4908),
    [anon_sym_task] = ACTIONS(4908),
    [anon_sym_assert] = ACTIONS(4908),
    [anon_sym_property] = ACTIONS(4908),
    [anon_sym_assume] = ACTIONS(4908),
    [anon_sym_cover] = ACTIONS(4908),
    [anon_sym_sequence] = ACTIONS(4908),
    [anon_sym_restrict] = ACTIONS(4908),
    [anon_sym_not] = ACTIONS(4908),
    [anon_sym_or] = ACTIONS(4908),
    [anon_sym_and] = ACTIONS(4908),
    [anon_sym_case] = ACTIONS(4908),
    [anon_sym_always] = ACTIONS(4908),
    [anon_sym_covergroup] = ACTIONS(4908),
    [anon_sym_end] = ACTIONS(4908),
    [anon_sym_let] = ACTIONS(4908),
    [anon_sym_pulldown] = ACTIONS(4908),
    [anon_sym_pullup] = ACTIONS(4908),
    [anon_sym_cmos] = ACTIONS(4908),
    [anon_sym_rcmos] = ACTIONS(4908),
    [anon_sym_bufif0] = ACTIONS(4908),
    [anon_sym_bufif1] = ACTIONS(4908),
    [anon_sym_notif0] = ACTIONS(4908),
    [anon_sym_notif1] = ACTIONS(4908),
    [anon_sym_nmos] = ACTIONS(4908),
    [anon_sym_pmos] = ACTIONS(4908),
    [anon_sym_rnmos] = ACTIONS(4908),
    [anon_sym_rpmos] = ACTIONS(4908),
    [anon_sym_nand] = ACTIONS(4908),
    [anon_sym_nor] = ACTIONS(4908),
    [anon_sym_xor] = ACTIONS(4908),
    [anon_sym_xnor] = ACTIONS(4908),
    [anon_sym_buf] = ACTIONS(4908),
    [anon_sym_tranif0] = ACTIONS(4908),
    [anon_sym_tranif1] = ACTIONS(4908),
    [anon_sym_rtranif1] = ACTIONS(4908),
    [anon_sym_rtranif0] = ACTIONS(4908),
    [anon_sym_tran] = ACTIONS(4908),
    [anon_sym_rtran] = ACTIONS(4908),
    [anon_sym_generate] = ACTIONS(4908),
    [anon_sym_for] = ACTIONS(4908),
    [anon_sym_initial] = ACTIONS(4908),
    [anon_sym_assign] = ACTIONS(4908),
    [anon_sym_alias] = ACTIONS(4908),
    [anon_sym_always_comb] = ACTIONS(4908),
    [anon_sym_always_latch] = ACTIONS(4908),
    [anon_sym_always_ff] = ACTIONS(4908),
    [anon_sym_final] = ACTIONS(4908),
    [anon_sym_global] = ACTIONS(4908),
    [anon_sym_LPAREN_STAR] = ACTIONS(4906),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4906),
    [anon_sym_DOLLARunit] = ACTIONS(4906),
  },
  [4661] = {
    [sym_simple_identifier] = ACTIONS(5854),
    [anon_sym_wire] = ACTIONS(5854),
    [anon_sym_tri] = ACTIONS(5854),
    [anon_sym_tri0] = ACTIONS(5854),
    [anon_sym_tri1] = ACTIONS(5854),
    [anon_sym_wand] = ACTIONS(5854),
    [anon_sym_triand] = ACTIONS(5854),
    [anon_sym_wor] = ACTIONS(5854),
    [anon_sym_trior] = ACTIONS(5854),
    [anon_sym_trireg] = ACTIONS(5854),
    [anon_sym_uwire] = ACTIONS(5854),
    [anon_sym_SEMI] = ACTIONS(5856),
    [anon_sym_extern] = ACTIONS(5854),
    [anon_sym_interface] = ACTIONS(5854),
    [anon_sym_checker] = ACTIONS(5854),
    [anon_sym_virtual] = ACTIONS(5854),
    [anon_sym_class] = ACTIONS(5854),
    [anon_sym_type] = ACTIONS(5854),
    [anon_sym_DOLLARfatal] = ACTIONS(5856),
    [anon_sym_DOLLARerror] = ACTIONS(5856),
    [anon_sym_DOLLARwarning] = ACTIONS(5856),
    [anon_sym_DOLLARinfo] = ACTIONS(5856),
    [anon_sym_default] = ACTIONS(5854),
    [anon_sym_clocking] = ACTIONS(5854),
    [anon_sym_defparam] = ACTIONS(5854),
    [anon_sym_bind] = ACTIONS(5854),
    [anon_sym_rand] = ACTIONS(5854),
    [anon_sym_const] = ACTIONS(5854),
    [anon_sym_function] = ACTIONS(5854),
    [anon_sym_static] = ACTIONS(5854),
    [anon_sym_constraint] = ACTIONS(5854),
    [anon_sym_if] = ACTIONS(5854),
    [anon_sym_else] = ACTIONS(5854),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_localparam] = ACTIONS(5854),
    [anon_sym_parameter] = ACTIONS(5854),
    [anon_sym_var] = ACTIONS(5854),
    [anon_sym_import] = ACTIONS(5854),
    [anon_sym_export] = ACTIONS(5854),
    [anon_sym_genvar] = ACTIONS(5854),
    [anon_sym_interconnect] = ACTIONS(5854),
    [anon_sym_typedef] = ACTIONS(5854),
    [anon_sym_enum] = ACTIONS(5854),
    [anon_sym_struct] = ACTIONS(5854),
    [anon_sym_union] = ACTIONS(5854),
    [anon_sym_nettype] = ACTIONS(5854),
    [anon_sym_automatic] = ACTIONS(5854),
    [anon_sym_string] = ACTIONS(5854),
    [anon_sym_chandle] = ACTIONS(5854),
    [anon_sym_event] = ACTIONS(5854),
    [anon_sym_byte] = ACTIONS(5854),
    [anon_sym_shortint] = ACTIONS(5854),
    [anon_sym_int] = ACTIONS(5854),
    [anon_sym_longint] = ACTIONS(5854),
    [anon_sym_integer] = ACTIONS(5854),
    [anon_sym_time] = ACTIONS(5854),
    [anon_sym_bit] = ACTIONS(5854),
    [anon_sym_logic] = ACTIONS(5854),
    [anon_sym_reg] = ACTIONS(5854),
    [anon_sym_shortreal] = ACTIONS(5854),
    [anon_sym_real] = ACTIONS(5854),
    [anon_sym_realtime] = ACTIONS(5854),
    [anon_sym_supply0] = ACTIONS(5854),
    [anon_sym_supply1] = ACTIONS(5854),
    [anon_sym_signed] = ACTIONS(5854),
    [anon_sym_unsigned] = ACTIONS(5854),
    [anon_sym_task] = ACTIONS(5854),
    [anon_sym_assert] = ACTIONS(5854),
    [anon_sym_property] = ACTIONS(5854),
    [anon_sym_assume] = ACTIONS(5854),
    [anon_sym_cover] = ACTIONS(5854),
    [anon_sym_sequence] = ACTIONS(5854),
    [anon_sym_restrict] = ACTIONS(5854),
    [anon_sym_not] = ACTIONS(5854),
    [anon_sym_or] = ACTIONS(5854),
    [anon_sym_and] = ACTIONS(5854),
    [anon_sym_case] = ACTIONS(5854),
    [anon_sym_always] = ACTIONS(5854),
    [anon_sym_covergroup] = ACTIONS(5854),
    [anon_sym_let] = ACTIONS(5854),
    [anon_sym_pulldown] = ACTIONS(5854),
    [anon_sym_pullup] = ACTIONS(5854),
    [anon_sym_cmos] = ACTIONS(5854),
    [anon_sym_rcmos] = ACTIONS(5854),
    [anon_sym_bufif0] = ACTIONS(5854),
    [anon_sym_bufif1] = ACTIONS(5854),
    [anon_sym_notif0] = ACTIONS(5854),
    [anon_sym_notif1] = ACTIONS(5854),
    [anon_sym_nmos] = ACTIONS(5854),
    [anon_sym_pmos] = ACTIONS(5854),
    [anon_sym_rnmos] = ACTIONS(5854),
    [anon_sym_rpmos] = ACTIONS(5854),
    [anon_sym_nand] = ACTIONS(5854),
    [anon_sym_nor] = ACTIONS(5854),
    [anon_sym_xor] = ACTIONS(5854),
    [anon_sym_xnor] = ACTIONS(5854),
    [anon_sym_buf] = ACTIONS(5854),
    [anon_sym_tranif0] = ACTIONS(5854),
    [anon_sym_tranif1] = ACTIONS(5854),
    [anon_sym_rtranif1] = ACTIONS(5854),
    [anon_sym_rtranif0] = ACTIONS(5854),
    [anon_sym_tran] = ACTIONS(5854),
    [anon_sym_rtran] = ACTIONS(5854),
    [anon_sym_generate] = ACTIONS(5854),
    [anon_sym_endgenerate] = ACTIONS(5854),
    [anon_sym_for] = ACTIONS(5854),
    [anon_sym_initial] = ACTIONS(5854),
    [anon_sym_assign] = ACTIONS(5854),
    [anon_sym_alias] = ACTIONS(5854),
    [anon_sym_always_comb] = ACTIONS(5854),
    [anon_sym_always_latch] = ACTIONS(5854),
    [anon_sym_always_ff] = ACTIONS(5854),
    [anon_sym_final] = ACTIONS(5854),
    [anon_sym_global] = ACTIONS(5854),
    [anon_sym_LPAREN_STAR] = ACTIONS(5856),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5856),
    [anon_sym_DOLLARunit] = ACTIONS(5856),
  },
  [4662] = {
    [sym_simple_identifier] = ACTIONS(5824),
    [anon_sym_wire] = ACTIONS(5824),
    [anon_sym_tri] = ACTIONS(5824),
    [anon_sym_tri0] = ACTIONS(5824),
    [anon_sym_tri1] = ACTIONS(5824),
    [anon_sym_wand] = ACTIONS(5824),
    [anon_sym_triand] = ACTIONS(5824),
    [anon_sym_wor] = ACTIONS(5824),
    [anon_sym_trior] = ACTIONS(5824),
    [anon_sym_trireg] = ACTIONS(5824),
    [anon_sym_uwire] = ACTIONS(5824),
    [anon_sym_SEMI] = ACTIONS(5826),
    [anon_sym_extern] = ACTIONS(5824),
    [anon_sym_interface] = ACTIONS(5824),
    [anon_sym_checker] = ACTIONS(5824),
    [anon_sym_virtual] = ACTIONS(5824),
    [anon_sym_class] = ACTIONS(5824),
    [anon_sym_type] = ACTIONS(5824),
    [anon_sym_DOLLARfatal] = ACTIONS(5826),
    [anon_sym_DOLLARerror] = ACTIONS(5826),
    [anon_sym_DOLLARwarning] = ACTIONS(5826),
    [anon_sym_DOLLARinfo] = ACTIONS(5826),
    [anon_sym_default] = ACTIONS(5824),
    [anon_sym_clocking] = ACTIONS(5824),
    [anon_sym_defparam] = ACTIONS(5824),
    [anon_sym_bind] = ACTIONS(5824),
    [anon_sym_rand] = ACTIONS(5824),
    [anon_sym_const] = ACTIONS(5824),
    [anon_sym_function] = ACTIONS(5824),
    [anon_sym_static] = ACTIONS(5824),
    [anon_sym_constraint] = ACTIONS(5824),
    [anon_sym_if] = ACTIONS(5824),
    [anon_sym_else] = ACTIONS(5824),
    [anon_sym_LBRACK] = ACTIONS(5826),
    [anon_sym_localparam] = ACTIONS(5824),
    [anon_sym_parameter] = ACTIONS(5824),
    [anon_sym_var] = ACTIONS(5824),
    [anon_sym_import] = ACTIONS(5824),
    [anon_sym_export] = ACTIONS(5824),
    [anon_sym_genvar] = ACTIONS(5824),
    [anon_sym_interconnect] = ACTIONS(5824),
    [anon_sym_typedef] = ACTIONS(5824),
    [anon_sym_enum] = ACTIONS(5824),
    [anon_sym_struct] = ACTIONS(5824),
    [anon_sym_union] = ACTIONS(5824),
    [anon_sym_nettype] = ACTIONS(5824),
    [anon_sym_automatic] = ACTIONS(5824),
    [anon_sym_string] = ACTIONS(5824),
    [anon_sym_chandle] = ACTIONS(5824),
    [anon_sym_event] = ACTIONS(5824),
    [anon_sym_byte] = ACTIONS(5824),
    [anon_sym_shortint] = ACTIONS(5824),
    [anon_sym_int] = ACTIONS(5824),
    [anon_sym_longint] = ACTIONS(5824),
    [anon_sym_integer] = ACTIONS(5824),
    [anon_sym_time] = ACTIONS(5824),
    [anon_sym_bit] = ACTIONS(5824),
    [anon_sym_logic] = ACTIONS(5824),
    [anon_sym_reg] = ACTIONS(5824),
    [anon_sym_shortreal] = ACTIONS(5824),
    [anon_sym_real] = ACTIONS(5824),
    [anon_sym_realtime] = ACTIONS(5824),
    [anon_sym_supply0] = ACTIONS(5824),
    [anon_sym_supply1] = ACTIONS(5824),
    [anon_sym_signed] = ACTIONS(5824),
    [anon_sym_unsigned] = ACTIONS(5824),
    [anon_sym_task] = ACTIONS(5824),
    [anon_sym_assert] = ACTIONS(5824),
    [anon_sym_property] = ACTIONS(5824),
    [anon_sym_assume] = ACTIONS(5824),
    [anon_sym_cover] = ACTIONS(5824),
    [anon_sym_sequence] = ACTIONS(5824),
    [anon_sym_restrict] = ACTIONS(5824),
    [anon_sym_not] = ACTIONS(5824),
    [anon_sym_or] = ACTIONS(5824),
    [anon_sym_and] = ACTIONS(5824),
    [anon_sym_case] = ACTIONS(5824),
    [anon_sym_always] = ACTIONS(5824),
    [anon_sym_covergroup] = ACTIONS(5824),
    [anon_sym_end] = ACTIONS(5824),
    [anon_sym_let] = ACTIONS(5824),
    [anon_sym_pulldown] = ACTIONS(5824),
    [anon_sym_pullup] = ACTIONS(5824),
    [anon_sym_cmos] = ACTIONS(5824),
    [anon_sym_rcmos] = ACTIONS(5824),
    [anon_sym_bufif0] = ACTIONS(5824),
    [anon_sym_bufif1] = ACTIONS(5824),
    [anon_sym_notif0] = ACTIONS(5824),
    [anon_sym_notif1] = ACTIONS(5824),
    [anon_sym_nmos] = ACTIONS(5824),
    [anon_sym_pmos] = ACTIONS(5824),
    [anon_sym_rnmos] = ACTIONS(5824),
    [anon_sym_rpmos] = ACTIONS(5824),
    [anon_sym_nand] = ACTIONS(5824),
    [anon_sym_nor] = ACTIONS(5824),
    [anon_sym_xor] = ACTIONS(5824),
    [anon_sym_xnor] = ACTIONS(5824),
    [anon_sym_buf] = ACTIONS(5824),
    [anon_sym_tranif0] = ACTIONS(5824),
    [anon_sym_tranif1] = ACTIONS(5824),
    [anon_sym_rtranif1] = ACTIONS(5824),
    [anon_sym_rtranif0] = ACTIONS(5824),
    [anon_sym_tran] = ACTIONS(5824),
    [anon_sym_rtran] = ACTIONS(5824),
    [anon_sym_generate] = ACTIONS(5824),
    [anon_sym_for] = ACTIONS(5824),
    [anon_sym_initial] = ACTIONS(5824),
    [anon_sym_assign] = ACTIONS(5824),
    [anon_sym_alias] = ACTIONS(5824),
    [anon_sym_always_comb] = ACTIONS(5824),
    [anon_sym_always_latch] = ACTIONS(5824),
    [anon_sym_always_ff] = ACTIONS(5824),
    [anon_sym_final] = ACTIONS(5824),
    [anon_sym_global] = ACTIONS(5824),
    [anon_sym_LPAREN_STAR] = ACTIONS(5826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5826),
    [anon_sym_DOLLARunit] = ACTIONS(5826),
  },
  [4663] = {
    [sym_simple_identifier] = ACTIONS(5828),
    [anon_sym_wire] = ACTIONS(5828),
    [anon_sym_tri] = ACTIONS(5828),
    [anon_sym_tri0] = ACTIONS(5828),
    [anon_sym_tri1] = ACTIONS(5828),
    [anon_sym_wand] = ACTIONS(5828),
    [anon_sym_triand] = ACTIONS(5828),
    [anon_sym_wor] = ACTIONS(5828),
    [anon_sym_trior] = ACTIONS(5828),
    [anon_sym_trireg] = ACTIONS(5828),
    [anon_sym_uwire] = ACTIONS(5828),
    [anon_sym_SEMI] = ACTIONS(5830),
    [anon_sym_extern] = ACTIONS(5828),
    [anon_sym_interface] = ACTIONS(5828),
    [anon_sym_checker] = ACTIONS(5828),
    [anon_sym_virtual] = ACTIONS(5828),
    [anon_sym_class] = ACTIONS(5828),
    [anon_sym_type] = ACTIONS(5828),
    [anon_sym_DOLLARfatal] = ACTIONS(5830),
    [anon_sym_DOLLARerror] = ACTIONS(5830),
    [anon_sym_DOLLARwarning] = ACTIONS(5830),
    [anon_sym_DOLLARinfo] = ACTIONS(5830),
    [anon_sym_default] = ACTIONS(5828),
    [anon_sym_clocking] = ACTIONS(5828),
    [anon_sym_defparam] = ACTIONS(5828),
    [anon_sym_bind] = ACTIONS(5828),
    [anon_sym_rand] = ACTIONS(5828),
    [anon_sym_const] = ACTIONS(5828),
    [anon_sym_function] = ACTIONS(5828),
    [anon_sym_static] = ACTIONS(5828),
    [anon_sym_constraint] = ACTIONS(5828),
    [anon_sym_if] = ACTIONS(5828),
    [anon_sym_else] = ACTIONS(5828),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_localparam] = ACTIONS(5828),
    [anon_sym_parameter] = ACTIONS(5828),
    [anon_sym_var] = ACTIONS(5828),
    [anon_sym_import] = ACTIONS(5828),
    [anon_sym_export] = ACTIONS(5828),
    [anon_sym_genvar] = ACTIONS(5828),
    [anon_sym_interconnect] = ACTIONS(5828),
    [anon_sym_typedef] = ACTIONS(5828),
    [anon_sym_enum] = ACTIONS(5828),
    [anon_sym_struct] = ACTIONS(5828),
    [anon_sym_union] = ACTIONS(5828),
    [anon_sym_nettype] = ACTIONS(5828),
    [anon_sym_automatic] = ACTIONS(5828),
    [anon_sym_string] = ACTIONS(5828),
    [anon_sym_chandle] = ACTIONS(5828),
    [anon_sym_event] = ACTIONS(5828),
    [anon_sym_byte] = ACTIONS(5828),
    [anon_sym_shortint] = ACTIONS(5828),
    [anon_sym_int] = ACTIONS(5828),
    [anon_sym_longint] = ACTIONS(5828),
    [anon_sym_integer] = ACTIONS(5828),
    [anon_sym_time] = ACTIONS(5828),
    [anon_sym_bit] = ACTIONS(5828),
    [anon_sym_logic] = ACTIONS(5828),
    [anon_sym_reg] = ACTIONS(5828),
    [anon_sym_shortreal] = ACTIONS(5828),
    [anon_sym_real] = ACTIONS(5828),
    [anon_sym_realtime] = ACTIONS(5828),
    [anon_sym_supply0] = ACTIONS(5828),
    [anon_sym_supply1] = ACTIONS(5828),
    [anon_sym_signed] = ACTIONS(5828),
    [anon_sym_unsigned] = ACTIONS(5828),
    [anon_sym_task] = ACTIONS(5828),
    [anon_sym_assert] = ACTIONS(5828),
    [anon_sym_property] = ACTIONS(5828),
    [anon_sym_assume] = ACTIONS(5828),
    [anon_sym_cover] = ACTIONS(5828),
    [anon_sym_sequence] = ACTIONS(5828),
    [anon_sym_restrict] = ACTIONS(5828),
    [anon_sym_not] = ACTIONS(5828),
    [anon_sym_or] = ACTIONS(5828),
    [anon_sym_and] = ACTIONS(5828),
    [anon_sym_case] = ACTIONS(5828),
    [anon_sym_always] = ACTIONS(5828),
    [anon_sym_covergroup] = ACTIONS(5828),
    [anon_sym_end] = ACTIONS(5828),
    [anon_sym_let] = ACTIONS(5828),
    [anon_sym_pulldown] = ACTIONS(5828),
    [anon_sym_pullup] = ACTIONS(5828),
    [anon_sym_cmos] = ACTIONS(5828),
    [anon_sym_rcmos] = ACTIONS(5828),
    [anon_sym_bufif0] = ACTIONS(5828),
    [anon_sym_bufif1] = ACTIONS(5828),
    [anon_sym_notif0] = ACTIONS(5828),
    [anon_sym_notif1] = ACTIONS(5828),
    [anon_sym_nmos] = ACTIONS(5828),
    [anon_sym_pmos] = ACTIONS(5828),
    [anon_sym_rnmos] = ACTIONS(5828),
    [anon_sym_rpmos] = ACTIONS(5828),
    [anon_sym_nand] = ACTIONS(5828),
    [anon_sym_nor] = ACTIONS(5828),
    [anon_sym_xor] = ACTIONS(5828),
    [anon_sym_xnor] = ACTIONS(5828),
    [anon_sym_buf] = ACTIONS(5828),
    [anon_sym_tranif0] = ACTIONS(5828),
    [anon_sym_tranif1] = ACTIONS(5828),
    [anon_sym_rtranif1] = ACTIONS(5828),
    [anon_sym_rtranif0] = ACTIONS(5828),
    [anon_sym_tran] = ACTIONS(5828),
    [anon_sym_rtran] = ACTIONS(5828),
    [anon_sym_generate] = ACTIONS(5828),
    [anon_sym_for] = ACTIONS(5828),
    [anon_sym_initial] = ACTIONS(5828),
    [anon_sym_assign] = ACTIONS(5828),
    [anon_sym_alias] = ACTIONS(5828),
    [anon_sym_always_comb] = ACTIONS(5828),
    [anon_sym_always_latch] = ACTIONS(5828),
    [anon_sym_always_ff] = ACTIONS(5828),
    [anon_sym_final] = ACTIONS(5828),
    [anon_sym_global] = ACTIONS(5828),
    [anon_sym_LPAREN_STAR] = ACTIONS(5830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5830),
    [anon_sym_DOLLARunit] = ACTIONS(5830),
  },
  [4664] = {
    [sym_simple_identifier] = ACTIONS(5858),
    [anon_sym_wire] = ACTIONS(5858),
    [anon_sym_tri] = ACTIONS(5858),
    [anon_sym_tri0] = ACTIONS(5858),
    [anon_sym_tri1] = ACTIONS(5858),
    [anon_sym_wand] = ACTIONS(5858),
    [anon_sym_triand] = ACTIONS(5858),
    [anon_sym_wor] = ACTIONS(5858),
    [anon_sym_trior] = ACTIONS(5858),
    [anon_sym_trireg] = ACTIONS(5858),
    [anon_sym_uwire] = ACTIONS(5858),
    [anon_sym_SEMI] = ACTIONS(5860),
    [anon_sym_extern] = ACTIONS(5858),
    [anon_sym_interface] = ACTIONS(5858),
    [anon_sym_checker] = ACTIONS(5858),
    [anon_sym_virtual] = ACTIONS(5858),
    [anon_sym_class] = ACTIONS(5858),
    [anon_sym_type] = ACTIONS(5858),
    [anon_sym_DOLLARfatal] = ACTIONS(5860),
    [anon_sym_DOLLARerror] = ACTIONS(5860),
    [anon_sym_DOLLARwarning] = ACTIONS(5860),
    [anon_sym_DOLLARinfo] = ACTIONS(5860),
    [anon_sym_default] = ACTIONS(5858),
    [anon_sym_clocking] = ACTIONS(5858),
    [anon_sym_defparam] = ACTIONS(5858),
    [anon_sym_bind] = ACTIONS(5858),
    [anon_sym_rand] = ACTIONS(5858),
    [anon_sym_const] = ACTIONS(5858),
    [anon_sym_function] = ACTIONS(5858),
    [anon_sym_static] = ACTIONS(5858),
    [anon_sym_constraint] = ACTIONS(5858),
    [anon_sym_if] = ACTIONS(5858),
    [anon_sym_else] = ACTIONS(5858),
    [anon_sym_LBRACK] = ACTIONS(5860),
    [anon_sym_localparam] = ACTIONS(5858),
    [anon_sym_parameter] = ACTIONS(5858),
    [anon_sym_var] = ACTIONS(5858),
    [anon_sym_import] = ACTIONS(5858),
    [anon_sym_export] = ACTIONS(5858),
    [anon_sym_genvar] = ACTIONS(5858),
    [anon_sym_interconnect] = ACTIONS(5858),
    [anon_sym_typedef] = ACTIONS(5858),
    [anon_sym_enum] = ACTIONS(5858),
    [anon_sym_struct] = ACTIONS(5858),
    [anon_sym_union] = ACTIONS(5858),
    [anon_sym_nettype] = ACTIONS(5858),
    [anon_sym_automatic] = ACTIONS(5858),
    [anon_sym_string] = ACTIONS(5858),
    [anon_sym_chandle] = ACTIONS(5858),
    [anon_sym_event] = ACTIONS(5858),
    [anon_sym_byte] = ACTIONS(5858),
    [anon_sym_shortint] = ACTIONS(5858),
    [anon_sym_int] = ACTIONS(5858),
    [anon_sym_longint] = ACTIONS(5858),
    [anon_sym_integer] = ACTIONS(5858),
    [anon_sym_time] = ACTIONS(5858),
    [anon_sym_bit] = ACTIONS(5858),
    [anon_sym_logic] = ACTIONS(5858),
    [anon_sym_reg] = ACTIONS(5858),
    [anon_sym_shortreal] = ACTIONS(5858),
    [anon_sym_real] = ACTIONS(5858),
    [anon_sym_realtime] = ACTIONS(5858),
    [anon_sym_supply0] = ACTIONS(5858),
    [anon_sym_supply1] = ACTIONS(5858),
    [anon_sym_signed] = ACTIONS(5858),
    [anon_sym_unsigned] = ACTIONS(5858),
    [anon_sym_task] = ACTIONS(5858),
    [anon_sym_assert] = ACTIONS(5858),
    [anon_sym_property] = ACTIONS(5858),
    [anon_sym_assume] = ACTIONS(5858),
    [anon_sym_cover] = ACTIONS(5858),
    [anon_sym_sequence] = ACTIONS(5858),
    [anon_sym_restrict] = ACTIONS(5858),
    [anon_sym_not] = ACTIONS(5858),
    [anon_sym_or] = ACTIONS(5858),
    [anon_sym_and] = ACTIONS(5858),
    [anon_sym_case] = ACTIONS(5858),
    [anon_sym_always] = ACTIONS(5858),
    [anon_sym_covergroup] = ACTIONS(5858),
    [anon_sym_let] = ACTIONS(5858),
    [anon_sym_pulldown] = ACTIONS(5858),
    [anon_sym_pullup] = ACTIONS(5858),
    [anon_sym_cmos] = ACTIONS(5858),
    [anon_sym_rcmos] = ACTIONS(5858),
    [anon_sym_bufif0] = ACTIONS(5858),
    [anon_sym_bufif1] = ACTIONS(5858),
    [anon_sym_notif0] = ACTIONS(5858),
    [anon_sym_notif1] = ACTIONS(5858),
    [anon_sym_nmos] = ACTIONS(5858),
    [anon_sym_pmos] = ACTIONS(5858),
    [anon_sym_rnmos] = ACTIONS(5858),
    [anon_sym_rpmos] = ACTIONS(5858),
    [anon_sym_nand] = ACTIONS(5858),
    [anon_sym_nor] = ACTIONS(5858),
    [anon_sym_xor] = ACTIONS(5858),
    [anon_sym_xnor] = ACTIONS(5858),
    [anon_sym_buf] = ACTIONS(5858),
    [anon_sym_tranif0] = ACTIONS(5858),
    [anon_sym_tranif1] = ACTIONS(5858),
    [anon_sym_rtranif1] = ACTIONS(5858),
    [anon_sym_rtranif0] = ACTIONS(5858),
    [anon_sym_tran] = ACTIONS(5858),
    [anon_sym_rtran] = ACTIONS(5858),
    [anon_sym_generate] = ACTIONS(5858),
    [anon_sym_endgenerate] = ACTIONS(5858),
    [anon_sym_for] = ACTIONS(5858),
    [anon_sym_initial] = ACTIONS(5858),
    [anon_sym_assign] = ACTIONS(5858),
    [anon_sym_alias] = ACTIONS(5858),
    [anon_sym_always_comb] = ACTIONS(5858),
    [anon_sym_always_latch] = ACTIONS(5858),
    [anon_sym_always_ff] = ACTIONS(5858),
    [anon_sym_final] = ACTIONS(5858),
    [anon_sym_global] = ACTIONS(5858),
    [anon_sym_LPAREN_STAR] = ACTIONS(5860),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5860),
    [anon_sym_DOLLARunit] = ACTIONS(5860),
  },
  [4665] = {
    [sym_simple_identifier] = ACTIONS(6083),
    [anon_sym_wire] = ACTIONS(6083),
    [anon_sym_tri] = ACTIONS(6083),
    [anon_sym_tri0] = ACTIONS(6083),
    [anon_sym_tri1] = ACTIONS(6083),
    [anon_sym_wand] = ACTIONS(6083),
    [anon_sym_triand] = ACTIONS(6083),
    [anon_sym_wor] = ACTIONS(6083),
    [anon_sym_trior] = ACTIONS(6083),
    [anon_sym_trireg] = ACTIONS(6083),
    [anon_sym_uwire] = ACTIONS(6083),
    [anon_sym_SEMI] = ACTIONS(6085),
    [anon_sym_extern] = ACTIONS(6083),
    [anon_sym_interface] = ACTIONS(6083),
    [anon_sym_checker] = ACTIONS(6083),
    [anon_sym_virtual] = ACTIONS(6083),
    [anon_sym_class] = ACTIONS(6083),
    [anon_sym_type] = ACTIONS(6083),
    [anon_sym_DOLLARfatal] = ACTIONS(6085),
    [anon_sym_DOLLARerror] = ACTIONS(6085),
    [anon_sym_DOLLARwarning] = ACTIONS(6085),
    [anon_sym_DOLLARinfo] = ACTIONS(6085),
    [anon_sym_default] = ACTIONS(6083),
    [anon_sym_clocking] = ACTIONS(6083),
    [anon_sym_defparam] = ACTIONS(6083),
    [anon_sym_bind] = ACTIONS(6083),
    [anon_sym_rand] = ACTIONS(6083),
    [anon_sym_const] = ACTIONS(6083),
    [anon_sym_function] = ACTIONS(6083),
    [anon_sym_static] = ACTIONS(6083),
    [anon_sym_constraint] = ACTIONS(6083),
    [anon_sym_if] = ACTIONS(6083),
    [anon_sym_else] = ACTIONS(6083),
    [anon_sym_LBRACK] = ACTIONS(6085),
    [anon_sym_localparam] = ACTIONS(6083),
    [anon_sym_parameter] = ACTIONS(6083),
    [anon_sym_var] = ACTIONS(6083),
    [anon_sym_import] = ACTIONS(6083),
    [anon_sym_export] = ACTIONS(6083),
    [anon_sym_genvar] = ACTIONS(6083),
    [anon_sym_interconnect] = ACTIONS(6083),
    [anon_sym_typedef] = ACTIONS(6083),
    [anon_sym_enum] = ACTIONS(6083),
    [anon_sym_struct] = ACTIONS(6083),
    [anon_sym_union] = ACTIONS(6083),
    [anon_sym_nettype] = ACTIONS(6083),
    [anon_sym_automatic] = ACTIONS(6083),
    [anon_sym_string] = ACTIONS(6083),
    [anon_sym_chandle] = ACTIONS(6083),
    [anon_sym_event] = ACTIONS(6083),
    [anon_sym_byte] = ACTIONS(6083),
    [anon_sym_shortint] = ACTIONS(6083),
    [anon_sym_int] = ACTIONS(6083),
    [anon_sym_longint] = ACTIONS(6083),
    [anon_sym_integer] = ACTIONS(6083),
    [anon_sym_time] = ACTIONS(6083),
    [anon_sym_bit] = ACTIONS(6083),
    [anon_sym_logic] = ACTIONS(6083),
    [anon_sym_reg] = ACTIONS(6083),
    [anon_sym_shortreal] = ACTIONS(6083),
    [anon_sym_real] = ACTIONS(6083),
    [anon_sym_realtime] = ACTIONS(6083),
    [anon_sym_supply0] = ACTIONS(6083),
    [anon_sym_supply1] = ACTIONS(6083),
    [anon_sym_signed] = ACTIONS(6083),
    [anon_sym_unsigned] = ACTIONS(6083),
    [anon_sym_task] = ACTIONS(6083),
    [anon_sym_assert] = ACTIONS(6083),
    [anon_sym_property] = ACTIONS(6083),
    [anon_sym_assume] = ACTIONS(6083),
    [anon_sym_cover] = ACTIONS(6083),
    [anon_sym_sequence] = ACTIONS(6083),
    [anon_sym_restrict] = ACTIONS(6083),
    [anon_sym_not] = ACTIONS(6083),
    [anon_sym_or] = ACTIONS(6083),
    [anon_sym_and] = ACTIONS(6083),
    [anon_sym_case] = ACTIONS(6083),
    [anon_sym_always] = ACTIONS(6083),
    [anon_sym_covergroup] = ACTIONS(6083),
    [anon_sym_end] = ACTIONS(6083),
    [anon_sym_let] = ACTIONS(6083),
    [anon_sym_pulldown] = ACTIONS(6083),
    [anon_sym_pullup] = ACTIONS(6083),
    [anon_sym_cmos] = ACTIONS(6083),
    [anon_sym_rcmos] = ACTIONS(6083),
    [anon_sym_bufif0] = ACTIONS(6083),
    [anon_sym_bufif1] = ACTIONS(6083),
    [anon_sym_notif0] = ACTIONS(6083),
    [anon_sym_notif1] = ACTIONS(6083),
    [anon_sym_nmos] = ACTIONS(6083),
    [anon_sym_pmos] = ACTIONS(6083),
    [anon_sym_rnmos] = ACTIONS(6083),
    [anon_sym_rpmos] = ACTIONS(6083),
    [anon_sym_nand] = ACTIONS(6083),
    [anon_sym_nor] = ACTIONS(6083),
    [anon_sym_xor] = ACTIONS(6083),
    [anon_sym_xnor] = ACTIONS(6083),
    [anon_sym_buf] = ACTIONS(6083),
    [anon_sym_tranif0] = ACTIONS(6083),
    [anon_sym_tranif1] = ACTIONS(6083),
    [anon_sym_rtranif1] = ACTIONS(6083),
    [anon_sym_rtranif0] = ACTIONS(6083),
    [anon_sym_tran] = ACTIONS(6083),
    [anon_sym_rtran] = ACTIONS(6083),
    [anon_sym_generate] = ACTIONS(6083),
    [anon_sym_for] = ACTIONS(6083),
    [anon_sym_initial] = ACTIONS(6083),
    [anon_sym_assign] = ACTIONS(6083),
    [anon_sym_alias] = ACTIONS(6083),
    [anon_sym_always_comb] = ACTIONS(6083),
    [anon_sym_always_latch] = ACTIONS(6083),
    [anon_sym_always_ff] = ACTIONS(6083),
    [anon_sym_final] = ACTIONS(6083),
    [anon_sym_global] = ACTIONS(6083),
    [anon_sym_LPAREN_STAR] = ACTIONS(6085),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6085),
    [anon_sym_DOLLARunit] = ACTIONS(6085),
  },
  [4666] = {
    [sym_simple_identifier] = ACTIONS(5862),
    [anon_sym_wire] = ACTIONS(5862),
    [anon_sym_tri] = ACTIONS(5862),
    [anon_sym_tri0] = ACTIONS(5862),
    [anon_sym_tri1] = ACTIONS(5862),
    [anon_sym_wand] = ACTIONS(5862),
    [anon_sym_triand] = ACTIONS(5862),
    [anon_sym_wor] = ACTIONS(5862),
    [anon_sym_trior] = ACTIONS(5862),
    [anon_sym_trireg] = ACTIONS(5862),
    [anon_sym_uwire] = ACTIONS(5862),
    [anon_sym_SEMI] = ACTIONS(5864),
    [anon_sym_extern] = ACTIONS(5862),
    [anon_sym_interface] = ACTIONS(5862),
    [anon_sym_checker] = ACTIONS(5862),
    [anon_sym_virtual] = ACTIONS(5862),
    [anon_sym_class] = ACTIONS(5862),
    [anon_sym_type] = ACTIONS(5862),
    [anon_sym_DOLLARfatal] = ACTIONS(5864),
    [anon_sym_DOLLARerror] = ACTIONS(5864),
    [anon_sym_DOLLARwarning] = ACTIONS(5864),
    [anon_sym_DOLLARinfo] = ACTIONS(5864),
    [anon_sym_default] = ACTIONS(5862),
    [anon_sym_clocking] = ACTIONS(5862),
    [anon_sym_defparam] = ACTIONS(5862),
    [anon_sym_bind] = ACTIONS(5862),
    [anon_sym_rand] = ACTIONS(5862),
    [anon_sym_const] = ACTIONS(5862),
    [anon_sym_function] = ACTIONS(5862),
    [anon_sym_static] = ACTIONS(5862),
    [anon_sym_constraint] = ACTIONS(5862),
    [anon_sym_if] = ACTIONS(5862),
    [anon_sym_else] = ACTIONS(5862),
    [anon_sym_LBRACK] = ACTIONS(5864),
    [anon_sym_localparam] = ACTIONS(5862),
    [anon_sym_parameter] = ACTIONS(5862),
    [anon_sym_var] = ACTIONS(5862),
    [anon_sym_import] = ACTIONS(5862),
    [anon_sym_export] = ACTIONS(5862),
    [anon_sym_genvar] = ACTIONS(5862),
    [anon_sym_interconnect] = ACTIONS(5862),
    [anon_sym_typedef] = ACTIONS(5862),
    [anon_sym_enum] = ACTIONS(5862),
    [anon_sym_struct] = ACTIONS(5862),
    [anon_sym_union] = ACTIONS(5862),
    [anon_sym_nettype] = ACTIONS(5862),
    [anon_sym_automatic] = ACTIONS(5862),
    [anon_sym_string] = ACTIONS(5862),
    [anon_sym_chandle] = ACTIONS(5862),
    [anon_sym_event] = ACTIONS(5862),
    [anon_sym_byte] = ACTIONS(5862),
    [anon_sym_shortint] = ACTIONS(5862),
    [anon_sym_int] = ACTIONS(5862),
    [anon_sym_longint] = ACTIONS(5862),
    [anon_sym_integer] = ACTIONS(5862),
    [anon_sym_time] = ACTIONS(5862),
    [anon_sym_bit] = ACTIONS(5862),
    [anon_sym_logic] = ACTIONS(5862),
    [anon_sym_reg] = ACTIONS(5862),
    [anon_sym_shortreal] = ACTIONS(5862),
    [anon_sym_real] = ACTIONS(5862),
    [anon_sym_realtime] = ACTIONS(5862),
    [anon_sym_supply0] = ACTIONS(5862),
    [anon_sym_supply1] = ACTIONS(5862),
    [anon_sym_signed] = ACTIONS(5862),
    [anon_sym_unsigned] = ACTIONS(5862),
    [anon_sym_task] = ACTIONS(5862),
    [anon_sym_assert] = ACTIONS(5862),
    [anon_sym_property] = ACTIONS(5862),
    [anon_sym_assume] = ACTIONS(5862),
    [anon_sym_cover] = ACTIONS(5862),
    [anon_sym_sequence] = ACTIONS(5862),
    [anon_sym_restrict] = ACTIONS(5862),
    [anon_sym_not] = ACTIONS(5862),
    [anon_sym_or] = ACTIONS(5862),
    [anon_sym_and] = ACTIONS(5862),
    [anon_sym_case] = ACTIONS(5862),
    [anon_sym_always] = ACTIONS(5862),
    [anon_sym_covergroup] = ACTIONS(5862),
    [anon_sym_let] = ACTIONS(5862),
    [anon_sym_pulldown] = ACTIONS(5862),
    [anon_sym_pullup] = ACTIONS(5862),
    [anon_sym_cmos] = ACTIONS(5862),
    [anon_sym_rcmos] = ACTIONS(5862),
    [anon_sym_bufif0] = ACTIONS(5862),
    [anon_sym_bufif1] = ACTIONS(5862),
    [anon_sym_notif0] = ACTIONS(5862),
    [anon_sym_notif1] = ACTIONS(5862),
    [anon_sym_nmos] = ACTIONS(5862),
    [anon_sym_pmos] = ACTIONS(5862),
    [anon_sym_rnmos] = ACTIONS(5862),
    [anon_sym_rpmos] = ACTIONS(5862),
    [anon_sym_nand] = ACTIONS(5862),
    [anon_sym_nor] = ACTIONS(5862),
    [anon_sym_xor] = ACTIONS(5862),
    [anon_sym_xnor] = ACTIONS(5862),
    [anon_sym_buf] = ACTIONS(5862),
    [anon_sym_tranif0] = ACTIONS(5862),
    [anon_sym_tranif1] = ACTIONS(5862),
    [anon_sym_rtranif1] = ACTIONS(5862),
    [anon_sym_rtranif0] = ACTIONS(5862),
    [anon_sym_tran] = ACTIONS(5862),
    [anon_sym_rtran] = ACTIONS(5862),
    [anon_sym_generate] = ACTIONS(5862),
    [anon_sym_endgenerate] = ACTIONS(5862),
    [anon_sym_for] = ACTIONS(5862),
    [anon_sym_initial] = ACTIONS(5862),
    [anon_sym_assign] = ACTIONS(5862),
    [anon_sym_alias] = ACTIONS(5862),
    [anon_sym_always_comb] = ACTIONS(5862),
    [anon_sym_always_latch] = ACTIONS(5862),
    [anon_sym_always_ff] = ACTIONS(5862),
    [anon_sym_final] = ACTIONS(5862),
    [anon_sym_global] = ACTIONS(5862),
    [anon_sym_LPAREN_STAR] = ACTIONS(5864),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5864),
    [anon_sym_DOLLARunit] = ACTIONS(5864),
  },
  [4667] = {
    [sym_simple_identifier] = ACTIONS(5832),
    [anon_sym_wire] = ACTIONS(5832),
    [anon_sym_tri] = ACTIONS(5832),
    [anon_sym_tri0] = ACTIONS(5832),
    [anon_sym_tri1] = ACTIONS(5832),
    [anon_sym_wand] = ACTIONS(5832),
    [anon_sym_triand] = ACTIONS(5832),
    [anon_sym_wor] = ACTIONS(5832),
    [anon_sym_trior] = ACTIONS(5832),
    [anon_sym_trireg] = ACTIONS(5832),
    [anon_sym_uwire] = ACTIONS(5832),
    [anon_sym_SEMI] = ACTIONS(5834),
    [anon_sym_extern] = ACTIONS(5832),
    [anon_sym_interface] = ACTIONS(5832),
    [anon_sym_checker] = ACTIONS(5832),
    [anon_sym_virtual] = ACTIONS(5832),
    [anon_sym_class] = ACTIONS(5832),
    [anon_sym_type] = ACTIONS(5832),
    [anon_sym_DOLLARfatal] = ACTIONS(5834),
    [anon_sym_DOLLARerror] = ACTIONS(5834),
    [anon_sym_DOLLARwarning] = ACTIONS(5834),
    [anon_sym_DOLLARinfo] = ACTIONS(5834),
    [anon_sym_default] = ACTIONS(5832),
    [anon_sym_clocking] = ACTIONS(5832),
    [anon_sym_defparam] = ACTIONS(5832),
    [anon_sym_bind] = ACTIONS(5832),
    [anon_sym_rand] = ACTIONS(5832),
    [anon_sym_const] = ACTIONS(5832),
    [anon_sym_function] = ACTIONS(5832),
    [anon_sym_static] = ACTIONS(5832),
    [anon_sym_constraint] = ACTIONS(5832),
    [anon_sym_if] = ACTIONS(5832),
    [anon_sym_else] = ACTIONS(5832),
    [anon_sym_LBRACK] = ACTIONS(5834),
    [anon_sym_localparam] = ACTIONS(5832),
    [anon_sym_parameter] = ACTIONS(5832),
    [anon_sym_var] = ACTIONS(5832),
    [anon_sym_import] = ACTIONS(5832),
    [anon_sym_export] = ACTIONS(5832),
    [anon_sym_genvar] = ACTIONS(5832),
    [anon_sym_interconnect] = ACTIONS(5832),
    [anon_sym_typedef] = ACTIONS(5832),
    [anon_sym_enum] = ACTIONS(5832),
    [anon_sym_struct] = ACTIONS(5832),
    [anon_sym_union] = ACTIONS(5832),
    [anon_sym_nettype] = ACTIONS(5832),
    [anon_sym_automatic] = ACTIONS(5832),
    [anon_sym_string] = ACTIONS(5832),
    [anon_sym_chandle] = ACTIONS(5832),
    [anon_sym_event] = ACTIONS(5832),
    [anon_sym_byte] = ACTIONS(5832),
    [anon_sym_shortint] = ACTIONS(5832),
    [anon_sym_int] = ACTIONS(5832),
    [anon_sym_longint] = ACTIONS(5832),
    [anon_sym_integer] = ACTIONS(5832),
    [anon_sym_time] = ACTIONS(5832),
    [anon_sym_bit] = ACTIONS(5832),
    [anon_sym_logic] = ACTIONS(5832),
    [anon_sym_reg] = ACTIONS(5832),
    [anon_sym_shortreal] = ACTIONS(5832),
    [anon_sym_real] = ACTIONS(5832),
    [anon_sym_realtime] = ACTIONS(5832),
    [anon_sym_supply0] = ACTIONS(5832),
    [anon_sym_supply1] = ACTIONS(5832),
    [anon_sym_signed] = ACTIONS(5832),
    [anon_sym_unsigned] = ACTIONS(5832),
    [anon_sym_task] = ACTIONS(5832),
    [anon_sym_assert] = ACTIONS(5832),
    [anon_sym_property] = ACTIONS(5832),
    [anon_sym_assume] = ACTIONS(5832),
    [anon_sym_cover] = ACTIONS(5832),
    [anon_sym_sequence] = ACTIONS(5832),
    [anon_sym_restrict] = ACTIONS(5832),
    [anon_sym_not] = ACTIONS(5832),
    [anon_sym_or] = ACTIONS(5832),
    [anon_sym_and] = ACTIONS(5832),
    [anon_sym_case] = ACTIONS(5832),
    [anon_sym_always] = ACTIONS(5832),
    [anon_sym_covergroup] = ACTIONS(5832),
    [anon_sym_end] = ACTIONS(5832),
    [anon_sym_let] = ACTIONS(5832),
    [anon_sym_pulldown] = ACTIONS(5832),
    [anon_sym_pullup] = ACTIONS(5832),
    [anon_sym_cmos] = ACTIONS(5832),
    [anon_sym_rcmos] = ACTIONS(5832),
    [anon_sym_bufif0] = ACTIONS(5832),
    [anon_sym_bufif1] = ACTIONS(5832),
    [anon_sym_notif0] = ACTIONS(5832),
    [anon_sym_notif1] = ACTIONS(5832),
    [anon_sym_nmos] = ACTIONS(5832),
    [anon_sym_pmos] = ACTIONS(5832),
    [anon_sym_rnmos] = ACTIONS(5832),
    [anon_sym_rpmos] = ACTIONS(5832),
    [anon_sym_nand] = ACTIONS(5832),
    [anon_sym_nor] = ACTIONS(5832),
    [anon_sym_xor] = ACTIONS(5832),
    [anon_sym_xnor] = ACTIONS(5832),
    [anon_sym_buf] = ACTIONS(5832),
    [anon_sym_tranif0] = ACTIONS(5832),
    [anon_sym_tranif1] = ACTIONS(5832),
    [anon_sym_rtranif1] = ACTIONS(5832),
    [anon_sym_rtranif0] = ACTIONS(5832),
    [anon_sym_tran] = ACTIONS(5832),
    [anon_sym_rtran] = ACTIONS(5832),
    [anon_sym_generate] = ACTIONS(5832),
    [anon_sym_for] = ACTIONS(5832),
    [anon_sym_initial] = ACTIONS(5832),
    [anon_sym_assign] = ACTIONS(5832),
    [anon_sym_alias] = ACTIONS(5832),
    [anon_sym_always_comb] = ACTIONS(5832),
    [anon_sym_always_latch] = ACTIONS(5832),
    [anon_sym_always_ff] = ACTIONS(5832),
    [anon_sym_final] = ACTIONS(5832),
    [anon_sym_global] = ACTIONS(5832),
    [anon_sym_LPAREN_STAR] = ACTIONS(5834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5834),
    [anon_sym_DOLLARunit] = ACTIONS(5834),
  },
  [4668] = {
    [sym_simple_identifier] = ACTIONS(4860),
    [anon_sym_wire] = ACTIONS(4860),
    [anon_sym_tri] = ACTIONS(4860),
    [anon_sym_tri0] = ACTIONS(4860),
    [anon_sym_tri1] = ACTIONS(4860),
    [anon_sym_wand] = ACTIONS(4860),
    [anon_sym_triand] = ACTIONS(4860),
    [anon_sym_wor] = ACTIONS(4860),
    [anon_sym_trior] = ACTIONS(4860),
    [anon_sym_trireg] = ACTIONS(4860),
    [anon_sym_uwire] = ACTIONS(4860),
    [anon_sym_SEMI] = ACTIONS(4858),
    [anon_sym_extern] = ACTIONS(4860),
    [anon_sym_interface] = ACTIONS(4860),
    [anon_sym_checker] = ACTIONS(4860),
    [anon_sym_virtual] = ACTIONS(4860),
    [anon_sym_class] = ACTIONS(4860),
    [anon_sym_type] = ACTIONS(4860),
    [anon_sym_DOLLARfatal] = ACTIONS(4858),
    [anon_sym_DOLLARerror] = ACTIONS(4858),
    [anon_sym_DOLLARwarning] = ACTIONS(4858),
    [anon_sym_DOLLARinfo] = ACTIONS(4858),
    [anon_sym_default] = ACTIONS(4860),
    [anon_sym_clocking] = ACTIONS(4860),
    [anon_sym_defparam] = ACTIONS(4860),
    [anon_sym_bind] = ACTIONS(4860),
    [anon_sym_rand] = ACTIONS(4860),
    [anon_sym_const] = ACTIONS(4860),
    [anon_sym_function] = ACTIONS(4860),
    [anon_sym_static] = ACTIONS(4860),
    [anon_sym_constraint] = ACTIONS(4860),
    [anon_sym_if] = ACTIONS(4860),
    [anon_sym_else] = ACTIONS(4860),
    [anon_sym_LBRACK] = ACTIONS(4858),
    [anon_sym_localparam] = ACTIONS(4860),
    [anon_sym_parameter] = ACTIONS(4860),
    [anon_sym_var] = ACTIONS(4860),
    [anon_sym_import] = ACTIONS(4860),
    [anon_sym_export] = ACTIONS(4860),
    [anon_sym_genvar] = ACTIONS(4860),
    [anon_sym_interconnect] = ACTIONS(4860),
    [anon_sym_typedef] = ACTIONS(4860),
    [anon_sym_enum] = ACTIONS(4860),
    [anon_sym_struct] = ACTIONS(4860),
    [anon_sym_union] = ACTIONS(4860),
    [anon_sym_nettype] = ACTIONS(4860),
    [anon_sym_automatic] = ACTIONS(4860),
    [anon_sym_string] = ACTIONS(4860),
    [anon_sym_chandle] = ACTIONS(4860),
    [anon_sym_event] = ACTIONS(4860),
    [anon_sym_byte] = ACTIONS(4860),
    [anon_sym_shortint] = ACTIONS(4860),
    [anon_sym_int] = ACTIONS(4860),
    [anon_sym_longint] = ACTIONS(4860),
    [anon_sym_integer] = ACTIONS(4860),
    [anon_sym_time] = ACTIONS(4860),
    [anon_sym_bit] = ACTIONS(4860),
    [anon_sym_logic] = ACTIONS(4860),
    [anon_sym_reg] = ACTIONS(4860),
    [anon_sym_shortreal] = ACTIONS(4860),
    [anon_sym_real] = ACTIONS(4860),
    [anon_sym_realtime] = ACTIONS(4860),
    [anon_sym_supply0] = ACTIONS(4860),
    [anon_sym_supply1] = ACTIONS(4860),
    [anon_sym_signed] = ACTIONS(4860),
    [anon_sym_unsigned] = ACTIONS(4860),
    [anon_sym_task] = ACTIONS(4860),
    [anon_sym_assert] = ACTIONS(4860),
    [anon_sym_property] = ACTIONS(4860),
    [anon_sym_assume] = ACTIONS(4860),
    [anon_sym_cover] = ACTIONS(4860),
    [anon_sym_sequence] = ACTIONS(4860),
    [anon_sym_restrict] = ACTIONS(4860),
    [anon_sym_not] = ACTIONS(4860),
    [anon_sym_or] = ACTIONS(4860),
    [anon_sym_and] = ACTIONS(4860),
    [anon_sym_case] = ACTIONS(4860),
    [anon_sym_always] = ACTIONS(4860),
    [anon_sym_covergroup] = ACTIONS(4860),
    [anon_sym_end] = ACTIONS(4860),
    [anon_sym_let] = ACTIONS(4860),
    [anon_sym_pulldown] = ACTIONS(4860),
    [anon_sym_pullup] = ACTIONS(4860),
    [anon_sym_cmos] = ACTIONS(4860),
    [anon_sym_rcmos] = ACTIONS(4860),
    [anon_sym_bufif0] = ACTIONS(4860),
    [anon_sym_bufif1] = ACTIONS(4860),
    [anon_sym_notif0] = ACTIONS(4860),
    [anon_sym_notif1] = ACTIONS(4860),
    [anon_sym_nmos] = ACTIONS(4860),
    [anon_sym_pmos] = ACTIONS(4860),
    [anon_sym_rnmos] = ACTIONS(4860),
    [anon_sym_rpmos] = ACTIONS(4860),
    [anon_sym_nand] = ACTIONS(4860),
    [anon_sym_nor] = ACTIONS(4860),
    [anon_sym_xor] = ACTIONS(4860),
    [anon_sym_xnor] = ACTIONS(4860),
    [anon_sym_buf] = ACTIONS(4860),
    [anon_sym_tranif0] = ACTIONS(4860),
    [anon_sym_tranif1] = ACTIONS(4860),
    [anon_sym_rtranif1] = ACTIONS(4860),
    [anon_sym_rtranif0] = ACTIONS(4860),
    [anon_sym_tran] = ACTIONS(4860),
    [anon_sym_rtran] = ACTIONS(4860),
    [anon_sym_generate] = ACTIONS(4860),
    [anon_sym_for] = ACTIONS(4860),
    [anon_sym_initial] = ACTIONS(4860),
    [anon_sym_assign] = ACTIONS(4860),
    [anon_sym_alias] = ACTIONS(4860),
    [anon_sym_always_comb] = ACTIONS(4860),
    [anon_sym_always_latch] = ACTIONS(4860),
    [anon_sym_always_ff] = ACTIONS(4860),
    [anon_sym_final] = ACTIONS(4860),
    [anon_sym_global] = ACTIONS(4860),
    [anon_sym_LPAREN_STAR] = ACTIONS(4858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4858),
    [anon_sym_DOLLARunit] = ACTIONS(4858),
  },
  [4669] = {
    [sym_simple_identifier] = ACTIONS(6695),
    [anon_sym_wire] = ACTIONS(6695),
    [anon_sym_tri] = ACTIONS(6695),
    [anon_sym_tri0] = ACTIONS(6695),
    [anon_sym_tri1] = ACTIONS(6695),
    [anon_sym_wand] = ACTIONS(6695),
    [anon_sym_triand] = ACTIONS(6695),
    [anon_sym_wor] = ACTIONS(6695),
    [anon_sym_trior] = ACTIONS(6695),
    [anon_sym_trireg] = ACTIONS(6695),
    [anon_sym_uwire] = ACTIONS(6695),
    [anon_sym_SEMI] = ACTIONS(6697),
    [anon_sym_extern] = ACTIONS(6695),
    [anon_sym_interface] = ACTIONS(6695),
    [anon_sym_checker] = ACTIONS(6695),
    [anon_sym_virtual] = ACTIONS(6695),
    [anon_sym_class] = ACTIONS(6695),
    [anon_sym_type] = ACTIONS(6695),
    [anon_sym_DOLLARfatal] = ACTIONS(6697),
    [anon_sym_DOLLARerror] = ACTIONS(6697),
    [anon_sym_DOLLARwarning] = ACTIONS(6697),
    [anon_sym_DOLLARinfo] = ACTIONS(6697),
    [anon_sym_default] = ACTIONS(6695),
    [anon_sym_clocking] = ACTIONS(6695),
    [anon_sym_defparam] = ACTIONS(6695),
    [anon_sym_bind] = ACTIONS(6695),
    [anon_sym_rand] = ACTIONS(6695),
    [anon_sym_const] = ACTIONS(6695),
    [anon_sym_function] = ACTIONS(6695),
    [anon_sym_static] = ACTIONS(6695),
    [anon_sym_constraint] = ACTIONS(6695),
    [anon_sym_if] = ACTIONS(6695),
    [anon_sym_else] = ACTIONS(6695),
    [anon_sym_LBRACK] = ACTIONS(6697),
    [anon_sym_localparam] = ACTIONS(6695),
    [anon_sym_parameter] = ACTIONS(6695),
    [anon_sym_var] = ACTIONS(6695),
    [anon_sym_import] = ACTIONS(6695),
    [anon_sym_export] = ACTIONS(6695),
    [anon_sym_genvar] = ACTIONS(6695),
    [anon_sym_interconnect] = ACTIONS(6695),
    [anon_sym_typedef] = ACTIONS(6695),
    [anon_sym_enum] = ACTIONS(6695),
    [anon_sym_struct] = ACTIONS(6695),
    [anon_sym_union] = ACTIONS(6695),
    [anon_sym_nettype] = ACTIONS(6695),
    [anon_sym_automatic] = ACTIONS(6695),
    [anon_sym_string] = ACTIONS(6695),
    [anon_sym_chandle] = ACTIONS(6695),
    [anon_sym_event] = ACTIONS(6695),
    [anon_sym_byte] = ACTIONS(6695),
    [anon_sym_shortint] = ACTIONS(6695),
    [anon_sym_int] = ACTIONS(6695),
    [anon_sym_longint] = ACTIONS(6695),
    [anon_sym_integer] = ACTIONS(6695),
    [anon_sym_time] = ACTIONS(6695),
    [anon_sym_bit] = ACTIONS(6695),
    [anon_sym_logic] = ACTIONS(6695),
    [anon_sym_reg] = ACTIONS(6695),
    [anon_sym_shortreal] = ACTIONS(6695),
    [anon_sym_real] = ACTIONS(6695),
    [anon_sym_realtime] = ACTIONS(6695),
    [anon_sym_supply0] = ACTIONS(6695),
    [anon_sym_supply1] = ACTIONS(6695),
    [anon_sym_signed] = ACTIONS(6695),
    [anon_sym_unsigned] = ACTIONS(6695),
    [anon_sym_task] = ACTIONS(6695),
    [anon_sym_assert] = ACTIONS(6695),
    [anon_sym_property] = ACTIONS(6695),
    [anon_sym_assume] = ACTIONS(6695),
    [anon_sym_cover] = ACTIONS(6695),
    [anon_sym_sequence] = ACTIONS(6695),
    [anon_sym_restrict] = ACTIONS(6695),
    [anon_sym_not] = ACTIONS(6695),
    [anon_sym_or] = ACTIONS(6695),
    [anon_sym_and] = ACTIONS(6695),
    [anon_sym_case] = ACTIONS(6695),
    [anon_sym_always] = ACTIONS(6695),
    [anon_sym_covergroup] = ACTIONS(6695),
    [anon_sym_let] = ACTIONS(6695),
    [anon_sym_pulldown] = ACTIONS(6695),
    [anon_sym_pullup] = ACTIONS(6695),
    [anon_sym_cmos] = ACTIONS(6695),
    [anon_sym_rcmos] = ACTIONS(6695),
    [anon_sym_bufif0] = ACTIONS(6695),
    [anon_sym_bufif1] = ACTIONS(6695),
    [anon_sym_notif0] = ACTIONS(6695),
    [anon_sym_notif1] = ACTIONS(6695),
    [anon_sym_nmos] = ACTIONS(6695),
    [anon_sym_pmos] = ACTIONS(6695),
    [anon_sym_rnmos] = ACTIONS(6695),
    [anon_sym_rpmos] = ACTIONS(6695),
    [anon_sym_nand] = ACTIONS(6695),
    [anon_sym_nor] = ACTIONS(6695),
    [anon_sym_xor] = ACTIONS(6695),
    [anon_sym_xnor] = ACTIONS(6695),
    [anon_sym_buf] = ACTIONS(6695),
    [anon_sym_tranif0] = ACTIONS(6695),
    [anon_sym_tranif1] = ACTIONS(6695),
    [anon_sym_rtranif1] = ACTIONS(6695),
    [anon_sym_rtranif0] = ACTIONS(6695),
    [anon_sym_tran] = ACTIONS(6695),
    [anon_sym_rtran] = ACTIONS(6695),
    [anon_sym_generate] = ACTIONS(6695),
    [anon_sym_endgenerate] = ACTIONS(6695),
    [anon_sym_for] = ACTIONS(6695),
    [anon_sym_initial] = ACTIONS(6695),
    [anon_sym_assign] = ACTIONS(6695),
    [anon_sym_alias] = ACTIONS(6695),
    [anon_sym_always_comb] = ACTIONS(6695),
    [anon_sym_always_latch] = ACTIONS(6695),
    [anon_sym_always_ff] = ACTIONS(6695),
    [anon_sym_final] = ACTIONS(6695),
    [anon_sym_global] = ACTIONS(6695),
    [anon_sym_LPAREN_STAR] = ACTIONS(6697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6697),
    [anon_sym_DOLLARunit] = ACTIONS(6697),
  },
  [4670] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_rand] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(10887),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_endgenerate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [4671] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(10891),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4672] = {
    [sym_simple_identifier] = ACTIONS(5866),
    [anon_sym_wire] = ACTIONS(5866),
    [anon_sym_tri] = ACTIONS(5866),
    [anon_sym_tri0] = ACTIONS(5866),
    [anon_sym_tri1] = ACTIONS(5866),
    [anon_sym_wand] = ACTIONS(5866),
    [anon_sym_triand] = ACTIONS(5866),
    [anon_sym_wor] = ACTIONS(5866),
    [anon_sym_trior] = ACTIONS(5866),
    [anon_sym_trireg] = ACTIONS(5866),
    [anon_sym_uwire] = ACTIONS(5866),
    [anon_sym_SEMI] = ACTIONS(5868),
    [anon_sym_extern] = ACTIONS(5866),
    [anon_sym_interface] = ACTIONS(5866),
    [anon_sym_checker] = ACTIONS(5866),
    [anon_sym_virtual] = ACTIONS(5866),
    [anon_sym_class] = ACTIONS(5866),
    [anon_sym_type] = ACTIONS(5866),
    [anon_sym_DOLLARfatal] = ACTIONS(5868),
    [anon_sym_DOLLARerror] = ACTIONS(5868),
    [anon_sym_DOLLARwarning] = ACTIONS(5868),
    [anon_sym_DOLLARinfo] = ACTIONS(5868),
    [anon_sym_default] = ACTIONS(5866),
    [anon_sym_clocking] = ACTIONS(5866),
    [anon_sym_defparam] = ACTIONS(5866),
    [anon_sym_bind] = ACTIONS(5866),
    [anon_sym_rand] = ACTIONS(5866),
    [anon_sym_const] = ACTIONS(5866),
    [anon_sym_function] = ACTIONS(5866),
    [anon_sym_static] = ACTIONS(5866),
    [anon_sym_constraint] = ACTIONS(5866),
    [anon_sym_if] = ACTIONS(5866),
    [anon_sym_else] = ACTIONS(5866),
    [anon_sym_LBRACK] = ACTIONS(5868),
    [anon_sym_localparam] = ACTIONS(5866),
    [anon_sym_parameter] = ACTIONS(5866),
    [anon_sym_var] = ACTIONS(5866),
    [anon_sym_import] = ACTIONS(5866),
    [anon_sym_export] = ACTIONS(5866),
    [anon_sym_genvar] = ACTIONS(5866),
    [anon_sym_interconnect] = ACTIONS(5866),
    [anon_sym_typedef] = ACTIONS(5866),
    [anon_sym_enum] = ACTIONS(5866),
    [anon_sym_struct] = ACTIONS(5866),
    [anon_sym_union] = ACTIONS(5866),
    [anon_sym_nettype] = ACTIONS(5866),
    [anon_sym_automatic] = ACTIONS(5866),
    [anon_sym_string] = ACTIONS(5866),
    [anon_sym_chandle] = ACTIONS(5866),
    [anon_sym_event] = ACTIONS(5866),
    [anon_sym_byte] = ACTIONS(5866),
    [anon_sym_shortint] = ACTIONS(5866),
    [anon_sym_int] = ACTIONS(5866),
    [anon_sym_longint] = ACTIONS(5866),
    [anon_sym_integer] = ACTIONS(5866),
    [anon_sym_time] = ACTIONS(5866),
    [anon_sym_bit] = ACTIONS(5866),
    [anon_sym_logic] = ACTIONS(5866),
    [anon_sym_reg] = ACTIONS(5866),
    [anon_sym_shortreal] = ACTIONS(5866),
    [anon_sym_real] = ACTIONS(5866),
    [anon_sym_realtime] = ACTIONS(5866),
    [anon_sym_supply0] = ACTIONS(5866),
    [anon_sym_supply1] = ACTIONS(5866),
    [anon_sym_signed] = ACTIONS(5866),
    [anon_sym_unsigned] = ACTIONS(5866),
    [anon_sym_task] = ACTIONS(5866),
    [anon_sym_assert] = ACTIONS(5866),
    [anon_sym_property] = ACTIONS(5866),
    [anon_sym_assume] = ACTIONS(5866),
    [anon_sym_cover] = ACTIONS(5866),
    [anon_sym_sequence] = ACTIONS(5866),
    [anon_sym_restrict] = ACTIONS(5866),
    [anon_sym_not] = ACTIONS(5866),
    [anon_sym_or] = ACTIONS(5866),
    [anon_sym_and] = ACTIONS(5866),
    [anon_sym_case] = ACTIONS(5866),
    [anon_sym_always] = ACTIONS(5866),
    [anon_sym_covergroup] = ACTIONS(5866),
    [anon_sym_let] = ACTIONS(5866),
    [anon_sym_pulldown] = ACTIONS(5866),
    [anon_sym_pullup] = ACTIONS(5866),
    [anon_sym_cmos] = ACTIONS(5866),
    [anon_sym_rcmos] = ACTIONS(5866),
    [anon_sym_bufif0] = ACTIONS(5866),
    [anon_sym_bufif1] = ACTIONS(5866),
    [anon_sym_notif0] = ACTIONS(5866),
    [anon_sym_notif1] = ACTIONS(5866),
    [anon_sym_nmos] = ACTIONS(5866),
    [anon_sym_pmos] = ACTIONS(5866),
    [anon_sym_rnmos] = ACTIONS(5866),
    [anon_sym_rpmos] = ACTIONS(5866),
    [anon_sym_nand] = ACTIONS(5866),
    [anon_sym_nor] = ACTIONS(5866),
    [anon_sym_xor] = ACTIONS(5866),
    [anon_sym_xnor] = ACTIONS(5866),
    [anon_sym_buf] = ACTIONS(5866),
    [anon_sym_tranif0] = ACTIONS(5866),
    [anon_sym_tranif1] = ACTIONS(5866),
    [anon_sym_rtranif1] = ACTIONS(5866),
    [anon_sym_rtranif0] = ACTIONS(5866),
    [anon_sym_tran] = ACTIONS(5866),
    [anon_sym_rtran] = ACTIONS(5866),
    [anon_sym_generate] = ACTIONS(5866),
    [anon_sym_endgenerate] = ACTIONS(5866),
    [anon_sym_for] = ACTIONS(5866),
    [anon_sym_initial] = ACTIONS(5866),
    [anon_sym_assign] = ACTIONS(5866),
    [anon_sym_alias] = ACTIONS(5866),
    [anon_sym_always_comb] = ACTIONS(5866),
    [anon_sym_always_latch] = ACTIONS(5866),
    [anon_sym_always_ff] = ACTIONS(5866),
    [anon_sym_final] = ACTIONS(5866),
    [anon_sym_global] = ACTIONS(5866),
    [anon_sym_LPAREN_STAR] = ACTIONS(5868),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5868),
    [anon_sym_DOLLARunit] = ACTIONS(5868),
  },
  [4673] = {
    [sym_simple_identifier] = ACTIONS(4642),
    [anon_sym_wire] = ACTIONS(4642),
    [anon_sym_tri] = ACTIONS(4642),
    [anon_sym_tri0] = ACTIONS(4642),
    [anon_sym_tri1] = ACTIONS(4642),
    [anon_sym_wand] = ACTIONS(4642),
    [anon_sym_triand] = ACTIONS(4642),
    [anon_sym_wor] = ACTIONS(4642),
    [anon_sym_trior] = ACTIONS(4642),
    [anon_sym_trireg] = ACTIONS(4642),
    [anon_sym_uwire] = ACTIONS(4642),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_extern] = ACTIONS(4642),
    [anon_sym_interface] = ACTIONS(4642),
    [anon_sym_checker] = ACTIONS(4642),
    [anon_sym_virtual] = ACTIONS(4642),
    [anon_sym_class] = ACTIONS(4642),
    [anon_sym_type] = ACTIONS(4642),
    [anon_sym_DOLLARfatal] = ACTIONS(4640),
    [anon_sym_DOLLARerror] = ACTIONS(4640),
    [anon_sym_DOLLARwarning] = ACTIONS(4640),
    [anon_sym_DOLLARinfo] = ACTIONS(4640),
    [anon_sym_default] = ACTIONS(4642),
    [anon_sym_clocking] = ACTIONS(4642),
    [anon_sym_defparam] = ACTIONS(4642),
    [anon_sym_bind] = ACTIONS(4642),
    [anon_sym_rand] = ACTIONS(4642),
    [anon_sym_const] = ACTIONS(4642),
    [anon_sym_function] = ACTIONS(4642),
    [anon_sym_static] = ACTIONS(4642),
    [anon_sym_constraint] = ACTIONS(4642),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_localparam] = ACTIONS(4642),
    [anon_sym_parameter] = ACTIONS(4642),
    [anon_sym_var] = ACTIONS(4642),
    [anon_sym_import] = ACTIONS(4642),
    [anon_sym_export] = ACTIONS(4642),
    [anon_sym_genvar] = ACTIONS(4642),
    [anon_sym_interconnect] = ACTIONS(4642),
    [anon_sym_typedef] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_struct] = ACTIONS(4642),
    [anon_sym_union] = ACTIONS(4642),
    [anon_sym_nettype] = ACTIONS(4642),
    [anon_sym_automatic] = ACTIONS(4642),
    [anon_sym_string] = ACTIONS(4642),
    [anon_sym_chandle] = ACTIONS(4642),
    [anon_sym_event] = ACTIONS(4642),
    [anon_sym_byte] = ACTIONS(4642),
    [anon_sym_shortint] = ACTIONS(4642),
    [anon_sym_int] = ACTIONS(4642),
    [anon_sym_longint] = ACTIONS(4642),
    [anon_sym_integer] = ACTIONS(4642),
    [anon_sym_time] = ACTIONS(4642),
    [anon_sym_bit] = ACTIONS(4642),
    [anon_sym_logic] = ACTIONS(4642),
    [anon_sym_reg] = ACTIONS(4642),
    [anon_sym_shortreal] = ACTIONS(4642),
    [anon_sym_real] = ACTIONS(4642),
    [anon_sym_realtime] = ACTIONS(4642),
    [anon_sym_supply0] = ACTIONS(4642),
    [anon_sym_supply1] = ACTIONS(4642),
    [anon_sym_signed] = ACTIONS(4642),
    [anon_sym_unsigned] = ACTIONS(4642),
    [anon_sym_task] = ACTIONS(4642),
    [anon_sym_assert] = ACTIONS(4642),
    [anon_sym_property] = ACTIONS(4642),
    [anon_sym_assume] = ACTIONS(4642),
    [anon_sym_cover] = ACTIONS(4642),
    [anon_sym_sequence] = ACTIONS(4642),
    [anon_sym_restrict] = ACTIONS(4642),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_and] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_always] = ACTIONS(4642),
    [anon_sym_covergroup] = ACTIONS(4642),
    [anon_sym_let] = ACTIONS(4642),
    [anon_sym_pulldown] = ACTIONS(4642),
    [anon_sym_pullup] = ACTIONS(4642),
    [anon_sym_cmos] = ACTIONS(4642),
    [anon_sym_rcmos] = ACTIONS(4642),
    [anon_sym_bufif0] = ACTIONS(4642),
    [anon_sym_bufif1] = ACTIONS(4642),
    [anon_sym_notif0] = ACTIONS(4642),
    [anon_sym_notif1] = ACTIONS(4642),
    [anon_sym_nmos] = ACTIONS(4642),
    [anon_sym_pmos] = ACTIONS(4642),
    [anon_sym_rnmos] = ACTIONS(4642),
    [anon_sym_rpmos] = ACTIONS(4642),
    [anon_sym_nand] = ACTIONS(4642),
    [anon_sym_nor] = ACTIONS(4642),
    [anon_sym_xor] = ACTIONS(4642),
    [anon_sym_xnor] = ACTIONS(4642),
    [anon_sym_buf] = ACTIONS(4642),
    [anon_sym_tranif0] = ACTIONS(4642),
    [anon_sym_tranif1] = ACTIONS(4642),
    [anon_sym_rtranif1] = ACTIONS(4642),
    [anon_sym_rtranif0] = ACTIONS(4642),
    [anon_sym_tran] = ACTIONS(4642),
    [anon_sym_rtran] = ACTIONS(4642),
    [anon_sym_generate] = ACTIONS(4642),
    [anon_sym_endgenerate] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_initial] = ACTIONS(4642),
    [anon_sym_assign] = ACTIONS(4642),
    [anon_sym_alias] = ACTIONS(4642),
    [anon_sym_always_comb] = ACTIONS(4642),
    [anon_sym_always_latch] = ACTIONS(4642),
    [anon_sym_always_ff] = ACTIONS(4642),
    [anon_sym_final] = ACTIONS(4642),
    [anon_sym_global] = ACTIONS(4642),
    [anon_sym_LPAREN_STAR] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4640),
    [anon_sym_DOLLARunit] = ACTIONS(4640),
  },
  [4674] = {
    [sym_simple_identifier] = ACTIONS(4630),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_rand] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_end] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [4675] = {
    [sym_simple_identifier] = ACTIONS(4674),
    [anon_sym_wire] = ACTIONS(4674),
    [anon_sym_tri] = ACTIONS(4674),
    [anon_sym_tri0] = ACTIONS(4674),
    [anon_sym_tri1] = ACTIONS(4674),
    [anon_sym_wand] = ACTIONS(4674),
    [anon_sym_triand] = ACTIONS(4674),
    [anon_sym_wor] = ACTIONS(4674),
    [anon_sym_trior] = ACTIONS(4674),
    [anon_sym_trireg] = ACTIONS(4674),
    [anon_sym_uwire] = ACTIONS(4674),
    [anon_sym_SEMI] = ACTIONS(4672),
    [anon_sym_extern] = ACTIONS(4674),
    [anon_sym_interface] = ACTIONS(4674),
    [anon_sym_checker] = ACTIONS(4674),
    [anon_sym_virtual] = ACTIONS(4674),
    [anon_sym_class] = ACTIONS(4674),
    [anon_sym_type] = ACTIONS(4674),
    [anon_sym_DOLLARfatal] = ACTIONS(4672),
    [anon_sym_DOLLARerror] = ACTIONS(4672),
    [anon_sym_DOLLARwarning] = ACTIONS(4672),
    [anon_sym_DOLLARinfo] = ACTIONS(4672),
    [anon_sym_default] = ACTIONS(4674),
    [anon_sym_clocking] = ACTIONS(4674),
    [anon_sym_defparam] = ACTIONS(4674),
    [anon_sym_bind] = ACTIONS(4674),
    [anon_sym_rand] = ACTIONS(4674),
    [anon_sym_const] = ACTIONS(4674),
    [anon_sym_function] = ACTIONS(4674),
    [anon_sym_static] = ACTIONS(4674),
    [anon_sym_constraint] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4674),
    [anon_sym_else] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4672),
    [anon_sym_localparam] = ACTIONS(4674),
    [anon_sym_parameter] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_import] = ACTIONS(4674),
    [anon_sym_export] = ACTIONS(4674),
    [anon_sym_genvar] = ACTIONS(4674),
    [anon_sym_interconnect] = ACTIONS(4674),
    [anon_sym_typedef] = ACTIONS(4674),
    [anon_sym_enum] = ACTIONS(4674),
    [anon_sym_struct] = ACTIONS(4674),
    [anon_sym_union] = ACTIONS(4674),
    [anon_sym_nettype] = ACTIONS(4674),
    [anon_sym_automatic] = ACTIONS(4674),
    [anon_sym_string] = ACTIONS(4674),
    [anon_sym_chandle] = ACTIONS(4674),
    [anon_sym_event] = ACTIONS(4674),
    [anon_sym_byte] = ACTIONS(4674),
    [anon_sym_shortint] = ACTIONS(4674),
    [anon_sym_int] = ACTIONS(4674),
    [anon_sym_longint] = ACTIONS(4674),
    [anon_sym_integer] = ACTIONS(4674),
    [anon_sym_time] = ACTIONS(4674),
    [anon_sym_bit] = ACTIONS(4674),
    [anon_sym_logic] = ACTIONS(4674),
    [anon_sym_reg] = ACTIONS(4674),
    [anon_sym_shortreal] = ACTIONS(4674),
    [anon_sym_real] = ACTIONS(4674),
    [anon_sym_realtime] = ACTIONS(4674),
    [anon_sym_supply0] = ACTIONS(4674),
    [anon_sym_supply1] = ACTIONS(4674),
    [anon_sym_signed] = ACTIONS(4674),
    [anon_sym_unsigned] = ACTIONS(4674),
    [anon_sym_task] = ACTIONS(4674),
    [anon_sym_assert] = ACTIONS(4674),
    [anon_sym_property] = ACTIONS(4674),
    [anon_sym_assume] = ACTIONS(4674),
    [anon_sym_cover] = ACTIONS(4674),
    [anon_sym_sequence] = ACTIONS(4674),
    [anon_sym_restrict] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_case] = ACTIONS(4674),
    [anon_sym_always] = ACTIONS(4674),
    [anon_sym_covergroup] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_pulldown] = ACTIONS(4674),
    [anon_sym_pullup] = ACTIONS(4674),
    [anon_sym_cmos] = ACTIONS(4674),
    [anon_sym_rcmos] = ACTIONS(4674),
    [anon_sym_bufif0] = ACTIONS(4674),
    [anon_sym_bufif1] = ACTIONS(4674),
    [anon_sym_notif0] = ACTIONS(4674),
    [anon_sym_notif1] = ACTIONS(4674),
    [anon_sym_nmos] = ACTIONS(4674),
    [anon_sym_pmos] = ACTIONS(4674),
    [anon_sym_rnmos] = ACTIONS(4674),
    [anon_sym_rpmos] = ACTIONS(4674),
    [anon_sym_nand] = ACTIONS(4674),
    [anon_sym_nor] = ACTIONS(4674),
    [anon_sym_xor] = ACTIONS(4674),
    [anon_sym_xnor] = ACTIONS(4674),
    [anon_sym_buf] = ACTIONS(4674),
    [anon_sym_tranif0] = ACTIONS(4674),
    [anon_sym_tranif1] = ACTIONS(4674),
    [anon_sym_rtranif1] = ACTIONS(4674),
    [anon_sym_rtranif0] = ACTIONS(4674),
    [anon_sym_tran] = ACTIONS(4674),
    [anon_sym_rtran] = ACTIONS(4674),
    [anon_sym_generate] = ACTIONS(4674),
    [anon_sym_endgenerate] = ACTIONS(4674),
    [anon_sym_for] = ACTIONS(4674),
    [anon_sym_initial] = ACTIONS(4674),
    [anon_sym_assign] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_always_comb] = ACTIONS(4674),
    [anon_sym_always_latch] = ACTIONS(4674),
    [anon_sym_always_ff] = ACTIONS(4674),
    [anon_sym_final] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LPAREN_STAR] = ACTIONS(4672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4672),
    [anon_sym_DOLLARunit] = ACTIONS(4672),
  },
  [4676] = {
    [sym_simple_identifier] = ACTIONS(5836),
    [anon_sym_wire] = ACTIONS(5836),
    [anon_sym_tri] = ACTIONS(5836),
    [anon_sym_tri0] = ACTIONS(5836),
    [anon_sym_tri1] = ACTIONS(5836),
    [anon_sym_wand] = ACTIONS(5836),
    [anon_sym_triand] = ACTIONS(5836),
    [anon_sym_wor] = ACTIONS(5836),
    [anon_sym_trior] = ACTIONS(5836),
    [anon_sym_trireg] = ACTIONS(5836),
    [anon_sym_uwire] = ACTIONS(5836),
    [anon_sym_SEMI] = ACTIONS(5838),
    [anon_sym_extern] = ACTIONS(5836),
    [anon_sym_interface] = ACTIONS(5836),
    [anon_sym_checker] = ACTIONS(5836),
    [anon_sym_virtual] = ACTIONS(5836),
    [anon_sym_class] = ACTIONS(5836),
    [anon_sym_type] = ACTIONS(5836),
    [anon_sym_DOLLARfatal] = ACTIONS(5838),
    [anon_sym_DOLLARerror] = ACTIONS(5838),
    [anon_sym_DOLLARwarning] = ACTIONS(5838),
    [anon_sym_DOLLARinfo] = ACTIONS(5838),
    [anon_sym_default] = ACTIONS(5836),
    [anon_sym_clocking] = ACTIONS(5836),
    [anon_sym_defparam] = ACTIONS(5836),
    [anon_sym_bind] = ACTIONS(5836),
    [anon_sym_rand] = ACTIONS(5836),
    [anon_sym_const] = ACTIONS(5836),
    [anon_sym_function] = ACTIONS(5836),
    [anon_sym_static] = ACTIONS(5836),
    [anon_sym_constraint] = ACTIONS(5836),
    [anon_sym_if] = ACTIONS(5836),
    [anon_sym_else] = ACTIONS(5836),
    [anon_sym_LBRACK] = ACTIONS(5838),
    [anon_sym_localparam] = ACTIONS(5836),
    [anon_sym_parameter] = ACTIONS(5836),
    [anon_sym_var] = ACTIONS(5836),
    [anon_sym_import] = ACTIONS(5836),
    [anon_sym_export] = ACTIONS(5836),
    [anon_sym_genvar] = ACTIONS(5836),
    [anon_sym_interconnect] = ACTIONS(5836),
    [anon_sym_typedef] = ACTIONS(5836),
    [anon_sym_enum] = ACTIONS(5836),
    [anon_sym_struct] = ACTIONS(5836),
    [anon_sym_union] = ACTIONS(5836),
    [anon_sym_nettype] = ACTIONS(5836),
    [anon_sym_automatic] = ACTIONS(5836),
    [anon_sym_string] = ACTIONS(5836),
    [anon_sym_chandle] = ACTIONS(5836),
    [anon_sym_event] = ACTIONS(5836),
    [anon_sym_byte] = ACTIONS(5836),
    [anon_sym_shortint] = ACTIONS(5836),
    [anon_sym_int] = ACTIONS(5836),
    [anon_sym_longint] = ACTIONS(5836),
    [anon_sym_integer] = ACTIONS(5836),
    [anon_sym_time] = ACTIONS(5836),
    [anon_sym_bit] = ACTIONS(5836),
    [anon_sym_logic] = ACTIONS(5836),
    [anon_sym_reg] = ACTIONS(5836),
    [anon_sym_shortreal] = ACTIONS(5836),
    [anon_sym_real] = ACTIONS(5836),
    [anon_sym_realtime] = ACTIONS(5836),
    [anon_sym_supply0] = ACTIONS(5836),
    [anon_sym_supply1] = ACTIONS(5836),
    [anon_sym_signed] = ACTIONS(5836),
    [anon_sym_unsigned] = ACTIONS(5836),
    [anon_sym_task] = ACTIONS(5836),
    [anon_sym_assert] = ACTIONS(5836),
    [anon_sym_property] = ACTIONS(5836),
    [anon_sym_assume] = ACTIONS(5836),
    [anon_sym_cover] = ACTIONS(5836),
    [anon_sym_sequence] = ACTIONS(5836),
    [anon_sym_restrict] = ACTIONS(5836),
    [anon_sym_not] = ACTIONS(5836),
    [anon_sym_or] = ACTIONS(5836),
    [anon_sym_and] = ACTIONS(5836),
    [anon_sym_case] = ACTIONS(5836),
    [anon_sym_always] = ACTIONS(5836),
    [anon_sym_covergroup] = ACTIONS(5836),
    [anon_sym_end] = ACTIONS(5836),
    [anon_sym_let] = ACTIONS(5836),
    [anon_sym_pulldown] = ACTIONS(5836),
    [anon_sym_pullup] = ACTIONS(5836),
    [anon_sym_cmos] = ACTIONS(5836),
    [anon_sym_rcmos] = ACTIONS(5836),
    [anon_sym_bufif0] = ACTIONS(5836),
    [anon_sym_bufif1] = ACTIONS(5836),
    [anon_sym_notif0] = ACTIONS(5836),
    [anon_sym_notif1] = ACTIONS(5836),
    [anon_sym_nmos] = ACTIONS(5836),
    [anon_sym_pmos] = ACTIONS(5836),
    [anon_sym_rnmos] = ACTIONS(5836),
    [anon_sym_rpmos] = ACTIONS(5836),
    [anon_sym_nand] = ACTIONS(5836),
    [anon_sym_nor] = ACTIONS(5836),
    [anon_sym_xor] = ACTIONS(5836),
    [anon_sym_xnor] = ACTIONS(5836),
    [anon_sym_buf] = ACTIONS(5836),
    [anon_sym_tranif0] = ACTIONS(5836),
    [anon_sym_tranif1] = ACTIONS(5836),
    [anon_sym_rtranif1] = ACTIONS(5836),
    [anon_sym_rtranif0] = ACTIONS(5836),
    [anon_sym_tran] = ACTIONS(5836),
    [anon_sym_rtran] = ACTIONS(5836),
    [anon_sym_generate] = ACTIONS(5836),
    [anon_sym_for] = ACTIONS(5836),
    [anon_sym_initial] = ACTIONS(5836),
    [anon_sym_assign] = ACTIONS(5836),
    [anon_sym_alias] = ACTIONS(5836),
    [anon_sym_always_comb] = ACTIONS(5836),
    [anon_sym_always_latch] = ACTIONS(5836),
    [anon_sym_always_ff] = ACTIONS(5836),
    [anon_sym_final] = ACTIONS(5836),
    [anon_sym_global] = ACTIONS(5836),
    [anon_sym_LPAREN_STAR] = ACTIONS(5838),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5838),
    [anon_sym_DOLLARunit] = ACTIONS(5838),
  },
  [4677] = {
    [sym_simple_identifier] = ACTIONS(4800),
    [anon_sym_wire] = ACTIONS(4800),
    [anon_sym_tri] = ACTIONS(4800),
    [anon_sym_tri0] = ACTIONS(4800),
    [anon_sym_tri1] = ACTIONS(4800),
    [anon_sym_wand] = ACTIONS(4800),
    [anon_sym_triand] = ACTIONS(4800),
    [anon_sym_wor] = ACTIONS(4800),
    [anon_sym_trior] = ACTIONS(4800),
    [anon_sym_trireg] = ACTIONS(4800),
    [anon_sym_uwire] = ACTIONS(4800),
    [anon_sym_SEMI] = ACTIONS(4798),
    [anon_sym_extern] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4800),
    [anon_sym_checker] = ACTIONS(4800),
    [anon_sym_virtual] = ACTIONS(4800),
    [anon_sym_class] = ACTIONS(4800),
    [anon_sym_type] = ACTIONS(4800),
    [anon_sym_DOLLARfatal] = ACTIONS(4798),
    [anon_sym_DOLLARerror] = ACTIONS(4798),
    [anon_sym_DOLLARwarning] = ACTIONS(4798),
    [anon_sym_DOLLARinfo] = ACTIONS(4798),
    [anon_sym_default] = ACTIONS(4800),
    [anon_sym_clocking] = ACTIONS(4800),
    [anon_sym_defparam] = ACTIONS(4800),
    [anon_sym_bind] = ACTIONS(4800),
    [anon_sym_rand] = ACTIONS(4800),
    [anon_sym_const] = ACTIONS(4800),
    [anon_sym_function] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4800),
    [anon_sym_constraint] = ACTIONS(4800),
    [anon_sym_if] = ACTIONS(4800),
    [anon_sym_else] = ACTIONS(4800),
    [anon_sym_LBRACK] = ACTIONS(4798),
    [anon_sym_localparam] = ACTIONS(4800),
    [anon_sym_parameter] = ACTIONS(4800),
    [anon_sym_var] = ACTIONS(4800),
    [anon_sym_import] = ACTIONS(4800),
    [anon_sym_export] = ACTIONS(4800),
    [anon_sym_genvar] = ACTIONS(4800),
    [anon_sym_interconnect] = ACTIONS(4800),
    [anon_sym_typedef] = ACTIONS(4800),
    [anon_sym_enum] = ACTIONS(4800),
    [anon_sym_struct] = ACTIONS(4800),
    [anon_sym_union] = ACTIONS(4800),
    [anon_sym_nettype] = ACTIONS(4800),
    [anon_sym_automatic] = ACTIONS(4800),
    [anon_sym_string] = ACTIONS(4800),
    [anon_sym_chandle] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4800),
    [anon_sym_byte] = ACTIONS(4800),
    [anon_sym_shortint] = ACTIONS(4800),
    [anon_sym_int] = ACTIONS(4800),
    [anon_sym_longint] = ACTIONS(4800),
    [anon_sym_integer] = ACTIONS(4800),
    [anon_sym_time] = ACTIONS(4800),
    [anon_sym_bit] = ACTIONS(4800),
    [anon_sym_logic] = ACTIONS(4800),
    [anon_sym_reg] = ACTIONS(4800),
    [anon_sym_shortreal] = ACTIONS(4800),
    [anon_sym_real] = ACTIONS(4800),
    [anon_sym_realtime] = ACTIONS(4800),
    [anon_sym_supply0] = ACTIONS(4800),
    [anon_sym_supply1] = ACTIONS(4800),
    [anon_sym_signed] = ACTIONS(4800),
    [anon_sym_unsigned] = ACTIONS(4800),
    [anon_sym_task] = ACTIONS(4800),
    [anon_sym_assert] = ACTIONS(4800),
    [anon_sym_property] = ACTIONS(4800),
    [anon_sym_assume] = ACTIONS(4800),
    [anon_sym_cover] = ACTIONS(4800),
    [anon_sym_sequence] = ACTIONS(4800),
    [anon_sym_restrict] = ACTIONS(4800),
    [anon_sym_not] = ACTIONS(4800),
    [anon_sym_or] = ACTIONS(4800),
    [anon_sym_and] = ACTIONS(4800),
    [anon_sym_case] = ACTIONS(4800),
    [anon_sym_always] = ACTIONS(4800),
    [anon_sym_covergroup] = ACTIONS(4800),
    [anon_sym_end] = ACTIONS(4800),
    [anon_sym_let] = ACTIONS(4800),
    [anon_sym_pulldown] = ACTIONS(4800),
    [anon_sym_pullup] = ACTIONS(4800),
    [anon_sym_cmos] = ACTIONS(4800),
    [anon_sym_rcmos] = ACTIONS(4800),
    [anon_sym_bufif0] = ACTIONS(4800),
    [anon_sym_bufif1] = ACTIONS(4800),
    [anon_sym_notif0] = ACTIONS(4800),
    [anon_sym_notif1] = ACTIONS(4800),
    [anon_sym_nmos] = ACTIONS(4800),
    [anon_sym_pmos] = ACTIONS(4800),
    [anon_sym_rnmos] = ACTIONS(4800),
    [anon_sym_rpmos] = ACTIONS(4800),
    [anon_sym_nand] = ACTIONS(4800),
    [anon_sym_nor] = ACTIONS(4800),
    [anon_sym_xor] = ACTIONS(4800),
    [anon_sym_xnor] = ACTIONS(4800),
    [anon_sym_buf] = ACTIONS(4800),
    [anon_sym_tranif0] = ACTIONS(4800),
    [anon_sym_tranif1] = ACTIONS(4800),
    [anon_sym_rtranif1] = ACTIONS(4800),
    [anon_sym_rtranif0] = ACTIONS(4800),
    [anon_sym_tran] = ACTIONS(4800),
    [anon_sym_rtran] = ACTIONS(4800),
    [anon_sym_generate] = ACTIONS(4800),
    [anon_sym_for] = ACTIONS(4800),
    [anon_sym_initial] = ACTIONS(4800),
    [anon_sym_assign] = ACTIONS(4800),
    [anon_sym_alias] = ACTIONS(4800),
    [anon_sym_always_comb] = ACTIONS(4800),
    [anon_sym_always_latch] = ACTIONS(4800),
    [anon_sym_always_ff] = ACTIONS(4800),
    [anon_sym_final] = ACTIONS(4800),
    [anon_sym_global] = ACTIONS(4800),
    [anon_sym_LPAREN_STAR] = ACTIONS(4798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4798),
    [anon_sym_DOLLARunit] = ACTIONS(4798),
  },
  [4678] = {
    [sym_simple_identifier] = ACTIONS(5840),
    [anon_sym_wire] = ACTIONS(5840),
    [anon_sym_tri] = ACTIONS(5840),
    [anon_sym_tri0] = ACTIONS(5840),
    [anon_sym_tri1] = ACTIONS(5840),
    [anon_sym_wand] = ACTIONS(5840),
    [anon_sym_triand] = ACTIONS(5840),
    [anon_sym_wor] = ACTIONS(5840),
    [anon_sym_trior] = ACTIONS(5840),
    [anon_sym_trireg] = ACTIONS(5840),
    [anon_sym_uwire] = ACTIONS(5840),
    [anon_sym_SEMI] = ACTIONS(5842),
    [anon_sym_extern] = ACTIONS(5840),
    [anon_sym_interface] = ACTIONS(5840),
    [anon_sym_checker] = ACTIONS(5840),
    [anon_sym_virtual] = ACTIONS(5840),
    [anon_sym_class] = ACTIONS(5840),
    [anon_sym_type] = ACTIONS(5840),
    [anon_sym_DOLLARfatal] = ACTIONS(5842),
    [anon_sym_DOLLARerror] = ACTIONS(5842),
    [anon_sym_DOLLARwarning] = ACTIONS(5842),
    [anon_sym_DOLLARinfo] = ACTIONS(5842),
    [anon_sym_default] = ACTIONS(5840),
    [anon_sym_clocking] = ACTIONS(5840),
    [anon_sym_defparam] = ACTIONS(5840),
    [anon_sym_bind] = ACTIONS(5840),
    [anon_sym_rand] = ACTIONS(5840),
    [anon_sym_const] = ACTIONS(5840),
    [anon_sym_function] = ACTIONS(5840),
    [anon_sym_static] = ACTIONS(5840),
    [anon_sym_constraint] = ACTIONS(5840),
    [anon_sym_if] = ACTIONS(5840),
    [anon_sym_else] = ACTIONS(5840),
    [anon_sym_LBRACK] = ACTIONS(5842),
    [anon_sym_localparam] = ACTIONS(5840),
    [anon_sym_parameter] = ACTIONS(5840),
    [anon_sym_var] = ACTIONS(5840),
    [anon_sym_import] = ACTIONS(5840),
    [anon_sym_export] = ACTIONS(5840),
    [anon_sym_genvar] = ACTIONS(5840),
    [anon_sym_interconnect] = ACTIONS(5840),
    [anon_sym_typedef] = ACTIONS(5840),
    [anon_sym_enum] = ACTIONS(5840),
    [anon_sym_struct] = ACTIONS(5840),
    [anon_sym_union] = ACTIONS(5840),
    [anon_sym_nettype] = ACTIONS(5840),
    [anon_sym_automatic] = ACTIONS(5840),
    [anon_sym_string] = ACTIONS(5840),
    [anon_sym_chandle] = ACTIONS(5840),
    [anon_sym_event] = ACTIONS(5840),
    [anon_sym_byte] = ACTIONS(5840),
    [anon_sym_shortint] = ACTIONS(5840),
    [anon_sym_int] = ACTIONS(5840),
    [anon_sym_longint] = ACTIONS(5840),
    [anon_sym_integer] = ACTIONS(5840),
    [anon_sym_time] = ACTIONS(5840),
    [anon_sym_bit] = ACTIONS(5840),
    [anon_sym_logic] = ACTIONS(5840),
    [anon_sym_reg] = ACTIONS(5840),
    [anon_sym_shortreal] = ACTIONS(5840),
    [anon_sym_real] = ACTIONS(5840),
    [anon_sym_realtime] = ACTIONS(5840),
    [anon_sym_supply0] = ACTIONS(5840),
    [anon_sym_supply1] = ACTIONS(5840),
    [anon_sym_signed] = ACTIONS(5840),
    [anon_sym_unsigned] = ACTIONS(5840),
    [anon_sym_task] = ACTIONS(5840),
    [anon_sym_assert] = ACTIONS(5840),
    [anon_sym_property] = ACTIONS(5840),
    [anon_sym_assume] = ACTIONS(5840),
    [anon_sym_cover] = ACTIONS(5840),
    [anon_sym_sequence] = ACTIONS(5840),
    [anon_sym_restrict] = ACTIONS(5840),
    [anon_sym_not] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5840),
    [anon_sym_and] = ACTIONS(5840),
    [anon_sym_case] = ACTIONS(5840),
    [anon_sym_always] = ACTIONS(5840),
    [anon_sym_covergroup] = ACTIONS(5840),
    [anon_sym_end] = ACTIONS(5840),
    [anon_sym_let] = ACTIONS(5840),
    [anon_sym_pulldown] = ACTIONS(5840),
    [anon_sym_pullup] = ACTIONS(5840),
    [anon_sym_cmos] = ACTIONS(5840),
    [anon_sym_rcmos] = ACTIONS(5840),
    [anon_sym_bufif0] = ACTIONS(5840),
    [anon_sym_bufif1] = ACTIONS(5840),
    [anon_sym_notif0] = ACTIONS(5840),
    [anon_sym_notif1] = ACTIONS(5840),
    [anon_sym_nmos] = ACTIONS(5840),
    [anon_sym_pmos] = ACTIONS(5840),
    [anon_sym_rnmos] = ACTIONS(5840),
    [anon_sym_rpmos] = ACTIONS(5840),
    [anon_sym_nand] = ACTIONS(5840),
    [anon_sym_nor] = ACTIONS(5840),
    [anon_sym_xor] = ACTIONS(5840),
    [anon_sym_xnor] = ACTIONS(5840),
    [anon_sym_buf] = ACTIONS(5840),
    [anon_sym_tranif0] = ACTIONS(5840),
    [anon_sym_tranif1] = ACTIONS(5840),
    [anon_sym_rtranif1] = ACTIONS(5840),
    [anon_sym_rtranif0] = ACTIONS(5840),
    [anon_sym_tran] = ACTIONS(5840),
    [anon_sym_rtran] = ACTIONS(5840),
    [anon_sym_generate] = ACTIONS(5840),
    [anon_sym_for] = ACTIONS(5840),
    [anon_sym_initial] = ACTIONS(5840),
    [anon_sym_assign] = ACTIONS(5840),
    [anon_sym_alias] = ACTIONS(5840),
    [anon_sym_always_comb] = ACTIONS(5840),
    [anon_sym_always_latch] = ACTIONS(5840),
    [anon_sym_always_ff] = ACTIONS(5840),
    [anon_sym_final] = ACTIONS(5840),
    [anon_sym_global] = ACTIONS(5840),
    [anon_sym_LPAREN_STAR] = ACTIONS(5842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5842),
    [anon_sym_DOLLARunit] = ACTIONS(5842),
  },
  [4679] = {
    [sym_simple_identifier] = ACTIONS(5174),
    [anon_sym_wire] = ACTIONS(5174),
    [anon_sym_tri] = ACTIONS(5174),
    [anon_sym_tri0] = ACTIONS(5174),
    [anon_sym_tri1] = ACTIONS(5174),
    [anon_sym_wand] = ACTIONS(5174),
    [anon_sym_triand] = ACTIONS(5174),
    [anon_sym_wor] = ACTIONS(5174),
    [anon_sym_trior] = ACTIONS(5174),
    [anon_sym_trireg] = ACTIONS(5174),
    [anon_sym_uwire] = ACTIONS(5174),
    [anon_sym_SEMI] = ACTIONS(5172),
    [anon_sym_extern] = ACTIONS(5174),
    [anon_sym_interface] = ACTIONS(5174),
    [anon_sym_checker] = ACTIONS(5174),
    [anon_sym_virtual] = ACTIONS(5174),
    [anon_sym_class] = ACTIONS(5174),
    [anon_sym_type] = ACTIONS(5174),
    [anon_sym_DOLLARfatal] = ACTIONS(5172),
    [anon_sym_DOLLARerror] = ACTIONS(5172),
    [anon_sym_DOLLARwarning] = ACTIONS(5172),
    [anon_sym_DOLLARinfo] = ACTIONS(5172),
    [anon_sym_default] = ACTIONS(5174),
    [anon_sym_clocking] = ACTIONS(5174),
    [anon_sym_defparam] = ACTIONS(5174),
    [anon_sym_bind] = ACTIONS(5174),
    [anon_sym_rand] = ACTIONS(5174),
    [anon_sym_const] = ACTIONS(5174),
    [anon_sym_function] = ACTIONS(5174),
    [anon_sym_static] = ACTIONS(5174),
    [anon_sym_constraint] = ACTIONS(5174),
    [anon_sym_if] = ACTIONS(5174),
    [anon_sym_else] = ACTIONS(5174),
    [anon_sym_LBRACK] = ACTIONS(5172),
    [anon_sym_localparam] = ACTIONS(5174),
    [anon_sym_parameter] = ACTIONS(5174),
    [anon_sym_var] = ACTIONS(5174),
    [anon_sym_import] = ACTIONS(5174),
    [anon_sym_export] = ACTIONS(5174),
    [anon_sym_genvar] = ACTIONS(5174),
    [anon_sym_interconnect] = ACTIONS(5174),
    [anon_sym_typedef] = ACTIONS(5174),
    [anon_sym_enum] = ACTIONS(5174),
    [anon_sym_struct] = ACTIONS(5174),
    [anon_sym_union] = ACTIONS(5174),
    [anon_sym_nettype] = ACTIONS(5174),
    [anon_sym_automatic] = ACTIONS(5174),
    [anon_sym_string] = ACTIONS(5174),
    [anon_sym_chandle] = ACTIONS(5174),
    [anon_sym_event] = ACTIONS(5174),
    [anon_sym_byte] = ACTIONS(5174),
    [anon_sym_shortint] = ACTIONS(5174),
    [anon_sym_int] = ACTIONS(5174),
    [anon_sym_longint] = ACTIONS(5174),
    [anon_sym_integer] = ACTIONS(5174),
    [anon_sym_time] = ACTIONS(5174),
    [anon_sym_bit] = ACTIONS(5174),
    [anon_sym_logic] = ACTIONS(5174),
    [anon_sym_reg] = ACTIONS(5174),
    [anon_sym_shortreal] = ACTIONS(5174),
    [anon_sym_real] = ACTIONS(5174),
    [anon_sym_realtime] = ACTIONS(5174),
    [anon_sym_supply0] = ACTIONS(5174),
    [anon_sym_supply1] = ACTIONS(5174),
    [anon_sym_signed] = ACTIONS(5174),
    [anon_sym_unsigned] = ACTIONS(5174),
    [anon_sym_task] = ACTIONS(5174),
    [anon_sym_assert] = ACTIONS(5174),
    [anon_sym_property] = ACTIONS(5174),
    [anon_sym_assume] = ACTIONS(5174),
    [anon_sym_cover] = ACTIONS(5174),
    [anon_sym_sequence] = ACTIONS(5174),
    [anon_sym_restrict] = ACTIONS(5174),
    [anon_sym_not] = ACTIONS(5174),
    [anon_sym_or] = ACTIONS(5174),
    [anon_sym_and] = ACTIONS(5174),
    [anon_sym_case] = ACTIONS(5174),
    [anon_sym_always] = ACTIONS(5174),
    [anon_sym_covergroup] = ACTIONS(5174),
    [anon_sym_let] = ACTIONS(5174),
    [anon_sym_pulldown] = ACTIONS(5174),
    [anon_sym_pullup] = ACTIONS(5174),
    [anon_sym_cmos] = ACTIONS(5174),
    [anon_sym_rcmos] = ACTIONS(5174),
    [anon_sym_bufif0] = ACTIONS(5174),
    [anon_sym_bufif1] = ACTIONS(5174),
    [anon_sym_notif0] = ACTIONS(5174),
    [anon_sym_notif1] = ACTIONS(5174),
    [anon_sym_nmos] = ACTIONS(5174),
    [anon_sym_pmos] = ACTIONS(5174),
    [anon_sym_rnmos] = ACTIONS(5174),
    [anon_sym_rpmos] = ACTIONS(5174),
    [anon_sym_nand] = ACTIONS(5174),
    [anon_sym_nor] = ACTIONS(5174),
    [anon_sym_xor] = ACTIONS(5174),
    [anon_sym_xnor] = ACTIONS(5174),
    [anon_sym_buf] = ACTIONS(5174),
    [anon_sym_tranif0] = ACTIONS(5174),
    [anon_sym_tranif1] = ACTIONS(5174),
    [anon_sym_rtranif1] = ACTIONS(5174),
    [anon_sym_rtranif0] = ACTIONS(5174),
    [anon_sym_tran] = ACTIONS(5174),
    [anon_sym_rtran] = ACTIONS(5174),
    [anon_sym_generate] = ACTIONS(5174),
    [anon_sym_endgenerate] = ACTIONS(5174),
    [anon_sym_for] = ACTIONS(5174),
    [anon_sym_initial] = ACTIONS(5174),
    [anon_sym_assign] = ACTIONS(5174),
    [anon_sym_alias] = ACTIONS(5174),
    [anon_sym_always_comb] = ACTIONS(5174),
    [anon_sym_always_latch] = ACTIONS(5174),
    [anon_sym_always_ff] = ACTIONS(5174),
    [anon_sym_final] = ACTIONS(5174),
    [anon_sym_global] = ACTIONS(5174),
    [anon_sym_LPAREN_STAR] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5172),
    [anon_sym_DOLLARunit] = ACTIONS(5172),
  },
  [4680] = {
    [sym_simple_identifier] = ACTIONS(5844),
    [anon_sym_wire] = ACTIONS(5844),
    [anon_sym_tri] = ACTIONS(5844),
    [anon_sym_tri0] = ACTIONS(5844),
    [anon_sym_tri1] = ACTIONS(5844),
    [anon_sym_wand] = ACTIONS(5844),
    [anon_sym_triand] = ACTIONS(5844),
    [anon_sym_wor] = ACTIONS(5844),
    [anon_sym_trior] = ACTIONS(5844),
    [anon_sym_trireg] = ACTIONS(5844),
    [anon_sym_uwire] = ACTIONS(5844),
    [anon_sym_SEMI] = ACTIONS(5846),
    [anon_sym_extern] = ACTIONS(5844),
    [anon_sym_interface] = ACTIONS(5844),
    [anon_sym_checker] = ACTIONS(5844),
    [anon_sym_virtual] = ACTIONS(5844),
    [anon_sym_class] = ACTIONS(5844),
    [anon_sym_type] = ACTIONS(5844),
    [anon_sym_DOLLARfatal] = ACTIONS(5846),
    [anon_sym_DOLLARerror] = ACTIONS(5846),
    [anon_sym_DOLLARwarning] = ACTIONS(5846),
    [anon_sym_DOLLARinfo] = ACTIONS(5846),
    [anon_sym_default] = ACTIONS(5844),
    [anon_sym_clocking] = ACTIONS(5844),
    [anon_sym_defparam] = ACTIONS(5844),
    [anon_sym_bind] = ACTIONS(5844),
    [anon_sym_rand] = ACTIONS(5844),
    [anon_sym_const] = ACTIONS(5844),
    [anon_sym_function] = ACTIONS(5844),
    [anon_sym_static] = ACTIONS(5844),
    [anon_sym_constraint] = ACTIONS(5844),
    [anon_sym_if] = ACTIONS(5844),
    [anon_sym_else] = ACTIONS(5844),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_localparam] = ACTIONS(5844),
    [anon_sym_parameter] = ACTIONS(5844),
    [anon_sym_var] = ACTIONS(5844),
    [anon_sym_import] = ACTIONS(5844),
    [anon_sym_export] = ACTIONS(5844),
    [anon_sym_genvar] = ACTIONS(5844),
    [anon_sym_interconnect] = ACTIONS(5844),
    [anon_sym_typedef] = ACTIONS(5844),
    [anon_sym_enum] = ACTIONS(5844),
    [anon_sym_struct] = ACTIONS(5844),
    [anon_sym_union] = ACTIONS(5844),
    [anon_sym_nettype] = ACTIONS(5844),
    [anon_sym_automatic] = ACTIONS(5844),
    [anon_sym_string] = ACTIONS(5844),
    [anon_sym_chandle] = ACTIONS(5844),
    [anon_sym_event] = ACTIONS(5844),
    [anon_sym_byte] = ACTIONS(5844),
    [anon_sym_shortint] = ACTIONS(5844),
    [anon_sym_int] = ACTIONS(5844),
    [anon_sym_longint] = ACTIONS(5844),
    [anon_sym_integer] = ACTIONS(5844),
    [anon_sym_time] = ACTIONS(5844),
    [anon_sym_bit] = ACTIONS(5844),
    [anon_sym_logic] = ACTIONS(5844),
    [anon_sym_reg] = ACTIONS(5844),
    [anon_sym_shortreal] = ACTIONS(5844),
    [anon_sym_real] = ACTIONS(5844),
    [anon_sym_realtime] = ACTIONS(5844),
    [anon_sym_supply0] = ACTIONS(5844),
    [anon_sym_supply1] = ACTIONS(5844),
    [anon_sym_signed] = ACTIONS(5844),
    [anon_sym_unsigned] = ACTIONS(5844),
    [anon_sym_task] = ACTIONS(5844),
    [anon_sym_assert] = ACTIONS(5844),
    [anon_sym_property] = ACTIONS(5844),
    [anon_sym_assume] = ACTIONS(5844),
    [anon_sym_cover] = ACTIONS(5844),
    [anon_sym_sequence] = ACTIONS(5844),
    [anon_sym_restrict] = ACTIONS(5844),
    [anon_sym_not] = ACTIONS(5844),
    [anon_sym_or] = ACTIONS(5844),
    [anon_sym_and] = ACTIONS(5844),
    [anon_sym_case] = ACTIONS(5844),
    [anon_sym_always] = ACTIONS(5844),
    [anon_sym_covergroup] = ACTIONS(5844),
    [anon_sym_end] = ACTIONS(5844),
    [anon_sym_let] = ACTIONS(5844),
    [anon_sym_pulldown] = ACTIONS(5844),
    [anon_sym_pullup] = ACTIONS(5844),
    [anon_sym_cmos] = ACTIONS(5844),
    [anon_sym_rcmos] = ACTIONS(5844),
    [anon_sym_bufif0] = ACTIONS(5844),
    [anon_sym_bufif1] = ACTIONS(5844),
    [anon_sym_notif0] = ACTIONS(5844),
    [anon_sym_notif1] = ACTIONS(5844),
    [anon_sym_nmos] = ACTIONS(5844),
    [anon_sym_pmos] = ACTIONS(5844),
    [anon_sym_rnmos] = ACTIONS(5844),
    [anon_sym_rpmos] = ACTIONS(5844),
    [anon_sym_nand] = ACTIONS(5844),
    [anon_sym_nor] = ACTIONS(5844),
    [anon_sym_xor] = ACTIONS(5844),
    [anon_sym_xnor] = ACTIONS(5844),
    [anon_sym_buf] = ACTIONS(5844),
    [anon_sym_tranif0] = ACTIONS(5844),
    [anon_sym_tranif1] = ACTIONS(5844),
    [anon_sym_rtranif1] = ACTIONS(5844),
    [anon_sym_rtranif0] = ACTIONS(5844),
    [anon_sym_tran] = ACTIONS(5844),
    [anon_sym_rtran] = ACTIONS(5844),
    [anon_sym_generate] = ACTIONS(5844),
    [anon_sym_for] = ACTIONS(5844),
    [anon_sym_initial] = ACTIONS(5844),
    [anon_sym_assign] = ACTIONS(5844),
    [anon_sym_alias] = ACTIONS(5844),
    [anon_sym_always_comb] = ACTIONS(5844),
    [anon_sym_always_latch] = ACTIONS(5844),
    [anon_sym_always_ff] = ACTIONS(5844),
    [anon_sym_final] = ACTIONS(5844),
    [anon_sym_global] = ACTIONS(5844),
    [anon_sym_LPAREN_STAR] = ACTIONS(5846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5846),
    [anon_sym_DOLLARunit] = ACTIONS(5846),
  },
  [4681] = {
    [sym_simple_identifier] = ACTIONS(4864),
    [anon_sym_wire] = ACTIONS(4864),
    [anon_sym_tri] = ACTIONS(4864),
    [anon_sym_tri0] = ACTIONS(4864),
    [anon_sym_tri1] = ACTIONS(4864),
    [anon_sym_wand] = ACTIONS(4864),
    [anon_sym_triand] = ACTIONS(4864),
    [anon_sym_wor] = ACTIONS(4864),
    [anon_sym_trior] = ACTIONS(4864),
    [anon_sym_trireg] = ACTIONS(4864),
    [anon_sym_uwire] = ACTIONS(4864),
    [anon_sym_SEMI] = ACTIONS(4862),
    [anon_sym_extern] = ACTIONS(4864),
    [anon_sym_interface] = ACTIONS(4864),
    [anon_sym_checker] = ACTIONS(4864),
    [anon_sym_virtual] = ACTIONS(4864),
    [anon_sym_class] = ACTIONS(4864),
    [anon_sym_type] = ACTIONS(4864),
    [anon_sym_DOLLARfatal] = ACTIONS(4862),
    [anon_sym_DOLLARerror] = ACTIONS(4862),
    [anon_sym_DOLLARwarning] = ACTIONS(4862),
    [anon_sym_DOLLARinfo] = ACTIONS(4862),
    [anon_sym_default] = ACTIONS(4864),
    [anon_sym_clocking] = ACTIONS(4864),
    [anon_sym_defparam] = ACTIONS(4864),
    [anon_sym_bind] = ACTIONS(4864),
    [anon_sym_rand] = ACTIONS(4864),
    [anon_sym_const] = ACTIONS(4864),
    [anon_sym_function] = ACTIONS(4864),
    [anon_sym_static] = ACTIONS(4864),
    [anon_sym_constraint] = ACTIONS(4864),
    [anon_sym_if] = ACTIONS(4864),
    [anon_sym_else] = ACTIONS(4864),
    [anon_sym_LBRACK] = ACTIONS(4862),
    [anon_sym_localparam] = ACTIONS(4864),
    [anon_sym_parameter] = ACTIONS(4864),
    [anon_sym_var] = ACTIONS(4864),
    [anon_sym_import] = ACTIONS(4864),
    [anon_sym_export] = ACTIONS(4864),
    [anon_sym_genvar] = ACTIONS(4864),
    [anon_sym_interconnect] = ACTIONS(4864),
    [anon_sym_typedef] = ACTIONS(4864),
    [anon_sym_enum] = ACTIONS(4864),
    [anon_sym_struct] = ACTIONS(4864),
    [anon_sym_union] = ACTIONS(4864),
    [anon_sym_nettype] = ACTIONS(4864),
    [anon_sym_automatic] = ACTIONS(4864),
    [anon_sym_string] = ACTIONS(4864),
    [anon_sym_chandle] = ACTIONS(4864),
    [anon_sym_event] = ACTIONS(4864),
    [anon_sym_byte] = ACTIONS(4864),
    [anon_sym_shortint] = ACTIONS(4864),
    [anon_sym_int] = ACTIONS(4864),
    [anon_sym_longint] = ACTIONS(4864),
    [anon_sym_integer] = ACTIONS(4864),
    [anon_sym_time] = ACTIONS(4864),
    [anon_sym_bit] = ACTIONS(4864),
    [anon_sym_logic] = ACTIONS(4864),
    [anon_sym_reg] = ACTIONS(4864),
    [anon_sym_shortreal] = ACTIONS(4864),
    [anon_sym_real] = ACTIONS(4864),
    [anon_sym_realtime] = ACTIONS(4864),
    [anon_sym_supply0] = ACTIONS(4864),
    [anon_sym_supply1] = ACTIONS(4864),
    [anon_sym_signed] = ACTIONS(4864),
    [anon_sym_unsigned] = ACTIONS(4864),
    [anon_sym_task] = ACTIONS(4864),
    [anon_sym_assert] = ACTIONS(4864),
    [anon_sym_property] = ACTIONS(4864),
    [anon_sym_assume] = ACTIONS(4864),
    [anon_sym_cover] = ACTIONS(4864),
    [anon_sym_sequence] = ACTIONS(4864),
    [anon_sym_restrict] = ACTIONS(4864),
    [anon_sym_not] = ACTIONS(4864),
    [anon_sym_or] = ACTIONS(4864),
    [anon_sym_and] = ACTIONS(4864),
    [anon_sym_case] = ACTIONS(4864),
    [anon_sym_always] = ACTIONS(4864),
    [anon_sym_covergroup] = ACTIONS(4864),
    [anon_sym_let] = ACTIONS(4864),
    [anon_sym_pulldown] = ACTIONS(4864),
    [anon_sym_pullup] = ACTIONS(4864),
    [anon_sym_cmos] = ACTIONS(4864),
    [anon_sym_rcmos] = ACTIONS(4864),
    [anon_sym_bufif0] = ACTIONS(4864),
    [anon_sym_bufif1] = ACTIONS(4864),
    [anon_sym_notif0] = ACTIONS(4864),
    [anon_sym_notif1] = ACTIONS(4864),
    [anon_sym_nmos] = ACTIONS(4864),
    [anon_sym_pmos] = ACTIONS(4864),
    [anon_sym_rnmos] = ACTIONS(4864),
    [anon_sym_rpmos] = ACTIONS(4864),
    [anon_sym_nand] = ACTIONS(4864),
    [anon_sym_nor] = ACTIONS(4864),
    [anon_sym_xor] = ACTIONS(4864),
    [anon_sym_xnor] = ACTIONS(4864),
    [anon_sym_buf] = ACTIONS(4864),
    [anon_sym_tranif0] = ACTIONS(4864),
    [anon_sym_tranif1] = ACTIONS(4864),
    [anon_sym_rtranif1] = ACTIONS(4864),
    [anon_sym_rtranif0] = ACTIONS(4864),
    [anon_sym_tran] = ACTIONS(4864),
    [anon_sym_rtran] = ACTIONS(4864),
    [anon_sym_generate] = ACTIONS(4864),
    [anon_sym_endgenerate] = ACTIONS(4864),
    [anon_sym_for] = ACTIONS(4864),
    [anon_sym_initial] = ACTIONS(4864),
    [anon_sym_assign] = ACTIONS(4864),
    [anon_sym_alias] = ACTIONS(4864),
    [anon_sym_always_comb] = ACTIONS(4864),
    [anon_sym_always_latch] = ACTIONS(4864),
    [anon_sym_always_ff] = ACTIONS(4864),
    [anon_sym_final] = ACTIONS(4864),
    [anon_sym_global] = ACTIONS(4864),
    [anon_sym_LPAREN_STAR] = ACTIONS(4862),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4862),
    [anon_sym_DOLLARunit] = ACTIONS(4862),
  },
  [4682] = {
    [sym_simple_identifier] = ACTIONS(5282),
    [anon_sym_wire] = ACTIONS(5282),
    [anon_sym_tri] = ACTIONS(5282),
    [anon_sym_tri0] = ACTIONS(5282),
    [anon_sym_tri1] = ACTIONS(5282),
    [anon_sym_wand] = ACTIONS(5282),
    [anon_sym_triand] = ACTIONS(5282),
    [anon_sym_wor] = ACTIONS(5282),
    [anon_sym_trior] = ACTIONS(5282),
    [anon_sym_trireg] = ACTIONS(5282),
    [anon_sym_uwire] = ACTIONS(5282),
    [anon_sym_SEMI] = ACTIONS(5280),
    [anon_sym_extern] = ACTIONS(5282),
    [anon_sym_interface] = ACTIONS(5282),
    [anon_sym_checker] = ACTIONS(5282),
    [anon_sym_virtual] = ACTIONS(5282),
    [anon_sym_class] = ACTIONS(5282),
    [anon_sym_type] = ACTIONS(5282),
    [anon_sym_DOLLARfatal] = ACTIONS(5280),
    [anon_sym_DOLLARerror] = ACTIONS(5280),
    [anon_sym_DOLLARwarning] = ACTIONS(5280),
    [anon_sym_DOLLARinfo] = ACTIONS(5280),
    [anon_sym_default] = ACTIONS(5282),
    [anon_sym_clocking] = ACTIONS(5282),
    [anon_sym_defparam] = ACTIONS(5282),
    [anon_sym_bind] = ACTIONS(5282),
    [anon_sym_rand] = ACTIONS(5282),
    [anon_sym_const] = ACTIONS(5282),
    [anon_sym_function] = ACTIONS(5282),
    [anon_sym_static] = ACTIONS(5282),
    [anon_sym_constraint] = ACTIONS(5282),
    [anon_sym_if] = ACTIONS(5282),
    [anon_sym_else] = ACTIONS(5282),
    [anon_sym_LBRACK] = ACTIONS(5280),
    [anon_sym_localparam] = ACTIONS(5282),
    [anon_sym_parameter] = ACTIONS(5282),
    [anon_sym_var] = ACTIONS(5282),
    [anon_sym_import] = ACTIONS(5282),
    [anon_sym_export] = ACTIONS(5282),
    [anon_sym_genvar] = ACTIONS(5282),
    [anon_sym_interconnect] = ACTIONS(5282),
    [anon_sym_typedef] = ACTIONS(5282),
    [anon_sym_enum] = ACTIONS(5282),
    [anon_sym_struct] = ACTIONS(5282),
    [anon_sym_union] = ACTIONS(5282),
    [anon_sym_nettype] = ACTIONS(5282),
    [anon_sym_automatic] = ACTIONS(5282),
    [anon_sym_string] = ACTIONS(5282),
    [anon_sym_chandle] = ACTIONS(5282),
    [anon_sym_event] = ACTIONS(5282),
    [anon_sym_byte] = ACTIONS(5282),
    [anon_sym_shortint] = ACTIONS(5282),
    [anon_sym_int] = ACTIONS(5282),
    [anon_sym_longint] = ACTIONS(5282),
    [anon_sym_integer] = ACTIONS(5282),
    [anon_sym_time] = ACTIONS(5282),
    [anon_sym_bit] = ACTIONS(5282),
    [anon_sym_logic] = ACTIONS(5282),
    [anon_sym_reg] = ACTIONS(5282),
    [anon_sym_shortreal] = ACTIONS(5282),
    [anon_sym_real] = ACTIONS(5282),
    [anon_sym_realtime] = ACTIONS(5282),
    [anon_sym_supply0] = ACTIONS(5282),
    [anon_sym_supply1] = ACTIONS(5282),
    [anon_sym_signed] = ACTIONS(5282),
    [anon_sym_unsigned] = ACTIONS(5282),
    [anon_sym_task] = ACTIONS(5282),
    [anon_sym_assert] = ACTIONS(5282),
    [anon_sym_property] = ACTIONS(5282),
    [anon_sym_assume] = ACTIONS(5282),
    [anon_sym_cover] = ACTIONS(5282),
    [anon_sym_sequence] = ACTIONS(5282),
    [anon_sym_restrict] = ACTIONS(5282),
    [anon_sym_not] = ACTIONS(5282),
    [anon_sym_or] = ACTIONS(5282),
    [anon_sym_and] = ACTIONS(5282),
    [anon_sym_case] = ACTIONS(5282),
    [anon_sym_always] = ACTIONS(5282),
    [anon_sym_covergroup] = ACTIONS(5282),
    [anon_sym_end] = ACTIONS(5282),
    [anon_sym_let] = ACTIONS(5282),
    [anon_sym_pulldown] = ACTIONS(5282),
    [anon_sym_pullup] = ACTIONS(5282),
    [anon_sym_cmos] = ACTIONS(5282),
    [anon_sym_rcmos] = ACTIONS(5282),
    [anon_sym_bufif0] = ACTIONS(5282),
    [anon_sym_bufif1] = ACTIONS(5282),
    [anon_sym_notif0] = ACTIONS(5282),
    [anon_sym_notif1] = ACTIONS(5282),
    [anon_sym_nmos] = ACTIONS(5282),
    [anon_sym_pmos] = ACTIONS(5282),
    [anon_sym_rnmos] = ACTIONS(5282),
    [anon_sym_rpmos] = ACTIONS(5282),
    [anon_sym_nand] = ACTIONS(5282),
    [anon_sym_nor] = ACTIONS(5282),
    [anon_sym_xor] = ACTIONS(5282),
    [anon_sym_xnor] = ACTIONS(5282),
    [anon_sym_buf] = ACTIONS(5282),
    [anon_sym_tranif0] = ACTIONS(5282),
    [anon_sym_tranif1] = ACTIONS(5282),
    [anon_sym_rtranif1] = ACTIONS(5282),
    [anon_sym_rtranif0] = ACTIONS(5282),
    [anon_sym_tran] = ACTIONS(5282),
    [anon_sym_rtran] = ACTIONS(5282),
    [anon_sym_generate] = ACTIONS(5282),
    [anon_sym_for] = ACTIONS(5282),
    [anon_sym_initial] = ACTIONS(5282),
    [anon_sym_assign] = ACTIONS(5282),
    [anon_sym_alias] = ACTIONS(5282),
    [anon_sym_always_comb] = ACTIONS(5282),
    [anon_sym_always_latch] = ACTIONS(5282),
    [anon_sym_always_ff] = ACTIONS(5282),
    [anon_sym_final] = ACTIONS(5282),
    [anon_sym_global] = ACTIONS(5282),
    [anon_sym_LPAREN_STAR] = ACTIONS(5280),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5280),
    [anon_sym_DOLLARunit] = ACTIONS(5280),
  },
  [4683] = {
    [sym_simple_identifier] = ACTIONS(5854),
    [anon_sym_wire] = ACTIONS(5854),
    [anon_sym_tri] = ACTIONS(5854),
    [anon_sym_tri0] = ACTIONS(5854),
    [anon_sym_tri1] = ACTIONS(5854),
    [anon_sym_wand] = ACTIONS(5854),
    [anon_sym_triand] = ACTIONS(5854),
    [anon_sym_wor] = ACTIONS(5854),
    [anon_sym_trior] = ACTIONS(5854),
    [anon_sym_trireg] = ACTIONS(5854),
    [anon_sym_uwire] = ACTIONS(5854),
    [anon_sym_SEMI] = ACTIONS(5856),
    [anon_sym_extern] = ACTIONS(5854),
    [anon_sym_interface] = ACTIONS(5854),
    [anon_sym_checker] = ACTIONS(5854),
    [anon_sym_virtual] = ACTIONS(5854),
    [anon_sym_class] = ACTIONS(5854),
    [anon_sym_type] = ACTIONS(5854),
    [anon_sym_DOLLARfatal] = ACTIONS(5856),
    [anon_sym_DOLLARerror] = ACTIONS(5856),
    [anon_sym_DOLLARwarning] = ACTIONS(5856),
    [anon_sym_DOLLARinfo] = ACTIONS(5856),
    [anon_sym_default] = ACTIONS(5854),
    [anon_sym_clocking] = ACTIONS(5854),
    [anon_sym_defparam] = ACTIONS(5854),
    [anon_sym_bind] = ACTIONS(5854),
    [anon_sym_rand] = ACTIONS(5854),
    [anon_sym_const] = ACTIONS(5854),
    [anon_sym_function] = ACTIONS(5854),
    [anon_sym_static] = ACTIONS(5854),
    [anon_sym_constraint] = ACTIONS(5854),
    [anon_sym_if] = ACTIONS(5854),
    [anon_sym_else] = ACTIONS(5854),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_localparam] = ACTIONS(5854),
    [anon_sym_parameter] = ACTIONS(5854),
    [anon_sym_var] = ACTIONS(5854),
    [anon_sym_import] = ACTIONS(5854),
    [anon_sym_export] = ACTIONS(5854),
    [anon_sym_genvar] = ACTIONS(5854),
    [anon_sym_interconnect] = ACTIONS(5854),
    [anon_sym_typedef] = ACTIONS(5854),
    [anon_sym_enum] = ACTIONS(5854),
    [anon_sym_struct] = ACTIONS(5854),
    [anon_sym_union] = ACTIONS(5854),
    [anon_sym_nettype] = ACTIONS(5854),
    [anon_sym_automatic] = ACTIONS(5854),
    [anon_sym_string] = ACTIONS(5854),
    [anon_sym_chandle] = ACTIONS(5854),
    [anon_sym_event] = ACTIONS(5854),
    [anon_sym_byte] = ACTIONS(5854),
    [anon_sym_shortint] = ACTIONS(5854),
    [anon_sym_int] = ACTIONS(5854),
    [anon_sym_longint] = ACTIONS(5854),
    [anon_sym_integer] = ACTIONS(5854),
    [anon_sym_time] = ACTIONS(5854),
    [anon_sym_bit] = ACTIONS(5854),
    [anon_sym_logic] = ACTIONS(5854),
    [anon_sym_reg] = ACTIONS(5854),
    [anon_sym_shortreal] = ACTIONS(5854),
    [anon_sym_real] = ACTIONS(5854),
    [anon_sym_realtime] = ACTIONS(5854),
    [anon_sym_supply0] = ACTIONS(5854),
    [anon_sym_supply1] = ACTIONS(5854),
    [anon_sym_signed] = ACTIONS(5854),
    [anon_sym_unsigned] = ACTIONS(5854),
    [anon_sym_task] = ACTIONS(5854),
    [anon_sym_assert] = ACTIONS(5854),
    [anon_sym_property] = ACTIONS(5854),
    [anon_sym_assume] = ACTIONS(5854),
    [anon_sym_cover] = ACTIONS(5854),
    [anon_sym_sequence] = ACTIONS(5854),
    [anon_sym_restrict] = ACTIONS(5854),
    [anon_sym_not] = ACTIONS(5854),
    [anon_sym_or] = ACTIONS(5854),
    [anon_sym_and] = ACTIONS(5854),
    [anon_sym_case] = ACTIONS(5854),
    [anon_sym_always] = ACTIONS(5854),
    [anon_sym_covergroup] = ACTIONS(5854),
    [anon_sym_end] = ACTIONS(5854),
    [anon_sym_let] = ACTIONS(5854),
    [anon_sym_pulldown] = ACTIONS(5854),
    [anon_sym_pullup] = ACTIONS(5854),
    [anon_sym_cmos] = ACTIONS(5854),
    [anon_sym_rcmos] = ACTIONS(5854),
    [anon_sym_bufif0] = ACTIONS(5854),
    [anon_sym_bufif1] = ACTIONS(5854),
    [anon_sym_notif0] = ACTIONS(5854),
    [anon_sym_notif1] = ACTIONS(5854),
    [anon_sym_nmos] = ACTIONS(5854),
    [anon_sym_pmos] = ACTIONS(5854),
    [anon_sym_rnmos] = ACTIONS(5854),
    [anon_sym_rpmos] = ACTIONS(5854),
    [anon_sym_nand] = ACTIONS(5854),
    [anon_sym_nor] = ACTIONS(5854),
    [anon_sym_xor] = ACTIONS(5854),
    [anon_sym_xnor] = ACTIONS(5854),
    [anon_sym_buf] = ACTIONS(5854),
    [anon_sym_tranif0] = ACTIONS(5854),
    [anon_sym_tranif1] = ACTIONS(5854),
    [anon_sym_rtranif1] = ACTIONS(5854),
    [anon_sym_rtranif0] = ACTIONS(5854),
    [anon_sym_tran] = ACTIONS(5854),
    [anon_sym_rtran] = ACTIONS(5854),
    [anon_sym_generate] = ACTIONS(5854),
    [anon_sym_for] = ACTIONS(5854),
    [anon_sym_initial] = ACTIONS(5854),
    [anon_sym_assign] = ACTIONS(5854),
    [anon_sym_alias] = ACTIONS(5854),
    [anon_sym_always_comb] = ACTIONS(5854),
    [anon_sym_always_latch] = ACTIONS(5854),
    [anon_sym_always_ff] = ACTIONS(5854),
    [anon_sym_final] = ACTIONS(5854),
    [anon_sym_global] = ACTIONS(5854),
    [anon_sym_LPAREN_STAR] = ACTIONS(5856),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5856),
    [anon_sym_DOLLARunit] = ACTIONS(5856),
  },
  [4684] = {
    [sym_simple_identifier] = ACTIONS(6617),
    [anon_sym_wire] = ACTIONS(6617),
    [anon_sym_tri] = ACTIONS(6617),
    [anon_sym_tri0] = ACTIONS(6617),
    [anon_sym_tri1] = ACTIONS(6617),
    [anon_sym_wand] = ACTIONS(6617),
    [anon_sym_triand] = ACTIONS(6617),
    [anon_sym_wor] = ACTIONS(6617),
    [anon_sym_trior] = ACTIONS(6617),
    [anon_sym_trireg] = ACTIONS(6617),
    [anon_sym_uwire] = ACTIONS(6617),
    [anon_sym_SEMI] = ACTIONS(6619),
    [anon_sym_extern] = ACTIONS(6617),
    [anon_sym_interface] = ACTIONS(6617),
    [anon_sym_checker] = ACTIONS(6617),
    [anon_sym_virtual] = ACTIONS(6617),
    [anon_sym_class] = ACTIONS(6617),
    [anon_sym_type] = ACTIONS(6617),
    [anon_sym_DOLLARfatal] = ACTIONS(6619),
    [anon_sym_DOLLARerror] = ACTIONS(6619),
    [anon_sym_DOLLARwarning] = ACTIONS(6619),
    [anon_sym_DOLLARinfo] = ACTIONS(6619),
    [anon_sym_default] = ACTIONS(6617),
    [anon_sym_clocking] = ACTIONS(6617),
    [anon_sym_defparam] = ACTIONS(6617),
    [anon_sym_bind] = ACTIONS(6617),
    [anon_sym_rand] = ACTIONS(6617),
    [anon_sym_const] = ACTIONS(6617),
    [anon_sym_function] = ACTIONS(6617),
    [anon_sym_static] = ACTIONS(6617),
    [anon_sym_constraint] = ACTIONS(6617),
    [anon_sym_if] = ACTIONS(6617),
    [anon_sym_else] = ACTIONS(6617),
    [anon_sym_LBRACK] = ACTIONS(6619),
    [anon_sym_localparam] = ACTIONS(6617),
    [anon_sym_parameter] = ACTIONS(6617),
    [anon_sym_var] = ACTIONS(6617),
    [anon_sym_import] = ACTIONS(6617),
    [anon_sym_export] = ACTIONS(6617),
    [anon_sym_genvar] = ACTIONS(6617),
    [anon_sym_interconnect] = ACTIONS(6617),
    [anon_sym_typedef] = ACTIONS(6617),
    [anon_sym_enum] = ACTIONS(6617),
    [anon_sym_struct] = ACTIONS(6617),
    [anon_sym_union] = ACTIONS(6617),
    [anon_sym_nettype] = ACTIONS(6617),
    [anon_sym_automatic] = ACTIONS(6617),
    [anon_sym_string] = ACTIONS(6617),
    [anon_sym_chandle] = ACTIONS(6617),
    [anon_sym_event] = ACTIONS(6617),
    [anon_sym_byte] = ACTIONS(6617),
    [anon_sym_shortint] = ACTIONS(6617),
    [anon_sym_int] = ACTIONS(6617),
    [anon_sym_longint] = ACTIONS(6617),
    [anon_sym_integer] = ACTIONS(6617),
    [anon_sym_time] = ACTIONS(6617),
    [anon_sym_bit] = ACTIONS(6617),
    [anon_sym_logic] = ACTIONS(6617),
    [anon_sym_reg] = ACTIONS(6617),
    [anon_sym_shortreal] = ACTIONS(6617),
    [anon_sym_real] = ACTIONS(6617),
    [anon_sym_realtime] = ACTIONS(6617),
    [anon_sym_supply0] = ACTIONS(6617),
    [anon_sym_supply1] = ACTIONS(6617),
    [anon_sym_signed] = ACTIONS(6617),
    [anon_sym_unsigned] = ACTIONS(6617),
    [anon_sym_task] = ACTIONS(6617),
    [anon_sym_assert] = ACTIONS(6617),
    [anon_sym_property] = ACTIONS(6617),
    [anon_sym_assume] = ACTIONS(6617),
    [anon_sym_cover] = ACTIONS(6617),
    [anon_sym_sequence] = ACTIONS(6617),
    [anon_sym_restrict] = ACTIONS(6617),
    [anon_sym_not] = ACTIONS(6617),
    [anon_sym_or] = ACTIONS(6617),
    [anon_sym_and] = ACTIONS(6617),
    [anon_sym_case] = ACTIONS(6617),
    [anon_sym_always] = ACTIONS(6617),
    [anon_sym_covergroup] = ACTIONS(6617),
    [anon_sym_let] = ACTIONS(6617),
    [anon_sym_pulldown] = ACTIONS(6617),
    [anon_sym_pullup] = ACTIONS(6617),
    [anon_sym_cmos] = ACTIONS(6617),
    [anon_sym_rcmos] = ACTIONS(6617),
    [anon_sym_bufif0] = ACTIONS(6617),
    [anon_sym_bufif1] = ACTIONS(6617),
    [anon_sym_notif0] = ACTIONS(6617),
    [anon_sym_notif1] = ACTIONS(6617),
    [anon_sym_nmos] = ACTIONS(6617),
    [anon_sym_pmos] = ACTIONS(6617),
    [anon_sym_rnmos] = ACTIONS(6617),
    [anon_sym_rpmos] = ACTIONS(6617),
    [anon_sym_nand] = ACTIONS(6617),
    [anon_sym_nor] = ACTIONS(6617),
    [anon_sym_xor] = ACTIONS(6617),
    [anon_sym_xnor] = ACTIONS(6617),
    [anon_sym_buf] = ACTIONS(6617),
    [anon_sym_tranif0] = ACTIONS(6617),
    [anon_sym_tranif1] = ACTIONS(6617),
    [anon_sym_rtranif1] = ACTIONS(6617),
    [anon_sym_rtranif0] = ACTIONS(6617),
    [anon_sym_tran] = ACTIONS(6617),
    [anon_sym_rtran] = ACTIONS(6617),
    [anon_sym_generate] = ACTIONS(6617),
    [anon_sym_endgenerate] = ACTIONS(6617),
    [anon_sym_for] = ACTIONS(6617),
    [anon_sym_initial] = ACTIONS(6617),
    [anon_sym_assign] = ACTIONS(6617),
    [anon_sym_alias] = ACTIONS(6617),
    [anon_sym_always_comb] = ACTIONS(6617),
    [anon_sym_always_latch] = ACTIONS(6617),
    [anon_sym_always_ff] = ACTIONS(6617),
    [anon_sym_final] = ACTIONS(6617),
    [anon_sym_global] = ACTIONS(6617),
    [anon_sym_LPAREN_STAR] = ACTIONS(6619),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6619),
    [anon_sym_DOLLARunit] = ACTIONS(6619),
  },
  [4685] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_rand] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_endgenerate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [4686] = {
    [sym_simple_identifier] = ACTIONS(5496),
    [anon_sym_wire] = ACTIONS(5496),
    [anon_sym_tri] = ACTIONS(5496),
    [anon_sym_tri0] = ACTIONS(5496),
    [anon_sym_tri1] = ACTIONS(5496),
    [anon_sym_wand] = ACTIONS(5496),
    [anon_sym_triand] = ACTIONS(5496),
    [anon_sym_wor] = ACTIONS(5496),
    [anon_sym_trior] = ACTIONS(5496),
    [anon_sym_trireg] = ACTIONS(5496),
    [anon_sym_uwire] = ACTIONS(5496),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_extern] = ACTIONS(5496),
    [anon_sym_interface] = ACTIONS(5496),
    [anon_sym_checker] = ACTIONS(5496),
    [anon_sym_virtual] = ACTIONS(5496),
    [anon_sym_class] = ACTIONS(5496),
    [anon_sym_type] = ACTIONS(5496),
    [anon_sym_DOLLARfatal] = ACTIONS(5494),
    [anon_sym_DOLLARerror] = ACTIONS(5494),
    [anon_sym_DOLLARwarning] = ACTIONS(5494),
    [anon_sym_DOLLARinfo] = ACTIONS(5494),
    [anon_sym_default] = ACTIONS(5496),
    [anon_sym_clocking] = ACTIONS(5496),
    [anon_sym_defparam] = ACTIONS(5496),
    [anon_sym_bind] = ACTIONS(5496),
    [anon_sym_rand] = ACTIONS(5496),
    [anon_sym_const] = ACTIONS(5496),
    [anon_sym_function] = ACTIONS(5496),
    [anon_sym_static] = ACTIONS(5496),
    [anon_sym_constraint] = ACTIONS(5496),
    [anon_sym_if] = ACTIONS(5496),
    [anon_sym_else] = ACTIONS(5496),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_localparam] = ACTIONS(5496),
    [anon_sym_parameter] = ACTIONS(5496),
    [anon_sym_var] = ACTIONS(5496),
    [anon_sym_import] = ACTIONS(5496),
    [anon_sym_export] = ACTIONS(5496),
    [anon_sym_genvar] = ACTIONS(5496),
    [anon_sym_interconnect] = ACTIONS(5496),
    [anon_sym_typedef] = ACTIONS(5496),
    [anon_sym_enum] = ACTIONS(5496),
    [anon_sym_struct] = ACTIONS(5496),
    [anon_sym_union] = ACTIONS(5496),
    [anon_sym_nettype] = ACTIONS(5496),
    [anon_sym_automatic] = ACTIONS(5496),
    [anon_sym_string] = ACTIONS(5496),
    [anon_sym_chandle] = ACTIONS(5496),
    [anon_sym_event] = ACTIONS(5496),
    [anon_sym_byte] = ACTIONS(5496),
    [anon_sym_shortint] = ACTIONS(5496),
    [anon_sym_int] = ACTIONS(5496),
    [anon_sym_longint] = ACTIONS(5496),
    [anon_sym_integer] = ACTIONS(5496),
    [anon_sym_time] = ACTIONS(5496),
    [anon_sym_bit] = ACTIONS(5496),
    [anon_sym_logic] = ACTIONS(5496),
    [anon_sym_reg] = ACTIONS(5496),
    [anon_sym_shortreal] = ACTIONS(5496),
    [anon_sym_real] = ACTIONS(5496),
    [anon_sym_realtime] = ACTIONS(5496),
    [anon_sym_supply0] = ACTIONS(5496),
    [anon_sym_supply1] = ACTIONS(5496),
    [anon_sym_signed] = ACTIONS(5496),
    [anon_sym_unsigned] = ACTIONS(5496),
    [anon_sym_task] = ACTIONS(5496),
    [anon_sym_assert] = ACTIONS(5496),
    [anon_sym_property] = ACTIONS(5496),
    [anon_sym_assume] = ACTIONS(5496),
    [anon_sym_cover] = ACTIONS(5496),
    [anon_sym_sequence] = ACTIONS(5496),
    [anon_sym_restrict] = ACTIONS(5496),
    [anon_sym_not] = ACTIONS(5496),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_and] = ACTIONS(5496),
    [anon_sym_case] = ACTIONS(5496),
    [anon_sym_always] = ACTIONS(5496),
    [anon_sym_covergroup] = ACTIONS(5496),
    [anon_sym_end] = ACTIONS(5496),
    [anon_sym_let] = ACTIONS(5496),
    [anon_sym_pulldown] = ACTIONS(5496),
    [anon_sym_pullup] = ACTIONS(5496),
    [anon_sym_cmos] = ACTIONS(5496),
    [anon_sym_rcmos] = ACTIONS(5496),
    [anon_sym_bufif0] = ACTIONS(5496),
    [anon_sym_bufif1] = ACTIONS(5496),
    [anon_sym_notif0] = ACTIONS(5496),
    [anon_sym_notif1] = ACTIONS(5496),
    [anon_sym_nmos] = ACTIONS(5496),
    [anon_sym_pmos] = ACTIONS(5496),
    [anon_sym_rnmos] = ACTIONS(5496),
    [anon_sym_rpmos] = ACTIONS(5496),
    [anon_sym_nand] = ACTIONS(5496),
    [anon_sym_nor] = ACTIONS(5496),
    [anon_sym_xor] = ACTIONS(5496),
    [anon_sym_xnor] = ACTIONS(5496),
    [anon_sym_buf] = ACTIONS(5496),
    [anon_sym_tranif0] = ACTIONS(5496),
    [anon_sym_tranif1] = ACTIONS(5496),
    [anon_sym_rtranif1] = ACTIONS(5496),
    [anon_sym_rtranif0] = ACTIONS(5496),
    [anon_sym_tran] = ACTIONS(5496),
    [anon_sym_rtran] = ACTIONS(5496),
    [anon_sym_generate] = ACTIONS(5496),
    [anon_sym_for] = ACTIONS(5496),
    [anon_sym_initial] = ACTIONS(5496),
    [anon_sym_assign] = ACTIONS(5496),
    [anon_sym_alias] = ACTIONS(5496),
    [anon_sym_always_comb] = ACTIONS(5496),
    [anon_sym_always_latch] = ACTIONS(5496),
    [anon_sym_always_ff] = ACTIONS(5496),
    [anon_sym_final] = ACTIONS(5496),
    [anon_sym_global] = ACTIONS(5496),
    [anon_sym_LPAREN_STAR] = ACTIONS(5494),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5494),
    [anon_sym_DOLLARunit] = ACTIONS(5494),
  },
  [4687] = {
    [sym_simple_identifier] = ACTIONS(4888),
    [anon_sym_wire] = ACTIONS(4888),
    [anon_sym_tri] = ACTIONS(4888),
    [anon_sym_tri0] = ACTIONS(4888),
    [anon_sym_tri1] = ACTIONS(4888),
    [anon_sym_wand] = ACTIONS(4888),
    [anon_sym_triand] = ACTIONS(4888),
    [anon_sym_wor] = ACTIONS(4888),
    [anon_sym_trior] = ACTIONS(4888),
    [anon_sym_trireg] = ACTIONS(4888),
    [anon_sym_uwire] = ACTIONS(4888),
    [anon_sym_SEMI] = ACTIONS(4886),
    [anon_sym_extern] = ACTIONS(4888),
    [anon_sym_interface] = ACTIONS(4888),
    [anon_sym_checker] = ACTIONS(4888),
    [anon_sym_virtual] = ACTIONS(4888),
    [anon_sym_class] = ACTIONS(4888),
    [anon_sym_type] = ACTIONS(4888),
    [anon_sym_DOLLARfatal] = ACTIONS(4886),
    [anon_sym_DOLLARerror] = ACTIONS(4886),
    [anon_sym_DOLLARwarning] = ACTIONS(4886),
    [anon_sym_DOLLARinfo] = ACTIONS(4886),
    [anon_sym_default] = ACTIONS(4888),
    [anon_sym_clocking] = ACTIONS(4888),
    [anon_sym_defparam] = ACTIONS(4888),
    [anon_sym_bind] = ACTIONS(4888),
    [anon_sym_rand] = ACTIONS(4888),
    [anon_sym_const] = ACTIONS(4888),
    [anon_sym_function] = ACTIONS(4888),
    [anon_sym_static] = ACTIONS(4888),
    [anon_sym_constraint] = ACTIONS(4888),
    [anon_sym_if] = ACTIONS(4888),
    [anon_sym_else] = ACTIONS(4888),
    [anon_sym_LBRACK] = ACTIONS(4886),
    [anon_sym_localparam] = ACTIONS(4888),
    [anon_sym_parameter] = ACTIONS(4888),
    [anon_sym_var] = ACTIONS(4888),
    [anon_sym_import] = ACTIONS(4888),
    [anon_sym_export] = ACTIONS(4888),
    [anon_sym_genvar] = ACTIONS(4888),
    [anon_sym_interconnect] = ACTIONS(4888),
    [anon_sym_typedef] = ACTIONS(4888),
    [anon_sym_enum] = ACTIONS(4888),
    [anon_sym_struct] = ACTIONS(4888),
    [anon_sym_union] = ACTIONS(4888),
    [anon_sym_nettype] = ACTIONS(4888),
    [anon_sym_automatic] = ACTIONS(4888),
    [anon_sym_string] = ACTIONS(4888),
    [anon_sym_chandle] = ACTIONS(4888),
    [anon_sym_event] = ACTIONS(4888),
    [anon_sym_byte] = ACTIONS(4888),
    [anon_sym_shortint] = ACTIONS(4888),
    [anon_sym_int] = ACTIONS(4888),
    [anon_sym_longint] = ACTIONS(4888),
    [anon_sym_integer] = ACTIONS(4888),
    [anon_sym_time] = ACTIONS(4888),
    [anon_sym_bit] = ACTIONS(4888),
    [anon_sym_logic] = ACTIONS(4888),
    [anon_sym_reg] = ACTIONS(4888),
    [anon_sym_shortreal] = ACTIONS(4888),
    [anon_sym_real] = ACTIONS(4888),
    [anon_sym_realtime] = ACTIONS(4888),
    [anon_sym_supply0] = ACTIONS(4888),
    [anon_sym_supply1] = ACTIONS(4888),
    [anon_sym_signed] = ACTIONS(4888),
    [anon_sym_unsigned] = ACTIONS(4888),
    [anon_sym_task] = ACTIONS(4888),
    [anon_sym_assert] = ACTIONS(4888),
    [anon_sym_property] = ACTIONS(4888),
    [anon_sym_assume] = ACTIONS(4888),
    [anon_sym_cover] = ACTIONS(4888),
    [anon_sym_sequence] = ACTIONS(4888),
    [anon_sym_restrict] = ACTIONS(4888),
    [anon_sym_not] = ACTIONS(4888),
    [anon_sym_or] = ACTIONS(4888),
    [anon_sym_and] = ACTIONS(4888),
    [anon_sym_case] = ACTIONS(4888),
    [anon_sym_always] = ACTIONS(4888),
    [anon_sym_covergroup] = ACTIONS(4888),
    [anon_sym_end] = ACTIONS(4888),
    [anon_sym_let] = ACTIONS(4888),
    [anon_sym_pulldown] = ACTIONS(4888),
    [anon_sym_pullup] = ACTIONS(4888),
    [anon_sym_cmos] = ACTIONS(4888),
    [anon_sym_rcmos] = ACTIONS(4888),
    [anon_sym_bufif0] = ACTIONS(4888),
    [anon_sym_bufif1] = ACTIONS(4888),
    [anon_sym_notif0] = ACTIONS(4888),
    [anon_sym_notif1] = ACTIONS(4888),
    [anon_sym_nmos] = ACTIONS(4888),
    [anon_sym_pmos] = ACTIONS(4888),
    [anon_sym_rnmos] = ACTIONS(4888),
    [anon_sym_rpmos] = ACTIONS(4888),
    [anon_sym_nand] = ACTIONS(4888),
    [anon_sym_nor] = ACTIONS(4888),
    [anon_sym_xor] = ACTIONS(4888),
    [anon_sym_xnor] = ACTIONS(4888),
    [anon_sym_buf] = ACTIONS(4888),
    [anon_sym_tranif0] = ACTIONS(4888),
    [anon_sym_tranif1] = ACTIONS(4888),
    [anon_sym_rtranif1] = ACTIONS(4888),
    [anon_sym_rtranif0] = ACTIONS(4888),
    [anon_sym_tran] = ACTIONS(4888),
    [anon_sym_rtran] = ACTIONS(4888),
    [anon_sym_generate] = ACTIONS(4888),
    [anon_sym_for] = ACTIONS(4888),
    [anon_sym_initial] = ACTIONS(4888),
    [anon_sym_assign] = ACTIONS(4888),
    [anon_sym_alias] = ACTIONS(4888),
    [anon_sym_always_comb] = ACTIONS(4888),
    [anon_sym_always_latch] = ACTIONS(4888),
    [anon_sym_always_ff] = ACTIONS(4888),
    [anon_sym_final] = ACTIONS(4888),
    [anon_sym_global] = ACTIONS(4888),
    [anon_sym_LPAREN_STAR] = ACTIONS(4886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4886),
    [anon_sym_DOLLARunit] = ACTIONS(4886),
  },
  [4688] = {
    [sym_simple_identifier] = ACTIONS(4968),
    [anon_sym_wire] = ACTIONS(4968),
    [anon_sym_tri] = ACTIONS(4968),
    [anon_sym_tri0] = ACTIONS(4968),
    [anon_sym_tri1] = ACTIONS(4968),
    [anon_sym_wand] = ACTIONS(4968),
    [anon_sym_triand] = ACTIONS(4968),
    [anon_sym_wor] = ACTIONS(4968),
    [anon_sym_trior] = ACTIONS(4968),
    [anon_sym_trireg] = ACTIONS(4968),
    [anon_sym_uwire] = ACTIONS(4968),
    [anon_sym_SEMI] = ACTIONS(4966),
    [anon_sym_extern] = ACTIONS(4968),
    [anon_sym_interface] = ACTIONS(4968),
    [anon_sym_checker] = ACTIONS(4968),
    [anon_sym_virtual] = ACTIONS(4968),
    [anon_sym_class] = ACTIONS(4968),
    [anon_sym_type] = ACTIONS(4968),
    [anon_sym_DOLLARfatal] = ACTIONS(4966),
    [anon_sym_DOLLARerror] = ACTIONS(4966),
    [anon_sym_DOLLARwarning] = ACTIONS(4966),
    [anon_sym_DOLLARinfo] = ACTIONS(4966),
    [anon_sym_default] = ACTIONS(4968),
    [anon_sym_clocking] = ACTIONS(4968),
    [anon_sym_defparam] = ACTIONS(4968),
    [anon_sym_bind] = ACTIONS(4968),
    [anon_sym_rand] = ACTIONS(4968),
    [anon_sym_const] = ACTIONS(4968),
    [anon_sym_function] = ACTIONS(4968),
    [anon_sym_static] = ACTIONS(4968),
    [anon_sym_constraint] = ACTIONS(4968),
    [anon_sym_if] = ACTIONS(4968),
    [anon_sym_else] = ACTIONS(4968),
    [anon_sym_LBRACK] = ACTIONS(4966),
    [anon_sym_localparam] = ACTIONS(4968),
    [anon_sym_parameter] = ACTIONS(4968),
    [anon_sym_var] = ACTIONS(4968),
    [anon_sym_import] = ACTIONS(4968),
    [anon_sym_export] = ACTIONS(4968),
    [anon_sym_genvar] = ACTIONS(4968),
    [anon_sym_interconnect] = ACTIONS(4968),
    [anon_sym_typedef] = ACTIONS(4968),
    [anon_sym_enum] = ACTIONS(4968),
    [anon_sym_struct] = ACTIONS(4968),
    [anon_sym_union] = ACTIONS(4968),
    [anon_sym_nettype] = ACTIONS(4968),
    [anon_sym_automatic] = ACTIONS(4968),
    [anon_sym_string] = ACTIONS(4968),
    [anon_sym_chandle] = ACTIONS(4968),
    [anon_sym_event] = ACTIONS(4968),
    [anon_sym_byte] = ACTIONS(4968),
    [anon_sym_shortint] = ACTIONS(4968),
    [anon_sym_int] = ACTIONS(4968),
    [anon_sym_longint] = ACTIONS(4968),
    [anon_sym_integer] = ACTIONS(4968),
    [anon_sym_time] = ACTIONS(4968),
    [anon_sym_bit] = ACTIONS(4968),
    [anon_sym_logic] = ACTIONS(4968),
    [anon_sym_reg] = ACTIONS(4968),
    [anon_sym_shortreal] = ACTIONS(4968),
    [anon_sym_real] = ACTIONS(4968),
    [anon_sym_realtime] = ACTIONS(4968),
    [anon_sym_supply0] = ACTIONS(4968),
    [anon_sym_supply1] = ACTIONS(4968),
    [anon_sym_signed] = ACTIONS(4968),
    [anon_sym_unsigned] = ACTIONS(4968),
    [anon_sym_task] = ACTIONS(4968),
    [anon_sym_assert] = ACTIONS(4968),
    [anon_sym_property] = ACTIONS(4968),
    [anon_sym_assume] = ACTIONS(4968),
    [anon_sym_cover] = ACTIONS(4968),
    [anon_sym_sequence] = ACTIONS(4968),
    [anon_sym_restrict] = ACTIONS(4968),
    [anon_sym_not] = ACTIONS(4968),
    [anon_sym_or] = ACTIONS(4968),
    [anon_sym_and] = ACTIONS(4968),
    [anon_sym_case] = ACTIONS(4968),
    [anon_sym_always] = ACTIONS(4968),
    [anon_sym_covergroup] = ACTIONS(4968),
    [anon_sym_let] = ACTIONS(4968),
    [anon_sym_pulldown] = ACTIONS(4968),
    [anon_sym_pullup] = ACTIONS(4968),
    [anon_sym_cmos] = ACTIONS(4968),
    [anon_sym_rcmos] = ACTIONS(4968),
    [anon_sym_bufif0] = ACTIONS(4968),
    [anon_sym_bufif1] = ACTIONS(4968),
    [anon_sym_notif0] = ACTIONS(4968),
    [anon_sym_notif1] = ACTIONS(4968),
    [anon_sym_nmos] = ACTIONS(4968),
    [anon_sym_pmos] = ACTIONS(4968),
    [anon_sym_rnmos] = ACTIONS(4968),
    [anon_sym_rpmos] = ACTIONS(4968),
    [anon_sym_nand] = ACTIONS(4968),
    [anon_sym_nor] = ACTIONS(4968),
    [anon_sym_xor] = ACTIONS(4968),
    [anon_sym_xnor] = ACTIONS(4968),
    [anon_sym_buf] = ACTIONS(4968),
    [anon_sym_tranif0] = ACTIONS(4968),
    [anon_sym_tranif1] = ACTIONS(4968),
    [anon_sym_rtranif1] = ACTIONS(4968),
    [anon_sym_rtranif0] = ACTIONS(4968),
    [anon_sym_tran] = ACTIONS(4968),
    [anon_sym_rtran] = ACTIONS(4968),
    [anon_sym_generate] = ACTIONS(4968),
    [anon_sym_endgenerate] = ACTIONS(4968),
    [anon_sym_for] = ACTIONS(4968),
    [anon_sym_initial] = ACTIONS(4968),
    [anon_sym_assign] = ACTIONS(4968),
    [anon_sym_alias] = ACTIONS(4968),
    [anon_sym_always_comb] = ACTIONS(4968),
    [anon_sym_always_latch] = ACTIONS(4968),
    [anon_sym_always_ff] = ACTIONS(4968),
    [anon_sym_final] = ACTIONS(4968),
    [anon_sym_global] = ACTIONS(4968),
    [anon_sym_LPAREN_STAR] = ACTIONS(4966),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4966),
    [anon_sym_DOLLARunit] = ACTIONS(4966),
  },
  [4689] = {
    [sym_simple_identifier] = ACTIONS(6645),
    [anon_sym_wire] = ACTIONS(6645),
    [anon_sym_tri] = ACTIONS(6645),
    [anon_sym_tri0] = ACTIONS(6645),
    [anon_sym_tri1] = ACTIONS(6645),
    [anon_sym_wand] = ACTIONS(6645),
    [anon_sym_triand] = ACTIONS(6645),
    [anon_sym_wor] = ACTIONS(6645),
    [anon_sym_trior] = ACTIONS(6645),
    [anon_sym_trireg] = ACTIONS(6645),
    [anon_sym_uwire] = ACTIONS(6645),
    [anon_sym_SEMI] = ACTIONS(6649),
    [anon_sym_extern] = ACTIONS(6645),
    [anon_sym_interface] = ACTIONS(6645),
    [anon_sym_checker] = ACTIONS(6645),
    [anon_sym_virtual] = ACTIONS(6645),
    [anon_sym_class] = ACTIONS(6645),
    [anon_sym_type] = ACTIONS(6645),
    [anon_sym_DOLLARfatal] = ACTIONS(6649),
    [anon_sym_DOLLARerror] = ACTIONS(6649),
    [anon_sym_DOLLARwarning] = ACTIONS(6649),
    [anon_sym_DOLLARinfo] = ACTIONS(6649),
    [anon_sym_default] = ACTIONS(6645),
    [anon_sym_clocking] = ACTIONS(6645),
    [anon_sym_defparam] = ACTIONS(6645),
    [anon_sym_bind] = ACTIONS(6645),
    [anon_sym_rand] = ACTIONS(6645),
    [anon_sym_const] = ACTIONS(6645),
    [anon_sym_function] = ACTIONS(6645),
    [anon_sym_static] = ACTIONS(6645),
    [anon_sym_constraint] = ACTIONS(6645),
    [anon_sym_if] = ACTIONS(6645),
    [anon_sym_else] = ACTIONS(6645),
    [anon_sym_LBRACK] = ACTIONS(6649),
    [anon_sym_localparam] = ACTIONS(6645),
    [anon_sym_parameter] = ACTIONS(6645),
    [anon_sym_var] = ACTIONS(6645),
    [anon_sym_import] = ACTIONS(6645),
    [anon_sym_export] = ACTIONS(6645),
    [anon_sym_genvar] = ACTIONS(6645),
    [anon_sym_interconnect] = ACTIONS(6645),
    [anon_sym_typedef] = ACTIONS(6645),
    [anon_sym_enum] = ACTIONS(6645),
    [anon_sym_struct] = ACTIONS(6645),
    [anon_sym_union] = ACTIONS(6645),
    [anon_sym_nettype] = ACTIONS(6645),
    [anon_sym_automatic] = ACTIONS(6645),
    [anon_sym_string] = ACTIONS(6645),
    [anon_sym_chandle] = ACTIONS(6645),
    [anon_sym_event] = ACTIONS(6645),
    [anon_sym_byte] = ACTIONS(6645),
    [anon_sym_shortint] = ACTIONS(6645),
    [anon_sym_int] = ACTIONS(6645),
    [anon_sym_longint] = ACTIONS(6645),
    [anon_sym_integer] = ACTIONS(6645),
    [anon_sym_time] = ACTIONS(6645),
    [anon_sym_bit] = ACTIONS(6645),
    [anon_sym_logic] = ACTIONS(6645),
    [anon_sym_reg] = ACTIONS(6645),
    [anon_sym_shortreal] = ACTIONS(6645),
    [anon_sym_real] = ACTIONS(6645),
    [anon_sym_realtime] = ACTIONS(6645),
    [anon_sym_supply0] = ACTIONS(6645),
    [anon_sym_supply1] = ACTIONS(6645),
    [anon_sym_signed] = ACTIONS(6645),
    [anon_sym_unsigned] = ACTIONS(6645),
    [anon_sym_task] = ACTIONS(6645),
    [anon_sym_assert] = ACTIONS(6645),
    [anon_sym_property] = ACTIONS(6645),
    [anon_sym_assume] = ACTIONS(6645),
    [anon_sym_cover] = ACTIONS(6645),
    [anon_sym_sequence] = ACTIONS(6645),
    [anon_sym_restrict] = ACTIONS(6645),
    [anon_sym_not] = ACTIONS(6645),
    [anon_sym_or] = ACTIONS(6645),
    [anon_sym_and] = ACTIONS(6645),
    [anon_sym_case] = ACTIONS(6645),
    [anon_sym_always] = ACTIONS(6645),
    [anon_sym_covergroup] = ACTIONS(6645),
    [anon_sym_let] = ACTIONS(6645),
    [anon_sym_pulldown] = ACTIONS(6645),
    [anon_sym_pullup] = ACTIONS(6645),
    [anon_sym_cmos] = ACTIONS(6645),
    [anon_sym_rcmos] = ACTIONS(6645),
    [anon_sym_bufif0] = ACTIONS(6645),
    [anon_sym_bufif1] = ACTIONS(6645),
    [anon_sym_notif0] = ACTIONS(6645),
    [anon_sym_notif1] = ACTIONS(6645),
    [anon_sym_nmos] = ACTIONS(6645),
    [anon_sym_pmos] = ACTIONS(6645),
    [anon_sym_rnmos] = ACTIONS(6645),
    [anon_sym_rpmos] = ACTIONS(6645),
    [anon_sym_nand] = ACTIONS(6645),
    [anon_sym_nor] = ACTIONS(6645),
    [anon_sym_xor] = ACTIONS(6645),
    [anon_sym_xnor] = ACTIONS(6645),
    [anon_sym_buf] = ACTIONS(6645),
    [anon_sym_tranif0] = ACTIONS(6645),
    [anon_sym_tranif1] = ACTIONS(6645),
    [anon_sym_rtranif1] = ACTIONS(6645),
    [anon_sym_rtranif0] = ACTIONS(6645),
    [anon_sym_tran] = ACTIONS(6645),
    [anon_sym_rtran] = ACTIONS(6645),
    [anon_sym_generate] = ACTIONS(6645),
    [anon_sym_endgenerate] = ACTIONS(6645),
    [anon_sym_for] = ACTIONS(6645),
    [anon_sym_initial] = ACTIONS(6645),
    [anon_sym_assign] = ACTIONS(6645),
    [anon_sym_alias] = ACTIONS(6645),
    [anon_sym_always_comb] = ACTIONS(6645),
    [anon_sym_always_latch] = ACTIONS(6645),
    [anon_sym_always_ff] = ACTIONS(6645),
    [anon_sym_final] = ACTIONS(6645),
    [anon_sym_global] = ACTIONS(6645),
    [anon_sym_LPAREN_STAR] = ACTIONS(6649),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6649),
    [anon_sym_DOLLARunit] = ACTIONS(6649),
  },
  [4690] = {
    [sym_simple_identifier] = ACTIONS(4784),
    [anon_sym_wire] = ACTIONS(4784),
    [anon_sym_tri] = ACTIONS(4784),
    [anon_sym_tri0] = ACTIONS(4784),
    [anon_sym_tri1] = ACTIONS(4784),
    [anon_sym_wand] = ACTIONS(4784),
    [anon_sym_triand] = ACTIONS(4784),
    [anon_sym_wor] = ACTIONS(4784),
    [anon_sym_trior] = ACTIONS(4784),
    [anon_sym_trireg] = ACTIONS(4784),
    [anon_sym_uwire] = ACTIONS(4784),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_extern] = ACTIONS(4784),
    [anon_sym_interface] = ACTIONS(4784),
    [anon_sym_checker] = ACTIONS(4784),
    [anon_sym_virtual] = ACTIONS(4784),
    [anon_sym_class] = ACTIONS(4784),
    [anon_sym_type] = ACTIONS(4784),
    [anon_sym_DOLLARfatal] = ACTIONS(4782),
    [anon_sym_DOLLARerror] = ACTIONS(4782),
    [anon_sym_DOLLARwarning] = ACTIONS(4782),
    [anon_sym_DOLLARinfo] = ACTIONS(4782),
    [anon_sym_default] = ACTIONS(4784),
    [anon_sym_clocking] = ACTIONS(4784),
    [anon_sym_defparam] = ACTIONS(4784),
    [anon_sym_bind] = ACTIONS(4784),
    [anon_sym_rand] = ACTIONS(4784),
    [anon_sym_const] = ACTIONS(4784),
    [anon_sym_function] = ACTIONS(4784),
    [anon_sym_static] = ACTIONS(4784),
    [anon_sym_constraint] = ACTIONS(4784),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [anon_sym_localparam] = ACTIONS(4784),
    [anon_sym_parameter] = ACTIONS(4784),
    [anon_sym_var] = ACTIONS(4784),
    [anon_sym_import] = ACTIONS(4784),
    [anon_sym_export] = ACTIONS(4784),
    [anon_sym_genvar] = ACTIONS(4784),
    [anon_sym_interconnect] = ACTIONS(4784),
    [anon_sym_typedef] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_struct] = ACTIONS(4784),
    [anon_sym_union] = ACTIONS(4784),
    [anon_sym_nettype] = ACTIONS(4784),
    [anon_sym_automatic] = ACTIONS(4784),
    [anon_sym_string] = ACTIONS(4784),
    [anon_sym_chandle] = ACTIONS(4784),
    [anon_sym_event] = ACTIONS(4784),
    [anon_sym_byte] = ACTIONS(4784),
    [anon_sym_shortint] = ACTIONS(4784),
    [anon_sym_int] = ACTIONS(4784),
    [anon_sym_longint] = ACTIONS(4784),
    [anon_sym_integer] = ACTIONS(4784),
    [anon_sym_time] = ACTIONS(4784),
    [anon_sym_bit] = ACTIONS(4784),
    [anon_sym_logic] = ACTIONS(4784),
    [anon_sym_reg] = ACTIONS(4784),
    [anon_sym_shortreal] = ACTIONS(4784),
    [anon_sym_real] = ACTIONS(4784),
    [anon_sym_realtime] = ACTIONS(4784),
    [anon_sym_supply0] = ACTIONS(4784),
    [anon_sym_supply1] = ACTIONS(4784),
    [anon_sym_signed] = ACTIONS(4784),
    [anon_sym_unsigned] = ACTIONS(4784),
    [anon_sym_task] = ACTIONS(4784),
    [anon_sym_assert] = ACTIONS(4784),
    [anon_sym_property] = ACTIONS(4784),
    [anon_sym_assume] = ACTIONS(4784),
    [anon_sym_cover] = ACTIONS(4784),
    [anon_sym_sequence] = ACTIONS(4784),
    [anon_sym_restrict] = ACTIONS(4784),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_or] = ACTIONS(4784),
    [anon_sym_and] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_always] = ACTIONS(4784),
    [anon_sym_covergroup] = ACTIONS(4784),
    [anon_sym_end] = ACTIONS(4784),
    [anon_sym_let] = ACTIONS(4784),
    [anon_sym_pulldown] = ACTIONS(4784),
    [anon_sym_pullup] = ACTIONS(4784),
    [anon_sym_cmos] = ACTIONS(4784),
    [anon_sym_rcmos] = ACTIONS(4784),
    [anon_sym_bufif0] = ACTIONS(4784),
    [anon_sym_bufif1] = ACTIONS(4784),
    [anon_sym_notif0] = ACTIONS(4784),
    [anon_sym_notif1] = ACTIONS(4784),
    [anon_sym_nmos] = ACTIONS(4784),
    [anon_sym_pmos] = ACTIONS(4784),
    [anon_sym_rnmos] = ACTIONS(4784),
    [anon_sym_rpmos] = ACTIONS(4784),
    [anon_sym_nand] = ACTIONS(4784),
    [anon_sym_nor] = ACTIONS(4784),
    [anon_sym_xor] = ACTIONS(4784),
    [anon_sym_xnor] = ACTIONS(4784),
    [anon_sym_buf] = ACTIONS(4784),
    [anon_sym_tranif0] = ACTIONS(4784),
    [anon_sym_tranif1] = ACTIONS(4784),
    [anon_sym_rtranif1] = ACTIONS(4784),
    [anon_sym_rtranif0] = ACTIONS(4784),
    [anon_sym_tran] = ACTIONS(4784),
    [anon_sym_rtran] = ACTIONS(4784),
    [anon_sym_generate] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_initial] = ACTIONS(4784),
    [anon_sym_assign] = ACTIONS(4784),
    [anon_sym_alias] = ACTIONS(4784),
    [anon_sym_always_comb] = ACTIONS(4784),
    [anon_sym_always_latch] = ACTIONS(4784),
    [anon_sym_always_ff] = ACTIONS(4784),
    [anon_sym_final] = ACTIONS(4784),
    [anon_sym_global] = ACTIONS(4784),
    [anon_sym_LPAREN_STAR] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4782),
    [anon_sym_DOLLARunit] = ACTIONS(4782),
  },
  [4691] = {
    [sym_simple_identifier] = ACTIONS(6011),
    [anon_sym_wire] = ACTIONS(6011),
    [anon_sym_tri] = ACTIONS(6011),
    [anon_sym_tri0] = ACTIONS(6011),
    [anon_sym_tri1] = ACTIONS(6011),
    [anon_sym_wand] = ACTIONS(6011),
    [anon_sym_triand] = ACTIONS(6011),
    [anon_sym_wor] = ACTIONS(6011),
    [anon_sym_trior] = ACTIONS(6011),
    [anon_sym_trireg] = ACTIONS(6011),
    [anon_sym_uwire] = ACTIONS(6011),
    [anon_sym_SEMI] = ACTIONS(6013),
    [anon_sym_extern] = ACTIONS(6011),
    [anon_sym_interface] = ACTIONS(6011),
    [anon_sym_checker] = ACTIONS(6011),
    [anon_sym_virtual] = ACTIONS(6011),
    [anon_sym_class] = ACTIONS(6011),
    [anon_sym_type] = ACTIONS(6011),
    [anon_sym_DOLLARfatal] = ACTIONS(6013),
    [anon_sym_DOLLARerror] = ACTIONS(6013),
    [anon_sym_DOLLARwarning] = ACTIONS(6013),
    [anon_sym_DOLLARinfo] = ACTIONS(6013),
    [anon_sym_default] = ACTIONS(6011),
    [anon_sym_clocking] = ACTIONS(6011),
    [anon_sym_defparam] = ACTIONS(6011),
    [anon_sym_bind] = ACTIONS(6011),
    [anon_sym_rand] = ACTIONS(6011),
    [anon_sym_const] = ACTIONS(6011),
    [anon_sym_function] = ACTIONS(6011),
    [anon_sym_static] = ACTIONS(6011),
    [anon_sym_constraint] = ACTIONS(6011),
    [anon_sym_if] = ACTIONS(6011),
    [anon_sym_else] = ACTIONS(6011),
    [anon_sym_LBRACK] = ACTIONS(6013),
    [anon_sym_localparam] = ACTIONS(6011),
    [anon_sym_parameter] = ACTIONS(6011),
    [anon_sym_var] = ACTIONS(6011),
    [anon_sym_import] = ACTIONS(6011),
    [anon_sym_export] = ACTIONS(6011),
    [anon_sym_genvar] = ACTIONS(6011),
    [anon_sym_interconnect] = ACTIONS(6011),
    [anon_sym_typedef] = ACTIONS(6011),
    [anon_sym_enum] = ACTIONS(6011),
    [anon_sym_struct] = ACTIONS(6011),
    [anon_sym_union] = ACTIONS(6011),
    [anon_sym_nettype] = ACTIONS(6011),
    [anon_sym_automatic] = ACTIONS(6011),
    [anon_sym_string] = ACTIONS(6011),
    [anon_sym_chandle] = ACTIONS(6011),
    [anon_sym_event] = ACTIONS(6011),
    [anon_sym_byte] = ACTIONS(6011),
    [anon_sym_shortint] = ACTIONS(6011),
    [anon_sym_int] = ACTIONS(6011),
    [anon_sym_longint] = ACTIONS(6011),
    [anon_sym_integer] = ACTIONS(6011),
    [anon_sym_time] = ACTIONS(6011),
    [anon_sym_bit] = ACTIONS(6011),
    [anon_sym_logic] = ACTIONS(6011),
    [anon_sym_reg] = ACTIONS(6011),
    [anon_sym_shortreal] = ACTIONS(6011),
    [anon_sym_real] = ACTIONS(6011),
    [anon_sym_realtime] = ACTIONS(6011),
    [anon_sym_supply0] = ACTIONS(6011),
    [anon_sym_supply1] = ACTIONS(6011),
    [anon_sym_signed] = ACTIONS(6011),
    [anon_sym_unsigned] = ACTIONS(6011),
    [anon_sym_task] = ACTIONS(6011),
    [anon_sym_assert] = ACTIONS(6011),
    [anon_sym_property] = ACTIONS(6011),
    [anon_sym_assume] = ACTIONS(6011),
    [anon_sym_cover] = ACTIONS(6011),
    [anon_sym_sequence] = ACTIONS(6011),
    [anon_sym_restrict] = ACTIONS(6011),
    [anon_sym_not] = ACTIONS(6011),
    [anon_sym_or] = ACTIONS(6011),
    [anon_sym_and] = ACTIONS(6011),
    [anon_sym_case] = ACTIONS(6011),
    [anon_sym_always] = ACTIONS(6011),
    [anon_sym_covergroup] = ACTIONS(6011),
    [anon_sym_end] = ACTIONS(6011),
    [anon_sym_let] = ACTIONS(6011),
    [anon_sym_pulldown] = ACTIONS(6011),
    [anon_sym_pullup] = ACTIONS(6011),
    [anon_sym_cmos] = ACTIONS(6011),
    [anon_sym_rcmos] = ACTIONS(6011),
    [anon_sym_bufif0] = ACTIONS(6011),
    [anon_sym_bufif1] = ACTIONS(6011),
    [anon_sym_notif0] = ACTIONS(6011),
    [anon_sym_notif1] = ACTIONS(6011),
    [anon_sym_nmos] = ACTIONS(6011),
    [anon_sym_pmos] = ACTIONS(6011),
    [anon_sym_rnmos] = ACTIONS(6011),
    [anon_sym_rpmos] = ACTIONS(6011),
    [anon_sym_nand] = ACTIONS(6011),
    [anon_sym_nor] = ACTIONS(6011),
    [anon_sym_xor] = ACTIONS(6011),
    [anon_sym_xnor] = ACTIONS(6011),
    [anon_sym_buf] = ACTIONS(6011),
    [anon_sym_tranif0] = ACTIONS(6011),
    [anon_sym_tranif1] = ACTIONS(6011),
    [anon_sym_rtranif1] = ACTIONS(6011),
    [anon_sym_rtranif0] = ACTIONS(6011),
    [anon_sym_tran] = ACTIONS(6011),
    [anon_sym_rtran] = ACTIONS(6011),
    [anon_sym_generate] = ACTIONS(6011),
    [anon_sym_for] = ACTIONS(6011),
    [anon_sym_initial] = ACTIONS(6011),
    [anon_sym_assign] = ACTIONS(6011),
    [anon_sym_alias] = ACTIONS(6011),
    [anon_sym_always_comb] = ACTIONS(6011),
    [anon_sym_always_latch] = ACTIONS(6011),
    [anon_sym_always_ff] = ACTIONS(6011),
    [anon_sym_final] = ACTIONS(6011),
    [anon_sym_global] = ACTIONS(6011),
    [anon_sym_LPAREN_STAR] = ACTIONS(6013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6013),
    [anon_sym_DOLLARunit] = ACTIONS(6013),
  },
  [4692] = {
    [sym_simple_identifier] = ACTIONS(6097),
    [anon_sym_wire] = ACTIONS(6097),
    [anon_sym_tri] = ACTIONS(6097),
    [anon_sym_tri0] = ACTIONS(6097),
    [anon_sym_tri1] = ACTIONS(6097),
    [anon_sym_wand] = ACTIONS(6097),
    [anon_sym_triand] = ACTIONS(6097),
    [anon_sym_wor] = ACTIONS(6097),
    [anon_sym_trior] = ACTIONS(6097),
    [anon_sym_trireg] = ACTIONS(6097),
    [anon_sym_uwire] = ACTIONS(6097),
    [anon_sym_SEMI] = ACTIONS(6099),
    [anon_sym_extern] = ACTIONS(6097),
    [anon_sym_interface] = ACTIONS(6097),
    [anon_sym_checker] = ACTIONS(6097),
    [anon_sym_virtual] = ACTIONS(6097),
    [anon_sym_class] = ACTIONS(6097),
    [anon_sym_type] = ACTIONS(6097),
    [anon_sym_DOLLARfatal] = ACTIONS(6099),
    [anon_sym_DOLLARerror] = ACTIONS(6099),
    [anon_sym_DOLLARwarning] = ACTIONS(6099),
    [anon_sym_DOLLARinfo] = ACTIONS(6099),
    [anon_sym_default] = ACTIONS(6097),
    [anon_sym_clocking] = ACTIONS(6097),
    [anon_sym_defparam] = ACTIONS(6097),
    [anon_sym_bind] = ACTIONS(6097),
    [anon_sym_rand] = ACTIONS(6097),
    [anon_sym_const] = ACTIONS(6097),
    [anon_sym_function] = ACTIONS(6097),
    [anon_sym_static] = ACTIONS(6097),
    [anon_sym_constraint] = ACTIONS(6097),
    [anon_sym_if] = ACTIONS(6097),
    [anon_sym_else] = ACTIONS(6097),
    [anon_sym_LBRACK] = ACTIONS(6099),
    [anon_sym_localparam] = ACTIONS(6097),
    [anon_sym_parameter] = ACTIONS(6097),
    [anon_sym_var] = ACTIONS(6097),
    [anon_sym_import] = ACTIONS(6097),
    [anon_sym_export] = ACTIONS(6097),
    [anon_sym_genvar] = ACTIONS(6097),
    [anon_sym_interconnect] = ACTIONS(6097),
    [anon_sym_typedef] = ACTIONS(6097),
    [anon_sym_enum] = ACTIONS(6097),
    [anon_sym_struct] = ACTIONS(6097),
    [anon_sym_union] = ACTIONS(6097),
    [anon_sym_nettype] = ACTIONS(6097),
    [anon_sym_automatic] = ACTIONS(6097),
    [anon_sym_string] = ACTIONS(6097),
    [anon_sym_chandle] = ACTIONS(6097),
    [anon_sym_event] = ACTIONS(6097),
    [anon_sym_byte] = ACTIONS(6097),
    [anon_sym_shortint] = ACTIONS(6097),
    [anon_sym_int] = ACTIONS(6097),
    [anon_sym_longint] = ACTIONS(6097),
    [anon_sym_integer] = ACTIONS(6097),
    [anon_sym_time] = ACTIONS(6097),
    [anon_sym_bit] = ACTIONS(6097),
    [anon_sym_logic] = ACTIONS(6097),
    [anon_sym_reg] = ACTIONS(6097),
    [anon_sym_shortreal] = ACTIONS(6097),
    [anon_sym_real] = ACTIONS(6097),
    [anon_sym_realtime] = ACTIONS(6097),
    [anon_sym_supply0] = ACTIONS(6097),
    [anon_sym_supply1] = ACTIONS(6097),
    [anon_sym_signed] = ACTIONS(6097),
    [anon_sym_unsigned] = ACTIONS(6097),
    [anon_sym_task] = ACTIONS(6097),
    [anon_sym_assert] = ACTIONS(6097),
    [anon_sym_property] = ACTIONS(6097),
    [anon_sym_assume] = ACTIONS(6097),
    [anon_sym_cover] = ACTIONS(6097),
    [anon_sym_sequence] = ACTIONS(6097),
    [anon_sym_restrict] = ACTIONS(6097),
    [anon_sym_not] = ACTIONS(6097),
    [anon_sym_or] = ACTIONS(6097),
    [anon_sym_and] = ACTIONS(6097),
    [anon_sym_case] = ACTIONS(6097),
    [anon_sym_always] = ACTIONS(6097),
    [anon_sym_covergroup] = ACTIONS(6097),
    [anon_sym_end] = ACTIONS(6097),
    [anon_sym_let] = ACTIONS(6097),
    [anon_sym_pulldown] = ACTIONS(6097),
    [anon_sym_pullup] = ACTIONS(6097),
    [anon_sym_cmos] = ACTIONS(6097),
    [anon_sym_rcmos] = ACTIONS(6097),
    [anon_sym_bufif0] = ACTIONS(6097),
    [anon_sym_bufif1] = ACTIONS(6097),
    [anon_sym_notif0] = ACTIONS(6097),
    [anon_sym_notif1] = ACTIONS(6097),
    [anon_sym_nmos] = ACTIONS(6097),
    [anon_sym_pmos] = ACTIONS(6097),
    [anon_sym_rnmos] = ACTIONS(6097),
    [anon_sym_rpmos] = ACTIONS(6097),
    [anon_sym_nand] = ACTIONS(6097),
    [anon_sym_nor] = ACTIONS(6097),
    [anon_sym_xor] = ACTIONS(6097),
    [anon_sym_xnor] = ACTIONS(6097),
    [anon_sym_buf] = ACTIONS(6097),
    [anon_sym_tranif0] = ACTIONS(6097),
    [anon_sym_tranif1] = ACTIONS(6097),
    [anon_sym_rtranif1] = ACTIONS(6097),
    [anon_sym_rtranif0] = ACTIONS(6097),
    [anon_sym_tran] = ACTIONS(6097),
    [anon_sym_rtran] = ACTIONS(6097),
    [anon_sym_generate] = ACTIONS(6097),
    [anon_sym_for] = ACTIONS(6097),
    [anon_sym_initial] = ACTIONS(6097),
    [anon_sym_assign] = ACTIONS(6097),
    [anon_sym_alias] = ACTIONS(6097),
    [anon_sym_always_comb] = ACTIONS(6097),
    [anon_sym_always_latch] = ACTIONS(6097),
    [anon_sym_always_ff] = ACTIONS(6097),
    [anon_sym_final] = ACTIONS(6097),
    [anon_sym_global] = ACTIONS(6097),
    [anon_sym_LPAREN_STAR] = ACTIONS(6099),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6099),
    [anon_sym_DOLLARunit] = ACTIONS(6099),
  },
  [4693] = {
    [sym_simple_identifier] = ACTIONS(6475),
    [anon_sym_wire] = ACTIONS(6475),
    [anon_sym_tri] = ACTIONS(6475),
    [anon_sym_tri0] = ACTIONS(6475),
    [anon_sym_tri1] = ACTIONS(6475),
    [anon_sym_wand] = ACTIONS(6475),
    [anon_sym_triand] = ACTIONS(6475),
    [anon_sym_wor] = ACTIONS(6475),
    [anon_sym_trior] = ACTIONS(6475),
    [anon_sym_trireg] = ACTIONS(6475),
    [anon_sym_uwire] = ACTIONS(6475),
    [anon_sym_SEMI] = ACTIONS(6477),
    [anon_sym_extern] = ACTIONS(6475),
    [anon_sym_interface] = ACTIONS(6475),
    [anon_sym_checker] = ACTIONS(6475),
    [anon_sym_virtual] = ACTIONS(6475),
    [anon_sym_class] = ACTIONS(6475),
    [anon_sym_type] = ACTIONS(6475),
    [anon_sym_DOLLARfatal] = ACTIONS(6477),
    [anon_sym_DOLLARerror] = ACTIONS(6477),
    [anon_sym_DOLLARwarning] = ACTIONS(6477),
    [anon_sym_DOLLARinfo] = ACTIONS(6477),
    [anon_sym_default] = ACTIONS(6475),
    [anon_sym_clocking] = ACTIONS(6475),
    [anon_sym_defparam] = ACTIONS(6475),
    [anon_sym_bind] = ACTIONS(6475),
    [anon_sym_rand] = ACTIONS(6475),
    [anon_sym_const] = ACTIONS(6475),
    [anon_sym_function] = ACTIONS(6475),
    [anon_sym_static] = ACTIONS(6475),
    [anon_sym_constraint] = ACTIONS(6475),
    [anon_sym_if] = ACTIONS(6475),
    [anon_sym_else] = ACTIONS(6475),
    [anon_sym_LBRACK] = ACTIONS(6477),
    [anon_sym_localparam] = ACTIONS(6475),
    [anon_sym_parameter] = ACTIONS(6475),
    [anon_sym_var] = ACTIONS(6475),
    [anon_sym_import] = ACTIONS(6475),
    [anon_sym_export] = ACTIONS(6475),
    [anon_sym_genvar] = ACTIONS(6475),
    [anon_sym_interconnect] = ACTIONS(6475),
    [anon_sym_typedef] = ACTIONS(6475),
    [anon_sym_enum] = ACTIONS(6475),
    [anon_sym_struct] = ACTIONS(6475),
    [anon_sym_union] = ACTIONS(6475),
    [anon_sym_nettype] = ACTIONS(6475),
    [anon_sym_automatic] = ACTIONS(6475),
    [anon_sym_string] = ACTIONS(6475),
    [anon_sym_chandle] = ACTIONS(6475),
    [anon_sym_event] = ACTIONS(6475),
    [anon_sym_byte] = ACTIONS(6475),
    [anon_sym_shortint] = ACTIONS(6475),
    [anon_sym_int] = ACTIONS(6475),
    [anon_sym_longint] = ACTIONS(6475),
    [anon_sym_integer] = ACTIONS(6475),
    [anon_sym_time] = ACTIONS(6475),
    [anon_sym_bit] = ACTIONS(6475),
    [anon_sym_logic] = ACTIONS(6475),
    [anon_sym_reg] = ACTIONS(6475),
    [anon_sym_shortreal] = ACTIONS(6475),
    [anon_sym_real] = ACTIONS(6475),
    [anon_sym_realtime] = ACTIONS(6475),
    [anon_sym_supply0] = ACTIONS(6475),
    [anon_sym_supply1] = ACTIONS(6475),
    [anon_sym_signed] = ACTIONS(6475),
    [anon_sym_unsigned] = ACTIONS(6475),
    [anon_sym_task] = ACTIONS(6475),
    [anon_sym_assert] = ACTIONS(6475),
    [anon_sym_property] = ACTIONS(6475),
    [anon_sym_assume] = ACTIONS(6475),
    [anon_sym_cover] = ACTIONS(6475),
    [anon_sym_sequence] = ACTIONS(6475),
    [anon_sym_restrict] = ACTIONS(6475),
    [anon_sym_not] = ACTIONS(6475),
    [anon_sym_or] = ACTIONS(6475),
    [anon_sym_and] = ACTIONS(6475),
    [anon_sym_case] = ACTIONS(6475),
    [anon_sym_always] = ACTIONS(6475),
    [anon_sym_covergroup] = ACTIONS(6475),
    [anon_sym_let] = ACTIONS(6475),
    [anon_sym_pulldown] = ACTIONS(6475),
    [anon_sym_pullup] = ACTIONS(6475),
    [anon_sym_cmos] = ACTIONS(6475),
    [anon_sym_rcmos] = ACTIONS(6475),
    [anon_sym_bufif0] = ACTIONS(6475),
    [anon_sym_bufif1] = ACTIONS(6475),
    [anon_sym_notif0] = ACTIONS(6475),
    [anon_sym_notif1] = ACTIONS(6475),
    [anon_sym_nmos] = ACTIONS(6475),
    [anon_sym_pmos] = ACTIONS(6475),
    [anon_sym_rnmos] = ACTIONS(6475),
    [anon_sym_rpmos] = ACTIONS(6475),
    [anon_sym_nand] = ACTIONS(6475),
    [anon_sym_nor] = ACTIONS(6475),
    [anon_sym_xor] = ACTIONS(6475),
    [anon_sym_xnor] = ACTIONS(6475),
    [anon_sym_buf] = ACTIONS(6475),
    [anon_sym_tranif0] = ACTIONS(6475),
    [anon_sym_tranif1] = ACTIONS(6475),
    [anon_sym_rtranif1] = ACTIONS(6475),
    [anon_sym_rtranif0] = ACTIONS(6475),
    [anon_sym_tran] = ACTIONS(6475),
    [anon_sym_rtran] = ACTIONS(6475),
    [anon_sym_generate] = ACTIONS(6475),
    [anon_sym_endgenerate] = ACTIONS(6475),
    [anon_sym_for] = ACTIONS(6475),
    [anon_sym_initial] = ACTIONS(6475),
    [anon_sym_assign] = ACTIONS(6475),
    [anon_sym_alias] = ACTIONS(6475),
    [anon_sym_always_comb] = ACTIONS(6475),
    [anon_sym_always_latch] = ACTIONS(6475),
    [anon_sym_always_ff] = ACTIONS(6475),
    [anon_sym_final] = ACTIONS(6475),
    [anon_sym_global] = ACTIONS(6475),
    [anon_sym_LPAREN_STAR] = ACTIONS(6477),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6477),
    [anon_sym_DOLLARunit] = ACTIONS(6477),
  },
  [4694] = {
    [sym_simple_identifier] = ACTIONS(6015),
    [anon_sym_wire] = ACTIONS(6015),
    [anon_sym_tri] = ACTIONS(6015),
    [anon_sym_tri0] = ACTIONS(6015),
    [anon_sym_tri1] = ACTIONS(6015),
    [anon_sym_wand] = ACTIONS(6015),
    [anon_sym_triand] = ACTIONS(6015),
    [anon_sym_wor] = ACTIONS(6015),
    [anon_sym_trior] = ACTIONS(6015),
    [anon_sym_trireg] = ACTIONS(6015),
    [anon_sym_uwire] = ACTIONS(6015),
    [anon_sym_SEMI] = ACTIONS(6017),
    [anon_sym_extern] = ACTIONS(6015),
    [anon_sym_interface] = ACTIONS(6015),
    [anon_sym_checker] = ACTIONS(6015),
    [anon_sym_virtual] = ACTIONS(6015),
    [anon_sym_class] = ACTIONS(6015),
    [anon_sym_type] = ACTIONS(6015),
    [anon_sym_DOLLARfatal] = ACTIONS(6017),
    [anon_sym_DOLLARerror] = ACTIONS(6017),
    [anon_sym_DOLLARwarning] = ACTIONS(6017),
    [anon_sym_DOLLARinfo] = ACTIONS(6017),
    [anon_sym_default] = ACTIONS(6015),
    [anon_sym_clocking] = ACTIONS(6015),
    [anon_sym_defparam] = ACTIONS(6015),
    [anon_sym_bind] = ACTIONS(6015),
    [anon_sym_rand] = ACTIONS(6015),
    [anon_sym_const] = ACTIONS(6015),
    [anon_sym_function] = ACTIONS(6015),
    [anon_sym_static] = ACTIONS(6015),
    [anon_sym_constraint] = ACTIONS(6015),
    [anon_sym_if] = ACTIONS(6015),
    [anon_sym_else] = ACTIONS(6015),
    [anon_sym_LBRACK] = ACTIONS(6017),
    [anon_sym_localparam] = ACTIONS(6015),
    [anon_sym_parameter] = ACTIONS(6015),
    [anon_sym_var] = ACTIONS(6015),
    [anon_sym_import] = ACTIONS(6015),
    [anon_sym_export] = ACTIONS(6015),
    [anon_sym_genvar] = ACTIONS(6015),
    [anon_sym_interconnect] = ACTIONS(6015),
    [anon_sym_typedef] = ACTIONS(6015),
    [anon_sym_enum] = ACTIONS(6015),
    [anon_sym_struct] = ACTIONS(6015),
    [anon_sym_union] = ACTIONS(6015),
    [anon_sym_nettype] = ACTIONS(6015),
    [anon_sym_automatic] = ACTIONS(6015),
    [anon_sym_string] = ACTIONS(6015),
    [anon_sym_chandle] = ACTIONS(6015),
    [anon_sym_event] = ACTIONS(6015),
    [anon_sym_byte] = ACTIONS(6015),
    [anon_sym_shortint] = ACTIONS(6015),
    [anon_sym_int] = ACTIONS(6015),
    [anon_sym_longint] = ACTIONS(6015),
    [anon_sym_integer] = ACTIONS(6015),
    [anon_sym_time] = ACTIONS(6015),
    [anon_sym_bit] = ACTIONS(6015),
    [anon_sym_logic] = ACTIONS(6015),
    [anon_sym_reg] = ACTIONS(6015),
    [anon_sym_shortreal] = ACTIONS(6015),
    [anon_sym_real] = ACTIONS(6015),
    [anon_sym_realtime] = ACTIONS(6015),
    [anon_sym_supply0] = ACTIONS(6015),
    [anon_sym_supply1] = ACTIONS(6015),
    [anon_sym_signed] = ACTIONS(6015),
    [anon_sym_unsigned] = ACTIONS(6015),
    [anon_sym_task] = ACTIONS(6015),
    [anon_sym_assert] = ACTIONS(6015),
    [anon_sym_property] = ACTIONS(6015),
    [anon_sym_assume] = ACTIONS(6015),
    [anon_sym_cover] = ACTIONS(6015),
    [anon_sym_sequence] = ACTIONS(6015),
    [anon_sym_restrict] = ACTIONS(6015),
    [anon_sym_not] = ACTIONS(6015),
    [anon_sym_or] = ACTIONS(6015),
    [anon_sym_and] = ACTIONS(6015),
    [anon_sym_case] = ACTIONS(6015),
    [anon_sym_always] = ACTIONS(6015),
    [anon_sym_covergroup] = ACTIONS(6015),
    [anon_sym_end] = ACTIONS(6015),
    [anon_sym_let] = ACTIONS(6015),
    [anon_sym_pulldown] = ACTIONS(6015),
    [anon_sym_pullup] = ACTIONS(6015),
    [anon_sym_cmos] = ACTIONS(6015),
    [anon_sym_rcmos] = ACTIONS(6015),
    [anon_sym_bufif0] = ACTIONS(6015),
    [anon_sym_bufif1] = ACTIONS(6015),
    [anon_sym_notif0] = ACTIONS(6015),
    [anon_sym_notif1] = ACTIONS(6015),
    [anon_sym_nmos] = ACTIONS(6015),
    [anon_sym_pmos] = ACTIONS(6015),
    [anon_sym_rnmos] = ACTIONS(6015),
    [anon_sym_rpmos] = ACTIONS(6015),
    [anon_sym_nand] = ACTIONS(6015),
    [anon_sym_nor] = ACTIONS(6015),
    [anon_sym_xor] = ACTIONS(6015),
    [anon_sym_xnor] = ACTIONS(6015),
    [anon_sym_buf] = ACTIONS(6015),
    [anon_sym_tranif0] = ACTIONS(6015),
    [anon_sym_tranif1] = ACTIONS(6015),
    [anon_sym_rtranif1] = ACTIONS(6015),
    [anon_sym_rtranif0] = ACTIONS(6015),
    [anon_sym_tran] = ACTIONS(6015),
    [anon_sym_rtran] = ACTIONS(6015),
    [anon_sym_generate] = ACTIONS(6015),
    [anon_sym_for] = ACTIONS(6015),
    [anon_sym_initial] = ACTIONS(6015),
    [anon_sym_assign] = ACTIONS(6015),
    [anon_sym_alias] = ACTIONS(6015),
    [anon_sym_always_comb] = ACTIONS(6015),
    [anon_sym_always_latch] = ACTIONS(6015),
    [anon_sym_always_ff] = ACTIONS(6015),
    [anon_sym_final] = ACTIONS(6015),
    [anon_sym_global] = ACTIONS(6015),
    [anon_sym_LPAREN_STAR] = ACTIONS(6017),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6017),
    [anon_sym_DOLLARunit] = ACTIONS(6017),
  },
  [4695] = {
    [sym_simple_identifier] = ACTIONS(6249),
    [anon_sym_wire] = ACTIONS(6249),
    [anon_sym_tri] = ACTIONS(6249),
    [anon_sym_tri0] = ACTIONS(6249),
    [anon_sym_tri1] = ACTIONS(6249),
    [anon_sym_wand] = ACTIONS(6249),
    [anon_sym_triand] = ACTIONS(6249),
    [anon_sym_wor] = ACTIONS(6249),
    [anon_sym_trior] = ACTIONS(6249),
    [anon_sym_trireg] = ACTIONS(6249),
    [anon_sym_uwire] = ACTIONS(6249),
    [anon_sym_SEMI] = ACTIONS(6251),
    [anon_sym_extern] = ACTIONS(6249),
    [anon_sym_interface] = ACTIONS(6249),
    [anon_sym_checker] = ACTIONS(6249),
    [anon_sym_virtual] = ACTIONS(6249),
    [anon_sym_class] = ACTIONS(6249),
    [anon_sym_type] = ACTIONS(6249),
    [anon_sym_DOLLARfatal] = ACTIONS(6251),
    [anon_sym_DOLLARerror] = ACTIONS(6251),
    [anon_sym_DOLLARwarning] = ACTIONS(6251),
    [anon_sym_DOLLARinfo] = ACTIONS(6251),
    [anon_sym_default] = ACTIONS(6249),
    [anon_sym_clocking] = ACTIONS(6249),
    [anon_sym_defparam] = ACTIONS(6249),
    [anon_sym_bind] = ACTIONS(6249),
    [anon_sym_rand] = ACTIONS(6249),
    [anon_sym_const] = ACTIONS(6249),
    [anon_sym_function] = ACTIONS(6249),
    [anon_sym_static] = ACTIONS(6249),
    [anon_sym_constraint] = ACTIONS(6249),
    [anon_sym_if] = ACTIONS(6249),
    [anon_sym_else] = ACTIONS(6249),
    [anon_sym_LBRACK] = ACTIONS(6251),
    [anon_sym_localparam] = ACTIONS(6249),
    [anon_sym_parameter] = ACTIONS(6249),
    [anon_sym_var] = ACTIONS(6249),
    [anon_sym_import] = ACTIONS(6249),
    [anon_sym_export] = ACTIONS(6249),
    [anon_sym_genvar] = ACTIONS(6249),
    [anon_sym_interconnect] = ACTIONS(6249),
    [anon_sym_typedef] = ACTIONS(6249),
    [anon_sym_enum] = ACTIONS(6249),
    [anon_sym_struct] = ACTIONS(6249),
    [anon_sym_union] = ACTIONS(6249),
    [anon_sym_nettype] = ACTIONS(6249),
    [anon_sym_automatic] = ACTIONS(6249),
    [anon_sym_string] = ACTIONS(6249),
    [anon_sym_chandle] = ACTIONS(6249),
    [anon_sym_event] = ACTIONS(6249),
    [anon_sym_byte] = ACTIONS(6249),
    [anon_sym_shortint] = ACTIONS(6249),
    [anon_sym_int] = ACTIONS(6249),
    [anon_sym_longint] = ACTIONS(6249),
    [anon_sym_integer] = ACTIONS(6249),
    [anon_sym_time] = ACTIONS(6249),
    [anon_sym_bit] = ACTIONS(6249),
    [anon_sym_logic] = ACTIONS(6249),
    [anon_sym_reg] = ACTIONS(6249),
    [anon_sym_shortreal] = ACTIONS(6249),
    [anon_sym_real] = ACTIONS(6249),
    [anon_sym_realtime] = ACTIONS(6249),
    [anon_sym_supply0] = ACTIONS(6249),
    [anon_sym_supply1] = ACTIONS(6249),
    [anon_sym_signed] = ACTIONS(6249),
    [anon_sym_unsigned] = ACTIONS(6249),
    [anon_sym_task] = ACTIONS(6249),
    [anon_sym_assert] = ACTIONS(6249),
    [anon_sym_property] = ACTIONS(6249),
    [anon_sym_assume] = ACTIONS(6249),
    [anon_sym_cover] = ACTIONS(6249),
    [anon_sym_sequence] = ACTIONS(6249),
    [anon_sym_restrict] = ACTIONS(6249),
    [anon_sym_not] = ACTIONS(6249),
    [anon_sym_or] = ACTIONS(6249),
    [anon_sym_and] = ACTIONS(6249),
    [anon_sym_case] = ACTIONS(6249),
    [anon_sym_always] = ACTIONS(6249),
    [anon_sym_covergroup] = ACTIONS(6249),
    [anon_sym_end] = ACTIONS(6249),
    [anon_sym_let] = ACTIONS(6249),
    [anon_sym_pulldown] = ACTIONS(6249),
    [anon_sym_pullup] = ACTIONS(6249),
    [anon_sym_cmos] = ACTIONS(6249),
    [anon_sym_rcmos] = ACTIONS(6249),
    [anon_sym_bufif0] = ACTIONS(6249),
    [anon_sym_bufif1] = ACTIONS(6249),
    [anon_sym_notif0] = ACTIONS(6249),
    [anon_sym_notif1] = ACTIONS(6249),
    [anon_sym_nmos] = ACTIONS(6249),
    [anon_sym_pmos] = ACTIONS(6249),
    [anon_sym_rnmos] = ACTIONS(6249),
    [anon_sym_rpmos] = ACTIONS(6249),
    [anon_sym_nand] = ACTIONS(6249),
    [anon_sym_nor] = ACTIONS(6249),
    [anon_sym_xor] = ACTIONS(6249),
    [anon_sym_xnor] = ACTIONS(6249),
    [anon_sym_buf] = ACTIONS(6249),
    [anon_sym_tranif0] = ACTIONS(6249),
    [anon_sym_tranif1] = ACTIONS(6249),
    [anon_sym_rtranif1] = ACTIONS(6249),
    [anon_sym_rtranif0] = ACTIONS(6249),
    [anon_sym_tran] = ACTIONS(6249),
    [anon_sym_rtran] = ACTIONS(6249),
    [anon_sym_generate] = ACTIONS(6249),
    [anon_sym_for] = ACTIONS(6249),
    [anon_sym_initial] = ACTIONS(6249),
    [anon_sym_assign] = ACTIONS(6249),
    [anon_sym_alias] = ACTIONS(6249),
    [anon_sym_always_comb] = ACTIONS(6249),
    [anon_sym_always_latch] = ACTIONS(6249),
    [anon_sym_always_ff] = ACTIONS(6249),
    [anon_sym_final] = ACTIONS(6249),
    [anon_sym_global] = ACTIONS(6249),
    [anon_sym_LPAREN_STAR] = ACTIONS(6251),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6251),
    [anon_sym_DOLLARunit] = ACTIONS(6251),
  },
  [4696] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_rand] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_end] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [4697] = {
    [sym_simple_identifier] = ACTIONS(4948),
    [anon_sym_wire] = ACTIONS(4948),
    [anon_sym_tri] = ACTIONS(4948),
    [anon_sym_tri0] = ACTIONS(4948),
    [anon_sym_tri1] = ACTIONS(4948),
    [anon_sym_wand] = ACTIONS(4948),
    [anon_sym_triand] = ACTIONS(4948),
    [anon_sym_wor] = ACTIONS(4948),
    [anon_sym_trior] = ACTIONS(4948),
    [anon_sym_trireg] = ACTIONS(4948),
    [anon_sym_uwire] = ACTIONS(4948),
    [anon_sym_SEMI] = ACTIONS(4946),
    [anon_sym_extern] = ACTIONS(4948),
    [anon_sym_interface] = ACTIONS(4948),
    [anon_sym_checker] = ACTIONS(4948),
    [anon_sym_virtual] = ACTIONS(4948),
    [anon_sym_class] = ACTIONS(4948),
    [anon_sym_type] = ACTIONS(4948),
    [anon_sym_DOLLARfatal] = ACTIONS(4946),
    [anon_sym_DOLLARerror] = ACTIONS(4946),
    [anon_sym_DOLLARwarning] = ACTIONS(4946),
    [anon_sym_DOLLARinfo] = ACTIONS(4946),
    [anon_sym_default] = ACTIONS(4948),
    [anon_sym_clocking] = ACTIONS(4948),
    [anon_sym_defparam] = ACTIONS(4948),
    [anon_sym_bind] = ACTIONS(4948),
    [anon_sym_rand] = ACTIONS(4948),
    [anon_sym_const] = ACTIONS(4948),
    [anon_sym_function] = ACTIONS(4948),
    [anon_sym_static] = ACTIONS(4948),
    [anon_sym_constraint] = ACTIONS(4948),
    [anon_sym_if] = ACTIONS(4948),
    [anon_sym_else] = ACTIONS(4948),
    [anon_sym_LBRACK] = ACTIONS(4946),
    [anon_sym_localparam] = ACTIONS(4948),
    [anon_sym_parameter] = ACTIONS(4948),
    [anon_sym_var] = ACTIONS(4948),
    [anon_sym_import] = ACTIONS(4948),
    [anon_sym_export] = ACTIONS(4948),
    [anon_sym_genvar] = ACTIONS(4948),
    [anon_sym_interconnect] = ACTIONS(4948),
    [anon_sym_typedef] = ACTIONS(4948),
    [anon_sym_enum] = ACTIONS(4948),
    [anon_sym_struct] = ACTIONS(4948),
    [anon_sym_union] = ACTIONS(4948),
    [anon_sym_nettype] = ACTIONS(4948),
    [anon_sym_automatic] = ACTIONS(4948),
    [anon_sym_string] = ACTIONS(4948),
    [anon_sym_chandle] = ACTIONS(4948),
    [anon_sym_event] = ACTIONS(4948),
    [anon_sym_byte] = ACTIONS(4948),
    [anon_sym_shortint] = ACTIONS(4948),
    [anon_sym_int] = ACTIONS(4948),
    [anon_sym_longint] = ACTIONS(4948),
    [anon_sym_integer] = ACTIONS(4948),
    [anon_sym_time] = ACTIONS(4948),
    [anon_sym_bit] = ACTIONS(4948),
    [anon_sym_logic] = ACTIONS(4948),
    [anon_sym_reg] = ACTIONS(4948),
    [anon_sym_shortreal] = ACTIONS(4948),
    [anon_sym_real] = ACTIONS(4948),
    [anon_sym_realtime] = ACTIONS(4948),
    [anon_sym_supply0] = ACTIONS(4948),
    [anon_sym_supply1] = ACTIONS(4948),
    [anon_sym_signed] = ACTIONS(4948),
    [anon_sym_unsigned] = ACTIONS(4948),
    [anon_sym_task] = ACTIONS(4948),
    [anon_sym_assert] = ACTIONS(4948),
    [anon_sym_property] = ACTIONS(4948),
    [anon_sym_assume] = ACTIONS(4948),
    [anon_sym_cover] = ACTIONS(4948),
    [anon_sym_sequence] = ACTIONS(4948),
    [anon_sym_restrict] = ACTIONS(4948),
    [anon_sym_not] = ACTIONS(4948),
    [anon_sym_or] = ACTIONS(4948),
    [anon_sym_and] = ACTIONS(4948),
    [anon_sym_case] = ACTIONS(4948),
    [anon_sym_always] = ACTIONS(4948),
    [anon_sym_covergroup] = ACTIONS(4948),
    [anon_sym_end] = ACTIONS(4948),
    [anon_sym_let] = ACTIONS(4948),
    [anon_sym_pulldown] = ACTIONS(4948),
    [anon_sym_pullup] = ACTIONS(4948),
    [anon_sym_cmos] = ACTIONS(4948),
    [anon_sym_rcmos] = ACTIONS(4948),
    [anon_sym_bufif0] = ACTIONS(4948),
    [anon_sym_bufif1] = ACTIONS(4948),
    [anon_sym_notif0] = ACTIONS(4948),
    [anon_sym_notif1] = ACTIONS(4948),
    [anon_sym_nmos] = ACTIONS(4948),
    [anon_sym_pmos] = ACTIONS(4948),
    [anon_sym_rnmos] = ACTIONS(4948),
    [anon_sym_rpmos] = ACTIONS(4948),
    [anon_sym_nand] = ACTIONS(4948),
    [anon_sym_nor] = ACTIONS(4948),
    [anon_sym_xor] = ACTIONS(4948),
    [anon_sym_xnor] = ACTIONS(4948),
    [anon_sym_buf] = ACTIONS(4948),
    [anon_sym_tranif0] = ACTIONS(4948),
    [anon_sym_tranif1] = ACTIONS(4948),
    [anon_sym_rtranif1] = ACTIONS(4948),
    [anon_sym_rtranif0] = ACTIONS(4948),
    [anon_sym_tran] = ACTIONS(4948),
    [anon_sym_rtran] = ACTIONS(4948),
    [anon_sym_generate] = ACTIONS(4948),
    [anon_sym_for] = ACTIONS(4948),
    [anon_sym_initial] = ACTIONS(4948),
    [anon_sym_assign] = ACTIONS(4948),
    [anon_sym_alias] = ACTIONS(4948),
    [anon_sym_always_comb] = ACTIONS(4948),
    [anon_sym_always_latch] = ACTIONS(4948),
    [anon_sym_always_ff] = ACTIONS(4948),
    [anon_sym_final] = ACTIONS(4948),
    [anon_sym_global] = ACTIONS(4948),
    [anon_sym_LPAREN_STAR] = ACTIONS(4946),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4946),
    [anon_sym_DOLLARunit] = ACTIONS(4946),
  },
  [4698] = {
    [sym_simple_identifier] = ACTIONS(5218),
    [anon_sym_wire] = ACTIONS(5218),
    [anon_sym_tri] = ACTIONS(5218),
    [anon_sym_tri0] = ACTIONS(5218),
    [anon_sym_tri1] = ACTIONS(5218),
    [anon_sym_wand] = ACTIONS(5218),
    [anon_sym_triand] = ACTIONS(5218),
    [anon_sym_wor] = ACTIONS(5218),
    [anon_sym_trior] = ACTIONS(5218),
    [anon_sym_trireg] = ACTIONS(5218),
    [anon_sym_uwire] = ACTIONS(5218),
    [anon_sym_SEMI] = ACTIONS(5216),
    [anon_sym_extern] = ACTIONS(5218),
    [anon_sym_interface] = ACTIONS(5218),
    [anon_sym_checker] = ACTIONS(5218),
    [anon_sym_virtual] = ACTIONS(5218),
    [anon_sym_class] = ACTIONS(5218),
    [anon_sym_type] = ACTIONS(5218),
    [anon_sym_DOLLARfatal] = ACTIONS(5216),
    [anon_sym_DOLLARerror] = ACTIONS(5216),
    [anon_sym_DOLLARwarning] = ACTIONS(5216),
    [anon_sym_DOLLARinfo] = ACTIONS(5216),
    [anon_sym_default] = ACTIONS(5218),
    [anon_sym_clocking] = ACTIONS(5218),
    [anon_sym_defparam] = ACTIONS(5218),
    [anon_sym_bind] = ACTIONS(5218),
    [anon_sym_rand] = ACTIONS(5218),
    [anon_sym_const] = ACTIONS(5218),
    [anon_sym_function] = ACTIONS(5218),
    [anon_sym_static] = ACTIONS(5218),
    [anon_sym_constraint] = ACTIONS(5218),
    [anon_sym_if] = ACTIONS(5218),
    [anon_sym_else] = ACTIONS(5218),
    [anon_sym_LBRACK] = ACTIONS(5216),
    [anon_sym_localparam] = ACTIONS(5218),
    [anon_sym_parameter] = ACTIONS(5218),
    [anon_sym_var] = ACTIONS(5218),
    [anon_sym_import] = ACTIONS(5218),
    [anon_sym_export] = ACTIONS(5218),
    [anon_sym_genvar] = ACTIONS(5218),
    [anon_sym_interconnect] = ACTIONS(5218),
    [anon_sym_typedef] = ACTIONS(5218),
    [anon_sym_enum] = ACTIONS(5218),
    [anon_sym_struct] = ACTIONS(5218),
    [anon_sym_union] = ACTIONS(5218),
    [anon_sym_nettype] = ACTIONS(5218),
    [anon_sym_automatic] = ACTIONS(5218),
    [anon_sym_string] = ACTIONS(5218),
    [anon_sym_chandle] = ACTIONS(5218),
    [anon_sym_event] = ACTIONS(5218),
    [anon_sym_byte] = ACTIONS(5218),
    [anon_sym_shortint] = ACTIONS(5218),
    [anon_sym_int] = ACTIONS(5218),
    [anon_sym_longint] = ACTIONS(5218),
    [anon_sym_integer] = ACTIONS(5218),
    [anon_sym_time] = ACTIONS(5218),
    [anon_sym_bit] = ACTIONS(5218),
    [anon_sym_logic] = ACTIONS(5218),
    [anon_sym_reg] = ACTIONS(5218),
    [anon_sym_shortreal] = ACTIONS(5218),
    [anon_sym_real] = ACTIONS(5218),
    [anon_sym_realtime] = ACTIONS(5218),
    [anon_sym_supply0] = ACTIONS(5218),
    [anon_sym_supply1] = ACTIONS(5218),
    [anon_sym_signed] = ACTIONS(5218),
    [anon_sym_unsigned] = ACTIONS(5218),
    [anon_sym_task] = ACTIONS(5218),
    [anon_sym_assert] = ACTIONS(5218),
    [anon_sym_property] = ACTIONS(5218),
    [anon_sym_assume] = ACTIONS(5218),
    [anon_sym_cover] = ACTIONS(5218),
    [anon_sym_sequence] = ACTIONS(5218),
    [anon_sym_restrict] = ACTIONS(5218),
    [anon_sym_not] = ACTIONS(5218),
    [anon_sym_or] = ACTIONS(5218),
    [anon_sym_and] = ACTIONS(5218),
    [anon_sym_case] = ACTIONS(5218),
    [anon_sym_always] = ACTIONS(5218),
    [anon_sym_covergroup] = ACTIONS(5218),
    [anon_sym_end] = ACTIONS(5218),
    [anon_sym_let] = ACTIONS(5218),
    [anon_sym_pulldown] = ACTIONS(5218),
    [anon_sym_pullup] = ACTIONS(5218),
    [anon_sym_cmos] = ACTIONS(5218),
    [anon_sym_rcmos] = ACTIONS(5218),
    [anon_sym_bufif0] = ACTIONS(5218),
    [anon_sym_bufif1] = ACTIONS(5218),
    [anon_sym_notif0] = ACTIONS(5218),
    [anon_sym_notif1] = ACTIONS(5218),
    [anon_sym_nmos] = ACTIONS(5218),
    [anon_sym_pmos] = ACTIONS(5218),
    [anon_sym_rnmos] = ACTIONS(5218),
    [anon_sym_rpmos] = ACTIONS(5218),
    [anon_sym_nand] = ACTIONS(5218),
    [anon_sym_nor] = ACTIONS(5218),
    [anon_sym_xor] = ACTIONS(5218),
    [anon_sym_xnor] = ACTIONS(5218),
    [anon_sym_buf] = ACTIONS(5218),
    [anon_sym_tranif0] = ACTIONS(5218),
    [anon_sym_tranif1] = ACTIONS(5218),
    [anon_sym_rtranif1] = ACTIONS(5218),
    [anon_sym_rtranif0] = ACTIONS(5218),
    [anon_sym_tran] = ACTIONS(5218),
    [anon_sym_rtran] = ACTIONS(5218),
    [anon_sym_generate] = ACTIONS(5218),
    [anon_sym_for] = ACTIONS(5218),
    [anon_sym_initial] = ACTIONS(5218),
    [anon_sym_assign] = ACTIONS(5218),
    [anon_sym_alias] = ACTIONS(5218),
    [anon_sym_always_comb] = ACTIONS(5218),
    [anon_sym_always_latch] = ACTIONS(5218),
    [anon_sym_always_ff] = ACTIONS(5218),
    [anon_sym_final] = ACTIONS(5218),
    [anon_sym_global] = ACTIONS(5218),
    [anon_sym_LPAREN_STAR] = ACTIONS(5216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5216),
    [anon_sym_DOLLARunit] = ACTIONS(5216),
  },
  [4699] = {
    [sym_simple_identifier] = ACTIONS(6479),
    [anon_sym_wire] = ACTIONS(6479),
    [anon_sym_tri] = ACTIONS(6479),
    [anon_sym_tri0] = ACTIONS(6479),
    [anon_sym_tri1] = ACTIONS(6479),
    [anon_sym_wand] = ACTIONS(6479),
    [anon_sym_triand] = ACTIONS(6479),
    [anon_sym_wor] = ACTIONS(6479),
    [anon_sym_trior] = ACTIONS(6479),
    [anon_sym_trireg] = ACTIONS(6479),
    [anon_sym_uwire] = ACTIONS(6479),
    [anon_sym_SEMI] = ACTIONS(6481),
    [anon_sym_extern] = ACTIONS(6479),
    [anon_sym_interface] = ACTIONS(6479),
    [anon_sym_checker] = ACTIONS(6479),
    [anon_sym_virtual] = ACTIONS(6479),
    [anon_sym_class] = ACTIONS(6479),
    [anon_sym_type] = ACTIONS(6479),
    [anon_sym_DOLLARfatal] = ACTIONS(6481),
    [anon_sym_DOLLARerror] = ACTIONS(6481),
    [anon_sym_DOLLARwarning] = ACTIONS(6481),
    [anon_sym_DOLLARinfo] = ACTIONS(6481),
    [anon_sym_default] = ACTIONS(6479),
    [anon_sym_clocking] = ACTIONS(6479),
    [anon_sym_defparam] = ACTIONS(6479),
    [anon_sym_bind] = ACTIONS(6479),
    [anon_sym_rand] = ACTIONS(6479),
    [anon_sym_const] = ACTIONS(6479),
    [anon_sym_function] = ACTIONS(6479),
    [anon_sym_static] = ACTIONS(6479),
    [anon_sym_constraint] = ACTIONS(6479),
    [anon_sym_if] = ACTIONS(6479),
    [anon_sym_else] = ACTIONS(6479),
    [anon_sym_LBRACK] = ACTIONS(6481),
    [anon_sym_localparam] = ACTIONS(6479),
    [anon_sym_parameter] = ACTIONS(6479),
    [anon_sym_var] = ACTIONS(6479),
    [anon_sym_import] = ACTIONS(6479),
    [anon_sym_export] = ACTIONS(6479),
    [anon_sym_genvar] = ACTIONS(6479),
    [anon_sym_interconnect] = ACTIONS(6479),
    [anon_sym_typedef] = ACTIONS(6479),
    [anon_sym_enum] = ACTIONS(6479),
    [anon_sym_struct] = ACTIONS(6479),
    [anon_sym_union] = ACTIONS(6479),
    [anon_sym_nettype] = ACTIONS(6479),
    [anon_sym_automatic] = ACTIONS(6479),
    [anon_sym_string] = ACTIONS(6479),
    [anon_sym_chandle] = ACTIONS(6479),
    [anon_sym_event] = ACTIONS(6479),
    [anon_sym_byte] = ACTIONS(6479),
    [anon_sym_shortint] = ACTIONS(6479),
    [anon_sym_int] = ACTIONS(6479),
    [anon_sym_longint] = ACTIONS(6479),
    [anon_sym_integer] = ACTIONS(6479),
    [anon_sym_time] = ACTIONS(6479),
    [anon_sym_bit] = ACTIONS(6479),
    [anon_sym_logic] = ACTIONS(6479),
    [anon_sym_reg] = ACTIONS(6479),
    [anon_sym_shortreal] = ACTIONS(6479),
    [anon_sym_real] = ACTIONS(6479),
    [anon_sym_realtime] = ACTIONS(6479),
    [anon_sym_supply0] = ACTIONS(6479),
    [anon_sym_supply1] = ACTIONS(6479),
    [anon_sym_signed] = ACTIONS(6479),
    [anon_sym_unsigned] = ACTIONS(6479),
    [anon_sym_task] = ACTIONS(6479),
    [anon_sym_assert] = ACTIONS(6479),
    [anon_sym_property] = ACTIONS(6479),
    [anon_sym_assume] = ACTIONS(6479),
    [anon_sym_cover] = ACTIONS(6479),
    [anon_sym_sequence] = ACTIONS(6479),
    [anon_sym_restrict] = ACTIONS(6479),
    [anon_sym_not] = ACTIONS(6479),
    [anon_sym_or] = ACTIONS(6479),
    [anon_sym_and] = ACTIONS(6479),
    [anon_sym_case] = ACTIONS(6479),
    [anon_sym_always] = ACTIONS(6479),
    [anon_sym_covergroup] = ACTIONS(6479),
    [anon_sym_end] = ACTIONS(6479),
    [anon_sym_let] = ACTIONS(6479),
    [anon_sym_pulldown] = ACTIONS(6479),
    [anon_sym_pullup] = ACTIONS(6479),
    [anon_sym_cmos] = ACTIONS(6479),
    [anon_sym_rcmos] = ACTIONS(6479),
    [anon_sym_bufif0] = ACTIONS(6479),
    [anon_sym_bufif1] = ACTIONS(6479),
    [anon_sym_notif0] = ACTIONS(6479),
    [anon_sym_notif1] = ACTIONS(6479),
    [anon_sym_nmos] = ACTIONS(6479),
    [anon_sym_pmos] = ACTIONS(6479),
    [anon_sym_rnmos] = ACTIONS(6479),
    [anon_sym_rpmos] = ACTIONS(6479),
    [anon_sym_nand] = ACTIONS(6479),
    [anon_sym_nor] = ACTIONS(6479),
    [anon_sym_xor] = ACTIONS(6479),
    [anon_sym_xnor] = ACTIONS(6479),
    [anon_sym_buf] = ACTIONS(6479),
    [anon_sym_tranif0] = ACTIONS(6479),
    [anon_sym_tranif1] = ACTIONS(6479),
    [anon_sym_rtranif1] = ACTIONS(6479),
    [anon_sym_rtranif0] = ACTIONS(6479),
    [anon_sym_tran] = ACTIONS(6479),
    [anon_sym_rtran] = ACTIONS(6479),
    [anon_sym_generate] = ACTIONS(6479),
    [anon_sym_for] = ACTIONS(6479),
    [anon_sym_initial] = ACTIONS(6479),
    [anon_sym_assign] = ACTIONS(6479),
    [anon_sym_alias] = ACTIONS(6479),
    [anon_sym_always_comb] = ACTIONS(6479),
    [anon_sym_always_latch] = ACTIONS(6479),
    [anon_sym_always_ff] = ACTIONS(6479),
    [anon_sym_final] = ACTIONS(6479),
    [anon_sym_global] = ACTIONS(6479),
    [anon_sym_LPAREN_STAR] = ACTIONS(6481),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6481),
    [anon_sym_DOLLARunit] = ACTIONS(6481),
  },
  [4700] = {
    [sym_simple_identifier] = ACTIONS(6593),
    [anon_sym_wire] = ACTIONS(6593),
    [anon_sym_tri] = ACTIONS(6593),
    [anon_sym_tri0] = ACTIONS(6593),
    [anon_sym_tri1] = ACTIONS(6593),
    [anon_sym_wand] = ACTIONS(6593),
    [anon_sym_triand] = ACTIONS(6593),
    [anon_sym_wor] = ACTIONS(6593),
    [anon_sym_trior] = ACTIONS(6593),
    [anon_sym_trireg] = ACTIONS(6593),
    [anon_sym_uwire] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(6595),
    [anon_sym_extern] = ACTIONS(6593),
    [anon_sym_interface] = ACTIONS(6593),
    [anon_sym_checker] = ACTIONS(6593),
    [anon_sym_virtual] = ACTIONS(6593),
    [anon_sym_class] = ACTIONS(6593),
    [anon_sym_type] = ACTIONS(6593),
    [anon_sym_DOLLARfatal] = ACTIONS(6595),
    [anon_sym_DOLLARerror] = ACTIONS(6595),
    [anon_sym_DOLLARwarning] = ACTIONS(6595),
    [anon_sym_DOLLARinfo] = ACTIONS(6595),
    [anon_sym_default] = ACTIONS(6593),
    [anon_sym_clocking] = ACTIONS(6593),
    [anon_sym_defparam] = ACTIONS(6593),
    [anon_sym_bind] = ACTIONS(6593),
    [anon_sym_rand] = ACTIONS(6593),
    [anon_sym_const] = ACTIONS(6593),
    [anon_sym_function] = ACTIONS(6593),
    [anon_sym_static] = ACTIONS(6593),
    [anon_sym_constraint] = ACTIONS(6593),
    [anon_sym_if] = ACTIONS(6593),
    [anon_sym_else] = ACTIONS(6593),
    [anon_sym_LBRACK] = ACTIONS(6595),
    [anon_sym_localparam] = ACTIONS(6593),
    [anon_sym_parameter] = ACTIONS(6593),
    [anon_sym_var] = ACTIONS(6593),
    [anon_sym_import] = ACTIONS(6593),
    [anon_sym_export] = ACTIONS(6593),
    [anon_sym_genvar] = ACTIONS(6593),
    [anon_sym_interconnect] = ACTIONS(6593),
    [anon_sym_typedef] = ACTIONS(6593),
    [anon_sym_enum] = ACTIONS(6593),
    [anon_sym_struct] = ACTIONS(6593),
    [anon_sym_union] = ACTIONS(6593),
    [anon_sym_nettype] = ACTIONS(6593),
    [anon_sym_automatic] = ACTIONS(6593),
    [anon_sym_string] = ACTIONS(6593),
    [anon_sym_chandle] = ACTIONS(6593),
    [anon_sym_event] = ACTIONS(6593),
    [anon_sym_byte] = ACTIONS(6593),
    [anon_sym_shortint] = ACTIONS(6593),
    [anon_sym_int] = ACTIONS(6593),
    [anon_sym_longint] = ACTIONS(6593),
    [anon_sym_integer] = ACTIONS(6593),
    [anon_sym_time] = ACTIONS(6593),
    [anon_sym_bit] = ACTIONS(6593),
    [anon_sym_logic] = ACTIONS(6593),
    [anon_sym_reg] = ACTIONS(6593),
    [anon_sym_shortreal] = ACTIONS(6593),
    [anon_sym_real] = ACTIONS(6593),
    [anon_sym_realtime] = ACTIONS(6593),
    [anon_sym_supply0] = ACTIONS(6593),
    [anon_sym_supply1] = ACTIONS(6593),
    [anon_sym_signed] = ACTIONS(6593),
    [anon_sym_unsigned] = ACTIONS(6593),
    [anon_sym_task] = ACTIONS(6593),
    [anon_sym_assert] = ACTIONS(6593),
    [anon_sym_property] = ACTIONS(6593),
    [anon_sym_assume] = ACTIONS(6593),
    [anon_sym_cover] = ACTIONS(6593),
    [anon_sym_sequence] = ACTIONS(6593),
    [anon_sym_restrict] = ACTIONS(6593),
    [anon_sym_not] = ACTIONS(6593),
    [anon_sym_or] = ACTIONS(6593),
    [anon_sym_and] = ACTIONS(6593),
    [anon_sym_case] = ACTIONS(6593),
    [anon_sym_always] = ACTIONS(6593),
    [anon_sym_covergroup] = ACTIONS(6593),
    [anon_sym_end] = ACTIONS(6593),
    [anon_sym_let] = ACTIONS(6593),
    [anon_sym_pulldown] = ACTIONS(6593),
    [anon_sym_pullup] = ACTIONS(6593),
    [anon_sym_cmos] = ACTIONS(6593),
    [anon_sym_rcmos] = ACTIONS(6593),
    [anon_sym_bufif0] = ACTIONS(6593),
    [anon_sym_bufif1] = ACTIONS(6593),
    [anon_sym_notif0] = ACTIONS(6593),
    [anon_sym_notif1] = ACTIONS(6593),
    [anon_sym_nmos] = ACTIONS(6593),
    [anon_sym_pmos] = ACTIONS(6593),
    [anon_sym_rnmos] = ACTIONS(6593),
    [anon_sym_rpmos] = ACTIONS(6593),
    [anon_sym_nand] = ACTIONS(6593),
    [anon_sym_nor] = ACTIONS(6593),
    [anon_sym_xor] = ACTIONS(6593),
    [anon_sym_xnor] = ACTIONS(6593),
    [anon_sym_buf] = ACTIONS(6593),
    [anon_sym_tranif0] = ACTIONS(6593),
    [anon_sym_tranif1] = ACTIONS(6593),
    [anon_sym_rtranif1] = ACTIONS(6593),
    [anon_sym_rtranif0] = ACTIONS(6593),
    [anon_sym_tran] = ACTIONS(6593),
    [anon_sym_rtran] = ACTIONS(6593),
    [anon_sym_generate] = ACTIONS(6593),
    [anon_sym_for] = ACTIONS(6593),
    [anon_sym_initial] = ACTIONS(6593),
    [anon_sym_assign] = ACTIONS(6593),
    [anon_sym_alias] = ACTIONS(6593),
    [anon_sym_always_comb] = ACTIONS(6593),
    [anon_sym_always_latch] = ACTIONS(6593),
    [anon_sym_always_ff] = ACTIONS(6593),
    [anon_sym_final] = ACTIONS(6593),
    [anon_sym_global] = ACTIONS(6593),
    [anon_sym_LPAREN_STAR] = ACTIONS(6595),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6595),
    [anon_sym_DOLLARunit] = ACTIONS(6595),
  },
  [4701] = {
    [sym_simple_identifier] = ACTIONS(6609),
    [anon_sym_wire] = ACTIONS(6609),
    [anon_sym_tri] = ACTIONS(6609),
    [anon_sym_tri0] = ACTIONS(6609),
    [anon_sym_tri1] = ACTIONS(6609),
    [anon_sym_wand] = ACTIONS(6609),
    [anon_sym_triand] = ACTIONS(6609),
    [anon_sym_wor] = ACTIONS(6609),
    [anon_sym_trior] = ACTIONS(6609),
    [anon_sym_trireg] = ACTIONS(6609),
    [anon_sym_uwire] = ACTIONS(6609),
    [anon_sym_SEMI] = ACTIONS(6611),
    [anon_sym_extern] = ACTIONS(6609),
    [anon_sym_interface] = ACTIONS(6609),
    [anon_sym_checker] = ACTIONS(6609),
    [anon_sym_virtual] = ACTIONS(6609),
    [anon_sym_class] = ACTIONS(6609),
    [anon_sym_type] = ACTIONS(6609),
    [anon_sym_DOLLARfatal] = ACTIONS(6611),
    [anon_sym_DOLLARerror] = ACTIONS(6611),
    [anon_sym_DOLLARwarning] = ACTIONS(6611),
    [anon_sym_DOLLARinfo] = ACTIONS(6611),
    [anon_sym_default] = ACTIONS(6609),
    [anon_sym_clocking] = ACTIONS(6609),
    [anon_sym_defparam] = ACTIONS(6609),
    [anon_sym_bind] = ACTIONS(6609),
    [anon_sym_rand] = ACTIONS(6609),
    [anon_sym_const] = ACTIONS(6609),
    [anon_sym_function] = ACTIONS(6609),
    [anon_sym_static] = ACTIONS(6609),
    [anon_sym_constraint] = ACTIONS(6609),
    [anon_sym_if] = ACTIONS(6609),
    [anon_sym_else] = ACTIONS(6609),
    [anon_sym_LBRACK] = ACTIONS(6611),
    [anon_sym_localparam] = ACTIONS(6609),
    [anon_sym_parameter] = ACTIONS(6609),
    [anon_sym_var] = ACTIONS(6609),
    [anon_sym_import] = ACTIONS(6609),
    [anon_sym_export] = ACTIONS(6609),
    [anon_sym_genvar] = ACTIONS(6609),
    [anon_sym_interconnect] = ACTIONS(6609),
    [anon_sym_typedef] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6609),
    [anon_sym_struct] = ACTIONS(6609),
    [anon_sym_union] = ACTIONS(6609),
    [anon_sym_nettype] = ACTIONS(6609),
    [anon_sym_automatic] = ACTIONS(6609),
    [anon_sym_string] = ACTIONS(6609),
    [anon_sym_chandle] = ACTIONS(6609),
    [anon_sym_event] = ACTIONS(6609),
    [anon_sym_byte] = ACTIONS(6609),
    [anon_sym_shortint] = ACTIONS(6609),
    [anon_sym_int] = ACTIONS(6609),
    [anon_sym_longint] = ACTIONS(6609),
    [anon_sym_integer] = ACTIONS(6609),
    [anon_sym_time] = ACTIONS(6609),
    [anon_sym_bit] = ACTIONS(6609),
    [anon_sym_logic] = ACTIONS(6609),
    [anon_sym_reg] = ACTIONS(6609),
    [anon_sym_shortreal] = ACTIONS(6609),
    [anon_sym_real] = ACTIONS(6609),
    [anon_sym_realtime] = ACTIONS(6609),
    [anon_sym_supply0] = ACTIONS(6609),
    [anon_sym_supply1] = ACTIONS(6609),
    [anon_sym_signed] = ACTIONS(6609),
    [anon_sym_unsigned] = ACTIONS(6609),
    [anon_sym_task] = ACTIONS(6609),
    [anon_sym_assert] = ACTIONS(6609),
    [anon_sym_property] = ACTIONS(6609),
    [anon_sym_assume] = ACTIONS(6609),
    [anon_sym_cover] = ACTIONS(6609),
    [anon_sym_sequence] = ACTIONS(6609),
    [anon_sym_restrict] = ACTIONS(6609),
    [anon_sym_not] = ACTIONS(6609),
    [anon_sym_or] = ACTIONS(6609),
    [anon_sym_and] = ACTIONS(6609),
    [anon_sym_case] = ACTIONS(6609),
    [anon_sym_always] = ACTIONS(6609),
    [anon_sym_covergroup] = ACTIONS(6609),
    [anon_sym_end] = ACTIONS(6609),
    [anon_sym_let] = ACTIONS(6609),
    [anon_sym_pulldown] = ACTIONS(6609),
    [anon_sym_pullup] = ACTIONS(6609),
    [anon_sym_cmos] = ACTIONS(6609),
    [anon_sym_rcmos] = ACTIONS(6609),
    [anon_sym_bufif0] = ACTIONS(6609),
    [anon_sym_bufif1] = ACTIONS(6609),
    [anon_sym_notif0] = ACTIONS(6609),
    [anon_sym_notif1] = ACTIONS(6609),
    [anon_sym_nmos] = ACTIONS(6609),
    [anon_sym_pmos] = ACTIONS(6609),
    [anon_sym_rnmos] = ACTIONS(6609),
    [anon_sym_rpmos] = ACTIONS(6609),
    [anon_sym_nand] = ACTIONS(6609),
    [anon_sym_nor] = ACTIONS(6609),
    [anon_sym_xor] = ACTIONS(6609),
    [anon_sym_xnor] = ACTIONS(6609),
    [anon_sym_buf] = ACTIONS(6609),
    [anon_sym_tranif0] = ACTIONS(6609),
    [anon_sym_tranif1] = ACTIONS(6609),
    [anon_sym_rtranif1] = ACTIONS(6609),
    [anon_sym_rtranif0] = ACTIONS(6609),
    [anon_sym_tran] = ACTIONS(6609),
    [anon_sym_rtran] = ACTIONS(6609),
    [anon_sym_generate] = ACTIONS(6609),
    [anon_sym_for] = ACTIONS(6609),
    [anon_sym_initial] = ACTIONS(6609),
    [anon_sym_assign] = ACTIONS(6609),
    [anon_sym_alias] = ACTIONS(6609),
    [anon_sym_always_comb] = ACTIONS(6609),
    [anon_sym_always_latch] = ACTIONS(6609),
    [anon_sym_always_ff] = ACTIONS(6609),
    [anon_sym_final] = ACTIONS(6609),
    [anon_sym_global] = ACTIONS(6609),
    [anon_sym_LPAREN_STAR] = ACTIONS(6611),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6611),
    [anon_sym_DOLLARunit] = ACTIONS(6611),
  },
  [4702] = {
    [sym_simple_identifier] = ACTIONS(4924),
    [anon_sym_wire] = ACTIONS(4924),
    [anon_sym_tri] = ACTIONS(4924),
    [anon_sym_tri0] = ACTIONS(4924),
    [anon_sym_tri1] = ACTIONS(4924),
    [anon_sym_wand] = ACTIONS(4924),
    [anon_sym_triand] = ACTIONS(4924),
    [anon_sym_wor] = ACTIONS(4924),
    [anon_sym_trior] = ACTIONS(4924),
    [anon_sym_trireg] = ACTIONS(4924),
    [anon_sym_uwire] = ACTIONS(4924),
    [anon_sym_SEMI] = ACTIONS(4922),
    [anon_sym_extern] = ACTIONS(4924),
    [anon_sym_interface] = ACTIONS(4924),
    [anon_sym_checker] = ACTIONS(4924),
    [anon_sym_virtual] = ACTIONS(4924),
    [anon_sym_class] = ACTIONS(4924),
    [anon_sym_type] = ACTIONS(4924),
    [anon_sym_DOLLARfatal] = ACTIONS(4922),
    [anon_sym_DOLLARerror] = ACTIONS(4922),
    [anon_sym_DOLLARwarning] = ACTIONS(4922),
    [anon_sym_DOLLARinfo] = ACTIONS(4922),
    [anon_sym_default] = ACTIONS(4924),
    [anon_sym_clocking] = ACTIONS(4924),
    [anon_sym_defparam] = ACTIONS(4924),
    [anon_sym_bind] = ACTIONS(4924),
    [anon_sym_rand] = ACTIONS(4924),
    [anon_sym_const] = ACTIONS(4924),
    [anon_sym_function] = ACTIONS(4924),
    [anon_sym_static] = ACTIONS(4924),
    [anon_sym_constraint] = ACTIONS(4924),
    [anon_sym_if] = ACTIONS(4924),
    [anon_sym_else] = ACTIONS(4924),
    [anon_sym_LBRACK] = ACTIONS(4922),
    [anon_sym_localparam] = ACTIONS(4924),
    [anon_sym_parameter] = ACTIONS(4924),
    [anon_sym_var] = ACTIONS(4924),
    [anon_sym_import] = ACTIONS(4924),
    [anon_sym_export] = ACTIONS(4924),
    [anon_sym_genvar] = ACTIONS(4924),
    [anon_sym_interconnect] = ACTIONS(4924),
    [anon_sym_typedef] = ACTIONS(4924),
    [anon_sym_enum] = ACTIONS(4924),
    [anon_sym_struct] = ACTIONS(4924),
    [anon_sym_union] = ACTIONS(4924),
    [anon_sym_nettype] = ACTIONS(4924),
    [anon_sym_automatic] = ACTIONS(4924),
    [anon_sym_string] = ACTIONS(4924),
    [anon_sym_chandle] = ACTIONS(4924),
    [anon_sym_event] = ACTIONS(4924),
    [anon_sym_byte] = ACTIONS(4924),
    [anon_sym_shortint] = ACTIONS(4924),
    [anon_sym_int] = ACTIONS(4924),
    [anon_sym_longint] = ACTIONS(4924),
    [anon_sym_integer] = ACTIONS(4924),
    [anon_sym_time] = ACTIONS(4924),
    [anon_sym_bit] = ACTIONS(4924),
    [anon_sym_logic] = ACTIONS(4924),
    [anon_sym_reg] = ACTIONS(4924),
    [anon_sym_shortreal] = ACTIONS(4924),
    [anon_sym_real] = ACTIONS(4924),
    [anon_sym_realtime] = ACTIONS(4924),
    [anon_sym_supply0] = ACTIONS(4924),
    [anon_sym_supply1] = ACTIONS(4924),
    [anon_sym_signed] = ACTIONS(4924),
    [anon_sym_unsigned] = ACTIONS(4924),
    [anon_sym_task] = ACTIONS(4924),
    [anon_sym_assert] = ACTIONS(4924),
    [anon_sym_property] = ACTIONS(4924),
    [anon_sym_assume] = ACTIONS(4924),
    [anon_sym_cover] = ACTIONS(4924),
    [anon_sym_sequence] = ACTIONS(4924),
    [anon_sym_restrict] = ACTIONS(4924),
    [anon_sym_not] = ACTIONS(4924),
    [anon_sym_or] = ACTIONS(4924),
    [anon_sym_and] = ACTIONS(4924),
    [anon_sym_case] = ACTIONS(4924),
    [anon_sym_always] = ACTIONS(4924),
    [anon_sym_covergroup] = ACTIONS(4924),
    [anon_sym_end] = ACTIONS(4924),
    [anon_sym_let] = ACTIONS(4924),
    [anon_sym_pulldown] = ACTIONS(4924),
    [anon_sym_pullup] = ACTIONS(4924),
    [anon_sym_cmos] = ACTIONS(4924),
    [anon_sym_rcmos] = ACTIONS(4924),
    [anon_sym_bufif0] = ACTIONS(4924),
    [anon_sym_bufif1] = ACTIONS(4924),
    [anon_sym_notif0] = ACTIONS(4924),
    [anon_sym_notif1] = ACTIONS(4924),
    [anon_sym_nmos] = ACTIONS(4924),
    [anon_sym_pmos] = ACTIONS(4924),
    [anon_sym_rnmos] = ACTIONS(4924),
    [anon_sym_rpmos] = ACTIONS(4924),
    [anon_sym_nand] = ACTIONS(4924),
    [anon_sym_nor] = ACTIONS(4924),
    [anon_sym_xor] = ACTIONS(4924),
    [anon_sym_xnor] = ACTIONS(4924),
    [anon_sym_buf] = ACTIONS(4924),
    [anon_sym_tranif0] = ACTIONS(4924),
    [anon_sym_tranif1] = ACTIONS(4924),
    [anon_sym_rtranif1] = ACTIONS(4924),
    [anon_sym_rtranif0] = ACTIONS(4924),
    [anon_sym_tran] = ACTIONS(4924),
    [anon_sym_rtran] = ACTIONS(4924),
    [anon_sym_generate] = ACTIONS(4924),
    [anon_sym_for] = ACTIONS(4924),
    [anon_sym_initial] = ACTIONS(4924),
    [anon_sym_assign] = ACTIONS(4924),
    [anon_sym_alias] = ACTIONS(4924),
    [anon_sym_always_comb] = ACTIONS(4924),
    [anon_sym_always_latch] = ACTIONS(4924),
    [anon_sym_always_ff] = ACTIONS(4924),
    [anon_sym_final] = ACTIONS(4924),
    [anon_sym_global] = ACTIONS(4924),
    [anon_sym_LPAREN_STAR] = ACTIONS(4922),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4922),
    [anon_sym_DOLLARunit] = ACTIONS(4922),
  },
  [4703] = {
    [sym_simple_identifier] = ACTIONS(6467),
    [anon_sym_wire] = ACTIONS(6467),
    [anon_sym_tri] = ACTIONS(6467),
    [anon_sym_tri0] = ACTIONS(6467),
    [anon_sym_tri1] = ACTIONS(6467),
    [anon_sym_wand] = ACTIONS(6467),
    [anon_sym_triand] = ACTIONS(6467),
    [anon_sym_wor] = ACTIONS(6467),
    [anon_sym_trior] = ACTIONS(6467),
    [anon_sym_trireg] = ACTIONS(6467),
    [anon_sym_uwire] = ACTIONS(6467),
    [anon_sym_SEMI] = ACTIONS(6469),
    [anon_sym_extern] = ACTIONS(6467),
    [anon_sym_interface] = ACTIONS(6467),
    [anon_sym_checker] = ACTIONS(6467),
    [anon_sym_virtual] = ACTIONS(6467),
    [anon_sym_class] = ACTIONS(6467),
    [anon_sym_type] = ACTIONS(6467),
    [anon_sym_DOLLARfatal] = ACTIONS(6469),
    [anon_sym_DOLLARerror] = ACTIONS(6469),
    [anon_sym_DOLLARwarning] = ACTIONS(6469),
    [anon_sym_DOLLARinfo] = ACTIONS(6469),
    [anon_sym_default] = ACTIONS(6467),
    [anon_sym_clocking] = ACTIONS(6467),
    [anon_sym_defparam] = ACTIONS(6467),
    [anon_sym_bind] = ACTIONS(6467),
    [anon_sym_rand] = ACTIONS(6467),
    [anon_sym_const] = ACTIONS(6467),
    [anon_sym_function] = ACTIONS(6467),
    [anon_sym_static] = ACTIONS(6467),
    [anon_sym_constraint] = ACTIONS(6467),
    [anon_sym_if] = ACTIONS(6467),
    [anon_sym_else] = ACTIONS(6467),
    [anon_sym_LBRACK] = ACTIONS(6469),
    [anon_sym_localparam] = ACTIONS(6467),
    [anon_sym_parameter] = ACTIONS(6467),
    [anon_sym_var] = ACTIONS(6467),
    [anon_sym_import] = ACTIONS(6467),
    [anon_sym_export] = ACTIONS(6467),
    [anon_sym_genvar] = ACTIONS(6467),
    [anon_sym_interconnect] = ACTIONS(6467),
    [anon_sym_typedef] = ACTIONS(6467),
    [anon_sym_enum] = ACTIONS(6467),
    [anon_sym_struct] = ACTIONS(6467),
    [anon_sym_union] = ACTIONS(6467),
    [anon_sym_nettype] = ACTIONS(6467),
    [anon_sym_automatic] = ACTIONS(6467),
    [anon_sym_string] = ACTIONS(6467),
    [anon_sym_chandle] = ACTIONS(6467),
    [anon_sym_event] = ACTIONS(6467),
    [anon_sym_byte] = ACTIONS(6467),
    [anon_sym_shortint] = ACTIONS(6467),
    [anon_sym_int] = ACTIONS(6467),
    [anon_sym_longint] = ACTIONS(6467),
    [anon_sym_integer] = ACTIONS(6467),
    [anon_sym_time] = ACTIONS(6467),
    [anon_sym_bit] = ACTIONS(6467),
    [anon_sym_logic] = ACTIONS(6467),
    [anon_sym_reg] = ACTIONS(6467),
    [anon_sym_shortreal] = ACTIONS(6467),
    [anon_sym_real] = ACTIONS(6467),
    [anon_sym_realtime] = ACTIONS(6467),
    [anon_sym_supply0] = ACTIONS(6467),
    [anon_sym_supply1] = ACTIONS(6467),
    [anon_sym_signed] = ACTIONS(6467),
    [anon_sym_unsigned] = ACTIONS(6467),
    [anon_sym_task] = ACTIONS(6467),
    [anon_sym_assert] = ACTIONS(6467),
    [anon_sym_property] = ACTIONS(6467),
    [anon_sym_assume] = ACTIONS(6467),
    [anon_sym_cover] = ACTIONS(6467),
    [anon_sym_sequence] = ACTIONS(6467),
    [anon_sym_restrict] = ACTIONS(6467),
    [anon_sym_not] = ACTIONS(6467),
    [anon_sym_or] = ACTIONS(6467),
    [anon_sym_and] = ACTIONS(6467),
    [anon_sym_case] = ACTIONS(6467),
    [anon_sym_always] = ACTIONS(6467),
    [anon_sym_covergroup] = ACTIONS(6467),
    [anon_sym_end] = ACTIONS(6467),
    [anon_sym_let] = ACTIONS(6467),
    [anon_sym_pulldown] = ACTIONS(6467),
    [anon_sym_pullup] = ACTIONS(6467),
    [anon_sym_cmos] = ACTIONS(6467),
    [anon_sym_rcmos] = ACTIONS(6467),
    [anon_sym_bufif0] = ACTIONS(6467),
    [anon_sym_bufif1] = ACTIONS(6467),
    [anon_sym_notif0] = ACTIONS(6467),
    [anon_sym_notif1] = ACTIONS(6467),
    [anon_sym_nmos] = ACTIONS(6467),
    [anon_sym_pmos] = ACTIONS(6467),
    [anon_sym_rnmos] = ACTIONS(6467),
    [anon_sym_rpmos] = ACTIONS(6467),
    [anon_sym_nand] = ACTIONS(6467),
    [anon_sym_nor] = ACTIONS(6467),
    [anon_sym_xor] = ACTIONS(6467),
    [anon_sym_xnor] = ACTIONS(6467),
    [anon_sym_buf] = ACTIONS(6467),
    [anon_sym_tranif0] = ACTIONS(6467),
    [anon_sym_tranif1] = ACTIONS(6467),
    [anon_sym_rtranif1] = ACTIONS(6467),
    [anon_sym_rtranif0] = ACTIONS(6467),
    [anon_sym_tran] = ACTIONS(6467),
    [anon_sym_rtran] = ACTIONS(6467),
    [anon_sym_generate] = ACTIONS(6467),
    [anon_sym_for] = ACTIONS(6467),
    [anon_sym_initial] = ACTIONS(6467),
    [anon_sym_assign] = ACTIONS(6467),
    [anon_sym_alias] = ACTIONS(6467),
    [anon_sym_always_comb] = ACTIONS(6467),
    [anon_sym_always_latch] = ACTIONS(6467),
    [anon_sym_always_ff] = ACTIONS(6467),
    [anon_sym_final] = ACTIONS(6467),
    [anon_sym_global] = ACTIONS(6467),
    [anon_sym_LPAREN_STAR] = ACTIONS(6469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6469),
    [anon_sym_DOLLARunit] = ACTIONS(6469),
  },
  [4704] = {
    [sym_simple_identifier] = ACTIONS(5222),
    [anon_sym_wire] = ACTIONS(5222),
    [anon_sym_tri] = ACTIONS(5222),
    [anon_sym_tri0] = ACTIONS(5222),
    [anon_sym_tri1] = ACTIONS(5222),
    [anon_sym_wand] = ACTIONS(5222),
    [anon_sym_triand] = ACTIONS(5222),
    [anon_sym_wor] = ACTIONS(5222),
    [anon_sym_trior] = ACTIONS(5222),
    [anon_sym_trireg] = ACTIONS(5222),
    [anon_sym_uwire] = ACTIONS(5222),
    [anon_sym_SEMI] = ACTIONS(5220),
    [anon_sym_extern] = ACTIONS(5222),
    [anon_sym_interface] = ACTIONS(5222),
    [anon_sym_checker] = ACTIONS(5222),
    [anon_sym_virtual] = ACTIONS(5222),
    [anon_sym_class] = ACTIONS(5222),
    [anon_sym_type] = ACTIONS(5222),
    [anon_sym_DOLLARfatal] = ACTIONS(5220),
    [anon_sym_DOLLARerror] = ACTIONS(5220),
    [anon_sym_DOLLARwarning] = ACTIONS(5220),
    [anon_sym_DOLLARinfo] = ACTIONS(5220),
    [anon_sym_default] = ACTIONS(5222),
    [anon_sym_clocking] = ACTIONS(5222),
    [anon_sym_defparam] = ACTIONS(5222),
    [anon_sym_bind] = ACTIONS(5222),
    [anon_sym_rand] = ACTIONS(5222),
    [anon_sym_const] = ACTIONS(5222),
    [anon_sym_function] = ACTIONS(5222),
    [anon_sym_static] = ACTIONS(5222),
    [anon_sym_constraint] = ACTIONS(5222),
    [anon_sym_if] = ACTIONS(5222),
    [anon_sym_else] = ACTIONS(5222),
    [anon_sym_LBRACK] = ACTIONS(5220),
    [anon_sym_localparam] = ACTIONS(5222),
    [anon_sym_parameter] = ACTIONS(5222),
    [anon_sym_var] = ACTIONS(5222),
    [anon_sym_import] = ACTIONS(5222),
    [anon_sym_export] = ACTIONS(5222),
    [anon_sym_genvar] = ACTIONS(5222),
    [anon_sym_interconnect] = ACTIONS(5222),
    [anon_sym_typedef] = ACTIONS(5222),
    [anon_sym_enum] = ACTIONS(5222),
    [anon_sym_struct] = ACTIONS(5222),
    [anon_sym_union] = ACTIONS(5222),
    [anon_sym_nettype] = ACTIONS(5222),
    [anon_sym_automatic] = ACTIONS(5222),
    [anon_sym_string] = ACTIONS(5222),
    [anon_sym_chandle] = ACTIONS(5222),
    [anon_sym_event] = ACTIONS(5222),
    [anon_sym_byte] = ACTIONS(5222),
    [anon_sym_shortint] = ACTIONS(5222),
    [anon_sym_int] = ACTIONS(5222),
    [anon_sym_longint] = ACTIONS(5222),
    [anon_sym_integer] = ACTIONS(5222),
    [anon_sym_time] = ACTIONS(5222),
    [anon_sym_bit] = ACTIONS(5222),
    [anon_sym_logic] = ACTIONS(5222),
    [anon_sym_reg] = ACTIONS(5222),
    [anon_sym_shortreal] = ACTIONS(5222),
    [anon_sym_real] = ACTIONS(5222),
    [anon_sym_realtime] = ACTIONS(5222),
    [anon_sym_supply0] = ACTIONS(5222),
    [anon_sym_supply1] = ACTIONS(5222),
    [anon_sym_signed] = ACTIONS(5222),
    [anon_sym_unsigned] = ACTIONS(5222),
    [anon_sym_task] = ACTIONS(5222),
    [anon_sym_assert] = ACTIONS(5222),
    [anon_sym_property] = ACTIONS(5222),
    [anon_sym_assume] = ACTIONS(5222),
    [anon_sym_cover] = ACTIONS(5222),
    [anon_sym_sequence] = ACTIONS(5222),
    [anon_sym_restrict] = ACTIONS(5222),
    [anon_sym_not] = ACTIONS(5222),
    [anon_sym_or] = ACTIONS(5222),
    [anon_sym_and] = ACTIONS(5222),
    [anon_sym_case] = ACTIONS(5222),
    [anon_sym_always] = ACTIONS(5222),
    [anon_sym_covergroup] = ACTIONS(5222),
    [anon_sym_let] = ACTIONS(5222),
    [anon_sym_pulldown] = ACTIONS(5222),
    [anon_sym_pullup] = ACTIONS(5222),
    [anon_sym_cmos] = ACTIONS(5222),
    [anon_sym_rcmos] = ACTIONS(5222),
    [anon_sym_bufif0] = ACTIONS(5222),
    [anon_sym_bufif1] = ACTIONS(5222),
    [anon_sym_notif0] = ACTIONS(5222),
    [anon_sym_notif1] = ACTIONS(5222),
    [anon_sym_nmos] = ACTIONS(5222),
    [anon_sym_pmos] = ACTIONS(5222),
    [anon_sym_rnmos] = ACTIONS(5222),
    [anon_sym_rpmos] = ACTIONS(5222),
    [anon_sym_nand] = ACTIONS(5222),
    [anon_sym_nor] = ACTIONS(5222),
    [anon_sym_xor] = ACTIONS(5222),
    [anon_sym_xnor] = ACTIONS(5222),
    [anon_sym_buf] = ACTIONS(5222),
    [anon_sym_tranif0] = ACTIONS(5222),
    [anon_sym_tranif1] = ACTIONS(5222),
    [anon_sym_rtranif1] = ACTIONS(5222),
    [anon_sym_rtranif0] = ACTIONS(5222),
    [anon_sym_tran] = ACTIONS(5222),
    [anon_sym_rtran] = ACTIONS(5222),
    [anon_sym_generate] = ACTIONS(5222),
    [anon_sym_endgenerate] = ACTIONS(5222),
    [anon_sym_for] = ACTIONS(5222),
    [anon_sym_initial] = ACTIONS(5222),
    [anon_sym_assign] = ACTIONS(5222),
    [anon_sym_alias] = ACTIONS(5222),
    [anon_sym_always_comb] = ACTIONS(5222),
    [anon_sym_always_latch] = ACTIONS(5222),
    [anon_sym_always_ff] = ACTIONS(5222),
    [anon_sym_final] = ACTIONS(5222),
    [anon_sym_global] = ACTIONS(5222),
    [anon_sym_LPAREN_STAR] = ACTIONS(5220),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5220),
    [anon_sym_DOLLARunit] = ACTIONS(5220),
  },
  [4705] = {
    [sym_simple_identifier] = ACTIONS(4720),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_rand] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_end] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [4706] = {
    [sym_simple_identifier] = ACTIONS(5858),
    [anon_sym_wire] = ACTIONS(5858),
    [anon_sym_tri] = ACTIONS(5858),
    [anon_sym_tri0] = ACTIONS(5858),
    [anon_sym_tri1] = ACTIONS(5858),
    [anon_sym_wand] = ACTIONS(5858),
    [anon_sym_triand] = ACTIONS(5858),
    [anon_sym_wor] = ACTIONS(5858),
    [anon_sym_trior] = ACTIONS(5858),
    [anon_sym_trireg] = ACTIONS(5858),
    [anon_sym_uwire] = ACTIONS(5858),
    [anon_sym_SEMI] = ACTIONS(5860),
    [anon_sym_extern] = ACTIONS(5858),
    [anon_sym_interface] = ACTIONS(5858),
    [anon_sym_checker] = ACTIONS(5858),
    [anon_sym_virtual] = ACTIONS(5858),
    [anon_sym_class] = ACTIONS(5858),
    [anon_sym_type] = ACTIONS(5858),
    [anon_sym_DOLLARfatal] = ACTIONS(5860),
    [anon_sym_DOLLARerror] = ACTIONS(5860),
    [anon_sym_DOLLARwarning] = ACTIONS(5860),
    [anon_sym_DOLLARinfo] = ACTIONS(5860),
    [anon_sym_default] = ACTIONS(5858),
    [anon_sym_clocking] = ACTIONS(5858),
    [anon_sym_defparam] = ACTIONS(5858),
    [anon_sym_bind] = ACTIONS(5858),
    [anon_sym_rand] = ACTIONS(5858),
    [anon_sym_const] = ACTIONS(5858),
    [anon_sym_function] = ACTIONS(5858),
    [anon_sym_static] = ACTIONS(5858),
    [anon_sym_constraint] = ACTIONS(5858),
    [anon_sym_if] = ACTIONS(5858),
    [anon_sym_else] = ACTIONS(5858),
    [anon_sym_LBRACK] = ACTIONS(5860),
    [anon_sym_localparam] = ACTIONS(5858),
    [anon_sym_parameter] = ACTIONS(5858),
    [anon_sym_var] = ACTIONS(5858),
    [anon_sym_import] = ACTIONS(5858),
    [anon_sym_export] = ACTIONS(5858),
    [anon_sym_genvar] = ACTIONS(5858),
    [anon_sym_interconnect] = ACTIONS(5858),
    [anon_sym_typedef] = ACTIONS(5858),
    [anon_sym_enum] = ACTIONS(5858),
    [anon_sym_struct] = ACTIONS(5858),
    [anon_sym_union] = ACTIONS(5858),
    [anon_sym_nettype] = ACTIONS(5858),
    [anon_sym_automatic] = ACTIONS(5858),
    [anon_sym_string] = ACTIONS(5858),
    [anon_sym_chandle] = ACTIONS(5858),
    [anon_sym_event] = ACTIONS(5858),
    [anon_sym_byte] = ACTIONS(5858),
    [anon_sym_shortint] = ACTIONS(5858),
    [anon_sym_int] = ACTIONS(5858),
    [anon_sym_longint] = ACTIONS(5858),
    [anon_sym_integer] = ACTIONS(5858),
    [anon_sym_time] = ACTIONS(5858),
    [anon_sym_bit] = ACTIONS(5858),
    [anon_sym_logic] = ACTIONS(5858),
    [anon_sym_reg] = ACTIONS(5858),
    [anon_sym_shortreal] = ACTIONS(5858),
    [anon_sym_real] = ACTIONS(5858),
    [anon_sym_realtime] = ACTIONS(5858),
    [anon_sym_supply0] = ACTIONS(5858),
    [anon_sym_supply1] = ACTIONS(5858),
    [anon_sym_signed] = ACTIONS(5858),
    [anon_sym_unsigned] = ACTIONS(5858),
    [anon_sym_task] = ACTIONS(5858),
    [anon_sym_assert] = ACTIONS(5858),
    [anon_sym_property] = ACTIONS(5858),
    [anon_sym_assume] = ACTIONS(5858),
    [anon_sym_cover] = ACTIONS(5858),
    [anon_sym_sequence] = ACTIONS(5858),
    [anon_sym_restrict] = ACTIONS(5858),
    [anon_sym_not] = ACTIONS(5858),
    [anon_sym_or] = ACTIONS(5858),
    [anon_sym_and] = ACTIONS(5858),
    [anon_sym_case] = ACTIONS(5858),
    [anon_sym_always] = ACTIONS(5858),
    [anon_sym_covergroup] = ACTIONS(5858),
    [anon_sym_end] = ACTIONS(5858),
    [anon_sym_let] = ACTIONS(5858),
    [anon_sym_pulldown] = ACTIONS(5858),
    [anon_sym_pullup] = ACTIONS(5858),
    [anon_sym_cmos] = ACTIONS(5858),
    [anon_sym_rcmos] = ACTIONS(5858),
    [anon_sym_bufif0] = ACTIONS(5858),
    [anon_sym_bufif1] = ACTIONS(5858),
    [anon_sym_notif0] = ACTIONS(5858),
    [anon_sym_notif1] = ACTIONS(5858),
    [anon_sym_nmos] = ACTIONS(5858),
    [anon_sym_pmos] = ACTIONS(5858),
    [anon_sym_rnmos] = ACTIONS(5858),
    [anon_sym_rpmos] = ACTIONS(5858),
    [anon_sym_nand] = ACTIONS(5858),
    [anon_sym_nor] = ACTIONS(5858),
    [anon_sym_xor] = ACTIONS(5858),
    [anon_sym_xnor] = ACTIONS(5858),
    [anon_sym_buf] = ACTIONS(5858),
    [anon_sym_tranif0] = ACTIONS(5858),
    [anon_sym_tranif1] = ACTIONS(5858),
    [anon_sym_rtranif1] = ACTIONS(5858),
    [anon_sym_rtranif0] = ACTIONS(5858),
    [anon_sym_tran] = ACTIONS(5858),
    [anon_sym_rtran] = ACTIONS(5858),
    [anon_sym_generate] = ACTIONS(5858),
    [anon_sym_for] = ACTIONS(5858),
    [anon_sym_initial] = ACTIONS(5858),
    [anon_sym_assign] = ACTIONS(5858),
    [anon_sym_alias] = ACTIONS(5858),
    [anon_sym_always_comb] = ACTIONS(5858),
    [anon_sym_always_latch] = ACTIONS(5858),
    [anon_sym_always_ff] = ACTIONS(5858),
    [anon_sym_final] = ACTIONS(5858),
    [anon_sym_global] = ACTIONS(5858),
    [anon_sym_LPAREN_STAR] = ACTIONS(5860),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5860),
    [anon_sym_DOLLARunit] = ACTIONS(5860),
  },
  [4707] = {
    [sym_simple_identifier] = ACTIONS(4928),
    [anon_sym_wire] = ACTIONS(4928),
    [anon_sym_tri] = ACTIONS(4928),
    [anon_sym_tri0] = ACTIONS(4928),
    [anon_sym_tri1] = ACTIONS(4928),
    [anon_sym_wand] = ACTIONS(4928),
    [anon_sym_triand] = ACTIONS(4928),
    [anon_sym_wor] = ACTIONS(4928),
    [anon_sym_trior] = ACTIONS(4928),
    [anon_sym_trireg] = ACTIONS(4928),
    [anon_sym_uwire] = ACTIONS(4928),
    [anon_sym_SEMI] = ACTIONS(4926),
    [anon_sym_extern] = ACTIONS(4928),
    [anon_sym_interface] = ACTIONS(4928),
    [anon_sym_checker] = ACTIONS(4928),
    [anon_sym_virtual] = ACTIONS(4928),
    [anon_sym_class] = ACTIONS(4928),
    [anon_sym_type] = ACTIONS(4928),
    [anon_sym_DOLLARfatal] = ACTIONS(4926),
    [anon_sym_DOLLARerror] = ACTIONS(4926),
    [anon_sym_DOLLARwarning] = ACTIONS(4926),
    [anon_sym_DOLLARinfo] = ACTIONS(4926),
    [anon_sym_default] = ACTIONS(4928),
    [anon_sym_clocking] = ACTIONS(4928),
    [anon_sym_defparam] = ACTIONS(4928),
    [anon_sym_bind] = ACTIONS(4928),
    [anon_sym_rand] = ACTIONS(4928),
    [anon_sym_const] = ACTIONS(4928),
    [anon_sym_function] = ACTIONS(4928),
    [anon_sym_static] = ACTIONS(4928),
    [anon_sym_constraint] = ACTIONS(4928),
    [anon_sym_if] = ACTIONS(4928),
    [anon_sym_else] = ACTIONS(4928),
    [anon_sym_LBRACK] = ACTIONS(4926),
    [anon_sym_localparam] = ACTIONS(4928),
    [anon_sym_parameter] = ACTIONS(4928),
    [anon_sym_var] = ACTIONS(4928),
    [anon_sym_import] = ACTIONS(4928),
    [anon_sym_export] = ACTIONS(4928),
    [anon_sym_genvar] = ACTIONS(4928),
    [anon_sym_interconnect] = ACTIONS(4928),
    [anon_sym_typedef] = ACTIONS(4928),
    [anon_sym_enum] = ACTIONS(4928),
    [anon_sym_struct] = ACTIONS(4928),
    [anon_sym_union] = ACTIONS(4928),
    [anon_sym_nettype] = ACTIONS(4928),
    [anon_sym_automatic] = ACTIONS(4928),
    [anon_sym_string] = ACTIONS(4928),
    [anon_sym_chandle] = ACTIONS(4928),
    [anon_sym_event] = ACTIONS(4928),
    [anon_sym_byte] = ACTIONS(4928),
    [anon_sym_shortint] = ACTIONS(4928),
    [anon_sym_int] = ACTIONS(4928),
    [anon_sym_longint] = ACTIONS(4928),
    [anon_sym_integer] = ACTIONS(4928),
    [anon_sym_time] = ACTIONS(4928),
    [anon_sym_bit] = ACTIONS(4928),
    [anon_sym_logic] = ACTIONS(4928),
    [anon_sym_reg] = ACTIONS(4928),
    [anon_sym_shortreal] = ACTIONS(4928),
    [anon_sym_real] = ACTIONS(4928),
    [anon_sym_realtime] = ACTIONS(4928),
    [anon_sym_supply0] = ACTIONS(4928),
    [anon_sym_supply1] = ACTIONS(4928),
    [anon_sym_signed] = ACTIONS(4928),
    [anon_sym_unsigned] = ACTIONS(4928),
    [anon_sym_task] = ACTIONS(4928),
    [anon_sym_assert] = ACTIONS(4928),
    [anon_sym_property] = ACTIONS(4928),
    [anon_sym_assume] = ACTIONS(4928),
    [anon_sym_cover] = ACTIONS(4928),
    [anon_sym_sequence] = ACTIONS(4928),
    [anon_sym_restrict] = ACTIONS(4928),
    [anon_sym_not] = ACTIONS(4928),
    [anon_sym_or] = ACTIONS(4928),
    [anon_sym_and] = ACTIONS(4928),
    [anon_sym_case] = ACTIONS(4928),
    [anon_sym_always] = ACTIONS(4928),
    [anon_sym_covergroup] = ACTIONS(4928),
    [anon_sym_end] = ACTIONS(4928),
    [anon_sym_let] = ACTIONS(4928),
    [anon_sym_pulldown] = ACTIONS(4928),
    [anon_sym_pullup] = ACTIONS(4928),
    [anon_sym_cmos] = ACTIONS(4928),
    [anon_sym_rcmos] = ACTIONS(4928),
    [anon_sym_bufif0] = ACTIONS(4928),
    [anon_sym_bufif1] = ACTIONS(4928),
    [anon_sym_notif0] = ACTIONS(4928),
    [anon_sym_notif1] = ACTIONS(4928),
    [anon_sym_nmos] = ACTIONS(4928),
    [anon_sym_pmos] = ACTIONS(4928),
    [anon_sym_rnmos] = ACTIONS(4928),
    [anon_sym_rpmos] = ACTIONS(4928),
    [anon_sym_nand] = ACTIONS(4928),
    [anon_sym_nor] = ACTIONS(4928),
    [anon_sym_xor] = ACTIONS(4928),
    [anon_sym_xnor] = ACTIONS(4928),
    [anon_sym_buf] = ACTIONS(4928),
    [anon_sym_tranif0] = ACTIONS(4928),
    [anon_sym_tranif1] = ACTIONS(4928),
    [anon_sym_rtranif1] = ACTIONS(4928),
    [anon_sym_rtranif0] = ACTIONS(4928),
    [anon_sym_tran] = ACTIONS(4928),
    [anon_sym_rtran] = ACTIONS(4928),
    [anon_sym_generate] = ACTIONS(4928),
    [anon_sym_for] = ACTIONS(4928),
    [anon_sym_initial] = ACTIONS(4928),
    [anon_sym_assign] = ACTIONS(4928),
    [anon_sym_alias] = ACTIONS(4928),
    [anon_sym_always_comb] = ACTIONS(4928),
    [anon_sym_always_latch] = ACTIONS(4928),
    [anon_sym_always_ff] = ACTIONS(4928),
    [anon_sym_final] = ACTIONS(4928),
    [anon_sym_global] = ACTIONS(4928),
    [anon_sym_LPAREN_STAR] = ACTIONS(4926),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4926),
    [anon_sym_DOLLARunit] = ACTIONS(4926),
  },
  [4708] = {
    [sym_simple_identifier] = ACTIONS(5862),
    [anon_sym_wire] = ACTIONS(5862),
    [anon_sym_tri] = ACTIONS(5862),
    [anon_sym_tri0] = ACTIONS(5862),
    [anon_sym_tri1] = ACTIONS(5862),
    [anon_sym_wand] = ACTIONS(5862),
    [anon_sym_triand] = ACTIONS(5862),
    [anon_sym_wor] = ACTIONS(5862),
    [anon_sym_trior] = ACTIONS(5862),
    [anon_sym_trireg] = ACTIONS(5862),
    [anon_sym_uwire] = ACTIONS(5862),
    [anon_sym_SEMI] = ACTIONS(5864),
    [anon_sym_extern] = ACTIONS(5862),
    [anon_sym_interface] = ACTIONS(5862),
    [anon_sym_checker] = ACTIONS(5862),
    [anon_sym_virtual] = ACTIONS(5862),
    [anon_sym_class] = ACTIONS(5862),
    [anon_sym_type] = ACTIONS(5862),
    [anon_sym_DOLLARfatal] = ACTIONS(5864),
    [anon_sym_DOLLARerror] = ACTIONS(5864),
    [anon_sym_DOLLARwarning] = ACTIONS(5864),
    [anon_sym_DOLLARinfo] = ACTIONS(5864),
    [anon_sym_default] = ACTIONS(5862),
    [anon_sym_clocking] = ACTIONS(5862),
    [anon_sym_defparam] = ACTIONS(5862),
    [anon_sym_bind] = ACTIONS(5862),
    [anon_sym_rand] = ACTIONS(5862),
    [anon_sym_const] = ACTIONS(5862),
    [anon_sym_function] = ACTIONS(5862),
    [anon_sym_static] = ACTIONS(5862),
    [anon_sym_constraint] = ACTIONS(5862),
    [anon_sym_if] = ACTIONS(5862),
    [anon_sym_else] = ACTIONS(5862),
    [anon_sym_LBRACK] = ACTIONS(5864),
    [anon_sym_localparam] = ACTIONS(5862),
    [anon_sym_parameter] = ACTIONS(5862),
    [anon_sym_var] = ACTIONS(5862),
    [anon_sym_import] = ACTIONS(5862),
    [anon_sym_export] = ACTIONS(5862),
    [anon_sym_genvar] = ACTIONS(5862),
    [anon_sym_interconnect] = ACTIONS(5862),
    [anon_sym_typedef] = ACTIONS(5862),
    [anon_sym_enum] = ACTIONS(5862),
    [anon_sym_struct] = ACTIONS(5862),
    [anon_sym_union] = ACTIONS(5862),
    [anon_sym_nettype] = ACTIONS(5862),
    [anon_sym_automatic] = ACTIONS(5862),
    [anon_sym_string] = ACTIONS(5862),
    [anon_sym_chandle] = ACTIONS(5862),
    [anon_sym_event] = ACTIONS(5862),
    [anon_sym_byte] = ACTIONS(5862),
    [anon_sym_shortint] = ACTIONS(5862),
    [anon_sym_int] = ACTIONS(5862),
    [anon_sym_longint] = ACTIONS(5862),
    [anon_sym_integer] = ACTIONS(5862),
    [anon_sym_time] = ACTIONS(5862),
    [anon_sym_bit] = ACTIONS(5862),
    [anon_sym_logic] = ACTIONS(5862),
    [anon_sym_reg] = ACTIONS(5862),
    [anon_sym_shortreal] = ACTIONS(5862),
    [anon_sym_real] = ACTIONS(5862),
    [anon_sym_realtime] = ACTIONS(5862),
    [anon_sym_supply0] = ACTIONS(5862),
    [anon_sym_supply1] = ACTIONS(5862),
    [anon_sym_signed] = ACTIONS(5862),
    [anon_sym_unsigned] = ACTIONS(5862),
    [anon_sym_task] = ACTIONS(5862),
    [anon_sym_assert] = ACTIONS(5862),
    [anon_sym_property] = ACTIONS(5862),
    [anon_sym_assume] = ACTIONS(5862),
    [anon_sym_cover] = ACTIONS(5862),
    [anon_sym_sequence] = ACTIONS(5862),
    [anon_sym_restrict] = ACTIONS(5862),
    [anon_sym_not] = ACTIONS(5862),
    [anon_sym_or] = ACTIONS(5862),
    [anon_sym_and] = ACTIONS(5862),
    [anon_sym_case] = ACTIONS(5862),
    [anon_sym_always] = ACTIONS(5862),
    [anon_sym_covergroup] = ACTIONS(5862),
    [anon_sym_end] = ACTIONS(5862),
    [anon_sym_let] = ACTIONS(5862),
    [anon_sym_pulldown] = ACTIONS(5862),
    [anon_sym_pullup] = ACTIONS(5862),
    [anon_sym_cmos] = ACTIONS(5862),
    [anon_sym_rcmos] = ACTIONS(5862),
    [anon_sym_bufif0] = ACTIONS(5862),
    [anon_sym_bufif1] = ACTIONS(5862),
    [anon_sym_notif0] = ACTIONS(5862),
    [anon_sym_notif1] = ACTIONS(5862),
    [anon_sym_nmos] = ACTIONS(5862),
    [anon_sym_pmos] = ACTIONS(5862),
    [anon_sym_rnmos] = ACTIONS(5862),
    [anon_sym_rpmos] = ACTIONS(5862),
    [anon_sym_nand] = ACTIONS(5862),
    [anon_sym_nor] = ACTIONS(5862),
    [anon_sym_xor] = ACTIONS(5862),
    [anon_sym_xnor] = ACTIONS(5862),
    [anon_sym_buf] = ACTIONS(5862),
    [anon_sym_tranif0] = ACTIONS(5862),
    [anon_sym_tranif1] = ACTIONS(5862),
    [anon_sym_rtranif1] = ACTIONS(5862),
    [anon_sym_rtranif0] = ACTIONS(5862),
    [anon_sym_tran] = ACTIONS(5862),
    [anon_sym_rtran] = ACTIONS(5862),
    [anon_sym_generate] = ACTIONS(5862),
    [anon_sym_for] = ACTIONS(5862),
    [anon_sym_initial] = ACTIONS(5862),
    [anon_sym_assign] = ACTIONS(5862),
    [anon_sym_alias] = ACTIONS(5862),
    [anon_sym_always_comb] = ACTIONS(5862),
    [anon_sym_always_latch] = ACTIONS(5862),
    [anon_sym_always_ff] = ACTIONS(5862),
    [anon_sym_final] = ACTIONS(5862),
    [anon_sym_global] = ACTIONS(5862),
    [anon_sym_LPAREN_STAR] = ACTIONS(5864),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5864),
    [anon_sym_DOLLARunit] = ACTIONS(5864),
  },
  [4709] = {
    [sym_simple_identifier] = ACTIONS(5230),
    [anon_sym_wire] = ACTIONS(5230),
    [anon_sym_tri] = ACTIONS(5230),
    [anon_sym_tri0] = ACTIONS(5230),
    [anon_sym_tri1] = ACTIONS(5230),
    [anon_sym_wand] = ACTIONS(5230),
    [anon_sym_triand] = ACTIONS(5230),
    [anon_sym_wor] = ACTIONS(5230),
    [anon_sym_trior] = ACTIONS(5230),
    [anon_sym_trireg] = ACTIONS(5230),
    [anon_sym_uwire] = ACTIONS(5230),
    [anon_sym_SEMI] = ACTIONS(5228),
    [anon_sym_extern] = ACTIONS(5230),
    [anon_sym_interface] = ACTIONS(5230),
    [anon_sym_checker] = ACTIONS(5230),
    [anon_sym_virtual] = ACTIONS(5230),
    [anon_sym_class] = ACTIONS(5230),
    [anon_sym_type] = ACTIONS(5230),
    [anon_sym_DOLLARfatal] = ACTIONS(5228),
    [anon_sym_DOLLARerror] = ACTIONS(5228),
    [anon_sym_DOLLARwarning] = ACTIONS(5228),
    [anon_sym_DOLLARinfo] = ACTIONS(5228),
    [anon_sym_default] = ACTIONS(5230),
    [anon_sym_clocking] = ACTIONS(5230),
    [anon_sym_defparam] = ACTIONS(5230),
    [anon_sym_bind] = ACTIONS(5230),
    [anon_sym_rand] = ACTIONS(5230),
    [anon_sym_const] = ACTIONS(5230),
    [anon_sym_function] = ACTIONS(5230),
    [anon_sym_static] = ACTIONS(5230),
    [anon_sym_constraint] = ACTIONS(5230),
    [anon_sym_if] = ACTIONS(5230),
    [anon_sym_else] = ACTIONS(5230),
    [anon_sym_LBRACK] = ACTIONS(5228),
    [anon_sym_localparam] = ACTIONS(5230),
    [anon_sym_parameter] = ACTIONS(5230),
    [anon_sym_var] = ACTIONS(5230),
    [anon_sym_import] = ACTIONS(5230),
    [anon_sym_export] = ACTIONS(5230),
    [anon_sym_genvar] = ACTIONS(5230),
    [anon_sym_interconnect] = ACTIONS(5230),
    [anon_sym_typedef] = ACTIONS(5230),
    [anon_sym_enum] = ACTIONS(5230),
    [anon_sym_struct] = ACTIONS(5230),
    [anon_sym_union] = ACTIONS(5230),
    [anon_sym_nettype] = ACTIONS(5230),
    [anon_sym_automatic] = ACTIONS(5230),
    [anon_sym_string] = ACTIONS(5230),
    [anon_sym_chandle] = ACTIONS(5230),
    [anon_sym_event] = ACTIONS(5230),
    [anon_sym_byte] = ACTIONS(5230),
    [anon_sym_shortint] = ACTIONS(5230),
    [anon_sym_int] = ACTIONS(5230),
    [anon_sym_longint] = ACTIONS(5230),
    [anon_sym_integer] = ACTIONS(5230),
    [anon_sym_time] = ACTIONS(5230),
    [anon_sym_bit] = ACTIONS(5230),
    [anon_sym_logic] = ACTIONS(5230),
    [anon_sym_reg] = ACTIONS(5230),
    [anon_sym_shortreal] = ACTIONS(5230),
    [anon_sym_real] = ACTIONS(5230),
    [anon_sym_realtime] = ACTIONS(5230),
    [anon_sym_supply0] = ACTIONS(5230),
    [anon_sym_supply1] = ACTIONS(5230),
    [anon_sym_signed] = ACTIONS(5230),
    [anon_sym_unsigned] = ACTIONS(5230),
    [anon_sym_task] = ACTIONS(5230),
    [anon_sym_assert] = ACTIONS(5230),
    [anon_sym_property] = ACTIONS(5230),
    [anon_sym_assume] = ACTIONS(5230),
    [anon_sym_cover] = ACTIONS(5230),
    [anon_sym_sequence] = ACTIONS(5230),
    [anon_sym_restrict] = ACTIONS(5230),
    [anon_sym_not] = ACTIONS(5230),
    [anon_sym_or] = ACTIONS(5230),
    [anon_sym_and] = ACTIONS(5230),
    [anon_sym_case] = ACTIONS(5230),
    [anon_sym_always] = ACTIONS(5230),
    [anon_sym_covergroup] = ACTIONS(5230),
    [anon_sym_end] = ACTIONS(5230),
    [anon_sym_let] = ACTIONS(5230),
    [anon_sym_pulldown] = ACTIONS(5230),
    [anon_sym_pullup] = ACTIONS(5230),
    [anon_sym_cmos] = ACTIONS(5230),
    [anon_sym_rcmos] = ACTIONS(5230),
    [anon_sym_bufif0] = ACTIONS(5230),
    [anon_sym_bufif1] = ACTIONS(5230),
    [anon_sym_notif0] = ACTIONS(5230),
    [anon_sym_notif1] = ACTIONS(5230),
    [anon_sym_nmos] = ACTIONS(5230),
    [anon_sym_pmos] = ACTIONS(5230),
    [anon_sym_rnmos] = ACTIONS(5230),
    [anon_sym_rpmos] = ACTIONS(5230),
    [anon_sym_nand] = ACTIONS(5230),
    [anon_sym_nor] = ACTIONS(5230),
    [anon_sym_xor] = ACTIONS(5230),
    [anon_sym_xnor] = ACTIONS(5230),
    [anon_sym_buf] = ACTIONS(5230),
    [anon_sym_tranif0] = ACTIONS(5230),
    [anon_sym_tranif1] = ACTIONS(5230),
    [anon_sym_rtranif1] = ACTIONS(5230),
    [anon_sym_rtranif0] = ACTIONS(5230),
    [anon_sym_tran] = ACTIONS(5230),
    [anon_sym_rtran] = ACTIONS(5230),
    [anon_sym_generate] = ACTIONS(5230),
    [anon_sym_for] = ACTIONS(5230),
    [anon_sym_initial] = ACTIONS(5230),
    [anon_sym_assign] = ACTIONS(5230),
    [anon_sym_alias] = ACTIONS(5230),
    [anon_sym_always_comb] = ACTIONS(5230),
    [anon_sym_always_latch] = ACTIONS(5230),
    [anon_sym_always_ff] = ACTIONS(5230),
    [anon_sym_final] = ACTIONS(5230),
    [anon_sym_global] = ACTIONS(5230),
    [anon_sym_LPAREN_STAR] = ACTIONS(5228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5228),
    [anon_sym_DOLLARunit] = ACTIONS(5228),
  },
  [4710] = {
    [sym_simple_identifier] = ACTIONS(5234),
    [anon_sym_wire] = ACTIONS(5234),
    [anon_sym_tri] = ACTIONS(5234),
    [anon_sym_tri0] = ACTIONS(5234),
    [anon_sym_tri1] = ACTIONS(5234),
    [anon_sym_wand] = ACTIONS(5234),
    [anon_sym_triand] = ACTIONS(5234),
    [anon_sym_wor] = ACTIONS(5234),
    [anon_sym_trior] = ACTIONS(5234),
    [anon_sym_trireg] = ACTIONS(5234),
    [anon_sym_uwire] = ACTIONS(5234),
    [anon_sym_SEMI] = ACTIONS(5232),
    [anon_sym_extern] = ACTIONS(5234),
    [anon_sym_interface] = ACTIONS(5234),
    [anon_sym_checker] = ACTIONS(5234),
    [anon_sym_virtual] = ACTIONS(5234),
    [anon_sym_class] = ACTIONS(5234),
    [anon_sym_type] = ACTIONS(5234),
    [anon_sym_DOLLARfatal] = ACTIONS(5232),
    [anon_sym_DOLLARerror] = ACTIONS(5232),
    [anon_sym_DOLLARwarning] = ACTIONS(5232),
    [anon_sym_DOLLARinfo] = ACTIONS(5232),
    [anon_sym_default] = ACTIONS(5234),
    [anon_sym_clocking] = ACTIONS(5234),
    [anon_sym_defparam] = ACTIONS(5234),
    [anon_sym_bind] = ACTIONS(5234),
    [anon_sym_rand] = ACTIONS(5234),
    [anon_sym_const] = ACTIONS(5234),
    [anon_sym_function] = ACTIONS(5234),
    [anon_sym_static] = ACTIONS(5234),
    [anon_sym_constraint] = ACTIONS(5234),
    [anon_sym_if] = ACTIONS(5234),
    [anon_sym_else] = ACTIONS(5234),
    [anon_sym_LBRACK] = ACTIONS(5232),
    [anon_sym_localparam] = ACTIONS(5234),
    [anon_sym_parameter] = ACTIONS(5234),
    [anon_sym_var] = ACTIONS(5234),
    [anon_sym_import] = ACTIONS(5234),
    [anon_sym_export] = ACTIONS(5234),
    [anon_sym_genvar] = ACTIONS(5234),
    [anon_sym_interconnect] = ACTIONS(5234),
    [anon_sym_typedef] = ACTIONS(5234),
    [anon_sym_enum] = ACTIONS(5234),
    [anon_sym_struct] = ACTIONS(5234),
    [anon_sym_union] = ACTIONS(5234),
    [anon_sym_nettype] = ACTIONS(5234),
    [anon_sym_automatic] = ACTIONS(5234),
    [anon_sym_string] = ACTIONS(5234),
    [anon_sym_chandle] = ACTIONS(5234),
    [anon_sym_event] = ACTIONS(5234),
    [anon_sym_byte] = ACTIONS(5234),
    [anon_sym_shortint] = ACTIONS(5234),
    [anon_sym_int] = ACTIONS(5234),
    [anon_sym_longint] = ACTIONS(5234),
    [anon_sym_integer] = ACTIONS(5234),
    [anon_sym_time] = ACTIONS(5234),
    [anon_sym_bit] = ACTIONS(5234),
    [anon_sym_logic] = ACTIONS(5234),
    [anon_sym_reg] = ACTIONS(5234),
    [anon_sym_shortreal] = ACTIONS(5234),
    [anon_sym_real] = ACTIONS(5234),
    [anon_sym_realtime] = ACTIONS(5234),
    [anon_sym_supply0] = ACTIONS(5234),
    [anon_sym_supply1] = ACTIONS(5234),
    [anon_sym_signed] = ACTIONS(5234),
    [anon_sym_unsigned] = ACTIONS(5234),
    [anon_sym_task] = ACTIONS(5234),
    [anon_sym_assert] = ACTIONS(5234),
    [anon_sym_property] = ACTIONS(5234),
    [anon_sym_assume] = ACTIONS(5234),
    [anon_sym_cover] = ACTIONS(5234),
    [anon_sym_sequence] = ACTIONS(5234),
    [anon_sym_restrict] = ACTIONS(5234),
    [anon_sym_not] = ACTIONS(5234),
    [anon_sym_or] = ACTIONS(5234),
    [anon_sym_and] = ACTIONS(5234),
    [anon_sym_case] = ACTIONS(5234),
    [anon_sym_always] = ACTIONS(5234),
    [anon_sym_covergroup] = ACTIONS(5234),
    [anon_sym_end] = ACTIONS(5234),
    [anon_sym_let] = ACTIONS(5234),
    [anon_sym_pulldown] = ACTIONS(5234),
    [anon_sym_pullup] = ACTIONS(5234),
    [anon_sym_cmos] = ACTIONS(5234),
    [anon_sym_rcmos] = ACTIONS(5234),
    [anon_sym_bufif0] = ACTIONS(5234),
    [anon_sym_bufif1] = ACTIONS(5234),
    [anon_sym_notif0] = ACTIONS(5234),
    [anon_sym_notif1] = ACTIONS(5234),
    [anon_sym_nmos] = ACTIONS(5234),
    [anon_sym_pmos] = ACTIONS(5234),
    [anon_sym_rnmos] = ACTIONS(5234),
    [anon_sym_rpmos] = ACTIONS(5234),
    [anon_sym_nand] = ACTIONS(5234),
    [anon_sym_nor] = ACTIONS(5234),
    [anon_sym_xor] = ACTIONS(5234),
    [anon_sym_xnor] = ACTIONS(5234),
    [anon_sym_buf] = ACTIONS(5234),
    [anon_sym_tranif0] = ACTIONS(5234),
    [anon_sym_tranif1] = ACTIONS(5234),
    [anon_sym_rtranif1] = ACTIONS(5234),
    [anon_sym_rtranif0] = ACTIONS(5234),
    [anon_sym_tran] = ACTIONS(5234),
    [anon_sym_rtran] = ACTIONS(5234),
    [anon_sym_generate] = ACTIONS(5234),
    [anon_sym_for] = ACTIONS(5234),
    [anon_sym_initial] = ACTIONS(5234),
    [anon_sym_assign] = ACTIONS(5234),
    [anon_sym_alias] = ACTIONS(5234),
    [anon_sym_always_comb] = ACTIONS(5234),
    [anon_sym_always_latch] = ACTIONS(5234),
    [anon_sym_always_ff] = ACTIONS(5234),
    [anon_sym_final] = ACTIONS(5234),
    [anon_sym_global] = ACTIONS(5234),
    [anon_sym_LPAREN_STAR] = ACTIONS(5232),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5232),
    [anon_sym_DOLLARunit] = ACTIONS(5232),
  },
  [4711] = {
    [sym_simple_identifier] = ACTIONS(6597),
    [anon_sym_wire] = ACTIONS(6597),
    [anon_sym_tri] = ACTIONS(6597),
    [anon_sym_tri0] = ACTIONS(6597),
    [anon_sym_tri1] = ACTIONS(6597),
    [anon_sym_wand] = ACTIONS(6597),
    [anon_sym_triand] = ACTIONS(6597),
    [anon_sym_wor] = ACTIONS(6597),
    [anon_sym_trior] = ACTIONS(6597),
    [anon_sym_trireg] = ACTIONS(6597),
    [anon_sym_uwire] = ACTIONS(6597),
    [anon_sym_SEMI] = ACTIONS(6599),
    [anon_sym_extern] = ACTIONS(6597),
    [anon_sym_interface] = ACTIONS(6597),
    [anon_sym_checker] = ACTIONS(6597),
    [anon_sym_virtual] = ACTIONS(6597),
    [anon_sym_class] = ACTIONS(6597),
    [anon_sym_type] = ACTIONS(6597),
    [anon_sym_DOLLARfatal] = ACTIONS(6599),
    [anon_sym_DOLLARerror] = ACTIONS(6599),
    [anon_sym_DOLLARwarning] = ACTIONS(6599),
    [anon_sym_DOLLARinfo] = ACTIONS(6599),
    [anon_sym_default] = ACTIONS(6597),
    [anon_sym_clocking] = ACTIONS(6597),
    [anon_sym_defparam] = ACTIONS(6597),
    [anon_sym_bind] = ACTIONS(6597),
    [anon_sym_rand] = ACTIONS(6597),
    [anon_sym_const] = ACTIONS(6597),
    [anon_sym_function] = ACTIONS(6597),
    [anon_sym_static] = ACTIONS(6597),
    [anon_sym_constraint] = ACTIONS(6597),
    [anon_sym_if] = ACTIONS(6597),
    [anon_sym_else] = ACTIONS(6597),
    [anon_sym_LBRACK] = ACTIONS(6599),
    [anon_sym_localparam] = ACTIONS(6597),
    [anon_sym_parameter] = ACTIONS(6597),
    [anon_sym_var] = ACTIONS(6597),
    [anon_sym_import] = ACTIONS(6597),
    [anon_sym_export] = ACTIONS(6597),
    [anon_sym_genvar] = ACTIONS(6597),
    [anon_sym_interconnect] = ACTIONS(6597),
    [anon_sym_typedef] = ACTIONS(6597),
    [anon_sym_enum] = ACTIONS(6597),
    [anon_sym_struct] = ACTIONS(6597),
    [anon_sym_union] = ACTIONS(6597),
    [anon_sym_nettype] = ACTIONS(6597),
    [anon_sym_automatic] = ACTIONS(6597),
    [anon_sym_string] = ACTIONS(6597),
    [anon_sym_chandle] = ACTIONS(6597),
    [anon_sym_event] = ACTIONS(6597),
    [anon_sym_byte] = ACTIONS(6597),
    [anon_sym_shortint] = ACTIONS(6597),
    [anon_sym_int] = ACTIONS(6597),
    [anon_sym_longint] = ACTIONS(6597),
    [anon_sym_integer] = ACTIONS(6597),
    [anon_sym_time] = ACTIONS(6597),
    [anon_sym_bit] = ACTIONS(6597),
    [anon_sym_logic] = ACTIONS(6597),
    [anon_sym_reg] = ACTIONS(6597),
    [anon_sym_shortreal] = ACTIONS(6597),
    [anon_sym_real] = ACTIONS(6597),
    [anon_sym_realtime] = ACTIONS(6597),
    [anon_sym_supply0] = ACTIONS(6597),
    [anon_sym_supply1] = ACTIONS(6597),
    [anon_sym_signed] = ACTIONS(6597),
    [anon_sym_unsigned] = ACTIONS(6597),
    [anon_sym_task] = ACTIONS(6597),
    [anon_sym_assert] = ACTIONS(6597),
    [anon_sym_property] = ACTIONS(6597),
    [anon_sym_assume] = ACTIONS(6597),
    [anon_sym_cover] = ACTIONS(6597),
    [anon_sym_sequence] = ACTIONS(6597),
    [anon_sym_restrict] = ACTIONS(6597),
    [anon_sym_not] = ACTIONS(6597),
    [anon_sym_or] = ACTIONS(6597),
    [anon_sym_and] = ACTIONS(6597),
    [anon_sym_case] = ACTIONS(6597),
    [anon_sym_always] = ACTIONS(6597),
    [anon_sym_covergroup] = ACTIONS(6597),
    [anon_sym_end] = ACTIONS(6597),
    [anon_sym_let] = ACTIONS(6597),
    [anon_sym_pulldown] = ACTIONS(6597),
    [anon_sym_pullup] = ACTIONS(6597),
    [anon_sym_cmos] = ACTIONS(6597),
    [anon_sym_rcmos] = ACTIONS(6597),
    [anon_sym_bufif0] = ACTIONS(6597),
    [anon_sym_bufif1] = ACTIONS(6597),
    [anon_sym_notif0] = ACTIONS(6597),
    [anon_sym_notif1] = ACTIONS(6597),
    [anon_sym_nmos] = ACTIONS(6597),
    [anon_sym_pmos] = ACTIONS(6597),
    [anon_sym_rnmos] = ACTIONS(6597),
    [anon_sym_rpmos] = ACTIONS(6597),
    [anon_sym_nand] = ACTIONS(6597),
    [anon_sym_nor] = ACTIONS(6597),
    [anon_sym_xor] = ACTIONS(6597),
    [anon_sym_xnor] = ACTIONS(6597),
    [anon_sym_buf] = ACTIONS(6597),
    [anon_sym_tranif0] = ACTIONS(6597),
    [anon_sym_tranif1] = ACTIONS(6597),
    [anon_sym_rtranif1] = ACTIONS(6597),
    [anon_sym_rtranif0] = ACTIONS(6597),
    [anon_sym_tran] = ACTIONS(6597),
    [anon_sym_rtran] = ACTIONS(6597),
    [anon_sym_generate] = ACTIONS(6597),
    [anon_sym_for] = ACTIONS(6597),
    [anon_sym_initial] = ACTIONS(6597),
    [anon_sym_assign] = ACTIONS(6597),
    [anon_sym_alias] = ACTIONS(6597),
    [anon_sym_always_comb] = ACTIONS(6597),
    [anon_sym_always_latch] = ACTIONS(6597),
    [anon_sym_always_ff] = ACTIONS(6597),
    [anon_sym_final] = ACTIONS(6597),
    [anon_sym_global] = ACTIONS(6597),
    [anon_sym_LPAREN_STAR] = ACTIONS(6599),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6599),
    [anon_sym_DOLLARunit] = ACTIONS(6599),
  },
  [4712] = {
    [sym_simple_identifier] = ACTIONS(6727),
    [anon_sym_wire] = ACTIONS(6727),
    [anon_sym_tri] = ACTIONS(6727),
    [anon_sym_tri0] = ACTIONS(6727),
    [anon_sym_tri1] = ACTIONS(6727),
    [anon_sym_wand] = ACTIONS(6727),
    [anon_sym_triand] = ACTIONS(6727),
    [anon_sym_wor] = ACTIONS(6727),
    [anon_sym_trior] = ACTIONS(6727),
    [anon_sym_trireg] = ACTIONS(6727),
    [anon_sym_uwire] = ACTIONS(6727),
    [anon_sym_SEMI] = ACTIONS(6729),
    [anon_sym_extern] = ACTIONS(6727),
    [anon_sym_interface] = ACTIONS(6727),
    [anon_sym_checker] = ACTIONS(6727),
    [anon_sym_virtual] = ACTIONS(6727),
    [anon_sym_class] = ACTIONS(6727),
    [anon_sym_type] = ACTIONS(6727),
    [anon_sym_DOLLARfatal] = ACTIONS(6729),
    [anon_sym_DOLLARerror] = ACTIONS(6729),
    [anon_sym_DOLLARwarning] = ACTIONS(6729),
    [anon_sym_DOLLARinfo] = ACTIONS(6729),
    [anon_sym_default] = ACTIONS(6727),
    [anon_sym_clocking] = ACTIONS(6727),
    [anon_sym_defparam] = ACTIONS(6727),
    [anon_sym_bind] = ACTIONS(6727),
    [anon_sym_rand] = ACTIONS(6727),
    [anon_sym_const] = ACTIONS(6727),
    [anon_sym_function] = ACTIONS(6727),
    [anon_sym_static] = ACTIONS(6727),
    [anon_sym_constraint] = ACTIONS(6727),
    [anon_sym_if] = ACTIONS(6727),
    [anon_sym_else] = ACTIONS(6727),
    [anon_sym_LBRACK] = ACTIONS(6729),
    [anon_sym_localparam] = ACTIONS(6727),
    [anon_sym_parameter] = ACTIONS(6727),
    [anon_sym_var] = ACTIONS(6727),
    [anon_sym_import] = ACTIONS(6727),
    [anon_sym_export] = ACTIONS(6727),
    [anon_sym_genvar] = ACTIONS(6727),
    [anon_sym_interconnect] = ACTIONS(6727),
    [anon_sym_typedef] = ACTIONS(6727),
    [anon_sym_enum] = ACTIONS(6727),
    [anon_sym_struct] = ACTIONS(6727),
    [anon_sym_union] = ACTIONS(6727),
    [anon_sym_nettype] = ACTIONS(6727),
    [anon_sym_automatic] = ACTIONS(6727),
    [anon_sym_string] = ACTIONS(6727),
    [anon_sym_chandle] = ACTIONS(6727),
    [anon_sym_event] = ACTIONS(6727),
    [anon_sym_byte] = ACTIONS(6727),
    [anon_sym_shortint] = ACTIONS(6727),
    [anon_sym_int] = ACTIONS(6727),
    [anon_sym_longint] = ACTIONS(6727),
    [anon_sym_integer] = ACTIONS(6727),
    [anon_sym_time] = ACTIONS(6727),
    [anon_sym_bit] = ACTIONS(6727),
    [anon_sym_logic] = ACTIONS(6727),
    [anon_sym_reg] = ACTIONS(6727),
    [anon_sym_shortreal] = ACTIONS(6727),
    [anon_sym_real] = ACTIONS(6727),
    [anon_sym_realtime] = ACTIONS(6727),
    [anon_sym_supply0] = ACTIONS(6727),
    [anon_sym_supply1] = ACTIONS(6727),
    [anon_sym_signed] = ACTIONS(6727),
    [anon_sym_unsigned] = ACTIONS(6727),
    [anon_sym_task] = ACTIONS(6727),
    [anon_sym_assert] = ACTIONS(6727),
    [anon_sym_property] = ACTIONS(6727),
    [anon_sym_assume] = ACTIONS(6727),
    [anon_sym_cover] = ACTIONS(6727),
    [anon_sym_sequence] = ACTIONS(6727),
    [anon_sym_restrict] = ACTIONS(6727),
    [anon_sym_not] = ACTIONS(6727),
    [anon_sym_or] = ACTIONS(6727),
    [anon_sym_and] = ACTIONS(6727),
    [anon_sym_case] = ACTIONS(6727),
    [anon_sym_always] = ACTIONS(6727),
    [anon_sym_covergroup] = ACTIONS(6727),
    [anon_sym_end] = ACTIONS(6727),
    [anon_sym_let] = ACTIONS(6727),
    [anon_sym_pulldown] = ACTIONS(6727),
    [anon_sym_pullup] = ACTIONS(6727),
    [anon_sym_cmos] = ACTIONS(6727),
    [anon_sym_rcmos] = ACTIONS(6727),
    [anon_sym_bufif0] = ACTIONS(6727),
    [anon_sym_bufif1] = ACTIONS(6727),
    [anon_sym_notif0] = ACTIONS(6727),
    [anon_sym_notif1] = ACTIONS(6727),
    [anon_sym_nmos] = ACTIONS(6727),
    [anon_sym_pmos] = ACTIONS(6727),
    [anon_sym_rnmos] = ACTIONS(6727),
    [anon_sym_rpmos] = ACTIONS(6727),
    [anon_sym_nand] = ACTIONS(6727),
    [anon_sym_nor] = ACTIONS(6727),
    [anon_sym_xor] = ACTIONS(6727),
    [anon_sym_xnor] = ACTIONS(6727),
    [anon_sym_buf] = ACTIONS(6727),
    [anon_sym_tranif0] = ACTIONS(6727),
    [anon_sym_tranif1] = ACTIONS(6727),
    [anon_sym_rtranif1] = ACTIONS(6727),
    [anon_sym_rtranif0] = ACTIONS(6727),
    [anon_sym_tran] = ACTIONS(6727),
    [anon_sym_rtran] = ACTIONS(6727),
    [anon_sym_generate] = ACTIONS(6727),
    [anon_sym_for] = ACTIONS(6727),
    [anon_sym_initial] = ACTIONS(6727),
    [anon_sym_assign] = ACTIONS(6727),
    [anon_sym_alias] = ACTIONS(6727),
    [anon_sym_always_comb] = ACTIONS(6727),
    [anon_sym_always_latch] = ACTIONS(6727),
    [anon_sym_always_ff] = ACTIONS(6727),
    [anon_sym_final] = ACTIONS(6727),
    [anon_sym_global] = ACTIONS(6727),
    [anon_sym_LPAREN_STAR] = ACTIONS(6729),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6729),
    [anon_sym_DOLLARunit] = ACTIONS(6729),
  },
  [4713] = {
    [sym_simple_identifier] = ACTIONS(6799),
    [anon_sym_wire] = ACTIONS(6799),
    [anon_sym_tri] = ACTIONS(6799),
    [anon_sym_tri0] = ACTIONS(6799),
    [anon_sym_tri1] = ACTIONS(6799),
    [anon_sym_wand] = ACTIONS(6799),
    [anon_sym_triand] = ACTIONS(6799),
    [anon_sym_wor] = ACTIONS(6799),
    [anon_sym_trior] = ACTIONS(6799),
    [anon_sym_trireg] = ACTIONS(6799),
    [anon_sym_uwire] = ACTIONS(6799),
    [anon_sym_SEMI] = ACTIONS(6801),
    [anon_sym_extern] = ACTIONS(6799),
    [anon_sym_interface] = ACTIONS(6799),
    [anon_sym_checker] = ACTIONS(6799),
    [anon_sym_virtual] = ACTIONS(6799),
    [anon_sym_class] = ACTIONS(6799),
    [anon_sym_type] = ACTIONS(6799),
    [anon_sym_DOLLARfatal] = ACTIONS(6801),
    [anon_sym_DOLLARerror] = ACTIONS(6801),
    [anon_sym_DOLLARwarning] = ACTIONS(6801),
    [anon_sym_DOLLARinfo] = ACTIONS(6801),
    [anon_sym_default] = ACTIONS(6799),
    [anon_sym_clocking] = ACTIONS(6799),
    [anon_sym_defparam] = ACTIONS(6799),
    [anon_sym_bind] = ACTIONS(6799),
    [anon_sym_rand] = ACTIONS(6799),
    [anon_sym_const] = ACTIONS(6799),
    [anon_sym_function] = ACTIONS(6799),
    [anon_sym_static] = ACTIONS(6799),
    [anon_sym_constraint] = ACTIONS(6799),
    [anon_sym_if] = ACTIONS(6799),
    [anon_sym_else] = ACTIONS(6799),
    [anon_sym_LBRACK] = ACTIONS(6801),
    [anon_sym_localparam] = ACTIONS(6799),
    [anon_sym_parameter] = ACTIONS(6799),
    [anon_sym_var] = ACTIONS(6799),
    [anon_sym_import] = ACTIONS(6799),
    [anon_sym_export] = ACTIONS(6799),
    [anon_sym_genvar] = ACTIONS(6799),
    [anon_sym_interconnect] = ACTIONS(6799),
    [anon_sym_typedef] = ACTIONS(6799),
    [anon_sym_enum] = ACTIONS(6799),
    [anon_sym_struct] = ACTIONS(6799),
    [anon_sym_union] = ACTIONS(6799),
    [anon_sym_nettype] = ACTIONS(6799),
    [anon_sym_automatic] = ACTIONS(6799),
    [anon_sym_string] = ACTIONS(6799),
    [anon_sym_chandle] = ACTIONS(6799),
    [anon_sym_event] = ACTIONS(6799),
    [anon_sym_byte] = ACTIONS(6799),
    [anon_sym_shortint] = ACTIONS(6799),
    [anon_sym_int] = ACTIONS(6799),
    [anon_sym_longint] = ACTIONS(6799),
    [anon_sym_integer] = ACTIONS(6799),
    [anon_sym_time] = ACTIONS(6799),
    [anon_sym_bit] = ACTIONS(6799),
    [anon_sym_logic] = ACTIONS(6799),
    [anon_sym_reg] = ACTIONS(6799),
    [anon_sym_shortreal] = ACTIONS(6799),
    [anon_sym_real] = ACTIONS(6799),
    [anon_sym_realtime] = ACTIONS(6799),
    [anon_sym_supply0] = ACTIONS(6799),
    [anon_sym_supply1] = ACTIONS(6799),
    [anon_sym_signed] = ACTIONS(6799),
    [anon_sym_unsigned] = ACTIONS(6799),
    [anon_sym_task] = ACTIONS(6799),
    [anon_sym_assert] = ACTIONS(6799),
    [anon_sym_property] = ACTIONS(6799),
    [anon_sym_assume] = ACTIONS(6799),
    [anon_sym_cover] = ACTIONS(6799),
    [anon_sym_sequence] = ACTIONS(6799),
    [anon_sym_restrict] = ACTIONS(6799),
    [anon_sym_not] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(6799),
    [anon_sym_and] = ACTIONS(6799),
    [anon_sym_case] = ACTIONS(6799),
    [anon_sym_always] = ACTIONS(6799),
    [anon_sym_covergroup] = ACTIONS(6799),
    [anon_sym_end] = ACTIONS(6799),
    [anon_sym_let] = ACTIONS(6799),
    [anon_sym_pulldown] = ACTIONS(6799),
    [anon_sym_pullup] = ACTIONS(6799),
    [anon_sym_cmos] = ACTIONS(6799),
    [anon_sym_rcmos] = ACTIONS(6799),
    [anon_sym_bufif0] = ACTIONS(6799),
    [anon_sym_bufif1] = ACTIONS(6799),
    [anon_sym_notif0] = ACTIONS(6799),
    [anon_sym_notif1] = ACTIONS(6799),
    [anon_sym_nmos] = ACTIONS(6799),
    [anon_sym_pmos] = ACTIONS(6799),
    [anon_sym_rnmos] = ACTIONS(6799),
    [anon_sym_rpmos] = ACTIONS(6799),
    [anon_sym_nand] = ACTIONS(6799),
    [anon_sym_nor] = ACTIONS(6799),
    [anon_sym_xor] = ACTIONS(6799),
    [anon_sym_xnor] = ACTIONS(6799),
    [anon_sym_buf] = ACTIONS(6799),
    [anon_sym_tranif0] = ACTIONS(6799),
    [anon_sym_tranif1] = ACTIONS(6799),
    [anon_sym_rtranif1] = ACTIONS(6799),
    [anon_sym_rtranif0] = ACTIONS(6799),
    [anon_sym_tran] = ACTIONS(6799),
    [anon_sym_rtran] = ACTIONS(6799),
    [anon_sym_generate] = ACTIONS(6799),
    [anon_sym_for] = ACTIONS(6799),
    [anon_sym_initial] = ACTIONS(6799),
    [anon_sym_assign] = ACTIONS(6799),
    [anon_sym_alias] = ACTIONS(6799),
    [anon_sym_always_comb] = ACTIONS(6799),
    [anon_sym_always_latch] = ACTIONS(6799),
    [anon_sym_always_ff] = ACTIONS(6799),
    [anon_sym_final] = ACTIONS(6799),
    [anon_sym_global] = ACTIONS(6799),
    [anon_sym_LPAREN_STAR] = ACTIONS(6801),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6801),
    [anon_sym_DOLLARunit] = ACTIONS(6801),
  },
  [4714] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5049),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(5049),
    [sym_package_or_generate_item_declaration] = STATE(5049),
    [sym_anonymous_program] = STATE(5049),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(5049),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(5049),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(10893),
    [anon_sym_wire] = ACTIONS(10896),
    [anon_sym_tri] = ACTIONS(10896),
    [anon_sym_tri0] = ACTIONS(10896),
    [anon_sym_tri1] = ACTIONS(10896),
    [anon_sym_wand] = ACTIONS(10896),
    [anon_sym_triand] = ACTIONS(10896),
    [anon_sym_wor] = ACTIONS(10896),
    [anon_sym_trior] = ACTIONS(10896),
    [anon_sym_trireg] = ACTIONS(10896),
    [anon_sym_uwire] = ACTIONS(10896),
    [anon_sym_SEMI] = ACTIONS(10899),
    [anon_sym_interface] = ACTIONS(10902),
    [anon_sym_program] = ACTIONS(10905),
    [anon_sym_checker] = ACTIONS(10908),
    [anon_sym_virtual] = ACTIONS(10911),
    [anon_sym_class] = ACTIONS(10914),
    [anon_sym_endpackage] = ACTIONS(10917),
    [anon_sym_timeunit] = ACTIONS(10920),
    [anon_sym_timeprecision] = ACTIONS(10923),
    [anon_sym_type] = ACTIONS(10926),
    [anon_sym_bind] = ACTIONS(10929),
    [anon_sym_const] = ACTIONS(10932),
    [anon_sym_function] = ACTIONS(10935),
    [anon_sym_static] = ACTIONS(10938),
    [anon_sym_constraint] = ACTIONS(10941),
    [anon_sym_LBRACK] = ACTIONS(10944),
    [anon_sym_localparam] = ACTIONS(10947),
    [anon_sym_parameter] = ACTIONS(10950),
    [anon_sym_var] = ACTIONS(10953),
    [anon_sym_import] = ACTIONS(10956),
    [anon_sym_export] = ACTIONS(10959),
    [anon_sym_interconnect] = ACTIONS(10962),
    [anon_sym_typedef] = ACTIONS(10965),
    [anon_sym_enum] = ACTIONS(10968),
    [anon_sym_struct] = ACTIONS(10971),
    [anon_sym_union] = ACTIONS(10974),
    [anon_sym_nettype] = ACTIONS(10977),
    [anon_sym_automatic] = ACTIONS(10980),
    [anon_sym_string] = ACTIONS(10983),
    [anon_sym_chandle] = ACTIONS(10983),
    [anon_sym_event] = ACTIONS(10983),
    [anon_sym_byte] = ACTIONS(10986),
    [anon_sym_shortint] = ACTIONS(10986),
    [anon_sym_int] = ACTIONS(10986),
    [anon_sym_longint] = ACTIONS(10986),
    [anon_sym_integer] = ACTIONS(10986),
    [anon_sym_time] = ACTIONS(10986),
    [anon_sym_bit] = ACTIONS(10989),
    [anon_sym_logic] = ACTIONS(10989),
    [anon_sym_reg] = ACTIONS(10989),
    [anon_sym_shortreal] = ACTIONS(10992),
    [anon_sym_real] = ACTIONS(10992),
    [anon_sym_realtime] = ACTIONS(10992),
    [anon_sym_supply0] = ACTIONS(10896),
    [anon_sym_supply1] = ACTIONS(10896),
    [anon_sym_signed] = ACTIONS(10995),
    [anon_sym_unsigned] = ACTIONS(10995),
    [anon_sym_task] = ACTIONS(10998),
    [anon_sym_property] = ACTIONS(11001),
    [anon_sym_sequence] = ACTIONS(11004),
    [anon_sym_covergroup] = ACTIONS(11007),
    [anon_sym_let] = ACTIONS(11010),
    [anon_sym_LPAREN_STAR] = ACTIONS(11013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11016),
    [anon_sym_DOLLARunit] = ACTIONS(11019),
  },
  [4715] = {
    [sym_simple_identifier] = ACTIONS(6617),
    [anon_sym_wire] = ACTIONS(6617),
    [anon_sym_tri] = ACTIONS(6617),
    [anon_sym_tri0] = ACTIONS(6617),
    [anon_sym_tri1] = ACTIONS(6617),
    [anon_sym_wand] = ACTIONS(6617),
    [anon_sym_triand] = ACTIONS(6617),
    [anon_sym_wor] = ACTIONS(6617),
    [anon_sym_trior] = ACTIONS(6617),
    [anon_sym_trireg] = ACTIONS(6617),
    [anon_sym_uwire] = ACTIONS(6617),
    [anon_sym_SEMI] = ACTIONS(6619),
    [anon_sym_extern] = ACTIONS(6617),
    [anon_sym_interface] = ACTIONS(6617),
    [anon_sym_checker] = ACTIONS(6617),
    [anon_sym_virtual] = ACTIONS(6617),
    [anon_sym_class] = ACTIONS(6617),
    [anon_sym_type] = ACTIONS(6617),
    [anon_sym_DOLLARfatal] = ACTIONS(6619),
    [anon_sym_DOLLARerror] = ACTIONS(6619),
    [anon_sym_DOLLARwarning] = ACTIONS(6619),
    [anon_sym_DOLLARinfo] = ACTIONS(6619),
    [anon_sym_default] = ACTIONS(6617),
    [anon_sym_clocking] = ACTIONS(6617),
    [anon_sym_defparam] = ACTIONS(6617),
    [anon_sym_bind] = ACTIONS(6617),
    [anon_sym_rand] = ACTIONS(6617),
    [anon_sym_const] = ACTIONS(6617),
    [anon_sym_function] = ACTIONS(6617),
    [anon_sym_static] = ACTIONS(6617),
    [anon_sym_constraint] = ACTIONS(6617),
    [anon_sym_if] = ACTIONS(6617),
    [anon_sym_else] = ACTIONS(6617),
    [anon_sym_LBRACK] = ACTIONS(6619),
    [anon_sym_localparam] = ACTIONS(6617),
    [anon_sym_parameter] = ACTIONS(6617),
    [anon_sym_var] = ACTIONS(6617),
    [anon_sym_import] = ACTIONS(6617),
    [anon_sym_export] = ACTIONS(6617),
    [anon_sym_genvar] = ACTIONS(6617),
    [anon_sym_interconnect] = ACTIONS(6617),
    [anon_sym_typedef] = ACTIONS(6617),
    [anon_sym_enum] = ACTIONS(6617),
    [anon_sym_struct] = ACTIONS(6617),
    [anon_sym_union] = ACTIONS(6617),
    [anon_sym_nettype] = ACTIONS(6617),
    [anon_sym_automatic] = ACTIONS(6617),
    [anon_sym_string] = ACTIONS(6617),
    [anon_sym_chandle] = ACTIONS(6617),
    [anon_sym_event] = ACTIONS(6617),
    [anon_sym_byte] = ACTIONS(6617),
    [anon_sym_shortint] = ACTIONS(6617),
    [anon_sym_int] = ACTIONS(6617),
    [anon_sym_longint] = ACTIONS(6617),
    [anon_sym_integer] = ACTIONS(6617),
    [anon_sym_time] = ACTIONS(6617),
    [anon_sym_bit] = ACTIONS(6617),
    [anon_sym_logic] = ACTIONS(6617),
    [anon_sym_reg] = ACTIONS(6617),
    [anon_sym_shortreal] = ACTIONS(6617),
    [anon_sym_real] = ACTIONS(6617),
    [anon_sym_realtime] = ACTIONS(6617),
    [anon_sym_supply0] = ACTIONS(6617),
    [anon_sym_supply1] = ACTIONS(6617),
    [anon_sym_signed] = ACTIONS(6617),
    [anon_sym_unsigned] = ACTIONS(6617),
    [anon_sym_task] = ACTIONS(6617),
    [anon_sym_assert] = ACTIONS(6617),
    [anon_sym_property] = ACTIONS(6617),
    [anon_sym_assume] = ACTIONS(6617),
    [anon_sym_cover] = ACTIONS(6617),
    [anon_sym_sequence] = ACTIONS(6617),
    [anon_sym_restrict] = ACTIONS(6617),
    [anon_sym_not] = ACTIONS(6617),
    [anon_sym_or] = ACTIONS(6617),
    [anon_sym_and] = ACTIONS(6617),
    [anon_sym_case] = ACTIONS(6617),
    [anon_sym_always] = ACTIONS(6617),
    [anon_sym_covergroup] = ACTIONS(6617),
    [anon_sym_end] = ACTIONS(6617),
    [anon_sym_let] = ACTIONS(6617),
    [anon_sym_pulldown] = ACTIONS(6617),
    [anon_sym_pullup] = ACTIONS(6617),
    [anon_sym_cmos] = ACTIONS(6617),
    [anon_sym_rcmos] = ACTIONS(6617),
    [anon_sym_bufif0] = ACTIONS(6617),
    [anon_sym_bufif1] = ACTIONS(6617),
    [anon_sym_notif0] = ACTIONS(6617),
    [anon_sym_notif1] = ACTIONS(6617),
    [anon_sym_nmos] = ACTIONS(6617),
    [anon_sym_pmos] = ACTIONS(6617),
    [anon_sym_rnmos] = ACTIONS(6617),
    [anon_sym_rpmos] = ACTIONS(6617),
    [anon_sym_nand] = ACTIONS(6617),
    [anon_sym_nor] = ACTIONS(6617),
    [anon_sym_xor] = ACTIONS(6617),
    [anon_sym_xnor] = ACTIONS(6617),
    [anon_sym_buf] = ACTIONS(6617),
    [anon_sym_tranif0] = ACTIONS(6617),
    [anon_sym_tranif1] = ACTIONS(6617),
    [anon_sym_rtranif1] = ACTIONS(6617),
    [anon_sym_rtranif0] = ACTIONS(6617),
    [anon_sym_tran] = ACTIONS(6617),
    [anon_sym_rtran] = ACTIONS(6617),
    [anon_sym_generate] = ACTIONS(6617),
    [anon_sym_for] = ACTIONS(6617),
    [anon_sym_initial] = ACTIONS(6617),
    [anon_sym_assign] = ACTIONS(6617),
    [anon_sym_alias] = ACTIONS(6617),
    [anon_sym_always_comb] = ACTIONS(6617),
    [anon_sym_always_latch] = ACTIONS(6617),
    [anon_sym_always_ff] = ACTIONS(6617),
    [anon_sym_final] = ACTIONS(6617),
    [anon_sym_global] = ACTIONS(6617),
    [anon_sym_LPAREN_STAR] = ACTIONS(6619),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6619),
    [anon_sym_DOLLARunit] = ACTIONS(6619),
  },
  [4716] = {
    [sym_simple_identifier] = ACTIONS(6327),
    [anon_sym_wire] = ACTIONS(6327),
    [anon_sym_tri] = ACTIONS(6327),
    [anon_sym_tri0] = ACTIONS(6327),
    [anon_sym_tri1] = ACTIONS(6327),
    [anon_sym_wand] = ACTIONS(6327),
    [anon_sym_triand] = ACTIONS(6327),
    [anon_sym_wor] = ACTIONS(6327),
    [anon_sym_trior] = ACTIONS(6327),
    [anon_sym_trireg] = ACTIONS(6327),
    [anon_sym_uwire] = ACTIONS(6327),
    [anon_sym_SEMI] = ACTIONS(6329),
    [anon_sym_extern] = ACTIONS(6327),
    [anon_sym_interface] = ACTIONS(6327),
    [anon_sym_checker] = ACTIONS(6327),
    [anon_sym_virtual] = ACTIONS(6327),
    [anon_sym_class] = ACTIONS(6327),
    [anon_sym_type] = ACTIONS(6327),
    [anon_sym_DOLLARfatal] = ACTIONS(6329),
    [anon_sym_DOLLARerror] = ACTIONS(6329),
    [anon_sym_DOLLARwarning] = ACTIONS(6329),
    [anon_sym_DOLLARinfo] = ACTIONS(6329),
    [anon_sym_default] = ACTIONS(6327),
    [anon_sym_clocking] = ACTIONS(6327),
    [anon_sym_defparam] = ACTIONS(6327),
    [anon_sym_bind] = ACTIONS(6327),
    [anon_sym_rand] = ACTIONS(6327),
    [anon_sym_const] = ACTIONS(6327),
    [anon_sym_function] = ACTIONS(6327),
    [anon_sym_static] = ACTIONS(6327),
    [anon_sym_constraint] = ACTIONS(6327),
    [anon_sym_if] = ACTIONS(6327),
    [anon_sym_else] = ACTIONS(6327),
    [anon_sym_LBRACK] = ACTIONS(6329),
    [anon_sym_localparam] = ACTIONS(6327),
    [anon_sym_parameter] = ACTIONS(6327),
    [anon_sym_var] = ACTIONS(6327),
    [anon_sym_import] = ACTIONS(6327),
    [anon_sym_export] = ACTIONS(6327),
    [anon_sym_genvar] = ACTIONS(6327),
    [anon_sym_interconnect] = ACTIONS(6327),
    [anon_sym_typedef] = ACTIONS(6327),
    [anon_sym_enum] = ACTIONS(6327),
    [anon_sym_struct] = ACTIONS(6327),
    [anon_sym_union] = ACTIONS(6327),
    [anon_sym_nettype] = ACTIONS(6327),
    [anon_sym_automatic] = ACTIONS(6327),
    [anon_sym_string] = ACTIONS(6327),
    [anon_sym_chandle] = ACTIONS(6327),
    [anon_sym_event] = ACTIONS(6327),
    [anon_sym_byte] = ACTIONS(6327),
    [anon_sym_shortint] = ACTIONS(6327),
    [anon_sym_int] = ACTIONS(6327),
    [anon_sym_longint] = ACTIONS(6327),
    [anon_sym_integer] = ACTIONS(6327),
    [anon_sym_time] = ACTIONS(6327),
    [anon_sym_bit] = ACTIONS(6327),
    [anon_sym_logic] = ACTIONS(6327),
    [anon_sym_reg] = ACTIONS(6327),
    [anon_sym_shortreal] = ACTIONS(6327),
    [anon_sym_real] = ACTIONS(6327),
    [anon_sym_realtime] = ACTIONS(6327),
    [anon_sym_supply0] = ACTIONS(6327),
    [anon_sym_supply1] = ACTIONS(6327),
    [anon_sym_signed] = ACTIONS(6327),
    [anon_sym_unsigned] = ACTIONS(6327),
    [anon_sym_task] = ACTIONS(6327),
    [anon_sym_assert] = ACTIONS(6327),
    [anon_sym_property] = ACTIONS(6327),
    [anon_sym_assume] = ACTIONS(6327),
    [anon_sym_cover] = ACTIONS(6327),
    [anon_sym_sequence] = ACTIONS(6327),
    [anon_sym_restrict] = ACTIONS(6327),
    [anon_sym_not] = ACTIONS(6327),
    [anon_sym_or] = ACTIONS(6327),
    [anon_sym_and] = ACTIONS(6327),
    [anon_sym_case] = ACTIONS(6327),
    [anon_sym_always] = ACTIONS(6327),
    [anon_sym_covergroup] = ACTIONS(6327),
    [anon_sym_end] = ACTIONS(6327),
    [anon_sym_let] = ACTIONS(6327),
    [anon_sym_pulldown] = ACTIONS(6327),
    [anon_sym_pullup] = ACTIONS(6327),
    [anon_sym_cmos] = ACTIONS(6327),
    [anon_sym_rcmos] = ACTIONS(6327),
    [anon_sym_bufif0] = ACTIONS(6327),
    [anon_sym_bufif1] = ACTIONS(6327),
    [anon_sym_notif0] = ACTIONS(6327),
    [anon_sym_notif1] = ACTIONS(6327),
    [anon_sym_nmos] = ACTIONS(6327),
    [anon_sym_pmos] = ACTIONS(6327),
    [anon_sym_rnmos] = ACTIONS(6327),
    [anon_sym_rpmos] = ACTIONS(6327),
    [anon_sym_nand] = ACTIONS(6327),
    [anon_sym_nor] = ACTIONS(6327),
    [anon_sym_xor] = ACTIONS(6327),
    [anon_sym_xnor] = ACTIONS(6327),
    [anon_sym_buf] = ACTIONS(6327),
    [anon_sym_tranif0] = ACTIONS(6327),
    [anon_sym_tranif1] = ACTIONS(6327),
    [anon_sym_rtranif1] = ACTIONS(6327),
    [anon_sym_rtranif0] = ACTIONS(6327),
    [anon_sym_tran] = ACTIONS(6327),
    [anon_sym_rtran] = ACTIONS(6327),
    [anon_sym_generate] = ACTIONS(6327),
    [anon_sym_for] = ACTIONS(6327),
    [anon_sym_initial] = ACTIONS(6327),
    [anon_sym_assign] = ACTIONS(6327),
    [anon_sym_alias] = ACTIONS(6327),
    [anon_sym_always_comb] = ACTIONS(6327),
    [anon_sym_always_latch] = ACTIONS(6327),
    [anon_sym_always_ff] = ACTIONS(6327),
    [anon_sym_final] = ACTIONS(6327),
    [anon_sym_global] = ACTIONS(6327),
    [anon_sym_LPAREN_STAR] = ACTIONS(6329),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6329),
    [anon_sym_DOLLARunit] = ACTIONS(6329),
  },
  [4717] = {
    [sym_simple_identifier] = ACTIONS(6449),
    [anon_sym_wire] = ACTIONS(6449),
    [anon_sym_tri] = ACTIONS(6449),
    [anon_sym_tri0] = ACTIONS(6449),
    [anon_sym_tri1] = ACTIONS(6449),
    [anon_sym_wand] = ACTIONS(6449),
    [anon_sym_triand] = ACTIONS(6449),
    [anon_sym_wor] = ACTIONS(6449),
    [anon_sym_trior] = ACTIONS(6449),
    [anon_sym_trireg] = ACTIONS(6449),
    [anon_sym_uwire] = ACTIONS(6449),
    [anon_sym_SEMI] = ACTIONS(6451),
    [anon_sym_extern] = ACTIONS(6449),
    [anon_sym_interface] = ACTIONS(6449),
    [anon_sym_checker] = ACTIONS(6449),
    [anon_sym_virtual] = ACTIONS(6449),
    [anon_sym_class] = ACTIONS(6449),
    [anon_sym_type] = ACTIONS(6449),
    [anon_sym_DOLLARfatal] = ACTIONS(6451),
    [anon_sym_DOLLARerror] = ACTIONS(6451),
    [anon_sym_DOLLARwarning] = ACTIONS(6451),
    [anon_sym_DOLLARinfo] = ACTIONS(6451),
    [anon_sym_default] = ACTIONS(6449),
    [anon_sym_clocking] = ACTIONS(6449),
    [anon_sym_defparam] = ACTIONS(6449),
    [anon_sym_bind] = ACTIONS(6449),
    [anon_sym_rand] = ACTIONS(6449),
    [anon_sym_const] = ACTIONS(6449),
    [anon_sym_function] = ACTIONS(6449),
    [anon_sym_static] = ACTIONS(6449),
    [anon_sym_constraint] = ACTIONS(6449),
    [anon_sym_if] = ACTIONS(6449),
    [anon_sym_else] = ACTIONS(6449),
    [anon_sym_LBRACK] = ACTIONS(6451),
    [anon_sym_localparam] = ACTIONS(6449),
    [anon_sym_parameter] = ACTIONS(6449),
    [anon_sym_var] = ACTIONS(6449),
    [anon_sym_import] = ACTIONS(6449),
    [anon_sym_export] = ACTIONS(6449),
    [anon_sym_genvar] = ACTIONS(6449),
    [anon_sym_interconnect] = ACTIONS(6449),
    [anon_sym_typedef] = ACTIONS(6449),
    [anon_sym_enum] = ACTIONS(6449),
    [anon_sym_struct] = ACTIONS(6449),
    [anon_sym_union] = ACTIONS(6449),
    [anon_sym_nettype] = ACTIONS(6449),
    [anon_sym_automatic] = ACTIONS(6449),
    [anon_sym_string] = ACTIONS(6449),
    [anon_sym_chandle] = ACTIONS(6449),
    [anon_sym_event] = ACTIONS(6449),
    [anon_sym_byte] = ACTIONS(6449),
    [anon_sym_shortint] = ACTIONS(6449),
    [anon_sym_int] = ACTIONS(6449),
    [anon_sym_longint] = ACTIONS(6449),
    [anon_sym_integer] = ACTIONS(6449),
    [anon_sym_time] = ACTIONS(6449),
    [anon_sym_bit] = ACTIONS(6449),
    [anon_sym_logic] = ACTIONS(6449),
    [anon_sym_reg] = ACTIONS(6449),
    [anon_sym_shortreal] = ACTIONS(6449),
    [anon_sym_real] = ACTIONS(6449),
    [anon_sym_realtime] = ACTIONS(6449),
    [anon_sym_supply0] = ACTIONS(6449),
    [anon_sym_supply1] = ACTIONS(6449),
    [anon_sym_signed] = ACTIONS(6449),
    [anon_sym_unsigned] = ACTIONS(6449),
    [anon_sym_task] = ACTIONS(6449),
    [anon_sym_assert] = ACTIONS(6449),
    [anon_sym_property] = ACTIONS(6449),
    [anon_sym_assume] = ACTIONS(6449),
    [anon_sym_cover] = ACTIONS(6449),
    [anon_sym_sequence] = ACTIONS(6449),
    [anon_sym_restrict] = ACTIONS(6449),
    [anon_sym_not] = ACTIONS(6449),
    [anon_sym_or] = ACTIONS(6449),
    [anon_sym_and] = ACTIONS(6449),
    [anon_sym_case] = ACTIONS(6449),
    [anon_sym_always] = ACTIONS(6449),
    [anon_sym_covergroup] = ACTIONS(6449),
    [anon_sym_end] = ACTIONS(6449),
    [anon_sym_let] = ACTIONS(6449),
    [anon_sym_pulldown] = ACTIONS(6449),
    [anon_sym_pullup] = ACTIONS(6449),
    [anon_sym_cmos] = ACTIONS(6449),
    [anon_sym_rcmos] = ACTIONS(6449),
    [anon_sym_bufif0] = ACTIONS(6449),
    [anon_sym_bufif1] = ACTIONS(6449),
    [anon_sym_notif0] = ACTIONS(6449),
    [anon_sym_notif1] = ACTIONS(6449),
    [anon_sym_nmos] = ACTIONS(6449),
    [anon_sym_pmos] = ACTIONS(6449),
    [anon_sym_rnmos] = ACTIONS(6449),
    [anon_sym_rpmos] = ACTIONS(6449),
    [anon_sym_nand] = ACTIONS(6449),
    [anon_sym_nor] = ACTIONS(6449),
    [anon_sym_xor] = ACTIONS(6449),
    [anon_sym_xnor] = ACTIONS(6449),
    [anon_sym_buf] = ACTIONS(6449),
    [anon_sym_tranif0] = ACTIONS(6449),
    [anon_sym_tranif1] = ACTIONS(6449),
    [anon_sym_rtranif1] = ACTIONS(6449),
    [anon_sym_rtranif0] = ACTIONS(6449),
    [anon_sym_tran] = ACTIONS(6449),
    [anon_sym_rtran] = ACTIONS(6449),
    [anon_sym_generate] = ACTIONS(6449),
    [anon_sym_for] = ACTIONS(6449),
    [anon_sym_initial] = ACTIONS(6449),
    [anon_sym_assign] = ACTIONS(6449),
    [anon_sym_alias] = ACTIONS(6449),
    [anon_sym_always_comb] = ACTIONS(6449),
    [anon_sym_always_latch] = ACTIONS(6449),
    [anon_sym_always_ff] = ACTIONS(6449),
    [anon_sym_final] = ACTIONS(6449),
    [anon_sym_global] = ACTIONS(6449),
    [anon_sym_LPAREN_STAR] = ACTIONS(6451),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6451),
    [anon_sym_DOLLARunit] = ACTIONS(6451),
  },
  [4718] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_rand] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_endgenerate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [4719] = {
    [sym_simple_identifier] = ACTIONS(4646),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_rand] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_end] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [4720] = {
    [sym_simple_identifier] = ACTIONS(5880),
    [anon_sym_wire] = ACTIONS(5880),
    [anon_sym_tri] = ACTIONS(5880),
    [anon_sym_tri0] = ACTIONS(5880),
    [anon_sym_tri1] = ACTIONS(5880),
    [anon_sym_wand] = ACTIONS(5880),
    [anon_sym_triand] = ACTIONS(5880),
    [anon_sym_wor] = ACTIONS(5880),
    [anon_sym_trior] = ACTIONS(5880),
    [anon_sym_trireg] = ACTIONS(5880),
    [anon_sym_uwire] = ACTIONS(5880),
    [anon_sym_SEMI] = ACTIONS(5882),
    [anon_sym_extern] = ACTIONS(5880),
    [anon_sym_interface] = ACTIONS(5880),
    [anon_sym_checker] = ACTIONS(5880),
    [anon_sym_virtual] = ACTIONS(5880),
    [anon_sym_class] = ACTIONS(5880),
    [anon_sym_type] = ACTIONS(5880),
    [anon_sym_DOLLARfatal] = ACTIONS(5882),
    [anon_sym_DOLLARerror] = ACTIONS(5882),
    [anon_sym_DOLLARwarning] = ACTIONS(5882),
    [anon_sym_DOLLARinfo] = ACTIONS(5882),
    [anon_sym_default] = ACTIONS(5880),
    [anon_sym_clocking] = ACTIONS(5880),
    [anon_sym_defparam] = ACTIONS(5880),
    [anon_sym_bind] = ACTIONS(5880),
    [anon_sym_rand] = ACTIONS(5880),
    [anon_sym_const] = ACTIONS(5880),
    [anon_sym_function] = ACTIONS(5880),
    [anon_sym_static] = ACTIONS(5880),
    [anon_sym_constraint] = ACTIONS(5880),
    [anon_sym_if] = ACTIONS(5880),
    [anon_sym_else] = ACTIONS(5880),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_localparam] = ACTIONS(5880),
    [anon_sym_parameter] = ACTIONS(5880),
    [anon_sym_var] = ACTIONS(5880),
    [anon_sym_import] = ACTIONS(5880),
    [anon_sym_export] = ACTIONS(5880),
    [anon_sym_genvar] = ACTIONS(5880),
    [anon_sym_interconnect] = ACTIONS(5880),
    [anon_sym_typedef] = ACTIONS(5880),
    [anon_sym_enum] = ACTIONS(5880),
    [anon_sym_struct] = ACTIONS(5880),
    [anon_sym_union] = ACTIONS(5880),
    [anon_sym_nettype] = ACTIONS(5880),
    [anon_sym_automatic] = ACTIONS(5880),
    [anon_sym_string] = ACTIONS(5880),
    [anon_sym_chandle] = ACTIONS(5880),
    [anon_sym_event] = ACTIONS(5880),
    [anon_sym_byte] = ACTIONS(5880),
    [anon_sym_shortint] = ACTIONS(5880),
    [anon_sym_int] = ACTIONS(5880),
    [anon_sym_longint] = ACTIONS(5880),
    [anon_sym_integer] = ACTIONS(5880),
    [anon_sym_time] = ACTIONS(5880),
    [anon_sym_bit] = ACTIONS(5880),
    [anon_sym_logic] = ACTIONS(5880),
    [anon_sym_reg] = ACTIONS(5880),
    [anon_sym_shortreal] = ACTIONS(5880),
    [anon_sym_real] = ACTIONS(5880),
    [anon_sym_realtime] = ACTIONS(5880),
    [anon_sym_supply0] = ACTIONS(5880),
    [anon_sym_supply1] = ACTIONS(5880),
    [anon_sym_signed] = ACTIONS(5880),
    [anon_sym_unsigned] = ACTIONS(5880),
    [anon_sym_task] = ACTIONS(5880),
    [anon_sym_assert] = ACTIONS(5880),
    [anon_sym_property] = ACTIONS(5880),
    [anon_sym_assume] = ACTIONS(5880),
    [anon_sym_cover] = ACTIONS(5880),
    [anon_sym_sequence] = ACTIONS(5880),
    [anon_sym_restrict] = ACTIONS(5880),
    [anon_sym_not] = ACTIONS(5880),
    [anon_sym_or] = ACTIONS(5880),
    [anon_sym_and] = ACTIONS(5880),
    [anon_sym_case] = ACTIONS(5880),
    [anon_sym_always] = ACTIONS(5880),
    [anon_sym_covergroup] = ACTIONS(5880),
    [anon_sym_let] = ACTIONS(5880),
    [anon_sym_pulldown] = ACTIONS(5880),
    [anon_sym_pullup] = ACTIONS(5880),
    [anon_sym_cmos] = ACTIONS(5880),
    [anon_sym_rcmos] = ACTIONS(5880),
    [anon_sym_bufif0] = ACTIONS(5880),
    [anon_sym_bufif1] = ACTIONS(5880),
    [anon_sym_notif0] = ACTIONS(5880),
    [anon_sym_notif1] = ACTIONS(5880),
    [anon_sym_nmos] = ACTIONS(5880),
    [anon_sym_pmos] = ACTIONS(5880),
    [anon_sym_rnmos] = ACTIONS(5880),
    [anon_sym_rpmos] = ACTIONS(5880),
    [anon_sym_nand] = ACTIONS(5880),
    [anon_sym_nor] = ACTIONS(5880),
    [anon_sym_xor] = ACTIONS(5880),
    [anon_sym_xnor] = ACTIONS(5880),
    [anon_sym_buf] = ACTIONS(5880),
    [anon_sym_tranif0] = ACTIONS(5880),
    [anon_sym_tranif1] = ACTIONS(5880),
    [anon_sym_rtranif1] = ACTIONS(5880),
    [anon_sym_rtranif0] = ACTIONS(5880),
    [anon_sym_tran] = ACTIONS(5880),
    [anon_sym_rtran] = ACTIONS(5880),
    [anon_sym_generate] = ACTIONS(5880),
    [anon_sym_endgenerate] = ACTIONS(5880),
    [anon_sym_for] = ACTIONS(5880),
    [anon_sym_initial] = ACTIONS(5880),
    [anon_sym_assign] = ACTIONS(5880),
    [anon_sym_alias] = ACTIONS(5880),
    [anon_sym_always_comb] = ACTIONS(5880),
    [anon_sym_always_latch] = ACTIONS(5880),
    [anon_sym_always_ff] = ACTIONS(5880),
    [anon_sym_final] = ACTIONS(5880),
    [anon_sym_global] = ACTIONS(5880),
    [anon_sym_LPAREN_STAR] = ACTIONS(5882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5882),
    [anon_sym_DOLLARunit] = ACTIONS(5882),
  },
  [4721] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11022),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4722] = {
    [sym_simple_identifier] = ACTIONS(6743),
    [anon_sym_wire] = ACTIONS(6743),
    [anon_sym_tri] = ACTIONS(6743),
    [anon_sym_tri0] = ACTIONS(6743),
    [anon_sym_tri1] = ACTIONS(6743),
    [anon_sym_wand] = ACTIONS(6743),
    [anon_sym_triand] = ACTIONS(6743),
    [anon_sym_wor] = ACTIONS(6743),
    [anon_sym_trior] = ACTIONS(6743),
    [anon_sym_trireg] = ACTIONS(6743),
    [anon_sym_uwire] = ACTIONS(6743),
    [anon_sym_SEMI] = ACTIONS(6745),
    [anon_sym_extern] = ACTIONS(6743),
    [anon_sym_interface] = ACTIONS(6743),
    [anon_sym_checker] = ACTIONS(6743),
    [anon_sym_virtual] = ACTIONS(6743),
    [anon_sym_class] = ACTIONS(6743),
    [anon_sym_type] = ACTIONS(6743),
    [anon_sym_DOLLARfatal] = ACTIONS(6745),
    [anon_sym_DOLLARerror] = ACTIONS(6745),
    [anon_sym_DOLLARwarning] = ACTIONS(6745),
    [anon_sym_DOLLARinfo] = ACTIONS(6745),
    [anon_sym_default] = ACTIONS(6743),
    [anon_sym_clocking] = ACTIONS(6743),
    [anon_sym_defparam] = ACTIONS(6743),
    [anon_sym_bind] = ACTIONS(6743),
    [anon_sym_rand] = ACTIONS(6743),
    [anon_sym_const] = ACTIONS(6743),
    [anon_sym_function] = ACTIONS(6743),
    [anon_sym_static] = ACTIONS(6743),
    [anon_sym_constraint] = ACTIONS(6743),
    [anon_sym_if] = ACTIONS(6743),
    [anon_sym_else] = ACTIONS(6743),
    [anon_sym_LBRACK] = ACTIONS(6745),
    [anon_sym_localparam] = ACTIONS(6743),
    [anon_sym_parameter] = ACTIONS(6743),
    [anon_sym_var] = ACTIONS(6743),
    [anon_sym_import] = ACTIONS(6743),
    [anon_sym_export] = ACTIONS(6743),
    [anon_sym_genvar] = ACTIONS(6743),
    [anon_sym_interconnect] = ACTIONS(6743),
    [anon_sym_typedef] = ACTIONS(6743),
    [anon_sym_enum] = ACTIONS(6743),
    [anon_sym_struct] = ACTIONS(6743),
    [anon_sym_union] = ACTIONS(6743),
    [anon_sym_nettype] = ACTIONS(6743),
    [anon_sym_automatic] = ACTIONS(6743),
    [anon_sym_string] = ACTIONS(6743),
    [anon_sym_chandle] = ACTIONS(6743),
    [anon_sym_event] = ACTIONS(6743),
    [anon_sym_byte] = ACTIONS(6743),
    [anon_sym_shortint] = ACTIONS(6743),
    [anon_sym_int] = ACTIONS(6743),
    [anon_sym_longint] = ACTIONS(6743),
    [anon_sym_integer] = ACTIONS(6743),
    [anon_sym_time] = ACTIONS(6743),
    [anon_sym_bit] = ACTIONS(6743),
    [anon_sym_logic] = ACTIONS(6743),
    [anon_sym_reg] = ACTIONS(6743),
    [anon_sym_shortreal] = ACTIONS(6743),
    [anon_sym_real] = ACTIONS(6743),
    [anon_sym_realtime] = ACTIONS(6743),
    [anon_sym_supply0] = ACTIONS(6743),
    [anon_sym_supply1] = ACTIONS(6743),
    [anon_sym_signed] = ACTIONS(6743),
    [anon_sym_unsigned] = ACTIONS(6743),
    [anon_sym_task] = ACTIONS(6743),
    [anon_sym_assert] = ACTIONS(6743),
    [anon_sym_property] = ACTIONS(6743),
    [anon_sym_assume] = ACTIONS(6743),
    [anon_sym_cover] = ACTIONS(6743),
    [anon_sym_sequence] = ACTIONS(6743),
    [anon_sym_restrict] = ACTIONS(6743),
    [anon_sym_not] = ACTIONS(6743),
    [anon_sym_or] = ACTIONS(6743),
    [anon_sym_and] = ACTIONS(6743),
    [anon_sym_case] = ACTIONS(6743),
    [anon_sym_always] = ACTIONS(6743),
    [anon_sym_covergroup] = ACTIONS(6743),
    [anon_sym_end] = ACTIONS(6743),
    [anon_sym_let] = ACTIONS(6743),
    [anon_sym_pulldown] = ACTIONS(6743),
    [anon_sym_pullup] = ACTIONS(6743),
    [anon_sym_cmos] = ACTIONS(6743),
    [anon_sym_rcmos] = ACTIONS(6743),
    [anon_sym_bufif0] = ACTIONS(6743),
    [anon_sym_bufif1] = ACTIONS(6743),
    [anon_sym_notif0] = ACTIONS(6743),
    [anon_sym_notif1] = ACTIONS(6743),
    [anon_sym_nmos] = ACTIONS(6743),
    [anon_sym_pmos] = ACTIONS(6743),
    [anon_sym_rnmos] = ACTIONS(6743),
    [anon_sym_rpmos] = ACTIONS(6743),
    [anon_sym_nand] = ACTIONS(6743),
    [anon_sym_nor] = ACTIONS(6743),
    [anon_sym_xor] = ACTIONS(6743),
    [anon_sym_xnor] = ACTIONS(6743),
    [anon_sym_buf] = ACTIONS(6743),
    [anon_sym_tranif0] = ACTIONS(6743),
    [anon_sym_tranif1] = ACTIONS(6743),
    [anon_sym_rtranif1] = ACTIONS(6743),
    [anon_sym_rtranif0] = ACTIONS(6743),
    [anon_sym_tran] = ACTIONS(6743),
    [anon_sym_rtran] = ACTIONS(6743),
    [anon_sym_generate] = ACTIONS(6743),
    [anon_sym_for] = ACTIONS(6743),
    [anon_sym_initial] = ACTIONS(6743),
    [anon_sym_assign] = ACTIONS(6743),
    [anon_sym_alias] = ACTIONS(6743),
    [anon_sym_always_comb] = ACTIONS(6743),
    [anon_sym_always_latch] = ACTIONS(6743),
    [anon_sym_always_ff] = ACTIONS(6743),
    [anon_sym_final] = ACTIONS(6743),
    [anon_sym_global] = ACTIONS(6743),
    [anon_sym_LPAREN_STAR] = ACTIONS(6745),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6745),
    [anon_sym_DOLLARunit] = ACTIONS(6745),
  },
  [4723] = {
    [sym_simple_identifier] = ACTIONS(6433),
    [anon_sym_wire] = ACTIONS(6433),
    [anon_sym_tri] = ACTIONS(6433),
    [anon_sym_tri0] = ACTIONS(6433),
    [anon_sym_tri1] = ACTIONS(6433),
    [anon_sym_wand] = ACTIONS(6433),
    [anon_sym_triand] = ACTIONS(6433),
    [anon_sym_wor] = ACTIONS(6433),
    [anon_sym_trior] = ACTIONS(6433),
    [anon_sym_trireg] = ACTIONS(6433),
    [anon_sym_uwire] = ACTIONS(6433),
    [anon_sym_SEMI] = ACTIONS(6435),
    [anon_sym_extern] = ACTIONS(6433),
    [anon_sym_interface] = ACTIONS(6433),
    [anon_sym_checker] = ACTIONS(6433),
    [anon_sym_virtual] = ACTIONS(6433),
    [anon_sym_class] = ACTIONS(6433),
    [anon_sym_type] = ACTIONS(6433),
    [anon_sym_DOLLARfatal] = ACTIONS(6435),
    [anon_sym_DOLLARerror] = ACTIONS(6435),
    [anon_sym_DOLLARwarning] = ACTIONS(6435),
    [anon_sym_DOLLARinfo] = ACTIONS(6435),
    [anon_sym_default] = ACTIONS(6433),
    [anon_sym_clocking] = ACTIONS(6433),
    [anon_sym_defparam] = ACTIONS(6433),
    [anon_sym_bind] = ACTIONS(6433),
    [anon_sym_rand] = ACTIONS(6433),
    [anon_sym_const] = ACTIONS(6433),
    [anon_sym_function] = ACTIONS(6433),
    [anon_sym_static] = ACTIONS(6433),
    [anon_sym_constraint] = ACTIONS(6433),
    [anon_sym_if] = ACTIONS(6433),
    [anon_sym_else] = ACTIONS(6433),
    [anon_sym_LBRACK] = ACTIONS(6435),
    [anon_sym_localparam] = ACTIONS(6433),
    [anon_sym_parameter] = ACTIONS(6433),
    [anon_sym_var] = ACTIONS(6433),
    [anon_sym_import] = ACTIONS(6433),
    [anon_sym_export] = ACTIONS(6433),
    [anon_sym_genvar] = ACTIONS(6433),
    [anon_sym_interconnect] = ACTIONS(6433),
    [anon_sym_typedef] = ACTIONS(6433),
    [anon_sym_enum] = ACTIONS(6433),
    [anon_sym_struct] = ACTIONS(6433),
    [anon_sym_union] = ACTIONS(6433),
    [anon_sym_nettype] = ACTIONS(6433),
    [anon_sym_automatic] = ACTIONS(6433),
    [anon_sym_string] = ACTIONS(6433),
    [anon_sym_chandle] = ACTIONS(6433),
    [anon_sym_event] = ACTIONS(6433),
    [anon_sym_byte] = ACTIONS(6433),
    [anon_sym_shortint] = ACTIONS(6433),
    [anon_sym_int] = ACTIONS(6433),
    [anon_sym_longint] = ACTIONS(6433),
    [anon_sym_integer] = ACTIONS(6433),
    [anon_sym_time] = ACTIONS(6433),
    [anon_sym_bit] = ACTIONS(6433),
    [anon_sym_logic] = ACTIONS(6433),
    [anon_sym_reg] = ACTIONS(6433),
    [anon_sym_shortreal] = ACTIONS(6433),
    [anon_sym_real] = ACTIONS(6433),
    [anon_sym_realtime] = ACTIONS(6433),
    [anon_sym_supply0] = ACTIONS(6433),
    [anon_sym_supply1] = ACTIONS(6433),
    [anon_sym_signed] = ACTIONS(6433),
    [anon_sym_unsigned] = ACTIONS(6433),
    [anon_sym_task] = ACTIONS(6433),
    [anon_sym_assert] = ACTIONS(6433),
    [anon_sym_property] = ACTIONS(6433),
    [anon_sym_assume] = ACTIONS(6433),
    [anon_sym_cover] = ACTIONS(6433),
    [anon_sym_sequence] = ACTIONS(6433),
    [anon_sym_restrict] = ACTIONS(6433),
    [anon_sym_not] = ACTIONS(6433),
    [anon_sym_or] = ACTIONS(6433),
    [anon_sym_and] = ACTIONS(6433),
    [anon_sym_case] = ACTIONS(6433),
    [anon_sym_always] = ACTIONS(6433),
    [anon_sym_covergroup] = ACTIONS(6433),
    [anon_sym_let] = ACTIONS(6433),
    [anon_sym_pulldown] = ACTIONS(6433),
    [anon_sym_pullup] = ACTIONS(6433),
    [anon_sym_cmos] = ACTIONS(6433),
    [anon_sym_rcmos] = ACTIONS(6433),
    [anon_sym_bufif0] = ACTIONS(6433),
    [anon_sym_bufif1] = ACTIONS(6433),
    [anon_sym_notif0] = ACTIONS(6433),
    [anon_sym_notif1] = ACTIONS(6433),
    [anon_sym_nmos] = ACTIONS(6433),
    [anon_sym_pmos] = ACTIONS(6433),
    [anon_sym_rnmos] = ACTIONS(6433),
    [anon_sym_rpmos] = ACTIONS(6433),
    [anon_sym_nand] = ACTIONS(6433),
    [anon_sym_nor] = ACTIONS(6433),
    [anon_sym_xor] = ACTIONS(6433),
    [anon_sym_xnor] = ACTIONS(6433),
    [anon_sym_buf] = ACTIONS(6433),
    [anon_sym_tranif0] = ACTIONS(6433),
    [anon_sym_tranif1] = ACTIONS(6433),
    [anon_sym_rtranif1] = ACTIONS(6433),
    [anon_sym_rtranif0] = ACTIONS(6433),
    [anon_sym_tran] = ACTIONS(6433),
    [anon_sym_rtran] = ACTIONS(6433),
    [anon_sym_generate] = ACTIONS(6433),
    [anon_sym_endgenerate] = ACTIONS(6433),
    [anon_sym_for] = ACTIONS(6433),
    [anon_sym_initial] = ACTIONS(6433),
    [anon_sym_assign] = ACTIONS(6433),
    [anon_sym_alias] = ACTIONS(6433),
    [anon_sym_always_comb] = ACTIONS(6433),
    [anon_sym_always_latch] = ACTIONS(6433),
    [anon_sym_always_ff] = ACTIONS(6433),
    [anon_sym_final] = ACTIONS(6433),
    [anon_sym_global] = ACTIONS(6433),
    [anon_sym_LPAREN_STAR] = ACTIONS(6435),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6435),
    [anon_sym_DOLLARunit] = ACTIONS(6435),
  },
  [4724] = {
    [sym_simple_identifier] = ACTIONS(6765),
    [anon_sym_wire] = ACTIONS(6765),
    [anon_sym_tri] = ACTIONS(6765),
    [anon_sym_tri0] = ACTIONS(6765),
    [anon_sym_tri1] = ACTIONS(6765),
    [anon_sym_wand] = ACTIONS(6765),
    [anon_sym_triand] = ACTIONS(6765),
    [anon_sym_wor] = ACTIONS(6765),
    [anon_sym_trior] = ACTIONS(6765),
    [anon_sym_trireg] = ACTIONS(6765),
    [anon_sym_uwire] = ACTIONS(6765),
    [anon_sym_SEMI] = ACTIONS(6768),
    [anon_sym_extern] = ACTIONS(6765),
    [anon_sym_interface] = ACTIONS(6765),
    [anon_sym_checker] = ACTIONS(6765),
    [anon_sym_virtual] = ACTIONS(6765),
    [anon_sym_class] = ACTIONS(6765),
    [anon_sym_type] = ACTIONS(6765),
    [anon_sym_DOLLARfatal] = ACTIONS(6768),
    [anon_sym_DOLLARerror] = ACTIONS(6768),
    [anon_sym_DOLLARwarning] = ACTIONS(6768),
    [anon_sym_DOLLARinfo] = ACTIONS(6768),
    [anon_sym_default] = ACTIONS(6765),
    [anon_sym_clocking] = ACTIONS(6765),
    [anon_sym_defparam] = ACTIONS(6765),
    [anon_sym_bind] = ACTIONS(6765),
    [anon_sym_rand] = ACTIONS(6765),
    [anon_sym_const] = ACTIONS(6765),
    [anon_sym_function] = ACTIONS(6765),
    [anon_sym_static] = ACTIONS(6765),
    [anon_sym_constraint] = ACTIONS(6765),
    [anon_sym_if] = ACTIONS(6765),
    [anon_sym_else] = ACTIONS(6765),
    [anon_sym_LBRACK] = ACTIONS(6768),
    [anon_sym_localparam] = ACTIONS(6765),
    [anon_sym_parameter] = ACTIONS(6765),
    [anon_sym_var] = ACTIONS(6765),
    [anon_sym_import] = ACTIONS(6765),
    [anon_sym_export] = ACTIONS(6765),
    [anon_sym_genvar] = ACTIONS(6765),
    [anon_sym_interconnect] = ACTIONS(6765),
    [anon_sym_typedef] = ACTIONS(6765),
    [anon_sym_enum] = ACTIONS(6765),
    [anon_sym_struct] = ACTIONS(6765),
    [anon_sym_union] = ACTIONS(6765),
    [anon_sym_nettype] = ACTIONS(6765),
    [anon_sym_automatic] = ACTIONS(6765),
    [anon_sym_string] = ACTIONS(6765),
    [anon_sym_chandle] = ACTIONS(6765),
    [anon_sym_event] = ACTIONS(6765),
    [anon_sym_byte] = ACTIONS(6765),
    [anon_sym_shortint] = ACTIONS(6765),
    [anon_sym_int] = ACTIONS(6765),
    [anon_sym_longint] = ACTIONS(6765),
    [anon_sym_integer] = ACTIONS(6765),
    [anon_sym_time] = ACTIONS(6765),
    [anon_sym_bit] = ACTIONS(6765),
    [anon_sym_logic] = ACTIONS(6765),
    [anon_sym_reg] = ACTIONS(6765),
    [anon_sym_shortreal] = ACTIONS(6765),
    [anon_sym_real] = ACTIONS(6765),
    [anon_sym_realtime] = ACTIONS(6765),
    [anon_sym_supply0] = ACTIONS(6765),
    [anon_sym_supply1] = ACTIONS(6765),
    [anon_sym_signed] = ACTIONS(6765),
    [anon_sym_unsigned] = ACTIONS(6765),
    [anon_sym_task] = ACTIONS(6765),
    [anon_sym_assert] = ACTIONS(6765),
    [anon_sym_property] = ACTIONS(6765),
    [anon_sym_assume] = ACTIONS(6765),
    [anon_sym_cover] = ACTIONS(6765),
    [anon_sym_sequence] = ACTIONS(6765),
    [anon_sym_restrict] = ACTIONS(6765),
    [anon_sym_not] = ACTIONS(6765),
    [anon_sym_or] = ACTIONS(6765),
    [anon_sym_and] = ACTIONS(6765),
    [anon_sym_case] = ACTIONS(6765),
    [anon_sym_always] = ACTIONS(6765),
    [anon_sym_covergroup] = ACTIONS(6765),
    [anon_sym_let] = ACTIONS(6765),
    [anon_sym_pulldown] = ACTIONS(6765),
    [anon_sym_pullup] = ACTIONS(6765),
    [anon_sym_cmos] = ACTIONS(6765),
    [anon_sym_rcmos] = ACTIONS(6765),
    [anon_sym_bufif0] = ACTIONS(6765),
    [anon_sym_bufif1] = ACTIONS(6765),
    [anon_sym_notif0] = ACTIONS(6765),
    [anon_sym_notif1] = ACTIONS(6765),
    [anon_sym_nmos] = ACTIONS(6765),
    [anon_sym_pmos] = ACTIONS(6765),
    [anon_sym_rnmos] = ACTIONS(6765),
    [anon_sym_rpmos] = ACTIONS(6765),
    [anon_sym_nand] = ACTIONS(6765),
    [anon_sym_nor] = ACTIONS(6765),
    [anon_sym_xor] = ACTIONS(6765),
    [anon_sym_xnor] = ACTIONS(6765),
    [anon_sym_buf] = ACTIONS(6765),
    [anon_sym_tranif0] = ACTIONS(6765),
    [anon_sym_tranif1] = ACTIONS(6765),
    [anon_sym_rtranif1] = ACTIONS(6765),
    [anon_sym_rtranif0] = ACTIONS(6765),
    [anon_sym_tran] = ACTIONS(6765),
    [anon_sym_rtran] = ACTIONS(6765),
    [anon_sym_generate] = ACTIONS(6765),
    [anon_sym_endgenerate] = ACTIONS(6765),
    [anon_sym_for] = ACTIONS(6765),
    [anon_sym_initial] = ACTIONS(6765),
    [anon_sym_assign] = ACTIONS(6765),
    [anon_sym_alias] = ACTIONS(6765),
    [anon_sym_always_comb] = ACTIONS(6765),
    [anon_sym_always_latch] = ACTIONS(6765),
    [anon_sym_always_ff] = ACTIONS(6765),
    [anon_sym_final] = ACTIONS(6765),
    [anon_sym_global] = ACTIONS(6765),
    [anon_sym_LPAREN_STAR] = ACTIONS(6768),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6768),
    [anon_sym_DOLLARunit] = ACTIONS(6768),
  },
  [4725] = {
    [sym_simple_identifier] = ACTIONS(5866),
    [anon_sym_wire] = ACTIONS(5866),
    [anon_sym_tri] = ACTIONS(5866),
    [anon_sym_tri0] = ACTIONS(5866),
    [anon_sym_tri1] = ACTIONS(5866),
    [anon_sym_wand] = ACTIONS(5866),
    [anon_sym_triand] = ACTIONS(5866),
    [anon_sym_wor] = ACTIONS(5866),
    [anon_sym_trior] = ACTIONS(5866),
    [anon_sym_trireg] = ACTIONS(5866),
    [anon_sym_uwire] = ACTIONS(5866),
    [anon_sym_SEMI] = ACTIONS(5868),
    [anon_sym_extern] = ACTIONS(5866),
    [anon_sym_interface] = ACTIONS(5866),
    [anon_sym_checker] = ACTIONS(5866),
    [anon_sym_virtual] = ACTIONS(5866),
    [anon_sym_class] = ACTIONS(5866),
    [anon_sym_type] = ACTIONS(5866),
    [anon_sym_DOLLARfatal] = ACTIONS(5868),
    [anon_sym_DOLLARerror] = ACTIONS(5868),
    [anon_sym_DOLLARwarning] = ACTIONS(5868),
    [anon_sym_DOLLARinfo] = ACTIONS(5868),
    [anon_sym_default] = ACTIONS(5866),
    [anon_sym_clocking] = ACTIONS(5866),
    [anon_sym_defparam] = ACTIONS(5866),
    [anon_sym_bind] = ACTIONS(5866),
    [anon_sym_rand] = ACTIONS(5866),
    [anon_sym_const] = ACTIONS(5866),
    [anon_sym_function] = ACTIONS(5866),
    [anon_sym_static] = ACTIONS(5866),
    [anon_sym_constraint] = ACTIONS(5866),
    [anon_sym_if] = ACTIONS(5866),
    [anon_sym_else] = ACTIONS(5866),
    [anon_sym_LBRACK] = ACTIONS(5868),
    [anon_sym_localparam] = ACTIONS(5866),
    [anon_sym_parameter] = ACTIONS(5866),
    [anon_sym_var] = ACTIONS(5866),
    [anon_sym_import] = ACTIONS(5866),
    [anon_sym_export] = ACTIONS(5866),
    [anon_sym_genvar] = ACTIONS(5866),
    [anon_sym_interconnect] = ACTIONS(5866),
    [anon_sym_typedef] = ACTIONS(5866),
    [anon_sym_enum] = ACTIONS(5866),
    [anon_sym_struct] = ACTIONS(5866),
    [anon_sym_union] = ACTIONS(5866),
    [anon_sym_nettype] = ACTIONS(5866),
    [anon_sym_automatic] = ACTIONS(5866),
    [anon_sym_string] = ACTIONS(5866),
    [anon_sym_chandle] = ACTIONS(5866),
    [anon_sym_event] = ACTIONS(5866),
    [anon_sym_byte] = ACTIONS(5866),
    [anon_sym_shortint] = ACTIONS(5866),
    [anon_sym_int] = ACTIONS(5866),
    [anon_sym_longint] = ACTIONS(5866),
    [anon_sym_integer] = ACTIONS(5866),
    [anon_sym_time] = ACTIONS(5866),
    [anon_sym_bit] = ACTIONS(5866),
    [anon_sym_logic] = ACTIONS(5866),
    [anon_sym_reg] = ACTIONS(5866),
    [anon_sym_shortreal] = ACTIONS(5866),
    [anon_sym_real] = ACTIONS(5866),
    [anon_sym_realtime] = ACTIONS(5866),
    [anon_sym_supply0] = ACTIONS(5866),
    [anon_sym_supply1] = ACTIONS(5866),
    [anon_sym_signed] = ACTIONS(5866),
    [anon_sym_unsigned] = ACTIONS(5866),
    [anon_sym_task] = ACTIONS(5866),
    [anon_sym_assert] = ACTIONS(5866),
    [anon_sym_property] = ACTIONS(5866),
    [anon_sym_assume] = ACTIONS(5866),
    [anon_sym_cover] = ACTIONS(5866),
    [anon_sym_sequence] = ACTIONS(5866),
    [anon_sym_restrict] = ACTIONS(5866),
    [anon_sym_not] = ACTIONS(5866),
    [anon_sym_or] = ACTIONS(5866),
    [anon_sym_and] = ACTIONS(5866),
    [anon_sym_case] = ACTIONS(5866),
    [anon_sym_always] = ACTIONS(5866),
    [anon_sym_covergroup] = ACTIONS(5866),
    [anon_sym_end] = ACTIONS(5866),
    [anon_sym_let] = ACTIONS(5866),
    [anon_sym_pulldown] = ACTIONS(5866),
    [anon_sym_pullup] = ACTIONS(5866),
    [anon_sym_cmos] = ACTIONS(5866),
    [anon_sym_rcmos] = ACTIONS(5866),
    [anon_sym_bufif0] = ACTIONS(5866),
    [anon_sym_bufif1] = ACTIONS(5866),
    [anon_sym_notif0] = ACTIONS(5866),
    [anon_sym_notif1] = ACTIONS(5866),
    [anon_sym_nmos] = ACTIONS(5866),
    [anon_sym_pmos] = ACTIONS(5866),
    [anon_sym_rnmos] = ACTIONS(5866),
    [anon_sym_rpmos] = ACTIONS(5866),
    [anon_sym_nand] = ACTIONS(5866),
    [anon_sym_nor] = ACTIONS(5866),
    [anon_sym_xor] = ACTIONS(5866),
    [anon_sym_xnor] = ACTIONS(5866),
    [anon_sym_buf] = ACTIONS(5866),
    [anon_sym_tranif0] = ACTIONS(5866),
    [anon_sym_tranif1] = ACTIONS(5866),
    [anon_sym_rtranif1] = ACTIONS(5866),
    [anon_sym_rtranif0] = ACTIONS(5866),
    [anon_sym_tran] = ACTIONS(5866),
    [anon_sym_rtran] = ACTIONS(5866),
    [anon_sym_generate] = ACTIONS(5866),
    [anon_sym_for] = ACTIONS(5866),
    [anon_sym_initial] = ACTIONS(5866),
    [anon_sym_assign] = ACTIONS(5866),
    [anon_sym_alias] = ACTIONS(5866),
    [anon_sym_always_comb] = ACTIONS(5866),
    [anon_sym_always_latch] = ACTIONS(5866),
    [anon_sym_always_ff] = ACTIONS(5866),
    [anon_sym_final] = ACTIONS(5866),
    [anon_sym_global] = ACTIONS(5866),
    [anon_sym_LPAREN_STAR] = ACTIONS(5868),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5868),
    [anon_sym_DOLLARunit] = ACTIONS(5868),
  },
  [4726] = {
    [sym_simple_identifier] = ACTIONS(5884),
    [anon_sym_wire] = ACTIONS(5884),
    [anon_sym_tri] = ACTIONS(5884),
    [anon_sym_tri0] = ACTIONS(5884),
    [anon_sym_tri1] = ACTIONS(5884),
    [anon_sym_wand] = ACTIONS(5884),
    [anon_sym_triand] = ACTIONS(5884),
    [anon_sym_wor] = ACTIONS(5884),
    [anon_sym_trior] = ACTIONS(5884),
    [anon_sym_trireg] = ACTIONS(5884),
    [anon_sym_uwire] = ACTIONS(5884),
    [anon_sym_SEMI] = ACTIONS(5886),
    [anon_sym_extern] = ACTIONS(5884),
    [anon_sym_interface] = ACTIONS(5884),
    [anon_sym_checker] = ACTIONS(5884),
    [anon_sym_virtual] = ACTIONS(5884),
    [anon_sym_class] = ACTIONS(5884),
    [anon_sym_type] = ACTIONS(5884),
    [anon_sym_DOLLARfatal] = ACTIONS(5886),
    [anon_sym_DOLLARerror] = ACTIONS(5886),
    [anon_sym_DOLLARwarning] = ACTIONS(5886),
    [anon_sym_DOLLARinfo] = ACTIONS(5886),
    [anon_sym_default] = ACTIONS(5884),
    [anon_sym_clocking] = ACTIONS(5884),
    [anon_sym_defparam] = ACTIONS(5884),
    [anon_sym_bind] = ACTIONS(5884),
    [anon_sym_rand] = ACTIONS(5884),
    [anon_sym_const] = ACTIONS(5884),
    [anon_sym_function] = ACTIONS(5884),
    [anon_sym_static] = ACTIONS(5884),
    [anon_sym_constraint] = ACTIONS(5884),
    [anon_sym_if] = ACTIONS(5884),
    [anon_sym_else] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [anon_sym_localparam] = ACTIONS(5884),
    [anon_sym_parameter] = ACTIONS(5884),
    [anon_sym_var] = ACTIONS(5884),
    [anon_sym_import] = ACTIONS(5884),
    [anon_sym_export] = ACTIONS(5884),
    [anon_sym_genvar] = ACTIONS(5884),
    [anon_sym_interconnect] = ACTIONS(5884),
    [anon_sym_typedef] = ACTIONS(5884),
    [anon_sym_enum] = ACTIONS(5884),
    [anon_sym_struct] = ACTIONS(5884),
    [anon_sym_union] = ACTIONS(5884),
    [anon_sym_nettype] = ACTIONS(5884),
    [anon_sym_automatic] = ACTIONS(5884),
    [anon_sym_string] = ACTIONS(5884),
    [anon_sym_chandle] = ACTIONS(5884),
    [anon_sym_event] = ACTIONS(5884),
    [anon_sym_byte] = ACTIONS(5884),
    [anon_sym_shortint] = ACTIONS(5884),
    [anon_sym_int] = ACTIONS(5884),
    [anon_sym_longint] = ACTIONS(5884),
    [anon_sym_integer] = ACTIONS(5884),
    [anon_sym_time] = ACTIONS(5884),
    [anon_sym_bit] = ACTIONS(5884),
    [anon_sym_logic] = ACTIONS(5884),
    [anon_sym_reg] = ACTIONS(5884),
    [anon_sym_shortreal] = ACTIONS(5884),
    [anon_sym_real] = ACTIONS(5884),
    [anon_sym_realtime] = ACTIONS(5884),
    [anon_sym_supply0] = ACTIONS(5884),
    [anon_sym_supply1] = ACTIONS(5884),
    [anon_sym_signed] = ACTIONS(5884),
    [anon_sym_unsigned] = ACTIONS(5884),
    [anon_sym_task] = ACTIONS(5884),
    [anon_sym_assert] = ACTIONS(5884),
    [anon_sym_property] = ACTIONS(5884),
    [anon_sym_assume] = ACTIONS(5884),
    [anon_sym_cover] = ACTIONS(5884),
    [anon_sym_sequence] = ACTIONS(5884),
    [anon_sym_restrict] = ACTIONS(5884),
    [anon_sym_not] = ACTIONS(5884),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_case] = ACTIONS(5884),
    [anon_sym_always] = ACTIONS(5884),
    [anon_sym_covergroup] = ACTIONS(5884),
    [anon_sym_let] = ACTIONS(5884),
    [anon_sym_pulldown] = ACTIONS(5884),
    [anon_sym_pullup] = ACTIONS(5884),
    [anon_sym_cmos] = ACTIONS(5884),
    [anon_sym_rcmos] = ACTIONS(5884),
    [anon_sym_bufif0] = ACTIONS(5884),
    [anon_sym_bufif1] = ACTIONS(5884),
    [anon_sym_notif0] = ACTIONS(5884),
    [anon_sym_notif1] = ACTIONS(5884),
    [anon_sym_nmos] = ACTIONS(5884),
    [anon_sym_pmos] = ACTIONS(5884),
    [anon_sym_rnmos] = ACTIONS(5884),
    [anon_sym_rpmos] = ACTIONS(5884),
    [anon_sym_nand] = ACTIONS(5884),
    [anon_sym_nor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_xnor] = ACTIONS(5884),
    [anon_sym_buf] = ACTIONS(5884),
    [anon_sym_tranif0] = ACTIONS(5884),
    [anon_sym_tranif1] = ACTIONS(5884),
    [anon_sym_rtranif1] = ACTIONS(5884),
    [anon_sym_rtranif0] = ACTIONS(5884),
    [anon_sym_tran] = ACTIONS(5884),
    [anon_sym_rtran] = ACTIONS(5884),
    [anon_sym_generate] = ACTIONS(5884),
    [anon_sym_endgenerate] = ACTIONS(5884),
    [anon_sym_for] = ACTIONS(5884),
    [anon_sym_initial] = ACTIONS(5884),
    [anon_sym_assign] = ACTIONS(5884),
    [anon_sym_alias] = ACTIONS(5884),
    [anon_sym_always_comb] = ACTIONS(5884),
    [anon_sym_always_latch] = ACTIONS(5884),
    [anon_sym_always_ff] = ACTIONS(5884),
    [anon_sym_final] = ACTIONS(5884),
    [anon_sym_global] = ACTIONS(5884),
    [anon_sym_LPAREN_STAR] = ACTIONS(5886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5886),
    [anon_sym_DOLLARunit] = ACTIONS(5886),
  },
  [4727] = {
    [sym_simple_identifier] = ACTIONS(4696),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_rand] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_end] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [4728] = {
    [sym_simple_identifier] = ACTIONS(6517),
    [anon_sym_wire] = ACTIONS(6517),
    [anon_sym_tri] = ACTIONS(6517),
    [anon_sym_tri0] = ACTIONS(6517),
    [anon_sym_tri1] = ACTIONS(6517),
    [anon_sym_wand] = ACTIONS(6517),
    [anon_sym_triand] = ACTIONS(6517),
    [anon_sym_wor] = ACTIONS(6517),
    [anon_sym_trior] = ACTIONS(6517),
    [anon_sym_trireg] = ACTIONS(6517),
    [anon_sym_uwire] = ACTIONS(6517),
    [anon_sym_SEMI] = ACTIONS(6520),
    [anon_sym_extern] = ACTIONS(6517),
    [anon_sym_interface] = ACTIONS(6517),
    [anon_sym_checker] = ACTIONS(6517),
    [anon_sym_virtual] = ACTIONS(6517),
    [anon_sym_class] = ACTIONS(6517),
    [anon_sym_type] = ACTIONS(6517),
    [anon_sym_DOLLARfatal] = ACTIONS(6520),
    [anon_sym_DOLLARerror] = ACTIONS(6520),
    [anon_sym_DOLLARwarning] = ACTIONS(6520),
    [anon_sym_DOLLARinfo] = ACTIONS(6520),
    [anon_sym_default] = ACTIONS(6517),
    [anon_sym_clocking] = ACTIONS(6517),
    [anon_sym_defparam] = ACTIONS(6517),
    [anon_sym_bind] = ACTIONS(6517),
    [anon_sym_rand] = ACTIONS(6517),
    [anon_sym_const] = ACTIONS(6517),
    [anon_sym_function] = ACTIONS(6517),
    [anon_sym_static] = ACTIONS(6517),
    [anon_sym_constraint] = ACTIONS(6517),
    [anon_sym_if] = ACTIONS(6517),
    [anon_sym_else] = ACTIONS(6517),
    [anon_sym_LBRACK] = ACTIONS(6520),
    [anon_sym_localparam] = ACTIONS(6517),
    [anon_sym_parameter] = ACTIONS(6517),
    [anon_sym_var] = ACTIONS(6517),
    [anon_sym_import] = ACTIONS(6517),
    [anon_sym_export] = ACTIONS(6517),
    [anon_sym_genvar] = ACTIONS(6517),
    [anon_sym_interconnect] = ACTIONS(6517),
    [anon_sym_typedef] = ACTIONS(6517),
    [anon_sym_enum] = ACTIONS(6517),
    [anon_sym_struct] = ACTIONS(6517),
    [anon_sym_union] = ACTIONS(6517),
    [anon_sym_nettype] = ACTIONS(6517),
    [anon_sym_automatic] = ACTIONS(6517),
    [anon_sym_string] = ACTIONS(6517),
    [anon_sym_chandle] = ACTIONS(6517),
    [anon_sym_event] = ACTIONS(6517),
    [anon_sym_byte] = ACTIONS(6517),
    [anon_sym_shortint] = ACTIONS(6517),
    [anon_sym_int] = ACTIONS(6517),
    [anon_sym_longint] = ACTIONS(6517),
    [anon_sym_integer] = ACTIONS(6517),
    [anon_sym_time] = ACTIONS(6517),
    [anon_sym_bit] = ACTIONS(6517),
    [anon_sym_logic] = ACTIONS(6517),
    [anon_sym_reg] = ACTIONS(6517),
    [anon_sym_shortreal] = ACTIONS(6517),
    [anon_sym_real] = ACTIONS(6517),
    [anon_sym_realtime] = ACTIONS(6517),
    [anon_sym_supply0] = ACTIONS(6517),
    [anon_sym_supply1] = ACTIONS(6517),
    [anon_sym_signed] = ACTIONS(6517),
    [anon_sym_unsigned] = ACTIONS(6517),
    [anon_sym_task] = ACTIONS(6517),
    [anon_sym_assert] = ACTIONS(6517),
    [anon_sym_property] = ACTIONS(6517),
    [anon_sym_assume] = ACTIONS(6517),
    [anon_sym_cover] = ACTIONS(6517),
    [anon_sym_sequence] = ACTIONS(6517),
    [anon_sym_restrict] = ACTIONS(6517),
    [anon_sym_not] = ACTIONS(6517),
    [anon_sym_or] = ACTIONS(6517),
    [anon_sym_and] = ACTIONS(6517),
    [anon_sym_case] = ACTIONS(6517),
    [anon_sym_always] = ACTIONS(6517),
    [anon_sym_covergroup] = ACTIONS(6517),
    [anon_sym_end] = ACTIONS(6517),
    [anon_sym_let] = ACTIONS(6517),
    [anon_sym_pulldown] = ACTIONS(6517),
    [anon_sym_pullup] = ACTIONS(6517),
    [anon_sym_cmos] = ACTIONS(6517),
    [anon_sym_rcmos] = ACTIONS(6517),
    [anon_sym_bufif0] = ACTIONS(6517),
    [anon_sym_bufif1] = ACTIONS(6517),
    [anon_sym_notif0] = ACTIONS(6517),
    [anon_sym_notif1] = ACTIONS(6517),
    [anon_sym_nmos] = ACTIONS(6517),
    [anon_sym_pmos] = ACTIONS(6517),
    [anon_sym_rnmos] = ACTIONS(6517),
    [anon_sym_rpmos] = ACTIONS(6517),
    [anon_sym_nand] = ACTIONS(6517),
    [anon_sym_nor] = ACTIONS(6517),
    [anon_sym_xor] = ACTIONS(6517),
    [anon_sym_xnor] = ACTIONS(6517),
    [anon_sym_buf] = ACTIONS(6517),
    [anon_sym_tranif0] = ACTIONS(6517),
    [anon_sym_tranif1] = ACTIONS(6517),
    [anon_sym_rtranif1] = ACTIONS(6517),
    [anon_sym_rtranif0] = ACTIONS(6517),
    [anon_sym_tran] = ACTIONS(6517),
    [anon_sym_rtran] = ACTIONS(6517),
    [anon_sym_generate] = ACTIONS(6517),
    [anon_sym_for] = ACTIONS(6517),
    [anon_sym_initial] = ACTIONS(6517),
    [anon_sym_assign] = ACTIONS(6517),
    [anon_sym_alias] = ACTIONS(6517),
    [anon_sym_always_comb] = ACTIONS(6517),
    [anon_sym_always_latch] = ACTIONS(6517),
    [anon_sym_always_ff] = ACTIONS(6517),
    [anon_sym_final] = ACTIONS(6517),
    [anon_sym_global] = ACTIONS(6517),
    [anon_sym_LPAREN_STAR] = ACTIONS(6520),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6520),
    [anon_sym_DOLLARunit] = ACTIONS(6520),
  },
  [4729] = {
    [sym_simple_identifier] = ACTIONS(6609),
    [anon_sym_wire] = ACTIONS(6609),
    [anon_sym_tri] = ACTIONS(6609),
    [anon_sym_tri0] = ACTIONS(6609),
    [anon_sym_tri1] = ACTIONS(6609),
    [anon_sym_wand] = ACTIONS(6609),
    [anon_sym_triand] = ACTIONS(6609),
    [anon_sym_wor] = ACTIONS(6609),
    [anon_sym_trior] = ACTIONS(6609),
    [anon_sym_trireg] = ACTIONS(6609),
    [anon_sym_uwire] = ACTIONS(6609),
    [anon_sym_SEMI] = ACTIONS(6611),
    [anon_sym_extern] = ACTIONS(6609),
    [anon_sym_interface] = ACTIONS(6609),
    [anon_sym_checker] = ACTIONS(6609),
    [anon_sym_virtual] = ACTIONS(6609),
    [anon_sym_class] = ACTIONS(6609),
    [anon_sym_type] = ACTIONS(6609),
    [anon_sym_DOLLARfatal] = ACTIONS(6611),
    [anon_sym_DOLLARerror] = ACTIONS(6611),
    [anon_sym_DOLLARwarning] = ACTIONS(6611),
    [anon_sym_DOLLARinfo] = ACTIONS(6611),
    [anon_sym_default] = ACTIONS(6609),
    [anon_sym_clocking] = ACTIONS(6609),
    [anon_sym_defparam] = ACTIONS(6609),
    [anon_sym_bind] = ACTIONS(6609),
    [anon_sym_rand] = ACTIONS(6609),
    [anon_sym_const] = ACTIONS(6609),
    [anon_sym_function] = ACTIONS(6609),
    [anon_sym_static] = ACTIONS(6609),
    [anon_sym_constraint] = ACTIONS(6609),
    [anon_sym_if] = ACTIONS(6609),
    [anon_sym_else] = ACTIONS(6609),
    [anon_sym_LBRACK] = ACTIONS(6611),
    [anon_sym_localparam] = ACTIONS(6609),
    [anon_sym_parameter] = ACTIONS(6609),
    [anon_sym_var] = ACTIONS(6609),
    [anon_sym_import] = ACTIONS(6609),
    [anon_sym_export] = ACTIONS(6609),
    [anon_sym_genvar] = ACTIONS(6609),
    [anon_sym_interconnect] = ACTIONS(6609),
    [anon_sym_typedef] = ACTIONS(6609),
    [anon_sym_enum] = ACTIONS(6609),
    [anon_sym_struct] = ACTIONS(6609),
    [anon_sym_union] = ACTIONS(6609),
    [anon_sym_nettype] = ACTIONS(6609),
    [anon_sym_automatic] = ACTIONS(6609),
    [anon_sym_string] = ACTIONS(6609),
    [anon_sym_chandle] = ACTIONS(6609),
    [anon_sym_event] = ACTIONS(6609),
    [anon_sym_byte] = ACTIONS(6609),
    [anon_sym_shortint] = ACTIONS(6609),
    [anon_sym_int] = ACTIONS(6609),
    [anon_sym_longint] = ACTIONS(6609),
    [anon_sym_integer] = ACTIONS(6609),
    [anon_sym_time] = ACTIONS(6609),
    [anon_sym_bit] = ACTIONS(6609),
    [anon_sym_logic] = ACTIONS(6609),
    [anon_sym_reg] = ACTIONS(6609),
    [anon_sym_shortreal] = ACTIONS(6609),
    [anon_sym_real] = ACTIONS(6609),
    [anon_sym_realtime] = ACTIONS(6609),
    [anon_sym_supply0] = ACTIONS(6609),
    [anon_sym_supply1] = ACTIONS(6609),
    [anon_sym_signed] = ACTIONS(6609),
    [anon_sym_unsigned] = ACTIONS(6609),
    [anon_sym_task] = ACTIONS(6609),
    [anon_sym_assert] = ACTIONS(6609),
    [anon_sym_property] = ACTIONS(6609),
    [anon_sym_assume] = ACTIONS(6609),
    [anon_sym_cover] = ACTIONS(6609),
    [anon_sym_sequence] = ACTIONS(6609),
    [anon_sym_restrict] = ACTIONS(6609),
    [anon_sym_not] = ACTIONS(6609),
    [anon_sym_or] = ACTIONS(6609),
    [anon_sym_and] = ACTIONS(6609),
    [anon_sym_case] = ACTIONS(6609),
    [anon_sym_always] = ACTIONS(6609),
    [anon_sym_covergroup] = ACTIONS(6609),
    [anon_sym_let] = ACTIONS(6609),
    [anon_sym_pulldown] = ACTIONS(6609),
    [anon_sym_pullup] = ACTIONS(6609),
    [anon_sym_cmos] = ACTIONS(6609),
    [anon_sym_rcmos] = ACTIONS(6609),
    [anon_sym_bufif0] = ACTIONS(6609),
    [anon_sym_bufif1] = ACTIONS(6609),
    [anon_sym_notif0] = ACTIONS(6609),
    [anon_sym_notif1] = ACTIONS(6609),
    [anon_sym_nmos] = ACTIONS(6609),
    [anon_sym_pmos] = ACTIONS(6609),
    [anon_sym_rnmos] = ACTIONS(6609),
    [anon_sym_rpmos] = ACTIONS(6609),
    [anon_sym_nand] = ACTIONS(6609),
    [anon_sym_nor] = ACTIONS(6609),
    [anon_sym_xor] = ACTIONS(6609),
    [anon_sym_xnor] = ACTIONS(6609),
    [anon_sym_buf] = ACTIONS(6609),
    [anon_sym_tranif0] = ACTIONS(6609),
    [anon_sym_tranif1] = ACTIONS(6609),
    [anon_sym_rtranif1] = ACTIONS(6609),
    [anon_sym_rtranif0] = ACTIONS(6609),
    [anon_sym_tran] = ACTIONS(6609),
    [anon_sym_rtran] = ACTIONS(6609),
    [anon_sym_generate] = ACTIONS(6609),
    [anon_sym_endgenerate] = ACTIONS(6609),
    [anon_sym_for] = ACTIONS(6609),
    [anon_sym_initial] = ACTIONS(6609),
    [anon_sym_assign] = ACTIONS(6609),
    [anon_sym_alias] = ACTIONS(6609),
    [anon_sym_always_comb] = ACTIONS(6609),
    [anon_sym_always_latch] = ACTIONS(6609),
    [anon_sym_always_ff] = ACTIONS(6609),
    [anon_sym_final] = ACTIONS(6609),
    [anon_sym_global] = ACTIONS(6609),
    [anon_sym_LPAREN_STAR] = ACTIONS(6611),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6611),
    [anon_sym_DOLLARunit] = ACTIONS(6611),
  },
  [4730] = {
    [sym_simple_identifier] = ACTIONS(4912),
    [anon_sym_wire] = ACTIONS(4912),
    [anon_sym_tri] = ACTIONS(4912),
    [anon_sym_tri0] = ACTIONS(4912),
    [anon_sym_tri1] = ACTIONS(4912),
    [anon_sym_wand] = ACTIONS(4912),
    [anon_sym_triand] = ACTIONS(4912),
    [anon_sym_wor] = ACTIONS(4912),
    [anon_sym_trior] = ACTIONS(4912),
    [anon_sym_trireg] = ACTIONS(4912),
    [anon_sym_uwire] = ACTIONS(4912),
    [anon_sym_SEMI] = ACTIONS(4910),
    [anon_sym_extern] = ACTIONS(4912),
    [anon_sym_interface] = ACTIONS(4912),
    [anon_sym_checker] = ACTIONS(4912),
    [anon_sym_virtual] = ACTIONS(4912),
    [anon_sym_class] = ACTIONS(4912),
    [anon_sym_type] = ACTIONS(4912),
    [anon_sym_DOLLARfatal] = ACTIONS(4910),
    [anon_sym_DOLLARerror] = ACTIONS(4910),
    [anon_sym_DOLLARwarning] = ACTIONS(4910),
    [anon_sym_DOLLARinfo] = ACTIONS(4910),
    [anon_sym_default] = ACTIONS(4912),
    [anon_sym_clocking] = ACTIONS(4912),
    [anon_sym_defparam] = ACTIONS(4912),
    [anon_sym_bind] = ACTIONS(4912),
    [anon_sym_rand] = ACTIONS(4912),
    [anon_sym_const] = ACTIONS(4912),
    [anon_sym_function] = ACTIONS(4912),
    [anon_sym_static] = ACTIONS(4912),
    [anon_sym_constraint] = ACTIONS(4912),
    [anon_sym_if] = ACTIONS(4912),
    [anon_sym_else] = ACTIONS(4912),
    [anon_sym_LBRACK] = ACTIONS(4910),
    [anon_sym_localparam] = ACTIONS(4912),
    [anon_sym_parameter] = ACTIONS(4912),
    [anon_sym_var] = ACTIONS(4912),
    [anon_sym_import] = ACTIONS(4912),
    [anon_sym_export] = ACTIONS(4912),
    [anon_sym_genvar] = ACTIONS(4912),
    [anon_sym_interconnect] = ACTIONS(4912),
    [anon_sym_typedef] = ACTIONS(4912),
    [anon_sym_enum] = ACTIONS(4912),
    [anon_sym_struct] = ACTIONS(4912),
    [anon_sym_union] = ACTIONS(4912),
    [anon_sym_nettype] = ACTIONS(4912),
    [anon_sym_automatic] = ACTIONS(4912),
    [anon_sym_string] = ACTIONS(4912),
    [anon_sym_chandle] = ACTIONS(4912),
    [anon_sym_event] = ACTIONS(4912),
    [anon_sym_byte] = ACTIONS(4912),
    [anon_sym_shortint] = ACTIONS(4912),
    [anon_sym_int] = ACTIONS(4912),
    [anon_sym_longint] = ACTIONS(4912),
    [anon_sym_integer] = ACTIONS(4912),
    [anon_sym_time] = ACTIONS(4912),
    [anon_sym_bit] = ACTIONS(4912),
    [anon_sym_logic] = ACTIONS(4912),
    [anon_sym_reg] = ACTIONS(4912),
    [anon_sym_shortreal] = ACTIONS(4912),
    [anon_sym_real] = ACTIONS(4912),
    [anon_sym_realtime] = ACTIONS(4912),
    [anon_sym_supply0] = ACTIONS(4912),
    [anon_sym_supply1] = ACTIONS(4912),
    [anon_sym_signed] = ACTIONS(4912),
    [anon_sym_unsigned] = ACTIONS(4912),
    [anon_sym_task] = ACTIONS(4912),
    [anon_sym_assert] = ACTIONS(4912),
    [anon_sym_property] = ACTIONS(4912),
    [anon_sym_assume] = ACTIONS(4912),
    [anon_sym_cover] = ACTIONS(4912),
    [anon_sym_sequence] = ACTIONS(4912),
    [anon_sym_restrict] = ACTIONS(4912),
    [anon_sym_not] = ACTIONS(4912),
    [anon_sym_or] = ACTIONS(4912),
    [anon_sym_and] = ACTIONS(4912),
    [anon_sym_case] = ACTIONS(4912),
    [anon_sym_always] = ACTIONS(4912),
    [anon_sym_covergroup] = ACTIONS(4912),
    [anon_sym_end] = ACTIONS(4912),
    [anon_sym_let] = ACTIONS(4912),
    [anon_sym_pulldown] = ACTIONS(4912),
    [anon_sym_pullup] = ACTIONS(4912),
    [anon_sym_cmos] = ACTIONS(4912),
    [anon_sym_rcmos] = ACTIONS(4912),
    [anon_sym_bufif0] = ACTIONS(4912),
    [anon_sym_bufif1] = ACTIONS(4912),
    [anon_sym_notif0] = ACTIONS(4912),
    [anon_sym_notif1] = ACTIONS(4912),
    [anon_sym_nmos] = ACTIONS(4912),
    [anon_sym_pmos] = ACTIONS(4912),
    [anon_sym_rnmos] = ACTIONS(4912),
    [anon_sym_rpmos] = ACTIONS(4912),
    [anon_sym_nand] = ACTIONS(4912),
    [anon_sym_nor] = ACTIONS(4912),
    [anon_sym_xor] = ACTIONS(4912),
    [anon_sym_xnor] = ACTIONS(4912),
    [anon_sym_buf] = ACTIONS(4912),
    [anon_sym_tranif0] = ACTIONS(4912),
    [anon_sym_tranif1] = ACTIONS(4912),
    [anon_sym_rtranif1] = ACTIONS(4912),
    [anon_sym_rtranif0] = ACTIONS(4912),
    [anon_sym_tran] = ACTIONS(4912),
    [anon_sym_rtran] = ACTIONS(4912),
    [anon_sym_generate] = ACTIONS(4912),
    [anon_sym_for] = ACTIONS(4912),
    [anon_sym_initial] = ACTIONS(4912),
    [anon_sym_assign] = ACTIONS(4912),
    [anon_sym_alias] = ACTIONS(4912),
    [anon_sym_always_comb] = ACTIONS(4912),
    [anon_sym_always_latch] = ACTIONS(4912),
    [anon_sym_always_ff] = ACTIONS(4912),
    [anon_sym_final] = ACTIONS(4912),
    [anon_sym_global] = ACTIONS(4912),
    [anon_sym_LPAREN_STAR] = ACTIONS(4910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4910),
    [anon_sym_DOLLARunit] = ACTIONS(4910),
  },
  [4731] = {
    [sym_simple_identifier] = ACTIONS(4618),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_rand] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_endgenerate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [4732] = {
    [sym_simple_identifier] = ACTIONS(4124),
    [anon_sym_wire] = ACTIONS(4124),
    [anon_sym_tri] = ACTIONS(4124),
    [anon_sym_tri0] = ACTIONS(4124),
    [anon_sym_tri1] = ACTIONS(4124),
    [anon_sym_wand] = ACTIONS(4124),
    [anon_sym_triand] = ACTIONS(4124),
    [anon_sym_wor] = ACTIONS(4124),
    [anon_sym_trior] = ACTIONS(4124),
    [anon_sym_trireg] = ACTIONS(4124),
    [anon_sym_uwire] = ACTIONS(4124),
    [anon_sym_SEMI] = ACTIONS(4122),
    [anon_sym_extern] = ACTIONS(4124),
    [anon_sym_interface] = ACTIONS(4124),
    [anon_sym_checker] = ACTIONS(4124),
    [anon_sym_virtual] = ACTIONS(4124),
    [anon_sym_class] = ACTIONS(4124),
    [anon_sym_type] = ACTIONS(4124),
    [anon_sym_DOLLARfatal] = ACTIONS(4122),
    [anon_sym_DOLLARerror] = ACTIONS(4122),
    [anon_sym_DOLLARwarning] = ACTIONS(4122),
    [anon_sym_DOLLARinfo] = ACTIONS(4122),
    [anon_sym_default] = ACTIONS(4124),
    [anon_sym_clocking] = ACTIONS(4124),
    [anon_sym_defparam] = ACTIONS(4124),
    [anon_sym_bind] = ACTIONS(4124),
    [anon_sym_rand] = ACTIONS(4124),
    [anon_sym_const] = ACTIONS(4124),
    [anon_sym_function] = ACTIONS(4124),
    [anon_sym_static] = ACTIONS(4124),
    [anon_sym_constraint] = ACTIONS(4124),
    [anon_sym_if] = ACTIONS(4124),
    [anon_sym_else] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4122),
    [anon_sym_localparam] = ACTIONS(4124),
    [anon_sym_parameter] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4124),
    [anon_sym_import] = ACTIONS(4124),
    [anon_sym_export] = ACTIONS(4124),
    [anon_sym_genvar] = ACTIONS(4124),
    [anon_sym_interconnect] = ACTIONS(4124),
    [anon_sym_typedef] = ACTIONS(4124),
    [anon_sym_enum] = ACTIONS(4124),
    [anon_sym_struct] = ACTIONS(4124),
    [anon_sym_union] = ACTIONS(4124),
    [anon_sym_nettype] = ACTIONS(4124),
    [anon_sym_automatic] = ACTIONS(4124),
    [anon_sym_string] = ACTIONS(4124),
    [anon_sym_chandle] = ACTIONS(4124),
    [anon_sym_event] = ACTIONS(4124),
    [anon_sym_byte] = ACTIONS(4124),
    [anon_sym_shortint] = ACTIONS(4124),
    [anon_sym_int] = ACTIONS(4124),
    [anon_sym_longint] = ACTIONS(4124),
    [anon_sym_integer] = ACTIONS(4124),
    [anon_sym_time] = ACTIONS(4124),
    [anon_sym_bit] = ACTIONS(4124),
    [anon_sym_logic] = ACTIONS(4124),
    [anon_sym_reg] = ACTIONS(4124),
    [anon_sym_shortreal] = ACTIONS(4124),
    [anon_sym_real] = ACTIONS(4124),
    [anon_sym_realtime] = ACTIONS(4124),
    [anon_sym_supply0] = ACTIONS(4124),
    [anon_sym_supply1] = ACTIONS(4124),
    [anon_sym_signed] = ACTIONS(4124),
    [anon_sym_unsigned] = ACTIONS(4124),
    [anon_sym_task] = ACTIONS(4124),
    [anon_sym_assert] = ACTIONS(4124),
    [anon_sym_property] = ACTIONS(4124),
    [anon_sym_assume] = ACTIONS(4124),
    [anon_sym_cover] = ACTIONS(4124),
    [anon_sym_sequence] = ACTIONS(4124),
    [anon_sym_restrict] = ACTIONS(4124),
    [anon_sym_not] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_case] = ACTIONS(4124),
    [anon_sym_always] = ACTIONS(4124),
    [anon_sym_covergroup] = ACTIONS(4124),
    [anon_sym_end] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_pulldown] = ACTIONS(4124),
    [anon_sym_pullup] = ACTIONS(4124),
    [anon_sym_cmos] = ACTIONS(4124),
    [anon_sym_rcmos] = ACTIONS(4124),
    [anon_sym_bufif0] = ACTIONS(4124),
    [anon_sym_bufif1] = ACTIONS(4124),
    [anon_sym_notif0] = ACTIONS(4124),
    [anon_sym_notif1] = ACTIONS(4124),
    [anon_sym_nmos] = ACTIONS(4124),
    [anon_sym_pmos] = ACTIONS(4124),
    [anon_sym_rnmos] = ACTIONS(4124),
    [anon_sym_rpmos] = ACTIONS(4124),
    [anon_sym_nand] = ACTIONS(4124),
    [anon_sym_nor] = ACTIONS(4124),
    [anon_sym_xor] = ACTIONS(4124),
    [anon_sym_xnor] = ACTIONS(4124),
    [anon_sym_buf] = ACTIONS(4124),
    [anon_sym_tranif0] = ACTIONS(4124),
    [anon_sym_tranif1] = ACTIONS(4124),
    [anon_sym_rtranif1] = ACTIONS(4124),
    [anon_sym_rtranif0] = ACTIONS(4124),
    [anon_sym_tran] = ACTIONS(4124),
    [anon_sym_rtran] = ACTIONS(4124),
    [anon_sym_generate] = ACTIONS(4124),
    [anon_sym_for] = ACTIONS(4124),
    [anon_sym_initial] = ACTIONS(4124),
    [anon_sym_assign] = ACTIONS(4124),
    [anon_sym_alias] = ACTIONS(4124),
    [anon_sym_always_comb] = ACTIONS(4124),
    [anon_sym_always_latch] = ACTIONS(4124),
    [anon_sym_always_ff] = ACTIONS(4124),
    [anon_sym_final] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4124),
    [anon_sym_LPAREN_STAR] = ACTIONS(4122),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4122),
    [anon_sym_DOLLARunit] = ACTIONS(4122),
  },
  [4733] = {
    [sym_attribute_instance] = STATE(4733),
    [aux_sym__description_repeat1] = STATE(4733),
    [sym_simple_identifier] = ACTIONS(9204),
    [anon_sym_DQUOTE] = ACTIONS(9206),
    [anon_sym_LPAREN] = ACTIONS(9204),
    [anon_sym_BQUOTE] = ACTIONS(9206),
    [anon_sym_DOT_STAR] = ACTIONS(9206),
    [anon_sym_SEMI] = ACTIONS(9206),
    [anon_sym_virtual] = ACTIONS(9204),
    [anon_sym_POUND] = ACTIONS(9204),
    [anon_sym_type] = ACTIONS(9204),
    [anon_sym_DOT] = ACTIONS(9204),
    [anon_sym_LBRACE] = ACTIONS(9206),
    [anon_sym_input] = ACTIONS(9204),
    [anon_sym_output] = ACTIONS(9204),
    [anon_sym_inout] = ACTIONS(9204),
    [anon_sym_ref] = ACTIONS(9204),
    [anon_sym_disable] = ACTIONS(9204),
    [anon_sym_const] = ACTIONS(9204),
    [anon_sym_local] = ACTIONS(9204),
    [anon_sym_super] = ACTIONS(9204),
    [anon_sym_if] = ACTIONS(9204),
    [anon_sym_foreach] = ACTIONS(9204),
    [anon_sym_LBRACK] = ACTIONS(9206),
    [anon_sym_unique] = ACTIONS(9204),
    [anon_sym_var] = ACTIONS(9204),
    [anon_sym_enum] = ACTIONS(9204),
    [anon_sym_struct] = ACTIONS(9204),
    [anon_sym_union] = ACTIONS(9204),
    [anon_sym_string] = ACTIONS(9204),
    [anon_sym_chandle] = ACTIONS(9204),
    [anon_sym_event] = ACTIONS(9204),
    [anon_sym_byte] = ACTIONS(9204),
    [anon_sym_shortint] = ACTIONS(9204),
    [anon_sym_int] = ACTIONS(9204),
    [anon_sym_longint] = ACTIONS(9204),
    [anon_sym_integer] = ACTIONS(9204),
    [anon_sym_time] = ACTIONS(9204),
    [anon_sym_bit] = ACTIONS(9204),
    [anon_sym_logic] = ACTIONS(9204),
    [anon_sym_reg] = ACTIONS(9204),
    [anon_sym_shortreal] = ACTIONS(9204),
    [anon_sym_real] = ACTIONS(9204),
    [anon_sym_realtime] = ACTIONS(9204),
    [anon_sym_signed] = ACTIONS(9204),
    [anon_sym_unsigned] = ACTIONS(9204),
    [anon_sym_tagged] = ACTIONS(9204),
    [anon_sym_DOLLAR] = ACTIONS(9204),
    [anon_sym_PLUS] = ACTIONS(9204),
    [anon_sym_PLUS_PLUS] = ACTIONS(9206),
    [anon_sym_assert] = ACTIONS(9204),
    [anon_sym_property] = ACTIONS(9204),
    [anon_sym_assume] = ACTIONS(9204),
    [anon_sym_cover] = ACTIONS(9204),
    [anon_sym_expect] = ACTIONS(9204),
    [anon_sym_sequence] = ACTIONS(9204),
    [anon_sym_restrict] = ACTIONS(9204),
    [anon_sym_case] = ACTIONS(9204),
    [anon_sym_untyped] = ACTIONS(9204),
    [anon_sym_POUND_POUND] = ACTIONS(9206),
    [anon_sym_begin] = ACTIONS(9204),
    [anon_sym_BANG] = ACTIONS(9206),
    [anon_sym_for] = ACTIONS(9204),
    [anon_sym_DASH] = ACTIONS(9204),
    [anon_sym_assign] = ACTIONS(9204),
    [anon_sym_deassign] = ACTIONS(9204),
    [anon_sym_force] = ACTIONS(9204),
    [anon_sym_release] = ACTIONS(9204),
    [anon_sym_fork] = ACTIONS(9204),
    [anon_sym_repeat] = ACTIONS(9204),
    [anon_sym_AT] = ACTIONS(9204),
    [anon_sym_AT_STAR] = ACTIONS(9206),
    [anon_sym_return] = ACTIONS(9204),
    [anon_sym_break] = ACTIONS(9204),
    [anon_sym_continue] = ACTIONS(9204),
    [anon_sym_wait] = ACTIONS(9204),
    [anon_sym_wait_order] = ACTIONS(9204),
    [anon_sym_DASH_GT] = ACTIONS(9204),
    [anon_sym_DASH_GT_GT] = ACTIONS(9206),
    [anon_sym_unique0] = ACTIONS(9204),
    [anon_sym_priority] = ACTIONS(9204),
    [anon_sym_casez] = ACTIONS(9204),
    [anon_sym_casex] = ACTIONS(9204),
    [anon_sym_randcase] = ACTIONS(9204),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9206),
    [anon_sym_forever] = ACTIONS(9204),
    [anon_sym_while] = ACTIONS(9204),
    [anon_sym_do] = ACTIONS(9204),
    [anon_sym_TILDE] = ACTIONS(9204),
    [anon_sym_std] = ACTIONS(9204),
    [anon_sym_randomize] = ACTIONS(9204),
    [anon_sym_null] = ACTIONS(9204),
    [anon_sym_AMP] = ACTIONS(9206),
    [anon_sym_PIPE] = ACTIONS(9206),
    [anon_sym_CARET] = ACTIONS(9204),
    [anon_sym_CARET_TILDE] = ACTIONS(9206),
    [anon_sym_TILDE_CARET] = ACTIONS(9206),
    [anon_sym_this] = ACTIONS(9204),
    [anon_sym_TILDE_AMP] = ACTIONS(9206),
    [anon_sym_TILDE_PIPE] = ACTIONS(9206),
    [anon_sym_DASH_DASH] = ACTIONS(9206),
    [aux_sym_decimal_number_token1] = ACTIONS(9206),
    [aux_sym_decimal_number_token2] = ACTIONS(9206),
    [sym_binary_number] = ACTIONS(9206),
    [sym_octal_number] = ACTIONS(9206),
    [sym_hex_number] = ACTIONS(9206),
    [aux_sym_real_number_token1] = ACTIONS(9206),
    [sym_fixed_point_number] = ACTIONS(9204),
    [sym_unsigned_number] = ACTIONS(9204),
    [anon_sym_SQUOTE0] = ACTIONS(9206),
    [anon_sym_SQUOTE1] = ACTIONS(9206),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(9206),
    [anon_sym_LPAREN_STAR] = ACTIONS(11024),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9206),
    [anon_sym_DOLLARroot] = ACTIONS(9204),
    [anon_sym_DOLLARunit] = ACTIONS(9204),
    [sym_system_tf_identifier] = ACTIONS(9204),
  },
  [4734] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_rand] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(6699),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_end] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [4735] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(11027),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_end] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [4736] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_rand] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(11029),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_end] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [4737] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_rand] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(11031),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_end] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [4738] = {
    [sym_simple_identifier] = ACTIONS(6739),
    [anon_sym_wire] = ACTIONS(6739),
    [anon_sym_tri] = ACTIONS(6739),
    [anon_sym_tri0] = ACTIONS(6739),
    [anon_sym_tri1] = ACTIONS(6739),
    [anon_sym_wand] = ACTIONS(6739),
    [anon_sym_triand] = ACTIONS(6739),
    [anon_sym_wor] = ACTIONS(6739),
    [anon_sym_trior] = ACTIONS(6739),
    [anon_sym_trireg] = ACTIONS(6739),
    [anon_sym_uwire] = ACTIONS(6739),
    [anon_sym_SEMI] = ACTIONS(6741),
    [anon_sym_extern] = ACTIONS(6739),
    [anon_sym_interface] = ACTIONS(6739),
    [anon_sym_checker] = ACTIONS(6739),
    [anon_sym_virtual] = ACTIONS(6739),
    [anon_sym_class] = ACTIONS(6739),
    [anon_sym_type] = ACTIONS(6739),
    [anon_sym_DOLLARfatal] = ACTIONS(6741),
    [anon_sym_DOLLARerror] = ACTIONS(6741),
    [anon_sym_DOLLARwarning] = ACTIONS(6741),
    [anon_sym_DOLLARinfo] = ACTIONS(6741),
    [anon_sym_default] = ACTIONS(6739),
    [anon_sym_clocking] = ACTIONS(6739),
    [anon_sym_defparam] = ACTIONS(6739),
    [anon_sym_bind] = ACTIONS(6739),
    [anon_sym_rand] = ACTIONS(6739),
    [anon_sym_const] = ACTIONS(6739),
    [anon_sym_function] = ACTIONS(6739),
    [anon_sym_static] = ACTIONS(6739),
    [anon_sym_constraint] = ACTIONS(6739),
    [anon_sym_if] = ACTIONS(6739),
    [anon_sym_else] = ACTIONS(6739),
    [anon_sym_LBRACK] = ACTIONS(6741),
    [anon_sym_localparam] = ACTIONS(6739),
    [anon_sym_parameter] = ACTIONS(6739),
    [anon_sym_var] = ACTIONS(6739),
    [anon_sym_import] = ACTIONS(6739),
    [anon_sym_export] = ACTIONS(6739),
    [anon_sym_genvar] = ACTIONS(6739),
    [anon_sym_interconnect] = ACTIONS(6739),
    [anon_sym_typedef] = ACTIONS(6739),
    [anon_sym_enum] = ACTIONS(6739),
    [anon_sym_struct] = ACTIONS(6739),
    [anon_sym_union] = ACTIONS(6739),
    [anon_sym_nettype] = ACTIONS(6739),
    [anon_sym_automatic] = ACTIONS(6739),
    [anon_sym_string] = ACTIONS(6739),
    [anon_sym_chandle] = ACTIONS(6739),
    [anon_sym_event] = ACTIONS(6739),
    [anon_sym_byte] = ACTIONS(6739),
    [anon_sym_shortint] = ACTIONS(6739),
    [anon_sym_int] = ACTIONS(6739),
    [anon_sym_longint] = ACTIONS(6739),
    [anon_sym_integer] = ACTIONS(6739),
    [anon_sym_time] = ACTIONS(6739),
    [anon_sym_bit] = ACTIONS(6739),
    [anon_sym_logic] = ACTIONS(6739),
    [anon_sym_reg] = ACTIONS(6739),
    [anon_sym_shortreal] = ACTIONS(6739),
    [anon_sym_real] = ACTIONS(6739),
    [anon_sym_realtime] = ACTIONS(6739),
    [anon_sym_supply0] = ACTIONS(6739),
    [anon_sym_supply1] = ACTIONS(6739),
    [anon_sym_signed] = ACTIONS(6739),
    [anon_sym_unsigned] = ACTIONS(6739),
    [anon_sym_task] = ACTIONS(6739),
    [anon_sym_assert] = ACTIONS(6739),
    [anon_sym_property] = ACTIONS(6739),
    [anon_sym_assume] = ACTIONS(6739),
    [anon_sym_cover] = ACTIONS(6739),
    [anon_sym_sequence] = ACTIONS(6739),
    [anon_sym_restrict] = ACTIONS(6739),
    [anon_sym_not] = ACTIONS(6739),
    [anon_sym_or] = ACTIONS(6739),
    [anon_sym_and] = ACTIONS(6739),
    [anon_sym_case] = ACTIONS(6739),
    [anon_sym_always] = ACTIONS(6739),
    [anon_sym_covergroup] = ACTIONS(6739),
    [anon_sym_let] = ACTIONS(6739),
    [anon_sym_pulldown] = ACTIONS(6739),
    [anon_sym_pullup] = ACTIONS(6739),
    [anon_sym_cmos] = ACTIONS(6739),
    [anon_sym_rcmos] = ACTIONS(6739),
    [anon_sym_bufif0] = ACTIONS(6739),
    [anon_sym_bufif1] = ACTIONS(6739),
    [anon_sym_notif0] = ACTIONS(6739),
    [anon_sym_notif1] = ACTIONS(6739),
    [anon_sym_nmos] = ACTIONS(6739),
    [anon_sym_pmos] = ACTIONS(6739),
    [anon_sym_rnmos] = ACTIONS(6739),
    [anon_sym_rpmos] = ACTIONS(6739),
    [anon_sym_nand] = ACTIONS(6739),
    [anon_sym_nor] = ACTIONS(6739),
    [anon_sym_xor] = ACTIONS(6739),
    [anon_sym_xnor] = ACTIONS(6739),
    [anon_sym_buf] = ACTIONS(6739),
    [anon_sym_tranif0] = ACTIONS(6739),
    [anon_sym_tranif1] = ACTIONS(6739),
    [anon_sym_rtranif1] = ACTIONS(6739),
    [anon_sym_rtranif0] = ACTIONS(6739),
    [anon_sym_tran] = ACTIONS(6739),
    [anon_sym_rtran] = ACTIONS(6739),
    [anon_sym_generate] = ACTIONS(6739),
    [anon_sym_endgenerate] = ACTIONS(6739),
    [anon_sym_for] = ACTIONS(6739),
    [anon_sym_initial] = ACTIONS(6739),
    [anon_sym_assign] = ACTIONS(6739),
    [anon_sym_alias] = ACTIONS(6739),
    [anon_sym_always_comb] = ACTIONS(6739),
    [anon_sym_always_latch] = ACTIONS(6739),
    [anon_sym_always_ff] = ACTIONS(6739),
    [anon_sym_final] = ACTIONS(6739),
    [anon_sym_global] = ACTIONS(6739),
    [anon_sym_LPAREN_STAR] = ACTIONS(6741),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6741),
    [anon_sym_DOLLARunit] = ACTIONS(6741),
  },
  [4739] = {
    [sym_simple_identifier] = ACTIONS(4832),
    [anon_sym_wire] = ACTIONS(4832),
    [anon_sym_tri] = ACTIONS(4832),
    [anon_sym_tri0] = ACTIONS(4832),
    [anon_sym_tri1] = ACTIONS(4832),
    [anon_sym_wand] = ACTIONS(4832),
    [anon_sym_triand] = ACTIONS(4832),
    [anon_sym_wor] = ACTIONS(4832),
    [anon_sym_trior] = ACTIONS(4832),
    [anon_sym_trireg] = ACTIONS(4832),
    [anon_sym_uwire] = ACTIONS(4832),
    [anon_sym_SEMI] = ACTIONS(4830),
    [anon_sym_extern] = ACTIONS(4832),
    [anon_sym_interface] = ACTIONS(4832),
    [anon_sym_checker] = ACTIONS(4832),
    [anon_sym_virtual] = ACTIONS(4832),
    [anon_sym_class] = ACTIONS(4832),
    [anon_sym_type] = ACTIONS(4832),
    [anon_sym_DOLLARfatal] = ACTIONS(4830),
    [anon_sym_DOLLARerror] = ACTIONS(4830),
    [anon_sym_DOLLARwarning] = ACTIONS(4830),
    [anon_sym_DOLLARinfo] = ACTIONS(4830),
    [anon_sym_default] = ACTIONS(4832),
    [anon_sym_clocking] = ACTIONS(4832),
    [anon_sym_defparam] = ACTIONS(4832),
    [anon_sym_bind] = ACTIONS(4832),
    [anon_sym_rand] = ACTIONS(4832),
    [anon_sym_const] = ACTIONS(4832),
    [anon_sym_function] = ACTIONS(4832),
    [anon_sym_static] = ACTIONS(4832),
    [anon_sym_constraint] = ACTIONS(4832),
    [anon_sym_if] = ACTIONS(4832),
    [anon_sym_else] = ACTIONS(4832),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [anon_sym_localparam] = ACTIONS(4832),
    [anon_sym_parameter] = ACTIONS(4832),
    [anon_sym_var] = ACTIONS(4832),
    [anon_sym_import] = ACTIONS(4832),
    [anon_sym_export] = ACTIONS(4832),
    [anon_sym_genvar] = ACTIONS(4832),
    [anon_sym_interconnect] = ACTIONS(4832),
    [anon_sym_typedef] = ACTIONS(4832),
    [anon_sym_enum] = ACTIONS(4832),
    [anon_sym_struct] = ACTIONS(4832),
    [anon_sym_union] = ACTIONS(4832),
    [anon_sym_nettype] = ACTIONS(4832),
    [anon_sym_automatic] = ACTIONS(4832),
    [anon_sym_string] = ACTIONS(4832),
    [anon_sym_chandle] = ACTIONS(4832),
    [anon_sym_event] = ACTIONS(4832),
    [anon_sym_byte] = ACTIONS(4832),
    [anon_sym_shortint] = ACTIONS(4832),
    [anon_sym_int] = ACTIONS(4832),
    [anon_sym_longint] = ACTIONS(4832),
    [anon_sym_integer] = ACTIONS(4832),
    [anon_sym_time] = ACTIONS(4832),
    [anon_sym_bit] = ACTIONS(4832),
    [anon_sym_logic] = ACTIONS(4832),
    [anon_sym_reg] = ACTIONS(4832),
    [anon_sym_shortreal] = ACTIONS(4832),
    [anon_sym_real] = ACTIONS(4832),
    [anon_sym_realtime] = ACTIONS(4832),
    [anon_sym_supply0] = ACTIONS(4832),
    [anon_sym_supply1] = ACTIONS(4832),
    [anon_sym_signed] = ACTIONS(4832),
    [anon_sym_unsigned] = ACTIONS(4832),
    [anon_sym_task] = ACTIONS(4832),
    [anon_sym_assert] = ACTIONS(4832),
    [anon_sym_property] = ACTIONS(4832),
    [anon_sym_assume] = ACTIONS(4832),
    [anon_sym_cover] = ACTIONS(4832),
    [anon_sym_sequence] = ACTIONS(4832),
    [anon_sym_restrict] = ACTIONS(4832),
    [anon_sym_not] = ACTIONS(4832),
    [anon_sym_or] = ACTIONS(4832),
    [anon_sym_and] = ACTIONS(4832),
    [anon_sym_case] = ACTIONS(4832),
    [anon_sym_always] = ACTIONS(4832),
    [anon_sym_covergroup] = ACTIONS(4832),
    [anon_sym_end] = ACTIONS(4832),
    [anon_sym_let] = ACTIONS(4832),
    [anon_sym_pulldown] = ACTIONS(4832),
    [anon_sym_pullup] = ACTIONS(4832),
    [anon_sym_cmos] = ACTIONS(4832),
    [anon_sym_rcmos] = ACTIONS(4832),
    [anon_sym_bufif0] = ACTIONS(4832),
    [anon_sym_bufif1] = ACTIONS(4832),
    [anon_sym_notif0] = ACTIONS(4832),
    [anon_sym_notif1] = ACTIONS(4832),
    [anon_sym_nmos] = ACTIONS(4832),
    [anon_sym_pmos] = ACTIONS(4832),
    [anon_sym_rnmos] = ACTIONS(4832),
    [anon_sym_rpmos] = ACTIONS(4832),
    [anon_sym_nand] = ACTIONS(4832),
    [anon_sym_nor] = ACTIONS(4832),
    [anon_sym_xor] = ACTIONS(4832),
    [anon_sym_xnor] = ACTIONS(4832),
    [anon_sym_buf] = ACTIONS(4832),
    [anon_sym_tranif0] = ACTIONS(4832),
    [anon_sym_tranif1] = ACTIONS(4832),
    [anon_sym_rtranif1] = ACTIONS(4832),
    [anon_sym_rtranif0] = ACTIONS(4832),
    [anon_sym_tran] = ACTIONS(4832),
    [anon_sym_rtran] = ACTIONS(4832),
    [anon_sym_generate] = ACTIONS(4832),
    [anon_sym_for] = ACTIONS(4832),
    [anon_sym_initial] = ACTIONS(4832),
    [anon_sym_assign] = ACTIONS(4832),
    [anon_sym_alias] = ACTIONS(4832),
    [anon_sym_always_comb] = ACTIONS(4832),
    [anon_sym_always_latch] = ACTIONS(4832),
    [anon_sym_always_ff] = ACTIONS(4832),
    [anon_sym_final] = ACTIONS(4832),
    [anon_sym_global] = ACTIONS(4832),
    [anon_sym_LPAREN_STAR] = ACTIONS(4830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4830),
    [anon_sym_DOLLARunit] = ACTIONS(4830),
  },
  [4740] = {
    [sym_simple_identifier] = ACTIONS(6401),
    [anon_sym_wire] = ACTIONS(6401),
    [anon_sym_tri] = ACTIONS(6401),
    [anon_sym_tri0] = ACTIONS(6401),
    [anon_sym_tri1] = ACTIONS(6401),
    [anon_sym_wand] = ACTIONS(6401),
    [anon_sym_triand] = ACTIONS(6401),
    [anon_sym_wor] = ACTIONS(6401),
    [anon_sym_trior] = ACTIONS(6401),
    [anon_sym_trireg] = ACTIONS(6401),
    [anon_sym_uwire] = ACTIONS(6401),
    [anon_sym_SEMI] = ACTIONS(6403),
    [anon_sym_extern] = ACTIONS(6401),
    [anon_sym_interface] = ACTIONS(6401),
    [anon_sym_checker] = ACTIONS(6401),
    [anon_sym_virtual] = ACTIONS(6401),
    [anon_sym_class] = ACTIONS(6401),
    [anon_sym_type] = ACTIONS(6401),
    [anon_sym_DOLLARfatal] = ACTIONS(6403),
    [anon_sym_DOLLARerror] = ACTIONS(6403),
    [anon_sym_DOLLARwarning] = ACTIONS(6403),
    [anon_sym_DOLLARinfo] = ACTIONS(6403),
    [anon_sym_default] = ACTIONS(6401),
    [anon_sym_clocking] = ACTIONS(6401),
    [anon_sym_defparam] = ACTIONS(6401),
    [anon_sym_bind] = ACTIONS(6401),
    [anon_sym_rand] = ACTIONS(6401),
    [anon_sym_const] = ACTIONS(6401),
    [anon_sym_function] = ACTIONS(6401),
    [anon_sym_static] = ACTIONS(6401),
    [anon_sym_constraint] = ACTIONS(6401),
    [anon_sym_if] = ACTIONS(6401),
    [anon_sym_else] = ACTIONS(6401),
    [anon_sym_LBRACK] = ACTIONS(6403),
    [anon_sym_localparam] = ACTIONS(6401),
    [anon_sym_parameter] = ACTIONS(6401),
    [anon_sym_var] = ACTIONS(6401),
    [anon_sym_import] = ACTIONS(6401),
    [anon_sym_export] = ACTIONS(6401),
    [anon_sym_genvar] = ACTIONS(6401),
    [anon_sym_interconnect] = ACTIONS(6401),
    [anon_sym_typedef] = ACTIONS(6401),
    [anon_sym_enum] = ACTIONS(6401),
    [anon_sym_struct] = ACTIONS(6401),
    [anon_sym_union] = ACTIONS(6401),
    [anon_sym_nettype] = ACTIONS(6401),
    [anon_sym_automatic] = ACTIONS(6401),
    [anon_sym_string] = ACTIONS(6401),
    [anon_sym_chandle] = ACTIONS(6401),
    [anon_sym_event] = ACTIONS(6401),
    [anon_sym_byte] = ACTIONS(6401),
    [anon_sym_shortint] = ACTIONS(6401),
    [anon_sym_int] = ACTIONS(6401),
    [anon_sym_longint] = ACTIONS(6401),
    [anon_sym_integer] = ACTIONS(6401),
    [anon_sym_time] = ACTIONS(6401),
    [anon_sym_bit] = ACTIONS(6401),
    [anon_sym_logic] = ACTIONS(6401),
    [anon_sym_reg] = ACTIONS(6401),
    [anon_sym_shortreal] = ACTIONS(6401),
    [anon_sym_real] = ACTIONS(6401),
    [anon_sym_realtime] = ACTIONS(6401),
    [anon_sym_supply0] = ACTIONS(6401),
    [anon_sym_supply1] = ACTIONS(6401),
    [anon_sym_signed] = ACTIONS(6401),
    [anon_sym_unsigned] = ACTIONS(6401),
    [anon_sym_task] = ACTIONS(6401),
    [anon_sym_assert] = ACTIONS(6401),
    [anon_sym_property] = ACTIONS(6401),
    [anon_sym_assume] = ACTIONS(6401),
    [anon_sym_cover] = ACTIONS(6401),
    [anon_sym_sequence] = ACTIONS(6401),
    [anon_sym_restrict] = ACTIONS(6401),
    [anon_sym_not] = ACTIONS(6401),
    [anon_sym_or] = ACTIONS(6401),
    [anon_sym_and] = ACTIONS(6401),
    [anon_sym_case] = ACTIONS(6401),
    [anon_sym_always] = ACTIONS(6401),
    [anon_sym_covergroup] = ACTIONS(6401),
    [anon_sym_let] = ACTIONS(6401),
    [anon_sym_pulldown] = ACTIONS(6401),
    [anon_sym_pullup] = ACTIONS(6401),
    [anon_sym_cmos] = ACTIONS(6401),
    [anon_sym_rcmos] = ACTIONS(6401),
    [anon_sym_bufif0] = ACTIONS(6401),
    [anon_sym_bufif1] = ACTIONS(6401),
    [anon_sym_notif0] = ACTIONS(6401),
    [anon_sym_notif1] = ACTIONS(6401),
    [anon_sym_nmos] = ACTIONS(6401),
    [anon_sym_pmos] = ACTIONS(6401),
    [anon_sym_rnmos] = ACTIONS(6401),
    [anon_sym_rpmos] = ACTIONS(6401),
    [anon_sym_nand] = ACTIONS(6401),
    [anon_sym_nor] = ACTIONS(6401),
    [anon_sym_xor] = ACTIONS(6401),
    [anon_sym_xnor] = ACTIONS(6401),
    [anon_sym_buf] = ACTIONS(6401),
    [anon_sym_tranif0] = ACTIONS(6401),
    [anon_sym_tranif1] = ACTIONS(6401),
    [anon_sym_rtranif1] = ACTIONS(6401),
    [anon_sym_rtranif0] = ACTIONS(6401),
    [anon_sym_tran] = ACTIONS(6401),
    [anon_sym_rtran] = ACTIONS(6401),
    [anon_sym_generate] = ACTIONS(6401),
    [anon_sym_endgenerate] = ACTIONS(6401),
    [anon_sym_for] = ACTIONS(6401),
    [anon_sym_initial] = ACTIONS(6401),
    [anon_sym_assign] = ACTIONS(6401),
    [anon_sym_alias] = ACTIONS(6401),
    [anon_sym_always_comb] = ACTIONS(6401),
    [anon_sym_always_latch] = ACTIONS(6401),
    [anon_sym_always_ff] = ACTIONS(6401),
    [anon_sym_final] = ACTIONS(6401),
    [anon_sym_global] = ACTIONS(6401),
    [anon_sym_LPAREN_STAR] = ACTIONS(6403),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6403),
    [anon_sym_DOLLARunit] = ACTIONS(6403),
  },
  [4741] = {
    [sym_simple_identifier] = ACTIONS(5274),
    [anon_sym_wire] = ACTIONS(5274),
    [anon_sym_tri] = ACTIONS(5274),
    [anon_sym_tri0] = ACTIONS(5274),
    [anon_sym_tri1] = ACTIONS(5274),
    [anon_sym_wand] = ACTIONS(5274),
    [anon_sym_triand] = ACTIONS(5274),
    [anon_sym_wor] = ACTIONS(5274),
    [anon_sym_trior] = ACTIONS(5274),
    [anon_sym_trireg] = ACTIONS(5274),
    [anon_sym_uwire] = ACTIONS(5274),
    [anon_sym_SEMI] = ACTIONS(5272),
    [anon_sym_extern] = ACTIONS(5274),
    [anon_sym_interface] = ACTIONS(5274),
    [anon_sym_checker] = ACTIONS(5274),
    [anon_sym_virtual] = ACTIONS(5274),
    [anon_sym_class] = ACTIONS(5274),
    [anon_sym_type] = ACTIONS(5274),
    [anon_sym_DOLLARfatal] = ACTIONS(5272),
    [anon_sym_DOLLARerror] = ACTIONS(5272),
    [anon_sym_DOLLARwarning] = ACTIONS(5272),
    [anon_sym_DOLLARinfo] = ACTIONS(5272),
    [anon_sym_default] = ACTIONS(5274),
    [anon_sym_clocking] = ACTIONS(5274),
    [anon_sym_defparam] = ACTIONS(5274),
    [anon_sym_bind] = ACTIONS(5274),
    [anon_sym_rand] = ACTIONS(5274),
    [anon_sym_const] = ACTIONS(5274),
    [anon_sym_function] = ACTIONS(5274),
    [anon_sym_static] = ACTIONS(5274),
    [anon_sym_constraint] = ACTIONS(5274),
    [anon_sym_if] = ACTIONS(5274),
    [anon_sym_else] = ACTIONS(5274),
    [anon_sym_LBRACK] = ACTIONS(5272),
    [anon_sym_localparam] = ACTIONS(5274),
    [anon_sym_parameter] = ACTIONS(5274),
    [anon_sym_var] = ACTIONS(5274),
    [anon_sym_import] = ACTIONS(5274),
    [anon_sym_export] = ACTIONS(5274),
    [anon_sym_genvar] = ACTIONS(5274),
    [anon_sym_interconnect] = ACTIONS(5274),
    [anon_sym_typedef] = ACTIONS(5274),
    [anon_sym_enum] = ACTIONS(5274),
    [anon_sym_struct] = ACTIONS(5274),
    [anon_sym_union] = ACTIONS(5274),
    [anon_sym_nettype] = ACTIONS(5274),
    [anon_sym_automatic] = ACTIONS(5274),
    [anon_sym_string] = ACTIONS(5274),
    [anon_sym_chandle] = ACTIONS(5274),
    [anon_sym_event] = ACTIONS(5274),
    [anon_sym_byte] = ACTIONS(5274),
    [anon_sym_shortint] = ACTIONS(5274),
    [anon_sym_int] = ACTIONS(5274),
    [anon_sym_longint] = ACTIONS(5274),
    [anon_sym_integer] = ACTIONS(5274),
    [anon_sym_time] = ACTIONS(5274),
    [anon_sym_bit] = ACTIONS(5274),
    [anon_sym_logic] = ACTIONS(5274),
    [anon_sym_reg] = ACTIONS(5274),
    [anon_sym_shortreal] = ACTIONS(5274),
    [anon_sym_real] = ACTIONS(5274),
    [anon_sym_realtime] = ACTIONS(5274),
    [anon_sym_supply0] = ACTIONS(5274),
    [anon_sym_supply1] = ACTIONS(5274),
    [anon_sym_signed] = ACTIONS(5274),
    [anon_sym_unsigned] = ACTIONS(5274),
    [anon_sym_task] = ACTIONS(5274),
    [anon_sym_assert] = ACTIONS(5274),
    [anon_sym_property] = ACTIONS(5274),
    [anon_sym_assume] = ACTIONS(5274),
    [anon_sym_cover] = ACTIONS(5274),
    [anon_sym_sequence] = ACTIONS(5274),
    [anon_sym_restrict] = ACTIONS(5274),
    [anon_sym_not] = ACTIONS(5274),
    [anon_sym_or] = ACTIONS(5274),
    [anon_sym_and] = ACTIONS(5274),
    [anon_sym_case] = ACTIONS(5274),
    [anon_sym_always] = ACTIONS(5274),
    [anon_sym_covergroup] = ACTIONS(5274),
    [anon_sym_end] = ACTIONS(5274),
    [anon_sym_let] = ACTIONS(5274),
    [anon_sym_pulldown] = ACTIONS(5274),
    [anon_sym_pullup] = ACTIONS(5274),
    [anon_sym_cmos] = ACTIONS(5274),
    [anon_sym_rcmos] = ACTIONS(5274),
    [anon_sym_bufif0] = ACTIONS(5274),
    [anon_sym_bufif1] = ACTIONS(5274),
    [anon_sym_notif0] = ACTIONS(5274),
    [anon_sym_notif1] = ACTIONS(5274),
    [anon_sym_nmos] = ACTIONS(5274),
    [anon_sym_pmos] = ACTIONS(5274),
    [anon_sym_rnmos] = ACTIONS(5274),
    [anon_sym_rpmos] = ACTIONS(5274),
    [anon_sym_nand] = ACTIONS(5274),
    [anon_sym_nor] = ACTIONS(5274),
    [anon_sym_xor] = ACTIONS(5274),
    [anon_sym_xnor] = ACTIONS(5274),
    [anon_sym_buf] = ACTIONS(5274),
    [anon_sym_tranif0] = ACTIONS(5274),
    [anon_sym_tranif1] = ACTIONS(5274),
    [anon_sym_rtranif1] = ACTIONS(5274),
    [anon_sym_rtranif0] = ACTIONS(5274),
    [anon_sym_tran] = ACTIONS(5274),
    [anon_sym_rtran] = ACTIONS(5274),
    [anon_sym_generate] = ACTIONS(5274),
    [anon_sym_for] = ACTIONS(5274),
    [anon_sym_initial] = ACTIONS(5274),
    [anon_sym_assign] = ACTIONS(5274),
    [anon_sym_alias] = ACTIONS(5274),
    [anon_sym_always_comb] = ACTIONS(5274),
    [anon_sym_always_latch] = ACTIONS(5274),
    [anon_sym_always_ff] = ACTIONS(5274),
    [anon_sym_final] = ACTIONS(5274),
    [anon_sym_global] = ACTIONS(5274),
    [anon_sym_LPAREN_STAR] = ACTIONS(5272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5272),
    [anon_sym_DOLLARunit] = ACTIONS(5272),
  },
  [4742] = {
    [sym_simple_identifier] = ACTIONS(4904),
    [anon_sym_wire] = ACTIONS(4904),
    [anon_sym_tri] = ACTIONS(4904),
    [anon_sym_tri0] = ACTIONS(4904),
    [anon_sym_tri1] = ACTIONS(4904),
    [anon_sym_wand] = ACTIONS(4904),
    [anon_sym_triand] = ACTIONS(4904),
    [anon_sym_wor] = ACTIONS(4904),
    [anon_sym_trior] = ACTIONS(4904),
    [anon_sym_trireg] = ACTIONS(4904),
    [anon_sym_uwire] = ACTIONS(4904),
    [anon_sym_SEMI] = ACTIONS(4902),
    [anon_sym_extern] = ACTIONS(4904),
    [anon_sym_interface] = ACTIONS(4904),
    [anon_sym_checker] = ACTIONS(4904),
    [anon_sym_virtual] = ACTIONS(4904),
    [anon_sym_class] = ACTIONS(4904),
    [anon_sym_type] = ACTIONS(4904),
    [anon_sym_DOLLARfatal] = ACTIONS(4902),
    [anon_sym_DOLLARerror] = ACTIONS(4902),
    [anon_sym_DOLLARwarning] = ACTIONS(4902),
    [anon_sym_DOLLARinfo] = ACTIONS(4902),
    [anon_sym_default] = ACTIONS(4904),
    [anon_sym_clocking] = ACTIONS(4904),
    [anon_sym_defparam] = ACTIONS(4904),
    [anon_sym_bind] = ACTIONS(4904),
    [anon_sym_rand] = ACTIONS(4904),
    [anon_sym_const] = ACTIONS(4904),
    [anon_sym_function] = ACTIONS(4904),
    [anon_sym_static] = ACTIONS(4904),
    [anon_sym_constraint] = ACTIONS(4904),
    [anon_sym_if] = ACTIONS(4904),
    [anon_sym_else] = ACTIONS(4904),
    [anon_sym_LBRACK] = ACTIONS(4902),
    [anon_sym_localparam] = ACTIONS(4904),
    [anon_sym_parameter] = ACTIONS(4904),
    [anon_sym_var] = ACTIONS(4904),
    [anon_sym_import] = ACTIONS(4904),
    [anon_sym_export] = ACTIONS(4904),
    [anon_sym_genvar] = ACTIONS(4904),
    [anon_sym_interconnect] = ACTIONS(4904),
    [anon_sym_typedef] = ACTIONS(4904),
    [anon_sym_enum] = ACTIONS(4904),
    [anon_sym_struct] = ACTIONS(4904),
    [anon_sym_union] = ACTIONS(4904),
    [anon_sym_nettype] = ACTIONS(4904),
    [anon_sym_automatic] = ACTIONS(4904),
    [anon_sym_string] = ACTIONS(4904),
    [anon_sym_chandle] = ACTIONS(4904),
    [anon_sym_event] = ACTIONS(4904),
    [anon_sym_byte] = ACTIONS(4904),
    [anon_sym_shortint] = ACTIONS(4904),
    [anon_sym_int] = ACTIONS(4904),
    [anon_sym_longint] = ACTIONS(4904),
    [anon_sym_integer] = ACTIONS(4904),
    [anon_sym_time] = ACTIONS(4904),
    [anon_sym_bit] = ACTIONS(4904),
    [anon_sym_logic] = ACTIONS(4904),
    [anon_sym_reg] = ACTIONS(4904),
    [anon_sym_shortreal] = ACTIONS(4904),
    [anon_sym_real] = ACTIONS(4904),
    [anon_sym_realtime] = ACTIONS(4904),
    [anon_sym_supply0] = ACTIONS(4904),
    [anon_sym_supply1] = ACTIONS(4904),
    [anon_sym_signed] = ACTIONS(4904),
    [anon_sym_unsigned] = ACTIONS(4904),
    [anon_sym_task] = ACTIONS(4904),
    [anon_sym_assert] = ACTIONS(4904),
    [anon_sym_property] = ACTIONS(4904),
    [anon_sym_assume] = ACTIONS(4904),
    [anon_sym_cover] = ACTIONS(4904),
    [anon_sym_sequence] = ACTIONS(4904),
    [anon_sym_restrict] = ACTIONS(4904),
    [anon_sym_not] = ACTIONS(4904),
    [anon_sym_or] = ACTIONS(4904),
    [anon_sym_and] = ACTIONS(4904),
    [anon_sym_case] = ACTIONS(4904),
    [anon_sym_always] = ACTIONS(4904),
    [anon_sym_covergroup] = ACTIONS(4904),
    [anon_sym_let] = ACTIONS(4904),
    [anon_sym_pulldown] = ACTIONS(4904),
    [anon_sym_pullup] = ACTIONS(4904),
    [anon_sym_cmos] = ACTIONS(4904),
    [anon_sym_rcmos] = ACTIONS(4904),
    [anon_sym_bufif0] = ACTIONS(4904),
    [anon_sym_bufif1] = ACTIONS(4904),
    [anon_sym_notif0] = ACTIONS(4904),
    [anon_sym_notif1] = ACTIONS(4904),
    [anon_sym_nmos] = ACTIONS(4904),
    [anon_sym_pmos] = ACTIONS(4904),
    [anon_sym_rnmos] = ACTIONS(4904),
    [anon_sym_rpmos] = ACTIONS(4904),
    [anon_sym_nand] = ACTIONS(4904),
    [anon_sym_nor] = ACTIONS(4904),
    [anon_sym_xor] = ACTIONS(4904),
    [anon_sym_xnor] = ACTIONS(4904),
    [anon_sym_buf] = ACTIONS(4904),
    [anon_sym_tranif0] = ACTIONS(4904),
    [anon_sym_tranif1] = ACTIONS(4904),
    [anon_sym_rtranif1] = ACTIONS(4904),
    [anon_sym_rtranif0] = ACTIONS(4904),
    [anon_sym_tran] = ACTIONS(4904),
    [anon_sym_rtran] = ACTIONS(4904),
    [anon_sym_generate] = ACTIONS(4904),
    [anon_sym_endgenerate] = ACTIONS(4904),
    [anon_sym_for] = ACTIONS(4904),
    [anon_sym_initial] = ACTIONS(4904),
    [anon_sym_assign] = ACTIONS(4904),
    [anon_sym_alias] = ACTIONS(4904),
    [anon_sym_always_comb] = ACTIONS(4904),
    [anon_sym_always_latch] = ACTIONS(4904),
    [anon_sym_always_ff] = ACTIONS(4904),
    [anon_sym_final] = ACTIONS(4904),
    [anon_sym_global] = ACTIONS(4904),
    [anon_sym_LPAREN_STAR] = ACTIONS(4902),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4902),
    [anon_sym_DOLLARunit] = ACTIONS(4902),
  },
  [4743] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(11033),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_endgenerate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [4744] = {
    [sym_simple_identifier] = ACTIONS(4940),
    [anon_sym_wire] = ACTIONS(4940),
    [anon_sym_tri] = ACTIONS(4940),
    [anon_sym_tri0] = ACTIONS(4940),
    [anon_sym_tri1] = ACTIONS(4940),
    [anon_sym_wand] = ACTIONS(4940),
    [anon_sym_triand] = ACTIONS(4940),
    [anon_sym_wor] = ACTIONS(4940),
    [anon_sym_trior] = ACTIONS(4940),
    [anon_sym_trireg] = ACTIONS(4940),
    [anon_sym_uwire] = ACTIONS(4940),
    [anon_sym_SEMI] = ACTIONS(4938),
    [anon_sym_extern] = ACTIONS(4940),
    [anon_sym_interface] = ACTIONS(4940),
    [anon_sym_checker] = ACTIONS(4940),
    [anon_sym_virtual] = ACTIONS(4940),
    [anon_sym_class] = ACTIONS(4940),
    [anon_sym_type] = ACTIONS(4940),
    [anon_sym_DOLLARfatal] = ACTIONS(4938),
    [anon_sym_DOLLARerror] = ACTIONS(4938),
    [anon_sym_DOLLARwarning] = ACTIONS(4938),
    [anon_sym_DOLLARinfo] = ACTIONS(4938),
    [anon_sym_default] = ACTIONS(4940),
    [anon_sym_clocking] = ACTIONS(4940),
    [anon_sym_defparam] = ACTIONS(4940),
    [anon_sym_bind] = ACTIONS(4940),
    [anon_sym_rand] = ACTIONS(4940),
    [anon_sym_const] = ACTIONS(4940),
    [anon_sym_function] = ACTIONS(4940),
    [anon_sym_static] = ACTIONS(4940),
    [anon_sym_constraint] = ACTIONS(4940),
    [anon_sym_if] = ACTIONS(4940),
    [anon_sym_else] = ACTIONS(4940),
    [anon_sym_LBRACK] = ACTIONS(4938),
    [anon_sym_localparam] = ACTIONS(4940),
    [anon_sym_parameter] = ACTIONS(4940),
    [anon_sym_var] = ACTIONS(4940),
    [anon_sym_import] = ACTIONS(4940),
    [anon_sym_export] = ACTIONS(4940),
    [anon_sym_genvar] = ACTIONS(4940),
    [anon_sym_interconnect] = ACTIONS(4940),
    [anon_sym_typedef] = ACTIONS(4940),
    [anon_sym_enum] = ACTIONS(4940),
    [anon_sym_struct] = ACTIONS(4940),
    [anon_sym_union] = ACTIONS(4940),
    [anon_sym_nettype] = ACTIONS(4940),
    [anon_sym_automatic] = ACTIONS(4940),
    [anon_sym_string] = ACTIONS(4940),
    [anon_sym_chandle] = ACTIONS(4940),
    [anon_sym_event] = ACTIONS(4940),
    [anon_sym_byte] = ACTIONS(4940),
    [anon_sym_shortint] = ACTIONS(4940),
    [anon_sym_int] = ACTIONS(4940),
    [anon_sym_longint] = ACTIONS(4940),
    [anon_sym_integer] = ACTIONS(4940),
    [anon_sym_time] = ACTIONS(4940),
    [anon_sym_bit] = ACTIONS(4940),
    [anon_sym_logic] = ACTIONS(4940),
    [anon_sym_reg] = ACTIONS(4940),
    [anon_sym_shortreal] = ACTIONS(4940),
    [anon_sym_real] = ACTIONS(4940),
    [anon_sym_realtime] = ACTIONS(4940),
    [anon_sym_supply0] = ACTIONS(4940),
    [anon_sym_supply1] = ACTIONS(4940),
    [anon_sym_signed] = ACTIONS(4940),
    [anon_sym_unsigned] = ACTIONS(4940),
    [anon_sym_task] = ACTIONS(4940),
    [anon_sym_assert] = ACTIONS(4940),
    [anon_sym_property] = ACTIONS(4940),
    [anon_sym_assume] = ACTIONS(4940),
    [anon_sym_cover] = ACTIONS(4940),
    [anon_sym_sequence] = ACTIONS(4940),
    [anon_sym_restrict] = ACTIONS(4940),
    [anon_sym_not] = ACTIONS(4940),
    [anon_sym_or] = ACTIONS(4940),
    [anon_sym_and] = ACTIONS(4940),
    [anon_sym_case] = ACTIONS(4940),
    [anon_sym_always] = ACTIONS(4940),
    [anon_sym_covergroup] = ACTIONS(4940),
    [anon_sym_let] = ACTIONS(4940),
    [anon_sym_pulldown] = ACTIONS(4940),
    [anon_sym_pullup] = ACTIONS(4940),
    [anon_sym_cmos] = ACTIONS(4940),
    [anon_sym_rcmos] = ACTIONS(4940),
    [anon_sym_bufif0] = ACTIONS(4940),
    [anon_sym_bufif1] = ACTIONS(4940),
    [anon_sym_notif0] = ACTIONS(4940),
    [anon_sym_notif1] = ACTIONS(4940),
    [anon_sym_nmos] = ACTIONS(4940),
    [anon_sym_pmos] = ACTIONS(4940),
    [anon_sym_rnmos] = ACTIONS(4940),
    [anon_sym_rpmos] = ACTIONS(4940),
    [anon_sym_nand] = ACTIONS(4940),
    [anon_sym_nor] = ACTIONS(4940),
    [anon_sym_xor] = ACTIONS(4940),
    [anon_sym_xnor] = ACTIONS(4940),
    [anon_sym_buf] = ACTIONS(4940),
    [anon_sym_tranif0] = ACTIONS(4940),
    [anon_sym_tranif1] = ACTIONS(4940),
    [anon_sym_rtranif1] = ACTIONS(4940),
    [anon_sym_rtranif0] = ACTIONS(4940),
    [anon_sym_tran] = ACTIONS(4940),
    [anon_sym_rtran] = ACTIONS(4940),
    [anon_sym_generate] = ACTIONS(4940),
    [anon_sym_endgenerate] = ACTIONS(4940),
    [anon_sym_for] = ACTIONS(4940),
    [anon_sym_initial] = ACTIONS(4940),
    [anon_sym_assign] = ACTIONS(4940),
    [anon_sym_alias] = ACTIONS(4940),
    [anon_sym_always_comb] = ACTIONS(4940),
    [anon_sym_always_latch] = ACTIONS(4940),
    [anon_sym_always_ff] = ACTIONS(4940),
    [anon_sym_final] = ACTIONS(4940),
    [anon_sym_global] = ACTIONS(4940),
    [anon_sym_LPAREN_STAR] = ACTIONS(4938),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4938),
    [anon_sym_DOLLARunit] = ACTIONS(4938),
  },
  [4745] = {
    [sym_simple_identifier] = ACTIONS(6731),
    [anon_sym_wire] = ACTIONS(6731),
    [anon_sym_tri] = ACTIONS(6731),
    [anon_sym_tri0] = ACTIONS(6731),
    [anon_sym_tri1] = ACTIONS(6731),
    [anon_sym_wand] = ACTIONS(6731),
    [anon_sym_triand] = ACTIONS(6731),
    [anon_sym_wor] = ACTIONS(6731),
    [anon_sym_trior] = ACTIONS(6731),
    [anon_sym_trireg] = ACTIONS(6731),
    [anon_sym_uwire] = ACTIONS(6731),
    [anon_sym_SEMI] = ACTIONS(6733),
    [anon_sym_extern] = ACTIONS(6731),
    [anon_sym_interface] = ACTIONS(6731),
    [anon_sym_checker] = ACTIONS(6731),
    [anon_sym_virtual] = ACTIONS(6731),
    [anon_sym_class] = ACTIONS(6731),
    [anon_sym_type] = ACTIONS(6731),
    [anon_sym_DOLLARfatal] = ACTIONS(6733),
    [anon_sym_DOLLARerror] = ACTIONS(6733),
    [anon_sym_DOLLARwarning] = ACTIONS(6733),
    [anon_sym_DOLLARinfo] = ACTIONS(6733),
    [anon_sym_default] = ACTIONS(6731),
    [anon_sym_clocking] = ACTIONS(6731),
    [anon_sym_defparam] = ACTIONS(6731),
    [anon_sym_bind] = ACTIONS(6731),
    [anon_sym_rand] = ACTIONS(6731),
    [anon_sym_const] = ACTIONS(6731),
    [anon_sym_function] = ACTIONS(6731),
    [anon_sym_static] = ACTIONS(6731),
    [anon_sym_constraint] = ACTIONS(6731),
    [anon_sym_if] = ACTIONS(6731),
    [anon_sym_else] = ACTIONS(6731),
    [anon_sym_LBRACK] = ACTIONS(6733),
    [anon_sym_localparam] = ACTIONS(6731),
    [anon_sym_parameter] = ACTIONS(6731),
    [anon_sym_var] = ACTIONS(6731),
    [anon_sym_import] = ACTIONS(6731),
    [anon_sym_export] = ACTIONS(6731),
    [anon_sym_genvar] = ACTIONS(6731),
    [anon_sym_interconnect] = ACTIONS(6731),
    [anon_sym_typedef] = ACTIONS(6731),
    [anon_sym_enum] = ACTIONS(6731),
    [anon_sym_struct] = ACTIONS(6731),
    [anon_sym_union] = ACTIONS(6731),
    [anon_sym_nettype] = ACTIONS(6731),
    [anon_sym_automatic] = ACTIONS(6731),
    [anon_sym_string] = ACTIONS(6731),
    [anon_sym_chandle] = ACTIONS(6731),
    [anon_sym_event] = ACTIONS(6731),
    [anon_sym_byte] = ACTIONS(6731),
    [anon_sym_shortint] = ACTIONS(6731),
    [anon_sym_int] = ACTIONS(6731),
    [anon_sym_longint] = ACTIONS(6731),
    [anon_sym_integer] = ACTIONS(6731),
    [anon_sym_time] = ACTIONS(6731),
    [anon_sym_bit] = ACTIONS(6731),
    [anon_sym_logic] = ACTIONS(6731),
    [anon_sym_reg] = ACTIONS(6731),
    [anon_sym_shortreal] = ACTIONS(6731),
    [anon_sym_real] = ACTIONS(6731),
    [anon_sym_realtime] = ACTIONS(6731),
    [anon_sym_supply0] = ACTIONS(6731),
    [anon_sym_supply1] = ACTIONS(6731),
    [anon_sym_signed] = ACTIONS(6731),
    [anon_sym_unsigned] = ACTIONS(6731),
    [anon_sym_task] = ACTIONS(6731),
    [anon_sym_assert] = ACTIONS(6731),
    [anon_sym_property] = ACTIONS(6731),
    [anon_sym_assume] = ACTIONS(6731),
    [anon_sym_cover] = ACTIONS(6731),
    [anon_sym_sequence] = ACTIONS(6731),
    [anon_sym_restrict] = ACTIONS(6731),
    [anon_sym_not] = ACTIONS(6731),
    [anon_sym_or] = ACTIONS(6731),
    [anon_sym_and] = ACTIONS(6731),
    [anon_sym_case] = ACTIONS(6731),
    [anon_sym_always] = ACTIONS(6731),
    [anon_sym_covergroup] = ACTIONS(6731),
    [anon_sym_end] = ACTIONS(6731),
    [anon_sym_let] = ACTIONS(6731),
    [anon_sym_pulldown] = ACTIONS(6731),
    [anon_sym_pullup] = ACTIONS(6731),
    [anon_sym_cmos] = ACTIONS(6731),
    [anon_sym_rcmos] = ACTIONS(6731),
    [anon_sym_bufif0] = ACTIONS(6731),
    [anon_sym_bufif1] = ACTIONS(6731),
    [anon_sym_notif0] = ACTIONS(6731),
    [anon_sym_notif1] = ACTIONS(6731),
    [anon_sym_nmos] = ACTIONS(6731),
    [anon_sym_pmos] = ACTIONS(6731),
    [anon_sym_rnmos] = ACTIONS(6731),
    [anon_sym_rpmos] = ACTIONS(6731),
    [anon_sym_nand] = ACTIONS(6731),
    [anon_sym_nor] = ACTIONS(6731),
    [anon_sym_xor] = ACTIONS(6731),
    [anon_sym_xnor] = ACTIONS(6731),
    [anon_sym_buf] = ACTIONS(6731),
    [anon_sym_tranif0] = ACTIONS(6731),
    [anon_sym_tranif1] = ACTIONS(6731),
    [anon_sym_rtranif1] = ACTIONS(6731),
    [anon_sym_rtranif0] = ACTIONS(6731),
    [anon_sym_tran] = ACTIONS(6731),
    [anon_sym_rtran] = ACTIONS(6731),
    [anon_sym_generate] = ACTIONS(6731),
    [anon_sym_for] = ACTIONS(6731),
    [anon_sym_initial] = ACTIONS(6731),
    [anon_sym_assign] = ACTIONS(6731),
    [anon_sym_alias] = ACTIONS(6731),
    [anon_sym_always_comb] = ACTIONS(6731),
    [anon_sym_always_latch] = ACTIONS(6731),
    [anon_sym_always_ff] = ACTIONS(6731),
    [anon_sym_final] = ACTIONS(6731),
    [anon_sym_global] = ACTIONS(6731),
    [anon_sym_LPAREN_STAR] = ACTIONS(6733),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6733),
    [anon_sym_DOLLARunit] = ACTIONS(6733),
  },
  [4746] = {
    [sym_simple_identifier] = ACTIONS(5290),
    [anon_sym_wire] = ACTIONS(5290),
    [anon_sym_tri] = ACTIONS(5290),
    [anon_sym_tri0] = ACTIONS(5290),
    [anon_sym_tri1] = ACTIONS(5290),
    [anon_sym_wand] = ACTIONS(5290),
    [anon_sym_triand] = ACTIONS(5290),
    [anon_sym_wor] = ACTIONS(5290),
    [anon_sym_trior] = ACTIONS(5290),
    [anon_sym_trireg] = ACTIONS(5290),
    [anon_sym_uwire] = ACTIONS(5290),
    [anon_sym_SEMI] = ACTIONS(5288),
    [anon_sym_extern] = ACTIONS(5290),
    [anon_sym_interface] = ACTIONS(5290),
    [anon_sym_checker] = ACTIONS(5290),
    [anon_sym_virtual] = ACTIONS(5290),
    [anon_sym_class] = ACTIONS(5290),
    [anon_sym_type] = ACTIONS(5290),
    [anon_sym_DOLLARfatal] = ACTIONS(5288),
    [anon_sym_DOLLARerror] = ACTIONS(5288),
    [anon_sym_DOLLARwarning] = ACTIONS(5288),
    [anon_sym_DOLLARinfo] = ACTIONS(5288),
    [anon_sym_default] = ACTIONS(5290),
    [anon_sym_clocking] = ACTIONS(5290),
    [anon_sym_defparam] = ACTIONS(5290),
    [anon_sym_bind] = ACTIONS(5290),
    [anon_sym_rand] = ACTIONS(5290),
    [anon_sym_const] = ACTIONS(5290),
    [anon_sym_function] = ACTIONS(5290),
    [anon_sym_static] = ACTIONS(5290),
    [anon_sym_constraint] = ACTIONS(5290),
    [anon_sym_if] = ACTIONS(5290),
    [anon_sym_else] = ACTIONS(5290),
    [anon_sym_LBRACK] = ACTIONS(5288),
    [anon_sym_localparam] = ACTIONS(5290),
    [anon_sym_parameter] = ACTIONS(5290),
    [anon_sym_var] = ACTIONS(5290),
    [anon_sym_import] = ACTIONS(5290),
    [anon_sym_export] = ACTIONS(5290),
    [anon_sym_genvar] = ACTIONS(5290),
    [anon_sym_interconnect] = ACTIONS(5290),
    [anon_sym_typedef] = ACTIONS(5290),
    [anon_sym_enum] = ACTIONS(5290),
    [anon_sym_struct] = ACTIONS(5290),
    [anon_sym_union] = ACTIONS(5290),
    [anon_sym_nettype] = ACTIONS(5290),
    [anon_sym_automatic] = ACTIONS(5290),
    [anon_sym_string] = ACTIONS(5290),
    [anon_sym_chandle] = ACTIONS(5290),
    [anon_sym_event] = ACTIONS(5290),
    [anon_sym_byte] = ACTIONS(5290),
    [anon_sym_shortint] = ACTIONS(5290),
    [anon_sym_int] = ACTIONS(5290),
    [anon_sym_longint] = ACTIONS(5290),
    [anon_sym_integer] = ACTIONS(5290),
    [anon_sym_time] = ACTIONS(5290),
    [anon_sym_bit] = ACTIONS(5290),
    [anon_sym_logic] = ACTIONS(5290),
    [anon_sym_reg] = ACTIONS(5290),
    [anon_sym_shortreal] = ACTIONS(5290),
    [anon_sym_real] = ACTIONS(5290),
    [anon_sym_realtime] = ACTIONS(5290),
    [anon_sym_supply0] = ACTIONS(5290),
    [anon_sym_supply1] = ACTIONS(5290),
    [anon_sym_signed] = ACTIONS(5290),
    [anon_sym_unsigned] = ACTIONS(5290),
    [anon_sym_task] = ACTIONS(5290),
    [anon_sym_assert] = ACTIONS(5290),
    [anon_sym_property] = ACTIONS(5290),
    [anon_sym_assume] = ACTIONS(5290),
    [anon_sym_cover] = ACTIONS(5290),
    [anon_sym_sequence] = ACTIONS(5290),
    [anon_sym_restrict] = ACTIONS(5290),
    [anon_sym_not] = ACTIONS(5290),
    [anon_sym_or] = ACTIONS(5290),
    [anon_sym_and] = ACTIONS(5290),
    [anon_sym_case] = ACTIONS(5290),
    [anon_sym_always] = ACTIONS(5290),
    [anon_sym_covergroup] = ACTIONS(5290),
    [anon_sym_end] = ACTIONS(5290),
    [anon_sym_let] = ACTIONS(5290),
    [anon_sym_pulldown] = ACTIONS(5290),
    [anon_sym_pullup] = ACTIONS(5290),
    [anon_sym_cmos] = ACTIONS(5290),
    [anon_sym_rcmos] = ACTIONS(5290),
    [anon_sym_bufif0] = ACTIONS(5290),
    [anon_sym_bufif1] = ACTIONS(5290),
    [anon_sym_notif0] = ACTIONS(5290),
    [anon_sym_notif1] = ACTIONS(5290),
    [anon_sym_nmos] = ACTIONS(5290),
    [anon_sym_pmos] = ACTIONS(5290),
    [anon_sym_rnmos] = ACTIONS(5290),
    [anon_sym_rpmos] = ACTIONS(5290),
    [anon_sym_nand] = ACTIONS(5290),
    [anon_sym_nor] = ACTIONS(5290),
    [anon_sym_xor] = ACTIONS(5290),
    [anon_sym_xnor] = ACTIONS(5290),
    [anon_sym_buf] = ACTIONS(5290),
    [anon_sym_tranif0] = ACTIONS(5290),
    [anon_sym_tranif1] = ACTIONS(5290),
    [anon_sym_rtranif1] = ACTIONS(5290),
    [anon_sym_rtranif0] = ACTIONS(5290),
    [anon_sym_tran] = ACTIONS(5290),
    [anon_sym_rtran] = ACTIONS(5290),
    [anon_sym_generate] = ACTIONS(5290),
    [anon_sym_for] = ACTIONS(5290),
    [anon_sym_initial] = ACTIONS(5290),
    [anon_sym_assign] = ACTIONS(5290),
    [anon_sym_alias] = ACTIONS(5290),
    [anon_sym_always_comb] = ACTIONS(5290),
    [anon_sym_always_latch] = ACTIONS(5290),
    [anon_sym_always_ff] = ACTIONS(5290),
    [anon_sym_final] = ACTIONS(5290),
    [anon_sym_global] = ACTIONS(5290),
    [anon_sym_LPAREN_STAR] = ACTIONS(5288),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5288),
    [anon_sym_DOLLARunit] = ACTIONS(5288),
  },
  [4747] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_rand] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_endgenerate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [4748] = {
    [sym_simple_identifier] = ACTIONS(5314),
    [anon_sym_wire] = ACTIONS(5314),
    [anon_sym_tri] = ACTIONS(5314),
    [anon_sym_tri0] = ACTIONS(5314),
    [anon_sym_tri1] = ACTIONS(5314),
    [anon_sym_wand] = ACTIONS(5314),
    [anon_sym_triand] = ACTIONS(5314),
    [anon_sym_wor] = ACTIONS(5314),
    [anon_sym_trior] = ACTIONS(5314),
    [anon_sym_trireg] = ACTIONS(5314),
    [anon_sym_uwire] = ACTIONS(5314),
    [anon_sym_SEMI] = ACTIONS(5312),
    [anon_sym_extern] = ACTIONS(5314),
    [anon_sym_interface] = ACTIONS(5314),
    [anon_sym_checker] = ACTIONS(5314),
    [anon_sym_virtual] = ACTIONS(5314),
    [anon_sym_class] = ACTIONS(5314),
    [anon_sym_type] = ACTIONS(5314),
    [anon_sym_DOLLARfatal] = ACTIONS(5312),
    [anon_sym_DOLLARerror] = ACTIONS(5312),
    [anon_sym_DOLLARwarning] = ACTIONS(5312),
    [anon_sym_DOLLARinfo] = ACTIONS(5312),
    [anon_sym_default] = ACTIONS(5314),
    [anon_sym_clocking] = ACTIONS(5314),
    [anon_sym_defparam] = ACTIONS(5314),
    [anon_sym_bind] = ACTIONS(5314),
    [anon_sym_rand] = ACTIONS(5314),
    [anon_sym_const] = ACTIONS(5314),
    [anon_sym_function] = ACTIONS(5314),
    [anon_sym_static] = ACTIONS(5314),
    [anon_sym_constraint] = ACTIONS(5314),
    [anon_sym_if] = ACTIONS(5314),
    [anon_sym_else] = ACTIONS(5314),
    [anon_sym_LBRACK] = ACTIONS(5312),
    [anon_sym_localparam] = ACTIONS(5314),
    [anon_sym_parameter] = ACTIONS(5314),
    [anon_sym_var] = ACTIONS(5314),
    [anon_sym_import] = ACTIONS(5314),
    [anon_sym_export] = ACTIONS(5314),
    [anon_sym_genvar] = ACTIONS(5314),
    [anon_sym_interconnect] = ACTIONS(5314),
    [anon_sym_typedef] = ACTIONS(5314),
    [anon_sym_enum] = ACTIONS(5314),
    [anon_sym_struct] = ACTIONS(5314),
    [anon_sym_union] = ACTIONS(5314),
    [anon_sym_nettype] = ACTIONS(5314),
    [anon_sym_automatic] = ACTIONS(5314),
    [anon_sym_string] = ACTIONS(5314),
    [anon_sym_chandle] = ACTIONS(5314),
    [anon_sym_event] = ACTIONS(5314),
    [anon_sym_byte] = ACTIONS(5314),
    [anon_sym_shortint] = ACTIONS(5314),
    [anon_sym_int] = ACTIONS(5314),
    [anon_sym_longint] = ACTIONS(5314),
    [anon_sym_integer] = ACTIONS(5314),
    [anon_sym_time] = ACTIONS(5314),
    [anon_sym_bit] = ACTIONS(5314),
    [anon_sym_logic] = ACTIONS(5314),
    [anon_sym_reg] = ACTIONS(5314),
    [anon_sym_shortreal] = ACTIONS(5314),
    [anon_sym_real] = ACTIONS(5314),
    [anon_sym_realtime] = ACTIONS(5314),
    [anon_sym_supply0] = ACTIONS(5314),
    [anon_sym_supply1] = ACTIONS(5314),
    [anon_sym_signed] = ACTIONS(5314),
    [anon_sym_unsigned] = ACTIONS(5314),
    [anon_sym_task] = ACTIONS(5314),
    [anon_sym_assert] = ACTIONS(5314),
    [anon_sym_property] = ACTIONS(5314),
    [anon_sym_assume] = ACTIONS(5314),
    [anon_sym_cover] = ACTIONS(5314),
    [anon_sym_sequence] = ACTIONS(5314),
    [anon_sym_restrict] = ACTIONS(5314),
    [anon_sym_not] = ACTIONS(5314),
    [anon_sym_or] = ACTIONS(5314),
    [anon_sym_and] = ACTIONS(5314),
    [anon_sym_case] = ACTIONS(5314),
    [anon_sym_always] = ACTIONS(5314),
    [anon_sym_covergroup] = ACTIONS(5314),
    [anon_sym_end] = ACTIONS(5314),
    [anon_sym_let] = ACTIONS(5314),
    [anon_sym_pulldown] = ACTIONS(5314),
    [anon_sym_pullup] = ACTIONS(5314),
    [anon_sym_cmos] = ACTIONS(5314),
    [anon_sym_rcmos] = ACTIONS(5314),
    [anon_sym_bufif0] = ACTIONS(5314),
    [anon_sym_bufif1] = ACTIONS(5314),
    [anon_sym_notif0] = ACTIONS(5314),
    [anon_sym_notif1] = ACTIONS(5314),
    [anon_sym_nmos] = ACTIONS(5314),
    [anon_sym_pmos] = ACTIONS(5314),
    [anon_sym_rnmos] = ACTIONS(5314),
    [anon_sym_rpmos] = ACTIONS(5314),
    [anon_sym_nand] = ACTIONS(5314),
    [anon_sym_nor] = ACTIONS(5314),
    [anon_sym_xor] = ACTIONS(5314),
    [anon_sym_xnor] = ACTIONS(5314),
    [anon_sym_buf] = ACTIONS(5314),
    [anon_sym_tranif0] = ACTIONS(5314),
    [anon_sym_tranif1] = ACTIONS(5314),
    [anon_sym_rtranif1] = ACTIONS(5314),
    [anon_sym_rtranif0] = ACTIONS(5314),
    [anon_sym_tran] = ACTIONS(5314),
    [anon_sym_rtran] = ACTIONS(5314),
    [anon_sym_generate] = ACTIONS(5314),
    [anon_sym_for] = ACTIONS(5314),
    [anon_sym_initial] = ACTIONS(5314),
    [anon_sym_assign] = ACTIONS(5314),
    [anon_sym_alias] = ACTIONS(5314),
    [anon_sym_always_comb] = ACTIONS(5314),
    [anon_sym_always_latch] = ACTIONS(5314),
    [anon_sym_always_ff] = ACTIONS(5314),
    [anon_sym_final] = ACTIONS(5314),
    [anon_sym_global] = ACTIONS(5314),
    [anon_sym_LPAREN_STAR] = ACTIONS(5312),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5312),
    [anon_sym_DOLLARunit] = ACTIONS(5312),
  },
  [4749] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_rand] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(5848),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_endgenerate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [4750] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_rand] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_endgenerate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [4751] = {
    [sym_simple_identifier] = ACTIONS(6225),
    [anon_sym_wire] = ACTIONS(6225),
    [anon_sym_tri] = ACTIONS(6225),
    [anon_sym_tri0] = ACTIONS(6225),
    [anon_sym_tri1] = ACTIONS(6225),
    [anon_sym_wand] = ACTIONS(6225),
    [anon_sym_triand] = ACTIONS(6225),
    [anon_sym_wor] = ACTIONS(6225),
    [anon_sym_trior] = ACTIONS(6225),
    [anon_sym_trireg] = ACTIONS(6225),
    [anon_sym_uwire] = ACTIONS(6225),
    [anon_sym_SEMI] = ACTIONS(6227),
    [anon_sym_extern] = ACTIONS(6225),
    [anon_sym_interface] = ACTIONS(6225),
    [anon_sym_checker] = ACTIONS(6225),
    [anon_sym_virtual] = ACTIONS(6225),
    [anon_sym_class] = ACTIONS(6225),
    [anon_sym_type] = ACTIONS(6225),
    [anon_sym_DOLLARfatal] = ACTIONS(6227),
    [anon_sym_DOLLARerror] = ACTIONS(6227),
    [anon_sym_DOLLARwarning] = ACTIONS(6227),
    [anon_sym_DOLLARinfo] = ACTIONS(6227),
    [anon_sym_default] = ACTIONS(6225),
    [anon_sym_clocking] = ACTIONS(6225),
    [anon_sym_defparam] = ACTIONS(6225),
    [anon_sym_bind] = ACTIONS(6225),
    [anon_sym_rand] = ACTIONS(6225),
    [anon_sym_const] = ACTIONS(6225),
    [anon_sym_function] = ACTIONS(6225),
    [anon_sym_static] = ACTIONS(6225),
    [anon_sym_constraint] = ACTIONS(6225),
    [anon_sym_if] = ACTIONS(6225),
    [anon_sym_else] = ACTIONS(6225),
    [anon_sym_LBRACK] = ACTIONS(6227),
    [anon_sym_localparam] = ACTIONS(6225),
    [anon_sym_parameter] = ACTIONS(6225),
    [anon_sym_var] = ACTIONS(6225),
    [anon_sym_import] = ACTIONS(6225),
    [anon_sym_export] = ACTIONS(6225),
    [anon_sym_genvar] = ACTIONS(6225),
    [anon_sym_interconnect] = ACTIONS(6225),
    [anon_sym_typedef] = ACTIONS(6225),
    [anon_sym_enum] = ACTIONS(6225),
    [anon_sym_struct] = ACTIONS(6225),
    [anon_sym_union] = ACTIONS(6225),
    [anon_sym_nettype] = ACTIONS(6225),
    [anon_sym_automatic] = ACTIONS(6225),
    [anon_sym_string] = ACTIONS(6225),
    [anon_sym_chandle] = ACTIONS(6225),
    [anon_sym_event] = ACTIONS(6225),
    [anon_sym_byte] = ACTIONS(6225),
    [anon_sym_shortint] = ACTIONS(6225),
    [anon_sym_int] = ACTIONS(6225),
    [anon_sym_longint] = ACTIONS(6225),
    [anon_sym_integer] = ACTIONS(6225),
    [anon_sym_time] = ACTIONS(6225),
    [anon_sym_bit] = ACTIONS(6225),
    [anon_sym_logic] = ACTIONS(6225),
    [anon_sym_reg] = ACTIONS(6225),
    [anon_sym_shortreal] = ACTIONS(6225),
    [anon_sym_real] = ACTIONS(6225),
    [anon_sym_realtime] = ACTIONS(6225),
    [anon_sym_supply0] = ACTIONS(6225),
    [anon_sym_supply1] = ACTIONS(6225),
    [anon_sym_signed] = ACTIONS(6225),
    [anon_sym_unsigned] = ACTIONS(6225),
    [anon_sym_task] = ACTIONS(6225),
    [anon_sym_assert] = ACTIONS(6225),
    [anon_sym_property] = ACTIONS(6225),
    [anon_sym_assume] = ACTIONS(6225),
    [anon_sym_cover] = ACTIONS(6225),
    [anon_sym_sequence] = ACTIONS(6225),
    [anon_sym_restrict] = ACTIONS(6225),
    [anon_sym_not] = ACTIONS(6225),
    [anon_sym_or] = ACTIONS(6225),
    [anon_sym_and] = ACTIONS(6225),
    [anon_sym_case] = ACTIONS(6225),
    [anon_sym_always] = ACTIONS(6225),
    [anon_sym_covergroup] = ACTIONS(6225),
    [anon_sym_let] = ACTIONS(6225),
    [anon_sym_pulldown] = ACTIONS(6225),
    [anon_sym_pullup] = ACTIONS(6225),
    [anon_sym_cmos] = ACTIONS(6225),
    [anon_sym_rcmos] = ACTIONS(6225),
    [anon_sym_bufif0] = ACTIONS(6225),
    [anon_sym_bufif1] = ACTIONS(6225),
    [anon_sym_notif0] = ACTIONS(6225),
    [anon_sym_notif1] = ACTIONS(6225),
    [anon_sym_nmos] = ACTIONS(6225),
    [anon_sym_pmos] = ACTIONS(6225),
    [anon_sym_rnmos] = ACTIONS(6225),
    [anon_sym_rpmos] = ACTIONS(6225),
    [anon_sym_nand] = ACTIONS(6225),
    [anon_sym_nor] = ACTIONS(6225),
    [anon_sym_xor] = ACTIONS(6225),
    [anon_sym_xnor] = ACTIONS(6225),
    [anon_sym_buf] = ACTIONS(6225),
    [anon_sym_tranif0] = ACTIONS(6225),
    [anon_sym_tranif1] = ACTIONS(6225),
    [anon_sym_rtranif1] = ACTIONS(6225),
    [anon_sym_rtranif0] = ACTIONS(6225),
    [anon_sym_tran] = ACTIONS(6225),
    [anon_sym_rtran] = ACTIONS(6225),
    [anon_sym_generate] = ACTIONS(6225),
    [anon_sym_endgenerate] = ACTIONS(6225),
    [anon_sym_for] = ACTIONS(6225),
    [anon_sym_initial] = ACTIONS(6225),
    [anon_sym_assign] = ACTIONS(6225),
    [anon_sym_alias] = ACTIONS(6225),
    [anon_sym_always_comb] = ACTIONS(6225),
    [anon_sym_always_latch] = ACTIONS(6225),
    [anon_sym_always_ff] = ACTIONS(6225),
    [anon_sym_final] = ACTIONS(6225),
    [anon_sym_global] = ACTIONS(6225),
    [anon_sym_LPAREN_STAR] = ACTIONS(6227),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6227),
    [anon_sym_DOLLARunit] = ACTIONS(6227),
  },
  [4752] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(11036),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_end] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [4753] = {
    [sym_simple_identifier] = ACTIONS(6573),
    [anon_sym_wire] = ACTIONS(6573),
    [anon_sym_tri] = ACTIONS(6573),
    [anon_sym_tri0] = ACTIONS(6573),
    [anon_sym_tri1] = ACTIONS(6573),
    [anon_sym_wand] = ACTIONS(6573),
    [anon_sym_triand] = ACTIONS(6573),
    [anon_sym_wor] = ACTIONS(6573),
    [anon_sym_trior] = ACTIONS(6573),
    [anon_sym_trireg] = ACTIONS(6573),
    [anon_sym_uwire] = ACTIONS(6573),
    [anon_sym_SEMI] = ACTIONS(6575),
    [anon_sym_extern] = ACTIONS(6573),
    [anon_sym_interface] = ACTIONS(6573),
    [anon_sym_checker] = ACTIONS(6573),
    [anon_sym_virtual] = ACTIONS(6573),
    [anon_sym_class] = ACTIONS(6573),
    [anon_sym_type] = ACTIONS(6573),
    [anon_sym_DOLLARfatal] = ACTIONS(6575),
    [anon_sym_DOLLARerror] = ACTIONS(6575),
    [anon_sym_DOLLARwarning] = ACTIONS(6575),
    [anon_sym_DOLLARinfo] = ACTIONS(6575),
    [anon_sym_default] = ACTIONS(6573),
    [anon_sym_clocking] = ACTIONS(6573),
    [anon_sym_defparam] = ACTIONS(6573),
    [anon_sym_bind] = ACTIONS(6573),
    [anon_sym_rand] = ACTIONS(6573),
    [anon_sym_const] = ACTIONS(6573),
    [anon_sym_function] = ACTIONS(6573),
    [anon_sym_static] = ACTIONS(6573),
    [anon_sym_constraint] = ACTIONS(6573),
    [anon_sym_if] = ACTIONS(6573),
    [anon_sym_else] = ACTIONS(6573),
    [anon_sym_LBRACK] = ACTIONS(6575),
    [anon_sym_localparam] = ACTIONS(6573),
    [anon_sym_parameter] = ACTIONS(6573),
    [anon_sym_var] = ACTIONS(6573),
    [anon_sym_import] = ACTIONS(6573),
    [anon_sym_export] = ACTIONS(6573),
    [anon_sym_genvar] = ACTIONS(6573),
    [anon_sym_interconnect] = ACTIONS(6573),
    [anon_sym_typedef] = ACTIONS(6573),
    [anon_sym_enum] = ACTIONS(6573),
    [anon_sym_struct] = ACTIONS(6573),
    [anon_sym_union] = ACTIONS(6573),
    [anon_sym_nettype] = ACTIONS(6573),
    [anon_sym_automatic] = ACTIONS(6573),
    [anon_sym_string] = ACTIONS(6573),
    [anon_sym_chandle] = ACTIONS(6573),
    [anon_sym_event] = ACTIONS(6573),
    [anon_sym_byte] = ACTIONS(6573),
    [anon_sym_shortint] = ACTIONS(6573),
    [anon_sym_int] = ACTIONS(6573),
    [anon_sym_longint] = ACTIONS(6573),
    [anon_sym_integer] = ACTIONS(6573),
    [anon_sym_time] = ACTIONS(6573),
    [anon_sym_bit] = ACTIONS(6573),
    [anon_sym_logic] = ACTIONS(6573),
    [anon_sym_reg] = ACTIONS(6573),
    [anon_sym_shortreal] = ACTIONS(6573),
    [anon_sym_real] = ACTIONS(6573),
    [anon_sym_realtime] = ACTIONS(6573),
    [anon_sym_supply0] = ACTIONS(6573),
    [anon_sym_supply1] = ACTIONS(6573),
    [anon_sym_signed] = ACTIONS(6573),
    [anon_sym_unsigned] = ACTIONS(6573),
    [anon_sym_task] = ACTIONS(6573),
    [anon_sym_assert] = ACTIONS(6573),
    [anon_sym_property] = ACTIONS(6573),
    [anon_sym_assume] = ACTIONS(6573),
    [anon_sym_cover] = ACTIONS(6573),
    [anon_sym_sequence] = ACTIONS(6573),
    [anon_sym_restrict] = ACTIONS(6573),
    [anon_sym_not] = ACTIONS(6573),
    [anon_sym_or] = ACTIONS(6573),
    [anon_sym_and] = ACTIONS(6573),
    [anon_sym_case] = ACTIONS(6573),
    [anon_sym_always] = ACTIONS(6573),
    [anon_sym_covergroup] = ACTIONS(6573),
    [anon_sym_let] = ACTIONS(6573),
    [anon_sym_pulldown] = ACTIONS(6573),
    [anon_sym_pullup] = ACTIONS(6573),
    [anon_sym_cmos] = ACTIONS(6573),
    [anon_sym_rcmos] = ACTIONS(6573),
    [anon_sym_bufif0] = ACTIONS(6573),
    [anon_sym_bufif1] = ACTIONS(6573),
    [anon_sym_notif0] = ACTIONS(6573),
    [anon_sym_notif1] = ACTIONS(6573),
    [anon_sym_nmos] = ACTIONS(6573),
    [anon_sym_pmos] = ACTIONS(6573),
    [anon_sym_rnmos] = ACTIONS(6573),
    [anon_sym_rpmos] = ACTIONS(6573),
    [anon_sym_nand] = ACTIONS(6573),
    [anon_sym_nor] = ACTIONS(6573),
    [anon_sym_xor] = ACTIONS(6573),
    [anon_sym_xnor] = ACTIONS(6573),
    [anon_sym_buf] = ACTIONS(6573),
    [anon_sym_tranif0] = ACTIONS(6573),
    [anon_sym_tranif1] = ACTIONS(6573),
    [anon_sym_rtranif1] = ACTIONS(6573),
    [anon_sym_rtranif0] = ACTIONS(6573),
    [anon_sym_tran] = ACTIONS(6573),
    [anon_sym_rtran] = ACTIONS(6573),
    [anon_sym_generate] = ACTIONS(6573),
    [anon_sym_endgenerate] = ACTIONS(6573),
    [anon_sym_for] = ACTIONS(6573),
    [anon_sym_initial] = ACTIONS(6573),
    [anon_sym_assign] = ACTIONS(6573),
    [anon_sym_alias] = ACTIONS(6573),
    [anon_sym_always_comb] = ACTIONS(6573),
    [anon_sym_always_latch] = ACTIONS(6573),
    [anon_sym_always_ff] = ACTIONS(6573),
    [anon_sym_final] = ACTIONS(6573),
    [anon_sym_global] = ACTIONS(6573),
    [anon_sym_LPAREN_STAR] = ACTIONS(6575),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6575),
    [anon_sym_DOLLARunit] = ACTIONS(6575),
  },
  [4754] = {
    [sym_simple_identifier] = ACTIONS(5594),
    [anon_sym_wire] = ACTIONS(5594),
    [anon_sym_tri] = ACTIONS(5594),
    [anon_sym_tri0] = ACTIONS(5594),
    [anon_sym_tri1] = ACTIONS(5594),
    [anon_sym_wand] = ACTIONS(5594),
    [anon_sym_triand] = ACTIONS(5594),
    [anon_sym_wor] = ACTIONS(5594),
    [anon_sym_trior] = ACTIONS(5594),
    [anon_sym_trireg] = ACTIONS(5594),
    [anon_sym_uwire] = ACTIONS(5594),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_extern] = ACTIONS(5594),
    [anon_sym_interface] = ACTIONS(5594),
    [anon_sym_checker] = ACTIONS(5594),
    [anon_sym_virtual] = ACTIONS(5594),
    [anon_sym_class] = ACTIONS(5594),
    [anon_sym_type] = ACTIONS(5594),
    [anon_sym_DOLLARfatal] = ACTIONS(5596),
    [anon_sym_DOLLARerror] = ACTIONS(5596),
    [anon_sym_DOLLARwarning] = ACTIONS(5596),
    [anon_sym_DOLLARinfo] = ACTIONS(5596),
    [anon_sym_default] = ACTIONS(5594),
    [anon_sym_clocking] = ACTIONS(5594),
    [anon_sym_defparam] = ACTIONS(5594),
    [anon_sym_bind] = ACTIONS(5594),
    [anon_sym_rand] = ACTIONS(5594),
    [anon_sym_const] = ACTIONS(5594),
    [anon_sym_function] = ACTIONS(5594),
    [anon_sym_static] = ACTIONS(5594),
    [anon_sym_constraint] = ACTIONS(5594),
    [anon_sym_if] = ACTIONS(5594),
    [anon_sym_else] = ACTIONS(5594),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_localparam] = ACTIONS(5594),
    [anon_sym_parameter] = ACTIONS(5594),
    [anon_sym_var] = ACTIONS(5594),
    [anon_sym_import] = ACTIONS(5594),
    [anon_sym_export] = ACTIONS(5594),
    [anon_sym_genvar] = ACTIONS(5594),
    [anon_sym_interconnect] = ACTIONS(5594),
    [anon_sym_typedef] = ACTIONS(5594),
    [anon_sym_enum] = ACTIONS(5594),
    [anon_sym_struct] = ACTIONS(5594),
    [anon_sym_union] = ACTIONS(5594),
    [anon_sym_nettype] = ACTIONS(5594),
    [anon_sym_automatic] = ACTIONS(5594),
    [anon_sym_string] = ACTIONS(5594),
    [anon_sym_chandle] = ACTIONS(5594),
    [anon_sym_event] = ACTIONS(5594),
    [anon_sym_byte] = ACTIONS(5594),
    [anon_sym_shortint] = ACTIONS(5594),
    [anon_sym_int] = ACTIONS(5594),
    [anon_sym_longint] = ACTIONS(5594),
    [anon_sym_integer] = ACTIONS(5594),
    [anon_sym_time] = ACTIONS(5594),
    [anon_sym_bit] = ACTIONS(5594),
    [anon_sym_logic] = ACTIONS(5594),
    [anon_sym_reg] = ACTIONS(5594),
    [anon_sym_shortreal] = ACTIONS(5594),
    [anon_sym_real] = ACTIONS(5594),
    [anon_sym_realtime] = ACTIONS(5594),
    [anon_sym_supply0] = ACTIONS(5594),
    [anon_sym_supply1] = ACTIONS(5594),
    [anon_sym_signed] = ACTIONS(5594),
    [anon_sym_unsigned] = ACTIONS(5594),
    [anon_sym_task] = ACTIONS(5594),
    [anon_sym_assert] = ACTIONS(5594),
    [anon_sym_property] = ACTIONS(5594),
    [anon_sym_assume] = ACTIONS(5594),
    [anon_sym_cover] = ACTIONS(5594),
    [anon_sym_sequence] = ACTIONS(5594),
    [anon_sym_restrict] = ACTIONS(5594),
    [anon_sym_not] = ACTIONS(5594),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_and] = ACTIONS(5594),
    [anon_sym_case] = ACTIONS(5594),
    [anon_sym_always] = ACTIONS(5594),
    [anon_sym_covergroup] = ACTIONS(5594),
    [anon_sym_end] = ACTIONS(5594),
    [anon_sym_let] = ACTIONS(5594),
    [anon_sym_pulldown] = ACTIONS(5594),
    [anon_sym_pullup] = ACTIONS(5594),
    [anon_sym_cmos] = ACTIONS(5594),
    [anon_sym_rcmos] = ACTIONS(5594),
    [anon_sym_bufif0] = ACTIONS(5594),
    [anon_sym_bufif1] = ACTIONS(5594),
    [anon_sym_notif0] = ACTIONS(5594),
    [anon_sym_notif1] = ACTIONS(5594),
    [anon_sym_nmos] = ACTIONS(5594),
    [anon_sym_pmos] = ACTIONS(5594),
    [anon_sym_rnmos] = ACTIONS(5594),
    [anon_sym_rpmos] = ACTIONS(5594),
    [anon_sym_nand] = ACTIONS(5594),
    [anon_sym_nor] = ACTIONS(5594),
    [anon_sym_xor] = ACTIONS(5594),
    [anon_sym_xnor] = ACTIONS(5594),
    [anon_sym_buf] = ACTIONS(5594),
    [anon_sym_tranif0] = ACTIONS(5594),
    [anon_sym_tranif1] = ACTIONS(5594),
    [anon_sym_rtranif1] = ACTIONS(5594),
    [anon_sym_rtranif0] = ACTIONS(5594),
    [anon_sym_tran] = ACTIONS(5594),
    [anon_sym_rtran] = ACTIONS(5594),
    [anon_sym_generate] = ACTIONS(5594),
    [anon_sym_for] = ACTIONS(5594),
    [anon_sym_initial] = ACTIONS(5594),
    [anon_sym_assign] = ACTIONS(5594),
    [anon_sym_alias] = ACTIONS(5594),
    [anon_sym_always_comb] = ACTIONS(5594),
    [anon_sym_always_latch] = ACTIONS(5594),
    [anon_sym_always_ff] = ACTIONS(5594),
    [anon_sym_final] = ACTIONS(5594),
    [anon_sym_global] = ACTIONS(5594),
    [anon_sym_LPAREN_STAR] = ACTIONS(5596),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5596),
    [anon_sym_DOLLARunit] = ACTIONS(5596),
  },
  [4755] = {
    [sym_simple_identifier] = ACTIONS(6529),
    [anon_sym_wire] = ACTIONS(6529),
    [anon_sym_tri] = ACTIONS(6529),
    [anon_sym_tri0] = ACTIONS(6529),
    [anon_sym_tri1] = ACTIONS(6529),
    [anon_sym_wand] = ACTIONS(6529),
    [anon_sym_triand] = ACTIONS(6529),
    [anon_sym_wor] = ACTIONS(6529),
    [anon_sym_trior] = ACTIONS(6529),
    [anon_sym_trireg] = ACTIONS(6529),
    [anon_sym_uwire] = ACTIONS(6529),
    [anon_sym_SEMI] = ACTIONS(6531),
    [anon_sym_extern] = ACTIONS(6529),
    [anon_sym_interface] = ACTIONS(6529),
    [anon_sym_checker] = ACTIONS(6529),
    [anon_sym_virtual] = ACTIONS(6529),
    [anon_sym_class] = ACTIONS(6529),
    [anon_sym_type] = ACTIONS(6529),
    [anon_sym_DOLLARfatal] = ACTIONS(6531),
    [anon_sym_DOLLARerror] = ACTIONS(6531),
    [anon_sym_DOLLARwarning] = ACTIONS(6531),
    [anon_sym_DOLLARinfo] = ACTIONS(6531),
    [anon_sym_default] = ACTIONS(6529),
    [anon_sym_clocking] = ACTIONS(6529),
    [anon_sym_defparam] = ACTIONS(6529),
    [anon_sym_bind] = ACTIONS(6529),
    [anon_sym_rand] = ACTIONS(6529),
    [anon_sym_const] = ACTIONS(6529),
    [anon_sym_function] = ACTIONS(6529),
    [anon_sym_static] = ACTIONS(6529),
    [anon_sym_constraint] = ACTIONS(6529),
    [anon_sym_if] = ACTIONS(6529),
    [anon_sym_else] = ACTIONS(6529),
    [anon_sym_LBRACK] = ACTIONS(6531),
    [anon_sym_localparam] = ACTIONS(6529),
    [anon_sym_parameter] = ACTIONS(6529),
    [anon_sym_var] = ACTIONS(6529),
    [anon_sym_import] = ACTIONS(6529),
    [anon_sym_export] = ACTIONS(6529),
    [anon_sym_genvar] = ACTIONS(6529),
    [anon_sym_interconnect] = ACTIONS(6529),
    [anon_sym_typedef] = ACTIONS(6529),
    [anon_sym_enum] = ACTIONS(6529),
    [anon_sym_struct] = ACTIONS(6529),
    [anon_sym_union] = ACTIONS(6529),
    [anon_sym_nettype] = ACTIONS(6529),
    [anon_sym_automatic] = ACTIONS(6529),
    [anon_sym_string] = ACTIONS(6529),
    [anon_sym_chandle] = ACTIONS(6529),
    [anon_sym_event] = ACTIONS(6529),
    [anon_sym_byte] = ACTIONS(6529),
    [anon_sym_shortint] = ACTIONS(6529),
    [anon_sym_int] = ACTIONS(6529),
    [anon_sym_longint] = ACTIONS(6529),
    [anon_sym_integer] = ACTIONS(6529),
    [anon_sym_time] = ACTIONS(6529),
    [anon_sym_bit] = ACTIONS(6529),
    [anon_sym_logic] = ACTIONS(6529),
    [anon_sym_reg] = ACTIONS(6529),
    [anon_sym_shortreal] = ACTIONS(6529),
    [anon_sym_real] = ACTIONS(6529),
    [anon_sym_realtime] = ACTIONS(6529),
    [anon_sym_supply0] = ACTIONS(6529),
    [anon_sym_supply1] = ACTIONS(6529),
    [anon_sym_signed] = ACTIONS(6529),
    [anon_sym_unsigned] = ACTIONS(6529),
    [anon_sym_task] = ACTIONS(6529),
    [anon_sym_assert] = ACTIONS(6529),
    [anon_sym_property] = ACTIONS(6529),
    [anon_sym_assume] = ACTIONS(6529),
    [anon_sym_cover] = ACTIONS(6529),
    [anon_sym_sequence] = ACTIONS(6529),
    [anon_sym_restrict] = ACTIONS(6529),
    [anon_sym_not] = ACTIONS(6529),
    [anon_sym_or] = ACTIONS(6529),
    [anon_sym_and] = ACTIONS(6529),
    [anon_sym_case] = ACTIONS(6529),
    [anon_sym_always] = ACTIONS(6529),
    [anon_sym_covergroup] = ACTIONS(6529),
    [anon_sym_end] = ACTIONS(6529),
    [anon_sym_let] = ACTIONS(6529),
    [anon_sym_pulldown] = ACTIONS(6529),
    [anon_sym_pullup] = ACTIONS(6529),
    [anon_sym_cmos] = ACTIONS(6529),
    [anon_sym_rcmos] = ACTIONS(6529),
    [anon_sym_bufif0] = ACTIONS(6529),
    [anon_sym_bufif1] = ACTIONS(6529),
    [anon_sym_notif0] = ACTIONS(6529),
    [anon_sym_notif1] = ACTIONS(6529),
    [anon_sym_nmos] = ACTIONS(6529),
    [anon_sym_pmos] = ACTIONS(6529),
    [anon_sym_rnmos] = ACTIONS(6529),
    [anon_sym_rpmos] = ACTIONS(6529),
    [anon_sym_nand] = ACTIONS(6529),
    [anon_sym_nor] = ACTIONS(6529),
    [anon_sym_xor] = ACTIONS(6529),
    [anon_sym_xnor] = ACTIONS(6529),
    [anon_sym_buf] = ACTIONS(6529),
    [anon_sym_tranif0] = ACTIONS(6529),
    [anon_sym_tranif1] = ACTIONS(6529),
    [anon_sym_rtranif1] = ACTIONS(6529),
    [anon_sym_rtranif0] = ACTIONS(6529),
    [anon_sym_tran] = ACTIONS(6529),
    [anon_sym_rtran] = ACTIONS(6529),
    [anon_sym_generate] = ACTIONS(6529),
    [anon_sym_for] = ACTIONS(6529),
    [anon_sym_initial] = ACTIONS(6529),
    [anon_sym_assign] = ACTIONS(6529),
    [anon_sym_alias] = ACTIONS(6529),
    [anon_sym_always_comb] = ACTIONS(6529),
    [anon_sym_always_latch] = ACTIONS(6529),
    [anon_sym_always_ff] = ACTIONS(6529),
    [anon_sym_final] = ACTIONS(6529),
    [anon_sym_global] = ACTIONS(6529),
    [anon_sym_LPAREN_STAR] = ACTIONS(6531),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6531),
    [anon_sym_DOLLARunit] = ACTIONS(6531),
  },
  [4756] = {
    [sym_simple_identifier] = ACTIONS(6327),
    [anon_sym_wire] = ACTIONS(6327),
    [anon_sym_tri] = ACTIONS(6327),
    [anon_sym_tri0] = ACTIONS(6327),
    [anon_sym_tri1] = ACTIONS(6327),
    [anon_sym_wand] = ACTIONS(6327),
    [anon_sym_triand] = ACTIONS(6327),
    [anon_sym_wor] = ACTIONS(6327),
    [anon_sym_trior] = ACTIONS(6327),
    [anon_sym_trireg] = ACTIONS(6327),
    [anon_sym_uwire] = ACTIONS(6327),
    [anon_sym_SEMI] = ACTIONS(6329),
    [anon_sym_extern] = ACTIONS(6327),
    [anon_sym_interface] = ACTIONS(6327),
    [anon_sym_checker] = ACTIONS(6327),
    [anon_sym_virtual] = ACTIONS(6327),
    [anon_sym_class] = ACTIONS(6327),
    [anon_sym_type] = ACTIONS(6327),
    [anon_sym_DOLLARfatal] = ACTIONS(6329),
    [anon_sym_DOLLARerror] = ACTIONS(6329),
    [anon_sym_DOLLARwarning] = ACTIONS(6329),
    [anon_sym_DOLLARinfo] = ACTIONS(6329),
    [anon_sym_default] = ACTIONS(6327),
    [anon_sym_clocking] = ACTIONS(6327),
    [anon_sym_defparam] = ACTIONS(6327),
    [anon_sym_bind] = ACTIONS(6327),
    [anon_sym_rand] = ACTIONS(6327),
    [anon_sym_const] = ACTIONS(6327),
    [anon_sym_function] = ACTIONS(6327),
    [anon_sym_static] = ACTIONS(6327),
    [anon_sym_constraint] = ACTIONS(6327),
    [anon_sym_if] = ACTIONS(6327),
    [anon_sym_else] = ACTIONS(6327),
    [anon_sym_LBRACK] = ACTIONS(6329),
    [anon_sym_localparam] = ACTIONS(6327),
    [anon_sym_parameter] = ACTIONS(6327),
    [anon_sym_var] = ACTIONS(6327),
    [anon_sym_import] = ACTIONS(6327),
    [anon_sym_export] = ACTIONS(6327),
    [anon_sym_genvar] = ACTIONS(6327),
    [anon_sym_interconnect] = ACTIONS(6327),
    [anon_sym_typedef] = ACTIONS(6327),
    [anon_sym_enum] = ACTIONS(6327),
    [anon_sym_struct] = ACTIONS(6327),
    [anon_sym_union] = ACTIONS(6327),
    [anon_sym_nettype] = ACTIONS(6327),
    [anon_sym_automatic] = ACTIONS(6327),
    [anon_sym_string] = ACTIONS(6327),
    [anon_sym_chandle] = ACTIONS(6327),
    [anon_sym_event] = ACTIONS(6327),
    [anon_sym_byte] = ACTIONS(6327),
    [anon_sym_shortint] = ACTIONS(6327),
    [anon_sym_int] = ACTIONS(6327),
    [anon_sym_longint] = ACTIONS(6327),
    [anon_sym_integer] = ACTIONS(6327),
    [anon_sym_time] = ACTIONS(6327),
    [anon_sym_bit] = ACTIONS(6327),
    [anon_sym_logic] = ACTIONS(6327),
    [anon_sym_reg] = ACTIONS(6327),
    [anon_sym_shortreal] = ACTIONS(6327),
    [anon_sym_real] = ACTIONS(6327),
    [anon_sym_realtime] = ACTIONS(6327),
    [anon_sym_supply0] = ACTIONS(6327),
    [anon_sym_supply1] = ACTIONS(6327),
    [anon_sym_signed] = ACTIONS(6327),
    [anon_sym_unsigned] = ACTIONS(6327),
    [anon_sym_task] = ACTIONS(6327),
    [anon_sym_assert] = ACTIONS(6327),
    [anon_sym_property] = ACTIONS(6327),
    [anon_sym_assume] = ACTIONS(6327),
    [anon_sym_cover] = ACTIONS(6327),
    [anon_sym_sequence] = ACTIONS(6327),
    [anon_sym_restrict] = ACTIONS(6327),
    [anon_sym_not] = ACTIONS(6327),
    [anon_sym_or] = ACTIONS(6327),
    [anon_sym_and] = ACTIONS(6327),
    [anon_sym_case] = ACTIONS(6327),
    [anon_sym_always] = ACTIONS(6327),
    [anon_sym_covergroup] = ACTIONS(6327),
    [anon_sym_let] = ACTIONS(6327),
    [anon_sym_pulldown] = ACTIONS(6327),
    [anon_sym_pullup] = ACTIONS(6327),
    [anon_sym_cmos] = ACTIONS(6327),
    [anon_sym_rcmos] = ACTIONS(6327),
    [anon_sym_bufif0] = ACTIONS(6327),
    [anon_sym_bufif1] = ACTIONS(6327),
    [anon_sym_notif0] = ACTIONS(6327),
    [anon_sym_notif1] = ACTIONS(6327),
    [anon_sym_nmos] = ACTIONS(6327),
    [anon_sym_pmos] = ACTIONS(6327),
    [anon_sym_rnmos] = ACTIONS(6327),
    [anon_sym_rpmos] = ACTIONS(6327),
    [anon_sym_nand] = ACTIONS(6327),
    [anon_sym_nor] = ACTIONS(6327),
    [anon_sym_xor] = ACTIONS(6327),
    [anon_sym_xnor] = ACTIONS(6327),
    [anon_sym_buf] = ACTIONS(6327),
    [anon_sym_tranif0] = ACTIONS(6327),
    [anon_sym_tranif1] = ACTIONS(6327),
    [anon_sym_rtranif1] = ACTIONS(6327),
    [anon_sym_rtranif0] = ACTIONS(6327),
    [anon_sym_tran] = ACTIONS(6327),
    [anon_sym_rtran] = ACTIONS(6327),
    [anon_sym_generate] = ACTIONS(6327),
    [anon_sym_endgenerate] = ACTIONS(6327),
    [anon_sym_for] = ACTIONS(6327),
    [anon_sym_initial] = ACTIONS(6327),
    [anon_sym_assign] = ACTIONS(6327),
    [anon_sym_alias] = ACTIONS(6327),
    [anon_sym_always_comb] = ACTIONS(6327),
    [anon_sym_always_latch] = ACTIONS(6327),
    [anon_sym_always_ff] = ACTIONS(6327),
    [anon_sym_final] = ACTIONS(6327),
    [anon_sym_global] = ACTIONS(6327),
    [anon_sym_LPAREN_STAR] = ACTIONS(6329),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6329),
    [anon_sym_DOLLARunit] = ACTIONS(6329),
  },
  [4757] = {
    [sym_simple_identifier] = ACTIONS(5848),
    [anon_sym_wire] = ACTIONS(5848),
    [anon_sym_tri] = ACTIONS(5848),
    [anon_sym_tri0] = ACTIONS(5848),
    [anon_sym_tri1] = ACTIONS(5848),
    [anon_sym_wand] = ACTIONS(5848),
    [anon_sym_triand] = ACTIONS(5848),
    [anon_sym_wor] = ACTIONS(5848),
    [anon_sym_trior] = ACTIONS(5848),
    [anon_sym_trireg] = ACTIONS(5848),
    [anon_sym_uwire] = ACTIONS(5848),
    [anon_sym_SEMI] = ACTIONS(5850),
    [anon_sym_extern] = ACTIONS(5848),
    [anon_sym_interface] = ACTIONS(5848),
    [anon_sym_checker] = ACTIONS(5848),
    [anon_sym_virtual] = ACTIONS(5848),
    [anon_sym_class] = ACTIONS(5848),
    [anon_sym_type] = ACTIONS(5848),
    [anon_sym_DOLLARfatal] = ACTIONS(5850),
    [anon_sym_DOLLARerror] = ACTIONS(5850),
    [anon_sym_DOLLARwarning] = ACTIONS(5850),
    [anon_sym_DOLLARinfo] = ACTIONS(5850),
    [anon_sym_default] = ACTIONS(5848),
    [anon_sym_clocking] = ACTIONS(5848),
    [anon_sym_defparam] = ACTIONS(5848),
    [anon_sym_bind] = ACTIONS(5848),
    [anon_sym_rand] = ACTIONS(5848),
    [anon_sym_const] = ACTIONS(5848),
    [anon_sym_function] = ACTIONS(5848),
    [anon_sym_static] = ACTIONS(5848),
    [anon_sym_constraint] = ACTIONS(5848),
    [anon_sym_if] = ACTIONS(5848),
    [anon_sym_else] = ACTIONS(5848),
    [anon_sym_LBRACK] = ACTIONS(5850),
    [anon_sym_localparam] = ACTIONS(5848),
    [anon_sym_parameter] = ACTIONS(5848),
    [anon_sym_var] = ACTIONS(5848),
    [anon_sym_import] = ACTIONS(5848),
    [anon_sym_export] = ACTIONS(5848),
    [anon_sym_genvar] = ACTIONS(5848),
    [anon_sym_interconnect] = ACTIONS(5848),
    [anon_sym_typedef] = ACTIONS(5848),
    [anon_sym_enum] = ACTIONS(5848),
    [anon_sym_struct] = ACTIONS(5848),
    [anon_sym_union] = ACTIONS(5848),
    [anon_sym_nettype] = ACTIONS(5848),
    [anon_sym_automatic] = ACTIONS(5848),
    [anon_sym_string] = ACTIONS(5848),
    [anon_sym_chandle] = ACTIONS(5848),
    [anon_sym_event] = ACTIONS(5848),
    [anon_sym_byte] = ACTIONS(5848),
    [anon_sym_shortint] = ACTIONS(5848),
    [anon_sym_int] = ACTIONS(5848),
    [anon_sym_longint] = ACTIONS(5848),
    [anon_sym_integer] = ACTIONS(5848),
    [anon_sym_time] = ACTIONS(5848),
    [anon_sym_bit] = ACTIONS(5848),
    [anon_sym_logic] = ACTIONS(5848),
    [anon_sym_reg] = ACTIONS(5848),
    [anon_sym_shortreal] = ACTIONS(5848),
    [anon_sym_real] = ACTIONS(5848),
    [anon_sym_realtime] = ACTIONS(5848),
    [anon_sym_supply0] = ACTIONS(5848),
    [anon_sym_supply1] = ACTIONS(5848),
    [anon_sym_signed] = ACTIONS(5848),
    [anon_sym_unsigned] = ACTIONS(5848),
    [anon_sym_task] = ACTIONS(5848),
    [anon_sym_assert] = ACTIONS(5848),
    [anon_sym_property] = ACTIONS(5848),
    [anon_sym_assume] = ACTIONS(5848),
    [anon_sym_cover] = ACTIONS(5848),
    [anon_sym_sequence] = ACTIONS(5848),
    [anon_sym_restrict] = ACTIONS(5848),
    [anon_sym_not] = ACTIONS(5848),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_and] = ACTIONS(5848),
    [anon_sym_case] = ACTIONS(5848),
    [anon_sym_always] = ACTIONS(5848),
    [anon_sym_covergroup] = ACTIONS(5848),
    [anon_sym_end] = ACTIONS(5848),
    [anon_sym_let] = ACTIONS(5848),
    [anon_sym_pulldown] = ACTIONS(5848),
    [anon_sym_pullup] = ACTIONS(5848),
    [anon_sym_cmos] = ACTIONS(5848),
    [anon_sym_rcmos] = ACTIONS(5848),
    [anon_sym_bufif0] = ACTIONS(5848),
    [anon_sym_bufif1] = ACTIONS(5848),
    [anon_sym_notif0] = ACTIONS(5848),
    [anon_sym_notif1] = ACTIONS(5848),
    [anon_sym_nmos] = ACTIONS(5848),
    [anon_sym_pmos] = ACTIONS(5848),
    [anon_sym_rnmos] = ACTIONS(5848),
    [anon_sym_rpmos] = ACTIONS(5848),
    [anon_sym_nand] = ACTIONS(5848),
    [anon_sym_nor] = ACTIONS(5848),
    [anon_sym_xor] = ACTIONS(5848),
    [anon_sym_xnor] = ACTIONS(5848),
    [anon_sym_buf] = ACTIONS(5848),
    [anon_sym_tranif0] = ACTIONS(5848),
    [anon_sym_tranif1] = ACTIONS(5848),
    [anon_sym_rtranif1] = ACTIONS(5848),
    [anon_sym_rtranif0] = ACTIONS(5848),
    [anon_sym_tran] = ACTIONS(5848),
    [anon_sym_rtran] = ACTIONS(5848),
    [anon_sym_generate] = ACTIONS(5848),
    [anon_sym_for] = ACTIONS(5848),
    [anon_sym_initial] = ACTIONS(5848),
    [anon_sym_assign] = ACTIONS(5848),
    [anon_sym_alias] = ACTIONS(5848),
    [anon_sym_always_comb] = ACTIONS(5848),
    [anon_sym_always_latch] = ACTIONS(5848),
    [anon_sym_always_ff] = ACTIONS(5848),
    [anon_sym_final] = ACTIONS(5848),
    [anon_sym_global] = ACTIONS(5848),
    [anon_sym_LPAREN_STAR] = ACTIONS(5850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5850),
    [anon_sym_DOLLARunit] = ACTIONS(5850),
  },
  [4758] = {
    [sym_simple_identifier] = ACTIONS(5174),
    [anon_sym_wire] = ACTIONS(5174),
    [anon_sym_tri] = ACTIONS(5174),
    [anon_sym_tri0] = ACTIONS(5174),
    [anon_sym_tri1] = ACTIONS(5174),
    [anon_sym_wand] = ACTIONS(5174),
    [anon_sym_triand] = ACTIONS(5174),
    [anon_sym_wor] = ACTIONS(5174),
    [anon_sym_trior] = ACTIONS(5174),
    [anon_sym_trireg] = ACTIONS(5174),
    [anon_sym_uwire] = ACTIONS(5174),
    [anon_sym_SEMI] = ACTIONS(5172),
    [anon_sym_extern] = ACTIONS(5174),
    [anon_sym_interface] = ACTIONS(5174),
    [anon_sym_checker] = ACTIONS(5174),
    [anon_sym_virtual] = ACTIONS(5174),
    [anon_sym_class] = ACTIONS(5174),
    [anon_sym_type] = ACTIONS(5174),
    [anon_sym_DOLLARfatal] = ACTIONS(5172),
    [anon_sym_DOLLARerror] = ACTIONS(5172),
    [anon_sym_DOLLARwarning] = ACTIONS(5172),
    [anon_sym_DOLLARinfo] = ACTIONS(5172),
    [anon_sym_default] = ACTIONS(5174),
    [anon_sym_clocking] = ACTIONS(5174),
    [anon_sym_defparam] = ACTIONS(5174),
    [anon_sym_bind] = ACTIONS(5174),
    [anon_sym_rand] = ACTIONS(5174),
    [anon_sym_const] = ACTIONS(5174),
    [anon_sym_function] = ACTIONS(5174),
    [anon_sym_static] = ACTIONS(5174),
    [anon_sym_constraint] = ACTIONS(5174),
    [anon_sym_if] = ACTIONS(5174),
    [anon_sym_else] = ACTIONS(5174),
    [anon_sym_LBRACK] = ACTIONS(5172),
    [anon_sym_localparam] = ACTIONS(5174),
    [anon_sym_parameter] = ACTIONS(5174),
    [anon_sym_var] = ACTIONS(5174),
    [anon_sym_import] = ACTIONS(5174),
    [anon_sym_export] = ACTIONS(5174),
    [anon_sym_genvar] = ACTIONS(5174),
    [anon_sym_interconnect] = ACTIONS(5174),
    [anon_sym_typedef] = ACTIONS(5174),
    [anon_sym_enum] = ACTIONS(5174),
    [anon_sym_struct] = ACTIONS(5174),
    [anon_sym_union] = ACTIONS(5174),
    [anon_sym_nettype] = ACTIONS(5174),
    [anon_sym_automatic] = ACTIONS(5174),
    [anon_sym_string] = ACTIONS(5174),
    [anon_sym_chandle] = ACTIONS(5174),
    [anon_sym_event] = ACTIONS(5174),
    [anon_sym_byte] = ACTIONS(5174),
    [anon_sym_shortint] = ACTIONS(5174),
    [anon_sym_int] = ACTIONS(5174),
    [anon_sym_longint] = ACTIONS(5174),
    [anon_sym_integer] = ACTIONS(5174),
    [anon_sym_time] = ACTIONS(5174),
    [anon_sym_bit] = ACTIONS(5174),
    [anon_sym_logic] = ACTIONS(5174),
    [anon_sym_reg] = ACTIONS(5174),
    [anon_sym_shortreal] = ACTIONS(5174),
    [anon_sym_real] = ACTIONS(5174),
    [anon_sym_realtime] = ACTIONS(5174),
    [anon_sym_supply0] = ACTIONS(5174),
    [anon_sym_supply1] = ACTIONS(5174),
    [anon_sym_signed] = ACTIONS(5174),
    [anon_sym_unsigned] = ACTIONS(5174),
    [anon_sym_task] = ACTIONS(5174),
    [anon_sym_assert] = ACTIONS(5174),
    [anon_sym_property] = ACTIONS(5174),
    [anon_sym_assume] = ACTIONS(5174),
    [anon_sym_cover] = ACTIONS(5174),
    [anon_sym_sequence] = ACTIONS(5174),
    [anon_sym_restrict] = ACTIONS(5174),
    [anon_sym_not] = ACTIONS(5174),
    [anon_sym_or] = ACTIONS(5174),
    [anon_sym_and] = ACTIONS(5174),
    [anon_sym_case] = ACTIONS(5174),
    [anon_sym_always] = ACTIONS(5174),
    [anon_sym_covergroup] = ACTIONS(5174),
    [anon_sym_end] = ACTIONS(5174),
    [anon_sym_let] = ACTIONS(5174),
    [anon_sym_pulldown] = ACTIONS(5174),
    [anon_sym_pullup] = ACTIONS(5174),
    [anon_sym_cmos] = ACTIONS(5174),
    [anon_sym_rcmos] = ACTIONS(5174),
    [anon_sym_bufif0] = ACTIONS(5174),
    [anon_sym_bufif1] = ACTIONS(5174),
    [anon_sym_notif0] = ACTIONS(5174),
    [anon_sym_notif1] = ACTIONS(5174),
    [anon_sym_nmos] = ACTIONS(5174),
    [anon_sym_pmos] = ACTIONS(5174),
    [anon_sym_rnmos] = ACTIONS(5174),
    [anon_sym_rpmos] = ACTIONS(5174),
    [anon_sym_nand] = ACTIONS(5174),
    [anon_sym_nor] = ACTIONS(5174),
    [anon_sym_xor] = ACTIONS(5174),
    [anon_sym_xnor] = ACTIONS(5174),
    [anon_sym_buf] = ACTIONS(5174),
    [anon_sym_tranif0] = ACTIONS(5174),
    [anon_sym_tranif1] = ACTIONS(5174),
    [anon_sym_rtranif1] = ACTIONS(5174),
    [anon_sym_rtranif0] = ACTIONS(5174),
    [anon_sym_tran] = ACTIONS(5174),
    [anon_sym_rtran] = ACTIONS(5174),
    [anon_sym_generate] = ACTIONS(5174),
    [anon_sym_for] = ACTIONS(5174),
    [anon_sym_initial] = ACTIONS(5174),
    [anon_sym_assign] = ACTIONS(5174),
    [anon_sym_alias] = ACTIONS(5174),
    [anon_sym_always_comb] = ACTIONS(5174),
    [anon_sym_always_latch] = ACTIONS(5174),
    [anon_sym_always_ff] = ACTIONS(5174),
    [anon_sym_final] = ACTIONS(5174),
    [anon_sym_global] = ACTIONS(5174),
    [anon_sym_LPAREN_STAR] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5172),
    [anon_sym_DOLLARunit] = ACTIONS(5172),
  },
  [4759] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11039),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4760] = {
    [sym_simple_identifier] = ACTIONS(5226),
    [anon_sym_wire] = ACTIONS(5226),
    [anon_sym_tri] = ACTIONS(5226),
    [anon_sym_tri0] = ACTIONS(5226),
    [anon_sym_tri1] = ACTIONS(5226),
    [anon_sym_wand] = ACTIONS(5226),
    [anon_sym_triand] = ACTIONS(5226),
    [anon_sym_wor] = ACTIONS(5226),
    [anon_sym_trior] = ACTIONS(5226),
    [anon_sym_trireg] = ACTIONS(5226),
    [anon_sym_uwire] = ACTIONS(5226),
    [anon_sym_SEMI] = ACTIONS(5224),
    [anon_sym_extern] = ACTIONS(5226),
    [anon_sym_interface] = ACTIONS(5226),
    [anon_sym_checker] = ACTIONS(5226),
    [anon_sym_virtual] = ACTIONS(5226),
    [anon_sym_class] = ACTIONS(5226),
    [anon_sym_type] = ACTIONS(5226),
    [anon_sym_DOLLARfatal] = ACTIONS(5224),
    [anon_sym_DOLLARerror] = ACTIONS(5224),
    [anon_sym_DOLLARwarning] = ACTIONS(5224),
    [anon_sym_DOLLARinfo] = ACTIONS(5224),
    [anon_sym_default] = ACTIONS(5226),
    [anon_sym_clocking] = ACTIONS(5226),
    [anon_sym_defparam] = ACTIONS(5226),
    [anon_sym_bind] = ACTIONS(5226),
    [anon_sym_rand] = ACTIONS(5226),
    [anon_sym_const] = ACTIONS(5226),
    [anon_sym_function] = ACTIONS(5226),
    [anon_sym_static] = ACTIONS(5226),
    [anon_sym_constraint] = ACTIONS(5226),
    [anon_sym_if] = ACTIONS(5226),
    [anon_sym_else] = ACTIONS(5226),
    [anon_sym_LBRACK] = ACTIONS(5224),
    [anon_sym_localparam] = ACTIONS(5226),
    [anon_sym_parameter] = ACTIONS(5226),
    [anon_sym_var] = ACTIONS(5226),
    [anon_sym_import] = ACTIONS(5226),
    [anon_sym_export] = ACTIONS(5226),
    [anon_sym_genvar] = ACTIONS(5226),
    [anon_sym_interconnect] = ACTIONS(5226),
    [anon_sym_typedef] = ACTIONS(5226),
    [anon_sym_enum] = ACTIONS(5226),
    [anon_sym_struct] = ACTIONS(5226),
    [anon_sym_union] = ACTIONS(5226),
    [anon_sym_nettype] = ACTIONS(5226),
    [anon_sym_automatic] = ACTIONS(5226),
    [anon_sym_string] = ACTIONS(5226),
    [anon_sym_chandle] = ACTIONS(5226),
    [anon_sym_event] = ACTIONS(5226),
    [anon_sym_byte] = ACTIONS(5226),
    [anon_sym_shortint] = ACTIONS(5226),
    [anon_sym_int] = ACTIONS(5226),
    [anon_sym_longint] = ACTIONS(5226),
    [anon_sym_integer] = ACTIONS(5226),
    [anon_sym_time] = ACTIONS(5226),
    [anon_sym_bit] = ACTIONS(5226),
    [anon_sym_logic] = ACTIONS(5226),
    [anon_sym_reg] = ACTIONS(5226),
    [anon_sym_shortreal] = ACTIONS(5226),
    [anon_sym_real] = ACTIONS(5226),
    [anon_sym_realtime] = ACTIONS(5226),
    [anon_sym_supply0] = ACTIONS(5226),
    [anon_sym_supply1] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5226),
    [anon_sym_unsigned] = ACTIONS(5226),
    [anon_sym_task] = ACTIONS(5226),
    [anon_sym_assert] = ACTIONS(5226),
    [anon_sym_property] = ACTIONS(5226),
    [anon_sym_assume] = ACTIONS(5226),
    [anon_sym_cover] = ACTIONS(5226),
    [anon_sym_sequence] = ACTIONS(5226),
    [anon_sym_restrict] = ACTIONS(5226),
    [anon_sym_not] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5226),
    [anon_sym_and] = ACTIONS(5226),
    [anon_sym_case] = ACTIONS(5226),
    [anon_sym_always] = ACTIONS(5226),
    [anon_sym_covergroup] = ACTIONS(5226),
    [anon_sym_let] = ACTIONS(5226),
    [anon_sym_pulldown] = ACTIONS(5226),
    [anon_sym_pullup] = ACTIONS(5226),
    [anon_sym_cmos] = ACTIONS(5226),
    [anon_sym_rcmos] = ACTIONS(5226),
    [anon_sym_bufif0] = ACTIONS(5226),
    [anon_sym_bufif1] = ACTIONS(5226),
    [anon_sym_notif0] = ACTIONS(5226),
    [anon_sym_notif1] = ACTIONS(5226),
    [anon_sym_nmos] = ACTIONS(5226),
    [anon_sym_pmos] = ACTIONS(5226),
    [anon_sym_rnmos] = ACTIONS(5226),
    [anon_sym_rpmos] = ACTIONS(5226),
    [anon_sym_nand] = ACTIONS(5226),
    [anon_sym_nor] = ACTIONS(5226),
    [anon_sym_xor] = ACTIONS(5226),
    [anon_sym_xnor] = ACTIONS(5226),
    [anon_sym_buf] = ACTIONS(5226),
    [anon_sym_tranif0] = ACTIONS(5226),
    [anon_sym_tranif1] = ACTIONS(5226),
    [anon_sym_rtranif1] = ACTIONS(5226),
    [anon_sym_rtranif0] = ACTIONS(5226),
    [anon_sym_tran] = ACTIONS(5226),
    [anon_sym_rtran] = ACTIONS(5226),
    [anon_sym_generate] = ACTIONS(5226),
    [anon_sym_endgenerate] = ACTIONS(5226),
    [anon_sym_for] = ACTIONS(5226),
    [anon_sym_initial] = ACTIONS(5226),
    [anon_sym_assign] = ACTIONS(5226),
    [anon_sym_alias] = ACTIONS(5226),
    [anon_sym_always_comb] = ACTIONS(5226),
    [anon_sym_always_latch] = ACTIONS(5226),
    [anon_sym_always_ff] = ACTIONS(5226),
    [anon_sym_final] = ACTIONS(5226),
    [anon_sym_global] = ACTIONS(5226),
    [anon_sym_LPAREN_STAR] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5224),
    [anon_sym_DOLLARunit] = ACTIONS(5224),
  },
  [4761] = {
    [sym_simple_identifier] = ACTIONS(4900),
    [anon_sym_wire] = ACTIONS(4900),
    [anon_sym_tri] = ACTIONS(4900),
    [anon_sym_tri0] = ACTIONS(4900),
    [anon_sym_tri1] = ACTIONS(4900),
    [anon_sym_wand] = ACTIONS(4900),
    [anon_sym_triand] = ACTIONS(4900),
    [anon_sym_wor] = ACTIONS(4900),
    [anon_sym_trior] = ACTIONS(4900),
    [anon_sym_trireg] = ACTIONS(4900),
    [anon_sym_uwire] = ACTIONS(4900),
    [anon_sym_SEMI] = ACTIONS(4898),
    [anon_sym_extern] = ACTIONS(4900),
    [anon_sym_interface] = ACTIONS(4900),
    [anon_sym_checker] = ACTIONS(4900),
    [anon_sym_virtual] = ACTIONS(4900),
    [anon_sym_class] = ACTIONS(4900),
    [anon_sym_type] = ACTIONS(4900),
    [anon_sym_DOLLARfatal] = ACTIONS(4898),
    [anon_sym_DOLLARerror] = ACTIONS(4898),
    [anon_sym_DOLLARwarning] = ACTIONS(4898),
    [anon_sym_DOLLARinfo] = ACTIONS(4898),
    [anon_sym_default] = ACTIONS(4900),
    [anon_sym_clocking] = ACTIONS(4900),
    [anon_sym_defparam] = ACTIONS(4900),
    [anon_sym_bind] = ACTIONS(4900),
    [anon_sym_rand] = ACTIONS(4900),
    [anon_sym_const] = ACTIONS(4900),
    [anon_sym_function] = ACTIONS(4900),
    [anon_sym_static] = ACTIONS(4900),
    [anon_sym_constraint] = ACTIONS(4900),
    [anon_sym_if] = ACTIONS(4900),
    [anon_sym_else] = ACTIONS(4900),
    [anon_sym_LBRACK] = ACTIONS(4898),
    [anon_sym_localparam] = ACTIONS(4900),
    [anon_sym_parameter] = ACTIONS(4900),
    [anon_sym_var] = ACTIONS(4900),
    [anon_sym_import] = ACTIONS(4900),
    [anon_sym_export] = ACTIONS(4900),
    [anon_sym_genvar] = ACTIONS(4900),
    [anon_sym_interconnect] = ACTIONS(4900),
    [anon_sym_typedef] = ACTIONS(4900),
    [anon_sym_enum] = ACTIONS(4900),
    [anon_sym_struct] = ACTIONS(4900),
    [anon_sym_union] = ACTIONS(4900),
    [anon_sym_nettype] = ACTIONS(4900),
    [anon_sym_automatic] = ACTIONS(4900),
    [anon_sym_string] = ACTIONS(4900),
    [anon_sym_chandle] = ACTIONS(4900),
    [anon_sym_event] = ACTIONS(4900),
    [anon_sym_byte] = ACTIONS(4900),
    [anon_sym_shortint] = ACTIONS(4900),
    [anon_sym_int] = ACTIONS(4900),
    [anon_sym_longint] = ACTIONS(4900),
    [anon_sym_integer] = ACTIONS(4900),
    [anon_sym_time] = ACTIONS(4900),
    [anon_sym_bit] = ACTIONS(4900),
    [anon_sym_logic] = ACTIONS(4900),
    [anon_sym_reg] = ACTIONS(4900),
    [anon_sym_shortreal] = ACTIONS(4900),
    [anon_sym_real] = ACTIONS(4900),
    [anon_sym_realtime] = ACTIONS(4900),
    [anon_sym_supply0] = ACTIONS(4900),
    [anon_sym_supply1] = ACTIONS(4900),
    [anon_sym_signed] = ACTIONS(4900),
    [anon_sym_unsigned] = ACTIONS(4900),
    [anon_sym_task] = ACTIONS(4900),
    [anon_sym_assert] = ACTIONS(4900),
    [anon_sym_property] = ACTIONS(4900),
    [anon_sym_assume] = ACTIONS(4900),
    [anon_sym_cover] = ACTIONS(4900),
    [anon_sym_sequence] = ACTIONS(4900),
    [anon_sym_restrict] = ACTIONS(4900),
    [anon_sym_not] = ACTIONS(4900),
    [anon_sym_or] = ACTIONS(4900),
    [anon_sym_and] = ACTIONS(4900),
    [anon_sym_case] = ACTIONS(4900),
    [anon_sym_always] = ACTIONS(4900),
    [anon_sym_covergroup] = ACTIONS(4900),
    [anon_sym_end] = ACTIONS(4900),
    [anon_sym_let] = ACTIONS(4900),
    [anon_sym_pulldown] = ACTIONS(4900),
    [anon_sym_pullup] = ACTIONS(4900),
    [anon_sym_cmos] = ACTIONS(4900),
    [anon_sym_rcmos] = ACTIONS(4900),
    [anon_sym_bufif0] = ACTIONS(4900),
    [anon_sym_bufif1] = ACTIONS(4900),
    [anon_sym_notif0] = ACTIONS(4900),
    [anon_sym_notif1] = ACTIONS(4900),
    [anon_sym_nmos] = ACTIONS(4900),
    [anon_sym_pmos] = ACTIONS(4900),
    [anon_sym_rnmos] = ACTIONS(4900),
    [anon_sym_rpmos] = ACTIONS(4900),
    [anon_sym_nand] = ACTIONS(4900),
    [anon_sym_nor] = ACTIONS(4900),
    [anon_sym_xor] = ACTIONS(4900),
    [anon_sym_xnor] = ACTIONS(4900),
    [anon_sym_buf] = ACTIONS(4900),
    [anon_sym_tranif0] = ACTIONS(4900),
    [anon_sym_tranif1] = ACTIONS(4900),
    [anon_sym_rtranif1] = ACTIONS(4900),
    [anon_sym_rtranif0] = ACTIONS(4900),
    [anon_sym_tran] = ACTIONS(4900),
    [anon_sym_rtran] = ACTIONS(4900),
    [anon_sym_generate] = ACTIONS(4900),
    [anon_sym_for] = ACTIONS(4900),
    [anon_sym_initial] = ACTIONS(4900),
    [anon_sym_assign] = ACTIONS(4900),
    [anon_sym_alias] = ACTIONS(4900),
    [anon_sym_always_comb] = ACTIONS(4900),
    [anon_sym_always_latch] = ACTIONS(4900),
    [anon_sym_always_ff] = ACTIONS(4900),
    [anon_sym_final] = ACTIONS(4900),
    [anon_sym_global] = ACTIONS(4900),
    [anon_sym_LPAREN_STAR] = ACTIONS(4898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4898),
    [anon_sym_DOLLARunit] = ACTIONS(4898),
  },
  [4762] = {
    [sym_simple_identifier] = ACTIONS(4944),
    [anon_sym_wire] = ACTIONS(4944),
    [anon_sym_tri] = ACTIONS(4944),
    [anon_sym_tri0] = ACTIONS(4944),
    [anon_sym_tri1] = ACTIONS(4944),
    [anon_sym_wand] = ACTIONS(4944),
    [anon_sym_triand] = ACTIONS(4944),
    [anon_sym_wor] = ACTIONS(4944),
    [anon_sym_trior] = ACTIONS(4944),
    [anon_sym_trireg] = ACTIONS(4944),
    [anon_sym_uwire] = ACTIONS(4944),
    [anon_sym_SEMI] = ACTIONS(4942),
    [anon_sym_extern] = ACTIONS(4944),
    [anon_sym_interface] = ACTIONS(4944),
    [anon_sym_checker] = ACTIONS(4944),
    [anon_sym_virtual] = ACTIONS(4944),
    [anon_sym_class] = ACTIONS(4944),
    [anon_sym_type] = ACTIONS(4944),
    [anon_sym_DOLLARfatal] = ACTIONS(4942),
    [anon_sym_DOLLARerror] = ACTIONS(4942),
    [anon_sym_DOLLARwarning] = ACTIONS(4942),
    [anon_sym_DOLLARinfo] = ACTIONS(4942),
    [anon_sym_default] = ACTIONS(4944),
    [anon_sym_clocking] = ACTIONS(4944),
    [anon_sym_defparam] = ACTIONS(4944),
    [anon_sym_bind] = ACTIONS(4944),
    [anon_sym_rand] = ACTIONS(4944),
    [anon_sym_const] = ACTIONS(4944),
    [anon_sym_function] = ACTIONS(4944),
    [anon_sym_static] = ACTIONS(4944),
    [anon_sym_constraint] = ACTIONS(4944),
    [anon_sym_if] = ACTIONS(4944),
    [anon_sym_else] = ACTIONS(4944),
    [anon_sym_LBRACK] = ACTIONS(4942),
    [anon_sym_localparam] = ACTIONS(4944),
    [anon_sym_parameter] = ACTIONS(4944),
    [anon_sym_var] = ACTIONS(4944),
    [anon_sym_import] = ACTIONS(4944),
    [anon_sym_export] = ACTIONS(4944),
    [anon_sym_genvar] = ACTIONS(4944),
    [anon_sym_interconnect] = ACTIONS(4944),
    [anon_sym_typedef] = ACTIONS(4944),
    [anon_sym_enum] = ACTIONS(4944),
    [anon_sym_struct] = ACTIONS(4944),
    [anon_sym_union] = ACTIONS(4944),
    [anon_sym_nettype] = ACTIONS(4944),
    [anon_sym_automatic] = ACTIONS(4944),
    [anon_sym_string] = ACTIONS(4944),
    [anon_sym_chandle] = ACTIONS(4944),
    [anon_sym_event] = ACTIONS(4944),
    [anon_sym_byte] = ACTIONS(4944),
    [anon_sym_shortint] = ACTIONS(4944),
    [anon_sym_int] = ACTIONS(4944),
    [anon_sym_longint] = ACTIONS(4944),
    [anon_sym_integer] = ACTIONS(4944),
    [anon_sym_time] = ACTIONS(4944),
    [anon_sym_bit] = ACTIONS(4944),
    [anon_sym_logic] = ACTIONS(4944),
    [anon_sym_reg] = ACTIONS(4944),
    [anon_sym_shortreal] = ACTIONS(4944),
    [anon_sym_real] = ACTIONS(4944),
    [anon_sym_realtime] = ACTIONS(4944),
    [anon_sym_supply0] = ACTIONS(4944),
    [anon_sym_supply1] = ACTIONS(4944),
    [anon_sym_signed] = ACTIONS(4944),
    [anon_sym_unsigned] = ACTIONS(4944),
    [anon_sym_task] = ACTIONS(4944),
    [anon_sym_assert] = ACTIONS(4944),
    [anon_sym_property] = ACTIONS(4944),
    [anon_sym_assume] = ACTIONS(4944),
    [anon_sym_cover] = ACTIONS(4944),
    [anon_sym_sequence] = ACTIONS(4944),
    [anon_sym_restrict] = ACTIONS(4944),
    [anon_sym_not] = ACTIONS(4944),
    [anon_sym_or] = ACTIONS(4944),
    [anon_sym_and] = ACTIONS(4944),
    [anon_sym_case] = ACTIONS(4944),
    [anon_sym_always] = ACTIONS(4944),
    [anon_sym_covergroup] = ACTIONS(4944),
    [anon_sym_let] = ACTIONS(4944),
    [anon_sym_pulldown] = ACTIONS(4944),
    [anon_sym_pullup] = ACTIONS(4944),
    [anon_sym_cmos] = ACTIONS(4944),
    [anon_sym_rcmos] = ACTIONS(4944),
    [anon_sym_bufif0] = ACTIONS(4944),
    [anon_sym_bufif1] = ACTIONS(4944),
    [anon_sym_notif0] = ACTIONS(4944),
    [anon_sym_notif1] = ACTIONS(4944),
    [anon_sym_nmos] = ACTIONS(4944),
    [anon_sym_pmos] = ACTIONS(4944),
    [anon_sym_rnmos] = ACTIONS(4944),
    [anon_sym_rpmos] = ACTIONS(4944),
    [anon_sym_nand] = ACTIONS(4944),
    [anon_sym_nor] = ACTIONS(4944),
    [anon_sym_xor] = ACTIONS(4944),
    [anon_sym_xnor] = ACTIONS(4944),
    [anon_sym_buf] = ACTIONS(4944),
    [anon_sym_tranif0] = ACTIONS(4944),
    [anon_sym_tranif1] = ACTIONS(4944),
    [anon_sym_rtranif1] = ACTIONS(4944),
    [anon_sym_rtranif0] = ACTIONS(4944),
    [anon_sym_tran] = ACTIONS(4944),
    [anon_sym_rtran] = ACTIONS(4944),
    [anon_sym_generate] = ACTIONS(4944),
    [anon_sym_endgenerate] = ACTIONS(4944),
    [anon_sym_for] = ACTIONS(4944),
    [anon_sym_initial] = ACTIONS(4944),
    [anon_sym_assign] = ACTIONS(4944),
    [anon_sym_alias] = ACTIONS(4944),
    [anon_sym_always_comb] = ACTIONS(4944),
    [anon_sym_always_latch] = ACTIONS(4944),
    [anon_sym_always_ff] = ACTIONS(4944),
    [anon_sym_final] = ACTIONS(4944),
    [anon_sym_global] = ACTIONS(4944),
    [anon_sym_LPAREN_STAR] = ACTIONS(4942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4942),
    [anon_sym_DOLLARunit] = ACTIONS(4942),
  },
  [4763] = {
    [sym_simple_identifier] = ACTIONS(5242),
    [anon_sym_wire] = ACTIONS(5242),
    [anon_sym_tri] = ACTIONS(5242),
    [anon_sym_tri0] = ACTIONS(5242),
    [anon_sym_tri1] = ACTIONS(5242),
    [anon_sym_wand] = ACTIONS(5242),
    [anon_sym_triand] = ACTIONS(5242),
    [anon_sym_wor] = ACTIONS(5242),
    [anon_sym_trior] = ACTIONS(5242),
    [anon_sym_trireg] = ACTIONS(5242),
    [anon_sym_uwire] = ACTIONS(5242),
    [anon_sym_SEMI] = ACTIONS(5240),
    [anon_sym_extern] = ACTIONS(5242),
    [anon_sym_interface] = ACTIONS(5242),
    [anon_sym_checker] = ACTIONS(5242),
    [anon_sym_virtual] = ACTIONS(5242),
    [anon_sym_class] = ACTIONS(5242),
    [anon_sym_type] = ACTIONS(5242),
    [anon_sym_DOLLARfatal] = ACTIONS(5240),
    [anon_sym_DOLLARerror] = ACTIONS(5240),
    [anon_sym_DOLLARwarning] = ACTIONS(5240),
    [anon_sym_DOLLARinfo] = ACTIONS(5240),
    [anon_sym_default] = ACTIONS(5242),
    [anon_sym_clocking] = ACTIONS(5242),
    [anon_sym_defparam] = ACTIONS(5242),
    [anon_sym_bind] = ACTIONS(5242),
    [anon_sym_rand] = ACTIONS(5242),
    [anon_sym_const] = ACTIONS(5242),
    [anon_sym_function] = ACTIONS(5242),
    [anon_sym_static] = ACTIONS(5242),
    [anon_sym_constraint] = ACTIONS(5242),
    [anon_sym_if] = ACTIONS(5242),
    [anon_sym_else] = ACTIONS(5242),
    [anon_sym_LBRACK] = ACTIONS(5240),
    [anon_sym_localparam] = ACTIONS(5242),
    [anon_sym_parameter] = ACTIONS(5242),
    [anon_sym_var] = ACTIONS(5242),
    [anon_sym_import] = ACTIONS(5242),
    [anon_sym_export] = ACTIONS(5242),
    [anon_sym_genvar] = ACTIONS(5242),
    [anon_sym_interconnect] = ACTIONS(5242),
    [anon_sym_typedef] = ACTIONS(5242),
    [anon_sym_enum] = ACTIONS(5242),
    [anon_sym_struct] = ACTIONS(5242),
    [anon_sym_union] = ACTIONS(5242),
    [anon_sym_nettype] = ACTIONS(5242),
    [anon_sym_automatic] = ACTIONS(5242),
    [anon_sym_string] = ACTIONS(5242),
    [anon_sym_chandle] = ACTIONS(5242),
    [anon_sym_event] = ACTIONS(5242),
    [anon_sym_byte] = ACTIONS(5242),
    [anon_sym_shortint] = ACTIONS(5242),
    [anon_sym_int] = ACTIONS(5242),
    [anon_sym_longint] = ACTIONS(5242),
    [anon_sym_integer] = ACTIONS(5242),
    [anon_sym_time] = ACTIONS(5242),
    [anon_sym_bit] = ACTIONS(5242),
    [anon_sym_logic] = ACTIONS(5242),
    [anon_sym_reg] = ACTIONS(5242),
    [anon_sym_shortreal] = ACTIONS(5242),
    [anon_sym_real] = ACTIONS(5242),
    [anon_sym_realtime] = ACTIONS(5242),
    [anon_sym_supply0] = ACTIONS(5242),
    [anon_sym_supply1] = ACTIONS(5242),
    [anon_sym_signed] = ACTIONS(5242),
    [anon_sym_unsigned] = ACTIONS(5242),
    [anon_sym_task] = ACTIONS(5242),
    [anon_sym_assert] = ACTIONS(5242),
    [anon_sym_property] = ACTIONS(5242),
    [anon_sym_assume] = ACTIONS(5242),
    [anon_sym_cover] = ACTIONS(5242),
    [anon_sym_sequence] = ACTIONS(5242),
    [anon_sym_restrict] = ACTIONS(5242),
    [anon_sym_not] = ACTIONS(5242),
    [anon_sym_or] = ACTIONS(5242),
    [anon_sym_and] = ACTIONS(5242),
    [anon_sym_case] = ACTIONS(5242),
    [anon_sym_always] = ACTIONS(5242),
    [anon_sym_covergroup] = ACTIONS(5242),
    [anon_sym_let] = ACTIONS(5242),
    [anon_sym_pulldown] = ACTIONS(5242),
    [anon_sym_pullup] = ACTIONS(5242),
    [anon_sym_cmos] = ACTIONS(5242),
    [anon_sym_rcmos] = ACTIONS(5242),
    [anon_sym_bufif0] = ACTIONS(5242),
    [anon_sym_bufif1] = ACTIONS(5242),
    [anon_sym_notif0] = ACTIONS(5242),
    [anon_sym_notif1] = ACTIONS(5242),
    [anon_sym_nmos] = ACTIONS(5242),
    [anon_sym_pmos] = ACTIONS(5242),
    [anon_sym_rnmos] = ACTIONS(5242),
    [anon_sym_rpmos] = ACTIONS(5242),
    [anon_sym_nand] = ACTIONS(5242),
    [anon_sym_nor] = ACTIONS(5242),
    [anon_sym_xor] = ACTIONS(5242),
    [anon_sym_xnor] = ACTIONS(5242),
    [anon_sym_buf] = ACTIONS(5242),
    [anon_sym_tranif0] = ACTIONS(5242),
    [anon_sym_tranif1] = ACTIONS(5242),
    [anon_sym_rtranif1] = ACTIONS(5242),
    [anon_sym_rtranif0] = ACTIONS(5242),
    [anon_sym_tran] = ACTIONS(5242),
    [anon_sym_rtran] = ACTIONS(5242),
    [anon_sym_generate] = ACTIONS(5242),
    [anon_sym_endgenerate] = ACTIONS(5242),
    [anon_sym_for] = ACTIONS(5242),
    [anon_sym_initial] = ACTIONS(5242),
    [anon_sym_assign] = ACTIONS(5242),
    [anon_sym_alias] = ACTIONS(5242),
    [anon_sym_always_comb] = ACTIONS(5242),
    [anon_sym_always_latch] = ACTIONS(5242),
    [anon_sym_always_ff] = ACTIONS(5242),
    [anon_sym_final] = ACTIONS(5242),
    [anon_sym_global] = ACTIONS(5242),
    [anon_sym_LPAREN_STAR] = ACTIONS(5240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5240),
    [anon_sym_DOLLARunit] = ACTIONS(5240),
  },
  [4764] = {
    [sym_simple_identifier] = ACTIONS(6637),
    [anon_sym_wire] = ACTIONS(6637),
    [anon_sym_tri] = ACTIONS(6637),
    [anon_sym_tri0] = ACTIONS(6637),
    [anon_sym_tri1] = ACTIONS(6637),
    [anon_sym_wand] = ACTIONS(6637),
    [anon_sym_triand] = ACTIONS(6637),
    [anon_sym_wor] = ACTIONS(6637),
    [anon_sym_trior] = ACTIONS(6637),
    [anon_sym_trireg] = ACTIONS(6637),
    [anon_sym_uwire] = ACTIONS(6637),
    [anon_sym_SEMI] = ACTIONS(6639),
    [anon_sym_extern] = ACTIONS(6637),
    [anon_sym_interface] = ACTIONS(6637),
    [anon_sym_checker] = ACTIONS(6637),
    [anon_sym_virtual] = ACTIONS(6637),
    [anon_sym_class] = ACTIONS(6637),
    [anon_sym_type] = ACTIONS(6637),
    [anon_sym_DOLLARfatal] = ACTIONS(6639),
    [anon_sym_DOLLARerror] = ACTIONS(6639),
    [anon_sym_DOLLARwarning] = ACTIONS(6639),
    [anon_sym_DOLLARinfo] = ACTIONS(6639),
    [anon_sym_default] = ACTIONS(6637),
    [anon_sym_clocking] = ACTIONS(6637),
    [anon_sym_defparam] = ACTIONS(6637),
    [anon_sym_bind] = ACTIONS(6637),
    [anon_sym_rand] = ACTIONS(6637),
    [anon_sym_const] = ACTIONS(6637),
    [anon_sym_function] = ACTIONS(6637),
    [anon_sym_static] = ACTIONS(6637),
    [anon_sym_constraint] = ACTIONS(6637),
    [anon_sym_if] = ACTIONS(6637),
    [anon_sym_else] = ACTIONS(6637),
    [anon_sym_LBRACK] = ACTIONS(6639),
    [anon_sym_localparam] = ACTIONS(6637),
    [anon_sym_parameter] = ACTIONS(6637),
    [anon_sym_var] = ACTIONS(6637),
    [anon_sym_import] = ACTIONS(6637),
    [anon_sym_export] = ACTIONS(6637),
    [anon_sym_genvar] = ACTIONS(6637),
    [anon_sym_interconnect] = ACTIONS(6637),
    [anon_sym_typedef] = ACTIONS(6637),
    [anon_sym_enum] = ACTIONS(6637),
    [anon_sym_struct] = ACTIONS(6637),
    [anon_sym_union] = ACTIONS(6637),
    [anon_sym_nettype] = ACTIONS(6637),
    [anon_sym_automatic] = ACTIONS(6637),
    [anon_sym_string] = ACTIONS(6637),
    [anon_sym_chandle] = ACTIONS(6637),
    [anon_sym_event] = ACTIONS(6637),
    [anon_sym_byte] = ACTIONS(6637),
    [anon_sym_shortint] = ACTIONS(6637),
    [anon_sym_int] = ACTIONS(6637),
    [anon_sym_longint] = ACTIONS(6637),
    [anon_sym_integer] = ACTIONS(6637),
    [anon_sym_time] = ACTIONS(6637),
    [anon_sym_bit] = ACTIONS(6637),
    [anon_sym_logic] = ACTIONS(6637),
    [anon_sym_reg] = ACTIONS(6637),
    [anon_sym_shortreal] = ACTIONS(6637),
    [anon_sym_real] = ACTIONS(6637),
    [anon_sym_realtime] = ACTIONS(6637),
    [anon_sym_supply0] = ACTIONS(6637),
    [anon_sym_supply1] = ACTIONS(6637),
    [anon_sym_signed] = ACTIONS(6637),
    [anon_sym_unsigned] = ACTIONS(6637),
    [anon_sym_task] = ACTIONS(6637),
    [anon_sym_assert] = ACTIONS(6637),
    [anon_sym_property] = ACTIONS(6637),
    [anon_sym_assume] = ACTIONS(6637),
    [anon_sym_cover] = ACTIONS(6637),
    [anon_sym_sequence] = ACTIONS(6637),
    [anon_sym_restrict] = ACTIONS(6637),
    [anon_sym_not] = ACTIONS(6637),
    [anon_sym_or] = ACTIONS(6637),
    [anon_sym_and] = ACTIONS(6637),
    [anon_sym_case] = ACTIONS(6637),
    [anon_sym_always] = ACTIONS(6637),
    [anon_sym_covergroup] = ACTIONS(6637),
    [anon_sym_end] = ACTIONS(6637),
    [anon_sym_let] = ACTIONS(6637),
    [anon_sym_pulldown] = ACTIONS(6637),
    [anon_sym_pullup] = ACTIONS(6637),
    [anon_sym_cmos] = ACTIONS(6637),
    [anon_sym_rcmos] = ACTIONS(6637),
    [anon_sym_bufif0] = ACTIONS(6637),
    [anon_sym_bufif1] = ACTIONS(6637),
    [anon_sym_notif0] = ACTIONS(6637),
    [anon_sym_notif1] = ACTIONS(6637),
    [anon_sym_nmos] = ACTIONS(6637),
    [anon_sym_pmos] = ACTIONS(6637),
    [anon_sym_rnmos] = ACTIONS(6637),
    [anon_sym_rpmos] = ACTIONS(6637),
    [anon_sym_nand] = ACTIONS(6637),
    [anon_sym_nor] = ACTIONS(6637),
    [anon_sym_xor] = ACTIONS(6637),
    [anon_sym_xnor] = ACTIONS(6637),
    [anon_sym_buf] = ACTIONS(6637),
    [anon_sym_tranif0] = ACTIONS(6637),
    [anon_sym_tranif1] = ACTIONS(6637),
    [anon_sym_rtranif1] = ACTIONS(6637),
    [anon_sym_rtranif0] = ACTIONS(6637),
    [anon_sym_tran] = ACTIONS(6637),
    [anon_sym_rtran] = ACTIONS(6637),
    [anon_sym_generate] = ACTIONS(6637),
    [anon_sym_for] = ACTIONS(6637),
    [anon_sym_initial] = ACTIONS(6637),
    [anon_sym_assign] = ACTIONS(6637),
    [anon_sym_alias] = ACTIONS(6637),
    [anon_sym_always_comb] = ACTIONS(6637),
    [anon_sym_always_latch] = ACTIONS(6637),
    [anon_sym_always_ff] = ACTIONS(6637),
    [anon_sym_final] = ACTIONS(6637),
    [anon_sym_global] = ACTIONS(6637),
    [anon_sym_LPAREN_STAR] = ACTIONS(6639),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6639),
    [anon_sym_DOLLARunit] = ACTIONS(6639),
  },
  [4765] = {
    [sym_simple_identifier] = ACTIONS(6653),
    [anon_sym_wire] = ACTIONS(6653),
    [anon_sym_tri] = ACTIONS(6653),
    [anon_sym_tri0] = ACTIONS(6653),
    [anon_sym_tri1] = ACTIONS(6653),
    [anon_sym_wand] = ACTIONS(6653),
    [anon_sym_triand] = ACTIONS(6653),
    [anon_sym_wor] = ACTIONS(6653),
    [anon_sym_trior] = ACTIONS(6653),
    [anon_sym_trireg] = ACTIONS(6653),
    [anon_sym_uwire] = ACTIONS(6653),
    [anon_sym_SEMI] = ACTIONS(6655),
    [anon_sym_extern] = ACTIONS(6653),
    [anon_sym_interface] = ACTIONS(6653),
    [anon_sym_checker] = ACTIONS(6653),
    [anon_sym_virtual] = ACTIONS(6653),
    [anon_sym_class] = ACTIONS(6653),
    [anon_sym_type] = ACTIONS(6653),
    [anon_sym_DOLLARfatal] = ACTIONS(6655),
    [anon_sym_DOLLARerror] = ACTIONS(6655),
    [anon_sym_DOLLARwarning] = ACTIONS(6655),
    [anon_sym_DOLLARinfo] = ACTIONS(6655),
    [anon_sym_default] = ACTIONS(6653),
    [anon_sym_clocking] = ACTIONS(6653),
    [anon_sym_defparam] = ACTIONS(6653),
    [anon_sym_bind] = ACTIONS(6653),
    [anon_sym_rand] = ACTIONS(6653),
    [anon_sym_const] = ACTIONS(6653),
    [anon_sym_function] = ACTIONS(6653),
    [anon_sym_static] = ACTIONS(6653),
    [anon_sym_constraint] = ACTIONS(6653),
    [anon_sym_if] = ACTIONS(6653),
    [anon_sym_else] = ACTIONS(6653),
    [anon_sym_LBRACK] = ACTIONS(6655),
    [anon_sym_localparam] = ACTIONS(6653),
    [anon_sym_parameter] = ACTIONS(6653),
    [anon_sym_var] = ACTIONS(6653),
    [anon_sym_import] = ACTIONS(6653),
    [anon_sym_export] = ACTIONS(6653),
    [anon_sym_genvar] = ACTIONS(6653),
    [anon_sym_interconnect] = ACTIONS(6653),
    [anon_sym_typedef] = ACTIONS(6653),
    [anon_sym_enum] = ACTIONS(6653),
    [anon_sym_struct] = ACTIONS(6653),
    [anon_sym_union] = ACTIONS(6653),
    [anon_sym_nettype] = ACTIONS(6653),
    [anon_sym_automatic] = ACTIONS(6653),
    [anon_sym_string] = ACTIONS(6653),
    [anon_sym_chandle] = ACTIONS(6653),
    [anon_sym_event] = ACTIONS(6653),
    [anon_sym_byte] = ACTIONS(6653),
    [anon_sym_shortint] = ACTIONS(6653),
    [anon_sym_int] = ACTIONS(6653),
    [anon_sym_longint] = ACTIONS(6653),
    [anon_sym_integer] = ACTIONS(6653),
    [anon_sym_time] = ACTIONS(6653),
    [anon_sym_bit] = ACTIONS(6653),
    [anon_sym_logic] = ACTIONS(6653),
    [anon_sym_reg] = ACTIONS(6653),
    [anon_sym_shortreal] = ACTIONS(6653),
    [anon_sym_real] = ACTIONS(6653),
    [anon_sym_realtime] = ACTIONS(6653),
    [anon_sym_supply0] = ACTIONS(6653),
    [anon_sym_supply1] = ACTIONS(6653),
    [anon_sym_signed] = ACTIONS(6653),
    [anon_sym_unsigned] = ACTIONS(6653),
    [anon_sym_task] = ACTIONS(6653),
    [anon_sym_assert] = ACTIONS(6653),
    [anon_sym_property] = ACTIONS(6653),
    [anon_sym_assume] = ACTIONS(6653),
    [anon_sym_cover] = ACTIONS(6653),
    [anon_sym_sequence] = ACTIONS(6653),
    [anon_sym_restrict] = ACTIONS(6653),
    [anon_sym_not] = ACTIONS(6653),
    [anon_sym_or] = ACTIONS(6653),
    [anon_sym_and] = ACTIONS(6653),
    [anon_sym_case] = ACTIONS(6653),
    [anon_sym_always] = ACTIONS(6653),
    [anon_sym_covergroup] = ACTIONS(6653),
    [anon_sym_end] = ACTIONS(6653),
    [anon_sym_let] = ACTIONS(6653),
    [anon_sym_pulldown] = ACTIONS(6653),
    [anon_sym_pullup] = ACTIONS(6653),
    [anon_sym_cmos] = ACTIONS(6653),
    [anon_sym_rcmos] = ACTIONS(6653),
    [anon_sym_bufif0] = ACTIONS(6653),
    [anon_sym_bufif1] = ACTIONS(6653),
    [anon_sym_notif0] = ACTIONS(6653),
    [anon_sym_notif1] = ACTIONS(6653),
    [anon_sym_nmos] = ACTIONS(6653),
    [anon_sym_pmos] = ACTIONS(6653),
    [anon_sym_rnmos] = ACTIONS(6653),
    [anon_sym_rpmos] = ACTIONS(6653),
    [anon_sym_nand] = ACTIONS(6653),
    [anon_sym_nor] = ACTIONS(6653),
    [anon_sym_xor] = ACTIONS(6653),
    [anon_sym_xnor] = ACTIONS(6653),
    [anon_sym_buf] = ACTIONS(6653),
    [anon_sym_tranif0] = ACTIONS(6653),
    [anon_sym_tranif1] = ACTIONS(6653),
    [anon_sym_rtranif1] = ACTIONS(6653),
    [anon_sym_rtranif0] = ACTIONS(6653),
    [anon_sym_tran] = ACTIONS(6653),
    [anon_sym_rtran] = ACTIONS(6653),
    [anon_sym_generate] = ACTIONS(6653),
    [anon_sym_for] = ACTIONS(6653),
    [anon_sym_initial] = ACTIONS(6653),
    [anon_sym_assign] = ACTIONS(6653),
    [anon_sym_alias] = ACTIONS(6653),
    [anon_sym_always_comb] = ACTIONS(6653),
    [anon_sym_always_latch] = ACTIONS(6653),
    [anon_sym_always_ff] = ACTIONS(6653),
    [anon_sym_final] = ACTIONS(6653),
    [anon_sym_global] = ACTIONS(6653),
    [anon_sym_LPAREN_STAR] = ACTIONS(6655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6655),
    [anon_sym_DOLLARunit] = ACTIONS(6655),
  },
  [4766] = {
    [sym_simple_identifier] = ACTIONS(5178),
    [anon_sym_wire] = ACTIONS(5178),
    [anon_sym_tri] = ACTIONS(5178),
    [anon_sym_tri0] = ACTIONS(5178),
    [anon_sym_tri1] = ACTIONS(5178),
    [anon_sym_wand] = ACTIONS(5178),
    [anon_sym_triand] = ACTIONS(5178),
    [anon_sym_wor] = ACTIONS(5178),
    [anon_sym_trior] = ACTIONS(5178),
    [anon_sym_trireg] = ACTIONS(5178),
    [anon_sym_uwire] = ACTIONS(5178),
    [anon_sym_SEMI] = ACTIONS(5176),
    [anon_sym_extern] = ACTIONS(5178),
    [anon_sym_interface] = ACTIONS(5178),
    [anon_sym_checker] = ACTIONS(5178),
    [anon_sym_virtual] = ACTIONS(5178),
    [anon_sym_class] = ACTIONS(5178),
    [anon_sym_type] = ACTIONS(5178),
    [anon_sym_DOLLARfatal] = ACTIONS(5176),
    [anon_sym_DOLLARerror] = ACTIONS(5176),
    [anon_sym_DOLLARwarning] = ACTIONS(5176),
    [anon_sym_DOLLARinfo] = ACTIONS(5176),
    [anon_sym_default] = ACTIONS(5178),
    [anon_sym_clocking] = ACTIONS(5178),
    [anon_sym_defparam] = ACTIONS(5178),
    [anon_sym_bind] = ACTIONS(5178),
    [anon_sym_rand] = ACTIONS(5178),
    [anon_sym_const] = ACTIONS(5178),
    [anon_sym_function] = ACTIONS(5178),
    [anon_sym_static] = ACTIONS(5178),
    [anon_sym_constraint] = ACTIONS(5178),
    [anon_sym_if] = ACTIONS(5178),
    [anon_sym_else] = ACTIONS(5178),
    [anon_sym_LBRACK] = ACTIONS(5176),
    [anon_sym_localparam] = ACTIONS(5178),
    [anon_sym_parameter] = ACTIONS(5178),
    [anon_sym_var] = ACTIONS(5178),
    [anon_sym_import] = ACTIONS(5178),
    [anon_sym_export] = ACTIONS(5178),
    [anon_sym_genvar] = ACTIONS(5178),
    [anon_sym_interconnect] = ACTIONS(5178),
    [anon_sym_typedef] = ACTIONS(5178),
    [anon_sym_enum] = ACTIONS(5178),
    [anon_sym_struct] = ACTIONS(5178),
    [anon_sym_union] = ACTIONS(5178),
    [anon_sym_nettype] = ACTIONS(5178),
    [anon_sym_automatic] = ACTIONS(5178),
    [anon_sym_string] = ACTIONS(5178),
    [anon_sym_chandle] = ACTIONS(5178),
    [anon_sym_event] = ACTIONS(5178),
    [anon_sym_byte] = ACTIONS(5178),
    [anon_sym_shortint] = ACTIONS(5178),
    [anon_sym_int] = ACTIONS(5178),
    [anon_sym_longint] = ACTIONS(5178),
    [anon_sym_integer] = ACTIONS(5178),
    [anon_sym_time] = ACTIONS(5178),
    [anon_sym_bit] = ACTIONS(5178),
    [anon_sym_logic] = ACTIONS(5178),
    [anon_sym_reg] = ACTIONS(5178),
    [anon_sym_shortreal] = ACTIONS(5178),
    [anon_sym_real] = ACTIONS(5178),
    [anon_sym_realtime] = ACTIONS(5178),
    [anon_sym_supply0] = ACTIONS(5178),
    [anon_sym_supply1] = ACTIONS(5178),
    [anon_sym_signed] = ACTIONS(5178),
    [anon_sym_unsigned] = ACTIONS(5178),
    [anon_sym_task] = ACTIONS(5178),
    [anon_sym_assert] = ACTIONS(5178),
    [anon_sym_property] = ACTIONS(5178),
    [anon_sym_assume] = ACTIONS(5178),
    [anon_sym_cover] = ACTIONS(5178),
    [anon_sym_sequence] = ACTIONS(5178),
    [anon_sym_restrict] = ACTIONS(5178),
    [anon_sym_not] = ACTIONS(5178),
    [anon_sym_or] = ACTIONS(5178),
    [anon_sym_and] = ACTIONS(5178),
    [anon_sym_case] = ACTIONS(5178),
    [anon_sym_always] = ACTIONS(5178),
    [anon_sym_covergroup] = ACTIONS(5178),
    [anon_sym_end] = ACTIONS(5178),
    [anon_sym_let] = ACTIONS(5178),
    [anon_sym_pulldown] = ACTIONS(5178),
    [anon_sym_pullup] = ACTIONS(5178),
    [anon_sym_cmos] = ACTIONS(5178),
    [anon_sym_rcmos] = ACTIONS(5178),
    [anon_sym_bufif0] = ACTIONS(5178),
    [anon_sym_bufif1] = ACTIONS(5178),
    [anon_sym_notif0] = ACTIONS(5178),
    [anon_sym_notif1] = ACTIONS(5178),
    [anon_sym_nmos] = ACTIONS(5178),
    [anon_sym_pmos] = ACTIONS(5178),
    [anon_sym_rnmos] = ACTIONS(5178),
    [anon_sym_rpmos] = ACTIONS(5178),
    [anon_sym_nand] = ACTIONS(5178),
    [anon_sym_nor] = ACTIONS(5178),
    [anon_sym_xor] = ACTIONS(5178),
    [anon_sym_xnor] = ACTIONS(5178),
    [anon_sym_buf] = ACTIONS(5178),
    [anon_sym_tranif0] = ACTIONS(5178),
    [anon_sym_tranif1] = ACTIONS(5178),
    [anon_sym_rtranif1] = ACTIONS(5178),
    [anon_sym_rtranif0] = ACTIONS(5178),
    [anon_sym_tran] = ACTIONS(5178),
    [anon_sym_rtran] = ACTIONS(5178),
    [anon_sym_generate] = ACTIONS(5178),
    [anon_sym_for] = ACTIONS(5178),
    [anon_sym_initial] = ACTIONS(5178),
    [anon_sym_assign] = ACTIONS(5178),
    [anon_sym_alias] = ACTIONS(5178),
    [anon_sym_always_comb] = ACTIONS(5178),
    [anon_sym_always_latch] = ACTIONS(5178),
    [anon_sym_always_ff] = ACTIONS(5178),
    [anon_sym_final] = ACTIONS(5178),
    [anon_sym_global] = ACTIONS(5178),
    [anon_sym_LPAREN_STAR] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5176),
    [anon_sym_DOLLARunit] = ACTIONS(5176),
  },
  [4767] = {
    [sym_simple_identifier] = ACTIONS(4948),
    [anon_sym_wire] = ACTIONS(4948),
    [anon_sym_tri] = ACTIONS(4948),
    [anon_sym_tri0] = ACTIONS(4948),
    [anon_sym_tri1] = ACTIONS(4948),
    [anon_sym_wand] = ACTIONS(4948),
    [anon_sym_triand] = ACTIONS(4948),
    [anon_sym_wor] = ACTIONS(4948),
    [anon_sym_trior] = ACTIONS(4948),
    [anon_sym_trireg] = ACTIONS(4948),
    [anon_sym_uwire] = ACTIONS(4948),
    [anon_sym_SEMI] = ACTIONS(4946),
    [anon_sym_extern] = ACTIONS(4948),
    [anon_sym_interface] = ACTIONS(4948),
    [anon_sym_checker] = ACTIONS(4948),
    [anon_sym_virtual] = ACTIONS(4948),
    [anon_sym_class] = ACTIONS(4948),
    [anon_sym_type] = ACTIONS(4948),
    [anon_sym_DOLLARfatal] = ACTIONS(4946),
    [anon_sym_DOLLARerror] = ACTIONS(4946),
    [anon_sym_DOLLARwarning] = ACTIONS(4946),
    [anon_sym_DOLLARinfo] = ACTIONS(4946),
    [anon_sym_default] = ACTIONS(4948),
    [anon_sym_clocking] = ACTIONS(4948),
    [anon_sym_defparam] = ACTIONS(4948),
    [anon_sym_bind] = ACTIONS(4948),
    [anon_sym_rand] = ACTIONS(4948),
    [anon_sym_const] = ACTIONS(4948),
    [anon_sym_function] = ACTIONS(4948),
    [anon_sym_static] = ACTIONS(4948),
    [anon_sym_constraint] = ACTIONS(4948),
    [anon_sym_if] = ACTIONS(4948),
    [anon_sym_else] = ACTIONS(4948),
    [anon_sym_LBRACK] = ACTIONS(4946),
    [anon_sym_localparam] = ACTIONS(4948),
    [anon_sym_parameter] = ACTIONS(4948),
    [anon_sym_var] = ACTIONS(4948),
    [anon_sym_import] = ACTIONS(4948),
    [anon_sym_export] = ACTIONS(4948),
    [anon_sym_genvar] = ACTIONS(4948),
    [anon_sym_interconnect] = ACTIONS(4948),
    [anon_sym_typedef] = ACTIONS(4948),
    [anon_sym_enum] = ACTIONS(4948),
    [anon_sym_struct] = ACTIONS(4948),
    [anon_sym_union] = ACTIONS(4948),
    [anon_sym_nettype] = ACTIONS(4948),
    [anon_sym_automatic] = ACTIONS(4948),
    [anon_sym_string] = ACTIONS(4948),
    [anon_sym_chandle] = ACTIONS(4948),
    [anon_sym_event] = ACTIONS(4948),
    [anon_sym_byte] = ACTIONS(4948),
    [anon_sym_shortint] = ACTIONS(4948),
    [anon_sym_int] = ACTIONS(4948),
    [anon_sym_longint] = ACTIONS(4948),
    [anon_sym_integer] = ACTIONS(4948),
    [anon_sym_time] = ACTIONS(4948),
    [anon_sym_bit] = ACTIONS(4948),
    [anon_sym_logic] = ACTIONS(4948),
    [anon_sym_reg] = ACTIONS(4948),
    [anon_sym_shortreal] = ACTIONS(4948),
    [anon_sym_real] = ACTIONS(4948),
    [anon_sym_realtime] = ACTIONS(4948),
    [anon_sym_supply0] = ACTIONS(4948),
    [anon_sym_supply1] = ACTIONS(4948),
    [anon_sym_signed] = ACTIONS(4948),
    [anon_sym_unsigned] = ACTIONS(4948),
    [anon_sym_task] = ACTIONS(4948),
    [anon_sym_assert] = ACTIONS(4948),
    [anon_sym_property] = ACTIONS(4948),
    [anon_sym_assume] = ACTIONS(4948),
    [anon_sym_cover] = ACTIONS(4948),
    [anon_sym_sequence] = ACTIONS(4948),
    [anon_sym_restrict] = ACTIONS(4948),
    [anon_sym_not] = ACTIONS(4948),
    [anon_sym_or] = ACTIONS(4948),
    [anon_sym_and] = ACTIONS(4948),
    [anon_sym_case] = ACTIONS(4948),
    [anon_sym_always] = ACTIONS(4948),
    [anon_sym_covergroup] = ACTIONS(4948),
    [anon_sym_let] = ACTIONS(4948),
    [anon_sym_pulldown] = ACTIONS(4948),
    [anon_sym_pullup] = ACTIONS(4948),
    [anon_sym_cmos] = ACTIONS(4948),
    [anon_sym_rcmos] = ACTIONS(4948),
    [anon_sym_bufif0] = ACTIONS(4948),
    [anon_sym_bufif1] = ACTIONS(4948),
    [anon_sym_notif0] = ACTIONS(4948),
    [anon_sym_notif1] = ACTIONS(4948),
    [anon_sym_nmos] = ACTIONS(4948),
    [anon_sym_pmos] = ACTIONS(4948),
    [anon_sym_rnmos] = ACTIONS(4948),
    [anon_sym_rpmos] = ACTIONS(4948),
    [anon_sym_nand] = ACTIONS(4948),
    [anon_sym_nor] = ACTIONS(4948),
    [anon_sym_xor] = ACTIONS(4948),
    [anon_sym_xnor] = ACTIONS(4948),
    [anon_sym_buf] = ACTIONS(4948),
    [anon_sym_tranif0] = ACTIONS(4948),
    [anon_sym_tranif1] = ACTIONS(4948),
    [anon_sym_rtranif1] = ACTIONS(4948),
    [anon_sym_rtranif0] = ACTIONS(4948),
    [anon_sym_tran] = ACTIONS(4948),
    [anon_sym_rtran] = ACTIONS(4948),
    [anon_sym_generate] = ACTIONS(4948),
    [anon_sym_endgenerate] = ACTIONS(4948),
    [anon_sym_for] = ACTIONS(4948),
    [anon_sym_initial] = ACTIONS(4948),
    [anon_sym_assign] = ACTIONS(4948),
    [anon_sym_alias] = ACTIONS(4948),
    [anon_sym_always_comb] = ACTIONS(4948),
    [anon_sym_always_latch] = ACTIONS(4948),
    [anon_sym_always_ff] = ACTIONS(4948),
    [anon_sym_final] = ACTIONS(4948),
    [anon_sym_global] = ACTIONS(4948),
    [anon_sym_LPAREN_STAR] = ACTIONS(4946),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4946),
    [anon_sym_DOLLARunit] = ACTIONS(4946),
  },
  [4768] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_rand] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(5965),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_end] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [4769] = {
    [sym_simple_identifier] = ACTIONS(6783),
    [anon_sym_wire] = ACTIONS(6783),
    [anon_sym_tri] = ACTIONS(6783),
    [anon_sym_tri0] = ACTIONS(6783),
    [anon_sym_tri1] = ACTIONS(6783),
    [anon_sym_wand] = ACTIONS(6783),
    [anon_sym_triand] = ACTIONS(6783),
    [anon_sym_wor] = ACTIONS(6783),
    [anon_sym_trior] = ACTIONS(6783),
    [anon_sym_trireg] = ACTIONS(6783),
    [anon_sym_uwire] = ACTIONS(6783),
    [anon_sym_SEMI] = ACTIONS(6786),
    [anon_sym_extern] = ACTIONS(6783),
    [anon_sym_interface] = ACTIONS(6783),
    [anon_sym_checker] = ACTIONS(6783),
    [anon_sym_virtual] = ACTIONS(6783),
    [anon_sym_class] = ACTIONS(6783),
    [anon_sym_type] = ACTIONS(6783),
    [anon_sym_DOLLARfatal] = ACTIONS(6786),
    [anon_sym_DOLLARerror] = ACTIONS(6786),
    [anon_sym_DOLLARwarning] = ACTIONS(6786),
    [anon_sym_DOLLARinfo] = ACTIONS(6786),
    [anon_sym_default] = ACTIONS(6783),
    [anon_sym_clocking] = ACTIONS(6783),
    [anon_sym_defparam] = ACTIONS(6783),
    [anon_sym_bind] = ACTIONS(6783),
    [anon_sym_rand] = ACTIONS(6783),
    [anon_sym_const] = ACTIONS(6783),
    [anon_sym_function] = ACTIONS(6783),
    [anon_sym_static] = ACTIONS(6783),
    [anon_sym_constraint] = ACTIONS(6783),
    [anon_sym_if] = ACTIONS(6783),
    [anon_sym_else] = ACTIONS(6783),
    [anon_sym_LBRACK] = ACTIONS(6786),
    [anon_sym_localparam] = ACTIONS(6783),
    [anon_sym_parameter] = ACTIONS(6783),
    [anon_sym_var] = ACTIONS(6783),
    [anon_sym_import] = ACTIONS(6783),
    [anon_sym_export] = ACTIONS(6783),
    [anon_sym_genvar] = ACTIONS(6783),
    [anon_sym_interconnect] = ACTIONS(6783),
    [anon_sym_typedef] = ACTIONS(6783),
    [anon_sym_enum] = ACTIONS(6783),
    [anon_sym_struct] = ACTIONS(6783),
    [anon_sym_union] = ACTIONS(6783),
    [anon_sym_nettype] = ACTIONS(6783),
    [anon_sym_automatic] = ACTIONS(6783),
    [anon_sym_string] = ACTIONS(6783),
    [anon_sym_chandle] = ACTIONS(6783),
    [anon_sym_event] = ACTIONS(6783),
    [anon_sym_byte] = ACTIONS(6783),
    [anon_sym_shortint] = ACTIONS(6783),
    [anon_sym_int] = ACTIONS(6783),
    [anon_sym_longint] = ACTIONS(6783),
    [anon_sym_integer] = ACTIONS(6783),
    [anon_sym_time] = ACTIONS(6783),
    [anon_sym_bit] = ACTIONS(6783),
    [anon_sym_logic] = ACTIONS(6783),
    [anon_sym_reg] = ACTIONS(6783),
    [anon_sym_shortreal] = ACTIONS(6783),
    [anon_sym_real] = ACTIONS(6783),
    [anon_sym_realtime] = ACTIONS(6783),
    [anon_sym_supply0] = ACTIONS(6783),
    [anon_sym_supply1] = ACTIONS(6783),
    [anon_sym_signed] = ACTIONS(6783),
    [anon_sym_unsigned] = ACTIONS(6783),
    [anon_sym_task] = ACTIONS(6783),
    [anon_sym_assert] = ACTIONS(6783),
    [anon_sym_property] = ACTIONS(6783),
    [anon_sym_assume] = ACTIONS(6783),
    [anon_sym_cover] = ACTIONS(6783),
    [anon_sym_sequence] = ACTIONS(6783),
    [anon_sym_restrict] = ACTIONS(6783),
    [anon_sym_not] = ACTIONS(6783),
    [anon_sym_or] = ACTIONS(6783),
    [anon_sym_and] = ACTIONS(6783),
    [anon_sym_case] = ACTIONS(6783),
    [anon_sym_always] = ACTIONS(6783),
    [anon_sym_covergroup] = ACTIONS(6783),
    [anon_sym_let] = ACTIONS(6783),
    [anon_sym_pulldown] = ACTIONS(6783),
    [anon_sym_pullup] = ACTIONS(6783),
    [anon_sym_cmos] = ACTIONS(6783),
    [anon_sym_rcmos] = ACTIONS(6783),
    [anon_sym_bufif0] = ACTIONS(6783),
    [anon_sym_bufif1] = ACTIONS(6783),
    [anon_sym_notif0] = ACTIONS(6783),
    [anon_sym_notif1] = ACTIONS(6783),
    [anon_sym_nmos] = ACTIONS(6783),
    [anon_sym_pmos] = ACTIONS(6783),
    [anon_sym_rnmos] = ACTIONS(6783),
    [anon_sym_rpmos] = ACTIONS(6783),
    [anon_sym_nand] = ACTIONS(6783),
    [anon_sym_nor] = ACTIONS(6783),
    [anon_sym_xor] = ACTIONS(6783),
    [anon_sym_xnor] = ACTIONS(6783),
    [anon_sym_buf] = ACTIONS(6783),
    [anon_sym_tranif0] = ACTIONS(6783),
    [anon_sym_tranif1] = ACTIONS(6783),
    [anon_sym_rtranif1] = ACTIONS(6783),
    [anon_sym_rtranif0] = ACTIONS(6783),
    [anon_sym_tran] = ACTIONS(6783),
    [anon_sym_rtran] = ACTIONS(6783),
    [anon_sym_generate] = ACTIONS(6783),
    [anon_sym_endgenerate] = ACTIONS(6783),
    [anon_sym_for] = ACTIONS(6783),
    [anon_sym_initial] = ACTIONS(6783),
    [anon_sym_assign] = ACTIONS(6783),
    [anon_sym_alias] = ACTIONS(6783),
    [anon_sym_always_comb] = ACTIONS(6783),
    [anon_sym_always_latch] = ACTIONS(6783),
    [anon_sym_always_ff] = ACTIONS(6783),
    [anon_sym_final] = ACTIONS(6783),
    [anon_sym_global] = ACTIONS(6783),
    [anon_sym_LPAREN_STAR] = ACTIONS(6786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6786),
    [anon_sym_DOLLARunit] = ACTIONS(6786),
  },
  [4770] = {
    [sym_simple_identifier] = ACTIONS(5600),
    [anon_sym_wire] = ACTIONS(5600),
    [anon_sym_tri] = ACTIONS(5600),
    [anon_sym_tri0] = ACTIONS(5600),
    [anon_sym_tri1] = ACTIONS(5600),
    [anon_sym_wand] = ACTIONS(5600),
    [anon_sym_triand] = ACTIONS(5600),
    [anon_sym_wor] = ACTIONS(5600),
    [anon_sym_trior] = ACTIONS(5600),
    [anon_sym_trireg] = ACTIONS(5600),
    [anon_sym_uwire] = ACTIONS(5600),
    [anon_sym_SEMI] = ACTIONS(5602),
    [anon_sym_extern] = ACTIONS(5600),
    [anon_sym_interface] = ACTIONS(5600),
    [anon_sym_checker] = ACTIONS(5600),
    [anon_sym_virtual] = ACTIONS(5600),
    [anon_sym_class] = ACTIONS(5600),
    [anon_sym_type] = ACTIONS(5600),
    [anon_sym_DOLLARfatal] = ACTIONS(5602),
    [anon_sym_DOLLARerror] = ACTIONS(5602),
    [anon_sym_DOLLARwarning] = ACTIONS(5602),
    [anon_sym_DOLLARinfo] = ACTIONS(5602),
    [anon_sym_default] = ACTIONS(5600),
    [anon_sym_clocking] = ACTIONS(5600),
    [anon_sym_defparam] = ACTIONS(5600),
    [anon_sym_bind] = ACTIONS(5600),
    [anon_sym_rand] = ACTIONS(5600),
    [anon_sym_const] = ACTIONS(5600),
    [anon_sym_function] = ACTIONS(5600),
    [anon_sym_static] = ACTIONS(5600),
    [anon_sym_constraint] = ACTIONS(5600),
    [anon_sym_if] = ACTIONS(5600),
    [anon_sym_else] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5602),
    [anon_sym_localparam] = ACTIONS(5600),
    [anon_sym_parameter] = ACTIONS(5600),
    [anon_sym_var] = ACTIONS(5600),
    [anon_sym_import] = ACTIONS(5600),
    [anon_sym_export] = ACTIONS(5600),
    [anon_sym_genvar] = ACTIONS(5600),
    [anon_sym_interconnect] = ACTIONS(5600),
    [anon_sym_typedef] = ACTIONS(5600),
    [anon_sym_enum] = ACTIONS(5600),
    [anon_sym_struct] = ACTIONS(5600),
    [anon_sym_union] = ACTIONS(5600),
    [anon_sym_nettype] = ACTIONS(5600),
    [anon_sym_automatic] = ACTIONS(5600),
    [anon_sym_string] = ACTIONS(5600),
    [anon_sym_chandle] = ACTIONS(5600),
    [anon_sym_event] = ACTIONS(5600),
    [anon_sym_byte] = ACTIONS(5600),
    [anon_sym_shortint] = ACTIONS(5600),
    [anon_sym_int] = ACTIONS(5600),
    [anon_sym_longint] = ACTIONS(5600),
    [anon_sym_integer] = ACTIONS(5600),
    [anon_sym_time] = ACTIONS(5600),
    [anon_sym_bit] = ACTIONS(5600),
    [anon_sym_logic] = ACTIONS(5600),
    [anon_sym_reg] = ACTIONS(5600),
    [anon_sym_shortreal] = ACTIONS(5600),
    [anon_sym_real] = ACTIONS(5600),
    [anon_sym_realtime] = ACTIONS(5600),
    [anon_sym_supply0] = ACTIONS(5600),
    [anon_sym_supply1] = ACTIONS(5600),
    [anon_sym_signed] = ACTIONS(5600),
    [anon_sym_unsigned] = ACTIONS(5600),
    [anon_sym_task] = ACTIONS(5600),
    [anon_sym_assert] = ACTIONS(5600),
    [anon_sym_property] = ACTIONS(5600),
    [anon_sym_assume] = ACTIONS(5600),
    [anon_sym_cover] = ACTIONS(5600),
    [anon_sym_sequence] = ACTIONS(5600),
    [anon_sym_restrict] = ACTIONS(5600),
    [anon_sym_not] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_case] = ACTIONS(5600),
    [anon_sym_always] = ACTIONS(5600),
    [anon_sym_covergroup] = ACTIONS(5600),
    [anon_sym_end] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_pulldown] = ACTIONS(5600),
    [anon_sym_pullup] = ACTIONS(5600),
    [anon_sym_cmos] = ACTIONS(5600),
    [anon_sym_rcmos] = ACTIONS(5600),
    [anon_sym_bufif0] = ACTIONS(5600),
    [anon_sym_bufif1] = ACTIONS(5600),
    [anon_sym_notif0] = ACTIONS(5600),
    [anon_sym_notif1] = ACTIONS(5600),
    [anon_sym_nmos] = ACTIONS(5600),
    [anon_sym_pmos] = ACTIONS(5600),
    [anon_sym_rnmos] = ACTIONS(5600),
    [anon_sym_rpmos] = ACTIONS(5600),
    [anon_sym_nand] = ACTIONS(5600),
    [anon_sym_nor] = ACTIONS(5600),
    [anon_sym_xor] = ACTIONS(5600),
    [anon_sym_xnor] = ACTIONS(5600),
    [anon_sym_buf] = ACTIONS(5600),
    [anon_sym_tranif0] = ACTIONS(5600),
    [anon_sym_tranif1] = ACTIONS(5600),
    [anon_sym_rtranif1] = ACTIONS(5600),
    [anon_sym_rtranif0] = ACTIONS(5600),
    [anon_sym_tran] = ACTIONS(5600),
    [anon_sym_rtran] = ACTIONS(5600),
    [anon_sym_generate] = ACTIONS(5600),
    [anon_sym_for] = ACTIONS(5600),
    [anon_sym_initial] = ACTIONS(5600),
    [anon_sym_assign] = ACTIONS(5600),
    [anon_sym_alias] = ACTIONS(5600),
    [anon_sym_always_comb] = ACTIONS(5600),
    [anon_sym_always_latch] = ACTIONS(5600),
    [anon_sym_always_ff] = ACTIONS(5600),
    [anon_sym_final] = ACTIONS(5600),
    [anon_sym_global] = ACTIONS(5600),
    [anon_sym_LPAREN_STAR] = ACTIONS(5602),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5602),
    [anon_sym_DOLLARunit] = ACTIONS(5602),
  },
  [4771] = {
    [sym_simple_identifier] = ACTIONS(5880),
    [anon_sym_wire] = ACTIONS(5880),
    [anon_sym_tri] = ACTIONS(5880),
    [anon_sym_tri0] = ACTIONS(5880),
    [anon_sym_tri1] = ACTIONS(5880),
    [anon_sym_wand] = ACTIONS(5880),
    [anon_sym_triand] = ACTIONS(5880),
    [anon_sym_wor] = ACTIONS(5880),
    [anon_sym_trior] = ACTIONS(5880),
    [anon_sym_trireg] = ACTIONS(5880),
    [anon_sym_uwire] = ACTIONS(5880),
    [anon_sym_SEMI] = ACTIONS(5882),
    [anon_sym_extern] = ACTIONS(5880),
    [anon_sym_interface] = ACTIONS(5880),
    [anon_sym_checker] = ACTIONS(5880),
    [anon_sym_virtual] = ACTIONS(5880),
    [anon_sym_class] = ACTIONS(5880),
    [anon_sym_type] = ACTIONS(5880),
    [anon_sym_DOLLARfatal] = ACTIONS(5882),
    [anon_sym_DOLLARerror] = ACTIONS(5882),
    [anon_sym_DOLLARwarning] = ACTIONS(5882),
    [anon_sym_DOLLARinfo] = ACTIONS(5882),
    [anon_sym_default] = ACTIONS(5880),
    [anon_sym_clocking] = ACTIONS(5880),
    [anon_sym_defparam] = ACTIONS(5880),
    [anon_sym_bind] = ACTIONS(5880),
    [anon_sym_rand] = ACTIONS(5880),
    [anon_sym_const] = ACTIONS(5880),
    [anon_sym_function] = ACTIONS(5880),
    [anon_sym_static] = ACTIONS(5880),
    [anon_sym_constraint] = ACTIONS(5880),
    [anon_sym_if] = ACTIONS(5880),
    [anon_sym_else] = ACTIONS(5880),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_localparam] = ACTIONS(5880),
    [anon_sym_parameter] = ACTIONS(5880),
    [anon_sym_var] = ACTIONS(5880),
    [anon_sym_import] = ACTIONS(5880),
    [anon_sym_export] = ACTIONS(5880),
    [anon_sym_genvar] = ACTIONS(5880),
    [anon_sym_interconnect] = ACTIONS(5880),
    [anon_sym_typedef] = ACTIONS(5880),
    [anon_sym_enum] = ACTIONS(5880),
    [anon_sym_struct] = ACTIONS(5880),
    [anon_sym_union] = ACTIONS(5880),
    [anon_sym_nettype] = ACTIONS(5880),
    [anon_sym_automatic] = ACTIONS(5880),
    [anon_sym_string] = ACTIONS(5880),
    [anon_sym_chandle] = ACTIONS(5880),
    [anon_sym_event] = ACTIONS(5880),
    [anon_sym_byte] = ACTIONS(5880),
    [anon_sym_shortint] = ACTIONS(5880),
    [anon_sym_int] = ACTIONS(5880),
    [anon_sym_longint] = ACTIONS(5880),
    [anon_sym_integer] = ACTIONS(5880),
    [anon_sym_time] = ACTIONS(5880),
    [anon_sym_bit] = ACTIONS(5880),
    [anon_sym_logic] = ACTIONS(5880),
    [anon_sym_reg] = ACTIONS(5880),
    [anon_sym_shortreal] = ACTIONS(5880),
    [anon_sym_real] = ACTIONS(5880),
    [anon_sym_realtime] = ACTIONS(5880),
    [anon_sym_supply0] = ACTIONS(5880),
    [anon_sym_supply1] = ACTIONS(5880),
    [anon_sym_signed] = ACTIONS(5880),
    [anon_sym_unsigned] = ACTIONS(5880),
    [anon_sym_task] = ACTIONS(5880),
    [anon_sym_assert] = ACTIONS(5880),
    [anon_sym_property] = ACTIONS(5880),
    [anon_sym_assume] = ACTIONS(5880),
    [anon_sym_cover] = ACTIONS(5880),
    [anon_sym_sequence] = ACTIONS(5880),
    [anon_sym_restrict] = ACTIONS(5880),
    [anon_sym_not] = ACTIONS(5880),
    [anon_sym_or] = ACTIONS(5880),
    [anon_sym_and] = ACTIONS(5880),
    [anon_sym_case] = ACTIONS(5880),
    [anon_sym_always] = ACTIONS(5880),
    [anon_sym_covergroup] = ACTIONS(5880),
    [anon_sym_end] = ACTIONS(5880),
    [anon_sym_let] = ACTIONS(5880),
    [anon_sym_pulldown] = ACTIONS(5880),
    [anon_sym_pullup] = ACTIONS(5880),
    [anon_sym_cmos] = ACTIONS(5880),
    [anon_sym_rcmos] = ACTIONS(5880),
    [anon_sym_bufif0] = ACTIONS(5880),
    [anon_sym_bufif1] = ACTIONS(5880),
    [anon_sym_notif0] = ACTIONS(5880),
    [anon_sym_notif1] = ACTIONS(5880),
    [anon_sym_nmos] = ACTIONS(5880),
    [anon_sym_pmos] = ACTIONS(5880),
    [anon_sym_rnmos] = ACTIONS(5880),
    [anon_sym_rpmos] = ACTIONS(5880),
    [anon_sym_nand] = ACTIONS(5880),
    [anon_sym_nor] = ACTIONS(5880),
    [anon_sym_xor] = ACTIONS(5880),
    [anon_sym_xnor] = ACTIONS(5880),
    [anon_sym_buf] = ACTIONS(5880),
    [anon_sym_tranif0] = ACTIONS(5880),
    [anon_sym_tranif1] = ACTIONS(5880),
    [anon_sym_rtranif1] = ACTIONS(5880),
    [anon_sym_rtranif0] = ACTIONS(5880),
    [anon_sym_tran] = ACTIONS(5880),
    [anon_sym_rtran] = ACTIONS(5880),
    [anon_sym_generate] = ACTIONS(5880),
    [anon_sym_for] = ACTIONS(5880),
    [anon_sym_initial] = ACTIONS(5880),
    [anon_sym_assign] = ACTIONS(5880),
    [anon_sym_alias] = ACTIONS(5880),
    [anon_sym_always_comb] = ACTIONS(5880),
    [anon_sym_always_latch] = ACTIONS(5880),
    [anon_sym_always_ff] = ACTIONS(5880),
    [anon_sym_final] = ACTIONS(5880),
    [anon_sym_global] = ACTIONS(5880),
    [anon_sym_LPAREN_STAR] = ACTIONS(5882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5882),
    [anon_sym_DOLLARunit] = ACTIONS(5882),
  },
  [4772] = {
    [sym_simple_identifier] = ACTIONS(6019),
    [anon_sym_wire] = ACTIONS(6019),
    [anon_sym_tri] = ACTIONS(6019),
    [anon_sym_tri0] = ACTIONS(6019),
    [anon_sym_tri1] = ACTIONS(6019),
    [anon_sym_wand] = ACTIONS(6019),
    [anon_sym_triand] = ACTIONS(6019),
    [anon_sym_wor] = ACTIONS(6019),
    [anon_sym_trior] = ACTIONS(6019),
    [anon_sym_trireg] = ACTIONS(6019),
    [anon_sym_uwire] = ACTIONS(6019),
    [anon_sym_SEMI] = ACTIONS(6021),
    [anon_sym_extern] = ACTIONS(6019),
    [anon_sym_interface] = ACTIONS(6019),
    [anon_sym_checker] = ACTIONS(6019),
    [anon_sym_virtual] = ACTIONS(6019),
    [anon_sym_class] = ACTIONS(6019),
    [anon_sym_type] = ACTIONS(6019),
    [anon_sym_DOLLARfatal] = ACTIONS(6021),
    [anon_sym_DOLLARerror] = ACTIONS(6021),
    [anon_sym_DOLLARwarning] = ACTIONS(6021),
    [anon_sym_DOLLARinfo] = ACTIONS(6021),
    [anon_sym_default] = ACTIONS(6019),
    [anon_sym_clocking] = ACTIONS(6019),
    [anon_sym_defparam] = ACTIONS(6019),
    [anon_sym_bind] = ACTIONS(6019),
    [anon_sym_rand] = ACTIONS(6019),
    [anon_sym_const] = ACTIONS(6019),
    [anon_sym_function] = ACTIONS(6019),
    [anon_sym_static] = ACTIONS(6019),
    [anon_sym_constraint] = ACTIONS(6019),
    [anon_sym_if] = ACTIONS(6019),
    [anon_sym_else] = ACTIONS(6019),
    [anon_sym_LBRACK] = ACTIONS(6021),
    [anon_sym_localparam] = ACTIONS(6019),
    [anon_sym_parameter] = ACTIONS(6019),
    [anon_sym_var] = ACTIONS(6019),
    [anon_sym_import] = ACTIONS(6019),
    [anon_sym_export] = ACTIONS(6019),
    [anon_sym_genvar] = ACTIONS(6019),
    [anon_sym_interconnect] = ACTIONS(6019),
    [anon_sym_typedef] = ACTIONS(6019),
    [anon_sym_enum] = ACTIONS(6019),
    [anon_sym_struct] = ACTIONS(6019),
    [anon_sym_union] = ACTIONS(6019),
    [anon_sym_nettype] = ACTIONS(6019),
    [anon_sym_automatic] = ACTIONS(6019),
    [anon_sym_string] = ACTIONS(6019),
    [anon_sym_chandle] = ACTIONS(6019),
    [anon_sym_event] = ACTIONS(6019),
    [anon_sym_byte] = ACTIONS(6019),
    [anon_sym_shortint] = ACTIONS(6019),
    [anon_sym_int] = ACTIONS(6019),
    [anon_sym_longint] = ACTIONS(6019),
    [anon_sym_integer] = ACTIONS(6019),
    [anon_sym_time] = ACTIONS(6019),
    [anon_sym_bit] = ACTIONS(6019),
    [anon_sym_logic] = ACTIONS(6019),
    [anon_sym_reg] = ACTIONS(6019),
    [anon_sym_shortreal] = ACTIONS(6019),
    [anon_sym_real] = ACTIONS(6019),
    [anon_sym_realtime] = ACTIONS(6019),
    [anon_sym_supply0] = ACTIONS(6019),
    [anon_sym_supply1] = ACTIONS(6019),
    [anon_sym_signed] = ACTIONS(6019),
    [anon_sym_unsigned] = ACTIONS(6019),
    [anon_sym_task] = ACTIONS(6019),
    [anon_sym_assert] = ACTIONS(6019),
    [anon_sym_property] = ACTIONS(6019),
    [anon_sym_assume] = ACTIONS(6019),
    [anon_sym_cover] = ACTIONS(6019),
    [anon_sym_sequence] = ACTIONS(6019),
    [anon_sym_restrict] = ACTIONS(6019),
    [anon_sym_not] = ACTIONS(6019),
    [anon_sym_or] = ACTIONS(6019),
    [anon_sym_and] = ACTIONS(6019),
    [anon_sym_case] = ACTIONS(6019),
    [anon_sym_always] = ACTIONS(6019),
    [anon_sym_covergroup] = ACTIONS(6019),
    [anon_sym_end] = ACTIONS(6019),
    [anon_sym_let] = ACTIONS(6019),
    [anon_sym_pulldown] = ACTIONS(6019),
    [anon_sym_pullup] = ACTIONS(6019),
    [anon_sym_cmos] = ACTIONS(6019),
    [anon_sym_rcmos] = ACTIONS(6019),
    [anon_sym_bufif0] = ACTIONS(6019),
    [anon_sym_bufif1] = ACTIONS(6019),
    [anon_sym_notif0] = ACTIONS(6019),
    [anon_sym_notif1] = ACTIONS(6019),
    [anon_sym_nmos] = ACTIONS(6019),
    [anon_sym_pmos] = ACTIONS(6019),
    [anon_sym_rnmos] = ACTIONS(6019),
    [anon_sym_rpmos] = ACTIONS(6019),
    [anon_sym_nand] = ACTIONS(6019),
    [anon_sym_nor] = ACTIONS(6019),
    [anon_sym_xor] = ACTIONS(6019),
    [anon_sym_xnor] = ACTIONS(6019),
    [anon_sym_buf] = ACTIONS(6019),
    [anon_sym_tranif0] = ACTIONS(6019),
    [anon_sym_tranif1] = ACTIONS(6019),
    [anon_sym_rtranif1] = ACTIONS(6019),
    [anon_sym_rtranif0] = ACTIONS(6019),
    [anon_sym_tran] = ACTIONS(6019),
    [anon_sym_rtran] = ACTIONS(6019),
    [anon_sym_generate] = ACTIONS(6019),
    [anon_sym_for] = ACTIONS(6019),
    [anon_sym_initial] = ACTIONS(6019),
    [anon_sym_assign] = ACTIONS(6019),
    [anon_sym_alias] = ACTIONS(6019),
    [anon_sym_always_comb] = ACTIONS(6019),
    [anon_sym_always_latch] = ACTIONS(6019),
    [anon_sym_always_ff] = ACTIONS(6019),
    [anon_sym_final] = ACTIONS(6019),
    [anon_sym_global] = ACTIONS(6019),
    [anon_sym_LPAREN_STAR] = ACTIONS(6021),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6021),
    [anon_sym_DOLLARunit] = ACTIONS(6021),
  },
  [4773] = {
    [sym_simple_identifier] = ACTIONS(5884),
    [anon_sym_wire] = ACTIONS(5884),
    [anon_sym_tri] = ACTIONS(5884),
    [anon_sym_tri0] = ACTIONS(5884),
    [anon_sym_tri1] = ACTIONS(5884),
    [anon_sym_wand] = ACTIONS(5884),
    [anon_sym_triand] = ACTIONS(5884),
    [anon_sym_wor] = ACTIONS(5884),
    [anon_sym_trior] = ACTIONS(5884),
    [anon_sym_trireg] = ACTIONS(5884),
    [anon_sym_uwire] = ACTIONS(5884),
    [anon_sym_SEMI] = ACTIONS(5886),
    [anon_sym_extern] = ACTIONS(5884),
    [anon_sym_interface] = ACTIONS(5884),
    [anon_sym_checker] = ACTIONS(5884),
    [anon_sym_virtual] = ACTIONS(5884),
    [anon_sym_class] = ACTIONS(5884),
    [anon_sym_type] = ACTIONS(5884),
    [anon_sym_DOLLARfatal] = ACTIONS(5886),
    [anon_sym_DOLLARerror] = ACTIONS(5886),
    [anon_sym_DOLLARwarning] = ACTIONS(5886),
    [anon_sym_DOLLARinfo] = ACTIONS(5886),
    [anon_sym_default] = ACTIONS(5884),
    [anon_sym_clocking] = ACTIONS(5884),
    [anon_sym_defparam] = ACTIONS(5884),
    [anon_sym_bind] = ACTIONS(5884),
    [anon_sym_rand] = ACTIONS(5884),
    [anon_sym_const] = ACTIONS(5884),
    [anon_sym_function] = ACTIONS(5884),
    [anon_sym_static] = ACTIONS(5884),
    [anon_sym_constraint] = ACTIONS(5884),
    [anon_sym_if] = ACTIONS(5884),
    [anon_sym_else] = ACTIONS(5884),
    [anon_sym_LBRACK] = ACTIONS(5886),
    [anon_sym_localparam] = ACTIONS(5884),
    [anon_sym_parameter] = ACTIONS(5884),
    [anon_sym_var] = ACTIONS(5884),
    [anon_sym_import] = ACTIONS(5884),
    [anon_sym_export] = ACTIONS(5884),
    [anon_sym_genvar] = ACTIONS(5884),
    [anon_sym_interconnect] = ACTIONS(5884),
    [anon_sym_typedef] = ACTIONS(5884),
    [anon_sym_enum] = ACTIONS(5884),
    [anon_sym_struct] = ACTIONS(5884),
    [anon_sym_union] = ACTIONS(5884),
    [anon_sym_nettype] = ACTIONS(5884),
    [anon_sym_automatic] = ACTIONS(5884),
    [anon_sym_string] = ACTIONS(5884),
    [anon_sym_chandle] = ACTIONS(5884),
    [anon_sym_event] = ACTIONS(5884),
    [anon_sym_byte] = ACTIONS(5884),
    [anon_sym_shortint] = ACTIONS(5884),
    [anon_sym_int] = ACTIONS(5884),
    [anon_sym_longint] = ACTIONS(5884),
    [anon_sym_integer] = ACTIONS(5884),
    [anon_sym_time] = ACTIONS(5884),
    [anon_sym_bit] = ACTIONS(5884),
    [anon_sym_logic] = ACTIONS(5884),
    [anon_sym_reg] = ACTIONS(5884),
    [anon_sym_shortreal] = ACTIONS(5884),
    [anon_sym_real] = ACTIONS(5884),
    [anon_sym_realtime] = ACTIONS(5884),
    [anon_sym_supply0] = ACTIONS(5884),
    [anon_sym_supply1] = ACTIONS(5884),
    [anon_sym_signed] = ACTIONS(5884),
    [anon_sym_unsigned] = ACTIONS(5884),
    [anon_sym_task] = ACTIONS(5884),
    [anon_sym_assert] = ACTIONS(5884),
    [anon_sym_property] = ACTIONS(5884),
    [anon_sym_assume] = ACTIONS(5884),
    [anon_sym_cover] = ACTIONS(5884),
    [anon_sym_sequence] = ACTIONS(5884),
    [anon_sym_restrict] = ACTIONS(5884),
    [anon_sym_not] = ACTIONS(5884),
    [anon_sym_or] = ACTIONS(5884),
    [anon_sym_and] = ACTIONS(5884),
    [anon_sym_case] = ACTIONS(5884),
    [anon_sym_always] = ACTIONS(5884),
    [anon_sym_covergroup] = ACTIONS(5884),
    [anon_sym_end] = ACTIONS(5884),
    [anon_sym_let] = ACTIONS(5884),
    [anon_sym_pulldown] = ACTIONS(5884),
    [anon_sym_pullup] = ACTIONS(5884),
    [anon_sym_cmos] = ACTIONS(5884),
    [anon_sym_rcmos] = ACTIONS(5884),
    [anon_sym_bufif0] = ACTIONS(5884),
    [anon_sym_bufif1] = ACTIONS(5884),
    [anon_sym_notif0] = ACTIONS(5884),
    [anon_sym_notif1] = ACTIONS(5884),
    [anon_sym_nmos] = ACTIONS(5884),
    [anon_sym_pmos] = ACTIONS(5884),
    [anon_sym_rnmos] = ACTIONS(5884),
    [anon_sym_rpmos] = ACTIONS(5884),
    [anon_sym_nand] = ACTIONS(5884),
    [anon_sym_nor] = ACTIONS(5884),
    [anon_sym_xor] = ACTIONS(5884),
    [anon_sym_xnor] = ACTIONS(5884),
    [anon_sym_buf] = ACTIONS(5884),
    [anon_sym_tranif0] = ACTIONS(5884),
    [anon_sym_tranif1] = ACTIONS(5884),
    [anon_sym_rtranif1] = ACTIONS(5884),
    [anon_sym_rtranif0] = ACTIONS(5884),
    [anon_sym_tran] = ACTIONS(5884),
    [anon_sym_rtran] = ACTIONS(5884),
    [anon_sym_generate] = ACTIONS(5884),
    [anon_sym_for] = ACTIONS(5884),
    [anon_sym_initial] = ACTIONS(5884),
    [anon_sym_assign] = ACTIONS(5884),
    [anon_sym_alias] = ACTIONS(5884),
    [anon_sym_always_comb] = ACTIONS(5884),
    [anon_sym_always_latch] = ACTIONS(5884),
    [anon_sym_always_ff] = ACTIONS(5884),
    [anon_sym_final] = ACTIONS(5884),
    [anon_sym_global] = ACTIONS(5884),
    [anon_sym_LPAREN_STAR] = ACTIONS(5886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5886),
    [anon_sym_DOLLARunit] = ACTIONS(5886),
  },
  [4774] = {
    [sym_simple_identifier] = ACTIONS(5246),
    [anon_sym_wire] = ACTIONS(5246),
    [anon_sym_tri] = ACTIONS(5246),
    [anon_sym_tri0] = ACTIONS(5246),
    [anon_sym_tri1] = ACTIONS(5246),
    [anon_sym_wand] = ACTIONS(5246),
    [anon_sym_triand] = ACTIONS(5246),
    [anon_sym_wor] = ACTIONS(5246),
    [anon_sym_trior] = ACTIONS(5246),
    [anon_sym_trireg] = ACTIONS(5246),
    [anon_sym_uwire] = ACTIONS(5246),
    [anon_sym_SEMI] = ACTIONS(5244),
    [anon_sym_extern] = ACTIONS(5246),
    [anon_sym_interface] = ACTIONS(5246),
    [anon_sym_checker] = ACTIONS(5246),
    [anon_sym_virtual] = ACTIONS(5246),
    [anon_sym_class] = ACTIONS(5246),
    [anon_sym_type] = ACTIONS(5246),
    [anon_sym_DOLLARfatal] = ACTIONS(5244),
    [anon_sym_DOLLARerror] = ACTIONS(5244),
    [anon_sym_DOLLARwarning] = ACTIONS(5244),
    [anon_sym_DOLLARinfo] = ACTIONS(5244),
    [anon_sym_default] = ACTIONS(5246),
    [anon_sym_clocking] = ACTIONS(5246),
    [anon_sym_defparam] = ACTIONS(5246),
    [anon_sym_bind] = ACTIONS(5246),
    [anon_sym_rand] = ACTIONS(5246),
    [anon_sym_const] = ACTIONS(5246),
    [anon_sym_function] = ACTIONS(5246),
    [anon_sym_static] = ACTIONS(5246),
    [anon_sym_constraint] = ACTIONS(5246),
    [anon_sym_if] = ACTIONS(5246),
    [anon_sym_else] = ACTIONS(5246),
    [anon_sym_LBRACK] = ACTIONS(5244),
    [anon_sym_localparam] = ACTIONS(5246),
    [anon_sym_parameter] = ACTIONS(5246),
    [anon_sym_var] = ACTIONS(5246),
    [anon_sym_import] = ACTIONS(5246),
    [anon_sym_export] = ACTIONS(5246),
    [anon_sym_genvar] = ACTIONS(5246),
    [anon_sym_interconnect] = ACTIONS(5246),
    [anon_sym_typedef] = ACTIONS(5246),
    [anon_sym_enum] = ACTIONS(5246),
    [anon_sym_struct] = ACTIONS(5246),
    [anon_sym_union] = ACTIONS(5246),
    [anon_sym_nettype] = ACTIONS(5246),
    [anon_sym_automatic] = ACTIONS(5246),
    [anon_sym_string] = ACTIONS(5246),
    [anon_sym_chandle] = ACTIONS(5246),
    [anon_sym_event] = ACTIONS(5246),
    [anon_sym_byte] = ACTIONS(5246),
    [anon_sym_shortint] = ACTIONS(5246),
    [anon_sym_int] = ACTIONS(5246),
    [anon_sym_longint] = ACTIONS(5246),
    [anon_sym_integer] = ACTIONS(5246),
    [anon_sym_time] = ACTIONS(5246),
    [anon_sym_bit] = ACTIONS(5246),
    [anon_sym_logic] = ACTIONS(5246),
    [anon_sym_reg] = ACTIONS(5246),
    [anon_sym_shortreal] = ACTIONS(5246),
    [anon_sym_real] = ACTIONS(5246),
    [anon_sym_realtime] = ACTIONS(5246),
    [anon_sym_supply0] = ACTIONS(5246),
    [anon_sym_supply1] = ACTIONS(5246),
    [anon_sym_signed] = ACTIONS(5246),
    [anon_sym_unsigned] = ACTIONS(5246),
    [anon_sym_task] = ACTIONS(5246),
    [anon_sym_assert] = ACTIONS(5246),
    [anon_sym_property] = ACTIONS(5246),
    [anon_sym_assume] = ACTIONS(5246),
    [anon_sym_cover] = ACTIONS(5246),
    [anon_sym_sequence] = ACTIONS(5246),
    [anon_sym_restrict] = ACTIONS(5246),
    [anon_sym_not] = ACTIONS(5246),
    [anon_sym_or] = ACTIONS(5246),
    [anon_sym_and] = ACTIONS(5246),
    [anon_sym_case] = ACTIONS(5246),
    [anon_sym_always] = ACTIONS(5246),
    [anon_sym_covergroup] = ACTIONS(5246),
    [anon_sym_let] = ACTIONS(5246),
    [anon_sym_pulldown] = ACTIONS(5246),
    [anon_sym_pullup] = ACTIONS(5246),
    [anon_sym_cmos] = ACTIONS(5246),
    [anon_sym_rcmos] = ACTIONS(5246),
    [anon_sym_bufif0] = ACTIONS(5246),
    [anon_sym_bufif1] = ACTIONS(5246),
    [anon_sym_notif0] = ACTIONS(5246),
    [anon_sym_notif1] = ACTIONS(5246),
    [anon_sym_nmos] = ACTIONS(5246),
    [anon_sym_pmos] = ACTIONS(5246),
    [anon_sym_rnmos] = ACTIONS(5246),
    [anon_sym_rpmos] = ACTIONS(5246),
    [anon_sym_nand] = ACTIONS(5246),
    [anon_sym_nor] = ACTIONS(5246),
    [anon_sym_xor] = ACTIONS(5246),
    [anon_sym_xnor] = ACTIONS(5246),
    [anon_sym_buf] = ACTIONS(5246),
    [anon_sym_tranif0] = ACTIONS(5246),
    [anon_sym_tranif1] = ACTIONS(5246),
    [anon_sym_rtranif1] = ACTIONS(5246),
    [anon_sym_rtranif0] = ACTIONS(5246),
    [anon_sym_tran] = ACTIONS(5246),
    [anon_sym_rtran] = ACTIONS(5246),
    [anon_sym_generate] = ACTIONS(5246),
    [anon_sym_endgenerate] = ACTIONS(5246),
    [anon_sym_for] = ACTIONS(5246),
    [anon_sym_initial] = ACTIONS(5246),
    [anon_sym_assign] = ACTIONS(5246),
    [anon_sym_alias] = ACTIONS(5246),
    [anon_sym_always_comb] = ACTIONS(5246),
    [anon_sym_always_latch] = ACTIONS(5246),
    [anon_sym_always_ff] = ACTIONS(5246),
    [anon_sym_final] = ACTIONS(5246),
    [anon_sym_global] = ACTIONS(5246),
    [anon_sym_LPAREN_STAR] = ACTIONS(5244),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5244),
    [anon_sym_DOLLARunit] = ACTIONS(5244),
  },
  [4775] = {
    [sym_simple_identifier] = ACTIONS(6107),
    [anon_sym_wire] = ACTIONS(6107),
    [anon_sym_tri] = ACTIONS(6107),
    [anon_sym_tri0] = ACTIONS(6107),
    [anon_sym_tri1] = ACTIONS(6107),
    [anon_sym_wand] = ACTIONS(6107),
    [anon_sym_triand] = ACTIONS(6107),
    [anon_sym_wor] = ACTIONS(6107),
    [anon_sym_trior] = ACTIONS(6107),
    [anon_sym_trireg] = ACTIONS(6107),
    [anon_sym_uwire] = ACTIONS(6107),
    [anon_sym_SEMI] = ACTIONS(6109),
    [anon_sym_extern] = ACTIONS(6107),
    [anon_sym_interface] = ACTIONS(6107),
    [anon_sym_checker] = ACTIONS(6107),
    [anon_sym_virtual] = ACTIONS(6107),
    [anon_sym_class] = ACTIONS(6107),
    [anon_sym_type] = ACTIONS(6107),
    [anon_sym_DOLLARfatal] = ACTIONS(6109),
    [anon_sym_DOLLARerror] = ACTIONS(6109),
    [anon_sym_DOLLARwarning] = ACTIONS(6109),
    [anon_sym_DOLLARinfo] = ACTIONS(6109),
    [anon_sym_default] = ACTIONS(6107),
    [anon_sym_clocking] = ACTIONS(6107),
    [anon_sym_defparam] = ACTIONS(6107),
    [anon_sym_bind] = ACTIONS(6107),
    [anon_sym_rand] = ACTIONS(6107),
    [anon_sym_const] = ACTIONS(6107),
    [anon_sym_function] = ACTIONS(6107),
    [anon_sym_static] = ACTIONS(6107),
    [anon_sym_constraint] = ACTIONS(6107),
    [anon_sym_if] = ACTIONS(6107),
    [anon_sym_else] = ACTIONS(6107),
    [anon_sym_LBRACK] = ACTIONS(6109),
    [anon_sym_localparam] = ACTIONS(6107),
    [anon_sym_parameter] = ACTIONS(6107),
    [anon_sym_var] = ACTIONS(6107),
    [anon_sym_import] = ACTIONS(6107),
    [anon_sym_export] = ACTIONS(6107),
    [anon_sym_genvar] = ACTIONS(6107),
    [anon_sym_interconnect] = ACTIONS(6107),
    [anon_sym_typedef] = ACTIONS(6107),
    [anon_sym_enum] = ACTIONS(6107),
    [anon_sym_struct] = ACTIONS(6107),
    [anon_sym_union] = ACTIONS(6107),
    [anon_sym_nettype] = ACTIONS(6107),
    [anon_sym_automatic] = ACTIONS(6107),
    [anon_sym_string] = ACTIONS(6107),
    [anon_sym_chandle] = ACTIONS(6107),
    [anon_sym_event] = ACTIONS(6107),
    [anon_sym_byte] = ACTIONS(6107),
    [anon_sym_shortint] = ACTIONS(6107),
    [anon_sym_int] = ACTIONS(6107),
    [anon_sym_longint] = ACTIONS(6107),
    [anon_sym_integer] = ACTIONS(6107),
    [anon_sym_time] = ACTIONS(6107),
    [anon_sym_bit] = ACTIONS(6107),
    [anon_sym_logic] = ACTIONS(6107),
    [anon_sym_reg] = ACTIONS(6107),
    [anon_sym_shortreal] = ACTIONS(6107),
    [anon_sym_real] = ACTIONS(6107),
    [anon_sym_realtime] = ACTIONS(6107),
    [anon_sym_supply0] = ACTIONS(6107),
    [anon_sym_supply1] = ACTIONS(6107),
    [anon_sym_signed] = ACTIONS(6107),
    [anon_sym_unsigned] = ACTIONS(6107),
    [anon_sym_task] = ACTIONS(6107),
    [anon_sym_assert] = ACTIONS(6107),
    [anon_sym_property] = ACTIONS(6107),
    [anon_sym_assume] = ACTIONS(6107),
    [anon_sym_cover] = ACTIONS(6107),
    [anon_sym_sequence] = ACTIONS(6107),
    [anon_sym_restrict] = ACTIONS(6107),
    [anon_sym_not] = ACTIONS(6107),
    [anon_sym_or] = ACTIONS(6107),
    [anon_sym_and] = ACTIONS(6107),
    [anon_sym_case] = ACTIONS(6107),
    [anon_sym_always] = ACTIONS(6107),
    [anon_sym_covergroup] = ACTIONS(6107),
    [anon_sym_let] = ACTIONS(6107),
    [anon_sym_pulldown] = ACTIONS(6107),
    [anon_sym_pullup] = ACTIONS(6107),
    [anon_sym_cmos] = ACTIONS(6107),
    [anon_sym_rcmos] = ACTIONS(6107),
    [anon_sym_bufif0] = ACTIONS(6107),
    [anon_sym_bufif1] = ACTIONS(6107),
    [anon_sym_notif0] = ACTIONS(6107),
    [anon_sym_notif1] = ACTIONS(6107),
    [anon_sym_nmos] = ACTIONS(6107),
    [anon_sym_pmos] = ACTIONS(6107),
    [anon_sym_rnmos] = ACTIONS(6107),
    [anon_sym_rpmos] = ACTIONS(6107),
    [anon_sym_nand] = ACTIONS(6107),
    [anon_sym_nor] = ACTIONS(6107),
    [anon_sym_xor] = ACTIONS(6107),
    [anon_sym_xnor] = ACTIONS(6107),
    [anon_sym_buf] = ACTIONS(6107),
    [anon_sym_tranif0] = ACTIONS(6107),
    [anon_sym_tranif1] = ACTIONS(6107),
    [anon_sym_rtranif1] = ACTIONS(6107),
    [anon_sym_rtranif0] = ACTIONS(6107),
    [anon_sym_tran] = ACTIONS(6107),
    [anon_sym_rtran] = ACTIONS(6107),
    [anon_sym_generate] = ACTIONS(6107),
    [anon_sym_endgenerate] = ACTIONS(6107),
    [anon_sym_for] = ACTIONS(6107),
    [anon_sym_initial] = ACTIONS(6107),
    [anon_sym_assign] = ACTIONS(6107),
    [anon_sym_alias] = ACTIONS(6107),
    [anon_sym_always_comb] = ACTIONS(6107),
    [anon_sym_always_latch] = ACTIONS(6107),
    [anon_sym_always_ff] = ACTIONS(6107),
    [anon_sym_final] = ACTIONS(6107),
    [anon_sym_global] = ACTIONS(6107),
    [anon_sym_LPAREN_STAR] = ACTIONS(6109),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6109),
    [anon_sym_DOLLARunit] = ACTIONS(6109),
  },
  [4776] = {
    [sym_simple_identifier] = ACTIONS(4536),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_rand] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_end] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [4777] = {
    [sym_simple_identifier] = ACTIONS(5178),
    [anon_sym_wire] = ACTIONS(5178),
    [anon_sym_tri] = ACTIONS(5178),
    [anon_sym_tri0] = ACTIONS(5178),
    [anon_sym_tri1] = ACTIONS(5178),
    [anon_sym_wand] = ACTIONS(5178),
    [anon_sym_triand] = ACTIONS(5178),
    [anon_sym_wor] = ACTIONS(5178),
    [anon_sym_trior] = ACTIONS(5178),
    [anon_sym_trireg] = ACTIONS(5178),
    [anon_sym_uwire] = ACTIONS(5178),
    [anon_sym_SEMI] = ACTIONS(5176),
    [anon_sym_extern] = ACTIONS(5178),
    [anon_sym_interface] = ACTIONS(5178),
    [anon_sym_checker] = ACTIONS(5178),
    [anon_sym_virtual] = ACTIONS(5178),
    [anon_sym_class] = ACTIONS(5178),
    [anon_sym_type] = ACTIONS(5178),
    [anon_sym_DOLLARfatal] = ACTIONS(5176),
    [anon_sym_DOLLARerror] = ACTIONS(5176),
    [anon_sym_DOLLARwarning] = ACTIONS(5176),
    [anon_sym_DOLLARinfo] = ACTIONS(5176),
    [anon_sym_default] = ACTIONS(5178),
    [anon_sym_clocking] = ACTIONS(5178),
    [anon_sym_defparam] = ACTIONS(5178),
    [anon_sym_bind] = ACTIONS(5178),
    [anon_sym_rand] = ACTIONS(5178),
    [anon_sym_const] = ACTIONS(5178),
    [anon_sym_function] = ACTIONS(5178),
    [anon_sym_static] = ACTIONS(5178),
    [anon_sym_constraint] = ACTIONS(5178),
    [anon_sym_if] = ACTIONS(5178),
    [anon_sym_else] = ACTIONS(5178),
    [anon_sym_LBRACK] = ACTIONS(5176),
    [anon_sym_localparam] = ACTIONS(5178),
    [anon_sym_parameter] = ACTIONS(5178),
    [anon_sym_var] = ACTIONS(5178),
    [anon_sym_import] = ACTIONS(5178),
    [anon_sym_export] = ACTIONS(5178),
    [anon_sym_genvar] = ACTIONS(5178),
    [anon_sym_interconnect] = ACTIONS(5178),
    [anon_sym_typedef] = ACTIONS(5178),
    [anon_sym_enum] = ACTIONS(5178),
    [anon_sym_struct] = ACTIONS(5178),
    [anon_sym_union] = ACTIONS(5178),
    [anon_sym_nettype] = ACTIONS(5178),
    [anon_sym_automatic] = ACTIONS(5178),
    [anon_sym_string] = ACTIONS(5178),
    [anon_sym_chandle] = ACTIONS(5178),
    [anon_sym_event] = ACTIONS(5178),
    [anon_sym_byte] = ACTIONS(5178),
    [anon_sym_shortint] = ACTIONS(5178),
    [anon_sym_int] = ACTIONS(5178),
    [anon_sym_longint] = ACTIONS(5178),
    [anon_sym_integer] = ACTIONS(5178),
    [anon_sym_time] = ACTIONS(5178),
    [anon_sym_bit] = ACTIONS(5178),
    [anon_sym_logic] = ACTIONS(5178),
    [anon_sym_reg] = ACTIONS(5178),
    [anon_sym_shortreal] = ACTIONS(5178),
    [anon_sym_real] = ACTIONS(5178),
    [anon_sym_realtime] = ACTIONS(5178),
    [anon_sym_supply0] = ACTIONS(5178),
    [anon_sym_supply1] = ACTIONS(5178),
    [anon_sym_signed] = ACTIONS(5178),
    [anon_sym_unsigned] = ACTIONS(5178),
    [anon_sym_task] = ACTIONS(5178),
    [anon_sym_assert] = ACTIONS(5178),
    [anon_sym_property] = ACTIONS(5178),
    [anon_sym_assume] = ACTIONS(5178),
    [anon_sym_cover] = ACTIONS(5178),
    [anon_sym_sequence] = ACTIONS(5178),
    [anon_sym_restrict] = ACTIONS(5178),
    [anon_sym_not] = ACTIONS(5178),
    [anon_sym_or] = ACTIONS(5178),
    [anon_sym_and] = ACTIONS(5178),
    [anon_sym_case] = ACTIONS(5178),
    [anon_sym_always] = ACTIONS(5178),
    [anon_sym_covergroup] = ACTIONS(5178),
    [anon_sym_let] = ACTIONS(5178),
    [anon_sym_pulldown] = ACTIONS(5178),
    [anon_sym_pullup] = ACTIONS(5178),
    [anon_sym_cmos] = ACTIONS(5178),
    [anon_sym_rcmos] = ACTIONS(5178),
    [anon_sym_bufif0] = ACTIONS(5178),
    [anon_sym_bufif1] = ACTIONS(5178),
    [anon_sym_notif0] = ACTIONS(5178),
    [anon_sym_notif1] = ACTIONS(5178),
    [anon_sym_nmos] = ACTIONS(5178),
    [anon_sym_pmos] = ACTIONS(5178),
    [anon_sym_rnmos] = ACTIONS(5178),
    [anon_sym_rpmos] = ACTIONS(5178),
    [anon_sym_nand] = ACTIONS(5178),
    [anon_sym_nor] = ACTIONS(5178),
    [anon_sym_xor] = ACTIONS(5178),
    [anon_sym_xnor] = ACTIONS(5178),
    [anon_sym_buf] = ACTIONS(5178),
    [anon_sym_tranif0] = ACTIONS(5178),
    [anon_sym_tranif1] = ACTIONS(5178),
    [anon_sym_rtranif1] = ACTIONS(5178),
    [anon_sym_rtranif0] = ACTIONS(5178),
    [anon_sym_tran] = ACTIONS(5178),
    [anon_sym_rtran] = ACTIONS(5178),
    [anon_sym_generate] = ACTIONS(5178),
    [anon_sym_endgenerate] = ACTIONS(5178),
    [anon_sym_for] = ACTIONS(5178),
    [anon_sym_initial] = ACTIONS(5178),
    [anon_sym_assign] = ACTIONS(5178),
    [anon_sym_alias] = ACTIONS(5178),
    [anon_sym_always_comb] = ACTIONS(5178),
    [anon_sym_always_latch] = ACTIONS(5178),
    [anon_sym_always_ff] = ACTIONS(5178),
    [anon_sym_final] = ACTIONS(5178),
    [anon_sym_global] = ACTIONS(5178),
    [anon_sym_LPAREN_STAR] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5176),
    [anon_sym_DOLLARunit] = ACTIONS(5176),
  },
  [4778] = {
    [sym_simple_identifier] = ACTIONS(4720),
    [anon_sym_wire] = ACTIONS(4720),
    [anon_sym_tri] = ACTIONS(4720),
    [anon_sym_tri0] = ACTIONS(4720),
    [anon_sym_tri1] = ACTIONS(4720),
    [anon_sym_wand] = ACTIONS(4720),
    [anon_sym_triand] = ACTIONS(4720),
    [anon_sym_wor] = ACTIONS(4720),
    [anon_sym_trior] = ACTIONS(4720),
    [anon_sym_trireg] = ACTIONS(4720),
    [anon_sym_uwire] = ACTIONS(4720),
    [anon_sym_SEMI] = ACTIONS(4718),
    [anon_sym_extern] = ACTIONS(4720),
    [anon_sym_interface] = ACTIONS(4720),
    [anon_sym_checker] = ACTIONS(4720),
    [anon_sym_virtual] = ACTIONS(4720),
    [anon_sym_class] = ACTIONS(4720),
    [anon_sym_type] = ACTIONS(4720),
    [anon_sym_DOLLARfatal] = ACTIONS(4718),
    [anon_sym_DOLLARerror] = ACTIONS(4718),
    [anon_sym_DOLLARwarning] = ACTIONS(4718),
    [anon_sym_DOLLARinfo] = ACTIONS(4718),
    [anon_sym_default] = ACTIONS(4720),
    [anon_sym_clocking] = ACTIONS(4720),
    [anon_sym_defparam] = ACTIONS(4720),
    [anon_sym_bind] = ACTIONS(4720),
    [anon_sym_rand] = ACTIONS(4720),
    [anon_sym_const] = ACTIONS(4720),
    [anon_sym_function] = ACTIONS(4720),
    [anon_sym_static] = ACTIONS(4720),
    [anon_sym_constraint] = ACTIONS(4720),
    [anon_sym_if] = ACTIONS(4720),
    [anon_sym_else] = ACTIONS(4720),
    [anon_sym_LBRACK] = ACTIONS(4718),
    [anon_sym_localparam] = ACTIONS(4720),
    [anon_sym_parameter] = ACTIONS(4720),
    [anon_sym_var] = ACTIONS(4720),
    [anon_sym_import] = ACTIONS(4720),
    [anon_sym_export] = ACTIONS(4720),
    [anon_sym_genvar] = ACTIONS(4720),
    [anon_sym_interconnect] = ACTIONS(4720),
    [anon_sym_typedef] = ACTIONS(4720),
    [anon_sym_enum] = ACTIONS(4720),
    [anon_sym_struct] = ACTIONS(4720),
    [anon_sym_union] = ACTIONS(4720),
    [anon_sym_nettype] = ACTIONS(4720),
    [anon_sym_automatic] = ACTIONS(4720),
    [anon_sym_string] = ACTIONS(4720),
    [anon_sym_chandle] = ACTIONS(4720),
    [anon_sym_event] = ACTIONS(4720),
    [anon_sym_byte] = ACTIONS(4720),
    [anon_sym_shortint] = ACTIONS(4720),
    [anon_sym_int] = ACTIONS(4720),
    [anon_sym_longint] = ACTIONS(4720),
    [anon_sym_integer] = ACTIONS(4720),
    [anon_sym_time] = ACTIONS(4720),
    [anon_sym_bit] = ACTIONS(4720),
    [anon_sym_logic] = ACTIONS(4720),
    [anon_sym_reg] = ACTIONS(4720),
    [anon_sym_shortreal] = ACTIONS(4720),
    [anon_sym_real] = ACTIONS(4720),
    [anon_sym_realtime] = ACTIONS(4720),
    [anon_sym_supply0] = ACTIONS(4720),
    [anon_sym_supply1] = ACTIONS(4720),
    [anon_sym_signed] = ACTIONS(4720),
    [anon_sym_unsigned] = ACTIONS(4720),
    [anon_sym_task] = ACTIONS(4720),
    [anon_sym_assert] = ACTIONS(4720),
    [anon_sym_property] = ACTIONS(4720),
    [anon_sym_assume] = ACTIONS(4720),
    [anon_sym_cover] = ACTIONS(4720),
    [anon_sym_sequence] = ACTIONS(4720),
    [anon_sym_restrict] = ACTIONS(4720),
    [anon_sym_not] = ACTIONS(4720),
    [anon_sym_or] = ACTIONS(4720),
    [anon_sym_and] = ACTIONS(4720),
    [anon_sym_case] = ACTIONS(4720),
    [anon_sym_always] = ACTIONS(4720),
    [anon_sym_covergroup] = ACTIONS(4720),
    [anon_sym_let] = ACTIONS(4720),
    [anon_sym_pulldown] = ACTIONS(4720),
    [anon_sym_pullup] = ACTIONS(4720),
    [anon_sym_cmos] = ACTIONS(4720),
    [anon_sym_rcmos] = ACTIONS(4720),
    [anon_sym_bufif0] = ACTIONS(4720),
    [anon_sym_bufif1] = ACTIONS(4720),
    [anon_sym_notif0] = ACTIONS(4720),
    [anon_sym_notif1] = ACTIONS(4720),
    [anon_sym_nmos] = ACTIONS(4720),
    [anon_sym_pmos] = ACTIONS(4720),
    [anon_sym_rnmos] = ACTIONS(4720),
    [anon_sym_rpmos] = ACTIONS(4720),
    [anon_sym_nand] = ACTIONS(4720),
    [anon_sym_nor] = ACTIONS(4720),
    [anon_sym_xor] = ACTIONS(4720),
    [anon_sym_xnor] = ACTIONS(4720),
    [anon_sym_buf] = ACTIONS(4720),
    [anon_sym_tranif0] = ACTIONS(4720),
    [anon_sym_tranif1] = ACTIONS(4720),
    [anon_sym_rtranif1] = ACTIONS(4720),
    [anon_sym_rtranif0] = ACTIONS(4720),
    [anon_sym_tran] = ACTIONS(4720),
    [anon_sym_rtran] = ACTIONS(4720),
    [anon_sym_generate] = ACTIONS(4720),
    [anon_sym_endgenerate] = ACTIONS(4720),
    [anon_sym_for] = ACTIONS(4720),
    [anon_sym_initial] = ACTIONS(4720),
    [anon_sym_assign] = ACTIONS(4720),
    [anon_sym_alias] = ACTIONS(4720),
    [anon_sym_always_comb] = ACTIONS(4720),
    [anon_sym_always_latch] = ACTIONS(4720),
    [anon_sym_always_ff] = ACTIONS(4720),
    [anon_sym_final] = ACTIONS(4720),
    [anon_sym_global] = ACTIONS(4720),
    [anon_sym_LPAREN_STAR] = ACTIONS(4718),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4718),
    [anon_sym_DOLLARunit] = ACTIONS(4718),
  },
  [4779] = {
    [sym_simple_identifier] = ACTIONS(4636),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_rand] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_end] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [4780] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(11041),
    [anon_sym_wire] = ACTIONS(11044),
    [anon_sym_tri] = ACTIONS(11044),
    [anon_sym_tri0] = ACTIONS(11044),
    [anon_sym_tri1] = ACTIONS(11044),
    [anon_sym_wand] = ACTIONS(11044),
    [anon_sym_triand] = ACTIONS(11044),
    [anon_sym_wor] = ACTIONS(11044),
    [anon_sym_trior] = ACTIONS(11044),
    [anon_sym_trireg] = ACTIONS(11044),
    [anon_sym_uwire] = ACTIONS(11044),
    [anon_sym_SEMI] = ACTIONS(11047),
    [anon_sym_interface] = ACTIONS(11050),
    [anon_sym_program] = ACTIONS(11053),
    [anon_sym_checker] = ACTIONS(11056),
    [anon_sym_virtual] = ACTIONS(11059),
    [anon_sym_class] = ACTIONS(11062),
    [anon_sym_endpackage] = ACTIONS(11065),
    [anon_sym_timeunit] = ACTIONS(11067),
    [anon_sym_timeprecision] = ACTIONS(11070),
    [anon_sym_type] = ACTIONS(11073),
    [anon_sym_bind] = ACTIONS(11076),
    [anon_sym_const] = ACTIONS(11079),
    [anon_sym_function] = ACTIONS(11082),
    [anon_sym_static] = ACTIONS(11085),
    [anon_sym_constraint] = ACTIONS(11088),
    [anon_sym_LBRACK] = ACTIONS(11091),
    [anon_sym_localparam] = ACTIONS(11094),
    [anon_sym_parameter] = ACTIONS(11097),
    [anon_sym_var] = ACTIONS(11100),
    [anon_sym_import] = ACTIONS(11103),
    [anon_sym_export] = ACTIONS(11106),
    [anon_sym_interconnect] = ACTIONS(11109),
    [anon_sym_typedef] = ACTIONS(11112),
    [anon_sym_enum] = ACTIONS(11115),
    [anon_sym_struct] = ACTIONS(11118),
    [anon_sym_union] = ACTIONS(11121),
    [anon_sym_nettype] = ACTIONS(11124),
    [anon_sym_automatic] = ACTIONS(11127),
    [anon_sym_string] = ACTIONS(11130),
    [anon_sym_chandle] = ACTIONS(11130),
    [anon_sym_event] = ACTIONS(11130),
    [anon_sym_byte] = ACTIONS(11133),
    [anon_sym_shortint] = ACTIONS(11133),
    [anon_sym_int] = ACTIONS(11133),
    [anon_sym_longint] = ACTIONS(11133),
    [anon_sym_integer] = ACTIONS(11133),
    [anon_sym_time] = ACTIONS(11133),
    [anon_sym_bit] = ACTIONS(11136),
    [anon_sym_logic] = ACTIONS(11136),
    [anon_sym_reg] = ACTIONS(11136),
    [anon_sym_shortreal] = ACTIONS(11139),
    [anon_sym_real] = ACTIONS(11139),
    [anon_sym_realtime] = ACTIONS(11139),
    [anon_sym_supply0] = ACTIONS(11044),
    [anon_sym_supply1] = ACTIONS(11044),
    [anon_sym_signed] = ACTIONS(11142),
    [anon_sym_unsigned] = ACTIONS(11142),
    [anon_sym_task] = ACTIONS(11145),
    [anon_sym_property] = ACTIONS(11148),
    [anon_sym_sequence] = ACTIONS(11151),
    [anon_sym_covergroup] = ACTIONS(11154),
    [anon_sym_let] = ACTIONS(11157),
    [anon_sym_LPAREN_STAR] = ACTIONS(11160),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11163),
    [anon_sym_DOLLARunit] = ACTIONS(11166),
  },
  [4781] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4714),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4721),
    [sym_package_or_generate_item_declaration] = STATE(4721),
    [sym_anonymous_program] = STATE(4721),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4721),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4721),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11169),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4782] = {
    [sym_simple_identifier] = ACTIONS(6027),
    [anon_sym_wire] = ACTIONS(6027),
    [anon_sym_tri] = ACTIONS(6027),
    [anon_sym_tri0] = ACTIONS(6027),
    [anon_sym_tri1] = ACTIONS(6027),
    [anon_sym_wand] = ACTIONS(6027),
    [anon_sym_triand] = ACTIONS(6027),
    [anon_sym_wor] = ACTIONS(6027),
    [anon_sym_trior] = ACTIONS(6027),
    [anon_sym_trireg] = ACTIONS(6027),
    [anon_sym_uwire] = ACTIONS(6027),
    [anon_sym_SEMI] = ACTIONS(6029),
    [anon_sym_extern] = ACTIONS(6027),
    [anon_sym_interface] = ACTIONS(6027),
    [anon_sym_checker] = ACTIONS(6027),
    [anon_sym_virtual] = ACTIONS(6027),
    [anon_sym_class] = ACTIONS(6027),
    [anon_sym_type] = ACTIONS(6027),
    [anon_sym_DOLLARfatal] = ACTIONS(6029),
    [anon_sym_DOLLARerror] = ACTIONS(6029),
    [anon_sym_DOLLARwarning] = ACTIONS(6029),
    [anon_sym_DOLLARinfo] = ACTIONS(6029),
    [anon_sym_default] = ACTIONS(6027),
    [anon_sym_clocking] = ACTIONS(6027),
    [anon_sym_defparam] = ACTIONS(6027),
    [anon_sym_bind] = ACTIONS(6027),
    [anon_sym_rand] = ACTIONS(6027),
    [anon_sym_const] = ACTIONS(6027),
    [anon_sym_function] = ACTIONS(6027),
    [anon_sym_static] = ACTIONS(6027),
    [anon_sym_constraint] = ACTIONS(6027),
    [anon_sym_if] = ACTIONS(6027),
    [anon_sym_else] = ACTIONS(6027),
    [anon_sym_LBRACK] = ACTIONS(6029),
    [anon_sym_localparam] = ACTIONS(6027),
    [anon_sym_parameter] = ACTIONS(6027),
    [anon_sym_var] = ACTIONS(6027),
    [anon_sym_import] = ACTIONS(6027),
    [anon_sym_export] = ACTIONS(6027),
    [anon_sym_genvar] = ACTIONS(6027),
    [anon_sym_interconnect] = ACTIONS(6027),
    [anon_sym_typedef] = ACTIONS(6027),
    [anon_sym_enum] = ACTIONS(6027),
    [anon_sym_struct] = ACTIONS(6027),
    [anon_sym_union] = ACTIONS(6027),
    [anon_sym_nettype] = ACTIONS(6027),
    [anon_sym_automatic] = ACTIONS(6027),
    [anon_sym_string] = ACTIONS(6027),
    [anon_sym_chandle] = ACTIONS(6027),
    [anon_sym_event] = ACTIONS(6027),
    [anon_sym_byte] = ACTIONS(6027),
    [anon_sym_shortint] = ACTIONS(6027),
    [anon_sym_int] = ACTIONS(6027),
    [anon_sym_longint] = ACTIONS(6027),
    [anon_sym_integer] = ACTIONS(6027),
    [anon_sym_time] = ACTIONS(6027),
    [anon_sym_bit] = ACTIONS(6027),
    [anon_sym_logic] = ACTIONS(6027),
    [anon_sym_reg] = ACTIONS(6027),
    [anon_sym_shortreal] = ACTIONS(6027),
    [anon_sym_real] = ACTIONS(6027),
    [anon_sym_realtime] = ACTIONS(6027),
    [anon_sym_supply0] = ACTIONS(6027),
    [anon_sym_supply1] = ACTIONS(6027),
    [anon_sym_signed] = ACTIONS(6027),
    [anon_sym_unsigned] = ACTIONS(6027),
    [anon_sym_task] = ACTIONS(6027),
    [anon_sym_assert] = ACTIONS(6027),
    [anon_sym_property] = ACTIONS(6027),
    [anon_sym_assume] = ACTIONS(6027),
    [anon_sym_cover] = ACTIONS(6027),
    [anon_sym_sequence] = ACTIONS(6027),
    [anon_sym_restrict] = ACTIONS(6027),
    [anon_sym_not] = ACTIONS(6027),
    [anon_sym_or] = ACTIONS(6027),
    [anon_sym_and] = ACTIONS(6027),
    [anon_sym_case] = ACTIONS(6027),
    [anon_sym_always] = ACTIONS(6027),
    [anon_sym_covergroup] = ACTIONS(6027),
    [anon_sym_end] = ACTIONS(6027),
    [anon_sym_let] = ACTIONS(6027),
    [anon_sym_pulldown] = ACTIONS(6027),
    [anon_sym_pullup] = ACTIONS(6027),
    [anon_sym_cmos] = ACTIONS(6027),
    [anon_sym_rcmos] = ACTIONS(6027),
    [anon_sym_bufif0] = ACTIONS(6027),
    [anon_sym_bufif1] = ACTIONS(6027),
    [anon_sym_notif0] = ACTIONS(6027),
    [anon_sym_notif1] = ACTIONS(6027),
    [anon_sym_nmos] = ACTIONS(6027),
    [anon_sym_pmos] = ACTIONS(6027),
    [anon_sym_rnmos] = ACTIONS(6027),
    [anon_sym_rpmos] = ACTIONS(6027),
    [anon_sym_nand] = ACTIONS(6027),
    [anon_sym_nor] = ACTIONS(6027),
    [anon_sym_xor] = ACTIONS(6027),
    [anon_sym_xnor] = ACTIONS(6027),
    [anon_sym_buf] = ACTIONS(6027),
    [anon_sym_tranif0] = ACTIONS(6027),
    [anon_sym_tranif1] = ACTIONS(6027),
    [anon_sym_rtranif1] = ACTIONS(6027),
    [anon_sym_rtranif0] = ACTIONS(6027),
    [anon_sym_tran] = ACTIONS(6027),
    [anon_sym_rtran] = ACTIONS(6027),
    [anon_sym_generate] = ACTIONS(6027),
    [anon_sym_for] = ACTIONS(6027),
    [anon_sym_initial] = ACTIONS(6027),
    [anon_sym_assign] = ACTIONS(6027),
    [anon_sym_alias] = ACTIONS(6027),
    [anon_sym_always_comb] = ACTIONS(6027),
    [anon_sym_always_latch] = ACTIONS(6027),
    [anon_sym_always_ff] = ACTIONS(6027),
    [anon_sym_final] = ACTIONS(6027),
    [anon_sym_global] = ACTIONS(6027),
    [anon_sym_LPAREN_STAR] = ACTIONS(6029),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6029),
    [anon_sym_DOLLARunit] = ACTIONS(6029),
  },
  [4783] = {
    [sym_simple_identifier] = ACTIONS(6533),
    [anon_sym_wire] = ACTIONS(6533),
    [anon_sym_tri] = ACTIONS(6533),
    [anon_sym_tri0] = ACTIONS(6533),
    [anon_sym_tri1] = ACTIONS(6533),
    [anon_sym_wand] = ACTIONS(6533),
    [anon_sym_triand] = ACTIONS(6533),
    [anon_sym_wor] = ACTIONS(6533),
    [anon_sym_trior] = ACTIONS(6533),
    [anon_sym_trireg] = ACTIONS(6533),
    [anon_sym_uwire] = ACTIONS(6533),
    [anon_sym_SEMI] = ACTIONS(6535),
    [anon_sym_extern] = ACTIONS(6533),
    [anon_sym_interface] = ACTIONS(6533),
    [anon_sym_checker] = ACTIONS(6533),
    [anon_sym_virtual] = ACTIONS(6533),
    [anon_sym_class] = ACTIONS(6533),
    [anon_sym_type] = ACTIONS(6533),
    [anon_sym_DOLLARfatal] = ACTIONS(6535),
    [anon_sym_DOLLARerror] = ACTIONS(6535),
    [anon_sym_DOLLARwarning] = ACTIONS(6535),
    [anon_sym_DOLLARinfo] = ACTIONS(6535),
    [anon_sym_default] = ACTIONS(6533),
    [anon_sym_clocking] = ACTIONS(6533),
    [anon_sym_defparam] = ACTIONS(6533),
    [anon_sym_bind] = ACTIONS(6533),
    [anon_sym_rand] = ACTIONS(6533),
    [anon_sym_const] = ACTIONS(6533),
    [anon_sym_function] = ACTIONS(6533),
    [anon_sym_static] = ACTIONS(6533),
    [anon_sym_constraint] = ACTIONS(6533),
    [anon_sym_if] = ACTIONS(6533),
    [anon_sym_else] = ACTIONS(6533),
    [anon_sym_LBRACK] = ACTIONS(6535),
    [anon_sym_localparam] = ACTIONS(6533),
    [anon_sym_parameter] = ACTIONS(6533),
    [anon_sym_var] = ACTIONS(6533),
    [anon_sym_import] = ACTIONS(6533),
    [anon_sym_export] = ACTIONS(6533),
    [anon_sym_genvar] = ACTIONS(6533),
    [anon_sym_interconnect] = ACTIONS(6533),
    [anon_sym_typedef] = ACTIONS(6533),
    [anon_sym_enum] = ACTIONS(6533),
    [anon_sym_struct] = ACTIONS(6533),
    [anon_sym_union] = ACTIONS(6533),
    [anon_sym_nettype] = ACTIONS(6533),
    [anon_sym_automatic] = ACTIONS(6533),
    [anon_sym_string] = ACTIONS(6533),
    [anon_sym_chandle] = ACTIONS(6533),
    [anon_sym_event] = ACTIONS(6533),
    [anon_sym_byte] = ACTIONS(6533),
    [anon_sym_shortint] = ACTIONS(6533),
    [anon_sym_int] = ACTIONS(6533),
    [anon_sym_longint] = ACTIONS(6533),
    [anon_sym_integer] = ACTIONS(6533),
    [anon_sym_time] = ACTIONS(6533),
    [anon_sym_bit] = ACTIONS(6533),
    [anon_sym_logic] = ACTIONS(6533),
    [anon_sym_reg] = ACTIONS(6533),
    [anon_sym_shortreal] = ACTIONS(6533),
    [anon_sym_real] = ACTIONS(6533),
    [anon_sym_realtime] = ACTIONS(6533),
    [anon_sym_supply0] = ACTIONS(6533),
    [anon_sym_supply1] = ACTIONS(6533),
    [anon_sym_signed] = ACTIONS(6533),
    [anon_sym_unsigned] = ACTIONS(6533),
    [anon_sym_task] = ACTIONS(6533),
    [anon_sym_assert] = ACTIONS(6533),
    [anon_sym_property] = ACTIONS(6533),
    [anon_sym_assume] = ACTIONS(6533),
    [anon_sym_cover] = ACTIONS(6533),
    [anon_sym_sequence] = ACTIONS(6533),
    [anon_sym_restrict] = ACTIONS(6533),
    [anon_sym_not] = ACTIONS(6533),
    [anon_sym_or] = ACTIONS(6533),
    [anon_sym_and] = ACTIONS(6533),
    [anon_sym_case] = ACTIONS(6533),
    [anon_sym_always] = ACTIONS(6533),
    [anon_sym_covergroup] = ACTIONS(6533),
    [anon_sym_let] = ACTIONS(6533),
    [anon_sym_pulldown] = ACTIONS(6533),
    [anon_sym_pullup] = ACTIONS(6533),
    [anon_sym_cmos] = ACTIONS(6533),
    [anon_sym_rcmos] = ACTIONS(6533),
    [anon_sym_bufif0] = ACTIONS(6533),
    [anon_sym_bufif1] = ACTIONS(6533),
    [anon_sym_notif0] = ACTIONS(6533),
    [anon_sym_notif1] = ACTIONS(6533),
    [anon_sym_nmos] = ACTIONS(6533),
    [anon_sym_pmos] = ACTIONS(6533),
    [anon_sym_rnmos] = ACTIONS(6533),
    [anon_sym_rpmos] = ACTIONS(6533),
    [anon_sym_nand] = ACTIONS(6533),
    [anon_sym_nor] = ACTIONS(6533),
    [anon_sym_xor] = ACTIONS(6533),
    [anon_sym_xnor] = ACTIONS(6533),
    [anon_sym_buf] = ACTIONS(6533),
    [anon_sym_tranif0] = ACTIONS(6533),
    [anon_sym_tranif1] = ACTIONS(6533),
    [anon_sym_rtranif1] = ACTIONS(6533),
    [anon_sym_rtranif0] = ACTIONS(6533),
    [anon_sym_tran] = ACTIONS(6533),
    [anon_sym_rtran] = ACTIONS(6533),
    [anon_sym_generate] = ACTIONS(6533),
    [anon_sym_endgenerate] = ACTIONS(6533),
    [anon_sym_for] = ACTIONS(6533),
    [anon_sym_initial] = ACTIONS(6533),
    [anon_sym_assign] = ACTIONS(6533),
    [anon_sym_alias] = ACTIONS(6533),
    [anon_sym_always_comb] = ACTIONS(6533),
    [anon_sym_always_latch] = ACTIONS(6533),
    [anon_sym_always_ff] = ACTIONS(6533),
    [anon_sym_final] = ACTIONS(6533),
    [anon_sym_global] = ACTIONS(6533),
    [anon_sym_LPAREN_STAR] = ACTIONS(6535),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6535),
    [anon_sym_DOLLARunit] = ACTIONS(6535),
  },
  [4784] = {
    [sym_simple_identifier] = ACTIONS(6691),
    [anon_sym_wire] = ACTIONS(6691),
    [anon_sym_tri] = ACTIONS(6691),
    [anon_sym_tri0] = ACTIONS(6691),
    [anon_sym_tri1] = ACTIONS(6691),
    [anon_sym_wand] = ACTIONS(6691),
    [anon_sym_triand] = ACTIONS(6691),
    [anon_sym_wor] = ACTIONS(6691),
    [anon_sym_trior] = ACTIONS(6691),
    [anon_sym_trireg] = ACTIONS(6691),
    [anon_sym_uwire] = ACTIONS(6691),
    [anon_sym_SEMI] = ACTIONS(6693),
    [anon_sym_extern] = ACTIONS(6691),
    [anon_sym_interface] = ACTIONS(6691),
    [anon_sym_checker] = ACTIONS(6691),
    [anon_sym_virtual] = ACTIONS(6691),
    [anon_sym_class] = ACTIONS(6691),
    [anon_sym_type] = ACTIONS(6691),
    [anon_sym_DOLLARfatal] = ACTIONS(6693),
    [anon_sym_DOLLARerror] = ACTIONS(6693),
    [anon_sym_DOLLARwarning] = ACTIONS(6693),
    [anon_sym_DOLLARinfo] = ACTIONS(6693),
    [anon_sym_default] = ACTIONS(6691),
    [anon_sym_clocking] = ACTIONS(6691),
    [anon_sym_defparam] = ACTIONS(6691),
    [anon_sym_bind] = ACTIONS(6691),
    [anon_sym_rand] = ACTIONS(6691),
    [anon_sym_const] = ACTIONS(6691),
    [anon_sym_function] = ACTIONS(6691),
    [anon_sym_static] = ACTIONS(6691),
    [anon_sym_constraint] = ACTIONS(6691),
    [anon_sym_if] = ACTIONS(6691),
    [anon_sym_else] = ACTIONS(6691),
    [anon_sym_LBRACK] = ACTIONS(6693),
    [anon_sym_localparam] = ACTIONS(6691),
    [anon_sym_parameter] = ACTIONS(6691),
    [anon_sym_var] = ACTIONS(6691),
    [anon_sym_import] = ACTIONS(6691),
    [anon_sym_export] = ACTIONS(6691),
    [anon_sym_genvar] = ACTIONS(6691),
    [anon_sym_interconnect] = ACTIONS(6691),
    [anon_sym_typedef] = ACTIONS(6691),
    [anon_sym_enum] = ACTIONS(6691),
    [anon_sym_struct] = ACTIONS(6691),
    [anon_sym_union] = ACTIONS(6691),
    [anon_sym_nettype] = ACTIONS(6691),
    [anon_sym_automatic] = ACTIONS(6691),
    [anon_sym_string] = ACTIONS(6691),
    [anon_sym_chandle] = ACTIONS(6691),
    [anon_sym_event] = ACTIONS(6691),
    [anon_sym_byte] = ACTIONS(6691),
    [anon_sym_shortint] = ACTIONS(6691),
    [anon_sym_int] = ACTIONS(6691),
    [anon_sym_longint] = ACTIONS(6691),
    [anon_sym_integer] = ACTIONS(6691),
    [anon_sym_time] = ACTIONS(6691),
    [anon_sym_bit] = ACTIONS(6691),
    [anon_sym_logic] = ACTIONS(6691),
    [anon_sym_reg] = ACTIONS(6691),
    [anon_sym_shortreal] = ACTIONS(6691),
    [anon_sym_real] = ACTIONS(6691),
    [anon_sym_realtime] = ACTIONS(6691),
    [anon_sym_supply0] = ACTIONS(6691),
    [anon_sym_supply1] = ACTIONS(6691),
    [anon_sym_signed] = ACTIONS(6691),
    [anon_sym_unsigned] = ACTIONS(6691),
    [anon_sym_task] = ACTIONS(6691),
    [anon_sym_assert] = ACTIONS(6691),
    [anon_sym_property] = ACTIONS(6691),
    [anon_sym_assume] = ACTIONS(6691),
    [anon_sym_cover] = ACTIONS(6691),
    [anon_sym_sequence] = ACTIONS(6691),
    [anon_sym_restrict] = ACTIONS(6691),
    [anon_sym_not] = ACTIONS(6691),
    [anon_sym_or] = ACTIONS(6691),
    [anon_sym_and] = ACTIONS(6691),
    [anon_sym_case] = ACTIONS(6691),
    [anon_sym_always] = ACTIONS(6691),
    [anon_sym_covergroup] = ACTIONS(6691),
    [anon_sym_end] = ACTIONS(6691),
    [anon_sym_let] = ACTIONS(6691),
    [anon_sym_pulldown] = ACTIONS(6691),
    [anon_sym_pullup] = ACTIONS(6691),
    [anon_sym_cmos] = ACTIONS(6691),
    [anon_sym_rcmos] = ACTIONS(6691),
    [anon_sym_bufif0] = ACTIONS(6691),
    [anon_sym_bufif1] = ACTIONS(6691),
    [anon_sym_notif0] = ACTIONS(6691),
    [anon_sym_notif1] = ACTIONS(6691),
    [anon_sym_nmos] = ACTIONS(6691),
    [anon_sym_pmos] = ACTIONS(6691),
    [anon_sym_rnmos] = ACTIONS(6691),
    [anon_sym_rpmos] = ACTIONS(6691),
    [anon_sym_nand] = ACTIONS(6691),
    [anon_sym_nor] = ACTIONS(6691),
    [anon_sym_xor] = ACTIONS(6691),
    [anon_sym_xnor] = ACTIONS(6691),
    [anon_sym_buf] = ACTIONS(6691),
    [anon_sym_tranif0] = ACTIONS(6691),
    [anon_sym_tranif1] = ACTIONS(6691),
    [anon_sym_rtranif1] = ACTIONS(6691),
    [anon_sym_rtranif0] = ACTIONS(6691),
    [anon_sym_tran] = ACTIONS(6691),
    [anon_sym_rtran] = ACTIONS(6691),
    [anon_sym_generate] = ACTIONS(6691),
    [anon_sym_for] = ACTIONS(6691),
    [anon_sym_initial] = ACTIONS(6691),
    [anon_sym_assign] = ACTIONS(6691),
    [anon_sym_alias] = ACTIONS(6691),
    [anon_sym_always_comb] = ACTIONS(6691),
    [anon_sym_always_latch] = ACTIONS(6691),
    [anon_sym_always_ff] = ACTIONS(6691),
    [anon_sym_final] = ACTIONS(6691),
    [anon_sym_global] = ACTIONS(6691),
    [anon_sym_LPAREN_STAR] = ACTIONS(6693),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6693),
    [anon_sym_DOLLARunit] = ACTIONS(6693),
  },
  [4785] = {
    [sym_simple_identifier] = ACTIONS(5206),
    [anon_sym_wire] = ACTIONS(5206),
    [anon_sym_tri] = ACTIONS(5206),
    [anon_sym_tri0] = ACTIONS(5206),
    [anon_sym_tri1] = ACTIONS(5206),
    [anon_sym_wand] = ACTIONS(5206),
    [anon_sym_triand] = ACTIONS(5206),
    [anon_sym_wor] = ACTIONS(5206),
    [anon_sym_trior] = ACTIONS(5206),
    [anon_sym_trireg] = ACTIONS(5206),
    [anon_sym_uwire] = ACTIONS(5206),
    [anon_sym_SEMI] = ACTIONS(5204),
    [anon_sym_extern] = ACTIONS(5206),
    [anon_sym_interface] = ACTIONS(5206),
    [anon_sym_checker] = ACTIONS(5206),
    [anon_sym_virtual] = ACTIONS(5206),
    [anon_sym_class] = ACTIONS(5206),
    [anon_sym_type] = ACTIONS(5206),
    [anon_sym_DOLLARfatal] = ACTIONS(5204),
    [anon_sym_DOLLARerror] = ACTIONS(5204),
    [anon_sym_DOLLARwarning] = ACTIONS(5204),
    [anon_sym_DOLLARinfo] = ACTIONS(5204),
    [anon_sym_default] = ACTIONS(5206),
    [anon_sym_clocking] = ACTIONS(5206),
    [anon_sym_defparam] = ACTIONS(5206),
    [anon_sym_bind] = ACTIONS(5206),
    [anon_sym_rand] = ACTIONS(5206),
    [anon_sym_const] = ACTIONS(5206),
    [anon_sym_function] = ACTIONS(5206),
    [anon_sym_static] = ACTIONS(5206),
    [anon_sym_constraint] = ACTIONS(5206),
    [anon_sym_if] = ACTIONS(5206),
    [anon_sym_else] = ACTIONS(5206),
    [anon_sym_LBRACK] = ACTIONS(5204),
    [anon_sym_localparam] = ACTIONS(5206),
    [anon_sym_parameter] = ACTIONS(5206),
    [anon_sym_var] = ACTIONS(5206),
    [anon_sym_import] = ACTIONS(5206),
    [anon_sym_export] = ACTIONS(5206),
    [anon_sym_genvar] = ACTIONS(5206),
    [anon_sym_interconnect] = ACTIONS(5206),
    [anon_sym_typedef] = ACTIONS(5206),
    [anon_sym_enum] = ACTIONS(5206),
    [anon_sym_struct] = ACTIONS(5206),
    [anon_sym_union] = ACTIONS(5206),
    [anon_sym_nettype] = ACTIONS(5206),
    [anon_sym_automatic] = ACTIONS(5206),
    [anon_sym_string] = ACTIONS(5206),
    [anon_sym_chandle] = ACTIONS(5206),
    [anon_sym_event] = ACTIONS(5206),
    [anon_sym_byte] = ACTIONS(5206),
    [anon_sym_shortint] = ACTIONS(5206),
    [anon_sym_int] = ACTIONS(5206),
    [anon_sym_longint] = ACTIONS(5206),
    [anon_sym_integer] = ACTIONS(5206),
    [anon_sym_time] = ACTIONS(5206),
    [anon_sym_bit] = ACTIONS(5206),
    [anon_sym_logic] = ACTIONS(5206),
    [anon_sym_reg] = ACTIONS(5206),
    [anon_sym_shortreal] = ACTIONS(5206),
    [anon_sym_real] = ACTIONS(5206),
    [anon_sym_realtime] = ACTIONS(5206),
    [anon_sym_supply0] = ACTIONS(5206),
    [anon_sym_supply1] = ACTIONS(5206),
    [anon_sym_signed] = ACTIONS(5206),
    [anon_sym_unsigned] = ACTIONS(5206),
    [anon_sym_task] = ACTIONS(5206),
    [anon_sym_assert] = ACTIONS(5206),
    [anon_sym_property] = ACTIONS(5206),
    [anon_sym_assume] = ACTIONS(5206),
    [anon_sym_cover] = ACTIONS(5206),
    [anon_sym_sequence] = ACTIONS(5206),
    [anon_sym_restrict] = ACTIONS(5206),
    [anon_sym_not] = ACTIONS(5206),
    [anon_sym_or] = ACTIONS(5206),
    [anon_sym_and] = ACTIONS(5206),
    [anon_sym_case] = ACTIONS(5206),
    [anon_sym_always] = ACTIONS(5206),
    [anon_sym_covergroup] = ACTIONS(5206),
    [anon_sym_end] = ACTIONS(5206),
    [anon_sym_let] = ACTIONS(5206),
    [anon_sym_pulldown] = ACTIONS(5206),
    [anon_sym_pullup] = ACTIONS(5206),
    [anon_sym_cmos] = ACTIONS(5206),
    [anon_sym_rcmos] = ACTIONS(5206),
    [anon_sym_bufif0] = ACTIONS(5206),
    [anon_sym_bufif1] = ACTIONS(5206),
    [anon_sym_notif0] = ACTIONS(5206),
    [anon_sym_notif1] = ACTIONS(5206),
    [anon_sym_nmos] = ACTIONS(5206),
    [anon_sym_pmos] = ACTIONS(5206),
    [anon_sym_rnmos] = ACTIONS(5206),
    [anon_sym_rpmos] = ACTIONS(5206),
    [anon_sym_nand] = ACTIONS(5206),
    [anon_sym_nor] = ACTIONS(5206),
    [anon_sym_xor] = ACTIONS(5206),
    [anon_sym_xnor] = ACTIONS(5206),
    [anon_sym_buf] = ACTIONS(5206),
    [anon_sym_tranif0] = ACTIONS(5206),
    [anon_sym_tranif1] = ACTIONS(5206),
    [anon_sym_rtranif1] = ACTIONS(5206),
    [anon_sym_rtranif0] = ACTIONS(5206),
    [anon_sym_tran] = ACTIONS(5206),
    [anon_sym_rtran] = ACTIONS(5206),
    [anon_sym_generate] = ACTIONS(5206),
    [anon_sym_for] = ACTIONS(5206),
    [anon_sym_initial] = ACTIONS(5206),
    [anon_sym_assign] = ACTIONS(5206),
    [anon_sym_alias] = ACTIONS(5206),
    [anon_sym_always_comb] = ACTIONS(5206),
    [anon_sym_always_latch] = ACTIONS(5206),
    [anon_sym_always_ff] = ACTIONS(5206),
    [anon_sym_final] = ACTIONS(5206),
    [anon_sym_global] = ACTIONS(5206),
    [anon_sym_LPAREN_STAR] = ACTIONS(5204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5204),
    [anon_sym_DOLLARunit] = ACTIONS(5204),
  },
  [4786] = {
    [sym_simple_identifier] = ACTIONS(5888),
    [anon_sym_wire] = ACTIONS(5888),
    [anon_sym_tri] = ACTIONS(5888),
    [anon_sym_tri0] = ACTIONS(5888),
    [anon_sym_tri1] = ACTIONS(5888),
    [anon_sym_wand] = ACTIONS(5888),
    [anon_sym_triand] = ACTIONS(5888),
    [anon_sym_wor] = ACTIONS(5888),
    [anon_sym_trior] = ACTIONS(5888),
    [anon_sym_trireg] = ACTIONS(5888),
    [anon_sym_uwire] = ACTIONS(5888),
    [anon_sym_SEMI] = ACTIONS(5890),
    [anon_sym_extern] = ACTIONS(5888),
    [anon_sym_interface] = ACTIONS(5888),
    [anon_sym_checker] = ACTIONS(5888),
    [anon_sym_virtual] = ACTIONS(5888),
    [anon_sym_class] = ACTIONS(5888),
    [anon_sym_type] = ACTIONS(5888),
    [anon_sym_DOLLARfatal] = ACTIONS(5890),
    [anon_sym_DOLLARerror] = ACTIONS(5890),
    [anon_sym_DOLLARwarning] = ACTIONS(5890),
    [anon_sym_DOLLARinfo] = ACTIONS(5890),
    [anon_sym_default] = ACTIONS(5888),
    [anon_sym_clocking] = ACTIONS(5888),
    [anon_sym_defparam] = ACTIONS(5888),
    [anon_sym_bind] = ACTIONS(5888),
    [anon_sym_rand] = ACTIONS(5888),
    [anon_sym_const] = ACTIONS(5888),
    [anon_sym_function] = ACTIONS(5888),
    [anon_sym_static] = ACTIONS(5888),
    [anon_sym_constraint] = ACTIONS(5888),
    [anon_sym_if] = ACTIONS(5888),
    [anon_sym_else] = ACTIONS(5888),
    [anon_sym_LBRACK] = ACTIONS(5890),
    [anon_sym_localparam] = ACTIONS(5888),
    [anon_sym_parameter] = ACTIONS(5888),
    [anon_sym_var] = ACTIONS(5888),
    [anon_sym_import] = ACTIONS(5888),
    [anon_sym_export] = ACTIONS(5888),
    [anon_sym_genvar] = ACTIONS(5888),
    [anon_sym_interconnect] = ACTIONS(5888),
    [anon_sym_typedef] = ACTIONS(5888),
    [anon_sym_enum] = ACTIONS(5888),
    [anon_sym_struct] = ACTIONS(5888),
    [anon_sym_union] = ACTIONS(5888),
    [anon_sym_nettype] = ACTIONS(5888),
    [anon_sym_automatic] = ACTIONS(5888),
    [anon_sym_string] = ACTIONS(5888),
    [anon_sym_chandle] = ACTIONS(5888),
    [anon_sym_event] = ACTIONS(5888),
    [anon_sym_byte] = ACTIONS(5888),
    [anon_sym_shortint] = ACTIONS(5888),
    [anon_sym_int] = ACTIONS(5888),
    [anon_sym_longint] = ACTIONS(5888),
    [anon_sym_integer] = ACTIONS(5888),
    [anon_sym_time] = ACTIONS(5888),
    [anon_sym_bit] = ACTIONS(5888),
    [anon_sym_logic] = ACTIONS(5888),
    [anon_sym_reg] = ACTIONS(5888),
    [anon_sym_shortreal] = ACTIONS(5888),
    [anon_sym_real] = ACTIONS(5888),
    [anon_sym_realtime] = ACTIONS(5888),
    [anon_sym_supply0] = ACTIONS(5888),
    [anon_sym_supply1] = ACTIONS(5888),
    [anon_sym_signed] = ACTIONS(5888),
    [anon_sym_unsigned] = ACTIONS(5888),
    [anon_sym_task] = ACTIONS(5888),
    [anon_sym_assert] = ACTIONS(5888),
    [anon_sym_property] = ACTIONS(5888),
    [anon_sym_assume] = ACTIONS(5888),
    [anon_sym_cover] = ACTIONS(5888),
    [anon_sym_sequence] = ACTIONS(5888),
    [anon_sym_restrict] = ACTIONS(5888),
    [anon_sym_not] = ACTIONS(5888),
    [anon_sym_or] = ACTIONS(5888),
    [anon_sym_and] = ACTIONS(5888),
    [anon_sym_case] = ACTIONS(5888),
    [anon_sym_always] = ACTIONS(5888),
    [anon_sym_covergroup] = ACTIONS(5888),
    [anon_sym_end] = ACTIONS(5888),
    [anon_sym_let] = ACTIONS(5888),
    [anon_sym_pulldown] = ACTIONS(5888),
    [anon_sym_pullup] = ACTIONS(5888),
    [anon_sym_cmos] = ACTIONS(5888),
    [anon_sym_rcmos] = ACTIONS(5888),
    [anon_sym_bufif0] = ACTIONS(5888),
    [anon_sym_bufif1] = ACTIONS(5888),
    [anon_sym_notif0] = ACTIONS(5888),
    [anon_sym_notif1] = ACTIONS(5888),
    [anon_sym_nmos] = ACTIONS(5888),
    [anon_sym_pmos] = ACTIONS(5888),
    [anon_sym_rnmos] = ACTIONS(5888),
    [anon_sym_rpmos] = ACTIONS(5888),
    [anon_sym_nand] = ACTIONS(5888),
    [anon_sym_nor] = ACTIONS(5888),
    [anon_sym_xor] = ACTIONS(5888),
    [anon_sym_xnor] = ACTIONS(5888),
    [anon_sym_buf] = ACTIONS(5888),
    [anon_sym_tranif0] = ACTIONS(5888),
    [anon_sym_tranif1] = ACTIONS(5888),
    [anon_sym_rtranif1] = ACTIONS(5888),
    [anon_sym_rtranif0] = ACTIONS(5888),
    [anon_sym_tran] = ACTIONS(5888),
    [anon_sym_rtran] = ACTIONS(5888),
    [anon_sym_generate] = ACTIONS(5888),
    [anon_sym_for] = ACTIONS(5888),
    [anon_sym_initial] = ACTIONS(5888),
    [anon_sym_assign] = ACTIONS(5888),
    [anon_sym_alias] = ACTIONS(5888),
    [anon_sym_always_comb] = ACTIONS(5888),
    [anon_sym_always_latch] = ACTIONS(5888),
    [anon_sym_always_ff] = ACTIONS(5888),
    [anon_sym_final] = ACTIONS(5888),
    [anon_sym_global] = ACTIONS(5888),
    [anon_sym_LPAREN_STAR] = ACTIONS(5890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5890),
    [anon_sym_DOLLARunit] = ACTIONS(5890),
  },
  [4787] = {
    [sym_simple_identifier] = ACTIONS(6157),
    [anon_sym_wire] = ACTIONS(6157),
    [anon_sym_tri] = ACTIONS(6157),
    [anon_sym_tri0] = ACTIONS(6157),
    [anon_sym_tri1] = ACTIONS(6157),
    [anon_sym_wand] = ACTIONS(6157),
    [anon_sym_triand] = ACTIONS(6157),
    [anon_sym_wor] = ACTIONS(6157),
    [anon_sym_trior] = ACTIONS(6157),
    [anon_sym_trireg] = ACTIONS(6157),
    [anon_sym_uwire] = ACTIONS(6157),
    [anon_sym_SEMI] = ACTIONS(6159),
    [anon_sym_extern] = ACTIONS(6157),
    [anon_sym_interface] = ACTIONS(6157),
    [anon_sym_checker] = ACTIONS(6157),
    [anon_sym_virtual] = ACTIONS(6157),
    [anon_sym_class] = ACTIONS(6157),
    [anon_sym_type] = ACTIONS(6157),
    [anon_sym_DOLLARfatal] = ACTIONS(6159),
    [anon_sym_DOLLARerror] = ACTIONS(6159),
    [anon_sym_DOLLARwarning] = ACTIONS(6159),
    [anon_sym_DOLLARinfo] = ACTIONS(6159),
    [anon_sym_default] = ACTIONS(6157),
    [anon_sym_clocking] = ACTIONS(6157),
    [anon_sym_defparam] = ACTIONS(6157),
    [anon_sym_bind] = ACTIONS(6157),
    [anon_sym_rand] = ACTIONS(6157),
    [anon_sym_const] = ACTIONS(6157),
    [anon_sym_function] = ACTIONS(6157),
    [anon_sym_static] = ACTIONS(6157),
    [anon_sym_constraint] = ACTIONS(6157),
    [anon_sym_if] = ACTIONS(6157),
    [anon_sym_else] = ACTIONS(6157),
    [anon_sym_LBRACK] = ACTIONS(6159),
    [anon_sym_localparam] = ACTIONS(6157),
    [anon_sym_parameter] = ACTIONS(6157),
    [anon_sym_var] = ACTIONS(6157),
    [anon_sym_import] = ACTIONS(6157),
    [anon_sym_export] = ACTIONS(6157),
    [anon_sym_genvar] = ACTIONS(6157),
    [anon_sym_interconnect] = ACTIONS(6157),
    [anon_sym_typedef] = ACTIONS(6157),
    [anon_sym_enum] = ACTIONS(6157),
    [anon_sym_struct] = ACTIONS(6157),
    [anon_sym_union] = ACTIONS(6157),
    [anon_sym_nettype] = ACTIONS(6157),
    [anon_sym_automatic] = ACTIONS(6157),
    [anon_sym_string] = ACTIONS(6157),
    [anon_sym_chandle] = ACTIONS(6157),
    [anon_sym_event] = ACTIONS(6157),
    [anon_sym_byte] = ACTIONS(6157),
    [anon_sym_shortint] = ACTIONS(6157),
    [anon_sym_int] = ACTIONS(6157),
    [anon_sym_longint] = ACTIONS(6157),
    [anon_sym_integer] = ACTIONS(6157),
    [anon_sym_time] = ACTIONS(6157),
    [anon_sym_bit] = ACTIONS(6157),
    [anon_sym_logic] = ACTIONS(6157),
    [anon_sym_reg] = ACTIONS(6157),
    [anon_sym_shortreal] = ACTIONS(6157),
    [anon_sym_real] = ACTIONS(6157),
    [anon_sym_realtime] = ACTIONS(6157),
    [anon_sym_supply0] = ACTIONS(6157),
    [anon_sym_supply1] = ACTIONS(6157),
    [anon_sym_signed] = ACTIONS(6157),
    [anon_sym_unsigned] = ACTIONS(6157),
    [anon_sym_task] = ACTIONS(6157),
    [anon_sym_assert] = ACTIONS(6157),
    [anon_sym_property] = ACTIONS(6157),
    [anon_sym_assume] = ACTIONS(6157),
    [anon_sym_cover] = ACTIONS(6157),
    [anon_sym_sequence] = ACTIONS(6157),
    [anon_sym_restrict] = ACTIONS(6157),
    [anon_sym_not] = ACTIONS(6157),
    [anon_sym_or] = ACTIONS(6157),
    [anon_sym_and] = ACTIONS(6157),
    [anon_sym_case] = ACTIONS(6157),
    [anon_sym_always] = ACTIONS(6157),
    [anon_sym_covergroup] = ACTIONS(6157),
    [anon_sym_let] = ACTIONS(6157),
    [anon_sym_pulldown] = ACTIONS(6157),
    [anon_sym_pullup] = ACTIONS(6157),
    [anon_sym_cmos] = ACTIONS(6157),
    [anon_sym_rcmos] = ACTIONS(6157),
    [anon_sym_bufif0] = ACTIONS(6157),
    [anon_sym_bufif1] = ACTIONS(6157),
    [anon_sym_notif0] = ACTIONS(6157),
    [anon_sym_notif1] = ACTIONS(6157),
    [anon_sym_nmos] = ACTIONS(6157),
    [anon_sym_pmos] = ACTIONS(6157),
    [anon_sym_rnmos] = ACTIONS(6157),
    [anon_sym_rpmos] = ACTIONS(6157),
    [anon_sym_nand] = ACTIONS(6157),
    [anon_sym_nor] = ACTIONS(6157),
    [anon_sym_xor] = ACTIONS(6157),
    [anon_sym_xnor] = ACTIONS(6157),
    [anon_sym_buf] = ACTIONS(6157),
    [anon_sym_tranif0] = ACTIONS(6157),
    [anon_sym_tranif1] = ACTIONS(6157),
    [anon_sym_rtranif1] = ACTIONS(6157),
    [anon_sym_rtranif0] = ACTIONS(6157),
    [anon_sym_tran] = ACTIONS(6157),
    [anon_sym_rtran] = ACTIONS(6157),
    [anon_sym_generate] = ACTIONS(6157),
    [anon_sym_endgenerate] = ACTIONS(6157),
    [anon_sym_for] = ACTIONS(6157),
    [anon_sym_initial] = ACTIONS(6157),
    [anon_sym_assign] = ACTIONS(6157),
    [anon_sym_alias] = ACTIONS(6157),
    [anon_sym_always_comb] = ACTIONS(6157),
    [anon_sym_always_latch] = ACTIONS(6157),
    [anon_sym_always_ff] = ACTIONS(6157),
    [anon_sym_final] = ACTIONS(6157),
    [anon_sym_global] = ACTIONS(6157),
    [anon_sym_LPAREN_STAR] = ACTIONS(6159),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6159),
    [anon_sym_DOLLARunit] = ACTIONS(6159),
  },
  [4788] = {
    [sym_simple_identifier] = ACTIONS(4968),
    [anon_sym_wire] = ACTIONS(4968),
    [anon_sym_tri] = ACTIONS(4968),
    [anon_sym_tri0] = ACTIONS(4968),
    [anon_sym_tri1] = ACTIONS(4968),
    [anon_sym_wand] = ACTIONS(4968),
    [anon_sym_triand] = ACTIONS(4968),
    [anon_sym_wor] = ACTIONS(4968),
    [anon_sym_trior] = ACTIONS(4968),
    [anon_sym_trireg] = ACTIONS(4968),
    [anon_sym_uwire] = ACTIONS(4968),
    [anon_sym_SEMI] = ACTIONS(4966),
    [anon_sym_extern] = ACTIONS(4968),
    [anon_sym_interface] = ACTIONS(4968),
    [anon_sym_checker] = ACTIONS(4968),
    [anon_sym_virtual] = ACTIONS(4968),
    [anon_sym_class] = ACTIONS(4968),
    [anon_sym_type] = ACTIONS(4968),
    [anon_sym_DOLLARfatal] = ACTIONS(4966),
    [anon_sym_DOLLARerror] = ACTIONS(4966),
    [anon_sym_DOLLARwarning] = ACTIONS(4966),
    [anon_sym_DOLLARinfo] = ACTIONS(4966),
    [anon_sym_default] = ACTIONS(4968),
    [anon_sym_clocking] = ACTIONS(4968),
    [anon_sym_defparam] = ACTIONS(4968),
    [anon_sym_bind] = ACTIONS(4968),
    [anon_sym_rand] = ACTIONS(4968),
    [anon_sym_const] = ACTIONS(4968),
    [anon_sym_function] = ACTIONS(4968),
    [anon_sym_static] = ACTIONS(4968),
    [anon_sym_constraint] = ACTIONS(4968),
    [anon_sym_if] = ACTIONS(4968),
    [anon_sym_else] = ACTIONS(4968),
    [anon_sym_LBRACK] = ACTIONS(4966),
    [anon_sym_localparam] = ACTIONS(4968),
    [anon_sym_parameter] = ACTIONS(4968),
    [anon_sym_var] = ACTIONS(4968),
    [anon_sym_import] = ACTIONS(4968),
    [anon_sym_export] = ACTIONS(4968),
    [anon_sym_genvar] = ACTIONS(4968),
    [anon_sym_interconnect] = ACTIONS(4968),
    [anon_sym_typedef] = ACTIONS(4968),
    [anon_sym_enum] = ACTIONS(4968),
    [anon_sym_struct] = ACTIONS(4968),
    [anon_sym_union] = ACTIONS(4968),
    [anon_sym_nettype] = ACTIONS(4968),
    [anon_sym_automatic] = ACTIONS(4968),
    [anon_sym_string] = ACTIONS(4968),
    [anon_sym_chandle] = ACTIONS(4968),
    [anon_sym_event] = ACTIONS(4968),
    [anon_sym_byte] = ACTIONS(4968),
    [anon_sym_shortint] = ACTIONS(4968),
    [anon_sym_int] = ACTIONS(4968),
    [anon_sym_longint] = ACTIONS(4968),
    [anon_sym_integer] = ACTIONS(4968),
    [anon_sym_time] = ACTIONS(4968),
    [anon_sym_bit] = ACTIONS(4968),
    [anon_sym_logic] = ACTIONS(4968),
    [anon_sym_reg] = ACTIONS(4968),
    [anon_sym_shortreal] = ACTIONS(4968),
    [anon_sym_real] = ACTIONS(4968),
    [anon_sym_realtime] = ACTIONS(4968),
    [anon_sym_supply0] = ACTIONS(4968),
    [anon_sym_supply1] = ACTIONS(4968),
    [anon_sym_signed] = ACTIONS(4968),
    [anon_sym_unsigned] = ACTIONS(4968),
    [anon_sym_task] = ACTIONS(4968),
    [anon_sym_assert] = ACTIONS(4968),
    [anon_sym_property] = ACTIONS(4968),
    [anon_sym_assume] = ACTIONS(4968),
    [anon_sym_cover] = ACTIONS(4968),
    [anon_sym_sequence] = ACTIONS(4968),
    [anon_sym_restrict] = ACTIONS(4968),
    [anon_sym_not] = ACTIONS(4968),
    [anon_sym_or] = ACTIONS(4968),
    [anon_sym_and] = ACTIONS(4968),
    [anon_sym_case] = ACTIONS(4968),
    [anon_sym_always] = ACTIONS(4968),
    [anon_sym_covergroup] = ACTIONS(4968),
    [anon_sym_end] = ACTIONS(4968),
    [anon_sym_let] = ACTIONS(4968),
    [anon_sym_pulldown] = ACTIONS(4968),
    [anon_sym_pullup] = ACTIONS(4968),
    [anon_sym_cmos] = ACTIONS(4968),
    [anon_sym_rcmos] = ACTIONS(4968),
    [anon_sym_bufif0] = ACTIONS(4968),
    [anon_sym_bufif1] = ACTIONS(4968),
    [anon_sym_notif0] = ACTIONS(4968),
    [anon_sym_notif1] = ACTIONS(4968),
    [anon_sym_nmos] = ACTIONS(4968),
    [anon_sym_pmos] = ACTIONS(4968),
    [anon_sym_rnmos] = ACTIONS(4968),
    [anon_sym_rpmos] = ACTIONS(4968),
    [anon_sym_nand] = ACTIONS(4968),
    [anon_sym_nor] = ACTIONS(4968),
    [anon_sym_xor] = ACTIONS(4968),
    [anon_sym_xnor] = ACTIONS(4968),
    [anon_sym_buf] = ACTIONS(4968),
    [anon_sym_tranif0] = ACTIONS(4968),
    [anon_sym_tranif1] = ACTIONS(4968),
    [anon_sym_rtranif1] = ACTIONS(4968),
    [anon_sym_rtranif0] = ACTIONS(4968),
    [anon_sym_tran] = ACTIONS(4968),
    [anon_sym_rtran] = ACTIONS(4968),
    [anon_sym_generate] = ACTIONS(4968),
    [anon_sym_for] = ACTIONS(4968),
    [anon_sym_initial] = ACTIONS(4968),
    [anon_sym_assign] = ACTIONS(4968),
    [anon_sym_alias] = ACTIONS(4968),
    [anon_sym_always_comb] = ACTIONS(4968),
    [anon_sym_always_latch] = ACTIONS(4968),
    [anon_sym_always_ff] = ACTIONS(4968),
    [anon_sym_final] = ACTIONS(4968),
    [anon_sym_global] = ACTIONS(4968),
    [anon_sym_LPAREN_STAR] = ACTIONS(4966),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4966),
    [anon_sym_DOLLARunit] = ACTIONS(4966),
  },
  [4789] = {
    [sym_simple_identifier] = ACTIONS(6115),
    [anon_sym_wire] = ACTIONS(6115),
    [anon_sym_tri] = ACTIONS(6115),
    [anon_sym_tri0] = ACTIONS(6115),
    [anon_sym_tri1] = ACTIONS(6115),
    [anon_sym_wand] = ACTIONS(6115),
    [anon_sym_triand] = ACTIONS(6115),
    [anon_sym_wor] = ACTIONS(6115),
    [anon_sym_trior] = ACTIONS(6115),
    [anon_sym_trireg] = ACTIONS(6115),
    [anon_sym_uwire] = ACTIONS(6115),
    [anon_sym_SEMI] = ACTIONS(6117),
    [anon_sym_extern] = ACTIONS(6115),
    [anon_sym_interface] = ACTIONS(6115),
    [anon_sym_checker] = ACTIONS(6115),
    [anon_sym_virtual] = ACTIONS(6115),
    [anon_sym_class] = ACTIONS(6115),
    [anon_sym_type] = ACTIONS(6115),
    [anon_sym_DOLLARfatal] = ACTIONS(6117),
    [anon_sym_DOLLARerror] = ACTIONS(6117),
    [anon_sym_DOLLARwarning] = ACTIONS(6117),
    [anon_sym_DOLLARinfo] = ACTIONS(6117),
    [anon_sym_default] = ACTIONS(6115),
    [anon_sym_clocking] = ACTIONS(6115),
    [anon_sym_defparam] = ACTIONS(6115),
    [anon_sym_bind] = ACTIONS(6115),
    [anon_sym_rand] = ACTIONS(6115),
    [anon_sym_const] = ACTIONS(6115),
    [anon_sym_function] = ACTIONS(6115),
    [anon_sym_static] = ACTIONS(6115),
    [anon_sym_constraint] = ACTIONS(6115),
    [anon_sym_if] = ACTIONS(6115),
    [anon_sym_else] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(6117),
    [anon_sym_localparam] = ACTIONS(6115),
    [anon_sym_parameter] = ACTIONS(6115),
    [anon_sym_var] = ACTIONS(6115),
    [anon_sym_import] = ACTIONS(6115),
    [anon_sym_export] = ACTIONS(6115),
    [anon_sym_genvar] = ACTIONS(6115),
    [anon_sym_interconnect] = ACTIONS(6115),
    [anon_sym_typedef] = ACTIONS(6115),
    [anon_sym_enum] = ACTIONS(6115),
    [anon_sym_struct] = ACTIONS(6115),
    [anon_sym_union] = ACTIONS(6115),
    [anon_sym_nettype] = ACTIONS(6115),
    [anon_sym_automatic] = ACTIONS(6115),
    [anon_sym_string] = ACTIONS(6115),
    [anon_sym_chandle] = ACTIONS(6115),
    [anon_sym_event] = ACTIONS(6115),
    [anon_sym_byte] = ACTIONS(6115),
    [anon_sym_shortint] = ACTIONS(6115),
    [anon_sym_int] = ACTIONS(6115),
    [anon_sym_longint] = ACTIONS(6115),
    [anon_sym_integer] = ACTIONS(6115),
    [anon_sym_time] = ACTIONS(6115),
    [anon_sym_bit] = ACTIONS(6115),
    [anon_sym_logic] = ACTIONS(6115),
    [anon_sym_reg] = ACTIONS(6115),
    [anon_sym_shortreal] = ACTIONS(6115),
    [anon_sym_real] = ACTIONS(6115),
    [anon_sym_realtime] = ACTIONS(6115),
    [anon_sym_supply0] = ACTIONS(6115),
    [anon_sym_supply1] = ACTIONS(6115),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_task] = ACTIONS(6115),
    [anon_sym_assert] = ACTIONS(6115),
    [anon_sym_property] = ACTIONS(6115),
    [anon_sym_assume] = ACTIONS(6115),
    [anon_sym_cover] = ACTIONS(6115),
    [anon_sym_sequence] = ACTIONS(6115),
    [anon_sym_restrict] = ACTIONS(6115),
    [anon_sym_not] = ACTIONS(6115),
    [anon_sym_or] = ACTIONS(6115),
    [anon_sym_and] = ACTIONS(6115),
    [anon_sym_case] = ACTIONS(6115),
    [anon_sym_always] = ACTIONS(6115),
    [anon_sym_covergroup] = ACTIONS(6115),
    [anon_sym_let] = ACTIONS(6115),
    [anon_sym_pulldown] = ACTIONS(6115),
    [anon_sym_pullup] = ACTIONS(6115),
    [anon_sym_cmos] = ACTIONS(6115),
    [anon_sym_rcmos] = ACTIONS(6115),
    [anon_sym_bufif0] = ACTIONS(6115),
    [anon_sym_bufif1] = ACTIONS(6115),
    [anon_sym_notif0] = ACTIONS(6115),
    [anon_sym_notif1] = ACTIONS(6115),
    [anon_sym_nmos] = ACTIONS(6115),
    [anon_sym_pmos] = ACTIONS(6115),
    [anon_sym_rnmos] = ACTIONS(6115),
    [anon_sym_rpmos] = ACTIONS(6115),
    [anon_sym_nand] = ACTIONS(6115),
    [anon_sym_nor] = ACTIONS(6115),
    [anon_sym_xor] = ACTIONS(6115),
    [anon_sym_xnor] = ACTIONS(6115),
    [anon_sym_buf] = ACTIONS(6115),
    [anon_sym_tranif0] = ACTIONS(6115),
    [anon_sym_tranif1] = ACTIONS(6115),
    [anon_sym_rtranif1] = ACTIONS(6115),
    [anon_sym_rtranif0] = ACTIONS(6115),
    [anon_sym_tran] = ACTIONS(6115),
    [anon_sym_rtran] = ACTIONS(6115),
    [anon_sym_generate] = ACTIONS(6115),
    [anon_sym_endgenerate] = ACTIONS(6115),
    [anon_sym_for] = ACTIONS(6115),
    [anon_sym_initial] = ACTIONS(6115),
    [anon_sym_assign] = ACTIONS(6115),
    [anon_sym_alias] = ACTIONS(6115),
    [anon_sym_always_comb] = ACTIONS(6115),
    [anon_sym_always_latch] = ACTIONS(6115),
    [anon_sym_always_ff] = ACTIONS(6115),
    [anon_sym_final] = ACTIONS(6115),
    [anon_sym_global] = ACTIONS(6115),
    [anon_sym_LPAREN_STAR] = ACTIONS(6117),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6117),
    [anon_sym_DOLLARunit] = ACTIONS(6117),
  },
  [4790] = {
    [sym_simple_identifier] = ACTIONS(5896),
    [anon_sym_wire] = ACTIONS(5896),
    [anon_sym_tri] = ACTIONS(5896),
    [anon_sym_tri0] = ACTIONS(5896),
    [anon_sym_tri1] = ACTIONS(5896),
    [anon_sym_wand] = ACTIONS(5896),
    [anon_sym_triand] = ACTIONS(5896),
    [anon_sym_wor] = ACTIONS(5896),
    [anon_sym_trior] = ACTIONS(5896),
    [anon_sym_trireg] = ACTIONS(5896),
    [anon_sym_uwire] = ACTIONS(5896),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym_extern] = ACTIONS(5896),
    [anon_sym_interface] = ACTIONS(5896),
    [anon_sym_checker] = ACTIONS(5896),
    [anon_sym_virtual] = ACTIONS(5896),
    [anon_sym_class] = ACTIONS(5896),
    [anon_sym_type] = ACTIONS(5896),
    [anon_sym_DOLLARfatal] = ACTIONS(5898),
    [anon_sym_DOLLARerror] = ACTIONS(5898),
    [anon_sym_DOLLARwarning] = ACTIONS(5898),
    [anon_sym_DOLLARinfo] = ACTIONS(5898),
    [anon_sym_default] = ACTIONS(5896),
    [anon_sym_clocking] = ACTIONS(5896),
    [anon_sym_defparam] = ACTIONS(5896),
    [anon_sym_bind] = ACTIONS(5896),
    [anon_sym_rand] = ACTIONS(5896),
    [anon_sym_const] = ACTIONS(5896),
    [anon_sym_function] = ACTIONS(5896),
    [anon_sym_static] = ACTIONS(5896),
    [anon_sym_constraint] = ACTIONS(5896),
    [anon_sym_if] = ACTIONS(5896),
    [anon_sym_else] = ACTIONS(5896),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_localparam] = ACTIONS(5896),
    [anon_sym_parameter] = ACTIONS(5896),
    [anon_sym_var] = ACTIONS(5896),
    [anon_sym_import] = ACTIONS(5896),
    [anon_sym_export] = ACTIONS(5896),
    [anon_sym_genvar] = ACTIONS(5896),
    [anon_sym_interconnect] = ACTIONS(5896),
    [anon_sym_typedef] = ACTIONS(5896),
    [anon_sym_enum] = ACTIONS(5896),
    [anon_sym_struct] = ACTIONS(5896),
    [anon_sym_union] = ACTIONS(5896),
    [anon_sym_nettype] = ACTIONS(5896),
    [anon_sym_automatic] = ACTIONS(5896),
    [anon_sym_string] = ACTIONS(5896),
    [anon_sym_chandle] = ACTIONS(5896),
    [anon_sym_event] = ACTIONS(5896),
    [anon_sym_byte] = ACTIONS(5896),
    [anon_sym_shortint] = ACTIONS(5896),
    [anon_sym_int] = ACTIONS(5896),
    [anon_sym_longint] = ACTIONS(5896),
    [anon_sym_integer] = ACTIONS(5896),
    [anon_sym_time] = ACTIONS(5896),
    [anon_sym_bit] = ACTIONS(5896),
    [anon_sym_logic] = ACTIONS(5896),
    [anon_sym_reg] = ACTIONS(5896),
    [anon_sym_shortreal] = ACTIONS(5896),
    [anon_sym_real] = ACTIONS(5896),
    [anon_sym_realtime] = ACTIONS(5896),
    [anon_sym_supply0] = ACTIONS(5896),
    [anon_sym_supply1] = ACTIONS(5896),
    [anon_sym_signed] = ACTIONS(5896),
    [anon_sym_unsigned] = ACTIONS(5896),
    [anon_sym_task] = ACTIONS(5896),
    [anon_sym_assert] = ACTIONS(5896),
    [anon_sym_property] = ACTIONS(5896),
    [anon_sym_assume] = ACTIONS(5896),
    [anon_sym_cover] = ACTIONS(5896),
    [anon_sym_sequence] = ACTIONS(5896),
    [anon_sym_restrict] = ACTIONS(5896),
    [anon_sym_not] = ACTIONS(5896),
    [anon_sym_or] = ACTIONS(5896),
    [anon_sym_and] = ACTIONS(5896),
    [anon_sym_case] = ACTIONS(5896),
    [anon_sym_always] = ACTIONS(5896),
    [anon_sym_covergroup] = ACTIONS(5896),
    [anon_sym_end] = ACTIONS(5896),
    [anon_sym_let] = ACTIONS(5896),
    [anon_sym_pulldown] = ACTIONS(5896),
    [anon_sym_pullup] = ACTIONS(5896),
    [anon_sym_cmos] = ACTIONS(5896),
    [anon_sym_rcmos] = ACTIONS(5896),
    [anon_sym_bufif0] = ACTIONS(5896),
    [anon_sym_bufif1] = ACTIONS(5896),
    [anon_sym_notif0] = ACTIONS(5896),
    [anon_sym_notif1] = ACTIONS(5896),
    [anon_sym_nmos] = ACTIONS(5896),
    [anon_sym_pmos] = ACTIONS(5896),
    [anon_sym_rnmos] = ACTIONS(5896),
    [anon_sym_rpmos] = ACTIONS(5896),
    [anon_sym_nand] = ACTIONS(5896),
    [anon_sym_nor] = ACTIONS(5896),
    [anon_sym_xor] = ACTIONS(5896),
    [anon_sym_xnor] = ACTIONS(5896),
    [anon_sym_buf] = ACTIONS(5896),
    [anon_sym_tranif0] = ACTIONS(5896),
    [anon_sym_tranif1] = ACTIONS(5896),
    [anon_sym_rtranif1] = ACTIONS(5896),
    [anon_sym_rtranif0] = ACTIONS(5896),
    [anon_sym_tran] = ACTIONS(5896),
    [anon_sym_rtran] = ACTIONS(5896),
    [anon_sym_generate] = ACTIONS(5896),
    [anon_sym_for] = ACTIONS(5896),
    [anon_sym_initial] = ACTIONS(5896),
    [anon_sym_assign] = ACTIONS(5896),
    [anon_sym_alias] = ACTIONS(5896),
    [anon_sym_always_comb] = ACTIONS(5896),
    [anon_sym_always_latch] = ACTIONS(5896),
    [anon_sym_always_ff] = ACTIONS(5896),
    [anon_sym_final] = ACTIONS(5896),
    [anon_sym_global] = ACTIONS(5896),
    [anon_sym_LPAREN_STAR] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5898),
    [anon_sym_DOLLARunit] = ACTIONS(5898),
  },
  [4791] = {
    [sym_simple_identifier] = ACTIONS(5250),
    [anon_sym_wire] = ACTIONS(5250),
    [anon_sym_tri] = ACTIONS(5250),
    [anon_sym_tri0] = ACTIONS(5250),
    [anon_sym_tri1] = ACTIONS(5250),
    [anon_sym_wand] = ACTIONS(5250),
    [anon_sym_triand] = ACTIONS(5250),
    [anon_sym_wor] = ACTIONS(5250),
    [anon_sym_trior] = ACTIONS(5250),
    [anon_sym_trireg] = ACTIONS(5250),
    [anon_sym_uwire] = ACTIONS(5250),
    [anon_sym_SEMI] = ACTIONS(5248),
    [anon_sym_extern] = ACTIONS(5250),
    [anon_sym_interface] = ACTIONS(5250),
    [anon_sym_checker] = ACTIONS(5250),
    [anon_sym_virtual] = ACTIONS(5250),
    [anon_sym_class] = ACTIONS(5250),
    [anon_sym_type] = ACTIONS(5250),
    [anon_sym_DOLLARfatal] = ACTIONS(5248),
    [anon_sym_DOLLARerror] = ACTIONS(5248),
    [anon_sym_DOLLARwarning] = ACTIONS(5248),
    [anon_sym_DOLLARinfo] = ACTIONS(5248),
    [anon_sym_default] = ACTIONS(5250),
    [anon_sym_clocking] = ACTIONS(5250),
    [anon_sym_defparam] = ACTIONS(5250),
    [anon_sym_bind] = ACTIONS(5250),
    [anon_sym_rand] = ACTIONS(5250),
    [anon_sym_const] = ACTIONS(5250),
    [anon_sym_function] = ACTIONS(5250),
    [anon_sym_static] = ACTIONS(5250),
    [anon_sym_constraint] = ACTIONS(5250),
    [anon_sym_if] = ACTIONS(5250),
    [anon_sym_else] = ACTIONS(5250),
    [anon_sym_LBRACK] = ACTIONS(5248),
    [anon_sym_localparam] = ACTIONS(5250),
    [anon_sym_parameter] = ACTIONS(5250),
    [anon_sym_var] = ACTIONS(5250),
    [anon_sym_import] = ACTIONS(5250),
    [anon_sym_export] = ACTIONS(5250),
    [anon_sym_genvar] = ACTIONS(5250),
    [anon_sym_interconnect] = ACTIONS(5250),
    [anon_sym_typedef] = ACTIONS(5250),
    [anon_sym_enum] = ACTIONS(5250),
    [anon_sym_struct] = ACTIONS(5250),
    [anon_sym_union] = ACTIONS(5250),
    [anon_sym_nettype] = ACTIONS(5250),
    [anon_sym_automatic] = ACTIONS(5250),
    [anon_sym_string] = ACTIONS(5250),
    [anon_sym_chandle] = ACTIONS(5250),
    [anon_sym_event] = ACTIONS(5250),
    [anon_sym_byte] = ACTIONS(5250),
    [anon_sym_shortint] = ACTIONS(5250),
    [anon_sym_int] = ACTIONS(5250),
    [anon_sym_longint] = ACTIONS(5250),
    [anon_sym_integer] = ACTIONS(5250),
    [anon_sym_time] = ACTIONS(5250),
    [anon_sym_bit] = ACTIONS(5250),
    [anon_sym_logic] = ACTIONS(5250),
    [anon_sym_reg] = ACTIONS(5250),
    [anon_sym_shortreal] = ACTIONS(5250),
    [anon_sym_real] = ACTIONS(5250),
    [anon_sym_realtime] = ACTIONS(5250),
    [anon_sym_supply0] = ACTIONS(5250),
    [anon_sym_supply1] = ACTIONS(5250),
    [anon_sym_signed] = ACTIONS(5250),
    [anon_sym_unsigned] = ACTIONS(5250),
    [anon_sym_task] = ACTIONS(5250),
    [anon_sym_assert] = ACTIONS(5250),
    [anon_sym_property] = ACTIONS(5250),
    [anon_sym_assume] = ACTIONS(5250),
    [anon_sym_cover] = ACTIONS(5250),
    [anon_sym_sequence] = ACTIONS(5250),
    [anon_sym_restrict] = ACTIONS(5250),
    [anon_sym_not] = ACTIONS(5250),
    [anon_sym_or] = ACTIONS(5250),
    [anon_sym_and] = ACTIONS(5250),
    [anon_sym_case] = ACTIONS(5250),
    [anon_sym_always] = ACTIONS(5250),
    [anon_sym_covergroup] = ACTIONS(5250),
    [anon_sym_let] = ACTIONS(5250),
    [anon_sym_pulldown] = ACTIONS(5250),
    [anon_sym_pullup] = ACTIONS(5250),
    [anon_sym_cmos] = ACTIONS(5250),
    [anon_sym_rcmos] = ACTIONS(5250),
    [anon_sym_bufif0] = ACTIONS(5250),
    [anon_sym_bufif1] = ACTIONS(5250),
    [anon_sym_notif0] = ACTIONS(5250),
    [anon_sym_notif1] = ACTIONS(5250),
    [anon_sym_nmos] = ACTIONS(5250),
    [anon_sym_pmos] = ACTIONS(5250),
    [anon_sym_rnmos] = ACTIONS(5250),
    [anon_sym_rpmos] = ACTIONS(5250),
    [anon_sym_nand] = ACTIONS(5250),
    [anon_sym_nor] = ACTIONS(5250),
    [anon_sym_xor] = ACTIONS(5250),
    [anon_sym_xnor] = ACTIONS(5250),
    [anon_sym_buf] = ACTIONS(5250),
    [anon_sym_tranif0] = ACTIONS(5250),
    [anon_sym_tranif1] = ACTIONS(5250),
    [anon_sym_rtranif1] = ACTIONS(5250),
    [anon_sym_rtranif0] = ACTIONS(5250),
    [anon_sym_tran] = ACTIONS(5250),
    [anon_sym_rtran] = ACTIONS(5250),
    [anon_sym_generate] = ACTIONS(5250),
    [anon_sym_endgenerate] = ACTIONS(5250),
    [anon_sym_for] = ACTIONS(5250),
    [anon_sym_initial] = ACTIONS(5250),
    [anon_sym_assign] = ACTIONS(5250),
    [anon_sym_alias] = ACTIONS(5250),
    [anon_sym_always_comb] = ACTIONS(5250),
    [anon_sym_always_latch] = ACTIONS(5250),
    [anon_sym_always_ff] = ACTIONS(5250),
    [anon_sym_final] = ACTIONS(5250),
    [anon_sym_global] = ACTIONS(5250),
    [anon_sym_LPAREN_STAR] = ACTIONS(5248),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5248),
    [anon_sym_DOLLARunit] = ACTIONS(5248),
  },
  [4792] = {
    [sym_simple_identifier] = ACTIONS(6107),
    [anon_sym_wire] = ACTIONS(6107),
    [anon_sym_tri] = ACTIONS(6107),
    [anon_sym_tri0] = ACTIONS(6107),
    [anon_sym_tri1] = ACTIONS(6107),
    [anon_sym_wand] = ACTIONS(6107),
    [anon_sym_triand] = ACTIONS(6107),
    [anon_sym_wor] = ACTIONS(6107),
    [anon_sym_trior] = ACTIONS(6107),
    [anon_sym_trireg] = ACTIONS(6107),
    [anon_sym_uwire] = ACTIONS(6107),
    [anon_sym_SEMI] = ACTIONS(6109),
    [anon_sym_extern] = ACTIONS(6107),
    [anon_sym_interface] = ACTIONS(6107),
    [anon_sym_checker] = ACTIONS(6107),
    [anon_sym_virtual] = ACTIONS(6107),
    [anon_sym_class] = ACTIONS(6107),
    [anon_sym_type] = ACTIONS(6107),
    [anon_sym_DOLLARfatal] = ACTIONS(6109),
    [anon_sym_DOLLARerror] = ACTIONS(6109),
    [anon_sym_DOLLARwarning] = ACTIONS(6109),
    [anon_sym_DOLLARinfo] = ACTIONS(6109),
    [anon_sym_default] = ACTIONS(6107),
    [anon_sym_clocking] = ACTIONS(6107),
    [anon_sym_defparam] = ACTIONS(6107),
    [anon_sym_bind] = ACTIONS(6107),
    [anon_sym_rand] = ACTIONS(6107),
    [anon_sym_const] = ACTIONS(6107),
    [anon_sym_function] = ACTIONS(6107),
    [anon_sym_static] = ACTIONS(6107),
    [anon_sym_constraint] = ACTIONS(6107),
    [anon_sym_if] = ACTIONS(6107),
    [anon_sym_else] = ACTIONS(6107),
    [anon_sym_LBRACK] = ACTIONS(6109),
    [anon_sym_localparam] = ACTIONS(6107),
    [anon_sym_parameter] = ACTIONS(6107),
    [anon_sym_var] = ACTIONS(6107),
    [anon_sym_import] = ACTIONS(6107),
    [anon_sym_export] = ACTIONS(6107),
    [anon_sym_genvar] = ACTIONS(6107),
    [anon_sym_interconnect] = ACTIONS(6107),
    [anon_sym_typedef] = ACTIONS(6107),
    [anon_sym_enum] = ACTIONS(6107),
    [anon_sym_struct] = ACTIONS(6107),
    [anon_sym_union] = ACTIONS(6107),
    [anon_sym_nettype] = ACTIONS(6107),
    [anon_sym_automatic] = ACTIONS(6107),
    [anon_sym_string] = ACTIONS(6107),
    [anon_sym_chandle] = ACTIONS(6107),
    [anon_sym_event] = ACTIONS(6107),
    [anon_sym_byte] = ACTIONS(6107),
    [anon_sym_shortint] = ACTIONS(6107),
    [anon_sym_int] = ACTIONS(6107),
    [anon_sym_longint] = ACTIONS(6107),
    [anon_sym_integer] = ACTIONS(6107),
    [anon_sym_time] = ACTIONS(6107),
    [anon_sym_bit] = ACTIONS(6107),
    [anon_sym_logic] = ACTIONS(6107),
    [anon_sym_reg] = ACTIONS(6107),
    [anon_sym_shortreal] = ACTIONS(6107),
    [anon_sym_real] = ACTIONS(6107),
    [anon_sym_realtime] = ACTIONS(6107),
    [anon_sym_supply0] = ACTIONS(6107),
    [anon_sym_supply1] = ACTIONS(6107),
    [anon_sym_signed] = ACTIONS(6107),
    [anon_sym_unsigned] = ACTIONS(6107),
    [anon_sym_task] = ACTIONS(6107),
    [anon_sym_assert] = ACTIONS(6107),
    [anon_sym_property] = ACTIONS(6107),
    [anon_sym_assume] = ACTIONS(6107),
    [anon_sym_cover] = ACTIONS(6107),
    [anon_sym_sequence] = ACTIONS(6107),
    [anon_sym_restrict] = ACTIONS(6107),
    [anon_sym_not] = ACTIONS(6107),
    [anon_sym_or] = ACTIONS(6107),
    [anon_sym_and] = ACTIONS(6107),
    [anon_sym_case] = ACTIONS(6107),
    [anon_sym_always] = ACTIONS(6107),
    [anon_sym_covergroup] = ACTIONS(6107),
    [anon_sym_end] = ACTIONS(6107),
    [anon_sym_let] = ACTIONS(6107),
    [anon_sym_pulldown] = ACTIONS(6107),
    [anon_sym_pullup] = ACTIONS(6107),
    [anon_sym_cmos] = ACTIONS(6107),
    [anon_sym_rcmos] = ACTIONS(6107),
    [anon_sym_bufif0] = ACTIONS(6107),
    [anon_sym_bufif1] = ACTIONS(6107),
    [anon_sym_notif0] = ACTIONS(6107),
    [anon_sym_notif1] = ACTIONS(6107),
    [anon_sym_nmos] = ACTIONS(6107),
    [anon_sym_pmos] = ACTIONS(6107),
    [anon_sym_rnmos] = ACTIONS(6107),
    [anon_sym_rpmos] = ACTIONS(6107),
    [anon_sym_nand] = ACTIONS(6107),
    [anon_sym_nor] = ACTIONS(6107),
    [anon_sym_xor] = ACTIONS(6107),
    [anon_sym_xnor] = ACTIONS(6107),
    [anon_sym_buf] = ACTIONS(6107),
    [anon_sym_tranif0] = ACTIONS(6107),
    [anon_sym_tranif1] = ACTIONS(6107),
    [anon_sym_rtranif1] = ACTIONS(6107),
    [anon_sym_rtranif0] = ACTIONS(6107),
    [anon_sym_tran] = ACTIONS(6107),
    [anon_sym_rtran] = ACTIONS(6107),
    [anon_sym_generate] = ACTIONS(6107),
    [anon_sym_for] = ACTIONS(6107),
    [anon_sym_initial] = ACTIONS(6107),
    [anon_sym_assign] = ACTIONS(6107),
    [anon_sym_alias] = ACTIONS(6107),
    [anon_sym_always_comb] = ACTIONS(6107),
    [anon_sym_always_latch] = ACTIONS(6107),
    [anon_sym_always_ff] = ACTIONS(6107),
    [anon_sym_final] = ACTIONS(6107),
    [anon_sym_global] = ACTIONS(6107),
    [anon_sym_LPAREN_STAR] = ACTIONS(6109),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6109),
    [anon_sym_DOLLARunit] = ACTIONS(6109),
  },
  [4793] = {
    [sym_simple_identifier] = ACTIONS(4864),
    [anon_sym_wire] = ACTIONS(4864),
    [anon_sym_tri] = ACTIONS(4864),
    [anon_sym_tri0] = ACTIONS(4864),
    [anon_sym_tri1] = ACTIONS(4864),
    [anon_sym_wand] = ACTIONS(4864),
    [anon_sym_triand] = ACTIONS(4864),
    [anon_sym_wor] = ACTIONS(4864),
    [anon_sym_trior] = ACTIONS(4864),
    [anon_sym_trireg] = ACTIONS(4864),
    [anon_sym_uwire] = ACTIONS(4864),
    [anon_sym_SEMI] = ACTIONS(4862),
    [anon_sym_extern] = ACTIONS(4864),
    [anon_sym_interface] = ACTIONS(4864),
    [anon_sym_checker] = ACTIONS(4864),
    [anon_sym_virtual] = ACTIONS(4864),
    [anon_sym_class] = ACTIONS(4864),
    [anon_sym_type] = ACTIONS(4864),
    [anon_sym_DOLLARfatal] = ACTIONS(4862),
    [anon_sym_DOLLARerror] = ACTIONS(4862),
    [anon_sym_DOLLARwarning] = ACTIONS(4862),
    [anon_sym_DOLLARinfo] = ACTIONS(4862),
    [anon_sym_default] = ACTIONS(4864),
    [anon_sym_clocking] = ACTIONS(4864),
    [anon_sym_defparam] = ACTIONS(4864),
    [anon_sym_bind] = ACTIONS(4864),
    [anon_sym_rand] = ACTIONS(4864),
    [anon_sym_const] = ACTIONS(4864),
    [anon_sym_function] = ACTIONS(4864),
    [anon_sym_static] = ACTIONS(4864),
    [anon_sym_constraint] = ACTIONS(4864),
    [anon_sym_if] = ACTIONS(4864),
    [anon_sym_else] = ACTIONS(4864),
    [anon_sym_LBRACK] = ACTIONS(4862),
    [anon_sym_localparam] = ACTIONS(4864),
    [anon_sym_parameter] = ACTIONS(4864),
    [anon_sym_var] = ACTIONS(4864),
    [anon_sym_import] = ACTIONS(4864),
    [anon_sym_export] = ACTIONS(4864),
    [anon_sym_genvar] = ACTIONS(4864),
    [anon_sym_interconnect] = ACTIONS(4864),
    [anon_sym_typedef] = ACTIONS(4864),
    [anon_sym_enum] = ACTIONS(4864),
    [anon_sym_struct] = ACTIONS(4864),
    [anon_sym_union] = ACTIONS(4864),
    [anon_sym_nettype] = ACTIONS(4864),
    [anon_sym_automatic] = ACTIONS(4864),
    [anon_sym_string] = ACTIONS(4864),
    [anon_sym_chandle] = ACTIONS(4864),
    [anon_sym_event] = ACTIONS(4864),
    [anon_sym_byte] = ACTIONS(4864),
    [anon_sym_shortint] = ACTIONS(4864),
    [anon_sym_int] = ACTIONS(4864),
    [anon_sym_longint] = ACTIONS(4864),
    [anon_sym_integer] = ACTIONS(4864),
    [anon_sym_time] = ACTIONS(4864),
    [anon_sym_bit] = ACTIONS(4864),
    [anon_sym_logic] = ACTIONS(4864),
    [anon_sym_reg] = ACTIONS(4864),
    [anon_sym_shortreal] = ACTIONS(4864),
    [anon_sym_real] = ACTIONS(4864),
    [anon_sym_realtime] = ACTIONS(4864),
    [anon_sym_supply0] = ACTIONS(4864),
    [anon_sym_supply1] = ACTIONS(4864),
    [anon_sym_signed] = ACTIONS(4864),
    [anon_sym_unsigned] = ACTIONS(4864),
    [anon_sym_task] = ACTIONS(4864),
    [anon_sym_assert] = ACTIONS(4864),
    [anon_sym_property] = ACTIONS(4864),
    [anon_sym_assume] = ACTIONS(4864),
    [anon_sym_cover] = ACTIONS(4864),
    [anon_sym_sequence] = ACTIONS(4864),
    [anon_sym_restrict] = ACTIONS(4864),
    [anon_sym_not] = ACTIONS(4864),
    [anon_sym_or] = ACTIONS(4864),
    [anon_sym_and] = ACTIONS(4864),
    [anon_sym_case] = ACTIONS(4864),
    [anon_sym_always] = ACTIONS(4864),
    [anon_sym_covergroup] = ACTIONS(4864),
    [anon_sym_end] = ACTIONS(4864),
    [anon_sym_let] = ACTIONS(4864),
    [anon_sym_pulldown] = ACTIONS(4864),
    [anon_sym_pullup] = ACTIONS(4864),
    [anon_sym_cmos] = ACTIONS(4864),
    [anon_sym_rcmos] = ACTIONS(4864),
    [anon_sym_bufif0] = ACTIONS(4864),
    [anon_sym_bufif1] = ACTIONS(4864),
    [anon_sym_notif0] = ACTIONS(4864),
    [anon_sym_notif1] = ACTIONS(4864),
    [anon_sym_nmos] = ACTIONS(4864),
    [anon_sym_pmos] = ACTIONS(4864),
    [anon_sym_rnmos] = ACTIONS(4864),
    [anon_sym_rpmos] = ACTIONS(4864),
    [anon_sym_nand] = ACTIONS(4864),
    [anon_sym_nor] = ACTIONS(4864),
    [anon_sym_xor] = ACTIONS(4864),
    [anon_sym_xnor] = ACTIONS(4864),
    [anon_sym_buf] = ACTIONS(4864),
    [anon_sym_tranif0] = ACTIONS(4864),
    [anon_sym_tranif1] = ACTIONS(4864),
    [anon_sym_rtranif1] = ACTIONS(4864),
    [anon_sym_rtranif0] = ACTIONS(4864),
    [anon_sym_tran] = ACTIONS(4864),
    [anon_sym_rtran] = ACTIONS(4864),
    [anon_sym_generate] = ACTIONS(4864),
    [anon_sym_for] = ACTIONS(4864),
    [anon_sym_initial] = ACTIONS(4864),
    [anon_sym_assign] = ACTIONS(4864),
    [anon_sym_alias] = ACTIONS(4864),
    [anon_sym_always_comb] = ACTIONS(4864),
    [anon_sym_always_latch] = ACTIONS(4864),
    [anon_sym_always_ff] = ACTIONS(4864),
    [anon_sym_final] = ACTIONS(4864),
    [anon_sym_global] = ACTIONS(4864),
    [anon_sym_LPAREN_STAR] = ACTIONS(4862),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4862),
    [anon_sym_DOLLARunit] = ACTIONS(4862),
  },
  [4794] = {
    [sym_simple_identifier] = ACTIONS(4300),
    [anon_sym_wire] = ACTIONS(4300),
    [anon_sym_tri] = ACTIONS(4300),
    [anon_sym_tri0] = ACTIONS(4300),
    [anon_sym_tri1] = ACTIONS(4300),
    [anon_sym_wand] = ACTIONS(4300),
    [anon_sym_triand] = ACTIONS(4300),
    [anon_sym_wor] = ACTIONS(4300),
    [anon_sym_trior] = ACTIONS(4300),
    [anon_sym_trireg] = ACTIONS(4300),
    [anon_sym_uwire] = ACTIONS(4300),
    [anon_sym_SEMI] = ACTIONS(4298),
    [anon_sym_extern] = ACTIONS(4300),
    [anon_sym_interface] = ACTIONS(4300),
    [anon_sym_checker] = ACTIONS(4300),
    [anon_sym_virtual] = ACTIONS(4300),
    [anon_sym_class] = ACTIONS(4300),
    [anon_sym_type] = ACTIONS(4300),
    [anon_sym_DOLLARfatal] = ACTIONS(4298),
    [anon_sym_DOLLARerror] = ACTIONS(4298),
    [anon_sym_DOLLARwarning] = ACTIONS(4298),
    [anon_sym_DOLLARinfo] = ACTIONS(4298),
    [anon_sym_default] = ACTIONS(4300),
    [anon_sym_clocking] = ACTIONS(4300),
    [anon_sym_defparam] = ACTIONS(4300),
    [anon_sym_bind] = ACTIONS(4300),
    [anon_sym_rand] = ACTIONS(4300),
    [anon_sym_const] = ACTIONS(4300),
    [anon_sym_function] = ACTIONS(4300),
    [anon_sym_static] = ACTIONS(4300),
    [anon_sym_constraint] = ACTIONS(4300),
    [anon_sym_if] = ACTIONS(4300),
    [anon_sym_else] = ACTIONS(4300),
    [anon_sym_LBRACK] = ACTIONS(4298),
    [anon_sym_localparam] = ACTIONS(4300),
    [anon_sym_parameter] = ACTIONS(4300),
    [anon_sym_var] = ACTIONS(4300),
    [anon_sym_import] = ACTIONS(4300),
    [anon_sym_export] = ACTIONS(4300),
    [anon_sym_genvar] = ACTIONS(4300),
    [anon_sym_interconnect] = ACTIONS(4300),
    [anon_sym_typedef] = ACTIONS(4300),
    [anon_sym_enum] = ACTIONS(4300),
    [anon_sym_struct] = ACTIONS(4300),
    [anon_sym_union] = ACTIONS(4300),
    [anon_sym_nettype] = ACTIONS(4300),
    [anon_sym_automatic] = ACTIONS(4300),
    [anon_sym_string] = ACTIONS(4300),
    [anon_sym_chandle] = ACTIONS(4300),
    [anon_sym_event] = ACTIONS(4300),
    [anon_sym_byte] = ACTIONS(4300),
    [anon_sym_shortint] = ACTIONS(4300),
    [anon_sym_int] = ACTIONS(4300),
    [anon_sym_longint] = ACTIONS(4300),
    [anon_sym_integer] = ACTIONS(4300),
    [anon_sym_time] = ACTIONS(4300),
    [anon_sym_bit] = ACTIONS(4300),
    [anon_sym_logic] = ACTIONS(4300),
    [anon_sym_reg] = ACTIONS(4300),
    [anon_sym_shortreal] = ACTIONS(4300),
    [anon_sym_real] = ACTIONS(4300),
    [anon_sym_realtime] = ACTIONS(4300),
    [anon_sym_supply0] = ACTIONS(4300),
    [anon_sym_supply1] = ACTIONS(4300),
    [anon_sym_signed] = ACTIONS(4300),
    [anon_sym_unsigned] = ACTIONS(4300),
    [anon_sym_task] = ACTIONS(4300),
    [anon_sym_assert] = ACTIONS(4300),
    [anon_sym_property] = ACTIONS(4300),
    [anon_sym_assume] = ACTIONS(4300),
    [anon_sym_cover] = ACTIONS(4300),
    [anon_sym_sequence] = ACTIONS(4300),
    [anon_sym_restrict] = ACTIONS(4300),
    [anon_sym_not] = ACTIONS(4300),
    [anon_sym_or] = ACTIONS(4300),
    [anon_sym_and] = ACTIONS(4300),
    [anon_sym_case] = ACTIONS(4300),
    [anon_sym_always] = ACTIONS(4300),
    [anon_sym_covergroup] = ACTIONS(4300),
    [anon_sym_end] = ACTIONS(4300),
    [anon_sym_let] = ACTIONS(4300),
    [anon_sym_pulldown] = ACTIONS(4300),
    [anon_sym_pullup] = ACTIONS(4300),
    [anon_sym_cmos] = ACTIONS(4300),
    [anon_sym_rcmos] = ACTIONS(4300),
    [anon_sym_bufif0] = ACTIONS(4300),
    [anon_sym_bufif1] = ACTIONS(4300),
    [anon_sym_notif0] = ACTIONS(4300),
    [anon_sym_notif1] = ACTIONS(4300),
    [anon_sym_nmos] = ACTIONS(4300),
    [anon_sym_pmos] = ACTIONS(4300),
    [anon_sym_rnmos] = ACTIONS(4300),
    [anon_sym_rpmos] = ACTIONS(4300),
    [anon_sym_nand] = ACTIONS(4300),
    [anon_sym_nor] = ACTIONS(4300),
    [anon_sym_xor] = ACTIONS(4300),
    [anon_sym_xnor] = ACTIONS(4300),
    [anon_sym_buf] = ACTIONS(4300),
    [anon_sym_tranif0] = ACTIONS(4300),
    [anon_sym_tranif1] = ACTIONS(4300),
    [anon_sym_rtranif1] = ACTIONS(4300),
    [anon_sym_rtranif0] = ACTIONS(4300),
    [anon_sym_tran] = ACTIONS(4300),
    [anon_sym_rtran] = ACTIONS(4300),
    [anon_sym_generate] = ACTIONS(4300),
    [anon_sym_for] = ACTIONS(4300),
    [anon_sym_initial] = ACTIONS(4300),
    [anon_sym_assign] = ACTIONS(4300),
    [anon_sym_alias] = ACTIONS(4300),
    [anon_sym_always_comb] = ACTIONS(4300),
    [anon_sym_always_latch] = ACTIONS(4300),
    [anon_sym_always_ff] = ACTIONS(4300),
    [anon_sym_final] = ACTIONS(4300),
    [anon_sym_global] = ACTIONS(4300),
    [anon_sym_LPAREN_STAR] = ACTIONS(4298),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4298),
    [anon_sym_DOLLARunit] = ACTIONS(4298),
  },
  [4795] = {
    [sym_simple_identifier] = ACTIONS(5182),
    [anon_sym_wire] = ACTIONS(5182),
    [anon_sym_tri] = ACTIONS(5182),
    [anon_sym_tri0] = ACTIONS(5182),
    [anon_sym_tri1] = ACTIONS(5182),
    [anon_sym_wand] = ACTIONS(5182),
    [anon_sym_triand] = ACTIONS(5182),
    [anon_sym_wor] = ACTIONS(5182),
    [anon_sym_trior] = ACTIONS(5182),
    [anon_sym_trireg] = ACTIONS(5182),
    [anon_sym_uwire] = ACTIONS(5182),
    [anon_sym_SEMI] = ACTIONS(5180),
    [anon_sym_extern] = ACTIONS(5182),
    [anon_sym_interface] = ACTIONS(5182),
    [anon_sym_checker] = ACTIONS(5182),
    [anon_sym_virtual] = ACTIONS(5182),
    [anon_sym_class] = ACTIONS(5182),
    [anon_sym_type] = ACTIONS(5182),
    [anon_sym_DOLLARfatal] = ACTIONS(5180),
    [anon_sym_DOLLARerror] = ACTIONS(5180),
    [anon_sym_DOLLARwarning] = ACTIONS(5180),
    [anon_sym_DOLLARinfo] = ACTIONS(5180),
    [anon_sym_default] = ACTIONS(5182),
    [anon_sym_clocking] = ACTIONS(5182),
    [anon_sym_defparam] = ACTIONS(5182),
    [anon_sym_bind] = ACTIONS(5182),
    [anon_sym_rand] = ACTIONS(5182),
    [anon_sym_const] = ACTIONS(5182),
    [anon_sym_function] = ACTIONS(5182),
    [anon_sym_static] = ACTIONS(5182),
    [anon_sym_constraint] = ACTIONS(5182),
    [anon_sym_if] = ACTIONS(5182),
    [anon_sym_else] = ACTIONS(5182),
    [anon_sym_LBRACK] = ACTIONS(5180),
    [anon_sym_localparam] = ACTIONS(5182),
    [anon_sym_parameter] = ACTIONS(5182),
    [anon_sym_var] = ACTIONS(5182),
    [anon_sym_import] = ACTIONS(5182),
    [anon_sym_export] = ACTIONS(5182),
    [anon_sym_genvar] = ACTIONS(5182),
    [anon_sym_interconnect] = ACTIONS(5182),
    [anon_sym_typedef] = ACTIONS(5182),
    [anon_sym_enum] = ACTIONS(5182),
    [anon_sym_struct] = ACTIONS(5182),
    [anon_sym_union] = ACTIONS(5182),
    [anon_sym_nettype] = ACTIONS(5182),
    [anon_sym_automatic] = ACTIONS(5182),
    [anon_sym_string] = ACTIONS(5182),
    [anon_sym_chandle] = ACTIONS(5182),
    [anon_sym_event] = ACTIONS(5182),
    [anon_sym_byte] = ACTIONS(5182),
    [anon_sym_shortint] = ACTIONS(5182),
    [anon_sym_int] = ACTIONS(5182),
    [anon_sym_longint] = ACTIONS(5182),
    [anon_sym_integer] = ACTIONS(5182),
    [anon_sym_time] = ACTIONS(5182),
    [anon_sym_bit] = ACTIONS(5182),
    [anon_sym_logic] = ACTIONS(5182),
    [anon_sym_reg] = ACTIONS(5182),
    [anon_sym_shortreal] = ACTIONS(5182),
    [anon_sym_real] = ACTIONS(5182),
    [anon_sym_realtime] = ACTIONS(5182),
    [anon_sym_supply0] = ACTIONS(5182),
    [anon_sym_supply1] = ACTIONS(5182),
    [anon_sym_signed] = ACTIONS(5182),
    [anon_sym_unsigned] = ACTIONS(5182),
    [anon_sym_task] = ACTIONS(5182),
    [anon_sym_assert] = ACTIONS(5182),
    [anon_sym_property] = ACTIONS(5182),
    [anon_sym_assume] = ACTIONS(5182),
    [anon_sym_cover] = ACTIONS(5182),
    [anon_sym_sequence] = ACTIONS(5182),
    [anon_sym_restrict] = ACTIONS(5182),
    [anon_sym_not] = ACTIONS(5182),
    [anon_sym_or] = ACTIONS(5182),
    [anon_sym_and] = ACTIONS(5182),
    [anon_sym_case] = ACTIONS(5182),
    [anon_sym_always] = ACTIONS(5182),
    [anon_sym_covergroup] = ACTIONS(5182),
    [anon_sym_end] = ACTIONS(5182),
    [anon_sym_let] = ACTIONS(5182),
    [anon_sym_pulldown] = ACTIONS(5182),
    [anon_sym_pullup] = ACTIONS(5182),
    [anon_sym_cmos] = ACTIONS(5182),
    [anon_sym_rcmos] = ACTIONS(5182),
    [anon_sym_bufif0] = ACTIONS(5182),
    [anon_sym_bufif1] = ACTIONS(5182),
    [anon_sym_notif0] = ACTIONS(5182),
    [anon_sym_notif1] = ACTIONS(5182),
    [anon_sym_nmos] = ACTIONS(5182),
    [anon_sym_pmos] = ACTIONS(5182),
    [anon_sym_rnmos] = ACTIONS(5182),
    [anon_sym_rpmos] = ACTIONS(5182),
    [anon_sym_nand] = ACTIONS(5182),
    [anon_sym_nor] = ACTIONS(5182),
    [anon_sym_xor] = ACTIONS(5182),
    [anon_sym_xnor] = ACTIONS(5182),
    [anon_sym_buf] = ACTIONS(5182),
    [anon_sym_tranif0] = ACTIONS(5182),
    [anon_sym_tranif1] = ACTIONS(5182),
    [anon_sym_rtranif1] = ACTIONS(5182),
    [anon_sym_rtranif0] = ACTIONS(5182),
    [anon_sym_tran] = ACTIONS(5182),
    [anon_sym_rtran] = ACTIONS(5182),
    [anon_sym_generate] = ACTIONS(5182),
    [anon_sym_for] = ACTIONS(5182),
    [anon_sym_initial] = ACTIONS(5182),
    [anon_sym_assign] = ACTIONS(5182),
    [anon_sym_alias] = ACTIONS(5182),
    [anon_sym_always_comb] = ACTIONS(5182),
    [anon_sym_always_latch] = ACTIONS(5182),
    [anon_sym_always_ff] = ACTIONS(5182),
    [anon_sym_final] = ACTIONS(5182),
    [anon_sym_global] = ACTIONS(5182),
    [anon_sym_LPAREN_STAR] = ACTIONS(5180),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5180),
    [anon_sym_DOLLARunit] = ACTIONS(5180),
  },
  [4796] = {
    [sym_simple_identifier] = ACTIONS(6111),
    [anon_sym_wire] = ACTIONS(6111),
    [anon_sym_tri] = ACTIONS(6111),
    [anon_sym_tri0] = ACTIONS(6111),
    [anon_sym_tri1] = ACTIONS(6111),
    [anon_sym_wand] = ACTIONS(6111),
    [anon_sym_triand] = ACTIONS(6111),
    [anon_sym_wor] = ACTIONS(6111),
    [anon_sym_trior] = ACTIONS(6111),
    [anon_sym_trireg] = ACTIONS(6111),
    [anon_sym_uwire] = ACTIONS(6111),
    [anon_sym_SEMI] = ACTIONS(6113),
    [anon_sym_extern] = ACTIONS(6111),
    [anon_sym_interface] = ACTIONS(6111),
    [anon_sym_checker] = ACTIONS(6111),
    [anon_sym_virtual] = ACTIONS(6111),
    [anon_sym_class] = ACTIONS(6111),
    [anon_sym_type] = ACTIONS(6111),
    [anon_sym_DOLLARfatal] = ACTIONS(6113),
    [anon_sym_DOLLARerror] = ACTIONS(6113),
    [anon_sym_DOLLARwarning] = ACTIONS(6113),
    [anon_sym_DOLLARinfo] = ACTIONS(6113),
    [anon_sym_default] = ACTIONS(6111),
    [anon_sym_clocking] = ACTIONS(6111),
    [anon_sym_defparam] = ACTIONS(6111),
    [anon_sym_bind] = ACTIONS(6111),
    [anon_sym_rand] = ACTIONS(6111),
    [anon_sym_const] = ACTIONS(6111),
    [anon_sym_function] = ACTIONS(6111),
    [anon_sym_static] = ACTIONS(6111),
    [anon_sym_constraint] = ACTIONS(6111),
    [anon_sym_if] = ACTIONS(6111),
    [anon_sym_else] = ACTIONS(6111),
    [anon_sym_LBRACK] = ACTIONS(6113),
    [anon_sym_localparam] = ACTIONS(6111),
    [anon_sym_parameter] = ACTIONS(6111),
    [anon_sym_var] = ACTIONS(6111),
    [anon_sym_import] = ACTIONS(6111),
    [anon_sym_export] = ACTIONS(6111),
    [anon_sym_genvar] = ACTIONS(6111),
    [anon_sym_interconnect] = ACTIONS(6111),
    [anon_sym_typedef] = ACTIONS(6111),
    [anon_sym_enum] = ACTIONS(6111),
    [anon_sym_struct] = ACTIONS(6111),
    [anon_sym_union] = ACTIONS(6111),
    [anon_sym_nettype] = ACTIONS(6111),
    [anon_sym_automatic] = ACTIONS(6111),
    [anon_sym_string] = ACTIONS(6111),
    [anon_sym_chandle] = ACTIONS(6111),
    [anon_sym_event] = ACTIONS(6111),
    [anon_sym_byte] = ACTIONS(6111),
    [anon_sym_shortint] = ACTIONS(6111),
    [anon_sym_int] = ACTIONS(6111),
    [anon_sym_longint] = ACTIONS(6111),
    [anon_sym_integer] = ACTIONS(6111),
    [anon_sym_time] = ACTIONS(6111),
    [anon_sym_bit] = ACTIONS(6111),
    [anon_sym_logic] = ACTIONS(6111),
    [anon_sym_reg] = ACTIONS(6111),
    [anon_sym_shortreal] = ACTIONS(6111),
    [anon_sym_real] = ACTIONS(6111),
    [anon_sym_realtime] = ACTIONS(6111),
    [anon_sym_supply0] = ACTIONS(6111),
    [anon_sym_supply1] = ACTIONS(6111),
    [anon_sym_signed] = ACTIONS(6111),
    [anon_sym_unsigned] = ACTIONS(6111),
    [anon_sym_task] = ACTIONS(6111),
    [anon_sym_assert] = ACTIONS(6111),
    [anon_sym_property] = ACTIONS(6111),
    [anon_sym_assume] = ACTIONS(6111),
    [anon_sym_cover] = ACTIONS(6111),
    [anon_sym_sequence] = ACTIONS(6111),
    [anon_sym_restrict] = ACTIONS(6111),
    [anon_sym_not] = ACTIONS(6111),
    [anon_sym_or] = ACTIONS(6111),
    [anon_sym_and] = ACTIONS(6111),
    [anon_sym_case] = ACTIONS(6111),
    [anon_sym_always] = ACTIONS(6111),
    [anon_sym_covergroup] = ACTIONS(6111),
    [anon_sym_end] = ACTIONS(6111),
    [anon_sym_let] = ACTIONS(6111),
    [anon_sym_pulldown] = ACTIONS(6111),
    [anon_sym_pullup] = ACTIONS(6111),
    [anon_sym_cmos] = ACTIONS(6111),
    [anon_sym_rcmos] = ACTIONS(6111),
    [anon_sym_bufif0] = ACTIONS(6111),
    [anon_sym_bufif1] = ACTIONS(6111),
    [anon_sym_notif0] = ACTIONS(6111),
    [anon_sym_notif1] = ACTIONS(6111),
    [anon_sym_nmos] = ACTIONS(6111),
    [anon_sym_pmos] = ACTIONS(6111),
    [anon_sym_rnmos] = ACTIONS(6111),
    [anon_sym_rpmos] = ACTIONS(6111),
    [anon_sym_nand] = ACTIONS(6111),
    [anon_sym_nor] = ACTIONS(6111),
    [anon_sym_xor] = ACTIONS(6111),
    [anon_sym_xnor] = ACTIONS(6111),
    [anon_sym_buf] = ACTIONS(6111),
    [anon_sym_tranif0] = ACTIONS(6111),
    [anon_sym_tranif1] = ACTIONS(6111),
    [anon_sym_rtranif1] = ACTIONS(6111),
    [anon_sym_rtranif0] = ACTIONS(6111),
    [anon_sym_tran] = ACTIONS(6111),
    [anon_sym_rtran] = ACTIONS(6111),
    [anon_sym_generate] = ACTIONS(6111),
    [anon_sym_for] = ACTIONS(6111),
    [anon_sym_initial] = ACTIONS(6111),
    [anon_sym_assign] = ACTIONS(6111),
    [anon_sym_alias] = ACTIONS(6111),
    [anon_sym_always_comb] = ACTIONS(6111),
    [anon_sym_always_latch] = ACTIONS(6111),
    [anon_sym_always_ff] = ACTIONS(6111),
    [anon_sym_final] = ACTIONS(6111),
    [anon_sym_global] = ACTIONS(6111),
    [anon_sym_LPAREN_STAR] = ACTIONS(6113),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6113),
    [anon_sym_DOLLARunit] = ACTIONS(6113),
  },
  [4797] = {
    [sym_simple_identifier] = ACTIONS(5770),
    [anon_sym_wire] = ACTIONS(5770),
    [anon_sym_tri] = ACTIONS(5770),
    [anon_sym_tri0] = ACTIONS(5770),
    [anon_sym_tri1] = ACTIONS(5770),
    [anon_sym_wand] = ACTIONS(5770),
    [anon_sym_triand] = ACTIONS(5770),
    [anon_sym_wor] = ACTIONS(5770),
    [anon_sym_trior] = ACTIONS(5770),
    [anon_sym_trireg] = ACTIONS(5770),
    [anon_sym_uwire] = ACTIONS(5770),
    [anon_sym_SEMI] = ACTIONS(5772),
    [anon_sym_extern] = ACTIONS(5770),
    [anon_sym_interface] = ACTIONS(5770),
    [anon_sym_checker] = ACTIONS(5770),
    [anon_sym_virtual] = ACTIONS(5770),
    [anon_sym_class] = ACTIONS(5770),
    [anon_sym_type] = ACTIONS(5770),
    [anon_sym_DOLLARfatal] = ACTIONS(5772),
    [anon_sym_DOLLARerror] = ACTIONS(5772),
    [anon_sym_DOLLARwarning] = ACTIONS(5772),
    [anon_sym_DOLLARinfo] = ACTIONS(5772),
    [anon_sym_default] = ACTIONS(5770),
    [anon_sym_clocking] = ACTIONS(5770),
    [anon_sym_defparam] = ACTIONS(5770),
    [anon_sym_bind] = ACTIONS(5770),
    [anon_sym_rand] = ACTIONS(5770),
    [anon_sym_const] = ACTIONS(5770),
    [anon_sym_function] = ACTIONS(5770),
    [anon_sym_static] = ACTIONS(5770),
    [anon_sym_constraint] = ACTIONS(5770),
    [anon_sym_if] = ACTIONS(5770),
    [anon_sym_else] = ACTIONS(5770),
    [anon_sym_LBRACK] = ACTIONS(5772),
    [anon_sym_localparam] = ACTIONS(5770),
    [anon_sym_parameter] = ACTIONS(5770),
    [anon_sym_var] = ACTIONS(5770),
    [anon_sym_import] = ACTIONS(5770),
    [anon_sym_export] = ACTIONS(5770),
    [anon_sym_genvar] = ACTIONS(5770),
    [anon_sym_interconnect] = ACTIONS(5770),
    [anon_sym_typedef] = ACTIONS(5770),
    [anon_sym_enum] = ACTIONS(5770),
    [anon_sym_struct] = ACTIONS(5770),
    [anon_sym_union] = ACTIONS(5770),
    [anon_sym_nettype] = ACTIONS(5770),
    [anon_sym_automatic] = ACTIONS(5770),
    [anon_sym_string] = ACTIONS(5770),
    [anon_sym_chandle] = ACTIONS(5770),
    [anon_sym_event] = ACTIONS(5770),
    [anon_sym_byte] = ACTIONS(5770),
    [anon_sym_shortint] = ACTIONS(5770),
    [anon_sym_int] = ACTIONS(5770),
    [anon_sym_longint] = ACTIONS(5770),
    [anon_sym_integer] = ACTIONS(5770),
    [anon_sym_time] = ACTIONS(5770),
    [anon_sym_bit] = ACTIONS(5770),
    [anon_sym_logic] = ACTIONS(5770),
    [anon_sym_reg] = ACTIONS(5770),
    [anon_sym_shortreal] = ACTIONS(5770),
    [anon_sym_real] = ACTIONS(5770),
    [anon_sym_realtime] = ACTIONS(5770),
    [anon_sym_supply0] = ACTIONS(5770),
    [anon_sym_supply1] = ACTIONS(5770),
    [anon_sym_signed] = ACTIONS(5770),
    [anon_sym_unsigned] = ACTIONS(5770),
    [anon_sym_task] = ACTIONS(5770),
    [anon_sym_assert] = ACTIONS(5770),
    [anon_sym_property] = ACTIONS(5770),
    [anon_sym_assume] = ACTIONS(5770),
    [anon_sym_cover] = ACTIONS(5770),
    [anon_sym_sequence] = ACTIONS(5770),
    [anon_sym_restrict] = ACTIONS(5770),
    [anon_sym_not] = ACTIONS(5770),
    [anon_sym_or] = ACTIONS(5770),
    [anon_sym_and] = ACTIONS(5770),
    [anon_sym_case] = ACTIONS(5770),
    [anon_sym_always] = ACTIONS(5770),
    [anon_sym_covergroup] = ACTIONS(5770),
    [anon_sym_let] = ACTIONS(5770),
    [anon_sym_pulldown] = ACTIONS(5770),
    [anon_sym_pullup] = ACTIONS(5770),
    [anon_sym_cmos] = ACTIONS(5770),
    [anon_sym_rcmos] = ACTIONS(5770),
    [anon_sym_bufif0] = ACTIONS(5770),
    [anon_sym_bufif1] = ACTIONS(5770),
    [anon_sym_notif0] = ACTIONS(5770),
    [anon_sym_notif1] = ACTIONS(5770),
    [anon_sym_nmos] = ACTIONS(5770),
    [anon_sym_pmos] = ACTIONS(5770),
    [anon_sym_rnmos] = ACTIONS(5770),
    [anon_sym_rpmos] = ACTIONS(5770),
    [anon_sym_nand] = ACTIONS(5770),
    [anon_sym_nor] = ACTIONS(5770),
    [anon_sym_xor] = ACTIONS(5770),
    [anon_sym_xnor] = ACTIONS(5770),
    [anon_sym_buf] = ACTIONS(5770),
    [anon_sym_tranif0] = ACTIONS(5770),
    [anon_sym_tranif1] = ACTIONS(5770),
    [anon_sym_rtranif1] = ACTIONS(5770),
    [anon_sym_rtranif0] = ACTIONS(5770),
    [anon_sym_tran] = ACTIONS(5770),
    [anon_sym_rtran] = ACTIONS(5770),
    [anon_sym_generate] = ACTIONS(5770),
    [anon_sym_endgenerate] = ACTIONS(5770),
    [anon_sym_for] = ACTIONS(5770),
    [anon_sym_initial] = ACTIONS(5770),
    [anon_sym_assign] = ACTIONS(5770),
    [anon_sym_alias] = ACTIONS(5770),
    [anon_sym_always_comb] = ACTIONS(5770),
    [anon_sym_always_latch] = ACTIONS(5770),
    [anon_sym_always_ff] = ACTIONS(5770),
    [anon_sym_final] = ACTIONS(5770),
    [anon_sym_global] = ACTIONS(5770),
    [anon_sym_LPAREN_STAR] = ACTIONS(5772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5772),
    [anon_sym_DOLLARunit] = ACTIONS(5772),
  },
  [4798] = {
    [sym_simple_identifier] = ACTIONS(6115),
    [anon_sym_wire] = ACTIONS(6115),
    [anon_sym_tri] = ACTIONS(6115),
    [anon_sym_tri0] = ACTIONS(6115),
    [anon_sym_tri1] = ACTIONS(6115),
    [anon_sym_wand] = ACTIONS(6115),
    [anon_sym_triand] = ACTIONS(6115),
    [anon_sym_wor] = ACTIONS(6115),
    [anon_sym_trior] = ACTIONS(6115),
    [anon_sym_trireg] = ACTIONS(6115),
    [anon_sym_uwire] = ACTIONS(6115),
    [anon_sym_SEMI] = ACTIONS(6117),
    [anon_sym_extern] = ACTIONS(6115),
    [anon_sym_interface] = ACTIONS(6115),
    [anon_sym_checker] = ACTIONS(6115),
    [anon_sym_virtual] = ACTIONS(6115),
    [anon_sym_class] = ACTIONS(6115),
    [anon_sym_type] = ACTIONS(6115),
    [anon_sym_DOLLARfatal] = ACTIONS(6117),
    [anon_sym_DOLLARerror] = ACTIONS(6117),
    [anon_sym_DOLLARwarning] = ACTIONS(6117),
    [anon_sym_DOLLARinfo] = ACTIONS(6117),
    [anon_sym_default] = ACTIONS(6115),
    [anon_sym_clocking] = ACTIONS(6115),
    [anon_sym_defparam] = ACTIONS(6115),
    [anon_sym_bind] = ACTIONS(6115),
    [anon_sym_rand] = ACTIONS(6115),
    [anon_sym_const] = ACTIONS(6115),
    [anon_sym_function] = ACTIONS(6115),
    [anon_sym_static] = ACTIONS(6115),
    [anon_sym_constraint] = ACTIONS(6115),
    [anon_sym_if] = ACTIONS(6115),
    [anon_sym_else] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(6117),
    [anon_sym_localparam] = ACTIONS(6115),
    [anon_sym_parameter] = ACTIONS(6115),
    [anon_sym_var] = ACTIONS(6115),
    [anon_sym_import] = ACTIONS(6115),
    [anon_sym_export] = ACTIONS(6115),
    [anon_sym_genvar] = ACTIONS(6115),
    [anon_sym_interconnect] = ACTIONS(6115),
    [anon_sym_typedef] = ACTIONS(6115),
    [anon_sym_enum] = ACTIONS(6115),
    [anon_sym_struct] = ACTIONS(6115),
    [anon_sym_union] = ACTIONS(6115),
    [anon_sym_nettype] = ACTIONS(6115),
    [anon_sym_automatic] = ACTIONS(6115),
    [anon_sym_string] = ACTIONS(6115),
    [anon_sym_chandle] = ACTIONS(6115),
    [anon_sym_event] = ACTIONS(6115),
    [anon_sym_byte] = ACTIONS(6115),
    [anon_sym_shortint] = ACTIONS(6115),
    [anon_sym_int] = ACTIONS(6115),
    [anon_sym_longint] = ACTIONS(6115),
    [anon_sym_integer] = ACTIONS(6115),
    [anon_sym_time] = ACTIONS(6115),
    [anon_sym_bit] = ACTIONS(6115),
    [anon_sym_logic] = ACTIONS(6115),
    [anon_sym_reg] = ACTIONS(6115),
    [anon_sym_shortreal] = ACTIONS(6115),
    [anon_sym_real] = ACTIONS(6115),
    [anon_sym_realtime] = ACTIONS(6115),
    [anon_sym_supply0] = ACTIONS(6115),
    [anon_sym_supply1] = ACTIONS(6115),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_task] = ACTIONS(6115),
    [anon_sym_assert] = ACTIONS(6115),
    [anon_sym_property] = ACTIONS(6115),
    [anon_sym_assume] = ACTIONS(6115),
    [anon_sym_cover] = ACTIONS(6115),
    [anon_sym_sequence] = ACTIONS(6115),
    [anon_sym_restrict] = ACTIONS(6115),
    [anon_sym_not] = ACTIONS(6115),
    [anon_sym_or] = ACTIONS(6115),
    [anon_sym_and] = ACTIONS(6115),
    [anon_sym_case] = ACTIONS(6115),
    [anon_sym_always] = ACTIONS(6115),
    [anon_sym_covergroup] = ACTIONS(6115),
    [anon_sym_end] = ACTIONS(6115),
    [anon_sym_let] = ACTIONS(6115),
    [anon_sym_pulldown] = ACTIONS(6115),
    [anon_sym_pullup] = ACTIONS(6115),
    [anon_sym_cmos] = ACTIONS(6115),
    [anon_sym_rcmos] = ACTIONS(6115),
    [anon_sym_bufif0] = ACTIONS(6115),
    [anon_sym_bufif1] = ACTIONS(6115),
    [anon_sym_notif0] = ACTIONS(6115),
    [anon_sym_notif1] = ACTIONS(6115),
    [anon_sym_nmos] = ACTIONS(6115),
    [anon_sym_pmos] = ACTIONS(6115),
    [anon_sym_rnmos] = ACTIONS(6115),
    [anon_sym_rpmos] = ACTIONS(6115),
    [anon_sym_nand] = ACTIONS(6115),
    [anon_sym_nor] = ACTIONS(6115),
    [anon_sym_xor] = ACTIONS(6115),
    [anon_sym_xnor] = ACTIONS(6115),
    [anon_sym_buf] = ACTIONS(6115),
    [anon_sym_tranif0] = ACTIONS(6115),
    [anon_sym_tranif1] = ACTIONS(6115),
    [anon_sym_rtranif1] = ACTIONS(6115),
    [anon_sym_rtranif0] = ACTIONS(6115),
    [anon_sym_tran] = ACTIONS(6115),
    [anon_sym_rtran] = ACTIONS(6115),
    [anon_sym_generate] = ACTIONS(6115),
    [anon_sym_for] = ACTIONS(6115),
    [anon_sym_initial] = ACTIONS(6115),
    [anon_sym_assign] = ACTIONS(6115),
    [anon_sym_alias] = ACTIONS(6115),
    [anon_sym_always_comb] = ACTIONS(6115),
    [anon_sym_always_latch] = ACTIONS(6115),
    [anon_sym_always_ff] = ACTIONS(6115),
    [anon_sym_final] = ACTIONS(6115),
    [anon_sym_global] = ACTIONS(6115),
    [anon_sym_LPAREN_STAR] = ACTIONS(6117),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6117),
    [anon_sym_DOLLARunit] = ACTIONS(6117),
  },
  [4799] = {
    [sym_simple_identifier] = ACTIONS(4868),
    [anon_sym_wire] = ACTIONS(4868),
    [anon_sym_tri] = ACTIONS(4868),
    [anon_sym_tri0] = ACTIONS(4868),
    [anon_sym_tri1] = ACTIONS(4868),
    [anon_sym_wand] = ACTIONS(4868),
    [anon_sym_triand] = ACTIONS(4868),
    [anon_sym_wor] = ACTIONS(4868),
    [anon_sym_trior] = ACTIONS(4868),
    [anon_sym_trireg] = ACTIONS(4868),
    [anon_sym_uwire] = ACTIONS(4868),
    [anon_sym_SEMI] = ACTIONS(4866),
    [anon_sym_extern] = ACTIONS(4868),
    [anon_sym_interface] = ACTIONS(4868),
    [anon_sym_checker] = ACTIONS(4868),
    [anon_sym_virtual] = ACTIONS(4868),
    [anon_sym_class] = ACTIONS(4868),
    [anon_sym_type] = ACTIONS(4868),
    [anon_sym_DOLLARfatal] = ACTIONS(4866),
    [anon_sym_DOLLARerror] = ACTIONS(4866),
    [anon_sym_DOLLARwarning] = ACTIONS(4866),
    [anon_sym_DOLLARinfo] = ACTIONS(4866),
    [anon_sym_default] = ACTIONS(4868),
    [anon_sym_clocking] = ACTIONS(4868),
    [anon_sym_defparam] = ACTIONS(4868),
    [anon_sym_bind] = ACTIONS(4868),
    [anon_sym_rand] = ACTIONS(4868),
    [anon_sym_const] = ACTIONS(4868),
    [anon_sym_function] = ACTIONS(4868),
    [anon_sym_static] = ACTIONS(4868),
    [anon_sym_constraint] = ACTIONS(4868),
    [anon_sym_if] = ACTIONS(4868),
    [anon_sym_else] = ACTIONS(4868),
    [anon_sym_LBRACK] = ACTIONS(4866),
    [anon_sym_localparam] = ACTIONS(4868),
    [anon_sym_parameter] = ACTIONS(4868),
    [anon_sym_var] = ACTIONS(4868),
    [anon_sym_import] = ACTIONS(4868),
    [anon_sym_export] = ACTIONS(4868),
    [anon_sym_genvar] = ACTIONS(4868),
    [anon_sym_interconnect] = ACTIONS(4868),
    [anon_sym_typedef] = ACTIONS(4868),
    [anon_sym_enum] = ACTIONS(4868),
    [anon_sym_struct] = ACTIONS(4868),
    [anon_sym_union] = ACTIONS(4868),
    [anon_sym_nettype] = ACTIONS(4868),
    [anon_sym_automatic] = ACTIONS(4868),
    [anon_sym_string] = ACTIONS(4868),
    [anon_sym_chandle] = ACTIONS(4868),
    [anon_sym_event] = ACTIONS(4868),
    [anon_sym_byte] = ACTIONS(4868),
    [anon_sym_shortint] = ACTIONS(4868),
    [anon_sym_int] = ACTIONS(4868),
    [anon_sym_longint] = ACTIONS(4868),
    [anon_sym_integer] = ACTIONS(4868),
    [anon_sym_time] = ACTIONS(4868),
    [anon_sym_bit] = ACTIONS(4868),
    [anon_sym_logic] = ACTIONS(4868),
    [anon_sym_reg] = ACTIONS(4868),
    [anon_sym_shortreal] = ACTIONS(4868),
    [anon_sym_real] = ACTIONS(4868),
    [anon_sym_realtime] = ACTIONS(4868),
    [anon_sym_supply0] = ACTIONS(4868),
    [anon_sym_supply1] = ACTIONS(4868),
    [anon_sym_signed] = ACTIONS(4868),
    [anon_sym_unsigned] = ACTIONS(4868),
    [anon_sym_task] = ACTIONS(4868),
    [anon_sym_assert] = ACTIONS(4868),
    [anon_sym_property] = ACTIONS(4868),
    [anon_sym_assume] = ACTIONS(4868),
    [anon_sym_cover] = ACTIONS(4868),
    [anon_sym_sequence] = ACTIONS(4868),
    [anon_sym_restrict] = ACTIONS(4868),
    [anon_sym_not] = ACTIONS(4868),
    [anon_sym_or] = ACTIONS(4868),
    [anon_sym_and] = ACTIONS(4868),
    [anon_sym_case] = ACTIONS(4868),
    [anon_sym_always] = ACTIONS(4868),
    [anon_sym_covergroup] = ACTIONS(4868),
    [anon_sym_let] = ACTIONS(4868),
    [anon_sym_pulldown] = ACTIONS(4868),
    [anon_sym_pullup] = ACTIONS(4868),
    [anon_sym_cmos] = ACTIONS(4868),
    [anon_sym_rcmos] = ACTIONS(4868),
    [anon_sym_bufif0] = ACTIONS(4868),
    [anon_sym_bufif1] = ACTIONS(4868),
    [anon_sym_notif0] = ACTIONS(4868),
    [anon_sym_notif1] = ACTIONS(4868),
    [anon_sym_nmos] = ACTIONS(4868),
    [anon_sym_pmos] = ACTIONS(4868),
    [anon_sym_rnmos] = ACTIONS(4868),
    [anon_sym_rpmos] = ACTIONS(4868),
    [anon_sym_nand] = ACTIONS(4868),
    [anon_sym_nor] = ACTIONS(4868),
    [anon_sym_xor] = ACTIONS(4868),
    [anon_sym_xnor] = ACTIONS(4868),
    [anon_sym_buf] = ACTIONS(4868),
    [anon_sym_tranif0] = ACTIONS(4868),
    [anon_sym_tranif1] = ACTIONS(4868),
    [anon_sym_rtranif1] = ACTIONS(4868),
    [anon_sym_rtranif0] = ACTIONS(4868),
    [anon_sym_tran] = ACTIONS(4868),
    [anon_sym_rtran] = ACTIONS(4868),
    [anon_sym_generate] = ACTIONS(4868),
    [anon_sym_endgenerate] = ACTIONS(4868),
    [anon_sym_for] = ACTIONS(4868),
    [anon_sym_initial] = ACTIONS(4868),
    [anon_sym_assign] = ACTIONS(4868),
    [anon_sym_alias] = ACTIONS(4868),
    [anon_sym_always_comb] = ACTIONS(4868),
    [anon_sym_always_latch] = ACTIONS(4868),
    [anon_sym_always_ff] = ACTIONS(4868),
    [anon_sym_final] = ACTIONS(4868),
    [anon_sym_global] = ACTIONS(4868),
    [anon_sym_LPAREN_STAR] = ACTIONS(4866),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4866),
    [anon_sym_DOLLARunit] = ACTIONS(4866),
  },
  [4800] = {
    [sym_simple_identifier] = ACTIONS(6739),
    [anon_sym_wire] = ACTIONS(6739),
    [anon_sym_tri] = ACTIONS(6739),
    [anon_sym_tri0] = ACTIONS(6739),
    [anon_sym_tri1] = ACTIONS(6739),
    [anon_sym_wand] = ACTIONS(6739),
    [anon_sym_triand] = ACTIONS(6739),
    [anon_sym_wor] = ACTIONS(6739),
    [anon_sym_trior] = ACTIONS(6739),
    [anon_sym_trireg] = ACTIONS(6739),
    [anon_sym_uwire] = ACTIONS(6739),
    [anon_sym_SEMI] = ACTIONS(6741),
    [anon_sym_extern] = ACTIONS(6739),
    [anon_sym_interface] = ACTIONS(6739),
    [anon_sym_checker] = ACTIONS(6739),
    [anon_sym_virtual] = ACTIONS(6739),
    [anon_sym_class] = ACTIONS(6739),
    [anon_sym_type] = ACTIONS(6739),
    [anon_sym_DOLLARfatal] = ACTIONS(6741),
    [anon_sym_DOLLARerror] = ACTIONS(6741),
    [anon_sym_DOLLARwarning] = ACTIONS(6741),
    [anon_sym_DOLLARinfo] = ACTIONS(6741),
    [anon_sym_default] = ACTIONS(6739),
    [anon_sym_clocking] = ACTIONS(6739),
    [anon_sym_defparam] = ACTIONS(6739),
    [anon_sym_bind] = ACTIONS(6739),
    [anon_sym_rand] = ACTIONS(6739),
    [anon_sym_const] = ACTIONS(6739),
    [anon_sym_function] = ACTIONS(6739),
    [anon_sym_static] = ACTIONS(6739),
    [anon_sym_constraint] = ACTIONS(6739),
    [anon_sym_if] = ACTIONS(6739),
    [anon_sym_else] = ACTIONS(6739),
    [anon_sym_LBRACK] = ACTIONS(6741),
    [anon_sym_localparam] = ACTIONS(6739),
    [anon_sym_parameter] = ACTIONS(6739),
    [anon_sym_var] = ACTIONS(6739),
    [anon_sym_import] = ACTIONS(6739),
    [anon_sym_export] = ACTIONS(6739),
    [anon_sym_genvar] = ACTIONS(6739),
    [anon_sym_interconnect] = ACTIONS(6739),
    [anon_sym_typedef] = ACTIONS(6739),
    [anon_sym_enum] = ACTIONS(6739),
    [anon_sym_struct] = ACTIONS(6739),
    [anon_sym_union] = ACTIONS(6739),
    [anon_sym_nettype] = ACTIONS(6739),
    [anon_sym_automatic] = ACTIONS(6739),
    [anon_sym_string] = ACTIONS(6739),
    [anon_sym_chandle] = ACTIONS(6739),
    [anon_sym_event] = ACTIONS(6739),
    [anon_sym_byte] = ACTIONS(6739),
    [anon_sym_shortint] = ACTIONS(6739),
    [anon_sym_int] = ACTIONS(6739),
    [anon_sym_longint] = ACTIONS(6739),
    [anon_sym_integer] = ACTIONS(6739),
    [anon_sym_time] = ACTIONS(6739),
    [anon_sym_bit] = ACTIONS(6739),
    [anon_sym_logic] = ACTIONS(6739),
    [anon_sym_reg] = ACTIONS(6739),
    [anon_sym_shortreal] = ACTIONS(6739),
    [anon_sym_real] = ACTIONS(6739),
    [anon_sym_realtime] = ACTIONS(6739),
    [anon_sym_supply0] = ACTIONS(6739),
    [anon_sym_supply1] = ACTIONS(6739),
    [anon_sym_signed] = ACTIONS(6739),
    [anon_sym_unsigned] = ACTIONS(6739),
    [anon_sym_task] = ACTIONS(6739),
    [anon_sym_assert] = ACTIONS(6739),
    [anon_sym_property] = ACTIONS(6739),
    [anon_sym_assume] = ACTIONS(6739),
    [anon_sym_cover] = ACTIONS(6739),
    [anon_sym_sequence] = ACTIONS(6739),
    [anon_sym_restrict] = ACTIONS(6739),
    [anon_sym_not] = ACTIONS(6739),
    [anon_sym_or] = ACTIONS(6739),
    [anon_sym_and] = ACTIONS(6739),
    [anon_sym_case] = ACTIONS(6739),
    [anon_sym_always] = ACTIONS(6739),
    [anon_sym_covergroup] = ACTIONS(6739),
    [anon_sym_end] = ACTIONS(6739),
    [anon_sym_let] = ACTIONS(6739),
    [anon_sym_pulldown] = ACTIONS(6739),
    [anon_sym_pullup] = ACTIONS(6739),
    [anon_sym_cmos] = ACTIONS(6739),
    [anon_sym_rcmos] = ACTIONS(6739),
    [anon_sym_bufif0] = ACTIONS(6739),
    [anon_sym_bufif1] = ACTIONS(6739),
    [anon_sym_notif0] = ACTIONS(6739),
    [anon_sym_notif1] = ACTIONS(6739),
    [anon_sym_nmos] = ACTIONS(6739),
    [anon_sym_pmos] = ACTIONS(6739),
    [anon_sym_rnmos] = ACTIONS(6739),
    [anon_sym_rpmos] = ACTIONS(6739),
    [anon_sym_nand] = ACTIONS(6739),
    [anon_sym_nor] = ACTIONS(6739),
    [anon_sym_xor] = ACTIONS(6739),
    [anon_sym_xnor] = ACTIONS(6739),
    [anon_sym_buf] = ACTIONS(6739),
    [anon_sym_tranif0] = ACTIONS(6739),
    [anon_sym_tranif1] = ACTIONS(6739),
    [anon_sym_rtranif1] = ACTIONS(6739),
    [anon_sym_rtranif0] = ACTIONS(6739),
    [anon_sym_tran] = ACTIONS(6739),
    [anon_sym_rtran] = ACTIONS(6739),
    [anon_sym_generate] = ACTIONS(6739),
    [anon_sym_for] = ACTIONS(6739),
    [anon_sym_initial] = ACTIONS(6739),
    [anon_sym_assign] = ACTIONS(6739),
    [anon_sym_alias] = ACTIONS(6739),
    [anon_sym_always_comb] = ACTIONS(6739),
    [anon_sym_always_latch] = ACTIONS(6739),
    [anon_sym_always_ff] = ACTIONS(6739),
    [anon_sym_final] = ACTIONS(6739),
    [anon_sym_global] = ACTIONS(6739),
    [anon_sym_LPAREN_STAR] = ACTIONS(6741),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6741),
    [anon_sym_DOLLARunit] = ACTIONS(6741),
  },
  [4801] = {
    [sym_simple_identifier] = ACTIONS(6793),
    [anon_sym_wire] = ACTIONS(6793),
    [anon_sym_tri] = ACTIONS(6793),
    [anon_sym_tri0] = ACTIONS(6793),
    [anon_sym_tri1] = ACTIONS(6793),
    [anon_sym_wand] = ACTIONS(6793),
    [anon_sym_triand] = ACTIONS(6793),
    [anon_sym_wor] = ACTIONS(6793),
    [anon_sym_trior] = ACTIONS(6793),
    [anon_sym_trireg] = ACTIONS(6793),
    [anon_sym_uwire] = ACTIONS(6793),
    [anon_sym_SEMI] = ACTIONS(6796),
    [anon_sym_extern] = ACTIONS(6793),
    [anon_sym_interface] = ACTIONS(6793),
    [anon_sym_checker] = ACTIONS(6793),
    [anon_sym_virtual] = ACTIONS(6793),
    [anon_sym_class] = ACTIONS(6793),
    [anon_sym_type] = ACTIONS(6793),
    [anon_sym_DOLLARfatal] = ACTIONS(6796),
    [anon_sym_DOLLARerror] = ACTIONS(6796),
    [anon_sym_DOLLARwarning] = ACTIONS(6796),
    [anon_sym_DOLLARinfo] = ACTIONS(6796),
    [anon_sym_default] = ACTIONS(6793),
    [anon_sym_clocking] = ACTIONS(6793),
    [anon_sym_defparam] = ACTIONS(6793),
    [anon_sym_bind] = ACTIONS(6793),
    [anon_sym_rand] = ACTIONS(6793),
    [anon_sym_const] = ACTIONS(6793),
    [anon_sym_function] = ACTIONS(6793),
    [anon_sym_static] = ACTIONS(6793),
    [anon_sym_constraint] = ACTIONS(6793),
    [anon_sym_if] = ACTIONS(6793),
    [anon_sym_else] = ACTIONS(6793),
    [anon_sym_LBRACK] = ACTIONS(6796),
    [anon_sym_localparam] = ACTIONS(6793),
    [anon_sym_parameter] = ACTIONS(6793),
    [anon_sym_var] = ACTIONS(6793),
    [anon_sym_import] = ACTIONS(6793),
    [anon_sym_export] = ACTIONS(6793),
    [anon_sym_genvar] = ACTIONS(6793),
    [anon_sym_interconnect] = ACTIONS(6793),
    [anon_sym_typedef] = ACTIONS(6793),
    [anon_sym_enum] = ACTIONS(6793),
    [anon_sym_struct] = ACTIONS(6793),
    [anon_sym_union] = ACTIONS(6793),
    [anon_sym_nettype] = ACTIONS(6793),
    [anon_sym_automatic] = ACTIONS(6793),
    [anon_sym_string] = ACTIONS(6793),
    [anon_sym_chandle] = ACTIONS(6793),
    [anon_sym_event] = ACTIONS(6793),
    [anon_sym_byte] = ACTIONS(6793),
    [anon_sym_shortint] = ACTIONS(6793),
    [anon_sym_int] = ACTIONS(6793),
    [anon_sym_longint] = ACTIONS(6793),
    [anon_sym_integer] = ACTIONS(6793),
    [anon_sym_time] = ACTIONS(6793),
    [anon_sym_bit] = ACTIONS(6793),
    [anon_sym_logic] = ACTIONS(6793),
    [anon_sym_reg] = ACTIONS(6793),
    [anon_sym_shortreal] = ACTIONS(6793),
    [anon_sym_real] = ACTIONS(6793),
    [anon_sym_realtime] = ACTIONS(6793),
    [anon_sym_supply0] = ACTIONS(6793),
    [anon_sym_supply1] = ACTIONS(6793),
    [anon_sym_signed] = ACTIONS(6793),
    [anon_sym_unsigned] = ACTIONS(6793),
    [anon_sym_task] = ACTIONS(6793),
    [anon_sym_assert] = ACTIONS(6793),
    [anon_sym_property] = ACTIONS(6793),
    [anon_sym_assume] = ACTIONS(6793),
    [anon_sym_cover] = ACTIONS(6793),
    [anon_sym_sequence] = ACTIONS(6793),
    [anon_sym_restrict] = ACTIONS(6793),
    [anon_sym_not] = ACTIONS(6793),
    [anon_sym_or] = ACTIONS(6793),
    [anon_sym_and] = ACTIONS(6793),
    [anon_sym_case] = ACTIONS(6793),
    [anon_sym_always] = ACTIONS(6793),
    [anon_sym_covergroup] = ACTIONS(6793),
    [anon_sym_let] = ACTIONS(6793),
    [anon_sym_pulldown] = ACTIONS(6793),
    [anon_sym_pullup] = ACTIONS(6793),
    [anon_sym_cmos] = ACTIONS(6793),
    [anon_sym_rcmos] = ACTIONS(6793),
    [anon_sym_bufif0] = ACTIONS(6793),
    [anon_sym_bufif1] = ACTIONS(6793),
    [anon_sym_notif0] = ACTIONS(6793),
    [anon_sym_notif1] = ACTIONS(6793),
    [anon_sym_nmos] = ACTIONS(6793),
    [anon_sym_pmos] = ACTIONS(6793),
    [anon_sym_rnmos] = ACTIONS(6793),
    [anon_sym_rpmos] = ACTIONS(6793),
    [anon_sym_nand] = ACTIONS(6793),
    [anon_sym_nor] = ACTIONS(6793),
    [anon_sym_xor] = ACTIONS(6793),
    [anon_sym_xnor] = ACTIONS(6793),
    [anon_sym_buf] = ACTIONS(6793),
    [anon_sym_tranif0] = ACTIONS(6793),
    [anon_sym_tranif1] = ACTIONS(6793),
    [anon_sym_rtranif1] = ACTIONS(6793),
    [anon_sym_rtranif0] = ACTIONS(6793),
    [anon_sym_tran] = ACTIONS(6793),
    [anon_sym_rtran] = ACTIONS(6793),
    [anon_sym_generate] = ACTIONS(6793),
    [anon_sym_endgenerate] = ACTIONS(6793),
    [anon_sym_for] = ACTIONS(6793),
    [anon_sym_initial] = ACTIONS(6793),
    [anon_sym_assign] = ACTIONS(6793),
    [anon_sym_alias] = ACTIONS(6793),
    [anon_sym_always_comb] = ACTIONS(6793),
    [anon_sym_always_latch] = ACTIONS(6793),
    [anon_sym_always_ff] = ACTIONS(6793),
    [anon_sym_final] = ACTIONS(6793),
    [anon_sym_global] = ACTIONS(6793),
    [anon_sym_LPAREN_STAR] = ACTIONS(6796),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6796),
    [anon_sym_DOLLARunit] = ACTIONS(6796),
  },
  [4802] = {
    [sym_simple_identifier] = ACTIONS(5242),
    [anon_sym_wire] = ACTIONS(5242),
    [anon_sym_tri] = ACTIONS(5242),
    [anon_sym_tri0] = ACTIONS(5242),
    [anon_sym_tri1] = ACTIONS(5242),
    [anon_sym_wand] = ACTIONS(5242),
    [anon_sym_triand] = ACTIONS(5242),
    [anon_sym_wor] = ACTIONS(5242),
    [anon_sym_trior] = ACTIONS(5242),
    [anon_sym_trireg] = ACTIONS(5242),
    [anon_sym_uwire] = ACTIONS(5242),
    [anon_sym_SEMI] = ACTIONS(5240),
    [anon_sym_extern] = ACTIONS(5242),
    [anon_sym_interface] = ACTIONS(5242),
    [anon_sym_checker] = ACTIONS(5242),
    [anon_sym_virtual] = ACTIONS(5242),
    [anon_sym_class] = ACTIONS(5242),
    [anon_sym_type] = ACTIONS(5242),
    [anon_sym_DOLLARfatal] = ACTIONS(5240),
    [anon_sym_DOLLARerror] = ACTIONS(5240),
    [anon_sym_DOLLARwarning] = ACTIONS(5240),
    [anon_sym_DOLLARinfo] = ACTIONS(5240),
    [anon_sym_default] = ACTIONS(5242),
    [anon_sym_clocking] = ACTIONS(5242),
    [anon_sym_defparam] = ACTIONS(5242),
    [anon_sym_bind] = ACTIONS(5242),
    [anon_sym_rand] = ACTIONS(5242),
    [anon_sym_const] = ACTIONS(5242),
    [anon_sym_function] = ACTIONS(5242),
    [anon_sym_static] = ACTIONS(5242),
    [anon_sym_constraint] = ACTIONS(5242),
    [anon_sym_if] = ACTIONS(5242),
    [anon_sym_else] = ACTIONS(5242),
    [anon_sym_LBRACK] = ACTIONS(5240),
    [anon_sym_localparam] = ACTIONS(5242),
    [anon_sym_parameter] = ACTIONS(5242),
    [anon_sym_var] = ACTIONS(5242),
    [anon_sym_import] = ACTIONS(5242),
    [anon_sym_export] = ACTIONS(5242),
    [anon_sym_genvar] = ACTIONS(5242),
    [anon_sym_interconnect] = ACTIONS(5242),
    [anon_sym_typedef] = ACTIONS(5242),
    [anon_sym_enum] = ACTIONS(5242),
    [anon_sym_struct] = ACTIONS(5242),
    [anon_sym_union] = ACTIONS(5242),
    [anon_sym_nettype] = ACTIONS(5242),
    [anon_sym_automatic] = ACTIONS(5242),
    [anon_sym_string] = ACTIONS(5242),
    [anon_sym_chandle] = ACTIONS(5242),
    [anon_sym_event] = ACTIONS(5242),
    [anon_sym_byte] = ACTIONS(5242),
    [anon_sym_shortint] = ACTIONS(5242),
    [anon_sym_int] = ACTIONS(5242),
    [anon_sym_longint] = ACTIONS(5242),
    [anon_sym_integer] = ACTIONS(5242),
    [anon_sym_time] = ACTIONS(5242),
    [anon_sym_bit] = ACTIONS(5242),
    [anon_sym_logic] = ACTIONS(5242),
    [anon_sym_reg] = ACTIONS(5242),
    [anon_sym_shortreal] = ACTIONS(5242),
    [anon_sym_real] = ACTIONS(5242),
    [anon_sym_realtime] = ACTIONS(5242),
    [anon_sym_supply0] = ACTIONS(5242),
    [anon_sym_supply1] = ACTIONS(5242),
    [anon_sym_signed] = ACTIONS(5242),
    [anon_sym_unsigned] = ACTIONS(5242),
    [anon_sym_task] = ACTIONS(5242),
    [anon_sym_assert] = ACTIONS(5242),
    [anon_sym_property] = ACTIONS(5242),
    [anon_sym_assume] = ACTIONS(5242),
    [anon_sym_cover] = ACTIONS(5242),
    [anon_sym_sequence] = ACTIONS(5242),
    [anon_sym_restrict] = ACTIONS(5242),
    [anon_sym_not] = ACTIONS(5242),
    [anon_sym_or] = ACTIONS(5242),
    [anon_sym_and] = ACTIONS(5242),
    [anon_sym_case] = ACTIONS(5242),
    [anon_sym_always] = ACTIONS(5242),
    [anon_sym_covergroup] = ACTIONS(5242),
    [anon_sym_end] = ACTIONS(5242),
    [anon_sym_let] = ACTIONS(5242),
    [anon_sym_pulldown] = ACTIONS(5242),
    [anon_sym_pullup] = ACTIONS(5242),
    [anon_sym_cmos] = ACTIONS(5242),
    [anon_sym_rcmos] = ACTIONS(5242),
    [anon_sym_bufif0] = ACTIONS(5242),
    [anon_sym_bufif1] = ACTIONS(5242),
    [anon_sym_notif0] = ACTIONS(5242),
    [anon_sym_notif1] = ACTIONS(5242),
    [anon_sym_nmos] = ACTIONS(5242),
    [anon_sym_pmos] = ACTIONS(5242),
    [anon_sym_rnmos] = ACTIONS(5242),
    [anon_sym_rpmos] = ACTIONS(5242),
    [anon_sym_nand] = ACTIONS(5242),
    [anon_sym_nor] = ACTIONS(5242),
    [anon_sym_xor] = ACTIONS(5242),
    [anon_sym_xnor] = ACTIONS(5242),
    [anon_sym_buf] = ACTIONS(5242),
    [anon_sym_tranif0] = ACTIONS(5242),
    [anon_sym_tranif1] = ACTIONS(5242),
    [anon_sym_rtranif1] = ACTIONS(5242),
    [anon_sym_rtranif0] = ACTIONS(5242),
    [anon_sym_tran] = ACTIONS(5242),
    [anon_sym_rtran] = ACTIONS(5242),
    [anon_sym_generate] = ACTIONS(5242),
    [anon_sym_for] = ACTIONS(5242),
    [anon_sym_initial] = ACTIONS(5242),
    [anon_sym_assign] = ACTIONS(5242),
    [anon_sym_alias] = ACTIONS(5242),
    [anon_sym_always_comb] = ACTIONS(5242),
    [anon_sym_always_latch] = ACTIONS(5242),
    [anon_sym_always_ff] = ACTIONS(5242),
    [anon_sym_final] = ACTIONS(5242),
    [anon_sym_global] = ACTIONS(5242),
    [anon_sym_LPAREN_STAR] = ACTIONS(5240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5240),
    [anon_sym_DOLLARunit] = ACTIONS(5240),
  },
  [4803] = {
    [sym_simple_identifier] = ACTIONS(4952),
    [anon_sym_wire] = ACTIONS(4952),
    [anon_sym_tri] = ACTIONS(4952),
    [anon_sym_tri0] = ACTIONS(4952),
    [anon_sym_tri1] = ACTIONS(4952),
    [anon_sym_wand] = ACTIONS(4952),
    [anon_sym_triand] = ACTIONS(4952),
    [anon_sym_wor] = ACTIONS(4952),
    [anon_sym_trior] = ACTIONS(4952),
    [anon_sym_trireg] = ACTIONS(4952),
    [anon_sym_uwire] = ACTIONS(4952),
    [anon_sym_SEMI] = ACTIONS(4950),
    [anon_sym_extern] = ACTIONS(4952),
    [anon_sym_interface] = ACTIONS(4952),
    [anon_sym_checker] = ACTIONS(4952),
    [anon_sym_virtual] = ACTIONS(4952),
    [anon_sym_class] = ACTIONS(4952),
    [anon_sym_type] = ACTIONS(4952),
    [anon_sym_DOLLARfatal] = ACTIONS(4950),
    [anon_sym_DOLLARerror] = ACTIONS(4950),
    [anon_sym_DOLLARwarning] = ACTIONS(4950),
    [anon_sym_DOLLARinfo] = ACTIONS(4950),
    [anon_sym_default] = ACTIONS(4952),
    [anon_sym_clocking] = ACTIONS(4952),
    [anon_sym_defparam] = ACTIONS(4952),
    [anon_sym_bind] = ACTIONS(4952),
    [anon_sym_rand] = ACTIONS(4952),
    [anon_sym_const] = ACTIONS(4952),
    [anon_sym_function] = ACTIONS(4952),
    [anon_sym_static] = ACTIONS(4952),
    [anon_sym_constraint] = ACTIONS(4952),
    [anon_sym_if] = ACTIONS(4952),
    [anon_sym_else] = ACTIONS(4952),
    [anon_sym_LBRACK] = ACTIONS(4950),
    [anon_sym_localparam] = ACTIONS(4952),
    [anon_sym_parameter] = ACTIONS(4952),
    [anon_sym_var] = ACTIONS(4952),
    [anon_sym_import] = ACTIONS(4952),
    [anon_sym_export] = ACTIONS(4952),
    [anon_sym_genvar] = ACTIONS(4952),
    [anon_sym_interconnect] = ACTIONS(4952),
    [anon_sym_typedef] = ACTIONS(4952),
    [anon_sym_enum] = ACTIONS(4952),
    [anon_sym_struct] = ACTIONS(4952),
    [anon_sym_union] = ACTIONS(4952),
    [anon_sym_nettype] = ACTIONS(4952),
    [anon_sym_automatic] = ACTIONS(4952),
    [anon_sym_string] = ACTIONS(4952),
    [anon_sym_chandle] = ACTIONS(4952),
    [anon_sym_event] = ACTIONS(4952),
    [anon_sym_byte] = ACTIONS(4952),
    [anon_sym_shortint] = ACTIONS(4952),
    [anon_sym_int] = ACTIONS(4952),
    [anon_sym_longint] = ACTIONS(4952),
    [anon_sym_integer] = ACTIONS(4952),
    [anon_sym_time] = ACTIONS(4952),
    [anon_sym_bit] = ACTIONS(4952),
    [anon_sym_logic] = ACTIONS(4952),
    [anon_sym_reg] = ACTIONS(4952),
    [anon_sym_shortreal] = ACTIONS(4952),
    [anon_sym_real] = ACTIONS(4952),
    [anon_sym_realtime] = ACTIONS(4952),
    [anon_sym_supply0] = ACTIONS(4952),
    [anon_sym_supply1] = ACTIONS(4952),
    [anon_sym_signed] = ACTIONS(4952),
    [anon_sym_unsigned] = ACTIONS(4952),
    [anon_sym_task] = ACTIONS(4952),
    [anon_sym_assert] = ACTIONS(4952),
    [anon_sym_property] = ACTIONS(4952),
    [anon_sym_assume] = ACTIONS(4952),
    [anon_sym_cover] = ACTIONS(4952),
    [anon_sym_sequence] = ACTIONS(4952),
    [anon_sym_restrict] = ACTIONS(4952),
    [anon_sym_not] = ACTIONS(4952),
    [anon_sym_or] = ACTIONS(4952),
    [anon_sym_and] = ACTIONS(4952),
    [anon_sym_case] = ACTIONS(4952),
    [anon_sym_always] = ACTIONS(4952),
    [anon_sym_covergroup] = ACTIONS(4952),
    [anon_sym_let] = ACTIONS(4952),
    [anon_sym_pulldown] = ACTIONS(4952),
    [anon_sym_pullup] = ACTIONS(4952),
    [anon_sym_cmos] = ACTIONS(4952),
    [anon_sym_rcmos] = ACTIONS(4952),
    [anon_sym_bufif0] = ACTIONS(4952),
    [anon_sym_bufif1] = ACTIONS(4952),
    [anon_sym_notif0] = ACTIONS(4952),
    [anon_sym_notif1] = ACTIONS(4952),
    [anon_sym_nmos] = ACTIONS(4952),
    [anon_sym_pmos] = ACTIONS(4952),
    [anon_sym_rnmos] = ACTIONS(4952),
    [anon_sym_rpmos] = ACTIONS(4952),
    [anon_sym_nand] = ACTIONS(4952),
    [anon_sym_nor] = ACTIONS(4952),
    [anon_sym_xor] = ACTIONS(4952),
    [anon_sym_xnor] = ACTIONS(4952),
    [anon_sym_buf] = ACTIONS(4952),
    [anon_sym_tranif0] = ACTIONS(4952),
    [anon_sym_tranif1] = ACTIONS(4952),
    [anon_sym_rtranif1] = ACTIONS(4952),
    [anon_sym_rtranif0] = ACTIONS(4952),
    [anon_sym_tran] = ACTIONS(4952),
    [anon_sym_rtran] = ACTIONS(4952),
    [anon_sym_generate] = ACTIONS(4952),
    [anon_sym_endgenerate] = ACTIONS(4952),
    [anon_sym_for] = ACTIONS(4952),
    [anon_sym_initial] = ACTIONS(4952),
    [anon_sym_assign] = ACTIONS(4952),
    [anon_sym_alias] = ACTIONS(4952),
    [anon_sym_always_comb] = ACTIONS(4952),
    [anon_sym_always_latch] = ACTIONS(4952),
    [anon_sym_always_ff] = ACTIONS(4952),
    [anon_sym_final] = ACTIONS(4952),
    [anon_sym_global] = ACTIONS(4952),
    [anon_sym_LPAREN_STAR] = ACTIONS(4950),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4950),
    [anon_sym_DOLLARunit] = ACTIONS(4950),
  },
  [4804] = {
    [sym_simple_identifier] = ACTIONS(5246),
    [anon_sym_wire] = ACTIONS(5246),
    [anon_sym_tri] = ACTIONS(5246),
    [anon_sym_tri0] = ACTIONS(5246),
    [anon_sym_tri1] = ACTIONS(5246),
    [anon_sym_wand] = ACTIONS(5246),
    [anon_sym_triand] = ACTIONS(5246),
    [anon_sym_wor] = ACTIONS(5246),
    [anon_sym_trior] = ACTIONS(5246),
    [anon_sym_trireg] = ACTIONS(5246),
    [anon_sym_uwire] = ACTIONS(5246),
    [anon_sym_SEMI] = ACTIONS(5244),
    [anon_sym_extern] = ACTIONS(5246),
    [anon_sym_interface] = ACTIONS(5246),
    [anon_sym_checker] = ACTIONS(5246),
    [anon_sym_virtual] = ACTIONS(5246),
    [anon_sym_class] = ACTIONS(5246),
    [anon_sym_type] = ACTIONS(5246),
    [anon_sym_DOLLARfatal] = ACTIONS(5244),
    [anon_sym_DOLLARerror] = ACTIONS(5244),
    [anon_sym_DOLLARwarning] = ACTIONS(5244),
    [anon_sym_DOLLARinfo] = ACTIONS(5244),
    [anon_sym_default] = ACTIONS(5246),
    [anon_sym_clocking] = ACTIONS(5246),
    [anon_sym_defparam] = ACTIONS(5246),
    [anon_sym_bind] = ACTIONS(5246),
    [anon_sym_rand] = ACTIONS(5246),
    [anon_sym_const] = ACTIONS(5246),
    [anon_sym_function] = ACTIONS(5246),
    [anon_sym_static] = ACTIONS(5246),
    [anon_sym_constraint] = ACTIONS(5246),
    [anon_sym_if] = ACTIONS(5246),
    [anon_sym_else] = ACTIONS(5246),
    [anon_sym_LBRACK] = ACTIONS(5244),
    [anon_sym_localparam] = ACTIONS(5246),
    [anon_sym_parameter] = ACTIONS(5246),
    [anon_sym_var] = ACTIONS(5246),
    [anon_sym_import] = ACTIONS(5246),
    [anon_sym_export] = ACTIONS(5246),
    [anon_sym_genvar] = ACTIONS(5246),
    [anon_sym_interconnect] = ACTIONS(5246),
    [anon_sym_typedef] = ACTIONS(5246),
    [anon_sym_enum] = ACTIONS(5246),
    [anon_sym_struct] = ACTIONS(5246),
    [anon_sym_union] = ACTIONS(5246),
    [anon_sym_nettype] = ACTIONS(5246),
    [anon_sym_automatic] = ACTIONS(5246),
    [anon_sym_string] = ACTIONS(5246),
    [anon_sym_chandle] = ACTIONS(5246),
    [anon_sym_event] = ACTIONS(5246),
    [anon_sym_byte] = ACTIONS(5246),
    [anon_sym_shortint] = ACTIONS(5246),
    [anon_sym_int] = ACTIONS(5246),
    [anon_sym_longint] = ACTIONS(5246),
    [anon_sym_integer] = ACTIONS(5246),
    [anon_sym_time] = ACTIONS(5246),
    [anon_sym_bit] = ACTIONS(5246),
    [anon_sym_logic] = ACTIONS(5246),
    [anon_sym_reg] = ACTIONS(5246),
    [anon_sym_shortreal] = ACTIONS(5246),
    [anon_sym_real] = ACTIONS(5246),
    [anon_sym_realtime] = ACTIONS(5246),
    [anon_sym_supply0] = ACTIONS(5246),
    [anon_sym_supply1] = ACTIONS(5246),
    [anon_sym_signed] = ACTIONS(5246),
    [anon_sym_unsigned] = ACTIONS(5246),
    [anon_sym_task] = ACTIONS(5246),
    [anon_sym_assert] = ACTIONS(5246),
    [anon_sym_property] = ACTIONS(5246),
    [anon_sym_assume] = ACTIONS(5246),
    [anon_sym_cover] = ACTIONS(5246),
    [anon_sym_sequence] = ACTIONS(5246),
    [anon_sym_restrict] = ACTIONS(5246),
    [anon_sym_not] = ACTIONS(5246),
    [anon_sym_or] = ACTIONS(5246),
    [anon_sym_and] = ACTIONS(5246),
    [anon_sym_case] = ACTIONS(5246),
    [anon_sym_always] = ACTIONS(5246),
    [anon_sym_covergroup] = ACTIONS(5246),
    [anon_sym_end] = ACTIONS(5246),
    [anon_sym_let] = ACTIONS(5246),
    [anon_sym_pulldown] = ACTIONS(5246),
    [anon_sym_pullup] = ACTIONS(5246),
    [anon_sym_cmos] = ACTIONS(5246),
    [anon_sym_rcmos] = ACTIONS(5246),
    [anon_sym_bufif0] = ACTIONS(5246),
    [anon_sym_bufif1] = ACTIONS(5246),
    [anon_sym_notif0] = ACTIONS(5246),
    [anon_sym_notif1] = ACTIONS(5246),
    [anon_sym_nmos] = ACTIONS(5246),
    [anon_sym_pmos] = ACTIONS(5246),
    [anon_sym_rnmos] = ACTIONS(5246),
    [anon_sym_rpmos] = ACTIONS(5246),
    [anon_sym_nand] = ACTIONS(5246),
    [anon_sym_nor] = ACTIONS(5246),
    [anon_sym_xor] = ACTIONS(5246),
    [anon_sym_xnor] = ACTIONS(5246),
    [anon_sym_buf] = ACTIONS(5246),
    [anon_sym_tranif0] = ACTIONS(5246),
    [anon_sym_tranif1] = ACTIONS(5246),
    [anon_sym_rtranif1] = ACTIONS(5246),
    [anon_sym_rtranif0] = ACTIONS(5246),
    [anon_sym_tran] = ACTIONS(5246),
    [anon_sym_rtran] = ACTIONS(5246),
    [anon_sym_generate] = ACTIONS(5246),
    [anon_sym_for] = ACTIONS(5246),
    [anon_sym_initial] = ACTIONS(5246),
    [anon_sym_assign] = ACTIONS(5246),
    [anon_sym_alias] = ACTIONS(5246),
    [anon_sym_always_comb] = ACTIONS(5246),
    [anon_sym_always_latch] = ACTIONS(5246),
    [anon_sym_always_ff] = ACTIONS(5246),
    [anon_sym_final] = ACTIONS(5246),
    [anon_sym_global] = ACTIONS(5246),
    [anon_sym_LPAREN_STAR] = ACTIONS(5244),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5244),
    [anon_sym_DOLLARunit] = ACTIONS(5244),
  },
  [4805] = {
    [sym_simple_identifier] = ACTIONS(6751),
    [anon_sym_wire] = ACTIONS(6751),
    [anon_sym_tri] = ACTIONS(6751),
    [anon_sym_tri0] = ACTIONS(6751),
    [anon_sym_tri1] = ACTIONS(6751),
    [anon_sym_wand] = ACTIONS(6751),
    [anon_sym_triand] = ACTIONS(6751),
    [anon_sym_wor] = ACTIONS(6751),
    [anon_sym_trior] = ACTIONS(6751),
    [anon_sym_trireg] = ACTIONS(6751),
    [anon_sym_uwire] = ACTIONS(6751),
    [anon_sym_SEMI] = ACTIONS(6753),
    [anon_sym_extern] = ACTIONS(6751),
    [anon_sym_interface] = ACTIONS(6751),
    [anon_sym_checker] = ACTIONS(6751),
    [anon_sym_virtual] = ACTIONS(6751),
    [anon_sym_class] = ACTIONS(6751),
    [anon_sym_type] = ACTIONS(6751),
    [anon_sym_DOLLARfatal] = ACTIONS(6753),
    [anon_sym_DOLLARerror] = ACTIONS(6753),
    [anon_sym_DOLLARwarning] = ACTIONS(6753),
    [anon_sym_DOLLARinfo] = ACTIONS(6753),
    [anon_sym_default] = ACTIONS(6751),
    [anon_sym_clocking] = ACTIONS(6751),
    [anon_sym_defparam] = ACTIONS(6751),
    [anon_sym_bind] = ACTIONS(6751),
    [anon_sym_rand] = ACTIONS(6751),
    [anon_sym_const] = ACTIONS(6751),
    [anon_sym_function] = ACTIONS(6751),
    [anon_sym_static] = ACTIONS(6751),
    [anon_sym_constraint] = ACTIONS(6751),
    [anon_sym_if] = ACTIONS(6751),
    [anon_sym_else] = ACTIONS(6751),
    [anon_sym_LBRACK] = ACTIONS(6753),
    [anon_sym_localparam] = ACTIONS(6751),
    [anon_sym_parameter] = ACTIONS(6751),
    [anon_sym_var] = ACTIONS(6751),
    [anon_sym_import] = ACTIONS(6751),
    [anon_sym_export] = ACTIONS(6751),
    [anon_sym_genvar] = ACTIONS(6751),
    [anon_sym_interconnect] = ACTIONS(6751),
    [anon_sym_typedef] = ACTIONS(6751),
    [anon_sym_enum] = ACTIONS(6751),
    [anon_sym_struct] = ACTIONS(6751),
    [anon_sym_union] = ACTIONS(6751),
    [anon_sym_nettype] = ACTIONS(6751),
    [anon_sym_automatic] = ACTIONS(6751),
    [anon_sym_string] = ACTIONS(6751),
    [anon_sym_chandle] = ACTIONS(6751),
    [anon_sym_event] = ACTIONS(6751),
    [anon_sym_byte] = ACTIONS(6751),
    [anon_sym_shortint] = ACTIONS(6751),
    [anon_sym_int] = ACTIONS(6751),
    [anon_sym_longint] = ACTIONS(6751),
    [anon_sym_integer] = ACTIONS(6751),
    [anon_sym_time] = ACTIONS(6751),
    [anon_sym_bit] = ACTIONS(6751),
    [anon_sym_logic] = ACTIONS(6751),
    [anon_sym_reg] = ACTIONS(6751),
    [anon_sym_shortreal] = ACTIONS(6751),
    [anon_sym_real] = ACTIONS(6751),
    [anon_sym_realtime] = ACTIONS(6751),
    [anon_sym_supply0] = ACTIONS(6751),
    [anon_sym_supply1] = ACTIONS(6751),
    [anon_sym_signed] = ACTIONS(6751),
    [anon_sym_unsigned] = ACTIONS(6751),
    [anon_sym_task] = ACTIONS(6751),
    [anon_sym_assert] = ACTIONS(6751),
    [anon_sym_property] = ACTIONS(6751),
    [anon_sym_assume] = ACTIONS(6751),
    [anon_sym_cover] = ACTIONS(6751),
    [anon_sym_sequence] = ACTIONS(6751),
    [anon_sym_restrict] = ACTIONS(6751),
    [anon_sym_not] = ACTIONS(6751),
    [anon_sym_or] = ACTIONS(6751),
    [anon_sym_and] = ACTIONS(6751),
    [anon_sym_case] = ACTIONS(6751),
    [anon_sym_always] = ACTIONS(6751),
    [anon_sym_covergroup] = ACTIONS(6751),
    [anon_sym_let] = ACTIONS(6751),
    [anon_sym_pulldown] = ACTIONS(6751),
    [anon_sym_pullup] = ACTIONS(6751),
    [anon_sym_cmos] = ACTIONS(6751),
    [anon_sym_rcmos] = ACTIONS(6751),
    [anon_sym_bufif0] = ACTIONS(6751),
    [anon_sym_bufif1] = ACTIONS(6751),
    [anon_sym_notif0] = ACTIONS(6751),
    [anon_sym_notif1] = ACTIONS(6751),
    [anon_sym_nmos] = ACTIONS(6751),
    [anon_sym_pmos] = ACTIONS(6751),
    [anon_sym_rnmos] = ACTIONS(6751),
    [anon_sym_rpmos] = ACTIONS(6751),
    [anon_sym_nand] = ACTIONS(6751),
    [anon_sym_nor] = ACTIONS(6751),
    [anon_sym_xor] = ACTIONS(6751),
    [anon_sym_xnor] = ACTIONS(6751),
    [anon_sym_buf] = ACTIONS(6751),
    [anon_sym_tranif0] = ACTIONS(6751),
    [anon_sym_tranif1] = ACTIONS(6751),
    [anon_sym_rtranif1] = ACTIONS(6751),
    [anon_sym_rtranif0] = ACTIONS(6751),
    [anon_sym_tran] = ACTIONS(6751),
    [anon_sym_rtran] = ACTIONS(6751),
    [anon_sym_generate] = ACTIONS(6751),
    [anon_sym_endgenerate] = ACTIONS(6751),
    [anon_sym_for] = ACTIONS(6751),
    [anon_sym_initial] = ACTIONS(6751),
    [anon_sym_assign] = ACTIONS(6751),
    [anon_sym_alias] = ACTIONS(6751),
    [anon_sym_always_comb] = ACTIONS(6751),
    [anon_sym_always_latch] = ACTIONS(6751),
    [anon_sym_always_ff] = ACTIONS(6751),
    [anon_sym_final] = ACTIONS(6751),
    [anon_sym_global] = ACTIONS(6751),
    [anon_sym_LPAREN_STAR] = ACTIONS(6753),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6753),
    [anon_sym_DOLLARunit] = ACTIONS(6753),
  },
  [4806] = {
    [sym_simple_identifier] = ACTIONS(6537),
    [anon_sym_wire] = ACTIONS(6537),
    [anon_sym_tri] = ACTIONS(6537),
    [anon_sym_tri0] = ACTIONS(6537),
    [anon_sym_tri1] = ACTIONS(6537),
    [anon_sym_wand] = ACTIONS(6537),
    [anon_sym_triand] = ACTIONS(6537),
    [anon_sym_wor] = ACTIONS(6537),
    [anon_sym_trior] = ACTIONS(6537),
    [anon_sym_trireg] = ACTIONS(6537),
    [anon_sym_uwire] = ACTIONS(6537),
    [anon_sym_SEMI] = ACTIONS(6541),
    [anon_sym_extern] = ACTIONS(6537),
    [anon_sym_interface] = ACTIONS(6537),
    [anon_sym_checker] = ACTIONS(6537),
    [anon_sym_virtual] = ACTIONS(6537),
    [anon_sym_class] = ACTIONS(6537),
    [anon_sym_type] = ACTIONS(6537),
    [anon_sym_DOLLARfatal] = ACTIONS(6541),
    [anon_sym_DOLLARerror] = ACTIONS(6541),
    [anon_sym_DOLLARwarning] = ACTIONS(6541),
    [anon_sym_DOLLARinfo] = ACTIONS(6541),
    [anon_sym_default] = ACTIONS(6537),
    [anon_sym_clocking] = ACTIONS(6537),
    [anon_sym_defparam] = ACTIONS(6537),
    [anon_sym_bind] = ACTIONS(6537),
    [anon_sym_rand] = ACTIONS(6537),
    [anon_sym_const] = ACTIONS(6537),
    [anon_sym_function] = ACTIONS(6537),
    [anon_sym_static] = ACTIONS(6537),
    [anon_sym_constraint] = ACTIONS(6537),
    [anon_sym_if] = ACTIONS(6537),
    [anon_sym_else] = ACTIONS(6537),
    [anon_sym_LBRACK] = ACTIONS(6541),
    [anon_sym_localparam] = ACTIONS(6537),
    [anon_sym_parameter] = ACTIONS(6537),
    [anon_sym_var] = ACTIONS(6537),
    [anon_sym_import] = ACTIONS(6537),
    [anon_sym_export] = ACTIONS(6537),
    [anon_sym_genvar] = ACTIONS(6537),
    [anon_sym_interconnect] = ACTIONS(6537),
    [anon_sym_typedef] = ACTIONS(6537),
    [anon_sym_enum] = ACTIONS(6537),
    [anon_sym_struct] = ACTIONS(6537),
    [anon_sym_union] = ACTIONS(6537),
    [anon_sym_nettype] = ACTIONS(6537),
    [anon_sym_automatic] = ACTIONS(6537),
    [anon_sym_string] = ACTIONS(6537),
    [anon_sym_chandle] = ACTIONS(6537),
    [anon_sym_event] = ACTIONS(6537),
    [anon_sym_byte] = ACTIONS(6537),
    [anon_sym_shortint] = ACTIONS(6537),
    [anon_sym_int] = ACTIONS(6537),
    [anon_sym_longint] = ACTIONS(6537),
    [anon_sym_integer] = ACTIONS(6537),
    [anon_sym_time] = ACTIONS(6537),
    [anon_sym_bit] = ACTIONS(6537),
    [anon_sym_logic] = ACTIONS(6537),
    [anon_sym_reg] = ACTIONS(6537),
    [anon_sym_shortreal] = ACTIONS(6537),
    [anon_sym_real] = ACTIONS(6537),
    [anon_sym_realtime] = ACTIONS(6537),
    [anon_sym_supply0] = ACTIONS(6537),
    [anon_sym_supply1] = ACTIONS(6537),
    [anon_sym_signed] = ACTIONS(6537),
    [anon_sym_unsigned] = ACTIONS(6537),
    [anon_sym_task] = ACTIONS(6537),
    [anon_sym_assert] = ACTIONS(6537),
    [anon_sym_property] = ACTIONS(6537),
    [anon_sym_assume] = ACTIONS(6537),
    [anon_sym_cover] = ACTIONS(6537),
    [anon_sym_sequence] = ACTIONS(6537),
    [anon_sym_restrict] = ACTIONS(6537),
    [anon_sym_not] = ACTIONS(6537),
    [anon_sym_or] = ACTIONS(6537),
    [anon_sym_and] = ACTIONS(6537),
    [anon_sym_case] = ACTIONS(6537),
    [anon_sym_always] = ACTIONS(6537),
    [anon_sym_covergroup] = ACTIONS(6537),
    [anon_sym_let] = ACTIONS(6537),
    [anon_sym_pulldown] = ACTIONS(6537),
    [anon_sym_pullup] = ACTIONS(6537),
    [anon_sym_cmos] = ACTIONS(6537),
    [anon_sym_rcmos] = ACTIONS(6537),
    [anon_sym_bufif0] = ACTIONS(6537),
    [anon_sym_bufif1] = ACTIONS(6537),
    [anon_sym_notif0] = ACTIONS(6537),
    [anon_sym_notif1] = ACTIONS(6537),
    [anon_sym_nmos] = ACTIONS(6537),
    [anon_sym_pmos] = ACTIONS(6537),
    [anon_sym_rnmos] = ACTIONS(6537),
    [anon_sym_rpmos] = ACTIONS(6537),
    [anon_sym_nand] = ACTIONS(6537),
    [anon_sym_nor] = ACTIONS(6537),
    [anon_sym_xor] = ACTIONS(6537),
    [anon_sym_xnor] = ACTIONS(6537),
    [anon_sym_buf] = ACTIONS(6537),
    [anon_sym_tranif0] = ACTIONS(6537),
    [anon_sym_tranif1] = ACTIONS(6537),
    [anon_sym_rtranif1] = ACTIONS(6537),
    [anon_sym_rtranif0] = ACTIONS(6537),
    [anon_sym_tran] = ACTIONS(6537),
    [anon_sym_rtran] = ACTIONS(6537),
    [anon_sym_generate] = ACTIONS(6537),
    [anon_sym_endgenerate] = ACTIONS(6537),
    [anon_sym_for] = ACTIONS(6537),
    [anon_sym_initial] = ACTIONS(6537),
    [anon_sym_assign] = ACTIONS(6537),
    [anon_sym_alias] = ACTIONS(6537),
    [anon_sym_always_comb] = ACTIONS(6537),
    [anon_sym_always_latch] = ACTIONS(6537),
    [anon_sym_always_ff] = ACTIONS(6537),
    [anon_sym_final] = ACTIONS(6537),
    [anon_sym_global] = ACTIONS(6537),
    [anon_sym_LPAREN_STAR] = ACTIONS(6541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6541),
    [anon_sym_DOLLARunit] = ACTIONS(6541),
  },
  [4807] = {
    [sym_simple_identifier] = ACTIONS(4956),
    [anon_sym_wire] = ACTIONS(4956),
    [anon_sym_tri] = ACTIONS(4956),
    [anon_sym_tri0] = ACTIONS(4956),
    [anon_sym_tri1] = ACTIONS(4956),
    [anon_sym_wand] = ACTIONS(4956),
    [anon_sym_triand] = ACTIONS(4956),
    [anon_sym_wor] = ACTIONS(4956),
    [anon_sym_trior] = ACTIONS(4956),
    [anon_sym_trireg] = ACTIONS(4956),
    [anon_sym_uwire] = ACTIONS(4956),
    [anon_sym_SEMI] = ACTIONS(4954),
    [anon_sym_extern] = ACTIONS(4956),
    [anon_sym_interface] = ACTIONS(4956),
    [anon_sym_checker] = ACTIONS(4956),
    [anon_sym_virtual] = ACTIONS(4956),
    [anon_sym_class] = ACTIONS(4956),
    [anon_sym_type] = ACTIONS(4956),
    [anon_sym_DOLLARfatal] = ACTIONS(4954),
    [anon_sym_DOLLARerror] = ACTIONS(4954),
    [anon_sym_DOLLARwarning] = ACTIONS(4954),
    [anon_sym_DOLLARinfo] = ACTIONS(4954),
    [anon_sym_default] = ACTIONS(4956),
    [anon_sym_clocking] = ACTIONS(4956),
    [anon_sym_defparam] = ACTIONS(4956),
    [anon_sym_bind] = ACTIONS(4956),
    [anon_sym_rand] = ACTIONS(4956),
    [anon_sym_const] = ACTIONS(4956),
    [anon_sym_function] = ACTIONS(4956),
    [anon_sym_static] = ACTIONS(4956),
    [anon_sym_constraint] = ACTIONS(4956),
    [anon_sym_if] = ACTIONS(4956),
    [anon_sym_else] = ACTIONS(4956),
    [anon_sym_LBRACK] = ACTIONS(4954),
    [anon_sym_localparam] = ACTIONS(4956),
    [anon_sym_parameter] = ACTIONS(4956),
    [anon_sym_var] = ACTIONS(4956),
    [anon_sym_import] = ACTIONS(4956),
    [anon_sym_export] = ACTIONS(4956),
    [anon_sym_genvar] = ACTIONS(4956),
    [anon_sym_interconnect] = ACTIONS(4956),
    [anon_sym_typedef] = ACTIONS(4956),
    [anon_sym_enum] = ACTIONS(4956),
    [anon_sym_struct] = ACTIONS(4956),
    [anon_sym_union] = ACTIONS(4956),
    [anon_sym_nettype] = ACTIONS(4956),
    [anon_sym_automatic] = ACTIONS(4956),
    [anon_sym_string] = ACTIONS(4956),
    [anon_sym_chandle] = ACTIONS(4956),
    [anon_sym_event] = ACTIONS(4956),
    [anon_sym_byte] = ACTIONS(4956),
    [anon_sym_shortint] = ACTIONS(4956),
    [anon_sym_int] = ACTIONS(4956),
    [anon_sym_longint] = ACTIONS(4956),
    [anon_sym_integer] = ACTIONS(4956),
    [anon_sym_time] = ACTIONS(4956),
    [anon_sym_bit] = ACTIONS(4956),
    [anon_sym_logic] = ACTIONS(4956),
    [anon_sym_reg] = ACTIONS(4956),
    [anon_sym_shortreal] = ACTIONS(4956),
    [anon_sym_real] = ACTIONS(4956),
    [anon_sym_realtime] = ACTIONS(4956),
    [anon_sym_supply0] = ACTIONS(4956),
    [anon_sym_supply1] = ACTIONS(4956),
    [anon_sym_signed] = ACTIONS(4956),
    [anon_sym_unsigned] = ACTIONS(4956),
    [anon_sym_task] = ACTIONS(4956),
    [anon_sym_assert] = ACTIONS(4956),
    [anon_sym_property] = ACTIONS(4956),
    [anon_sym_assume] = ACTIONS(4956),
    [anon_sym_cover] = ACTIONS(4956),
    [anon_sym_sequence] = ACTIONS(4956),
    [anon_sym_restrict] = ACTIONS(4956),
    [anon_sym_not] = ACTIONS(4956),
    [anon_sym_or] = ACTIONS(4956),
    [anon_sym_and] = ACTIONS(4956),
    [anon_sym_case] = ACTIONS(4956),
    [anon_sym_always] = ACTIONS(4956),
    [anon_sym_covergroup] = ACTIONS(4956),
    [anon_sym_let] = ACTIONS(4956),
    [anon_sym_pulldown] = ACTIONS(4956),
    [anon_sym_pullup] = ACTIONS(4956),
    [anon_sym_cmos] = ACTIONS(4956),
    [anon_sym_rcmos] = ACTIONS(4956),
    [anon_sym_bufif0] = ACTIONS(4956),
    [anon_sym_bufif1] = ACTIONS(4956),
    [anon_sym_notif0] = ACTIONS(4956),
    [anon_sym_notif1] = ACTIONS(4956),
    [anon_sym_nmos] = ACTIONS(4956),
    [anon_sym_pmos] = ACTIONS(4956),
    [anon_sym_rnmos] = ACTIONS(4956),
    [anon_sym_rpmos] = ACTIONS(4956),
    [anon_sym_nand] = ACTIONS(4956),
    [anon_sym_nor] = ACTIONS(4956),
    [anon_sym_xor] = ACTIONS(4956),
    [anon_sym_xnor] = ACTIONS(4956),
    [anon_sym_buf] = ACTIONS(4956),
    [anon_sym_tranif0] = ACTIONS(4956),
    [anon_sym_tranif1] = ACTIONS(4956),
    [anon_sym_rtranif1] = ACTIONS(4956),
    [anon_sym_rtranif0] = ACTIONS(4956),
    [anon_sym_tran] = ACTIONS(4956),
    [anon_sym_rtran] = ACTIONS(4956),
    [anon_sym_generate] = ACTIONS(4956),
    [anon_sym_endgenerate] = ACTIONS(4956),
    [anon_sym_for] = ACTIONS(4956),
    [anon_sym_initial] = ACTIONS(4956),
    [anon_sym_assign] = ACTIONS(4956),
    [anon_sym_alias] = ACTIONS(4956),
    [anon_sym_always_comb] = ACTIONS(4956),
    [anon_sym_always_latch] = ACTIONS(4956),
    [anon_sym_always_ff] = ACTIONS(4956),
    [anon_sym_final] = ACTIONS(4956),
    [anon_sym_global] = ACTIONS(4956),
    [anon_sym_LPAREN_STAR] = ACTIONS(4954),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4954),
    [anon_sym_DOLLARunit] = ACTIONS(4954),
  },
  [4808] = {
    [sym_simple_identifier] = ACTIONS(4960),
    [anon_sym_wire] = ACTIONS(4960),
    [anon_sym_tri] = ACTIONS(4960),
    [anon_sym_tri0] = ACTIONS(4960),
    [anon_sym_tri1] = ACTIONS(4960),
    [anon_sym_wand] = ACTIONS(4960),
    [anon_sym_triand] = ACTIONS(4960),
    [anon_sym_wor] = ACTIONS(4960),
    [anon_sym_trior] = ACTIONS(4960),
    [anon_sym_trireg] = ACTIONS(4960),
    [anon_sym_uwire] = ACTIONS(4960),
    [anon_sym_SEMI] = ACTIONS(4958),
    [anon_sym_extern] = ACTIONS(4960),
    [anon_sym_interface] = ACTIONS(4960),
    [anon_sym_checker] = ACTIONS(4960),
    [anon_sym_virtual] = ACTIONS(4960),
    [anon_sym_class] = ACTIONS(4960),
    [anon_sym_type] = ACTIONS(4960),
    [anon_sym_DOLLARfatal] = ACTIONS(4958),
    [anon_sym_DOLLARerror] = ACTIONS(4958),
    [anon_sym_DOLLARwarning] = ACTIONS(4958),
    [anon_sym_DOLLARinfo] = ACTIONS(4958),
    [anon_sym_default] = ACTIONS(4960),
    [anon_sym_clocking] = ACTIONS(4960),
    [anon_sym_defparam] = ACTIONS(4960),
    [anon_sym_bind] = ACTIONS(4960),
    [anon_sym_rand] = ACTIONS(4960),
    [anon_sym_const] = ACTIONS(4960),
    [anon_sym_function] = ACTIONS(4960),
    [anon_sym_static] = ACTIONS(4960),
    [anon_sym_constraint] = ACTIONS(4960),
    [anon_sym_if] = ACTIONS(4960),
    [anon_sym_else] = ACTIONS(4960),
    [anon_sym_LBRACK] = ACTIONS(4958),
    [anon_sym_localparam] = ACTIONS(4960),
    [anon_sym_parameter] = ACTIONS(4960),
    [anon_sym_var] = ACTIONS(4960),
    [anon_sym_import] = ACTIONS(4960),
    [anon_sym_export] = ACTIONS(4960),
    [anon_sym_genvar] = ACTIONS(4960),
    [anon_sym_interconnect] = ACTIONS(4960),
    [anon_sym_typedef] = ACTIONS(4960),
    [anon_sym_enum] = ACTIONS(4960),
    [anon_sym_struct] = ACTIONS(4960),
    [anon_sym_union] = ACTIONS(4960),
    [anon_sym_nettype] = ACTIONS(4960),
    [anon_sym_automatic] = ACTIONS(4960),
    [anon_sym_string] = ACTIONS(4960),
    [anon_sym_chandle] = ACTIONS(4960),
    [anon_sym_event] = ACTIONS(4960),
    [anon_sym_byte] = ACTIONS(4960),
    [anon_sym_shortint] = ACTIONS(4960),
    [anon_sym_int] = ACTIONS(4960),
    [anon_sym_longint] = ACTIONS(4960),
    [anon_sym_integer] = ACTIONS(4960),
    [anon_sym_time] = ACTIONS(4960),
    [anon_sym_bit] = ACTIONS(4960),
    [anon_sym_logic] = ACTIONS(4960),
    [anon_sym_reg] = ACTIONS(4960),
    [anon_sym_shortreal] = ACTIONS(4960),
    [anon_sym_real] = ACTIONS(4960),
    [anon_sym_realtime] = ACTIONS(4960),
    [anon_sym_supply0] = ACTIONS(4960),
    [anon_sym_supply1] = ACTIONS(4960),
    [anon_sym_signed] = ACTIONS(4960),
    [anon_sym_unsigned] = ACTIONS(4960),
    [anon_sym_task] = ACTIONS(4960),
    [anon_sym_assert] = ACTIONS(4960),
    [anon_sym_property] = ACTIONS(4960),
    [anon_sym_assume] = ACTIONS(4960),
    [anon_sym_cover] = ACTIONS(4960),
    [anon_sym_sequence] = ACTIONS(4960),
    [anon_sym_restrict] = ACTIONS(4960),
    [anon_sym_not] = ACTIONS(4960),
    [anon_sym_or] = ACTIONS(4960),
    [anon_sym_and] = ACTIONS(4960),
    [anon_sym_case] = ACTIONS(4960),
    [anon_sym_always] = ACTIONS(4960),
    [anon_sym_covergroup] = ACTIONS(4960),
    [anon_sym_let] = ACTIONS(4960),
    [anon_sym_pulldown] = ACTIONS(4960),
    [anon_sym_pullup] = ACTIONS(4960),
    [anon_sym_cmos] = ACTIONS(4960),
    [anon_sym_rcmos] = ACTIONS(4960),
    [anon_sym_bufif0] = ACTIONS(4960),
    [anon_sym_bufif1] = ACTIONS(4960),
    [anon_sym_notif0] = ACTIONS(4960),
    [anon_sym_notif1] = ACTIONS(4960),
    [anon_sym_nmos] = ACTIONS(4960),
    [anon_sym_pmos] = ACTIONS(4960),
    [anon_sym_rnmos] = ACTIONS(4960),
    [anon_sym_rpmos] = ACTIONS(4960),
    [anon_sym_nand] = ACTIONS(4960),
    [anon_sym_nor] = ACTIONS(4960),
    [anon_sym_xor] = ACTIONS(4960),
    [anon_sym_xnor] = ACTIONS(4960),
    [anon_sym_buf] = ACTIONS(4960),
    [anon_sym_tranif0] = ACTIONS(4960),
    [anon_sym_tranif1] = ACTIONS(4960),
    [anon_sym_rtranif1] = ACTIONS(4960),
    [anon_sym_rtranif0] = ACTIONS(4960),
    [anon_sym_tran] = ACTIONS(4960),
    [anon_sym_rtran] = ACTIONS(4960),
    [anon_sym_generate] = ACTIONS(4960),
    [anon_sym_endgenerate] = ACTIONS(4960),
    [anon_sym_for] = ACTIONS(4960),
    [anon_sym_initial] = ACTIONS(4960),
    [anon_sym_assign] = ACTIONS(4960),
    [anon_sym_alias] = ACTIONS(4960),
    [anon_sym_always_comb] = ACTIONS(4960),
    [anon_sym_always_latch] = ACTIONS(4960),
    [anon_sym_always_ff] = ACTIONS(4960),
    [anon_sym_final] = ACTIONS(4960),
    [anon_sym_global] = ACTIONS(4960),
    [anon_sym_LPAREN_STAR] = ACTIONS(4958),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4958),
    [anon_sym_DOLLARunit] = ACTIONS(4958),
  },
  [4809] = {
    [sym_simple_identifier] = ACTIONS(4872),
    [anon_sym_wire] = ACTIONS(4872),
    [anon_sym_tri] = ACTIONS(4872),
    [anon_sym_tri0] = ACTIONS(4872),
    [anon_sym_tri1] = ACTIONS(4872),
    [anon_sym_wand] = ACTIONS(4872),
    [anon_sym_triand] = ACTIONS(4872),
    [anon_sym_wor] = ACTIONS(4872),
    [anon_sym_trior] = ACTIONS(4872),
    [anon_sym_trireg] = ACTIONS(4872),
    [anon_sym_uwire] = ACTIONS(4872),
    [anon_sym_SEMI] = ACTIONS(4870),
    [anon_sym_extern] = ACTIONS(4872),
    [anon_sym_interface] = ACTIONS(4872),
    [anon_sym_checker] = ACTIONS(4872),
    [anon_sym_virtual] = ACTIONS(4872),
    [anon_sym_class] = ACTIONS(4872),
    [anon_sym_type] = ACTIONS(4872),
    [anon_sym_DOLLARfatal] = ACTIONS(4870),
    [anon_sym_DOLLARerror] = ACTIONS(4870),
    [anon_sym_DOLLARwarning] = ACTIONS(4870),
    [anon_sym_DOLLARinfo] = ACTIONS(4870),
    [anon_sym_default] = ACTIONS(4872),
    [anon_sym_clocking] = ACTIONS(4872),
    [anon_sym_defparam] = ACTIONS(4872),
    [anon_sym_bind] = ACTIONS(4872),
    [anon_sym_rand] = ACTIONS(4872),
    [anon_sym_const] = ACTIONS(4872),
    [anon_sym_function] = ACTIONS(4872),
    [anon_sym_static] = ACTIONS(4872),
    [anon_sym_constraint] = ACTIONS(4872),
    [anon_sym_if] = ACTIONS(4872),
    [anon_sym_else] = ACTIONS(4872),
    [anon_sym_LBRACK] = ACTIONS(4870),
    [anon_sym_localparam] = ACTIONS(4872),
    [anon_sym_parameter] = ACTIONS(4872),
    [anon_sym_var] = ACTIONS(4872),
    [anon_sym_import] = ACTIONS(4872),
    [anon_sym_export] = ACTIONS(4872),
    [anon_sym_genvar] = ACTIONS(4872),
    [anon_sym_interconnect] = ACTIONS(4872),
    [anon_sym_typedef] = ACTIONS(4872),
    [anon_sym_enum] = ACTIONS(4872),
    [anon_sym_struct] = ACTIONS(4872),
    [anon_sym_union] = ACTIONS(4872),
    [anon_sym_nettype] = ACTIONS(4872),
    [anon_sym_automatic] = ACTIONS(4872),
    [anon_sym_string] = ACTIONS(4872),
    [anon_sym_chandle] = ACTIONS(4872),
    [anon_sym_event] = ACTIONS(4872),
    [anon_sym_byte] = ACTIONS(4872),
    [anon_sym_shortint] = ACTIONS(4872),
    [anon_sym_int] = ACTIONS(4872),
    [anon_sym_longint] = ACTIONS(4872),
    [anon_sym_integer] = ACTIONS(4872),
    [anon_sym_time] = ACTIONS(4872),
    [anon_sym_bit] = ACTIONS(4872),
    [anon_sym_logic] = ACTIONS(4872),
    [anon_sym_reg] = ACTIONS(4872),
    [anon_sym_shortreal] = ACTIONS(4872),
    [anon_sym_real] = ACTIONS(4872),
    [anon_sym_realtime] = ACTIONS(4872),
    [anon_sym_supply0] = ACTIONS(4872),
    [anon_sym_supply1] = ACTIONS(4872),
    [anon_sym_signed] = ACTIONS(4872),
    [anon_sym_unsigned] = ACTIONS(4872),
    [anon_sym_task] = ACTIONS(4872),
    [anon_sym_assert] = ACTIONS(4872),
    [anon_sym_property] = ACTIONS(4872),
    [anon_sym_assume] = ACTIONS(4872),
    [anon_sym_cover] = ACTIONS(4872),
    [anon_sym_sequence] = ACTIONS(4872),
    [anon_sym_restrict] = ACTIONS(4872),
    [anon_sym_not] = ACTIONS(4872),
    [anon_sym_or] = ACTIONS(4872),
    [anon_sym_and] = ACTIONS(4872),
    [anon_sym_case] = ACTIONS(4872),
    [anon_sym_always] = ACTIONS(4872),
    [anon_sym_covergroup] = ACTIONS(4872),
    [anon_sym_let] = ACTIONS(4872),
    [anon_sym_pulldown] = ACTIONS(4872),
    [anon_sym_pullup] = ACTIONS(4872),
    [anon_sym_cmos] = ACTIONS(4872),
    [anon_sym_rcmos] = ACTIONS(4872),
    [anon_sym_bufif0] = ACTIONS(4872),
    [anon_sym_bufif1] = ACTIONS(4872),
    [anon_sym_notif0] = ACTIONS(4872),
    [anon_sym_notif1] = ACTIONS(4872),
    [anon_sym_nmos] = ACTIONS(4872),
    [anon_sym_pmos] = ACTIONS(4872),
    [anon_sym_rnmos] = ACTIONS(4872),
    [anon_sym_rpmos] = ACTIONS(4872),
    [anon_sym_nand] = ACTIONS(4872),
    [anon_sym_nor] = ACTIONS(4872),
    [anon_sym_xor] = ACTIONS(4872),
    [anon_sym_xnor] = ACTIONS(4872),
    [anon_sym_buf] = ACTIONS(4872),
    [anon_sym_tranif0] = ACTIONS(4872),
    [anon_sym_tranif1] = ACTIONS(4872),
    [anon_sym_rtranif1] = ACTIONS(4872),
    [anon_sym_rtranif0] = ACTIONS(4872),
    [anon_sym_tran] = ACTIONS(4872),
    [anon_sym_rtran] = ACTIONS(4872),
    [anon_sym_generate] = ACTIONS(4872),
    [anon_sym_endgenerate] = ACTIONS(4872),
    [anon_sym_for] = ACTIONS(4872),
    [anon_sym_initial] = ACTIONS(4872),
    [anon_sym_assign] = ACTIONS(4872),
    [anon_sym_alias] = ACTIONS(4872),
    [anon_sym_always_comb] = ACTIONS(4872),
    [anon_sym_always_latch] = ACTIONS(4872),
    [anon_sym_always_ff] = ACTIONS(4872),
    [anon_sym_final] = ACTIONS(4872),
    [anon_sym_global] = ACTIONS(4872),
    [anon_sym_LPAREN_STAR] = ACTIONS(4870),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4870),
    [anon_sym_DOLLARunit] = ACTIONS(4870),
  },
  [4810] = {
    [sym_simple_identifier] = ACTIONS(5250),
    [anon_sym_wire] = ACTIONS(5250),
    [anon_sym_tri] = ACTIONS(5250),
    [anon_sym_tri0] = ACTIONS(5250),
    [anon_sym_tri1] = ACTIONS(5250),
    [anon_sym_wand] = ACTIONS(5250),
    [anon_sym_triand] = ACTIONS(5250),
    [anon_sym_wor] = ACTIONS(5250),
    [anon_sym_trior] = ACTIONS(5250),
    [anon_sym_trireg] = ACTIONS(5250),
    [anon_sym_uwire] = ACTIONS(5250),
    [anon_sym_SEMI] = ACTIONS(5248),
    [anon_sym_extern] = ACTIONS(5250),
    [anon_sym_interface] = ACTIONS(5250),
    [anon_sym_checker] = ACTIONS(5250),
    [anon_sym_virtual] = ACTIONS(5250),
    [anon_sym_class] = ACTIONS(5250),
    [anon_sym_type] = ACTIONS(5250),
    [anon_sym_DOLLARfatal] = ACTIONS(5248),
    [anon_sym_DOLLARerror] = ACTIONS(5248),
    [anon_sym_DOLLARwarning] = ACTIONS(5248),
    [anon_sym_DOLLARinfo] = ACTIONS(5248),
    [anon_sym_default] = ACTIONS(5250),
    [anon_sym_clocking] = ACTIONS(5250),
    [anon_sym_defparam] = ACTIONS(5250),
    [anon_sym_bind] = ACTIONS(5250),
    [anon_sym_rand] = ACTIONS(5250),
    [anon_sym_const] = ACTIONS(5250),
    [anon_sym_function] = ACTIONS(5250),
    [anon_sym_static] = ACTIONS(5250),
    [anon_sym_constraint] = ACTIONS(5250),
    [anon_sym_if] = ACTIONS(5250),
    [anon_sym_else] = ACTIONS(5250),
    [anon_sym_LBRACK] = ACTIONS(5248),
    [anon_sym_localparam] = ACTIONS(5250),
    [anon_sym_parameter] = ACTIONS(5250),
    [anon_sym_var] = ACTIONS(5250),
    [anon_sym_import] = ACTIONS(5250),
    [anon_sym_export] = ACTIONS(5250),
    [anon_sym_genvar] = ACTIONS(5250),
    [anon_sym_interconnect] = ACTIONS(5250),
    [anon_sym_typedef] = ACTIONS(5250),
    [anon_sym_enum] = ACTIONS(5250),
    [anon_sym_struct] = ACTIONS(5250),
    [anon_sym_union] = ACTIONS(5250),
    [anon_sym_nettype] = ACTIONS(5250),
    [anon_sym_automatic] = ACTIONS(5250),
    [anon_sym_string] = ACTIONS(5250),
    [anon_sym_chandle] = ACTIONS(5250),
    [anon_sym_event] = ACTIONS(5250),
    [anon_sym_byte] = ACTIONS(5250),
    [anon_sym_shortint] = ACTIONS(5250),
    [anon_sym_int] = ACTIONS(5250),
    [anon_sym_longint] = ACTIONS(5250),
    [anon_sym_integer] = ACTIONS(5250),
    [anon_sym_time] = ACTIONS(5250),
    [anon_sym_bit] = ACTIONS(5250),
    [anon_sym_logic] = ACTIONS(5250),
    [anon_sym_reg] = ACTIONS(5250),
    [anon_sym_shortreal] = ACTIONS(5250),
    [anon_sym_real] = ACTIONS(5250),
    [anon_sym_realtime] = ACTIONS(5250),
    [anon_sym_supply0] = ACTIONS(5250),
    [anon_sym_supply1] = ACTIONS(5250),
    [anon_sym_signed] = ACTIONS(5250),
    [anon_sym_unsigned] = ACTIONS(5250),
    [anon_sym_task] = ACTIONS(5250),
    [anon_sym_assert] = ACTIONS(5250),
    [anon_sym_property] = ACTIONS(5250),
    [anon_sym_assume] = ACTIONS(5250),
    [anon_sym_cover] = ACTIONS(5250),
    [anon_sym_sequence] = ACTIONS(5250),
    [anon_sym_restrict] = ACTIONS(5250),
    [anon_sym_not] = ACTIONS(5250),
    [anon_sym_or] = ACTIONS(5250),
    [anon_sym_and] = ACTIONS(5250),
    [anon_sym_case] = ACTIONS(5250),
    [anon_sym_always] = ACTIONS(5250),
    [anon_sym_covergroup] = ACTIONS(5250),
    [anon_sym_end] = ACTIONS(5250),
    [anon_sym_let] = ACTIONS(5250),
    [anon_sym_pulldown] = ACTIONS(5250),
    [anon_sym_pullup] = ACTIONS(5250),
    [anon_sym_cmos] = ACTIONS(5250),
    [anon_sym_rcmos] = ACTIONS(5250),
    [anon_sym_bufif0] = ACTIONS(5250),
    [anon_sym_bufif1] = ACTIONS(5250),
    [anon_sym_notif0] = ACTIONS(5250),
    [anon_sym_notif1] = ACTIONS(5250),
    [anon_sym_nmos] = ACTIONS(5250),
    [anon_sym_pmos] = ACTIONS(5250),
    [anon_sym_rnmos] = ACTIONS(5250),
    [anon_sym_rpmos] = ACTIONS(5250),
    [anon_sym_nand] = ACTIONS(5250),
    [anon_sym_nor] = ACTIONS(5250),
    [anon_sym_xor] = ACTIONS(5250),
    [anon_sym_xnor] = ACTIONS(5250),
    [anon_sym_buf] = ACTIONS(5250),
    [anon_sym_tranif0] = ACTIONS(5250),
    [anon_sym_tranif1] = ACTIONS(5250),
    [anon_sym_rtranif1] = ACTIONS(5250),
    [anon_sym_rtranif0] = ACTIONS(5250),
    [anon_sym_tran] = ACTIONS(5250),
    [anon_sym_rtran] = ACTIONS(5250),
    [anon_sym_generate] = ACTIONS(5250),
    [anon_sym_for] = ACTIONS(5250),
    [anon_sym_initial] = ACTIONS(5250),
    [anon_sym_assign] = ACTIONS(5250),
    [anon_sym_alias] = ACTIONS(5250),
    [anon_sym_always_comb] = ACTIONS(5250),
    [anon_sym_always_latch] = ACTIONS(5250),
    [anon_sym_always_ff] = ACTIONS(5250),
    [anon_sym_final] = ACTIONS(5250),
    [anon_sym_global] = ACTIONS(5250),
    [anon_sym_LPAREN_STAR] = ACTIONS(5248),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5248),
    [anon_sym_DOLLARunit] = ACTIONS(5248),
  },
  [4811] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_rand] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_end] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [4812] = {
    [sym_simple_identifier] = ACTIONS(1676),
    [anon_sym_wire] = ACTIONS(1676),
    [anon_sym_tri] = ACTIONS(1676),
    [anon_sym_tri0] = ACTIONS(1676),
    [anon_sym_tri1] = ACTIONS(1676),
    [anon_sym_wand] = ACTIONS(1676),
    [anon_sym_triand] = ACTIONS(1676),
    [anon_sym_wor] = ACTIONS(1676),
    [anon_sym_trior] = ACTIONS(1676),
    [anon_sym_trireg] = ACTIONS(1676),
    [anon_sym_uwire] = ACTIONS(1676),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_extern] = ACTIONS(1676),
    [anon_sym_interface] = ACTIONS(1676),
    [anon_sym_checker] = ACTIONS(1676),
    [anon_sym_virtual] = ACTIONS(1676),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_DOLLARfatal] = ACTIONS(1674),
    [anon_sym_DOLLARerror] = ACTIONS(1674),
    [anon_sym_DOLLARwarning] = ACTIONS(1674),
    [anon_sym_DOLLARinfo] = ACTIONS(1674),
    [anon_sym_default] = ACTIONS(1676),
    [anon_sym_clocking] = ACTIONS(1676),
    [anon_sym_defparam] = ACTIONS(1676),
    [anon_sym_bind] = ACTIONS(1676),
    [anon_sym_rand] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_constraint] = ACTIONS(1676),
    [anon_sym_if] = ACTIONS(1676),
    [anon_sym_else] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_localparam] = ACTIONS(1676),
    [anon_sym_parameter] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_export] = ACTIONS(1676),
    [anon_sym_genvar] = ACTIONS(1676),
    [anon_sym_interconnect] = ACTIONS(1676),
    [anon_sym_typedef] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [anon_sym_struct] = ACTIONS(1676),
    [anon_sym_union] = ACTIONS(1676),
    [anon_sym_nettype] = ACTIONS(1676),
    [anon_sym_automatic] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_chandle] = ACTIONS(1676),
    [anon_sym_event] = ACTIONS(1676),
    [anon_sym_byte] = ACTIONS(1676),
    [anon_sym_shortint] = ACTIONS(1676),
    [anon_sym_int] = ACTIONS(1676),
    [anon_sym_longint] = ACTIONS(1676),
    [anon_sym_integer] = ACTIONS(1676),
    [anon_sym_time] = ACTIONS(1676),
    [anon_sym_bit] = ACTIONS(1676),
    [anon_sym_logic] = ACTIONS(1676),
    [anon_sym_reg] = ACTIONS(1676),
    [anon_sym_shortreal] = ACTIONS(1676),
    [anon_sym_real] = ACTIONS(1676),
    [anon_sym_realtime] = ACTIONS(1676),
    [anon_sym_supply0] = ACTIONS(1676),
    [anon_sym_supply1] = ACTIONS(1676),
    [anon_sym_signed] = ACTIONS(1676),
    [anon_sym_unsigned] = ACTIONS(1676),
    [anon_sym_task] = ACTIONS(1676),
    [anon_sym_assert] = ACTIONS(1676),
    [anon_sym_property] = ACTIONS(1676),
    [anon_sym_assume] = ACTIONS(1676),
    [anon_sym_cover] = ACTIONS(1676),
    [anon_sym_sequence] = ACTIONS(1676),
    [anon_sym_restrict] = ACTIONS(1676),
    [anon_sym_not] = ACTIONS(1676),
    [anon_sym_or] = ACTIONS(1676),
    [anon_sym_and] = ACTIONS(1676),
    [anon_sym_case] = ACTIONS(1676),
    [anon_sym_always] = ACTIONS(1676),
    [anon_sym_covergroup] = ACTIONS(1676),
    [anon_sym_end] = ACTIONS(1676),
    [anon_sym_let] = ACTIONS(1676),
    [anon_sym_pulldown] = ACTIONS(1676),
    [anon_sym_pullup] = ACTIONS(1676),
    [anon_sym_cmos] = ACTIONS(1676),
    [anon_sym_rcmos] = ACTIONS(1676),
    [anon_sym_bufif0] = ACTIONS(1676),
    [anon_sym_bufif1] = ACTIONS(1676),
    [anon_sym_notif0] = ACTIONS(1676),
    [anon_sym_notif1] = ACTIONS(1676),
    [anon_sym_nmos] = ACTIONS(1676),
    [anon_sym_pmos] = ACTIONS(1676),
    [anon_sym_rnmos] = ACTIONS(1676),
    [anon_sym_rpmos] = ACTIONS(1676),
    [anon_sym_nand] = ACTIONS(1676),
    [anon_sym_nor] = ACTIONS(1676),
    [anon_sym_xor] = ACTIONS(1676),
    [anon_sym_xnor] = ACTIONS(1676),
    [anon_sym_buf] = ACTIONS(1676),
    [anon_sym_tranif0] = ACTIONS(1676),
    [anon_sym_tranif1] = ACTIONS(1676),
    [anon_sym_rtranif1] = ACTIONS(1676),
    [anon_sym_rtranif0] = ACTIONS(1676),
    [anon_sym_tran] = ACTIONS(1676),
    [anon_sym_rtran] = ACTIONS(1676),
    [anon_sym_generate] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1676),
    [anon_sym_initial] = ACTIONS(1676),
    [anon_sym_assign] = ACTIONS(1676),
    [anon_sym_alias] = ACTIONS(1676),
    [anon_sym_always_comb] = ACTIONS(1676),
    [anon_sym_always_latch] = ACTIONS(1676),
    [anon_sym_always_ff] = ACTIONS(1676),
    [anon_sym_final] = ACTIONS(1676),
    [anon_sym_global] = ACTIONS(1676),
    [anon_sym_LPAREN_STAR] = ACTIONS(1674),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1674),
    [anon_sym_DOLLARunit] = ACTIONS(1674),
  },
  [4813] = {
    [sym_simple_identifier] = ACTIONS(6723),
    [anon_sym_wire] = ACTIONS(6723),
    [anon_sym_tri] = ACTIONS(6723),
    [anon_sym_tri0] = ACTIONS(6723),
    [anon_sym_tri1] = ACTIONS(6723),
    [anon_sym_wand] = ACTIONS(6723),
    [anon_sym_triand] = ACTIONS(6723),
    [anon_sym_wor] = ACTIONS(6723),
    [anon_sym_trior] = ACTIONS(6723),
    [anon_sym_trireg] = ACTIONS(6723),
    [anon_sym_uwire] = ACTIONS(6723),
    [anon_sym_SEMI] = ACTIONS(6725),
    [anon_sym_extern] = ACTIONS(6723),
    [anon_sym_interface] = ACTIONS(6723),
    [anon_sym_checker] = ACTIONS(6723),
    [anon_sym_virtual] = ACTIONS(6723),
    [anon_sym_class] = ACTIONS(6723),
    [anon_sym_type] = ACTIONS(6723),
    [anon_sym_DOLLARfatal] = ACTIONS(6725),
    [anon_sym_DOLLARerror] = ACTIONS(6725),
    [anon_sym_DOLLARwarning] = ACTIONS(6725),
    [anon_sym_DOLLARinfo] = ACTIONS(6725),
    [anon_sym_default] = ACTIONS(6723),
    [anon_sym_clocking] = ACTIONS(6723),
    [anon_sym_defparam] = ACTIONS(6723),
    [anon_sym_bind] = ACTIONS(6723),
    [anon_sym_rand] = ACTIONS(6723),
    [anon_sym_const] = ACTIONS(6723),
    [anon_sym_function] = ACTIONS(6723),
    [anon_sym_static] = ACTIONS(6723),
    [anon_sym_constraint] = ACTIONS(6723),
    [anon_sym_if] = ACTIONS(6723),
    [anon_sym_else] = ACTIONS(6723),
    [anon_sym_LBRACK] = ACTIONS(6725),
    [anon_sym_localparam] = ACTIONS(6723),
    [anon_sym_parameter] = ACTIONS(6723),
    [anon_sym_var] = ACTIONS(6723),
    [anon_sym_import] = ACTIONS(6723),
    [anon_sym_export] = ACTIONS(6723),
    [anon_sym_genvar] = ACTIONS(6723),
    [anon_sym_interconnect] = ACTIONS(6723),
    [anon_sym_typedef] = ACTIONS(6723),
    [anon_sym_enum] = ACTIONS(6723),
    [anon_sym_struct] = ACTIONS(6723),
    [anon_sym_union] = ACTIONS(6723),
    [anon_sym_nettype] = ACTIONS(6723),
    [anon_sym_automatic] = ACTIONS(6723),
    [anon_sym_string] = ACTIONS(6723),
    [anon_sym_chandle] = ACTIONS(6723),
    [anon_sym_event] = ACTIONS(6723),
    [anon_sym_byte] = ACTIONS(6723),
    [anon_sym_shortint] = ACTIONS(6723),
    [anon_sym_int] = ACTIONS(6723),
    [anon_sym_longint] = ACTIONS(6723),
    [anon_sym_integer] = ACTIONS(6723),
    [anon_sym_time] = ACTIONS(6723),
    [anon_sym_bit] = ACTIONS(6723),
    [anon_sym_logic] = ACTIONS(6723),
    [anon_sym_reg] = ACTIONS(6723),
    [anon_sym_shortreal] = ACTIONS(6723),
    [anon_sym_real] = ACTIONS(6723),
    [anon_sym_realtime] = ACTIONS(6723),
    [anon_sym_supply0] = ACTIONS(6723),
    [anon_sym_supply1] = ACTIONS(6723),
    [anon_sym_signed] = ACTIONS(6723),
    [anon_sym_unsigned] = ACTIONS(6723),
    [anon_sym_task] = ACTIONS(6723),
    [anon_sym_assert] = ACTIONS(6723),
    [anon_sym_property] = ACTIONS(6723),
    [anon_sym_assume] = ACTIONS(6723),
    [anon_sym_cover] = ACTIONS(6723),
    [anon_sym_sequence] = ACTIONS(6723),
    [anon_sym_restrict] = ACTIONS(6723),
    [anon_sym_not] = ACTIONS(6723),
    [anon_sym_or] = ACTIONS(6723),
    [anon_sym_and] = ACTIONS(6723),
    [anon_sym_case] = ACTIONS(6723),
    [anon_sym_always] = ACTIONS(6723),
    [anon_sym_covergroup] = ACTIONS(6723),
    [anon_sym_let] = ACTIONS(6723),
    [anon_sym_pulldown] = ACTIONS(6723),
    [anon_sym_pullup] = ACTIONS(6723),
    [anon_sym_cmos] = ACTIONS(6723),
    [anon_sym_rcmos] = ACTIONS(6723),
    [anon_sym_bufif0] = ACTIONS(6723),
    [anon_sym_bufif1] = ACTIONS(6723),
    [anon_sym_notif0] = ACTIONS(6723),
    [anon_sym_notif1] = ACTIONS(6723),
    [anon_sym_nmos] = ACTIONS(6723),
    [anon_sym_pmos] = ACTIONS(6723),
    [anon_sym_rnmos] = ACTIONS(6723),
    [anon_sym_rpmos] = ACTIONS(6723),
    [anon_sym_nand] = ACTIONS(6723),
    [anon_sym_nor] = ACTIONS(6723),
    [anon_sym_xor] = ACTIONS(6723),
    [anon_sym_xnor] = ACTIONS(6723),
    [anon_sym_buf] = ACTIONS(6723),
    [anon_sym_tranif0] = ACTIONS(6723),
    [anon_sym_tranif1] = ACTIONS(6723),
    [anon_sym_rtranif1] = ACTIONS(6723),
    [anon_sym_rtranif0] = ACTIONS(6723),
    [anon_sym_tran] = ACTIONS(6723),
    [anon_sym_rtran] = ACTIONS(6723),
    [anon_sym_generate] = ACTIONS(6723),
    [anon_sym_endgenerate] = ACTIONS(6723),
    [anon_sym_for] = ACTIONS(6723),
    [anon_sym_initial] = ACTIONS(6723),
    [anon_sym_assign] = ACTIONS(6723),
    [anon_sym_alias] = ACTIONS(6723),
    [anon_sym_always_comb] = ACTIONS(6723),
    [anon_sym_always_latch] = ACTIONS(6723),
    [anon_sym_always_ff] = ACTIONS(6723),
    [anon_sym_final] = ACTIONS(6723),
    [anon_sym_global] = ACTIONS(6723),
    [anon_sym_LPAREN_STAR] = ACTIONS(6725),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6725),
    [anon_sym_DOLLARunit] = ACTIONS(6725),
  },
  [4814] = {
    [sym_simple_identifier] = ACTIONS(4884),
    [anon_sym_wire] = ACTIONS(4884),
    [anon_sym_tri] = ACTIONS(4884),
    [anon_sym_tri0] = ACTIONS(4884),
    [anon_sym_tri1] = ACTIONS(4884),
    [anon_sym_wand] = ACTIONS(4884),
    [anon_sym_triand] = ACTIONS(4884),
    [anon_sym_wor] = ACTIONS(4884),
    [anon_sym_trior] = ACTIONS(4884),
    [anon_sym_trireg] = ACTIONS(4884),
    [anon_sym_uwire] = ACTIONS(4884),
    [anon_sym_SEMI] = ACTIONS(4882),
    [anon_sym_extern] = ACTIONS(4884),
    [anon_sym_interface] = ACTIONS(4884),
    [anon_sym_checker] = ACTIONS(4884),
    [anon_sym_virtual] = ACTIONS(4884),
    [anon_sym_class] = ACTIONS(4884),
    [anon_sym_type] = ACTIONS(4884),
    [anon_sym_DOLLARfatal] = ACTIONS(4882),
    [anon_sym_DOLLARerror] = ACTIONS(4882),
    [anon_sym_DOLLARwarning] = ACTIONS(4882),
    [anon_sym_DOLLARinfo] = ACTIONS(4882),
    [anon_sym_default] = ACTIONS(4884),
    [anon_sym_clocking] = ACTIONS(4884),
    [anon_sym_defparam] = ACTIONS(4884),
    [anon_sym_bind] = ACTIONS(4884),
    [anon_sym_rand] = ACTIONS(4884),
    [anon_sym_const] = ACTIONS(4884),
    [anon_sym_function] = ACTIONS(4884),
    [anon_sym_static] = ACTIONS(4884),
    [anon_sym_constraint] = ACTIONS(4884),
    [anon_sym_if] = ACTIONS(4884),
    [anon_sym_else] = ACTIONS(4884),
    [anon_sym_LBRACK] = ACTIONS(4882),
    [anon_sym_localparam] = ACTIONS(4884),
    [anon_sym_parameter] = ACTIONS(4884),
    [anon_sym_var] = ACTIONS(4884),
    [anon_sym_import] = ACTIONS(4884),
    [anon_sym_export] = ACTIONS(4884),
    [anon_sym_genvar] = ACTIONS(4884),
    [anon_sym_interconnect] = ACTIONS(4884),
    [anon_sym_typedef] = ACTIONS(4884),
    [anon_sym_enum] = ACTIONS(4884),
    [anon_sym_struct] = ACTIONS(4884),
    [anon_sym_union] = ACTIONS(4884),
    [anon_sym_nettype] = ACTIONS(4884),
    [anon_sym_automatic] = ACTIONS(4884),
    [anon_sym_string] = ACTIONS(4884),
    [anon_sym_chandle] = ACTIONS(4884),
    [anon_sym_event] = ACTIONS(4884),
    [anon_sym_byte] = ACTIONS(4884),
    [anon_sym_shortint] = ACTIONS(4884),
    [anon_sym_int] = ACTIONS(4884),
    [anon_sym_longint] = ACTIONS(4884),
    [anon_sym_integer] = ACTIONS(4884),
    [anon_sym_time] = ACTIONS(4884),
    [anon_sym_bit] = ACTIONS(4884),
    [anon_sym_logic] = ACTIONS(4884),
    [anon_sym_reg] = ACTIONS(4884),
    [anon_sym_shortreal] = ACTIONS(4884),
    [anon_sym_real] = ACTIONS(4884),
    [anon_sym_realtime] = ACTIONS(4884),
    [anon_sym_supply0] = ACTIONS(4884),
    [anon_sym_supply1] = ACTIONS(4884),
    [anon_sym_signed] = ACTIONS(4884),
    [anon_sym_unsigned] = ACTIONS(4884),
    [anon_sym_task] = ACTIONS(4884),
    [anon_sym_assert] = ACTIONS(4884),
    [anon_sym_property] = ACTIONS(4884),
    [anon_sym_assume] = ACTIONS(4884),
    [anon_sym_cover] = ACTIONS(4884),
    [anon_sym_sequence] = ACTIONS(4884),
    [anon_sym_restrict] = ACTIONS(4884),
    [anon_sym_not] = ACTIONS(4884),
    [anon_sym_or] = ACTIONS(4884),
    [anon_sym_and] = ACTIONS(4884),
    [anon_sym_case] = ACTIONS(4884),
    [anon_sym_always] = ACTIONS(4884),
    [anon_sym_covergroup] = ACTIONS(4884),
    [anon_sym_end] = ACTIONS(4884),
    [anon_sym_let] = ACTIONS(4884),
    [anon_sym_pulldown] = ACTIONS(4884),
    [anon_sym_pullup] = ACTIONS(4884),
    [anon_sym_cmos] = ACTIONS(4884),
    [anon_sym_rcmos] = ACTIONS(4884),
    [anon_sym_bufif0] = ACTIONS(4884),
    [anon_sym_bufif1] = ACTIONS(4884),
    [anon_sym_notif0] = ACTIONS(4884),
    [anon_sym_notif1] = ACTIONS(4884),
    [anon_sym_nmos] = ACTIONS(4884),
    [anon_sym_pmos] = ACTIONS(4884),
    [anon_sym_rnmos] = ACTIONS(4884),
    [anon_sym_rpmos] = ACTIONS(4884),
    [anon_sym_nand] = ACTIONS(4884),
    [anon_sym_nor] = ACTIONS(4884),
    [anon_sym_xor] = ACTIONS(4884),
    [anon_sym_xnor] = ACTIONS(4884),
    [anon_sym_buf] = ACTIONS(4884),
    [anon_sym_tranif0] = ACTIONS(4884),
    [anon_sym_tranif1] = ACTIONS(4884),
    [anon_sym_rtranif1] = ACTIONS(4884),
    [anon_sym_rtranif0] = ACTIONS(4884),
    [anon_sym_tran] = ACTIONS(4884),
    [anon_sym_rtran] = ACTIONS(4884),
    [anon_sym_generate] = ACTIONS(4884),
    [anon_sym_for] = ACTIONS(4884),
    [anon_sym_initial] = ACTIONS(4884),
    [anon_sym_assign] = ACTIONS(4884),
    [anon_sym_alias] = ACTIONS(4884),
    [anon_sym_always_comb] = ACTIONS(4884),
    [anon_sym_always_latch] = ACTIONS(4884),
    [anon_sym_always_ff] = ACTIONS(4884),
    [anon_sym_final] = ACTIONS(4884),
    [anon_sym_global] = ACTIONS(4884),
    [anon_sym_LPAREN_STAR] = ACTIONS(4882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4882),
    [anon_sym_DOLLARunit] = ACTIONS(4882),
  },
  [4815] = {
    [sym_simple_identifier] = ACTIONS(4976),
    [anon_sym_wire] = ACTIONS(4976),
    [anon_sym_tri] = ACTIONS(4976),
    [anon_sym_tri0] = ACTIONS(4976),
    [anon_sym_tri1] = ACTIONS(4976),
    [anon_sym_wand] = ACTIONS(4976),
    [anon_sym_triand] = ACTIONS(4976),
    [anon_sym_wor] = ACTIONS(4976),
    [anon_sym_trior] = ACTIONS(4976),
    [anon_sym_trireg] = ACTIONS(4976),
    [anon_sym_uwire] = ACTIONS(4976),
    [anon_sym_SEMI] = ACTIONS(4974),
    [anon_sym_extern] = ACTIONS(4976),
    [anon_sym_interface] = ACTIONS(4976),
    [anon_sym_checker] = ACTIONS(4976),
    [anon_sym_virtual] = ACTIONS(4976),
    [anon_sym_class] = ACTIONS(4976),
    [anon_sym_type] = ACTIONS(4976),
    [anon_sym_DOLLARfatal] = ACTIONS(4974),
    [anon_sym_DOLLARerror] = ACTIONS(4974),
    [anon_sym_DOLLARwarning] = ACTIONS(4974),
    [anon_sym_DOLLARinfo] = ACTIONS(4974),
    [anon_sym_default] = ACTIONS(4976),
    [anon_sym_clocking] = ACTIONS(4976),
    [anon_sym_defparam] = ACTIONS(4976),
    [anon_sym_bind] = ACTIONS(4976),
    [anon_sym_rand] = ACTIONS(4976),
    [anon_sym_const] = ACTIONS(4976),
    [anon_sym_function] = ACTIONS(4976),
    [anon_sym_static] = ACTIONS(4976),
    [anon_sym_constraint] = ACTIONS(4976),
    [anon_sym_if] = ACTIONS(4976),
    [anon_sym_else] = ACTIONS(4976),
    [anon_sym_LBRACK] = ACTIONS(4974),
    [anon_sym_localparam] = ACTIONS(4976),
    [anon_sym_parameter] = ACTIONS(4976),
    [anon_sym_var] = ACTIONS(4976),
    [anon_sym_import] = ACTIONS(4976),
    [anon_sym_export] = ACTIONS(4976),
    [anon_sym_genvar] = ACTIONS(4976),
    [anon_sym_interconnect] = ACTIONS(4976),
    [anon_sym_typedef] = ACTIONS(4976),
    [anon_sym_enum] = ACTIONS(4976),
    [anon_sym_struct] = ACTIONS(4976),
    [anon_sym_union] = ACTIONS(4976),
    [anon_sym_nettype] = ACTIONS(4976),
    [anon_sym_automatic] = ACTIONS(4976),
    [anon_sym_string] = ACTIONS(4976),
    [anon_sym_chandle] = ACTIONS(4976),
    [anon_sym_event] = ACTIONS(4976),
    [anon_sym_byte] = ACTIONS(4976),
    [anon_sym_shortint] = ACTIONS(4976),
    [anon_sym_int] = ACTIONS(4976),
    [anon_sym_longint] = ACTIONS(4976),
    [anon_sym_integer] = ACTIONS(4976),
    [anon_sym_time] = ACTIONS(4976),
    [anon_sym_bit] = ACTIONS(4976),
    [anon_sym_logic] = ACTIONS(4976),
    [anon_sym_reg] = ACTIONS(4976),
    [anon_sym_shortreal] = ACTIONS(4976),
    [anon_sym_real] = ACTIONS(4976),
    [anon_sym_realtime] = ACTIONS(4976),
    [anon_sym_supply0] = ACTIONS(4976),
    [anon_sym_supply1] = ACTIONS(4976),
    [anon_sym_signed] = ACTIONS(4976),
    [anon_sym_unsigned] = ACTIONS(4976),
    [anon_sym_task] = ACTIONS(4976),
    [anon_sym_assert] = ACTIONS(4976),
    [anon_sym_property] = ACTIONS(4976),
    [anon_sym_assume] = ACTIONS(4976),
    [anon_sym_cover] = ACTIONS(4976),
    [anon_sym_sequence] = ACTIONS(4976),
    [anon_sym_restrict] = ACTIONS(4976),
    [anon_sym_not] = ACTIONS(4976),
    [anon_sym_or] = ACTIONS(4976),
    [anon_sym_and] = ACTIONS(4976),
    [anon_sym_case] = ACTIONS(4976),
    [anon_sym_always] = ACTIONS(4976),
    [anon_sym_covergroup] = ACTIONS(4976),
    [anon_sym_end] = ACTIONS(4976),
    [anon_sym_let] = ACTIONS(4976),
    [anon_sym_pulldown] = ACTIONS(4976),
    [anon_sym_pullup] = ACTIONS(4976),
    [anon_sym_cmos] = ACTIONS(4976),
    [anon_sym_rcmos] = ACTIONS(4976),
    [anon_sym_bufif0] = ACTIONS(4976),
    [anon_sym_bufif1] = ACTIONS(4976),
    [anon_sym_notif0] = ACTIONS(4976),
    [anon_sym_notif1] = ACTIONS(4976),
    [anon_sym_nmos] = ACTIONS(4976),
    [anon_sym_pmos] = ACTIONS(4976),
    [anon_sym_rnmos] = ACTIONS(4976),
    [anon_sym_rpmos] = ACTIONS(4976),
    [anon_sym_nand] = ACTIONS(4976),
    [anon_sym_nor] = ACTIONS(4976),
    [anon_sym_xor] = ACTIONS(4976),
    [anon_sym_xnor] = ACTIONS(4976),
    [anon_sym_buf] = ACTIONS(4976),
    [anon_sym_tranif0] = ACTIONS(4976),
    [anon_sym_tranif1] = ACTIONS(4976),
    [anon_sym_rtranif1] = ACTIONS(4976),
    [anon_sym_rtranif0] = ACTIONS(4976),
    [anon_sym_tran] = ACTIONS(4976),
    [anon_sym_rtran] = ACTIONS(4976),
    [anon_sym_generate] = ACTIONS(4976),
    [anon_sym_for] = ACTIONS(4976),
    [anon_sym_initial] = ACTIONS(4976),
    [anon_sym_assign] = ACTIONS(4976),
    [anon_sym_alias] = ACTIONS(4976),
    [anon_sym_always_comb] = ACTIONS(4976),
    [anon_sym_always_latch] = ACTIONS(4976),
    [anon_sym_always_ff] = ACTIONS(4976),
    [anon_sym_final] = ACTIONS(4976),
    [anon_sym_global] = ACTIONS(4976),
    [anon_sym_LPAREN_STAR] = ACTIONS(4974),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4974),
    [anon_sym_DOLLARunit] = ACTIONS(4974),
  },
  [4816] = {
    [sym_simple_identifier] = ACTIONS(4952),
    [anon_sym_wire] = ACTIONS(4952),
    [anon_sym_tri] = ACTIONS(4952),
    [anon_sym_tri0] = ACTIONS(4952),
    [anon_sym_tri1] = ACTIONS(4952),
    [anon_sym_wand] = ACTIONS(4952),
    [anon_sym_triand] = ACTIONS(4952),
    [anon_sym_wor] = ACTIONS(4952),
    [anon_sym_trior] = ACTIONS(4952),
    [anon_sym_trireg] = ACTIONS(4952),
    [anon_sym_uwire] = ACTIONS(4952),
    [anon_sym_SEMI] = ACTIONS(4950),
    [anon_sym_extern] = ACTIONS(4952),
    [anon_sym_interface] = ACTIONS(4952),
    [anon_sym_checker] = ACTIONS(4952),
    [anon_sym_virtual] = ACTIONS(4952),
    [anon_sym_class] = ACTIONS(4952),
    [anon_sym_type] = ACTIONS(4952),
    [anon_sym_DOLLARfatal] = ACTIONS(4950),
    [anon_sym_DOLLARerror] = ACTIONS(4950),
    [anon_sym_DOLLARwarning] = ACTIONS(4950),
    [anon_sym_DOLLARinfo] = ACTIONS(4950),
    [anon_sym_default] = ACTIONS(4952),
    [anon_sym_clocking] = ACTIONS(4952),
    [anon_sym_defparam] = ACTIONS(4952),
    [anon_sym_bind] = ACTIONS(4952),
    [anon_sym_rand] = ACTIONS(4952),
    [anon_sym_const] = ACTIONS(4952),
    [anon_sym_function] = ACTIONS(4952),
    [anon_sym_static] = ACTIONS(4952),
    [anon_sym_constraint] = ACTIONS(4952),
    [anon_sym_if] = ACTIONS(4952),
    [anon_sym_else] = ACTIONS(4952),
    [anon_sym_LBRACK] = ACTIONS(4950),
    [anon_sym_localparam] = ACTIONS(4952),
    [anon_sym_parameter] = ACTIONS(4952),
    [anon_sym_var] = ACTIONS(4952),
    [anon_sym_import] = ACTIONS(4952),
    [anon_sym_export] = ACTIONS(4952),
    [anon_sym_genvar] = ACTIONS(4952),
    [anon_sym_interconnect] = ACTIONS(4952),
    [anon_sym_typedef] = ACTIONS(4952),
    [anon_sym_enum] = ACTIONS(4952),
    [anon_sym_struct] = ACTIONS(4952),
    [anon_sym_union] = ACTIONS(4952),
    [anon_sym_nettype] = ACTIONS(4952),
    [anon_sym_automatic] = ACTIONS(4952),
    [anon_sym_string] = ACTIONS(4952),
    [anon_sym_chandle] = ACTIONS(4952),
    [anon_sym_event] = ACTIONS(4952),
    [anon_sym_byte] = ACTIONS(4952),
    [anon_sym_shortint] = ACTIONS(4952),
    [anon_sym_int] = ACTIONS(4952),
    [anon_sym_longint] = ACTIONS(4952),
    [anon_sym_integer] = ACTIONS(4952),
    [anon_sym_time] = ACTIONS(4952),
    [anon_sym_bit] = ACTIONS(4952),
    [anon_sym_logic] = ACTIONS(4952),
    [anon_sym_reg] = ACTIONS(4952),
    [anon_sym_shortreal] = ACTIONS(4952),
    [anon_sym_real] = ACTIONS(4952),
    [anon_sym_realtime] = ACTIONS(4952),
    [anon_sym_supply0] = ACTIONS(4952),
    [anon_sym_supply1] = ACTIONS(4952),
    [anon_sym_signed] = ACTIONS(4952),
    [anon_sym_unsigned] = ACTIONS(4952),
    [anon_sym_task] = ACTIONS(4952),
    [anon_sym_assert] = ACTIONS(4952),
    [anon_sym_property] = ACTIONS(4952),
    [anon_sym_assume] = ACTIONS(4952),
    [anon_sym_cover] = ACTIONS(4952),
    [anon_sym_sequence] = ACTIONS(4952),
    [anon_sym_restrict] = ACTIONS(4952),
    [anon_sym_not] = ACTIONS(4952),
    [anon_sym_or] = ACTIONS(4952),
    [anon_sym_and] = ACTIONS(4952),
    [anon_sym_case] = ACTIONS(4952),
    [anon_sym_always] = ACTIONS(4952),
    [anon_sym_covergroup] = ACTIONS(4952),
    [anon_sym_end] = ACTIONS(4952),
    [anon_sym_let] = ACTIONS(4952),
    [anon_sym_pulldown] = ACTIONS(4952),
    [anon_sym_pullup] = ACTIONS(4952),
    [anon_sym_cmos] = ACTIONS(4952),
    [anon_sym_rcmos] = ACTIONS(4952),
    [anon_sym_bufif0] = ACTIONS(4952),
    [anon_sym_bufif1] = ACTIONS(4952),
    [anon_sym_notif0] = ACTIONS(4952),
    [anon_sym_notif1] = ACTIONS(4952),
    [anon_sym_nmos] = ACTIONS(4952),
    [anon_sym_pmos] = ACTIONS(4952),
    [anon_sym_rnmos] = ACTIONS(4952),
    [anon_sym_rpmos] = ACTIONS(4952),
    [anon_sym_nand] = ACTIONS(4952),
    [anon_sym_nor] = ACTIONS(4952),
    [anon_sym_xor] = ACTIONS(4952),
    [anon_sym_xnor] = ACTIONS(4952),
    [anon_sym_buf] = ACTIONS(4952),
    [anon_sym_tranif0] = ACTIONS(4952),
    [anon_sym_tranif1] = ACTIONS(4952),
    [anon_sym_rtranif1] = ACTIONS(4952),
    [anon_sym_rtranif0] = ACTIONS(4952),
    [anon_sym_tran] = ACTIONS(4952),
    [anon_sym_rtran] = ACTIONS(4952),
    [anon_sym_generate] = ACTIONS(4952),
    [anon_sym_for] = ACTIONS(4952),
    [anon_sym_initial] = ACTIONS(4952),
    [anon_sym_assign] = ACTIONS(4952),
    [anon_sym_alias] = ACTIONS(4952),
    [anon_sym_always_comb] = ACTIONS(4952),
    [anon_sym_always_latch] = ACTIONS(4952),
    [anon_sym_always_ff] = ACTIONS(4952),
    [anon_sym_final] = ACTIONS(4952),
    [anon_sym_global] = ACTIONS(4952),
    [anon_sym_LPAREN_STAR] = ACTIONS(4950),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4950),
    [anon_sym_DOLLARunit] = ACTIONS(4950),
  },
  [4817] = {
    [sym_simple_identifier] = ACTIONS(6123),
    [anon_sym_wire] = ACTIONS(6123),
    [anon_sym_tri] = ACTIONS(6123),
    [anon_sym_tri0] = ACTIONS(6123),
    [anon_sym_tri1] = ACTIONS(6123),
    [anon_sym_wand] = ACTIONS(6123),
    [anon_sym_triand] = ACTIONS(6123),
    [anon_sym_wor] = ACTIONS(6123),
    [anon_sym_trior] = ACTIONS(6123),
    [anon_sym_trireg] = ACTIONS(6123),
    [anon_sym_uwire] = ACTIONS(6123),
    [anon_sym_SEMI] = ACTIONS(6125),
    [anon_sym_extern] = ACTIONS(6123),
    [anon_sym_interface] = ACTIONS(6123),
    [anon_sym_checker] = ACTIONS(6123),
    [anon_sym_virtual] = ACTIONS(6123),
    [anon_sym_class] = ACTIONS(6123),
    [anon_sym_type] = ACTIONS(6123),
    [anon_sym_DOLLARfatal] = ACTIONS(6125),
    [anon_sym_DOLLARerror] = ACTIONS(6125),
    [anon_sym_DOLLARwarning] = ACTIONS(6125),
    [anon_sym_DOLLARinfo] = ACTIONS(6125),
    [anon_sym_default] = ACTIONS(6123),
    [anon_sym_clocking] = ACTIONS(6123),
    [anon_sym_defparam] = ACTIONS(6123),
    [anon_sym_bind] = ACTIONS(6123),
    [anon_sym_rand] = ACTIONS(6123),
    [anon_sym_const] = ACTIONS(6123),
    [anon_sym_function] = ACTIONS(6123),
    [anon_sym_static] = ACTIONS(6123),
    [anon_sym_constraint] = ACTIONS(6123),
    [anon_sym_if] = ACTIONS(6123),
    [anon_sym_else] = ACTIONS(6123),
    [anon_sym_LBRACK] = ACTIONS(6125),
    [anon_sym_localparam] = ACTIONS(6123),
    [anon_sym_parameter] = ACTIONS(6123),
    [anon_sym_var] = ACTIONS(6123),
    [anon_sym_import] = ACTIONS(6123),
    [anon_sym_export] = ACTIONS(6123),
    [anon_sym_genvar] = ACTIONS(6123),
    [anon_sym_interconnect] = ACTIONS(6123),
    [anon_sym_typedef] = ACTIONS(6123),
    [anon_sym_enum] = ACTIONS(6123),
    [anon_sym_struct] = ACTIONS(6123),
    [anon_sym_union] = ACTIONS(6123),
    [anon_sym_nettype] = ACTIONS(6123),
    [anon_sym_automatic] = ACTIONS(6123),
    [anon_sym_string] = ACTIONS(6123),
    [anon_sym_chandle] = ACTIONS(6123),
    [anon_sym_event] = ACTIONS(6123),
    [anon_sym_byte] = ACTIONS(6123),
    [anon_sym_shortint] = ACTIONS(6123),
    [anon_sym_int] = ACTIONS(6123),
    [anon_sym_longint] = ACTIONS(6123),
    [anon_sym_integer] = ACTIONS(6123),
    [anon_sym_time] = ACTIONS(6123),
    [anon_sym_bit] = ACTIONS(6123),
    [anon_sym_logic] = ACTIONS(6123),
    [anon_sym_reg] = ACTIONS(6123),
    [anon_sym_shortreal] = ACTIONS(6123),
    [anon_sym_real] = ACTIONS(6123),
    [anon_sym_realtime] = ACTIONS(6123),
    [anon_sym_supply0] = ACTIONS(6123),
    [anon_sym_supply1] = ACTIONS(6123),
    [anon_sym_signed] = ACTIONS(6123),
    [anon_sym_unsigned] = ACTIONS(6123),
    [anon_sym_task] = ACTIONS(6123),
    [anon_sym_assert] = ACTIONS(6123),
    [anon_sym_property] = ACTIONS(6123),
    [anon_sym_assume] = ACTIONS(6123),
    [anon_sym_cover] = ACTIONS(6123),
    [anon_sym_sequence] = ACTIONS(6123),
    [anon_sym_restrict] = ACTIONS(6123),
    [anon_sym_not] = ACTIONS(6123),
    [anon_sym_or] = ACTIONS(6123),
    [anon_sym_and] = ACTIONS(6123),
    [anon_sym_case] = ACTIONS(6123),
    [anon_sym_always] = ACTIONS(6123),
    [anon_sym_covergroup] = ACTIONS(6123),
    [anon_sym_end] = ACTIONS(6123),
    [anon_sym_let] = ACTIONS(6123),
    [anon_sym_pulldown] = ACTIONS(6123),
    [anon_sym_pullup] = ACTIONS(6123),
    [anon_sym_cmos] = ACTIONS(6123),
    [anon_sym_rcmos] = ACTIONS(6123),
    [anon_sym_bufif0] = ACTIONS(6123),
    [anon_sym_bufif1] = ACTIONS(6123),
    [anon_sym_notif0] = ACTIONS(6123),
    [anon_sym_notif1] = ACTIONS(6123),
    [anon_sym_nmos] = ACTIONS(6123),
    [anon_sym_pmos] = ACTIONS(6123),
    [anon_sym_rnmos] = ACTIONS(6123),
    [anon_sym_rpmos] = ACTIONS(6123),
    [anon_sym_nand] = ACTIONS(6123),
    [anon_sym_nor] = ACTIONS(6123),
    [anon_sym_xor] = ACTIONS(6123),
    [anon_sym_xnor] = ACTIONS(6123),
    [anon_sym_buf] = ACTIONS(6123),
    [anon_sym_tranif0] = ACTIONS(6123),
    [anon_sym_tranif1] = ACTIONS(6123),
    [anon_sym_rtranif1] = ACTIONS(6123),
    [anon_sym_rtranif0] = ACTIONS(6123),
    [anon_sym_tran] = ACTIONS(6123),
    [anon_sym_rtran] = ACTIONS(6123),
    [anon_sym_generate] = ACTIONS(6123),
    [anon_sym_for] = ACTIONS(6123),
    [anon_sym_initial] = ACTIONS(6123),
    [anon_sym_assign] = ACTIONS(6123),
    [anon_sym_alias] = ACTIONS(6123),
    [anon_sym_always_comb] = ACTIONS(6123),
    [anon_sym_always_latch] = ACTIONS(6123),
    [anon_sym_always_ff] = ACTIONS(6123),
    [anon_sym_final] = ACTIONS(6123),
    [anon_sym_global] = ACTIONS(6123),
    [anon_sym_LPAREN_STAR] = ACTIONS(6125),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6125),
    [anon_sym_DOLLARunit] = ACTIONS(6125),
  },
  [4818] = {
    [sym_simple_identifier] = ACTIONS(5170),
    [anon_sym_wire] = ACTIONS(5170),
    [anon_sym_tri] = ACTIONS(5170),
    [anon_sym_tri0] = ACTIONS(5170),
    [anon_sym_tri1] = ACTIONS(5170),
    [anon_sym_wand] = ACTIONS(5170),
    [anon_sym_triand] = ACTIONS(5170),
    [anon_sym_wor] = ACTIONS(5170),
    [anon_sym_trior] = ACTIONS(5170),
    [anon_sym_trireg] = ACTIONS(5170),
    [anon_sym_uwire] = ACTIONS(5170),
    [anon_sym_SEMI] = ACTIONS(5168),
    [anon_sym_extern] = ACTIONS(5170),
    [anon_sym_interface] = ACTIONS(5170),
    [anon_sym_checker] = ACTIONS(5170),
    [anon_sym_virtual] = ACTIONS(5170),
    [anon_sym_class] = ACTIONS(5170),
    [anon_sym_type] = ACTIONS(5170),
    [anon_sym_DOLLARfatal] = ACTIONS(5168),
    [anon_sym_DOLLARerror] = ACTIONS(5168),
    [anon_sym_DOLLARwarning] = ACTIONS(5168),
    [anon_sym_DOLLARinfo] = ACTIONS(5168),
    [anon_sym_default] = ACTIONS(5170),
    [anon_sym_clocking] = ACTIONS(5170),
    [anon_sym_defparam] = ACTIONS(5170),
    [anon_sym_bind] = ACTIONS(5170),
    [anon_sym_rand] = ACTIONS(5170),
    [anon_sym_const] = ACTIONS(5170),
    [anon_sym_function] = ACTIONS(5170),
    [anon_sym_static] = ACTIONS(5170),
    [anon_sym_constraint] = ACTIONS(5170),
    [anon_sym_if] = ACTIONS(5170),
    [anon_sym_else] = ACTIONS(5170),
    [anon_sym_LBRACK] = ACTIONS(5168),
    [anon_sym_localparam] = ACTIONS(5170),
    [anon_sym_parameter] = ACTIONS(5170),
    [anon_sym_var] = ACTIONS(5170),
    [anon_sym_import] = ACTIONS(5170),
    [anon_sym_export] = ACTIONS(5170),
    [anon_sym_genvar] = ACTIONS(5170),
    [anon_sym_interconnect] = ACTIONS(5170),
    [anon_sym_typedef] = ACTIONS(5170),
    [anon_sym_enum] = ACTIONS(5170),
    [anon_sym_struct] = ACTIONS(5170),
    [anon_sym_union] = ACTIONS(5170),
    [anon_sym_nettype] = ACTIONS(5170),
    [anon_sym_automatic] = ACTIONS(5170),
    [anon_sym_string] = ACTIONS(5170),
    [anon_sym_chandle] = ACTIONS(5170),
    [anon_sym_event] = ACTIONS(5170),
    [anon_sym_byte] = ACTIONS(5170),
    [anon_sym_shortint] = ACTIONS(5170),
    [anon_sym_int] = ACTIONS(5170),
    [anon_sym_longint] = ACTIONS(5170),
    [anon_sym_integer] = ACTIONS(5170),
    [anon_sym_time] = ACTIONS(5170),
    [anon_sym_bit] = ACTIONS(5170),
    [anon_sym_logic] = ACTIONS(5170),
    [anon_sym_reg] = ACTIONS(5170),
    [anon_sym_shortreal] = ACTIONS(5170),
    [anon_sym_real] = ACTIONS(5170),
    [anon_sym_realtime] = ACTIONS(5170),
    [anon_sym_supply0] = ACTIONS(5170),
    [anon_sym_supply1] = ACTIONS(5170),
    [anon_sym_signed] = ACTIONS(5170),
    [anon_sym_unsigned] = ACTIONS(5170),
    [anon_sym_task] = ACTIONS(5170),
    [anon_sym_assert] = ACTIONS(5170),
    [anon_sym_property] = ACTIONS(5170),
    [anon_sym_assume] = ACTIONS(5170),
    [anon_sym_cover] = ACTIONS(5170),
    [anon_sym_sequence] = ACTIONS(5170),
    [anon_sym_restrict] = ACTIONS(5170),
    [anon_sym_not] = ACTIONS(5170),
    [anon_sym_or] = ACTIONS(5170),
    [anon_sym_and] = ACTIONS(5170),
    [anon_sym_case] = ACTIONS(5170),
    [anon_sym_always] = ACTIONS(5170),
    [anon_sym_covergroup] = ACTIONS(5170),
    [anon_sym_let] = ACTIONS(5170),
    [anon_sym_pulldown] = ACTIONS(5170),
    [anon_sym_pullup] = ACTIONS(5170),
    [anon_sym_cmos] = ACTIONS(5170),
    [anon_sym_rcmos] = ACTIONS(5170),
    [anon_sym_bufif0] = ACTIONS(5170),
    [anon_sym_bufif1] = ACTIONS(5170),
    [anon_sym_notif0] = ACTIONS(5170),
    [anon_sym_notif1] = ACTIONS(5170),
    [anon_sym_nmos] = ACTIONS(5170),
    [anon_sym_pmos] = ACTIONS(5170),
    [anon_sym_rnmos] = ACTIONS(5170),
    [anon_sym_rpmos] = ACTIONS(5170),
    [anon_sym_nand] = ACTIONS(5170),
    [anon_sym_nor] = ACTIONS(5170),
    [anon_sym_xor] = ACTIONS(5170),
    [anon_sym_xnor] = ACTIONS(5170),
    [anon_sym_buf] = ACTIONS(5170),
    [anon_sym_tranif0] = ACTIONS(5170),
    [anon_sym_tranif1] = ACTIONS(5170),
    [anon_sym_rtranif1] = ACTIONS(5170),
    [anon_sym_rtranif0] = ACTIONS(5170),
    [anon_sym_tran] = ACTIONS(5170),
    [anon_sym_rtran] = ACTIONS(5170),
    [anon_sym_generate] = ACTIONS(5170),
    [anon_sym_endgenerate] = ACTIONS(5170),
    [anon_sym_for] = ACTIONS(5170),
    [anon_sym_initial] = ACTIONS(5170),
    [anon_sym_assign] = ACTIONS(5170),
    [anon_sym_alias] = ACTIONS(5170),
    [anon_sym_always_comb] = ACTIONS(5170),
    [anon_sym_always_latch] = ACTIONS(5170),
    [anon_sym_always_ff] = ACTIONS(5170),
    [anon_sym_final] = ACTIONS(5170),
    [anon_sym_global] = ACTIONS(5170),
    [anon_sym_LPAREN_STAR] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5168),
    [anon_sym_DOLLARunit] = ACTIONS(5168),
  },
  [4819] = {
    [sym_simple_identifier] = ACTIONS(4702),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_rand] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_endgenerate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [4820] = {
    [sym_simple_identifier] = ACTIONS(5360),
    [anon_sym_wire] = ACTIONS(5360),
    [anon_sym_tri] = ACTIONS(5360),
    [anon_sym_tri0] = ACTIONS(5360),
    [anon_sym_tri1] = ACTIONS(5360),
    [anon_sym_wand] = ACTIONS(5360),
    [anon_sym_triand] = ACTIONS(5360),
    [anon_sym_wor] = ACTIONS(5360),
    [anon_sym_trior] = ACTIONS(5360),
    [anon_sym_trireg] = ACTIONS(5360),
    [anon_sym_uwire] = ACTIONS(5360),
    [anon_sym_SEMI] = ACTIONS(5358),
    [anon_sym_extern] = ACTIONS(5360),
    [anon_sym_interface] = ACTIONS(5360),
    [anon_sym_checker] = ACTIONS(5360),
    [anon_sym_virtual] = ACTIONS(5360),
    [anon_sym_class] = ACTIONS(5360),
    [anon_sym_type] = ACTIONS(5360),
    [anon_sym_DOLLARfatal] = ACTIONS(5358),
    [anon_sym_DOLLARerror] = ACTIONS(5358),
    [anon_sym_DOLLARwarning] = ACTIONS(5358),
    [anon_sym_DOLLARinfo] = ACTIONS(5358),
    [anon_sym_default] = ACTIONS(5360),
    [anon_sym_clocking] = ACTIONS(5360),
    [anon_sym_defparam] = ACTIONS(5360),
    [anon_sym_bind] = ACTIONS(5360),
    [anon_sym_rand] = ACTIONS(5360),
    [anon_sym_const] = ACTIONS(5360),
    [anon_sym_function] = ACTIONS(5360),
    [anon_sym_static] = ACTIONS(5360),
    [anon_sym_constraint] = ACTIONS(5360),
    [anon_sym_if] = ACTIONS(5360),
    [anon_sym_else] = ACTIONS(5360),
    [anon_sym_LBRACK] = ACTIONS(5358),
    [anon_sym_localparam] = ACTIONS(5360),
    [anon_sym_parameter] = ACTIONS(5360),
    [anon_sym_var] = ACTIONS(5360),
    [anon_sym_import] = ACTIONS(5360),
    [anon_sym_export] = ACTIONS(5360),
    [anon_sym_genvar] = ACTIONS(5360),
    [anon_sym_interconnect] = ACTIONS(5360),
    [anon_sym_typedef] = ACTIONS(5360),
    [anon_sym_enum] = ACTIONS(5360),
    [anon_sym_struct] = ACTIONS(5360),
    [anon_sym_union] = ACTIONS(5360),
    [anon_sym_nettype] = ACTIONS(5360),
    [anon_sym_automatic] = ACTIONS(5360),
    [anon_sym_string] = ACTIONS(5360),
    [anon_sym_chandle] = ACTIONS(5360),
    [anon_sym_event] = ACTIONS(5360),
    [anon_sym_byte] = ACTIONS(5360),
    [anon_sym_shortint] = ACTIONS(5360),
    [anon_sym_int] = ACTIONS(5360),
    [anon_sym_longint] = ACTIONS(5360),
    [anon_sym_integer] = ACTIONS(5360),
    [anon_sym_time] = ACTIONS(5360),
    [anon_sym_bit] = ACTIONS(5360),
    [anon_sym_logic] = ACTIONS(5360),
    [anon_sym_reg] = ACTIONS(5360),
    [anon_sym_shortreal] = ACTIONS(5360),
    [anon_sym_real] = ACTIONS(5360),
    [anon_sym_realtime] = ACTIONS(5360),
    [anon_sym_supply0] = ACTIONS(5360),
    [anon_sym_supply1] = ACTIONS(5360),
    [anon_sym_signed] = ACTIONS(5360),
    [anon_sym_unsigned] = ACTIONS(5360),
    [anon_sym_task] = ACTIONS(5360),
    [anon_sym_assert] = ACTIONS(5360),
    [anon_sym_property] = ACTIONS(5360),
    [anon_sym_assume] = ACTIONS(5360),
    [anon_sym_cover] = ACTIONS(5360),
    [anon_sym_sequence] = ACTIONS(5360),
    [anon_sym_restrict] = ACTIONS(5360),
    [anon_sym_not] = ACTIONS(5360),
    [anon_sym_or] = ACTIONS(5360),
    [anon_sym_and] = ACTIONS(5360),
    [anon_sym_case] = ACTIONS(5360),
    [anon_sym_always] = ACTIONS(5360),
    [anon_sym_covergroup] = ACTIONS(5360),
    [anon_sym_let] = ACTIONS(5360),
    [anon_sym_pulldown] = ACTIONS(5360),
    [anon_sym_pullup] = ACTIONS(5360),
    [anon_sym_cmos] = ACTIONS(5360),
    [anon_sym_rcmos] = ACTIONS(5360),
    [anon_sym_bufif0] = ACTIONS(5360),
    [anon_sym_bufif1] = ACTIONS(5360),
    [anon_sym_notif0] = ACTIONS(5360),
    [anon_sym_notif1] = ACTIONS(5360),
    [anon_sym_nmos] = ACTIONS(5360),
    [anon_sym_pmos] = ACTIONS(5360),
    [anon_sym_rnmos] = ACTIONS(5360),
    [anon_sym_rpmos] = ACTIONS(5360),
    [anon_sym_nand] = ACTIONS(5360),
    [anon_sym_nor] = ACTIONS(5360),
    [anon_sym_xor] = ACTIONS(5360),
    [anon_sym_xnor] = ACTIONS(5360),
    [anon_sym_buf] = ACTIONS(5360),
    [anon_sym_tranif0] = ACTIONS(5360),
    [anon_sym_tranif1] = ACTIONS(5360),
    [anon_sym_rtranif1] = ACTIONS(5360),
    [anon_sym_rtranif0] = ACTIONS(5360),
    [anon_sym_tran] = ACTIONS(5360),
    [anon_sym_rtran] = ACTIONS(5360),
    [anon_sym_generate] = ACTIONS(5360),
    [anon_sym_endgenerate] = ACTIONS(5360),
    [anon_sym_for] = ACTIONS(5360),
    [anon_sym_initial] = ACTIONS(5360),
    [anon_sym_assign] = ACTIONS(5360),
    [anon_sym_alias] = ACTIONS(5360),
    [anon_sym_always_comb] = ACTIONS(5360),
    [anon_sym_always_latch] = ACTIONS(5360),
    [anon_sym_always_ff] = ACTIONS(5360),
    [anon_sym_final] = ACTIONS(5360),
    [anon_sym_global] = ACTIONS(5360),
    [anon_sym_LPAREN_STAR] = ACTIONS(5358),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5358),
    [anon_sym_DOLLARunit] = ACTIONS(5358),
  },
  [4821] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_rand] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_end] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [4822] = {
    [sym_simple_identifier] = ACTIONS(4916),
    [anon_sym_wire] = ACTIONS(4916),
    [anon_sym_tri] = ACTIONS(4916),
    [anon_sym_tri0] = ACTIONS(4916),
    [anon_sym_tri1] = ACTIONS(4916),
    [anon_sym_wand] = ACTIONS(4916),
    [anon_sym_triand] = ACTIONS(4916),
    [anon_sym_wor] = ACTIONS(4916),
    [anon_sym_trior] = ACTIONS(4916),
    [anon_sym_trireg] = ACTIONS(4916),
    [anon_sym_uwire] = ACTIONS(4916),
    [anon_sym_SEMI] = ACTIONS(4914),
    [anon_sym_extern] = ACTIONS(4916),
    [anon_sym_interface] = ACTIONS(4916),
    [anon_sym_checker] = ACTIONS(4916),
    [anon_sym_virtual] = ACTIONS(4916),
    [anon_sym_class] = ACTIONS(4916),
    [anon_sym_type] = ACTIONS(4916),
    [anon_sym_DOLLARfatal] = ACTIONS(4914),
    [anon_sym_DOLLARerror] = ACTIONS(4914),
    [anon_sym_DOLLARwarning] = ACTIONS(4914),
    [anon_sym_DOLLARinfo] = ACTIONS(4914),
    [anon_sym_default] = ACTIONS(4916),
    [anon_sym_clocking] = ACTIONS(4916),
    [anon_sym_defparam] = ACTIONS(4916),
    [anon_sym_bind] = ACTIONS(4916),
    [anon_sym_rand] = ACTIONS(4916),
    [anon_sym_const] = ACTIONS(4916),
    [anon_sym_function] = ACTIONS(4916),
    [anon_sym_static] = ACTIONS(4916),
    [anon_sym_constraint] = ACTIONS(4916),
    [anon_sym_if] = ACTIONS(4916),
    [anon_sym_else] = ACTIONS(4916),
    [anon_sym_LBRACK] = ACTIONS(4914),
    [anon_sym_localparam] = ACTIONS(4916),
    [anon_sym_parameter] = ACTIONS(4916),
    [anon_sym_var] = ACTIONS(4916),
    [anon_sym_import] = ACTIONS(4916),
    [anon_sym_export] = ACTIONS(4916),
    [anon_sym_genvar] = ACTIONS(4916),
    [anon_sym_interconnect] = ACTIONS(4916),
    [anon_sym_typedef] = ACTIONS(4916),
    [anon_sym_enum] = ACTIONS(4916),
    [anon_sym_struct] = ACTIONS(4916),
    [anon_sym_union] = ACTIONS(4916),
    [anon_sym_nettype] = ACTIONS(4916),
    [anon_sym_automatic] = ACTIONS(4916),
    [anon_sym_string] = ACTIONS(4916),
    [anon_sym_chandle] = ACTIONS(4916),
    [anon_sym_event] = ACTIONS(4916),
    [anon_sym_byte] = ACTIONS(4916),
    [anon_sym_shortint] = ACTIONS(4916),
    [anon_sym_int] = ACTIONS(4916),
    [anon_sym_longint] = ACTIONS(4916),
    [anon_sym_integer] = ACTIONS(4916),
    [anon_sym_time] = ACTIONS(4916),
    [anon_sym_bit] = ACTIONS(4916),
    [anon_sym_logic] = ACTIONS(4916),
    [anon_sym_reg] = ACTIONS(4916),
    [anon_sym_shortreal] = ACTIONS(4916),
    [anon_sym_real] = ACTIONS(4916),
    [anon_sym_realtime] = ACTIONS(4916),
    [anon_sym_supply0] = ACTIONS(4916),
    [anon_sym_supply1] = ACTIONS(4916),
    [anon_sym_signed] = ACTIONS(4916),
    [anon_sym_unsigned] = ACTIONS(4916),
    [anon_sym_task] = ACTIONS(4916),
    [anon_sym_assert] = ACTIONS(4916),
    [anon_sym_property] = ACTIONS(4916),
    [anon_sym_assume] = ACTIONS(4916),
    [anon_sym_cover] = ACTIONS(4916),
    [anon_sym_sequence] = ACTIONS(4916),
    [anon_sym_restrict] = ACTIONS(4916),
    [anon_sym_not] = ACTIONS(4916),
    [anon_sym_or] = ACTIONS(4916),
    [anon_sym_and] = ACTIONS(4916),
    [anon_sym_case] = ACTIONS(4916),
    [anon_sym_always] = ACTIONS(4916),
    [anon_sym_covergroup] = ACTIONS(4916),
    [anon_sym_end] = ACTIONS(4916),
    [anon_sym_let] = ACTIONS(4916),
    [anon_sym_pulldown] = ACTIONS(4916),
    [anon_sym_pullup] = ACTIONS(4916),
    [anon_sym_cmos] = ACTIONS(4916),
    [anon_sym_rcmos] = ACTIONS(4916),
    [anon_sym_bufif0] = ACTIONS(4916),
    [anon_sym_bufif1] = ACTIONS(4916),
    [anon_sym_notif0] = ACTIONS(4916),
    [anon_sym_notif1] = ACTIONS(4916),
    [anon_sym_nmos] = ACTIONS(4916),
    [anon_sym_pmos] = ACTIONS(4916),
    [anon_sym_rnmos] = ACTIONS(4916),
    [anon_sym_rpmos] = ACTIONS(4916),
    [anon_sym_nand] = ACTIONS(4916),
    [anon_sym_nor] = ACTIONS(4916),
    [anon_sym_xor] = ACTIONS(4916),
    [anon_sym_xnor] = ACTIONS(4916),
    [anon_sym_buf] = ACTIONS(4916),
    [anon_sym_tranif0] = ACTIONS(4916),
    [anon_sym_tranif1] = ACTIONS(4916),
    [anon_sym_rtranif1] = ACTIONS(4916),
    [anon_sym_rtranif0] = ACTIONS(4916),
    [anon_sym_tran] = ACTIONS(4916),
    [anon_sym_rtran] = ACTIONS(4916),
    [anon_sym_generate] = ACTIONS(4916),
    [anon_sym_for] = ACTIONS(4916),
    [anon_sym_initial] = ACTIONS(4916),
    [anon_sym_assign] = ACTIONS(4916),
    [anon_sym_alias] = ACTIONS(4916),
    [anon_sym_always_comb] = ACTIONS(4916),
    [anon_sym_always_latch] = ACTIONS(4916),
    [anon_sym_always_ff] = ACTIONS(4916),
    [anon_sym_final] = ACTIONS(4916),
    [anon_sym_global] = ACTIONS(4916),
    [anon_sym_LPAREN_STAR] = ACTIONS(4914),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4914),
    [anon_sym_DOLLARunit] = ACTIONS(4914),
  },
  [4823] = {
    [sym_simple_identifier] = ACTIONS(4128),
    [anon_sym_wire] = ACTIONS(4128),
    [anon_sym_tri] = ACTIONS(4128),
    [anon_sym_tri0] = ACTIONS(4128),
    [anon_sym_tri1] = ACTIONS(4128),
    [anon_sym_wand] = ACTIONS(4128),
    [anon_sym_triand] = ACTIONS(4128),
    [anon_sym_wor] = ACTIONS(4128),
    [anon_sym_trior] = ACTIONS(4128),
    [anon_sym_trireg] = ACTIONS(4128),
    [anon_sym_uwire] = ACTIONS(4128),
    [anon_sym_SEMI] = ACTIONS(4126),
    [anon_sym_extern] = ACTIONS(4128),
    [anon_sym_interface] = ACTIONS(4128),
    [anon_sym_checker] = ACTIONS(4128),
    [anon_sym_virtual] = ACTIONS(4128),
    [anon_sym_class] = ACTIONS(4128),
    [anon_sym_type] = ACTIONS(4128),
    [anon_sym_DOLLARfatal] = ACTIONS(4126),
    [anon_sym_DOLLARerror] = ACTIONS(4126),
    [anon_sym_DOLLARwarning] = ACTIONS(4126),
    [anon_sym_DOLLARinfo] = ACTIONS(4126),
    [anon_sym_default] = ACTIONS(4128),
    [anon_sym_clocking] = ACTIONS(4128),
    [anon_sym_defparam] = ACTIONS(4128),
    [anon_sym_bind] = ACTIONS(4128),
    [anon_sym_rand] = ACTIONS(4128),
    [anon_sym_const] = ACTIONS(4128),
    [anon_sym_function] = ACTIONS(4128),
    [anon_sym_static] = ACTIONS(4128),
    [anon_sym_constraint] = ACTIONS(4128),
    [anon_sym_if] = ACTIONS(4128),
    [anon_sym_else] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4126),
    [anon_sym_localparam] = ACTIONS(4128),
    [anon_sym_parameter] = ACTIONS(4128),
    [anon_sym_var] = ACTIONS(4128),
    [anon_sym_import] = ACTIONS(4128),
    [anon_sym_export] = ACTIONS(4128),
    [anon_sym_genvar] = ACTIONS(4128),
    [anon_sym_interconnect] = ACTIONS(4128),
    [anon_sym_typedef] = ACTIONS(4128),
    [anon_sym_enum] = ACTIONS(4128),
    [anon_sym_struct] = ACTIONS(4128),
    [anon_sym_union] = ACTIONS(4128),
    [anon_sym_nettype] = ACTIONS(4128),
    [anon_sym_automatic] = ACTIONS(4128),
    [anon_sym_string] = ACTIONS(4128),
    [anon_sym_chandle] = ACTIONS(4128),
    [anon_sym_event] = ACTIONS(4128),
    [anon_sym_byte] = ACTIONS(4128),
    [anon_sym_shortint] = ACTIONS(4128),
    [anon_sym_int] = ACTIONS(4128),
    [anon_sym_longint] = ACTIONS(4128),
    [anon_sym_integer] = ACTIONS(4128),
    [anon_sym_time] = ACTIONS(4128),
    [anon_sym_bit] = ACTIONS(4128),
    [anon_sym_logic] = ACTIONS(4128),
    [anon_sym_reg] = ACTIONS(4128),
    [anon_sym_shortreal] = ACTIONS(4128),
    [anon_sym_real] = ACTIONS(4128),
    [anon_sym_realtime] = ACTIONS(4128),
    [anon_sym_supply0] = ACTIONS(4128),
    [anon_sym_supply1] = ACTIONS(4128),
    [anon_sym_signed] = ACTIONS(4128),
    [anon_sym_unsigned] = ACTIONS(4128),
    [anon_sym_task] = ACTIONS(4128),
    [anon_sym_assert] = ACTIONS(4128),
    [anon_sym_property] = ACTIONS(4128),
    [anon_sym_assume] = ACTIONS(4128),
    [anon_sym_cover] = ACTIONS(4128),
    [anon_sym_sequence] = ACTIONS(4128),
    [anon_sym_restrict] = ACTIONS(4128),
    [anon_sym_not] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_case] = ACTIONS(4128),
    [anon_sym_always] = ACTIONS(4128),
    [anon_sym_covergroup] = ACTIONS(4128),
    [anon_sym_end] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_pulldown] = ACTIONS(4128),
    [anon_sym_pullup] = ACTIONS(4128),
    [anon_sym_cmos] = ACTIONS(4128),
    [anon_sym_rcmos] = ACTIONS(4128),
    [anon_sym_bufif0] = ACTIONS(4128),
    [anon_sym_bufif1] = ACTIONS(4128),
    [anon_sym_notif0] = ACTIONS(4128),
    [anon_sym_notif1] = ACTIONS(4128),
    [anon_sym_nmos] = ACTIONS(4128),
    [anon_sym_pmos] = ACTIONS(4128),
    [anon_sym_rnmos] = ACTIONS(4128),
    [anon_sym_rpmos] = ACTIONS(4128),
    [anon_sym_nand] = ACTIONS(4128),
    [anon_sym_nor] = ACTIONS(4128),
    [anon_sym_xor] = ACTIONS(4128),
    [anon_sym_xnor] = ACTIONS(4128),
    [anon_sym_buf] = ACTIONS(4128),
    [anon_sym_tranif0] = ACTIONS(4128),
    [anon_sym_tranif1] = ACTIONS(4128),
    [anon_sym_rtranif1] = ACTIONS(4128),
    [anon_sym_rtranif0] = ACTIONS(4128),
    [anon_sym_tran] = ACTIONS(4128),
    [anon_sym_rtran] = ACTIONS(4128),
    [anon_sym_generate] = ACTIONS(4128),
    [anon_sym_for] = ACTIONS(4128),
    [anon_sym_initial] = ACTIONS(4128),
    [anon_sym_assign] = ACTIONS(4128),
    [anon_sym_alias] = ACTIONS(4128),
    [anon_sym_always_comb] = ACTIONS(4128),
    [anon_sym_always_latch] = ACTIONS(4128),
    [anon_sym_always_ff] = ACTIONS(4128),
    [anon_sym_final] = ACTIONS(4128),
    [anon_sym_global] = ACTIONS(4128),
    [anon_sym_LPAREN_STAR] = ACTIONS(4126),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4126),
    [anon_sym_DOLLARunit] = ACTIONS(4126),
  },
  [4824] = {
    [sym_simple_identifier] = ACTIONS(5756),
    [anon_sym_wire] = ACTIONS(5756),
    [anon_sym_tri] = ACTIONS(5756),
    [anon_sym_tri0] = ACTIONS(5756),
    [anon_sym_tri1] = ACTIONS(5756),
    [anon_sym_wand] = ACTIONS(5756),
    [anon_sym_triand] = ACTIONS(5756),
    [anon_sym_wor] = ACTIONS(5756),
    [anon_sym_trior] = ACTIONS(5756),
    [anon_sym_trireg] = ACTIONS(5756),
    [anon_sym_uwire] = ACTIONS(5756),
    [anon_sym_SEMI] = ACTIONS(5758),
    [anon_sym_extern] = ACTIONS(5756),
    [anon_sym_interface] = ACTIONS(5756),
    [anon_sym_checker] = ACTIONS(5756),
    [anon_sym_virtual] = ACTIONS(5756),
    [anon_sym_class] = ACTIONS(5756),
    [anon_sym_type] = ACTIONS(5756),
    [anon_sym_DOLLARfatal] = ACTIONS(5758),
    [anon_sym_DOLLARerror] = ACTIONS(5758),
    [anon_sym_DOLLARwarning] = ACTIONS(5758),
    [anon_sym_DOLLARinfo] = ACTIONS(5758),
    [anon_sym_default] = ACTIONS(5756),
    [anon_sym_clocking] = ACTIONS(5756),
    [anon_sym_defparam] = ACTIONS(5756),
    [anon_sym_bind] = ACTIONS(5756),
    [anon_sym_rand] = ACTIONS(5756),
    [anon_sym_const] = ACTIONS(5756),
    [anon_sym_function] = ACTIONS(5756),
    [anon_sym_static] = ACTIONS(5756),
    [anon_sym_constraint] = ACTIONS(5756),
    [anon_sym_if] = ACTIONS(5756),
    [anon_sym_else] = ACTIONS(5756),
    [anon_sym_LBRACK] = ACTIONS(5758),
    [anon_sym_localparam] = ACTIONS(5756),
    [anon_sym_parameter] = ACTIONS(5756),
    [anon_sym_var] = ACTIONS(5756),
    [anon_sym_import] = ACTIONS(5756),
    [anon_sym_export] = ACTIONS(5756),
    [anon_sym_genvar] = ACTIONS(5756),
    [anon_sym_interconnect] = ACTIONS(5756),
    [anon_sym_typedef] = ACTIONS(5756),
    [anon_sym_enum] = ACTIONS(5756),
    [anon_sym_struct] = ACTIONS(5756),
    [anon_sym_union] = ACTIONS(5756),
    [anon_sym_nettype] = ACTIONS(5756),
    [anon_sym_automatic] = ACTIONS(5756),
    [anon_sym_string] = ACTIONS(5756),
    [anon_sym_chandle] = ACTIONS(5756),
    [anon_sym_event] = ACTIONS(5756),
    [anon_sym_byte] = ACTIONS(5756),
    [anon_sym_shortint] = ACTIONS(5756),
    [anon_sym_int] = ACTIONS(5756),
    [anon_sym_longint] = ACTIONS(5756),
    [anon_sym_integer] = ACTIONS(5756),
    [anon_sym_time] = ACTIONS(5756),
    [anon_sym_bit] = ACTIONS(5756),
    [anon_sym_logic] = ACTIONS(5756),
    [anon_sym_reg] = ACTIONS(5756),
    [anon_sym_shortreal] = ACTIONS(5756),
    [anon_sym_real] = ACTIONS(5756),
    [anon_sym_realtime] = ACTIONS(5756),
    [anon_sym_supply0] = ACTIONS(5756),
    [anon_sym_supply1] = ACTIONS(5756),
    [anon_sym_signed] = ACTIONS(5756),
    [anon_sym_unsigned] = ACTIONS(5756),
    [anon_sym_task] = ACTIONS(5756),
    [anon_sym_assert] = ACTIONS(5756),
    [anon_sym_property] = ACTIONS(5756),
    [anon_sym_assume] = ACTIONS(5756),
    [anon_sym_cover] = ACTIONS(5756),
    [anon_sym_sequence] = ACTIONS(5756),
    [anon_sym_restrict] = ACTIONS(5756),
    [anon_sym_not] = ACTIONS(5756),
    [anon_sym_or] = ACTIONS(5756),
    [anon_sym_and] = ACTIONS(5756),
    [anon_sym_case] = ACTIONS(5756),
    [anon_sym_always] = ACTIONS(5756),
    [anon_sym_covergroup] = ACTIONS(5756),
    [anon_sym_let] = ACTIONS(5756),
    [anon_sym_pulldown] = ACTIONS(5756),
    [anon_sym_pullup] = ACTIONS(5756),
    [anon_sym_cmos] = ACTIONS(5756),
    [anon_sym_rcmos] = ACTIONS(5756),
    [anon_sym_bufif0] = ACTIONS(5756),
    [anon_sym_bufif1] = ACTIONS(5756),
    [anon_sym_notif0] = ACTIONS(5756),
    [anon_sym_notif1] = ACTIONS(5756),
    [anon_sym_nmos] = ACTIONS(5756),
    [anon_sym_pmos] = ACTIONS(5756),
    [anon_sym_rnmos] = ACTIONS(5756),
    [anon_sym_rpmos] = ACTIONS(5756),
    [anon_sym_nand] = ACTIONS(5756),
    [anon_sym_nor] = ACTIONS(5756),
    [anon_sym_xor] = ACTIONS(5756),
    [anon_sym_xnor] = ACTIONS(5756),
    [anon_sym_buf] = ACTIONS(5756),
    [anon_sym_tranif0] = ACTIONS(5756),
    [anon_sym_tranif1] = ACTIONS(5756),
    [anon_sym_rtranif1] = ACTIONS(5756),
    [anon_sym_rtranif0] = ACTIONS(5756),
    [anon_sym_tran] = ACTIONS(5756),
    [anon_sym_rtran] = ACTIONS(5756),
    [anon_sym_generate] = ACTIONS(5756),
    [anon_sym_endgenerate] = ACTIONS(5756),
    [anon_sym_for] = ACTIONS(5756),
    [anon_sym_initial] = ACTIONS(5756),
    [anon_sym_assign] = ACTIONS(5756),
    [anon_sym_alias] = ACTIONS(5756),
    [anon_sym_always_comb] = ACTIONS(5756),
    [anon_sym_always_latch] = ACTIONS(5756),
    [anon_sym_always_ff] = ACTIONS(5756),
    [anon_sym_final] = ACTIONS(5756),
    [anon_sym_global] = ACTIONS(5756),
    [anon_sym_LPAREN_STAR] = ACTIONS(5758),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5758),
    [anon_sym_DOLLARunit] = ACTIONS(5758),
  },
  [4825] = {
    [sym_simple_identifier] = ACTIONS(5198),
    [anon_sym_wire] = ACTIONS(5198),
    [anon_sym_tri] = ACTIONS(5198),
    [anon_sym_tri0] = ACTIONS(5198),
    [anon_sym_tri1] = ACTIONS(5198),
    [anon_sym_wand] = ACTIONS(5198),
    [anon_sym_triand] = ACTIONS(5198),
    [anon_sym_wor] = ACTIONS(5198),
    [anon_sym_trior] = ACTIONS(5198),
    [anon_sym_trireg] = ACTIONS(5198),
    [anon_sym_uwire] = ACTIONS(5198),
    [anon_sym_SEMI] = ACTIONS(5196),
    [anon_sym_extern] = ACTIONS(5198),
    [anon_sym_interface] = ACTIONS(5198),
    [anon_sym_checker] = ACTIONS(5198),
    [anon_sym_virtual] = ACTIONS(5198),
    [anon_sym_class] = ACTIONS(5198),
    [anon_sym_type] = ACTIONS(5198),
    [anon_sym_DOLLARfatal] = ACTIONS(5196),
    [anon_sym_DOLLARerror] = ACTIONS(5196),
    [anon_sym_DOLLARwarning] = ACTIONS(5196),
    [anon_sym_DOLLARinfo] = ACTIONS(5196),
    [anon_sym_default] = ACTIONS(5198),
    [anon_sym_clocking] = ACTIONS(5198),
    [anon_sym_defparam] = ACTIONS(5198),
    [anon_sym_bind] = ACTIONS(5198),
    [anon_sym_rand] = ACTIONS(5198),
    [anon_sym_const] = ACTIONS(5198),
    [anon_sym_function] = ACTIONS(5198),
    [anon_sym_static] = ACTIONS(5198),
    [anon_sym_constraint] = ACTIONS(5198),
    [anon_sym_if] = ACTIONS(5198),
    [anon_sym_else] = ACTIONS(5198),
    [anon_sym_LBRACK] = ACTIONS(5196),
    [anon_sym_localparam] = ACTIONS(5198),
    [anon_sym_parameter] = ACTIONS(5198),
    [anon_sym_var] = ACTIONS(5198),
    [anon_sym_import] = ACTIONS(5198),
    [anon_sym_export] = ACTIONS(5198),
    [anon_sym_genvar] = ACTIONS(5198),
    [anon_sym_interconnect] = ACTIONS(5198),
    [anon_sym_typedef] = ACTIONS(5198),
    [anon_sym_enum] = ACTIONS(5198),
    [anon_sym_struct] = ACTIONS(5198),
    [anon_sym_union] = ACTIONS(5198),
    [anon_sym_nettype] = ACTIONS(5198),
    [anon_sym_automatic] = ACTIONS(5198),
    [anon_sym_string] = ACTIONS(5198),
    [anon_sym_chandle] = ACTIONS(5198),
    [anon_sym_event] = ACTIONS(5198),
    [anon_sym_byte] = ACTIONS(5198),
    [anon_sym_shortint] = ACTIONS(5198),
    [anon_sym_int] = ACTIONS(5198),
    [anon_sym_longint] = ACTIONS(5198),
    [anon_sym_integer] = ACTIONS(5198),
    [anon_sym_time] = ACTIONS(5198),
    [anon_sym_bit] = ACTIONS(5198),
    [anon_sym_logic] = ACTIONS(5198),
    [anon_sym_reg] = ACTIONS(5198),
    [anon_sym_shortreal] = ACTIONS(5198),
    [anon_sym_real] = ACTIONS(5198),
    [anon_sym_realtime] = ACTIONS(5198),
    [anon_sym_supply0] = ACTIONS(5198),
    [anon_sym_supply1] = ACTIONS(5198),
    [anon_sym_signed] = ACTIONS(5198),
    [anon_sym_unsigned] = ACTIONS(5198),
    [anon_sym_task] = ACTIONS(5198),
    [anon_sym_assert] = ACTIONS(5198),
    [anon_sym_property] = ACTIONS(5198),
    [anon_sym_assume] = ACTIONS(5198),
    [anon_sym_cover] = ACTIONS(5198),
    [anon_sym_sequence] = ACTIONS(5198),
    [anon_sym_restrict] = ACTIONS(5198),
    [anon_sym_not] = ACTIONS(5198),
    [anon_sym_or] = ACTIONS(5198),
    [anon_sym_and] = ACTIONS(5198),
    [anon_sym_case] = ACTIONS(5198),
    [anon_sym_always] = ACTIONS(5198),
    [anon_sym_covergroup] = ACTIONS(5198),
    [anon_sym_end] = ACTIONS(5198),
    [anon_sym_let] = ACTIONS(5198),
    [anon_sym_pulldown] = ACTIONS(5198),
    [anon_sym_pullup] = ACTIONS(5198),
    [anon_sym_cmos] = ACTIONS(5198),
    [anon_sym_rcmos] = ACTIONS(5198),
    [anon_sym_bufif0] = ACTIONS(5198),
    [anon_sym_bufif1] = ACTIONS(5198),
    [anon_sym_notif0] = ACTIONS(5198),
    [anon_sym_notif1] = ACTIONS(5198),
    [anon_sym_nmos] = ACTIONS(5198),
    [anon_sym_pmos] = ACTIONS(5198),
    [anon_sym_rnmos] = ACTIONS(5198),
    [anon_sym_rpmos] = ACTIONS(5198),
    [anon_sym_nand] = ACTIONS(5198),
    [anon_sym_nor] = ACTIONS(5198),
    [anon_sym_xor] = ACTIONS(5198),
    [anon_sym_xnor] = ACTIONS(5198),
    [anon_sym_buf] = ACTIONS(5198),
    [anon_sym_tranif0] = ACTIONS(5198),
    [anon_sym_tranif1] = ACTIONS(5198),
    [anon_sym_rtranif1] = ACTIONS(5198),
    [anon_sym_rtranif0] = ACTIONS(5198),
    [anon_sym_tran] = ACTIONS(5198),
    [anon_sym_rtran] = ACTIONS(5198),
    [anon_sym_generate] = ACTIONS(5198),
    [anon_sym_for] = ACTIONS(5198),
    [anon_sym_initial] = ACTIONS(5198),
    [anon_sym_assign] = ACTIONS(5198),
    [anon_sym_alias] = ACTIONS(5198),
    [anon_sym_always_comb] = ACTIONS(5198),
    [anon_sym_always_latch] = ACTIONS(5198),
    [anon_sym_always_ff] = ACTIONS(5198),
    [anon_sym_final] = ACTIONS(5198),
    [anon_sym_global] = ACTIONS(5198),
    [anon_sym_LPAREN_STAR] = ACTIONS(5196),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5196),
    [anon_sym_DOLLARunit] = ACTIONS(5196),
  },
  [4826] = {
    [sym_simple_identifier] = ACTIONS(4702),
    [anon_sym_wire] = ACTIONS(4702),
    [anon_sym_tri] = ACTIONS(4702),
    [anon_sym_tri0] = ACTIONS(4702),
    [anon_sym_tri1] = ACTIONS(4702),
    [anon_sym_wand] = ACTIONS(4702),
    [anon_sym_triand] = ACTIONS(4702),
    [anon_sym_wor] = ACTIONS(4702),
    [anon_sym_trior] = ACTIONS(4702),
    [anon_sym_trireg] = ACTIONS(4702),
    [anon_sym_uwire] = ACTIONS(4702),
    [anon_sym_SEMI] = ACTIONS(4700),
    [anon_sym_extern] = ACTIONS(4702),
    [anon_sym_interface] = ACTIONS(4702),
    [anon_sym_checker] = ACTIONS(4702),
    [anon_sym_virtual] = ACTIONS(4702),
    [anon_sym_class] = ACTIONS(4702),
    [anon_sym_type] = ACTIONS(4702),
    [anon_sym_DOLLARfatal] = ACTIONS(4700),
    [anon_sym_DOLLARerror] = ACTIONS(4700),
    [anon_sym_DOLLARwarning] = ACTIONS(4700),
    [anon_sym_DOLLARinfo] = ACTIONS(4700),
    [anon_sym_default] = ACTIONS(4702),
    [anon_sym_clocking] = ACTIONS(4702),
    [anon_sym_defparam] = ACTIONS(4702),
    [anon_sym_bind] = ACTIONS(4702),
    [anon_sym_rand] = ACTIONS(4702),
    [anon_sym_const] = ACTIONS(4702),
    [anon_sym_function] = ACTIONS(4702),
    [anon_sym_static] = ACTIONS(4702),
    [anon_sym_constraint] = ACTIONS(4702),
    [anon_sym_if] = ACTIONS(4702),
    [anon_sym_else] = ACTIONS(4702),
    [anon_sym_LBRACK] = ACTIONS(4700),
    [anon_sym_localparam] = ACTIONS(4702),
    [anon_sym_parameter] = ACTIONS(4702),
    [anon_sym_var] = ACTIONS(4702),
    [anon_sym_import] = ACTIONS(4702),
    [anon_sym_export] = ACTIONS(4702),
    [anon_sym_genvar] = ACTIONS(4702),
    [anon_sym_interconnect] = ACTIONS(4702),
    [anon_sym_typedef] = ACTIONS(4702),
    [anon_sym_enum] = ACTIONS(4702),
    [anon_sym_struct] = ACTIONS(4702),
    [anon_sym_union] = ACTIONS(4702),
    [anon_sym_nettype] = ACTIONS(4702),
    [anon_sym_automatic] = ACTIONS(4702),
    [anon_sym_string] = ACTIONS(4702),
    [anon_sym_chandle] = ACTIONS(4702),
    [anon_sym_event] = ACTIONS(4702),
    [anon_sym_byte] = ACTIONS(4702),
    [anon_sym_shortint] = ACTIONS(4702),
    [anon_sym_int] = ACTIONS(4702),
    [anon_sym_longint] = ACTIONS(4702),
    [anon_sym_integer] = ACTIONS(4702),
    [anon_sym_time] = ACTIONS(4702),
    [anon_sym_bit] = ACTIONS(4702),
    [anon_sym_logic] = ACTIONS(4702),
    [anon_sym_reg] = ACTIONS(4702),
    [anon_sym_shortreal] = ACTIONS(4702),
    [anon_sym_real] = ACTIONS(4702),
    [anon_sym_realtime] = ACTIONS(4702),
    [anon_sym_supply0] = ACTIONS(4702),
    [anon_sym_supply1] = ACTIONS(4702),
    [anon_sym_signed] = ACTIONS(4702),
    [anon_sym_unsigned] = ACTIONS(4702),
    [anon_sym_task] = ACTIONS(4702),
    [anon_sym_assert] = ACTIONS(4702),
    [anon_sym_property] = ACTIONS(4702),
    [anon_sym_assume] = ACTIONS(4702),
    [anon_sym_cover] = ACTIONS(4702),
    [anon_sym_sequence] = ACTIONS(4702),
    [anon_sym_restrict] = ACTIONS(4702),
    [anon_sym_not] = ACTIONS(4702),
    [anon_sym_or] = ACTIONS(4702),
    [anon_sym_and] = ACTIONS(4702),
    [anon_sym_case] = ACTIONS(4702),
    [anon_sym_always] = ACTIONS(4702),
    [anon_sym_covergroup] = ACTIONS(4702),
    [anon_sym_end] = ACTIONS(4702),
    [anon_sym_let] = ACTIONS(4702),
    [anon_sym_pulldown] = ACTIONS(4702),
    [anon_sym_pullup] = ACTIONS(4702),
    [anon_sym_cmos] = ACTIONS(4702),
    [anon_sym_rcmos] = ACTIONS(4702),
    [anon_sym_bufif0] = ACTIONS(4702),
    [anon_sym_bufif1] = ACTIONS(4702),
    [anon_sym_notif0] = ACTIONS(4702),
    [anon_sym_notif1] = ACTIONS(4702),
    [anon_sym_nmos] = ACTIONS(4702),
    [anon_sym_pmos] = ACTIONS(4702),
    [anon_sym_rnmos] = ACTIONS(4702),
    [anon_sym_rpmos] = ACTIONS(4702),
    [anon_sym_nand] = ACTIONS(4702),
    [anon_sym_nor] = ACTIONS(4702),
    [anon_sym_xor] = ACTIONS(4702),
    [anon_sym_xnor] = ACTIONS(4702),
    [anon_sym_buf] = ACTIONS(4702),
    [anon_sym_tranif0] = ACTIONS(4702),
    [anon_sym_tranif1] = ACTIONS(4702),
    [anon_sym_rtranif1] = ACTIONS(4702),
    [anon_sym_rtranif0] = ACTIONS(4702),
    [anon_sym_tran] = ACTIONS(4702),
    [anon_sym_rtran] = ACTIONS(4702),
    [anon_sym_generate] = ACTIONS(4702),
    [anon_sym_for] = ACTIONS(4702),
    [anon_sym_initial] = ACTIONS(4702),
    [anon_sym_assign] = ACTIONS(4702),
    [anon_sym_alias] = ACTIONS(4702),
    [anon_sym_always_comb] = ACTIONS(4702),
    [anon_sym_always_latch] = ACTIONS(4702),
    [anon_sym_always_ff] = ACTIONS(4702),
    [anon_sym_final] = ACTIONS(4702),
    [anon_sym_global] = ACTIONS(4702),
    [anon_sym_LPAREN_STAR] = ACTIONS(4700),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4700),
    [anon_sym_DOLLARunit] = ACTIONS(4700),
  },
  [4827] = {
    [sym_simple_identifier] = ACTIONS(4200),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_rand] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_endgenerate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [4828] = {
    [sym_simple_identifier] = ACTIONS(4584),
    [anon_sym_wire] = ACTIONS(4584),
    [anon_sym_tri] = ACTIONS(4584),
    [anon_sym_tri0] = ACTIONS(4584),
    [anon_sym_tri1] = ACTIONS(4584),
    [anon_sym_wand] = ACTIONS(4584),
    [anon_sym_triand] = ACTIONS(4584),
    [anon_sym_wor] = ACTIONS(4584),
    [anon_sym_trior] = ACTIONS(4584),
    [anon_sym_trireg] = ACTIONS(4584),
    [anon_sym_uwire] = ACTIONS(4584),
    [anon_sym_SEMI] = ACTIONS(4582),
    [anon_sym_extern] = ACTIONS(4584),
    [anon_sym_interface] = ACTIONS(4584),
    [anon_sym_checker] = ACTIONS(4584),
    [anon_sym_virtual] = ACTIONS(4584),
    [anon_sym_class] = ACTIONS(4584),
    [anon_sym_type] = ACTIONS(4584),
    [anon_sym_DOLLARfatal] = ACTIONS(4582),
    [anon_sym_DOLLARerror] = ACTIONS(4582),
    [anon_sym_DOLLARwarning] = ACTIONS(4582),
    [anon_sym_DOLLARinfo] = ACTIONS(4582),
    [anon_sym_default] = ACTIONS(4584),
    [anon_sym_clocking] = ACTIONS(4584),
    [anon_sym_defparam] = ACTIONS(4584),
    [anon_sym_bind] = ACTIONS(4584),
    [anon_sym_rand] = ACTIONS(4584),
    [anon_sym_const] = ACTIONS(4584),
    [anon_sym_function] = ACTIONS(4584),
    [anon_sym_static] = ACTIONS(4584),
    [anon_sym_constraint] = ACTIONS(4584),
    [anon_sym_if] = ACTIONS(4584),
    [anon_sym_else] = ACTIONS(4584),
    [anon_sym_LBRACK] = ACTIONS(4582),
    [anon_sym_localparam] = ACTIONS(4584),
    [anon_sym_parameter] = ACTIONS(4584),
    [anon_sym_var] = ACTIONS(4584),
    [anon_sym_import] = ACTIONS(4584),
    [anon_sym_export] = ACTIONS(4584),
    [anon_sym_genvar] = ACTIONS(4584),
    [anon_sym_interconnect] = ACTIONS(4584),
    [anon_sym_typedef] = ACTIONS(4584),
    [anon_sym_enum] = ACTIONS(4584),
    [anon_sym_struct] = ACTIONS(4584),
    [anon_sym_union] = ACTIONS(4584),
    [anon_sym_nettype] = ACTIONS(4584),
    [anon_sym_automatic] = ACTIONS(4584),
    [anon_sym_string] = ACTIONS(4584),
    [anon_sym_chandle] = ACTIONS(4584),
    [anon_sym_event] = ACTIONS(4584),
    [anon_sym_byte] = ACTIONS(4584),
    [anon_sym_shortint] = ACTIONS(4584),
    [anon_sym_int] = ACTIONS(4584),
    [anon_sym_longint] = ACTIONS(4584),
    [anon_sym_integer] = ACTIONS(4584),
    [anon_sym_time] = ACTIONS(4584),
    [anon_sym_bit] = ACTIONS(4584),
    [anon_sym_logic] = ACTIONS(4584),
    [anon_sym_reg] = ACTIONS(4584),
    [anon_sym_shortreal] = ACTIONS(4584),
    [anon_sym_real] = ACTIONS(4584),
    [anon_sym_realtime] = ACTIONS(4584),
    [anon_sym_supply0] = ACTIONS(4584),
    [anon_sym_supply1] = ACTIONS(4584),
    [anon_sym_signed] = ACTIONS(4584),
    [anon_sym_unsigned] = ACTIONS(4584),
    [anon_sym_task] = ACTIONS(4584),
    [anon_sym_assert] = ACTIONS(4584),
    [anon_sym_property] = ACTIONS(4584),
    [anon_sym_assume] = ACTIONS(4584),
    [anon_sym_cover] = ACTIONS(4584),
    [anon_sym_sequence] = ACTIONS(4584),
    [anon_sym_restrict] = ACTIONS(4584),
    [anon_sym_not] = ACTIONS(4584),
    [anon_sym_or] = ACTIONS(4584),
    [anon_sym_and] = ACTIONS(4584),
    [anon_sym_case] = ACTIONS(4584),
    [anon_sym_always] = ACTIONS(4584),
    [anon_sym_covergroup] = ACTIONS(4584),
    [anon_sym_let] = ACTIONS(4584),
    [anon_sym_pulldown] = ACTIONS(4584),
    [anon_sym_pullup] = ACTIONS(4584),
    [anon_sym_cmos] = ACTIONS(4584),
    [anon_sym_rcmos] = ACTIONS(4584),
    [anon_sym_bufif0] = ACTIONS(4584),
    [anon_sym_bufif1] = ACTIONS(4584),
    [anon_sym_notif0] = ACTIONS(4584),
    [anon_sym_notif1] = ACTIONS(4584),
    [anon_sym_nmos] = ACTIONS(4584),
    [anon_sym_pmos] = ACTIONS(4584),
    [anon_sym_rnmos] = ACTIONS(4584),
    [anon_sym_rpmos] = ACTIONS(4584),
    [anon_sym_nand] = ACTIONS(4584),
    [anon_sym_nor] = ACTIONS(4584),
    [anon_sym_xor] = ACTIONS(4584),
    [anon_sym_xnor] = ACTIONS(4584),
    [anon_sym_buf] = ACTIONS(4584),
    [anon_sym_tranif0] = ACTIONS(4584),
    [anon_sym_tranif1] = ACTIONS(4584),
    [anon_sym_rtranif1] = ACTIONS(4584),
    [anon_sym_rtranif0] = ACTIONS(4584),
    [anon_sym_tran] = ACTIONS(4584),
    [anon_sym_rtran] = ACTIONS(4584),
    [anon_sym_generate] = ACTIONS(4584),
    [anon_sym_endgenerate] = ACTIONS(4584),
    [anon_sym_for] = ACTIONS(4584),
    [anon_sym_initial] = ACTIONS(4584),
    [anon_sym_assign] = ACTIONS(4584),
    [anon_sym_alias] = ACTIONS(4584),
    [anon_sym_always_comb] = ACTIONS(4584),
    [anon_sym_always_latch] = ACTIONS(4584),
    [anon_sym_always_ff] = ACTIONS(4584),
    [anon_sym_final] = ACTIONS(4584),
    [anon_sym_global] = ACTIONS(4584),
    [anon_sym_LPAREN_STAR] = ACTIONS(4582),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4582),
    [anon_sym_DOLLARunit] = ACTIONS(4582),
  },
  [4829] = {
    [sym_simple_identifier] = ACTIONS(4892),
    [anon_sym_wire] = ACTIONS(4892),
    [anon_sym_tri] = ACTIONS(4892),
    [anon_sym_tri0] = ACTIONS(4892),
    [anon_sym_tri1] = ACTIONS(4892),
    [anon_sym_wand] = ACTIONS(4892),
    [anon_sym_triand] = ACTIONS(4892),
    [anon_sym_wor] = ACTIONS(4892),
    [anon_sym_trior] = ACTIONS(4892),
    [anon_sym_trireg] = ACTIONS(4892),
    [anon_sym_uwire] = ACTIONS(4892),
    [anon_sym_SEMI] = ACTIONS(4890),
    [anon_sym_extern] = ACTIONS(4892),
    [anon_sym_interface] = ACTIONS(4892),
    [anon_sym_checker] = ACTIONS(4892),
    [anon_sym_virtual] = ACTIONS(4892),
    [anon_sym_class] = ACTIONS(4892),
    [anon_sym_type] = ACTIONS(4892),
    [anon_sym_DOLLARfatal] = ACTIONS(4890),
    [anon_sym_DOLLARerror] = ACTIONS(4890),
    [anon_sym_DOLLARwarning] = ACTIONS(4890),
    [anon_sym_DOLLARinfo] = ACTIONS(4890),
    [anon_sym_default] = ACTIONS(4892),
    [anon_sym_clocking] = ACTIONS(4892),
    [anon_sym_defparam] = ACTIONS(4892),
    [anon_sym_bind] = ACTIONS(4892),
    [anon_sym_rand] = ACTIONS(4892),
    [anon_sym_const] = ACTIONS(4892),
    [anon_sym_function] = ACTIONS(4892),
    [anon_sym_static] = ACTIONS(4892),
    [anon_sym_constraint] = ACTIONS(4892),
    [anon_sym_if] = ACTIONS(4892),
    [anon_sym_else] = ACTIONS(4892),
    [anon_sym_LBRACK] = ACTIONS(4890),
    [anon_sym_localparam] = ACTIONS(4892),
    [anon_sym_parameter] = ACTIONS(4892),
    [anon_sym_var] = ACTIONS(4892),
    [anon_sym_import] = ACTIONS(4892),
    [anon_sym_export] = ACTIONS(4892),
    [anon_sym_genvar] = ACTIONS(4892),
    [anon_sym_interconnect] = ACTIONS(4892),
    [anon_sym_typedef] = ACTIONS(4892),
    [anon_sym_enum] = ACTIONS(4892),
    [anon_sym_struct] = ACTIONS(4892),
    [anon_sym_union] = ACTIONS(4892),
    [anon_sym_nettype] = ACTIONS(4892),
    [anon_sym_automatic] = ACTIONS(4892),
    [anon_sym_string] = ACTIONS(4892),
    [anon_sym_chandle] = ACTIONS(4892),
    [anon_sym_event] = ACTIONS(4892),
    [anon_sym_byte] = ACTIONS(4892),
    [anon_sym_shortint] = ACTIONS(4892),
    [anon_sym_int] = ACTIONS(4892),
    [anon_sym_longint] = ACTIONS(4892),
    [anon_sym_integer] = ACTIONS(4892),
    [anon_sym_time] = ACTIONS(4892),
    [anon_sym_bit] = ACTIONS(4892),
    [anon_sym_logic] = ACTIONS(4892),
    [anon_sym_reg] = ACTIONS(4892),
    [anon_sym_shortreal] = ACTIONS(4892),
    [anon_sym_real] = ACTIONS(4892),
    [anon_sym_realtime] = ACTIONS(4892),
    [anon_sym_supply0] = ACTIONS(4892),
    [anon_sym_supply1] = ACTIONS(4892),
    [anon_sym_signed] = ACTIONS(4892),
    [anon_sym_unsigned] = ACTIONS(4892),
    [anon_sym_task] = ACTIONS(4892),
    [anon_sym_assert] = ACTIONS(4892),
    [anon_sym_property] = ACTIONS(4892),
    [anon_sym_assume] = ACTIONS(4892),
    [anon_sym_cover] = ACTIONS(4892),
    [anon_sym_sequence] = ACTIONS(4892),
    [anon_sym_restrict] = ACTIONS(4892),
    [anon_sym_not] = ACTIONS(4892),
    [anon_sym_or] = ACTIONS(4892),
    [anon_sym_and] = ACTIONS(4892),
    [anon_sym_case] = ACTIONS(4892),
    [anon_sym_always] = ACTIONS(4892),
    [anon_sym_covergroup] = ACTIONS(4892),
    [anon_sym_end] = ACTIONS(4892),
    [anon_sym_let] = ACTIONS(4892),
    [anon_sym_pulldown] = ACTIONS(4892),
    [anon_sym_pullup] = ACTIONS(4892),
    [anon_sym_cmos] = ACTIONS(4892),
    [anon_sym_rcmos] = ACTIONS(4892),
    [anon_sym_bufif0] = ACTIONS(4892),
    [anon_sym_bufif1] = ACTIONS(4892),
    [anon_sym_notif0] = ACTIONS(4892),
    [anon_sym_notif1] = ACTIONS(4892),
    [anon_sym_nmos] = ACTIONS(4892),
    [anon_sym_pmos] = ACTIONS(4892),
    [anon_sym_rnmos] = ACTIONS(4892),
    [anon_sym_rpmos] = ACTIONS(4892),
    [anon_sym_nand] = ACTIONS(4892),
    [anon_sym_nor] = ACTIONS(4892),
    [anon_sym_xor] = ACTIONS(4892),
    [anon_sym_xnor] = ACTIONS(4892),
    [anon_sym_buf] = ACTIONS(4892),
    [anon_sym_tranif0] = ACTIONS(4892),
    [anon_sym_tranif1] = ACTIONS(4892),
    [anon_sym_rtranif1] = ACTIONS(4892),
    [anon_sym_rtranif0] = ACTIONS(4892),
    [anon_sym_tran] = ACTIONS(4892),
    [anon_sym_rtran] = ACTIONS(4892),
    [anon_sym_generate] = ACTIONS(4892),
    [anon_sym_for] = ACTIONS(4892),
    [anon_sym_initial] = ACTIONS(4892),
    [anon_sym_assign] = ACTIONS(4892),
    [anon_sym_alias] = ACTIONS(4892),
    [anon_sym_always_comb] = ACTIONS(4892),
    [anon_sym_always_latch] = ACTIONS(4892),
    [anon_sym_always_ff] = ACTIONS(4892),
    [anon_sym_final] = ACTIONS(4892),
    [anon_sym_global] = ACTIONS(4892),
    [anon_sym_LPAREN_STAR] = ACTIONS(4890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4890),
    [anon_sym_DOLLARunit] = ACTIONS(4890),
  },
  [4830] = {
    [sym_simple_identifier] = ACTIONS(4976),
    [anon_sym_wire] = ACTIONS(4976),
    [anon_sym_tri] = ACTIONS(4976),
    [anon_sym_tri0] = ACTIONS(4976),
    [anon_sym_tri1] = ACTIONS(4976),
    [anon_sym_wand] = ACTIONS(4976),
    [anon_sym_triand] = ACTIONS(4976),
    [anon_sym_wor] = ACTIONS(4976),
    [anon_sym_trior] = ACTIONS(4976),
    [anon_sym_trireg] = ACTIONS(4976),
    [anon_sym_uwire] = ACTIONS(4976),
    [anon_sym_SEMI] = ACTIONS(4974),
    [anon_sym_extern] = ACTIONS(4976),
    [anon_sym_interface] = ACTIONS(4976),
    [anon_sym_checker] = ACTIONS(4976),
    [anon_sym_virtual] = ACTIONS(4976),
    [anon_sym_class] = ACTIONS(4976),
    [anon_sym_type] = ACTIONS(4976),
    [anon_sym_DOLLARfatal] = ACTIONS(4974),
    [anon_sym_DOLLARerror] = ACTIONS(4974),
    [anon_sym_DOLLARwarning] = ACTIONS(4974),
    [anon_sym_DOLLARinfo] = ACTIONS(4974),
    [anon_sym_default] = ACTIONS(4976),
    [anon_sym_clocking] = ACTIONS(4976),
    [anon_sym_defparam] = ACTIONS(4976),
    [anon_sym_bind] = ACTIONS(4976),
    [anon_sym_rand] = ACTIONS(4976),
    [anon_sym_const] = ACTIONS(4976),
    [anon_sym_function] = ACTIONS(4976),
    [anon_sym_static] = ACTIONS(4976),
    [anon_sym_constraint] = ACTIONS(4976),
    [anon_sym_if] = ACTIONS(4976),
    [anon_sym_else] = ACTIONS(4976),
    [anon_sym_LBRACK] = ACTIONS(4974),
    [anon_sym_localparam] = ACTIONS(4976),
    [anon_sym_parameter] = ACTIONS(4976),
    [anon_sym_var] = ACTIONS(4976),
    [anon_sym_import] = ACTIONS(4976),
    [anon_sym_export] = ACTIONS(4976),
    [anon_sym_genvar] = ACTIONS(4976),
    [anon_sym_interconnect] = ACTIONS(4976),
    [anon_sym_typedef] = ACTIONS(4976),
    [anon_sym_enum] = ACTIONS(4976),
    [anon_sym_struct] = ACTIONS(4976),
    [anon_sym_union] = ACTIONS(4976),
    [anon_sym_nettype] = ACTIONS(4976),
    [anon_sym_automatic] = ACTIONS(4976),
    [anon_sym_string] = ACTIONS(4976),
    [anon_sym_chandle] = ACTIONS(4976),
    [anon_sym_event] = ACTIONS(4976),
    [anon_sym_byte] = ACTIONS(4976),
    [anon_sym_shortint] = ACTIONS(4976),
    [anon_sym_int] = ACTIONS(4976),
    [anon_sym_longint] = ACTIONS(4976),
    [anon_sym_integer] = ACTIONS(4976),
    [anon_sym_time] = ACTIONS(4976),
    [anon_sym_bit] = ACTIONS(4976),
    [anon_sym_logic] = ACTIONS(4976),
    [anon_sym_reg] = ACTIONS(4976),
    [anon_sym_shortreal] = ACTIONS(4976),
    [anon_sym_real] = ACTIONS(4976),
    [anon_sym_realtime] = ACTIONS(4976),
    [anon_sym_supply0] = ACTIONS(4976),
    [anon_sym_supply1] = ACTIONS(4976),
    [anon_sym_signed] = ACTIONS(4976),
    [anon_sym_unsigned] = ACTIONS(4976),
    [anon_sym_task] = ACTIONS(4976),
    [anon_sym_assert] = ACTIONS(4976),
    [anon_sym_property] = ACTIONS(4976),
    [anon_sym_assume] = ACTIONS(4976),
    [anon_sym_cover] = ACTIONS(4976),
    [anon_sym_sequence] = ACTIONS(4976),
    [anon_sym_restrict] = ACTIONS(4976),
    [anon_sym_not] = ACTIONS(4976),
    [anon_sym_or] = ACTIONS(4976),
    [anon_sym_and] = ACTIONS(4976),
    [anon_sym_case] = ACTIONS(4976),
    [anon_sym_always] = ACTIONS(4976),
    [anon_sym_covergroup] = ACTIONS(4976),
    [anon_sym_let] = ACTIONS(4976),
    [anon_sym_pulldown] = ACTIONS(4976),
    [anon_sym_pullup] = ACTIONS(4976),
    [anon_sym_cmos] = ACTIONS(4976),
    [anon_sym_rcmos] = ACTIONS(4976),
    [anon_sym_bufif0] = ACTIONS(4976),
    [anon_sym_bufif1] = ACTIONS(4976),
    [anon_sym_notif0] = ACTIONS(4976),
    [anon_sym_notif1] = ACTIONS(4976),
    [anon_sym_nmos] = ACTIONS(4976),
    [anon_sym_pmos] = ACTIONS(4976),
    [anon_sym_rnmos] = ACTIONS(4976),
    [anon_sym_rpmos] = ACTIONS(4976),
    [anon_sym_nand] = ACTIONS(4976),
    [anon_sym_nor] = ACTIONS(4976),
    [anon_sym_xor] = ACTIONS(4976),
    [anon_sym_xnor] = ACTIONS(4976),
    [anon_sym_buf] = ACTIONS(4976),
    [anon_sym_tranif0] = ACTIONS(4976),
    [anon_sym_tranif1] = ACTIONS(4976),
    [anon_sym_rtranif1] = ACTIONS(4976),
    [anon_sym_rtranif0] = ACTIONS(4976),
    [anon_sym_tran] = ACTIONS(4976),
    [anon_sym_rtran] = ACTIONS(4976),
    [anon_sym_generate] = ACTIONS(4976),
    [anon_sym_endgenerate] = ACTIONS(4976),
    [anon_sym_for] = ACTIONS(4976),
    [anon_sym_initial] = ACTIONS(4976),
    [anon_sym_assign] = ACTIONS(4976),
    [anon_sym_alias] = ACTIONS(4976),
    [anon_sym_always_comb] = ACTIONS(4976),
    [anon_sym_always_latch] = ACTIONS(4976),
    [anon_sym_always_ff] = ACTIONS(4976),
    [anon_sym_final] = ACTIONS(4976),
    [anon_sym_global] = ACTIONS(4976),
    [anon_sym_LPAREN_STAR] = ACTIONS(4974),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4974),
    [anon_sym_DOLLARunit] = ACTIONS(4974),
  },
  [4831] = {
    [sym_simple_identifier] = ACTIONS(5210),
    [anon_sym_wire] = ACTIONS(5210),
    [anon_sym_tri] = ACTIONS(5210),
    [anon_sym_tri0] = ACTIONS(5210),
    [anon_sym_tri1] = ACTIONS(5210),
    [anon_sym_wand] = ACTIONS(5210),
    [anon_sym_triand] = ACTIONS(5210),
    [anon_sym_wor] = ACTIONS(5210),
    [anon_sym_trior] = ACTIONS(5210),
    [anon_sym_trireg] = ACTIONS(5210),
    [anon_sym_uwire] = ACTIONS(5210),
    [anon_sym_SEMI] = ACTIONS(5208),
    [anon_sym_extern] = ACTIONS(5210),
    [anon_sym_interface] = ACTIONS(5210),
    [anon_sym_checker] = ACTIONS(5210),
    [anon_sym_virtual] = ACTIONS(5210),
    [anon_sym_class] = ACTIONS(5210),
    [anon_sym_type] = ACTIONS(5210),
    [anon_sym_DOLLARfatal] = ACTIONS(5208),
    [anon_sym_DOLLARerror] = ACTIONS(5208),
    [anon_sym_DOLLARwarning] = ACTIONS(5208),
    [anon_sym_DOLLARinfo] = ACTIONS(5208),
    [anon_sym_default] = ACTIONS(5210),
    [anon_sym_clocking] = ACTIONS(5210),
    [anon_sym_defparam] = ACTIONS(5210),
    [anon_sym_bind] = ACTIONS(5210),
    [anon_sym_rand] = ACTIONS(5210),
    [anon_sym_const] = ACTIONS(5210),
    [anon_sym_function] = ACTIONS(5210),
    [anon_sym_static] = ACTIONS(5210),
    [anon_sym_constraint] = ACTIONS(5210),
    [anon_sym_if] = ACTIONS(5210),
    [anon_sym_else] = ACTIONS(5210),
    [anon_sym_LBRACK] = ACTIONS(5208),
    [anon_sym_localparam] = ACTIONS(5210),
    [anon_sym_parameter] = ACTIONS(5210),
    [anon_sym_var] = ACTIONS(5210),
    [anon_sym_import] = ACTIONS(5210),
    [anon_sym_export] = ACTIONS(5210),
    [anon_sym_genvar] = ACTIONS(5210),
    [anon_sym_interconnect] = ACTIONS(5210),
    [anon_sym_typedef] = ACTIONS(5210),
    [anon_sym_enum] = ACTIONS(5210),
    [anon_sym_struct] = ACTIONS(5210),
    [anon_sym_union] = ACTIONS(5210),
    [anon_sym_nettype] = ACTIONS(5210),
    [anon_sym_automatic] = ACTIONS(5210),
    [anon_sym_string] = ACTIONS(5210),
    [anon_sym_chandle] = ACTIONS(5210),
    [anon_sym_event] = ACTIONS(5210),
    [anon_sym_byte] = ACTIONS(5210),
    [anon_sym_shortint] = ACTIONS(5210),
    [anon_sym_int] = ACTIONS(5210),
    [anon_sym_longint] = ACTIONS(5210),
    [anon_sym_integer] = ACTIONS(5210),
    [anon_sym_time] = ACTIONS(5210),
    [anon_sym_bit] = ACTIONS(5210),
    [anon_sym_logic] = ACTIONS(5210),
    [anon_sym_reg] = ACTIONS(5210),
    [anon_sym_shortreal] = ACTIONS(5210),
    [anon_sym_real] = ACTIONS(5210),
    [anon_sym_realtime] = ACTIONS(5210),
    [anon_sym_supply0] = ACTIONS(5210),
    [anon_sym_supply1] = ACTIONS(5210),
    [anon_sym_signed] = ACTIONS(5210),
    [anon_sym_unsigned] = ACTIONS(5210),
    [anon_sym_task] = ACTIONS(5210),
    [anon_sym_assert] = ACTIONS(5210),
    [anon_sym_property] = ACTIONS(5210),
    [anon_sym_assume] = ACTIONS(5210),
    [anon_sym_cover] = ACTIONS(5210),
    [anon_sym_sequence] = ACTIONS(5210),
    [anon_sym_restrict] = ACTIONS(5210),
    [anon_sym_not] = ACTIONS(5210),
    [anon_sym_or] = ACTIONS(5210),
    [anon_sym_and] = ACTIONS(5210),
    [anon_sym_case] = ACTIONS(5210),
    [anon_sym_always] = ACTIONS(5210),
    [anon_sym_covergroup] = ACTIONS(5210),
    [anon_sym_let] = ACTIONS(5210),
    [anon_sym_pulldown] = ACTIONS(5210),
    [anon_sym_pullup] = ACTIONS(5210),
    [anon_sym_cmos] = ACTIONS(5210),
    [anon_sym_rcmos] = ACTIONS(5210),
    [anon_sym_bufif0] = ACTIONS(5210),
    [anon_sym_bufif1] = ACTIONS(5210),
    [anon_sym_notif0] = ACTIONS(5210),
    [anon_sym_notif1] = ACTIONS(5210),
    [anon_sym_nmos] = ACTIONS(5210),
    [anon_sym_pmos] = ACTIONS(5210),
    [anon_sym_rnmos] = ACTIONS(5210),
    [anon_sym_rpmos] = ACTIONS(5210),
    [anon_sym_nand] = ACTIONS(5210),
    [anon_sym_nor] = ACTIONS(5210),
    [anon_sym_xor] = ACTIONS(5210),
    [anon_sym_xnor] = ACTIONS(5210),
    [anon_sym_buf] = ACTIONS(5210),
    [anon_sym_tranif0] = ACTIONS(5210),
    [anon_sym_tranif1] = ACTIONS(5210),
    [anon_sym_rtranif1] = ACTIONS(5210),
    [anon_sym_rtranif0] = ACTIONS(5210),
    [anon_sym_tran] = ACTIONS(5210),
    [anon_sym_rtran] = ACTIONS(5210),
    [anon_sym_generate] = ACTIONS(5210),
    [anon_sym_endgenerate] = ACTIONS(5210),
    [anon_sym_for] = ACTIONS(5210),
    [anon_sym_initial] = ACTIONS(5210),
    [anon_sym_assign] = ACTIONS(5210),
    [anon_sym_alias] = ACTIONS(5210),
    [anon_sym_always_comb] = ACTIONS(5210),
    [anon_sym_always_latch] = ACTIONS(5210),
    [anon_sym_always_ff] = ACTIONS(5210),
    [anon_sym_final] = ACTIONS(5210),
    [anon_sym_global] = ACTIONS(5210),
    [anon_sym_LPAREN_STAR] = ACTIONS(5208),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5208),
    [anon_sym_DOLLARunit] = ACTIONS(5208),
  },
  [4832] = {
    [sym_simple_identifier] = ACTIONS(6131),
    [anon_sym_wire] = ACTIONS(6131),
    [anon_sym_tri] = ACTIONS(6131),
    [anon_sym_tri0] = ACTIONS(6131),
    [anon_sym_tri1] = ACTIONS(6131),
    [anon_sym_wand] = ACTIONS(6131),
    [anon_sym_triand] = ACTIONS(6131),
    [anon_sym_wor] = ACTIONS(6131),
    [anon_sym_trior] = ACTIONS(6131),
    [anon_sym_trireg] = ACTIONS(6131),
    [anon_sym_uwire] = ACTIONS(6131),
    [anon_sym_SEMI] = ACTIONS(6133),
    [anon_sym_extern] = ACTIONS(6131),
    [anon_sym_interface] = ACTIONS(6131),
    [anon_sym_checker] = ACTIONS(6131),
    [anon_sym_virtual] = ACTIONS(6131),
    [anon_sym_class] = ACTIONS(6131),
    [anon_sym_type] = ACTIONS(6131),
    [anon_sym_DOLLARfatal] = ACTIONS(6133),
    [anon_sym_DOLLARerror] = ACTIONS(6133),
    [anon_sym_DOLLARwarning] = ACTIONS(6133),
    [anon_sym_DOLLARinfo] = ACTIONS(6133),
    [anon_sym_default] = ACTIONS(6131),
    [anon_sym_clocking] = ACTIONS(6131),
    [anon_sym_defparam] = ACTIONS(6131),
    [anon_sym_bind] = ACTIONS(6131),
    [anon_sym_rand] = ACTIONS(6131),
    [anon_sym_const] = ACTIONS(6131),
    [anon_sym_function] = ACTIONS(6131),
    [anon_sym_static] = ACTIONS(6131),
    [anon_sym_constraint] = ACTIONS(6131),
    [anon_sym_if] = ACTIONS(6131),
    [anon_sym_else] = ACTIONS(6131),
    [anon_sym_LBRACK] = ACTIONS(6133),
    [anon_sym_localparam] = ACTIONS(6131),
    [anon_sym_parameter] = ACTIONS(6131),
    [anon_sym_var] = ACTIONS(6131),
    [anon_sym_import] = ACTIONS(6131),
    [anon_sym_export] = ACTIONS(6131),
    [anon_sym_genvar] = ACTIONS(6131),
    [anon_sym_interconnect] = ACTIONS(6131),
    [anon_sym_typedef] = ACTIONS(6131),
    [anon_sym_enum] = ACTIONS(6131),
    [anon_sym_struct] = ACTIONS(6131),
    [anon_sym_union] = ACTIONS(6131),
    [anon_sym_nettype] = ACTIONS(6131),
    [anon_sym_automatic] = ACTIONS(6131),
    [anon_sym_string] = ACTIONS(6131),
    [anon_sym_chandle] = ACTIONS(6131),
    [anon_sym_event] = ACTIONS(6131),
    [anon_sym_byte] = ACTIONS(6131),
    [anon_sym_shortint] = ACTIONS(6131),
    [anon_sym_int] = ACTIONS(6131),
    [anon_sym_longint] = ACTIONS(6131),
    [anon_sym_integer] = ACTIONS(6131),
    [anon_sym_time] = ACTIONS(6131),
    [anon_sym_bit] = ACTIONS(6131),
    [anon_sym_logic] = ACTIONS(6131),
    [anon_sym_reg] = ACTIONS(6131),
    [anon_sym_shortreal] = ACTIONS(6131),
    [anon_sym_real] = ACTIONS(6131),
    [anon_sym_realtime] = ACTIONS(6131),
    [anon_sym_supply0] = ACTIONS(6131),
    [anon_sym_supply1] = ACTIONS(6131),
    [anon_sym_signed] = ACTIONS(6131),
    [anon_sym_unsigned] = ACTIONS(6131),
    [anon_sym_task] = ACTIONS(6131),
    [anon_sym_assert] = ACTIONS(6131),
    [anon_sym_property] = ACTIONS(6131),
    [anon_sym_assume] = ACTIONS(6131),
    [anon_sym_cover] = ACTIONS(6131),
    [anon_sym_sequence] = ACTIONS(6131),
    [anon_sym_restrict] = ACTIONS(6131),
    [anon_sym_not] = ACTIONS(6131),
    [anon_sym_or] = ACTIONS(6131),
    [anon_sym_and] = ACTIONS(6131),
    [anon_sym_case] = ACTIONS(6131),
    [anon_sym_always] = ACTIONS(6131),
    [anon_sym_covergroup] = ACTIONS(6131),
    [anon_sym_end] = ACTIONS(6131),
    [anon_sym_let] = ACTIONS(6131),
    [anon_sym_pulldown] = ACTIONS(6131),
    [anon_sym_pullup] = ACTIONS(6131),
    [anon_sym_cmos] = ACTIONS(6131),
    [anon_sym_rcmos] = ACTIONS(6131),
    [anon_sym_bufif0] = ACTIONS(6131),
    [anon_sym_bufif1] = ACTIONS(6131),
    [anon_sym_notif0] = ACTIONS(6131),
    [anon_sym_notif1] = ACTIONS(6131),
    [anon_sym_nmos] = ACTIONS(6131),
    [anon_sym_pmos] = ACTIONS(6131),
    [anon_sym_rnmos] = ACTIONS(6131),
    [anon_sym_rpmos] = ACTIONS(6131),
    [anon_sym_nand] = ACTIONS(6131),
    [anon_sym_nor] = ACTIONS(6131),
    [anon_sym_xor] = ACTIONS(6131),
    [anon_sym_xnor] = ACTIONS(6131),
    [anon_sym_buf] = ACTIONS(6131),
    [anon_sym_tranif0] = ACTIONS(6131),
    [anon_sym_tranif1] = ACTIONS(6131),
    [anon_sym_rtranif1] = ACTIONS(6131),
    [anon_sym_rtranif0] = ACTIONS(6131),
    [anon_sym_tran] = ACTIONS(6131),
    [anon_sym_rtran] = ACTIONS(6131),
    [anon_sym_generate] = ACTIONS(6131),
    [anon_sym_for] = ACTIONS(6131),
    [anon_sym_initial] = ACTIONS(6131),
    [anon_sym_assign] = ACTIONS(6131),
    [anon_sym_alias] = ACTIONS(6131),
    [anon_sym_always_comb] = ACTIONS(6131),
    [anon_sym_always_latch] = ACTIONS(6131),
    [anon_sym_always_ff] = ACTIONS(6131),
    [anon_sym_final] = ACTIONS(6131),
    [anon_sym_global] = ACTIONS(6131),
    [anon_sym_LPAREN_STAR] = ACTIONS(6133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6133),
    [anon_sym_DOLLARunit] = ACTIONS(6133),
  },
  [4833] = {
    [sym_simple_identifier] = ACTIONS(4972),
    [anon_sym_wire] = ACTIONS(4972),
    [anon_sym_tri] = ACTIONS(4972),
    [anon_sym_tri0] = ACTIONS(4972),
    [anon_sym_tri1] = ACTIONS(4972),
    [anon_sym_wand] = ACTIONS(4972),
    [anon_sym_triand] = ACTIONS(4972),
    [anon_sym_wor] = ACTIONS(4972),
    [anon_sym_trior] = ACTIONS(4972),
    [anon_sym_trireg] = ACTIONS(4972),
    [anon_sym_uwire] = ACTIONS(4972),
    [anon_sym_SEMI] = ACTIONS(4970),
    [anon_sym_extern] = ACTIONS(4972),
    [anon_sym_interface] = ACTIONS(4972),
    [anon_sym_checker] = ACTIONS(4972),
    [anon_sym_virtual] = ACTIONS(4972),
    [anon_sym_class] = ACTIONS(4972),
    [anon_sym_type] = ACTIONS(4972),
    [anon_sym_DOLLARfatal] = ACTIONS(4970),
    [anon_sym_DOLLARerror] = ACTIONS(4970),
    [anon_sym_DOLLARwarning] = ACTIONS(4970),
    [anon_sym_DOLLARinfo] = ACTIONS(4970),
    [anon_sym_default] = ACTIONS(4972),
    [anon_sym_clocking] = ACTIONS(4972),
    [anon_sym_defparam] = ACTIONS(4972),
    [anon_sym_bind] = ACTIONS(4972),
    [anon_sym_rand] = ACTIONS(4972),
    [anon_sym_const] = ACTIONS(4972),
    [anon_sym_function] = ACTIONS(4972),
    [anon_sym_static] = ACTIONS(4972),
    [anon_sym_constraint] = ACTIONS(4972),
    [anon_sym_if] = ACTIONS(4972),
    [anon_sym_else] = ACTIONS(4972),
    [anon_sym_LBRACK] = ACTIONS(4970),
    [anon_sym_localparam] = ACTIONS(4972),
    [anon_sym_parameter] = ACTIONS(4972),
    [anon_sym_var] = ACTIONS(4972),
    [anon_sym_import] = ACTIONS(4972),
    [anon_sym_export] = ACTIONS(4972),
    [anon_sym_genvar] = ACTIONS(4972),
    [anon_sym_interconnect] = ACTIONS(4972),
    [anon_sym_typedef] = ACTIONS(4972),
    [anon_sym_enum] = ACTIONS(4972),
    [anon_sym_struct] = ACTIONS(4972),
    [anon_sym_union] = ACTIONS(4972),
    [anon_sym_nettype] = ACTIONS(4972),
    [anon_sym_automatic] = ACTIONS(4972),
    [anon_sym_string] = ACTIONS(4972),
    [anon_sym_chandle] = ACTIONS(4972),
    [anon_sym_event] = ACTIONS(4972),
    [anon_sym_byte] = ACTIONS(4972),
    [anon_sym_shortint] = ACTIONS(4972),
    [anon_sym_int] = ACTIONS(4972),
    [anon_sym_longint] = ACTIONS(4972),
    [anon_sym_integer] = ACTIONS(4972),
    [anon_sym_time] = ACTIONS(4972),
    [anon_sym_bit] = ACTIONS(4972),
    [anon_sym_logic] = ACTIONS(4972),
    [anon_sym_reg] = ACTIONS(4972),
    [anon_sym_shortreal] = ACTIONS(4972),
    [anon_sym_real] = ACTIONS(4972),
    [anon_sym_realtime] = ACTIONS(4972),
    [anon_sym_supply0] = ACTIONS(4972),
    [anon_sym_supply1] = ACTIONS(4972),
    [anon_sym_signed] = ACTIONS(4972),
    [anon_sym_unsigned] = ACTIONS(4972),
    [anon_sym_task] = ACTIONS(4972),
    [anon_sym_assert] = ACTIONS(4972),
    [anon_sym_property] = ACTIONS(4972),
    [anon_sym_assume] = ACTIONS(4972),
    [anon_sym_cover] = ACTIONS(4972),
    [anon_sym_sequence] = ACTIONS(4972),
    [anon_sym_restrict] = ACTIONS(4972),
    [anon_sym_not] = ACTIONS(4972),
    [anon_sym_or] = ACTIONS(4972),
    [anon_sym_and] = ACTIONS(4972),
    [anon_sym_case] = ACTIONS(4972),
    [anon_sym_always] = ACTIONS(4972),
    [anon_sym_covergroup] = ACTIONS(4972),
    [anon_sym_let] = ACTIONS(4972),
    [anon_sym_pulldown] = ACTIONS(4972),
    [anon_sym_pullup] = ACTIONS(4972),
    [anon_sym_cmos] = ACTIONS(4972),
    [anon_sym_rcmos] = ACTIONS(4972),
    [anon_sym_bufif0] = ACTIONS(4972),
    [anon_sym_bufif1] = ACTIONS(4972),
    [anon_sym_notif0] = ACTIONS(4972),
    [anon_sym_notif1] = ACTIONS(4972),
    [anon_sym_nmos] = ACTIONS(4972),
    [anon_sym_pmos] = ACTIONS(4972),
    [anon_sym_rnmos] = ACTIONS(4972),
    [anon_sym_rpmos] = ACTIONS(4972),
    [anon_sym_nand] = ACTIONS(4972),
    [anon_sym_nor] = ACTIONS(4972),
    [anon_sym_xor] = ACTIONS(4972),
    [anon_sym_xnor] = ACTIONS(4972),
    [anon_sym_buf] = ACTIONS(4972),
    [anon_sym_tranif0] = ACTIONS(4972),
    [anon_sym_tranif1] = ACTIONS(4972),
    [anon_sym_rtranif1] = ACTIONS(4972),
    [anon_sym_rtranif0] = ACTIONS(4972),
    [anon_sym_tran] = ACTIONS(4972),
    [anon_sym_rtran] = ACTIONS(4972),
    [anon_sym_generate] = ACTIONS(4972),
    [anon_sym_endgenerate] = ACTIONS(4972),
    [anon_sym_for] = ACTIONS(4972),
    [anon_sym_initial] = ACTIONS(4972),
    [anon_sym_assign] = ACTIONS(4972),
    [anon_sym_alias] = ACTIONS(4972),
    [anon_sym_always_comb] = ACTIONS(4972),
    [anon_sym_always_latch] = ACTIONS(4972),
    [anon_sym_always_ff] = ACTIONS(4972),
    [anon_sym_final] = ACTIONS(4972),
    [anon_sym_global] = ACTIONS(4972),
    [anon_sym_LPAREN_STAR] = ACTIONS(4970),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4970),
    [anon_sym_DOLLARunit] = ACTIONS(4970),
  },
  [4834] = {
    [sym_simple_identifier] = ACTIONS(4816),
    [anon_sym_wire] = ACTIONS(4816),
    [anon_sym_tri] = ACTIONS(4816),
    [anon_sym_tri0] = ACTIONS(4816),
    [anon_sym_tri1] = ACTIONS(4816),
    [anon_sym_wand] = ACTIONS(4816),
    [anon_sym_triand] = ACTIONS(4816),
    [anon_sym_wor] = ACTIONS(4816),
    [anon_sym_trior] = ACTIONS(4816),
    [anon_sym_trireg] = ACTIONS(4816),
    [anon_sym_uwire] = ACTIONS(4816),
    [anon_sym_SEMI] = ACTIONS(4814),
    [anon_sym_extern] = ACTIONS(4816),
    [anon_sym_interface] = ACTIONS(4816),
    [anon_sym_checker] = ACTIONS(4816),
    [anon_sym_virtual] = ACTIONS(4816),
    [anon_sym_class] = ACTIONS(4816),
    [anon_sym_type] = ACTIONS(4816),
    [anon_sym_DOLLARfatal] = ACTIONS(4814),
    [anon_sym_DOLLARerror] = ACTIONS(4814),
    [anon_sym_DOLLARwarning] = ACTIONS(4814),
    [anon_sym_DOLLARinfo] = ACTIONS(4814),
    [anon_sym_default] = ACTIONS(4816),
    [anon_sym_clocking] = ACTIONS(4816),
    [anon_sym_defparam] = ACTIONS(4816),
    [anon_sym_bind] = ACTIONS(4816),
    [anon_sym_rand] = ACTIONS(4816),
    [anon_sym_const] = ACTIONS(4816),
    [anon_sym_function] = ACTIONS(4816),
    [anon_sym_static] = ACTIONS(4816),
    [anon_sym_constraint] = ACTIONS(4816),
    [anon_sym_if] = ACTIONS(4816),
    [anon_sym_else] = ACTIONS(4816),
    [anon_sym_LBRACK] = ACTIONS(4814),
    [anon_sym_localparam] = ACTIONS(4816),
    [anon_sym_parameter] = ACTIONS(4816),
    [anon_sym_var] = ACTIONS(4816),
    [anon_sym_import] = ACTIONS(4816),
    [anon_sym_export] = ACTIONS(4816),
    [anon_sym_genvar] = ACTIONS(4816),
    [anon_sym_interconnect] = ACTIONS(4816),
    [anon_sym_typedef] = ACTIONS(4816),
    [anon_sym_enum] = ACTIONS(4816),
    [anon_sym_struct] = ACTIONS(4816),
    [anon_sym_union] = ACTIONS(4816),
    [anon_sym_nettype] = ACTIONS(4816),
    [anon_sym_automatic] = ACTIONS(4816),
    [anon_sym_string] = ACTIONS(4816),
    [anon_sym_chandle] = ACTIONS(4816),
    [anon_sym_event] = ACTIONS(4816),
    [anon_sym_byte] = ACTIONS(4816),
    [anon_sym_shortint] = ACTIONS(4816),
    [anon_sym_int] = ACTIONS(4816),
    [anon_sym_longint] = ACTIONS(4816),
    [anon_sym_integer] = ACTIONS(4816),
    [anon_sym_time] = ACTIONS(4816),
    [anon_sym_bit] = ACTIONS(4816),
    [anon_sym_logic] = ACTIONS(4816),
    [anon_sym_reg] = ACTIONS(4816),
    [anon_sym_shortreal] = ACTIONS(4816),
    [anon_sym_real] = ACTIONS(4816),
    [anon_sym_realtime] = ACTIONS(4816),
    [anon_sym_supply0] = ACTIONS(4816),
    [anon_sym_supply1] = ACTIONS(4816),
    [anon_sym_signed] = ACTIONS(4816),
    [anon_sym_unsigned] = ACTIONS(4816),
    [anon_sym_task] = ACTIONS(4816),
    [anon_sym_assert] = ACTIONS(4816),
    [anon_sym_property] = ACTIONS(4816),
    [anon_sym_assume] = ACTIONS(4816),
    [anon_sym_cover] = ACTIONS(4816),
    [anon_sym_sequence] = ACTIONS(4816),
    [anon_sym_restrict] = ACTIONS(4816),
    [anon_sym_not] = ACTIONS(4816),
    [anon_sym_or] = ACTIONS(4816),
    [anon_sym_and] = ACTIONS(4816),
    [anon_sym_case] = ACTIONS(4816),
    [anon_sym_always] = ACTIONS(4816),
    [anon_sym_covergroup] = ACTIONS(4816),
    [anon_sym_let] = ACTIONS(4816),
    [anon_sym_pulldown] = ACTIONS(4816),
    [anon_sym_pullup] = ACTIONS(4816),
    [anon_sym_cmos] = ACTIONS(4816),
    [anon_sym_rcmos] = ACTIONS(4816),
    [anon_sym_bufif0] = ACTIONS(4816),
    [anon_sym_bufif1] = ACTIONS(4816),
    [anon_sym_notif0] = ACTIONS(4816),
    [anon_sym_notif1] = ACTIONS(4816),
    [anon_sym_nmos] = ACTIONS(4816),
    [anon_sym_pmos] = ACTIONS(4816),
    [anon_sym_rnmos] = ACTIONS(4816),
    [anon_sym_rpmos] = ACTIONS(4816),
    [anon_sym_nand] = ACTIONS(4816),
    [anon_sym_nor] = ACTIONS(4816),
    [anon_sym_xor] = ACTIONS(4816),
    [anon_sym_xnor] = ACTIONS(4816),
    [anon_sym_buf] = ACTIONS(4816),
    [anon_sym_tranif0] = ACTIONS(4816),
    [anon_sym_tranif1] = ACTIONS(4816),
    [anon_sym_rtranif1] = ACTIONS(4816),
    [anon_sym_rtranif0] = ACTIONS(4816),
    [anon_sym_tran] = ACTIONS(4816),
    [anon_sym_rtran] = ACTIONS(4816),
    [anon_sym_generate] = ACTIONS(4816),
    [anon_sym_endgenerate] = ACTIONS(4816),
    [anon_sym_for] = ACTIONS(4816),
    [anon_sym_initial] = ACTIONS(4816),
    [anon_sym_assign] = ACTIONS(4816),
    [anon_sym_alias] = ACTIONS(4816),
    [anon_sym_always_comb] = ACTIONS(4816),
    [anon_sym_always_latch] = ACTIONS(4816),
    [anon_sym_always_ff] = ACTIONS(4816),
    [anon_sym_final] = ACTIONS(4816),
    [anon_sym_global] = ACTIONS(4816),
    [anon_sym_LPAREN_STAR] = ACTIONS(4814),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4814),
    [anon_sym_DOLLARunit] = ACTIONS(4814),
  },
  [4835] = {
    [sym_simple_identifier] = ACTIONS(4876),
    [anon_sym_wire] = ACTIONS(4876),
    [anon_sym_tri] = ACTIONS(4876),
    [anon_sym_tri0] = ACTIONS(4876),
    [anon_sym_tri1] = ACTIONS(4876),
    [anon_sym_wand] = ACTIONS(4876),
    [anon_sym_triand] = ACTIONS(4876),
    [anon_sym_wor] = ACTIONS(4876),
    [anon_sym_trior] = ACTIONS(4876),
    [anon_sym_trireg] = ACTIONS(4876),
    [anon_sym_uwire] = ACTIONS(4876),
    [anon_sym_SEMI] = ACTIONS(4874),
    [anon_sym_extern] = ACTIONS(4876),
    [anon_sym_interface] = ACTIONS(4876),
    [anon_sym_checker] = ACTIONS(4876),
    [anon_sym_virtual] = ACTIONS(4876),
    [anon_sym_class] = ACTIONS(4876),
    [anon_sym_type] = ACTIONS(4876),
    [anon_sym_DOLLARfatal] = ACTIONS(4874),
    [anon_sym_DOLLARerror] = ACTIONS(4874),
    [anon_sym_DOLLARwarning] = ACTIONS(4874),
    [anon_sym_DOLLARinfo] = ACTIONS(4874),
    [anon_sym_default] = ACTIONS(4876),
    [anon_sym_clocking] = ACTIONS(4876),
    [anon_sym_defparam] = ACTIONS(4876),
    [anon_sym_bind] = ACTIONS(4876),
    [anon_sym_rand] = ACTIONS(4876),
    [anon_sym_const] = ACTIONS(4876),
    [anon_sym_function] = ACTIONS(4876),
    [anon_sym_static] = ACTIONS(4876),
    [anon_sym_constraint] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4876),
    [anon_sym_else] = ACTIONS(4876),
    [anon_sym_LBRACK] = ACTIONS(4874),
    [anon_sym_localparam] = ACTIONS(4876),
    [anon_sym_parameter] = ACTIONS(4876),
    [anon_sym_var] = ACTIONS(4876),
    [anon_sym_import] = ACTIONS(4876),
    [anon_sym_export] = ACTIONS(4876),
    [anon_sym_genvar] = ACTIONS(4876),
    [anon_sym_interconnect] = ACTIONS(4876),
    [anon_sym_typedef] = ACTIONS(4876),
    [anon_sym_enum] = ACTIONS(4876),
    [anon_sym_struct] = ACTIONS(4876),
    [anon_sym_union] = ACTIONS(4876),
    [anon_sym_nettype] = ACTIONS(4876),
    [anon_sym_automatic] = ACTIONS(4876),
    [anon_sym_string] = ACTIONS(4876),
    [anon_sym_chandle] = ACTIONS(4876),
    [anon_sym_event] = ACTIONS(4876),
    [anon_sym_byte] = ACTIONS(4876),
    [anon_sym_shortint] = ACTIONS(4876),
    [anon_sym_int] = ACTIONS(4876),
    [anon_sym_longint] = ACTIONS(4876),
    [anon_sym_integer] = ACTIONS(4876),
    [anon_sym_time] = ACTIONS(4876),
    [anon_sym_bit] = ACTIONS(4876),
    [anon_sym_logic] = ACTIONS(4876),
    [anon_sym_reg] = ACTIONS(4876),
    [anon_sym_shortreal] = ACTIONS(4876),
    [anon_sym_real] = ACTIONS(4876),
    [anon_sym_realtime] = ACTIONS(4876),
    [anon_sym_supply0] = ACTIONS(4876),
    [anon_sym_supply1] = ACTIONS(4876),
    [anon_sym_signed] = ACTIONS(4876),
    [anon_sym_unsigned] = ACTIONS(4876),
    [anon_sym_task] = ACTIONS(4876),
    [anon_sym_assert] = ACTIONS(4876),
    [anon_sym_property] = ACTIONS(4876),
    [anon_sym_assume] = ACTIONS(4876),
    [anon_sym_cover] = ACTIONS(4876),
    [anon_sym_sequence] = ACTIONS(4876),
    [anon_sym_restrict] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4876),
    [anon_sym_or] = ACTIONS(4876),
    [anon_sym_and] = ACTIONS(4876),
    [anon_sym_case] = ACTIONS(4876),
    [anon_sym_always] = ACTIONS(4876),
    [anon_sym_covergroup] = ACTIONS(4876),
    [anon_sym_let] = ACTIONS(4876),
    [anon_sym_pulldown] = ACTIONS(4876),
    [anon_sym_pullup] = ACTIONS(4876),
    [anon_sym_cmos] = ACTIONS(4876),
    [anon_sym_rcmos] = ACTIONS(4876),
    [anon_sym_bufif0] = ACTIONS(4876),
    [anon_sym_bufif1] = ACTIONS(4876),
    [anon_sym_notif0] = ACTIONS(4876),
    [anon_sym_notif1] = ACTIONS(4876),
    [anon_sym_nmos] = ACTIONS(4876),
    [anon_sym_pmos] = ACTIONS(4876),
    [anon_sym_rnmos] = ACTIONS(4876),
    [anon_sym_rpmos] = ACTIONS(4876),
    [anon_sym_nand] = ACTIONS(4876),
    [anon_sym_nor] = ACTIONS(4876),
    [anon_sym_xor] = ACTIONS(4876),
    [anon_sym_xnor] = ACTIONS(4876),
    [anon_sym_buf] = ACTIONS(4876),
    [anon_sym_tranif0] = ACTIONS(4876),
    [anon_sym_tranif1] = ACTIONS(4876),
    [anon_sym_rtranif1] = ACTIONS(4876),
    [anon_sym_rtranif0] = ACTIONS(4876),
    [anon_sym_tran] = ACTIONS(4876),
    [anon_sym_rtran] = ACTIONS(4876),
    [anon_sym_generate] = ACTIONS(4876),
    [anon_sym_endgenerate] = ACTIONS(4876),
    [anon_sym_for] = ACTIONS(4876),
    [anon_sym_initial] = ACTIONS(4876),
    [anon_sym_assign] = ACTIONS(4876),
    [anon_sym_alias] = ACTIONS(4876),
    [anon_sym_always_comb] = ACTIONS(4876),
    [anon_sym_always_latch] = ACTIONS(4876),
    [anon_sym_always_ff] = ACTIONS(4876),
    [anon_sym_final] = ACTIONS(4876),
    [anon_sym_global] = ACTIONS(4876),
    [anon_sym_LPAREN_STAR] = ACTIONS(4874),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4874),
    [anon_sym_DOLLARunit] = ACTIONS(4874),
  },
  [4836] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_rand] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(6699),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_endgenerate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [4837] = {
    [sym_simple_identifier] = ACTIONS(4774),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_rand] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_end] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [4838] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_rand] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_end] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [4839] = {
    [sym_simple_identifier] = ACTIONS(6577),
    [anon_sym_wire] = ACTIONS(6577),
    [anon_sym_tri] = ACTIONS(6577),
    [anon_sym_tri0] = ACTIONS(6577),
    [anon_sym_tri1] = ACTIONS(6577),
    [anon_sym_wand] = ACTIONS(6577),
    [anon_sym_triand] = ACTIONS(6577),
    [anon_sym_wor] = ACTIONS(6577),
    [anon_sym_trior] = ACTIONS(6577),
    [anon_sym_trireg] = ACTIONS(6577),
    [anon_sym_uwire] = ACTIONS(6577),
    [anon_sym_SEMI] = ACTIONS(6579),
    [anon_sym_extern] = ACTIONS(6577),
    [anon_sym_interface] = ACTIONS(6577),
    [anon_sym_checker] = ACTIONS(6577),
    [anon_sym_virtual] = ACTIONS(6577),
    [anon_sym_class] = ACTIONS(6577),
    [anon_sym_type] = ACTIONS(6577),
    [anon_sym_DOLLARfatal] = ACTIONS(6579),
    [anon_sym_DOLLARerror] = ACTIONS(6579),
    [anon_sym_DOLLARwarning] = ACTIONS(6579),
    [anon_sym_DOLLARinfo] = ACTIONS(6579),
    [anon_sym_default] = ACTIONS(6577),
    [anon_sym_clocking] = ACTIONS(6577),
    [anon_sym_defparam] = ACTIONS(6577),
    [anon_sym_bind] = ACTIONS(6577),
    [anon_sym_rand] = ACTIONS(6577),
    [anon_sym_const] = ACTIONS(6577),
    [anon_sym_function] = ACTIONS(6577),
    [anon_sym_static] = ACTIONS(6577),
    [anon_sym_constraint] = ACTIONS(6577),
    [anon_sym_if] = ACTIONS(6577),
    [anon_sym_else] = ACTIONS(6577),
    [anon_sym_LBRACK] = ACTIONS(6579),
    [anon_sym_localparam] = ACTIONS(6577),
    [anon_sym_parameter] = ACTIONS(6577),
    [anon_sym_var] = ACTIONS(6577),
    [anon_sym_import] = ACTIONS(6577),
    [anon_sym_export] = ACTIONS(6577),
    [anon_sym_genvar] = ACTIONS(6577),
    [anon_sym_interconnect] = ACTIONS(6577),
    [anon_sym_typedef] = ACTIONS(6577),
    [anon_sym_enum] = ACTIONS(6577),
    [anon_sym_struct] = ACTIONS(6577),
    [anon_sym_union] = ACTIONS(6577),
    [anon_sym_nettype] = ACTIONS(6577),
    [anon_sym_automatic] = ACTIONS(6577),
    [anon_sym_string] = ACTIONS(6577),
    [anon_sym_chandle] = ACTIONS(6577),
    [anon_sym_event] = ACTIONS(6577),
    [anon_sym_byte] = ACTIONS(6577),
    [anon_sym_shortint] = ACTIONS(6577),
    [anon_sym_int] = ACTIONS(6577),
    [anon_sym_longint] = ACTIONS(6577),
    [anon_sym_integer] = ACTIONS(6577),
    [anon_sym_time] = ACTIONS(6577),
    [anon_sym_bit] = ACTIONS(6577),
    [anon_sym_logic] = ACTIONS(6577),
    [anon_sym_reg] = ACTIONS(6577),
    [anon_sym_shortreal] = ACTIONS(6577),
    [anon_sym_real] = ACTIONS(6577),
    [anon_sym_realtime] = ACTIONS(6577),
    [anon_sym_supply0] = ACTIONS(6577),
    [anon_sym_supply1] = ACTIONS(6577),
    [anon_sym_signed] = ACTIONS(6577),
    [anon_sym_unsigned] = ACTIONS(6577),
    [anon_sym_task] = ACTIONS(6577),
    [anon_sym_assert] = ACTIONS(6577),
    [anon_sym_property] = ACTIONS(6577),
    [anon_sym_assume] = ACTIONS(6577),
    [anon_sym_cover] = ACTIONS(6577),
    [anon_sym_sequence] = ACTIONS(6577),
    [anon_sym_restrict] = ACTIONS(6577),
    [anon_sym_not] = ACTIONS(6577),
    [anon_sym_or] = ACTIONS(6577),
    [anon_sym_and] = ACTIONS(6577),
    [anon_sym_case] = ACTIONS(6577),
    [anon_sym_always] = ACTIONS(6577),
    [anon_sym_covergroup] = ACTIONS(6577),
    [anon_sym_let] = ACTIONS(6577),
    [anon_sym_pulldown] = ACTIONS(6577),
    [anon_sym_pullup] = ACTIONS(6577),
    [anon_sym_cmos] = ACTIONS(6577),
    [anon_sym_rcmos] = ACTIONS(6577),
    [anon_sym_bufif0] = ACTIONS(6577),
    [anon_sym_bufif1] = ACTIONS(6577),
    [anon_sym_notif0] = ACTIONS(6577),
    [anon_sym_notif1] = ACTIONS(6577),
    [anon_sym_nmos] = ACTIONS(6577),
    [anon_sym_pmos] = ACTIONS(6577),
    [anon_sym_rnmos] = ACTIONS(6577),
    [anon_sym_rpmos] = ACTIONS(6577),
    [anon_sym_nand] = ACTIONS(6577),
    [anon_sym_nor] = ACTIONS(6577),
    [anon_sym_xor] = ACTIONS(6577),
    [anon_sym_xnor] = ACTIONS(6577),
    [anon_sym_buf] = ACTIONS(6577),
    [anon_sym_tranif0] = ACTIONS(6577),
    [anon_sym_tranif1] = ACTIONS(6577),
    [anon_sym_rtranif1] = ACTIONS(6577),
    [anon_sym_rtranif0] = ACTIONS(6577),
    [anon_sym_tran] = ACTIONS(6577),
    [anon_sym_rtran] = ACTIONS(6577),
    [anon_sym_generate] = ACTIONS(6577),
    [anon_sym_endgenerate] = ACTIONS(6577),
    [anon_sym_for] = ACTIONS(6577),
    [anon_sym_initial] = ACTIONS(6577),
    [anon_sym_assign] = ACTIONS(6577),
    [anon_sym_alias] = ACTIONS(6577),
    [anon_sym_always_comb] = ACTIONS(6577),
    [anon_sym_always_latch] = ACTIONS(6577),
    [anon_sym_always_ff] = ACTIONS(6577),
    [anon_sym_final] = ACTIONS(6577),
    [anon_sym_global] = ACTIONS(6577),
    [anon_sym_LPAREN_STAR] = ACTIONS(6579),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6579),
    [anon_sym_DOLLARunit] = ACTIONS(6579),
  },
  [4840] = {
    [sym_simple_identifier] = ACTIONS(6661),
    [anon_sym_wire] = ACTIONS(6661),
    [anon_sym_tri] = ACTIONS(6661),
    [anon_sym_tri0] = ACTIONS(6661),
    [anon_sym_tri1] = ACTIONS(6661),
    [anon_sym_wand] = ACTIONS(6661),
    [anon_sym_triand] = ACTIONS(6661),
    [anon_sym_wor] = ACTIONS(6661),
    [anon_sym_trior] = ACTIONS(6661),
    [anon_sym_trireg] = ACTIONS(6661),
    [anon_sym_uwire] = ACTIONS(6661),
    [anon_sym_SEMI] = ACTIONS(6663),
    [anon_sym_extern] = ACTIONS(6661),
    [anon_sym_interface] = ACTIONS(6661),
    [anon_sym_checker] = ACTIONS(6661),
    [anon_sym_virtual] = ACTIONS(6661),
    [anon_sym_class] = ACTIONS(6661),
    [anon_sym_type] = ACTIONS(6661),
    [anon_sym_DOLLARfatal] = ACTIONS(6663),
    [anon_sym_DOLLARerror] = ACTIONS(6663),
    [anon_sym_DOLLARwarning] = ACTIONS(6663),
    [anon_sym_DOLLARinfo] = ACTIONS(6663),
    [anon_sym_default] = ACTIONS(6661),
    [anon_sym_clocking] = ACTIONS(6661),
    [anon_sym_defparam] = ACTIONS(6661),
    [anon_sym_bind] = ACTIONS(6661),
    [anon_sym_rand] = ACTIONS(6661),
    [anon_sym_const] = ACTIONS(6661),
    [anon_sym_function] = ACTIONS(6661),
    [anon_sym_static] = ACTIONS(6661),
    [anon_sym_constraint] = ACTIONS(6661),
    [anon_sym_if] = ACTIONS(6661),
    [anon_sym_else] = ACTIONS(6661),
    [anon_sym_LBRACK] = ACTIONS(6663),
    [anon_sym_localparam] = ACTIONS(6661),
    [anon_sym_parameter] = ACTIONS(6661),
    [anon_sym_var] = ACTIONS(6661),
    [anon_sym_import] = ACTIONS(6661),
    [anon_sym_export] = ACTIONS(6661),
    [anon_sym_genvar] = ACTIONS(6661),
    [anon_sym_interconnect] = ACTIONS(6661),
    [anon_sym_typedef] = ACTIONS(6661),
    [anon_sym_enum] = ACTIONS(6661),
    [anon_sym_struct] = ACTIONS(6661),
    [anon_sym_union] = ACTIONS(6661),
    [anon_sym_nettype] = ACTIONS(6661),
    [anon_sym_automatic] = ACTIONS(6661),
    [anon_sym_string] = ACTIONS(6661),
    [anon_sym_chandle] = ACTIONS(6661),
    [anon_sym_event] = ACTIONS(6661),
    [anon_sym_byte] = ACTIONS(6661),
    [anon_sym_shortint] = ACTIONS(6661),
    [anon_sym_int] = ACTIONS(6661),
    [anon_sym_longint] = ACTIONS(6661),
    [anon_sym_integer] = ACTIONS(6661),
    [anon_sym_time] = ACTIONS(6661),
    [anon_sym_bit] = ACTIONS(6661),
    [anon_sym_logic] = ACTIONS(6661),
    [anon_sym_reg] = ACTIONS(6661),
    [anon_sym_shortreal] = ACTIONS(6661),
    [anon_sym_real] = ACTIONS(6661),
    [anon_sym_realtime] = ACTIONS(6661),
    [anon_sym_supply0] = ACTIONS(6661),
    [anon_sym_supply1] = ACTIONS(6661),
    [anon_sym_signed] = ACTIONS(6661),
    [anon_sym_unsigned] = ACTIONS(6661),
    [anon_sym_task] = ACTIONS(6661),
    [anon_sym_assert] = ACTIONS(6661),
    [anon_sym_property] = ACTIONS(6661),
    [anon_sym_assume] = ACTIONS(6661),
    [anon_sym_cover] = ACTIONS(6661),
    [anon_sym_sequence] = ACTIONS(6661),
    [anon_sym_restrict] = ACTIONS(6661),
    [anon_sym_not] = ACTIONS(6661),
    [anon_sym_or] = ACTIONS(6661),
    [anon_sym_and] = ACTIONS(6661),
    [anon_sym_case] = ACTIONS(6661),
    [anon_sym_always] = ACTIONS(6661),
    [anon_sym_covergroup] = ACTIONS(6661),
    [anon_sym_let] = ACTIONS(6661),
    [anon_sym_pulldown] = ACTIONS(6661),
    [anon_sym_pullup] = ACTIONS(6661),
    [anon_sym_cmos] = ACTIONS(6661),
    [anon_sym_rcmos] = ACTIONS(6661),
    [anon_sym_bufif0] = ACTIONS(6661),
    [anon_sym_bufif1] = ACTIONS(6661),
    [anon_sym_notif0] = ACTIONS(6661),
    [anon_sym_notif1] = ACTIONS(6661),
    [anon_sym_nmos] = ACTIONS(6661),
    [anon_sym_pmos] = ACTIONS(6661),
    [anon_sym_rnmos] = ACTIONS(6661),
    [anon_sym_rpmos] = ACTIONS(6661),
    [anon_sym_nand] = ACTIONS(6661),
    [anon_sym_nor] = ACTIONS(6661),
    [anon_sym_xor] = ACTIONS(6661),
    [anon_sym_xnor] = ACTIONS(6661),
    [anon_sym_buf] = ACTIONS(6661),
    [anon_sym_tranif0] = ACTIONS(6661),
    [anon_sym_tranif1] = ACTIONS(6661),
    [anon_sym_rtranif1] = ACTIONS(6661),
    [anon_sym_rtranif0] = ACTIONS(6661),
    [anon_sym_tran] = ACTIONS(6661),
    [anon_sym_rtran] = ACTIONS(6661),
    [anon_sym_generate] = ACTIONS(6661),
    [anon_sym_endgenerate] = ACTIONS(6661),
    [anon_sym_for] = ACTIONS(6661),
    [anon_sym_initial] = ACTIONS(6661),
    [anon_sym_assign] = ACTIONS(6661),
    [anon_sym_alias] = ACTIONS(6661),
    [anon_sym_always_comb] = ACTIONS(6661),
    [anon_sym_always_latch] = ACTIONS(6661),
    [anon_sym_always_ff] = ACTIONS(6661),
    [anon_sym_final] = ACTIONS(6661),
    [anon_sym_global] = ACTIONS(6661),
    [anon_sym_LPAREN_STAR] = ACTIONS(6663),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6663),
    [anon_sym_DOLLARunit] = ACTIONS(6663),
  },
  [4841] = {
    [sym_simple_identifier] = ACTIONS(6523),
    [anon_sym_wire] = ACTIONS(6523),
    [anon_sym_tri] = ACTIONS(6523),
    [anon_sym_tri0] = ACTIONS(6523),
    [anon_sym_tri1] = ACTIONS(6523),
    [anon_sym_wand] = ACTIONS(6523),
    [anon_sym_triand] = ACTIONS(6523),
    [anon_sym_wor] = ACTIONS(6523),
    [anon_sym_trior] = ACTIONS(6523),
    [anon_sym_trireg] = ACTIONS(6523),
    [anon_sym_uwire] = ACTIONS(6523),
    [anon_sym_SEMI] = ACTIONS(6526),
    [anon_sym_extern] = ACTIONS(6523),
    [anon_sym_interface] = ACTIONS(6523),
    [anon_sym_checker] = ACTIONS(6523),
    [anon_sym_virtual] = ACTIONS(6523),
    [anon_sym_class] = ACTIONS(6523),
    [anon_sym_type] = ACTIONS(6523),
    [anon_sym_DOLLARfatal] = ACTIONS(6526),
    [anon_sym_DOLLARerror] = ACTIONS(6526),
    [anon_sym_DOLLARwarning] = ACTIONS(6526),
    [anon_sym_DOLLARinfo] = ACTIONS(6526),
    [anon_sym_default] = ACTIONS(6523),
    [anon_sym_clocking] = ACTIONS(6523),
    [anon_sym_defparam] = ACTIONS(6523),
    [anon_sym_bind] = ACTIONS(6523),
    [anon_sym_rand] = ACTIONS(6523),
    [anon_sym_const] = ACTIONS(6523),
    [anon_sym_function] = ACTIONS(6523),
    [anon_sym_static] = ACTIONS(6523),
    [anon_sym_constraint] = ACTIONS(6523),
    [anon_sym_if] = ACTIONS(6523),
    [anon_sym_else] = ACTIONS(6523),
    [anon_sym_LBRACK] = ACTIONS(6526),
    [anon_sym_localparam] = ACTIONS(6523),
    [anon_sym_parameter] = ACTIONS(6523),
    [anon_sym_var] = ACTIONS(6523),
    [anon_sym_import] = ACTIONS(6523),
    [anon_sym_export] = ACTIONS(6523),
    [anon_sym_genvar] = ACTIONS(6523),
    [anon_sym_interconnect] = ACTIONS(6523),
    [anon_sym_typedef] = ACTIONS(6523),
    [anon_sym_enum] = ACTIONS(6523),
    [anon_sym_struct] = ACTIONS(6523),
    [anon_sym_union] = ACTIONS(6523),
    [anon_sym_nettype] = ACTIONS(6523),
    [anon_sym_automatic] = ACTIONS(6523),
    [anon_sym_string] = ACTIONS(6523),
    [anon_sym_chandle] = ACTIONS(6523),
    [anon_sym_event] = ACTIONS(6523),
    [anon_sym_byte] = ACTIONS(6523),
    [anon_sym_shortint] = ACTIONS(6523),
    [anon_sym_int] = ACTIONS(6523),
    [anon_sym_longint] = ACTIONS(6523),
    [anon_sym_integer] = ACTIONS(6523),
    [anon_sym_time] = ACTIONS(6523),
    [anon_sym_bit] = ACTIONS(6523),
    [anon_sym_logic] = ACTIONS(6523),
    [anon_sym_reg] = ACTIONS(6523),
    [anon_sym_shortreal] = ACTIONS(6523),
    [anon_sym_real] = ACTIONS(6523),
    [anon_sym_realtime] = ACTIONS(6523),
    [anon_sym_supply0] = ACTIONS(6523),
    [anon_sym_supply1] = ACTIONS(6523),
    [anon_sym_signed] = ACTIONS(6523),
    [anon_sym_unsigned] = ACTIONS(6523),
    [anon_sym_task] = ACTIONS(6523),
    [anon_sym_assert] = ACTIONS(6523),
    [anon_sym_property] = ACTIONS(6523),
    [anon_sym_assume] = ACTIONS(6523),
    [anon_sym_cover] = ACTIONS(6523),
    [anon_sym_sequence] = ACTIONS(6523),
    [anon_sym_restrict] = ACTIONS(6523),
    [anon_sym_not] = ACTIONS(6523),
    [anon_sym_or] = ACTIONS(6523),
    [anon_sym_and] = ACTIONS(6523),
    [anon_sym_case] = ACTIONS(6523),
    [anon_sym_always] = ACTIONS(6523),
    [anon_sym_covergroup] = ACTIONS(6523),
    [anon_sym_end] = ACTIONS(6523),
    [anon_sym_let] = ACTIONS(6523),
    [anon_sym_pulldown] = ACTIONS(6523),
    [anon_sym_pullup] = ACTIONS(6523),
    [anon_sym_cmos] = ACTIONS(6523),
    [anon_sym_rcmos] = ACTIONS(6523),
    [anon_sym_bufif0] = ACTIONS(6523),
    [anon_sym_bufif1] = ACTIONS(6523),
    [anon_sym_notif0] = ACTIONS(6523),
    [anon_sym_notif1] = ACTIONS(6523),
    [anon_sym_nmos] = ACTIONS(6523),
    [anon_sym_pmos] = ACTIONS(6523),
    [anon_sym_rnmos] = ACTIONS(6523),
    [anon_sym_rpmos] = ACTIONS(6523),
    [anon_sym_nand] = ACTIONS(6523),
    [anon_sym_nor] = ACTIONS(6523),
    [anon_sym_xor] = ACTIONS(6523),
    [anon_sym_xnor] = ACTIONS(6523),
    [anon_sym_buf] = ACTIONS(6523),
    [anon_sym_tranif0] = ACTIONS(6523),
    [anon_sym_tranif1] = ACTIONS(6523),
    [anon_sym_rtranif1] = ACTIONS(6523),
    [anon_sym_rtranif0] = ACTIONS(6523),
    [anon_sym_tran] = ACTIONS(6523),
    [anon_sym_rtran] = ACTIONS(6523),
    [anon_sym_generate] = ACTIONS(6523),
    [anon_sym_for] = ACTIONS(6523),
    [anon_sym_initial] = ACTIONS(6523),
    [anon_sym_assign] = ACTIONS(6523),
    [anon_sym_alias] = ACTIONS(6523),
    [anon_sym_always_comb] = ACTIONS(6523),
    [anon_sym_always_latch] = ACTIONS(6523),
    [anon_sym_always_ff] = ACTIONS(6523),
    [anon_sym_final] = ACTIONS(6523),
    [anon_sym_global] = ACTIONS(6523),
    [anon_sym_LPAREN_STAR] = ACTIONS(6526),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6526),
    [anon_sym_DOLLARunit] = ACTIONS(6526),
  },
  [4842] = {
    [sym_simple_identifier] = ACTIONS(4478),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_rand] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_end] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [4843] = {
    [sym_simple_identifier] = ACTIONS(6123),
    [anon_sym_wire] = ACTIONS(6123),
    [anon_sym_tri] = ACTIONS(6123),
    [anon_sym_tri0] = ACTIONS(6123),
    [anon_sym_tri1] = ACTIONS(6123),
    [anon_sym_wand] = ACTIONS(6123),
    [anon_sym_triand] = ACTIONS(6123),
    [anon_sym_wor] = ACTIONS(6123),
    [anon_sym_trior] = ACTIONS(6123),
    [anon_sym_trireg] = ACTIONS(6123),
    [anon_sym_uwire] = ACTIONS(6123),
    [anon_sym_SEMI] = ACTIONS(6125),
    [anon_sym_extern] = ACTIONS(6123),
    [anon_sym_interface] = ACTIONS(6123),
    [anon_sym_checker] = ACTIONS(6123),
    [anon_sym_virtual] = ACTIONS(6123),
    [anon_sym_class] = ACTIONS(6123),
    [anon_sym_type] = ACTIONS(6123),
    [anon_sym_DOLLARfatal] = ACTIONS(6125),
    [anon_sym_DOLLARerror] = ACTIONS(6125),
    [anon_sym_DOLLARwarning] = ACTIONS(6125),
    [anon_sym_DOLLARinfo] = ACTIONS(6125),
    [anon_sym_default] = ACTIONS(6123),
    [anon_sym_clocking] = ACTIONS(6123),
    [anon_sym_defparam] = ACTIONS(6123),
    [anon_sym_bind] = ACTIONS(6123),
    [anon_sym_rand] = ACTIONS(6123),
    [anon_sym_const] = ACTIONS(6123),
    [anon_sym_function] = ACTIONS(6123),
    [anon_sym_static] = ACTIONS(6123),
    [anon_sym_constraint] = ACTIONS(6123),
    [anon_sym_if] = ACTIONS(6123),
    [anon_sym_else] = ACTIONS(6123),
    [anon_sym_LBRACK] = ACTIONS(6125),
    [anon_sym_localparam] = ACTIONS(6123),
    [anon_sym_parameter] = ACTIONS(6123),
    [anon_sym_var] = ACTIONS(6123),
    [anon_sym_import] = ACTIONS(6123),
    [anon_sym_export] = ACTIONS(6123),
    [anon_sym_genvar] = ACTIONS(6123),
    [anon_sym_interconnect] = ACTIONS(6123),
    [anon_sym_typedef] = ACTIONS(6123),
    [anon_sym_enum] = ACTIONS(6123),
    [anon_sym_struct] = ACTIONS(6123),
    [anon_sym_union] = ACTIONS(6123),
    [anon_sym_nettype] = ACTIONS(6123),
    [anon_sym_automatic] = ACTIONS(6123),
    [anon_sym_string] = ACTIONS(6123),
    [anon_sym_chandle] = ACTIONS(6123),
    [anon_sym_event] = ACTIONS(6123),
    [anon_sym_byte] = ACTIONS(6123),
    [anon_sym_shortint] = ACTIONS(6123),
    [anon_sym_int] = ACTIONS(6123),
    [anon_sym_longint] = ACTIONS(6123),
    [anon_sym_integer] = ACTIONS(6123),
    [anon_sym_time] = ACTIONS(6123),
    [anon_sym_bit] = ACTIONS(6123),
    [anon_sym_logic] = ACTIONS(6123),
    [anon_sym_reg] = ACTIONS(6123),
    [anon_sym_shortreal] = ACTIONS(6123),
    [anon_sym_real] = ACTIONS(6123),
    [anon_sym_realtime] = ACTIONS(6123),
    [anon_sym_supply0] = ACTIONS(6123),
    [anon_sym_supply1] = ACTIONS(6123),
    [anon_sym_signed] = ACTIONS(6123),
    [anon_sym_unsigned] = ACTIONS(6123),
    [anon_sym_task] = ACTIONS(6123),
    [anon_sym_assert] = ACTIONS(6123),
    [anon_sym_property] = ACTIONS(6123),
    [anon_sym_assume] = ACTIONS(6123),
    [anon_sym_cover] = ACTIONS(6123),
    [anon_sym_sequence] = ACTIONS(6123),
    [anon_sym_restrict] = ACTIONS(6123),
    [anon_sym_not] = ACTIONS(6123),
    [anon_sym_or] = ACTIONS(6123),
    [anon_sym_and] = ACTIONS(6123),
    [anon_sym_case] = ACTIONS(6123),
    [anon_sym_always] = ACTIONS(6123),
    [anon_sym_covergroup] = ACTIONS(6123),
    [anon_sym_let] = ACTIONS(6123),
    [anon_sym_pulldown] = ACTIONS(6123),
    [anon_sym_pullup] = ACTIONS(6123),
    [anon_sym_cmos] = ACTIONS(6123),
    [anon_sym_rcmos] = ACTIONS(6123),
    [anon_sym_bufif0] = ACTIONS(6123),
    [anon_sym_bufif1] = ACTIONS(6123),
    [anon_sym_notif0] = ACTIONS(6123),
    [anon_sym_notif1] = ACTIONS(6123),
    [anon_sym_nmos] = ACTIONS(6123),
    [anon_sym_pmos] = ACTIONS(6123),
    [anon_sym_rnmos] = ACTIONS(6123),
    [anon_sym_rpmos] = ACTIONS(6123),
    [anon_sym_nand] = ACTIONS(6123),
    [anon_sym_nor] = ACTIONS(6123),
    [anon_sym_xor] = ACTIONS(6123),
    [anon_sym_xnor] = ACTIONS(6123),
    [anon_sym_buf] = ACTIONS(6123),
    [anon_sym_tranif0] = ACTIONS(6123),
    [anon_sym_tranif1] = ACTIONS(6123),
    [anon_sym_rtranif1] = ACTIONS(6123),
    [anon_sym_rtranif0] = ACTIONS(6123),
    [anon_sym_tran] = ACTIONS(6123),
    [anon_sym_rtran] = ACTIONS(6123),
    [anon_sym_generate] = ACTIONS(6123),
    [anon_sym_endgenerate] = ACTIONS(6123),
    [anon_sym_for] = ACTIONS(6123),
    [anon_sym_initial] = ACTIONS(6123),
    [anon_sym_assign] = ACTIONS(6123),
    [anon_sym_alias] = ACTIONS(6123),
    [anon_sym_always_comb] = ACTIONS(6123),
    [anon_sym_always_latch] = ACTIONS(6123),
    [anon_sym_always_ff] = ACTIONS(6123),
    [anon_sym_final] = ACTIONS(6123),
    [anon_sym_global] = ACTIONS(6123),
    [anon_sym_LPAREN_STAR] = ACTIONS(6125),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6125),
    [anon_sym_DOLLARunit] = ACTIONS(6125),
  },
  [4844] = {
    [sym_simple_identifier] = ACTIONS(4196),
    [anon_sym_wire] = ACTIONS(4196),
    [anon_sym_tri] = ACTIONS(4196),
    [anon_sym_tri0] = ACTIONS(4196),
    [anon_sym_tri1] = ACTIONS(4196),
    [anon_sym_wand] = ACTIONS(4196),
    [anon_sym_triand] = ACTIONS(4196),
    [anon_sym_wor] = ACTIONS(4196),
    [anon_sym_trior] = ACTIONS(4196),
    [anon_sym_trireg] = ACTIONS(4196),
    [anon_sym_uwire] = ACTIONS(4196),
    [anon_sym_SEMI] = ACTIONS(4194),
    [anon_sym_extern] = ACTIONS(4196),
    [anon_sym_interface] = ACTIONS(4196),
    [anon_sym_checker] = ACTIONS(4196),
    [anon_sym_virtual] = ACTIONS(4196),
    [anon_sym_class] = ACTIONS(4196),
    [anon_sym_type] = ACTIONS(4196),
    [anon_sym_DOLLARfatal] = ACTIONS(4194),
    [anon_sym_DOLLARerror] = ACTIONS(4194),
    [anon_sym_DOLLARwarning] = ACTIONS(4194),
    [anon_sym_DOLLARinfo] = ACTIONS(4194),
    [anon_sym_default] = ACTIONS(4196),
    [anon_sym_clocking] = ACTIONS(4196),
    [anon_sym_defparam] = ACTIONS(4196),
    [anon_sym_bind] = ACTIONS(4196),
    [anon_sym_rand] = ACTIONS(4196),
    [anon_sym_const] = ACTIONS(4196),
    [anon_sym_function] = ACTIONS(4196),
    [anon_sym_static] = ACTIONS(4196),
    [anon_sym_constraint] = ACTIONS(4196),
    [anon_sym_if] = ACTIONS(4196),
    [anon_sym_else] = ACTIONS(4196),
    [anon_sym_LBRACK] = ACTIONS(4194),
    [anon_sym_localparam] = ACTIONS(4196),
    [anon_sym_parameter] = ACTIONS(4196),
    [anon_sym_var] = ACTIONS(4196),
    [anon_sym_import] = ACTIONS(4196),
    [anon_sym_export] = ACTIONS(4196),
    [anon_sym_genvar] = ACTIONS(4196),
    [anon_sym_interconnect] = ACTIONS(4196),
    [anon_sym_typedef] = ACTIONS(4196),
    [anon_sym_enum] = ACTIONS(4196),
    [anon_sym_struct] = ACTIONS(4196),
    [anon_sym_union] = ACTIONS(4196),
    [anon_sym_nettype] = ACTIONS(4196),
    [anon_sym_automatic] = ACTIONS(4196),
    [anon_sym_string] = ACTIONS(4196),
    [anon_sym_chandle] = ACTIONS(4196),
    [anon_sym_event] = ACTIONS(4196),
    [anon_sym_byte] = ACTIONS(4196),
    [anon_sym_shortint] = ACTIONS(4196),
    [anon_sym_int] = ACTIONS(4196),
    [anon_sym_longint] = ACTIONS(4196),
    [anon_sym_integer] = ACTIONS(4196),
    [anon_sym_time] = ACTIONS(4196),
    [anon_sym_bit] = ACTIONS(4196),
    [anon_sym_logic] = ACTIONS(4196),
    [anon_sym_reg] = ACTIONS(4196),
    [anon_sym_shortreal] = ACTIONS(4196),
    [anon_sym_real] = ACTIONS(4196),
    [anon_sym_realtime] = ACTIONS(4196),
    [anon_sym_supply0] = ACTIONS(4196),
    [anon_sym_supply1] = ACTIONS(4196),
    [anon_sym_signed] = ACTIONS(4196),
    [anon_sym_unsigned] = ACTIONS(4196),
    [anon_sym_task] = ACTIONS(4196),
    [anon_sym_assert] = ACTIONS(4196),
    [anon_sym_property] = ACTIONS(4196),
    [anon_sym_assume] = ACTIONS(4196),
    [anon_sym_cover] = ACTIONS(4196),
    [anon_sym_sequence] = ACTIONS(4196),
    [anon_sym_restrict] = ACTIONS(4196),
    [anon_sym_not] = ACTIONS(4196),
    [anon_sym_or] = ACTIONS(4196),
    [anon_sym_and] = ACTIONS(4196),
    [anon_sym_case] = ACTIONS(4196),
    [anon_sym_always] = ACTIONS(4196),
    [anon_sym_covergroup] = ACTIONS(4196),
    [anon_sym_end] = ACTIONS(4196),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_pulldown] = ACTIONS(4196),
    [anon_sym_pullup] = ACTIONS(4196),
    [anon_sym_cmos] = ACTIONS(4196),
    [anon_sym_rcmos] = ACTIONS(4196),
    [anon_sym_bufif0] = ACTIONS(4196),
    [anon_sym_bufif1] = ACTIONS(4196),
    [anon_sym_notif0] = ACTIONS(4196),
    [anon_sym_notif1] = ACTIONS(4196),
    [anon_sym_nmos] = ACTIONS(4196),
    [anon_sym_pmos] = ACTIONS(4196),
    [anon_sym_rnmos] = ACTIONS(4196),
    [anon_sym_rpmos] = ACTIONS(4196),
    [anon_sym_nand] = ACTIONS(4196),
    [anon_sym_nor] = ACTIONS(4196),
    [anon_sym_xor] = ACTIONS(4196),
    [anon_sym_xnor] = ACTIONS(4196),
    [anon_sym_buf] = ACTIONS(4196),
    [anon_sym_tranif0] = ACTIONS(4196),
    [anon_sym_tranif1] = ACTIONS(4196),
    [anon_sym_rtranif1] = ACTIONS(4196),
    [anon_sym_rtranif0] = ACTIONS(4196),
    [anon_sym_tran] = ACTIONS(4196),
    [anon_sym_rtran] = ACTIONS(4196),
    [anon_sym_generate] = ACTIONS(4196),
    [anon_sym_for] = ACTIONS(4196),
    [anon_sym_initial] = ACTIONS(4196),
    [anon_sym_assign] = ACTIONS(4196),
    [anon_sym_alias] = ACTIONS(4196),
    [anon_sym_always_comb] = ACTIONS(4196),
    [anon_sym_always_latch] = ACTIONS(4196),
    [anon_sym_always_ff] = ACTIONS(4196),
    [anon_sym_final] = ACTIONS(4196),
    [anon_sym_global] = ACTIONS(4196),
    [anon_sym_LPAREN_STAR] = ACTIONS(4194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4194),
    [anon_sym_DOLLARunit] = ACTIONS(4194),
  },
  [4845] = {
    [sym_simple_identifier] = ACTIONS(5182),
    [anon_sym_wire] = ACTIONS(5182),
    [anon_sym_tri] = ACTIONS(5182),
    [anon_sym_tri0] = ACTIONS(5182),
    [anon_sym_tri1] = ACTIONS(5182),
    [anon_sym_wand] = ACTIONS(5182),
    [anon_sym_triand] = ACTIONS(5182),
    [anon_sym_wor] = ACTIONS(5182),
    [anon_sym_trior] = ACTIONS(5182),
    [anon_sym_trireg] = ACTIONS(5182),
    [anon_sym_uwire] = ACTIONS(5182),
    [anon_sym_SEMI] = ACTIONS(5180),
    [anon_sym_extern] = ACTIONS(5182),
    [anon_sym_interface] = ACTIONS(5182),
    [anon_sym_checker] = ACTIONS(5182),
    [anon_sym_virtual] = ACTIONS(5182),
    [anon_sym_class] = ACTIONS(5182),
    [anon_sym_type] = ACTIONS(5182),
    [anon_sym_DOLLARfatal] = ACTIONS(5180),
    [anon_sym_DOLLARerror] = ACTIONS(5180),
    [anon_sym_DOLLARwarning] = ACTIONS(5180),
    [anon_sym_DOLLARinfo] = ACTIONS(5180),
    [anon_sym_default] = ACTIONS(5182),
    [anon_sym_clocking] = ACTIONS(5182),
    [anon_sym_defparam] = ACTIONS(5182),
    [anon_sym_bind] = ACTIONS(5182),
    [anon_sym_rand] = ACTIONS(5182),
    [anon_sym_const] = ACTIONS(5182),
    [anon_sym_function] = ACTIONS(5182),
    [anon_sym_static] = ACTIONS(5182),
    [anon_sym_constraint] = ACTIONS(5182),
    [anon_sym_if] = ACTIONS(5182),
    [anon_sym_else] = ACTIONS(5182),
    [anon_sym_LBRACK] = ACTIONS(5180),
    [anon_sym_localparam] = ACTIONS(5182),
    [anon_sym_parameter] = ACTIONS(5182),
    [anon_sym_var] = ACTIONS(5182),
    [anon_sym_import] = ACTIONS(5182),
    [anon_sym_export] = ACTIONS(5182),
    [anon_sym_genvar] = ACTIONS(5182),
    [anon_sym_interconnect] = ACTIONS(5182),
    [anon_sym_typedef] = ACTIONS(5182),
    [anon_sym_enum] = ACTIONS(5182),
    [anon_sym_struct] = ACTIONS(5182),
    [anon_sym_union] = ACTIONS(5182),
    [anon_sym_nettype] = ACTIONS(5182),
    [anon_sym_automatic] = ACTIONS(5182),
    [anon_sym_string] = ACTIONS(5182),
    [anon_sym_chandle] = ACTIONS(5182),
    [anon_sym_event] = ACTIONS(5182),
    [anon_sym_byte] = ACTIONS(5182),
    [anon_sym_shortint] = ACTIONS(5182),
    [anon_sym_int] = ACTIONS(5182),
    [anon_sym_longint] = ACTIONS(5182),
    [anon_sym_integer] = ACTIONS(5182),
    [anon_sym_time] = ACTIONS(5182),
    [anon_sym_bit] = ACTIONS(5182),
    [anon_sym_logic] = ACTIONS(5182),
    [anon_sym_reg] = ACTIONS(5182),
    [anon_sym_shortreal] = ACTIONS(5182),
    [anon_sym_real] = ACTIONS(5182),
    [anon_sym_realtime] = ACTIONS(5182),
    [anon_sym_supply0] = ACTIONS(5182),
    [anon_sym_supply1] = ACTIONS(5182),
    [anon_sym_signed] = ACTIONS(5182),
    [anon_sym_unsigned] = ACTIONS(5182),
    [anon_sym_task] = ACTIONS(5182),
    [anon_sym_assert] = ACTIONS(5182),
    [anon_sym_property] = ACTIONS(5182),
    [anon_sym_assume] = ACTIONS(5182),
    [anon_sym_cover] = ACTIONS(5182),
    [anon_sym_sequence] = ACTIONS(5182),
    [anon_sym_restrict] = ACTIONS(5182),
    [anon_sym_not] = ACTIONS(5182),
    [anon_sym_or] = ACTIONS(5182),
    [anon_sym_and] = ACTIONS(5182),
    [anon_sym_case] = ACTIONS(5182),
    [anon_sym_always] = ACTIONS(5182),
    [anon_sym_covergroup] = ACTIONS(5182),
    [anon_sym_let] = ACTIONS(5182),
    [anon_sym_pulldown] = ACTIONS(5182),
    [anon_sym_pullup] = ACTIONS(5182),
    [anon_sym_cmos] = ACTIONS(5182),
    [anon_sym_rcmos] = ACTIONS(5182),
    [anon_sym_bufif0] = ACTIONS(5182),
    [anon_sym_bufif1] = ACTIONS(5182),
    [anon_sym_notif0] = ACTIONS(5182),
    [anon_sym_notif1] = ACTIONS(5182),
    [anon_sym_nmos] = ACTIONS(5182),
    [anon_sym_pmos] = ACTIONS(5182),
    [anon_sym_rnmos] = ACTIONS(5182),
    [anon_sym_rpmos] = ACTIONS(5182),
    [anon_sym_nand] = ACTIONS(5182),
    [anon_sym_nor] = ACTIONS(5182),
    [anon_sym_xor] = ACTIONS(5182),
    [anon_sym_xnor] = ACTIONS(5182),
    [anon_sym_buf] = ACTIONS(5182),
    [anon_sym_tranif0] = ACTIONS(5182),
    [anon_sym_tranif1] = ACTIONS(5182),
    [anon_sym_rtranif1] = ACTIONS(5182),
    [anon_sym_rtranif0] = ACTIONS(5182),
    [anon_sym_tran] = ACTIONS(5182),
    [anon_sym_rtran] = ACTIONS(5182),
    [anon_sym_generate] = ACTIONS(5182),
    [anon_sym_endgenerate] = ACTIONS(5182),
    [anon_sym_for] = ACTIONS(5182),
    [anon_sym_initial] = ACTIONS(5182),
    [anon_sym_assign] = ACTIONS(5182),
    [anon_sym_alias] = ACTIONS(5182),
    [anon_sym_always_comb] = ACTIONS(5182),
    [anon_sym_always_latch] = ACTIONS(5182),
    [anon_sym_always_ff] = ACTIONS(5182),
    [anon_sym_final] = ACTIONS(5182),
    [anon_sym_global] = ACTIONS(5182),
    [anon_sym_LPAREN_STAR] = ACTIONS(5180),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5180),
    [anon_sym_DOLLARunit] = ACTIONS(5180),
  },
  [4846] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_rand] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_endgenerate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [4847] = {
    [sym_simple_identifier] = ACTIONS(6137),
    [anon_sym_wire] = ACTIONS(6137),
    [anon_sym_tri] = ACTIONS(6137),
    [anon_sym_tri0] = ACTIONS(6137),
    [anon_sym_tri1] = ACTIONS(6137),
    [anon_sym_wand] = ACTIONS(6137),
    [anon_sym_triand] = ACTIONS(6137),
    [anon_sym_wor] = ACTIONS(6137),
    [anon_sym_trior] = ACTIONS(6137),
    [anon_sym_trireg] = ACTIONS(6137),
    [anon_sym_uwire] = ACTIONS(6137),
    [anon_sym_SEMI] = ACTIONS(6139),
    [anon_sym_extern] = ACTIONS(6137),
    [anon_sym_interface] = ACTIONS(6137),
    [anon_sym_checker] = ACTIONS(6137),
    [anon_sym_virtual] = ACTIONS(6137),
    [anon_sym_class] = ACTIONS(6137),
    [anon_sym_type] = ACTIONS(6137),
    [anon_sym_DOLLARfatal] = ACTIONS(6139),
    [anon_sym_DOLLARerror] = ACTIONS(6139),
    [anon_sym_DOLLARwarning] = ACTIONS(6139),
    [anon_sym_DOLLARinfo] = ACTIONS(6139),
    [anon_sym_default] = ACTIONS(6137),
    [anon_sym_clocking] = ACTIONS(6137),
    [anon_sym_defparam] = ACTIONS(6137),
    [anon_sym_bind] = ACTIONS(6137),
    [anon_sym_rand] = ACTIONS(6137),
    [anon_sym_const] = ACTIONS(6137),
    [anon_sym_function] = ACTIONS(6137),
    [anon_sym_static] = ACTIONS(6137),
    [anon_sym_constraint] = ACTIONS(6137),
    [anon_sym_if] = ACTIONS(6137),
    [anon_sym_else] = ACTIONS(6137),
    [anon_sym_LBRACK] = ACTIONS(6139),
    [anon_sym_localparam] = ACTIONS(6137),
    [anon_sym_parameter] = ACTIONS(6137),
    [anon_sym_var] = ACTIONS(6137),
    [anon_sym_import] = ACTIONS(6137),
    [anon_sym_export] = ACTIONS(6137),
    [anon_sym_genvar] = ACTIONS(6137),
    [anon_sym_interconnect] = ACTIONS(6137),
    [anon_sym_typedef] = ACTIONS(6137),
    [anon_sym_enum] = ACTIONS(6137),
    [anon_sym_struct] = ACTIONS(6137),
    [anon_sym_union] = ACTIONS(6137),
    [anon_sym_nettype] = ACTIONS(6137),
    [anon_sym_automatic] = ACTIONS(6137),
    [anon_sym_string] = ACTIONS(6137),
    [anon_sym_chandle] = ACTIONS(6137),
    [anon_sym_event] = ACTIONS(6137),
    [anon_sym_byte] = ACTIONS(6137),
    [anon_sym_shortint] = ACTIONS(6137),
    [anon_sym_int] = ACTIONS(6137),
    [anon_sym_longint] = ACTIONS(6137),
    [anon_sym_integer] = ACTIONS(6137),
    [anon_sym_time] = ACTIONS(6137),
    [anon_sym_bit] = ACTIONS(6137),
    [anon_sym_logic] = ACTIONS(6137),
    [anon_sym_reg] = ACTIONS(6137),
    [anon_sym_shortreal] = ACTIONS(6137),
    [anon_sym_real] = ACTIONS(6137),
    [anon_sym_realtime] = ACTIONS(6137),
    [anon_sym_supply0] = ACTIONS(6137),
    [anon_sym_supply1] = ACTIONS(6137),
    [anon_sym_signed] = ACTIONS(6137),
    [anon_sym_unsigned] = ACTIONS(6137),
    [anon_sym_task] = ACTIONS(6137),
    [anon_sym_assert] = ACTIONS(6137),
    [anon_sym_property] = ACTIONS(6137),
    [anon_sym_assume] = ACTIONS(6137),
    [anon_sym_cover] = ACTIONS(6137),
    [anon_sym_sequence] = ACTIONS(6137),
    [anon_sym_restrict] = ACTIONS(6137),
    [anon_sym_not] = ACTIONS(6137),
    [anon_sym_or] = ACTIONS(6137),
    [anon_sym_and] = ACTIONS(6137),
    [anon_sym_case] = ACTIONS(6137),
    [anon_sym_always] = ACTIONS(6137),
    [anon_sym_covergroup] = ACTIONS(6137),
    [anon_sym_end] = ACTIONS(6137),
    [anon_sym_let] = ACTIONS(6137),
    [anon_sym_pulldown] = ACTIONS(6137),
    [anon_sym_pullup] = ACTIONS(6137),
    [anon_sym_cmos] = ACTIONS(6137),
    [anon_sym_rcmos] = ACTIONS(6137),
    [anon_sym_bufif0] = ACTIONS(6137),
    [anon_sym_bufif1] = ACTIONS(6137),
    [anon_sym_notif0] = ACTIONS(6137),
    [anon_sym_notif1] = ACTIONS(6137),
    [anon_sym_nmos] = ACTIONS(6137),
    [anon_sym_pmos] = ACTIONS(6137),
    [anon_sym_rnmos] = ACTIONS(6137),
    [anon_sym_rpmos] = ACTIONS(6137),
    [anon_sym_nand] = ACTIONS(6137),
    [anon_sym_nor] = ACTIONS(6137),
    [anon_sym_xor] = ACTIONS(6137),
    [anon_sym_xnor] = ACTIONS(6137),
    [anon_sym_buf] = ACTIONS(6137),
    [anon_sym_tranif0] = ACTIONS(6137),
    [anon_sym_tranif1] = ACTIONS(6137),
    [anon_sym_rtranif1] = ACTIONS(6137),
    [anon_sym_rtranif0] = ACTIONS(6137),
    [anon_sym_tran] = ACTIONS(6137),
    [anon_sym_rtran] = ACTIONS(6137),
    [anon_sym_generate] = ACTIONS(6137),
    [anon_sym_for] = ACTIONS(6137),
    [anon_sym_initial] = ACTIONS(6137),
    [anon_sym_assign] = ACTIONS(6137),
    [anon_sym_alias] = ACTIONS(6137),
    [anon_sym_always_comb] = ACTIONS(6137),
    [anon_sym_always_latch] = ACTIONS(6137),
    [anon_sym_always_ff] = ACTIONS(6137),
    [anon_sym_final] = ACTIONS(6137),
    [anon_sym_global] = ACTIONS(6137),
    [anon_sym_LPAREN_STAR] = ACTIONS(6139),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6139),
    [anon_sym_DOLLARunit] = ACTIONS(6139),
  },
  [4848] = {
    [sym_simple_identifier] = ACTIONS(6581),
    [anon_sym_wire] = ACTIONS(6581),
    [anon_sym_tri] = ACTIONS(6581),
    [anon_sym_tri0] = ACTIONS(6581),
    [anon_sym_tri1] = ACTIONS(6581),
    [anon_sym_wand] = ACTIONS(6581),
    [anon_sym_triand] = ACTIONS(6581),
    [anon_sym_wor] = ACTIONS(6581),
    [anon_sym_trior] = ACTIONS(6581),
    [anon_sym_trireg] = ACTIONS(6581),
    [anon_sym_uwire] = ACTIONS(6581),
    [anon_sym_SEMI] = ACTIONS(6583),
    [anon_sym_extern] = ACTIONS(6581),
    [anon_sym_interface] = ACTIONS(6581),
    [anon_sym_checker] = ACTIONS(6581),
    [anon_sym_virtual] = ACTIONS(6581),
    [anon_sym_class] = ACTIONS(6581),
    [anon_sym_type] = ACTIONS(6581),
    [anon_sym_DOLLARfatal] = ACTIONS(6583),
    [anon_sym_DOLLARerror] = ACTIONS(6583),
    [anon_sym_DOLLARwarning] = ACTIONS(6583),
    [anon_sym_DOLLARinfo] = ACTIONS(6583),
    [anon_sym_default] = ACTIONS(6581),
    [anon_sym_clocking] = ACTIONS(6581),
    [anon_sym_defparam] = ACTIONS(6581),
    [anon_sym_bind] = ACTIONS(6581),
    [anon_sym_rand] = ACTIONS(6581),
    [anon_sym_const] = ACTIONS(6581),
    [anon_sym_function] = ACTIONS(6581),
    [anon_sym_static] = ACTIONS(6581),
    [anon_sym_constraint] = ACTIONS(6581),
    [anon_sym_if] = ACTIONS(6581),
    [anon_sym_else] = ACTIONS(6581),
    [anon_sym_LBRACK] = ACTIONS(6583),
    [anon_sym_localparam] = ACTIONS(6581),
    [anon_sym_parameter] = ACTIONS(6581),
    [anon_sym_var] = ACTIONS(6581),
    [anon_sym_import] = ACTIONS(6581),
    [anon_sym_export] = ACTIONS(6581),
    [anon_sym_genvar] = ACTIONS(6581),
    [anon_sym_interconnect] = ACTIONS(6581),
    [anon_sym_typedef] = ACTIONS(6581),
    [anon_sym_enum] = ACTIONS(6581),
    [anon_sym_struct] = ACTIONS(6581),
    [anon_sym_union] = ACTIONS(6581),
    [anon_sym_nettype] = ACTIONS(6581),
    [anon_sym_automatic] = ACTIONS(6581),
    [anon_sym_string] = ACTIONS(6581),
    [anon_sym_chandle] = ACTIONS(6581),
    [anon_sym_event] = ACTIONS(6581),
    [anon_sym_byte] = ACTIONS(6581),
    [anon_sym_shortint] = ACTIONS(6581),
    [anon_sym_int] = ACTIONS(6581),
    [anon_sym_longint] = ACTIONS(6581),
    [anon_sym_integer] = ACTIONS(6581),
    [anon_sym_time] = ACTIONS(6581),
    [anon_sym_bit] = ACTIONS(6581),
    [anon_sym_logic] = ACTIONS(6581),
    [anon_sym_reg] = ACTIONS(6581),
    [anon_sym_shortreal] = ACTIONS(6581),
    [anon_sym_real] = ACTIONS(6581),
    [anon_sym_realtime] = ACTIONS(6581),
    [anon_sym_supply0] = ACTIONS(6581),
    [anon_sym_supply1] = ACTIONS(6581),
    [anon_sym_signed] = ACTIONS(6581),
    [anon_sym_unsigned] = ACTIONS(6581),
    [anon_sym_task] = ACTIONS(6581),
    [anon_sym_assert] = ACTIONS(6581),
    [anon_sym_property] = ACTIONS(6581),
    [anon_sym_assume] = ACTIONS(6581),
    [anon_sym_cover] = ACTIONS(6581),
    [anon_sym_sequence] = ACTIONS(6581),
    [anon_sym_restrict] = ACTIONS(6581),
    [anon_sym_not] = ACTIONS(6581),
    [anon_sym_or] = ACTIONS(6581),
    [anon_sym_and] = ACTIONS(6581),
    [anon_sym_case] = ACTIONS(6581),
    [anon_sym_always] = ACTIONS(6581),
    [anon_sym_covergroup] = ACTIONS(6581),
    [anon_sym_let] = ACTIONS(6581),
    [anon_sym_pulldown] = ACTIONS(6581),
    [anon_sym_pullup] = ACTIONS(6581),
    [anon_sym_cmos] = ACTIONS(6581),
    [anon_sym_rcmos] = ACTIONS(6581),
    [anon_sym_bufif0] = ACTIONS(6581),
    [anon_sym_bufif1] = ACTIONS(6581),
    [anon_sym_notif0] = ACTIONS(6581),
    [anon_sym_notif1] = ACTIONS(6581),
    [anon_sym_nmos] = ACTIONS(6581),
    [anon_sym_pmos] = ACTIONS(6581),
    [anon_sym_rnmos] = ACTIONS(6581),
    [anon_sym_rpmos] = ACTIONS(6581),
    [anon_sym_nand] = ACTIONS(6581),
    [anon_sym_nor] = ACTIONS(6581),
    [anon_sym_xor] = ACTIONS(6581),
    [anon_sym_xnor] = ACTIONS(6581),
    [anon_sym_buf] = ACTIONS(6581),
    [anon_sym_tranif0] = ACTIONS(6581),
    [anon_sym_tranif1] = ACTIONS(6581),
    [anon_sym_rtranif1] = ACTIONS(6581),
    [anon_sym_rtranif0] = ACTIONS(6581),
    [anon_sym_tran] = ACTIONS(6581),
    [anon_sym_rtran] = ACTIONS(6581),
    [anon_sym_generate] = ACTIONS(6581),
    [anon_sym_endgenerate] = ACTIONS(6581),
    [anon_sym_for] = ACTIONS(6581),
    [anon_sym_initial] = ACTIONS(6581),
    [anon_sym_assign] = ACTIONS(6581),
    [anon_sym_alias] = ACTIONS(6581),
    [anon_sym_always_comb] = ACTIONS(6581),
    [anon_sym_always_latch] = ACTIONS(6581),
    [anon_sym_always_ff] = ACTIONS(6581),
    [anon_sym_final] = ACTIONS(6581),
    [anon_sym_global] = ACTIONS(6581),
    [anon_sym_LPAREN_STAR] = ACTIONS(6583),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6583),
    [anon_sym_DOLLARunit] = ACTIONS(6583),
  },
  [4849] = {
    [sym_simple_identifier] = ACTIONS(6141),
    [anon_sym_wire] = ACTIONS(6141),
    [anon_sym_tri] = ACTIONS(6141),
    [anon_sym_tri0] = ACTIONS(6141),
    [anon_sym_tri1] = ACTIONS(6141),
    [anon_sym_wand] = ACTIONS(6141),
    [anon_sym_triand] = ACTIONS(6141),
    [anon_sym_wor] = ACTIONS(6141),
    [anon_sym_trior] = ACTIONS(6141),
    [anon_sym_trireg] = ACTIONS(6141),
    [anon_sym_uwire] = ACTIONS(6141),
    [anon_sym_SEMI] = ACTIONS(6143),
    [anon_sym_extern] = ACTIONS(6141),
    [anon_sym_interface] = ACTIONS(6141),
    [anon_sym_checker] = ACTIONS(6141),
    [anon_sym_virtual] = ACTIONS(6141),
    [anon_sym_class] = ACTIONS(6141),
    [anon_sym_type] = ACTIONS(6141),
    [anon_sym_DOLLARfatal] = ACTIONS(6143),
    [anon_sym_DOLLARerror] = ACTIONS(6143),
    [anon_sym_DOLLARwarning] = ACTIONS(6143),
    [anon_sym_DOLLARinfo] = ACTIONS(6143),
    [anon_sym_default] = ACTIONS(6141),
    [anon_sym_clocking] = ACTIONS(6141),
    [anon_sym_defparam] = ACTIONS(6141),
    [anon_sym_bind] = ACTIONS(6141),
    [anon_sym_rand] = ACTIONS(6141),
    [anon_sym_const] = ACTIONS(6141),
    [anon_sym_function] = ACTIONS(6141),
    [anon_sym_static] = ACTIONS(6141),
    [anon_sym_constraint] = ACTIONS(6141),
    [anon_sym_if] = ACTIONS(6141),
    [anon_sym_else] = ACTIONS(6141),
    [anon_sym_LBRACK] = ACTIONS(6143),
    [anon_sym_localparam] = ACTIONS(6141),
    [anon_sym_parameter] = ACTIONS(6141),
    [anon_sym_var] = ACTIONS(6141),
    [anon_sym_import] = ACTIONS(6141),
    [anon_sym_export] = ACTIONS(6141),
    [anon_sym_genvar] = ACTIONS(6141),
    [anon_sym_interconnect] = ACTIONS(6141),
    [anon_sym_typedef] = ACTIONS(6141),
    [anon_sym_enum] = ACTIONS(6141),
    [anon_sym_struct] = ACTIONS(6141),
    [anon_sym_union] = ACTIONS(6141),
    [anon_sym_nettype] = ACTIONS(6141),
    [anon_sym_automatic] = ACTIONS(6141),
    [anon_sym_string] = ACTIONS(6141),
    [anon_sym_chandle] = ACTIONS(6141),
    [anon_sym_event] = ACTIONS(6141),
    [anon_sym_byte] = ACTIONS(6141),
    [anon_sym_shortint] = ACTIONS(6141),
    [anon_sym_int] = ACTIONS(6141),
    [anon_sym_longint] = ACTIONS(6141),
    [anon_sym_integer] = ACTIONS(6141),
    [anon_sym_time] = ACTIONS(6141),
    [anon_sym_bit] = ACTIONS(6141),
    [anon_sym_logic] = ACTIONS(6141),
    [anon_sym_reg] = ACTIONS(6141),
    [anon_sym_shortreal] = ACTIONS(6141),
    [anon_sym_real] = ACTIONS(6141),
    [anon_sym_realtime] = ACTIONS(6141),
    [anon_sym_supply0] = ACTIONS(6141),
    [anon_sym_supply1] = ACTIONS(6141),
    [anon_sym_signed] = ACTIONS(6141),
    [anon_sym_unsigned] = ACTIONS(6141),
    [anon_sym_task] = ACTIONS(6141),
    [anon_sym_assert] = ACTIONS(6141),
    [anon_sym_property] = ACTIONS(6141),
    [anon_sym_assume] = ACTIONS(6141),
    [anon_sym_cover] = ACTIONS(6141),
    [anon_sym_sequence] = ACTIONS(6141),
    [anon_sym_restrict] = ACTIONS(6141),
    [anon_sym_not] = ACTIONS(6141),
    [anon_sym_or] = ACTIONS(6141),
    [anon_sym_and] = ACTIONS(6141),
    [anon_sym_case] = ACTIONS(6141),
    [anon_sym_always] = ACTIONS(6141),
    [anon_sym_covergroup] = ACTIONS(6141),
    [anon_sym_end] = ACTIONS(6141),
    [anon_sym_let] = ACTIONS(6141),
    [anon_sym_pulldown] = ACTIONS(6141),
    [anon_sym_pullup] = ACTIONS(6141),
    [anon_sym_cmos] = ACTIONS(6141),
    [anon_sym_rcmos] = ACTIONS(6141),
    [anon_sym_bufif0] = ACTIONS(6141),
    [anon_sym_bufif1] = ACTIONS(6141),
    [anon_sym_notif0] = ACTIONS(6141),
    [anon_sym_notif1] = ACTIONS(6141),
    [anon_sym_nmos] = ACTIONS(6141),
    [anon_sym_pmos] = ACTIONS(6141),
    [anon_sym_rnmos] = ACTIONS(6141),
    [anon_sym_rpmos] = ACTIONS(6141),
    [anon_sym_nand] = ACTIONS(6141),
    [anon_sym_nor] = ACTIONS(6141),
    [anon_sym_xor] = ACTIONS(6141),
    [anon_sym_xnor] = ACTIONS(6141),
    [anon_sym_buf] = ACTIONS(6141),
    [anon_sym_tranif0] = ACTIONS(6141),
    [anon_sym_tranif1] = ACTIONS(6141),
    [anon_sym_rtranif1] = ACTIONS(6141),
    [anon_sym_rtranif0] = ACTIONS(6141),
    [anon_sym_tran] = ACTIONS(6141),
    [anon_sym_rtran] = ACTIONS(6141),
    [anon_sym_generate] = ACTIONS(6141),
    [anon_sym_for] = ACTIONS(6141),
    [anon_sym_initial] = ACTIONS(6141),
    [anon_sym_assign] = ACTIONS(6141),
    [anon_sym_alias] = ACTIONS(6141),
    [anon_sym_always_comb] = ACTIONS(6141),
    [anon_sym_always_latch] = ACTIONS(6141),
    [anon_sym_always_ff] = ACTIONS(6141),
    [anon_sym_final] = ACTIONS(6141),
    [anon_sym_global] = ACTIONS(6141),
    [anon_sym_LPAREN_STAR] = ACTIONS(6143),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6143),
    [anon_sym_DOLLARunit] = ACTIONS(6143),
  },
  [4850] = {
    [sym_simple_identifier] = ACTIONS(4732),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_rand] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_end] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [4851] = {
    [sym_simple_identifier] = ACTIONS(5694),
    [anon_sym_wire] = ACTIONS(5694),
    [anon_sym_tri] = ACTIONS(5694),
    [anon_sym_tri0] = ACTIONS(5694),
    [anon_sym_tri1] = ACTIONS(5694),
    [anon_sym_wand] = ACTIONS(5694),
    [anon_sym_triand] = ACTIONS(5694),
    [anon_sym_wor] = ACTIONS(5694),
    [anon_sym_trior] = ACTIONS(5694),
    [anon_sym_trireg] = ACTIONS(5694),
    [anon_sym_uwire] = ACTIONS(5694),
    [anon_sym_SEMI] = ACTIONS(5696),
    [anon_sym_extern] = ACTIONS(5694),
    [anon_sym_interface] = ACTIONS(5694),
    [anon_sym_checker] = ACTIONS(5694),
    [anon_sym_virtual] = ACTIONS(5694),
    [anon_sym_class] = ACTIONS(5694),
    [anon_sym_type] = ACTIONS(5694),
    [anon_sym_DOLLARfatal] = ACTIONS(5696),
    [anon_sym_DOLLARerror] = ACTIONS(5696),
    [anon_sym_DOLLARwarning] = ACTIONS(5696),
    [anon_sym_DOLLARinfo] = ACTIONS(5696),
    [anon_sym_default] = ACTIONS(5694),
    [anon_sym_clocking] = ACTIONS(5694),
    [anon_sym_defparam] = ACTIONS(5694),
    [anon_sym_bind] = ACTIONS(5694),
    [anon_sym_rand] = ACTIONS(5694),
    [anon_sym_const] = ACTIONS(5694),
    [anon_sym_function] = ACTIONS(5694),
    [anon_sym_static] = ACTIONS(5694),
    [anon_sym_constraint] = ACTIONS(5694),
    [anon_sym_if] = ACTIONS(5694),
    [anon_sym_else] = ACTIONS(5694),
    [anon_sym_LBRACK] = ACTIONS(5696),
    [anon_sym_localparam] = ACTIONS(5694),
    [anon_sym_parameter] = ACTIONS(5694),
    [anon_sym_var] = ACTIONS(5694),
    [anon_sym_import] = ACTIONS(5694),
    [anon_sym_export] = ACTIONS(5694),
    [anon_sym_genvar] = ACTIONS(5694),
    [anon_sym_interconnect] = ACTIONS(5694),
    [anon_sym_typedef] = ACTIONS(5694),
    [anon_sym_enum] = ACTIONS(5694),
    [anon_sym_struct] = ACTIONS(5694),
    [anon_sym_union] = ACTIONS(5694),
    [anon_sym_nettype] = ACTIONS(5694),
    [anon_sym_automatic] = ACTIONS(5694),
    [anon_sym_string] = ACTIONS(5694),
    [anon_sym_chandle] = ACTIONS(5694),
    [anon_sym_event] = ACTIONS(5694),
    [anon_sym_byte] = ACTIONS(5694),
    [anon_sym_shortint] = ACTIONS(5694),
    [anon_sym_int] = ACTIONS(5694),
    [anon_sym_longint] = ACTIONS(5694),
    [anon_sym_integer] = ACTIONS(5694),
    [anon_sym_time] = ACTIONS(5694),
    [anon_sym_bit] = ACTIONS(5694),
    [anon_sym_logic] = ACTIONS(5694),
    [anon_sym_reg] = ACTIONS(5694),
    [anon_sym_shortreal] = ACTIONS(5694),
    [anon_sym_real] = ACTIONS(5694),
    [anon_sym_realtime] = ACTIONS(5694),
    [anon_sym_supply0] = ACTIONS(5694),
    [anon_sym_supply1] = ACTIONS(5694),
    [anon_sym_signed] = ACTIONS(5694),
    [anon_sym_unsigned] = ACTIONS(5694),
    [anon_sym_task] = ACTIONS(5694),
    [anon_sym_assert] = ACTIONS(5694),
    [anon_sym_property] = ACTIONS(5694),
    [anon_sym_assume] = ACTIONS(5694),
    [anon_sym_cover] = ACTIONS(5694),
    [anon_sym_sequence] = ACTIONS(5694),
    [anon_sym_restrict] = ACTIONS(5694),
    [anon_sym_not] = ACTIONS(5694),
    [anon_sym_or] = ACTIONS(5694),
    [anon_sym_and] = ACTIONS(5694),
    [anon_sym_case] = ACTIONS(5694),
    [anon_sym_always] = ACTIONS(5694),
    [anon_sym_covergroup] = ACTIONS(5694),
    [anon_sym_let] = ACTIONS(5694),
    [anon_sym_pulldown] = ACTIONS(5694),
    [anon_sym_pullup] = ACTIONS(5694),
    [anon_sym_cmos] = ACTIONS(5694),
    [anon_sym_rcmos] = ACTIONS(5694),
    [anon_sym_bufif0] = ACTIONS(5694),
    [anon_sym_bufif1] = ACTIONS(5694),
    [anon_sym_notif0] = ACTIONS(5694),
    [anon_sym_notif1] = ACTIONS(5694),
    [anon_sym_nmos] = ACTIONS(5694),
    [anon_sym_pmos] = ACTIONS(5694),
    [anon_sym_rnmos] = ACTIONS(5694),
    [anon_sym_rpmos] = ACTIONS(5694),
    [anon_sym_nand] = ACTIONS(5694),
    [anon_sym_nor] = ACTIONS(5694),
    [anon_sym_xor] = ACTIONS(5694),
    [anon_sym_xnor] = ACTIONS(5694),
    [anon_sym_buf] = ACTIONS(5694),
    [anon_sym_tranif0] = ACTIONS(5694),
    [anon_sym_tranif1] = ACTIONS(5694),
    [anon_sym_rtranif1] = ACTIONS(5694),
    [anon_sym_rtranif0] = ACTIONS(5694),
    [anon_sym_tran] = ACTIONS(5694),
    [anon_sym_rtran] = ACTIONS(5694),
    [anon_sym_generate] = ACTIONS(5694),
    [anon_sym_endgenerate] = ACTIONS(5694),
    [anon_sym_for] = ACTIONS(5694),
    [anon_sym_initial] = ACTIONS(5694),
    [anon_sym_assign] = ACTIONS(5694),
    [anon_sym_alias] = ACTIONS(5694),
    [anon_sym_always_comb] = ACTIONS(5694),
    [anon_sym_always_latch] = ACTIONS(5694),
    [anon_sym_always_ff] = ACTIONS(5694),
    [anon_sym_final] = ACTIONS(5694),
    [anon_sym_global] = ACTIONS(5694),
    [anon_sym_LPAREN_STAR] = ACTIONS(5696),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5696),
    [anon_sym_DOLLARunit] = ACTIONS(5696),
  },
  [4852] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_rand] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_end] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [4853] = {
    [sym_simple_identifier] = ACTIONS(5262),
    [anon_sym_wire] = ACTIONS(5262),
    [anon_sym_tri] = ACTIONS(5262),
    [anon_sym_tri0] = ACTIONS(5262),
    [anon_sym_tri1] = ACTIONS(5262),
    [anon_sym_wand] = ACTIONS(5262),
    [anon_sym_triand] = ACTIONS(5262),
    [anon_sym_wor] = ACTIONS(5262),
    [anon_sym_trior] = ACTIONS(5262),
    [anon_sym_trireg] = ACTIONS(5262),
    [anon_sym_uwire] = ACTIONS(5262),
    [anon_sym_SEMI] = ACTIONS(5260),
    [anon_sym_extern] = ACTIONS(5262),
    [anon_sym_interface] = ACTIONS(5262),
    [anon_sym_checker] = ACTIONS(5262),
    [anon_sym_virtual] = ACTIONS(5262),
    [anon_sym_class] = ACTIONS(5262),
    [anon_sym_type] = ACTIONS(5262),
    [anon_sym_DOLLARfatal] = ACTIONS(5260),
    [anon_sym_DOLLARerror] = ACTIONS(5260),
    [anon_sym_DOLLARwarning] = ACTIONS(5260),
    [anon_sym_DOLLARinfo] = ACTIONS(5260),
    [anon_sym_default] = ACTIONS(5262),
    [anon_sym_clocking] = ACTIONS(5262),
    [anon_sym_defparam] = ACTIONS(5262),
    [anon_sym_bind] = ACTIONS(5262),
    [anon_sym_rand] = ACTIONS(5262),
    [anon_sym_const] = ACTIONS(5262),
    [anon_sym_function] = ACTIONS(5262),
    [anon_sym_static] = ACTIONS(5262),
    [anon_sym_constraint] = ACTIONS(5262),
    [anon_sym_if] = ACTIONS(5262),
    [anon_sym_else] = ACTIONS(5262),
    [anon_sym_LBRACK] = ACTIONS(5260),
    [anon_sym_localparam] = ACTIONS(5262),
    [anon_sym_parameter] = ACTIONS(5262),
    [anon_sym_var] = ACTIONS(5262),
    [anon_sym_import] = ACTIONS(5262),
    [anon_sym_export] = ACTIONS(5262),
    [anon_sym_genvar] = ACTIONS(5262),
    [anon_sym_interconnect] = ACTIONS(5262),
    [anon_sym_typedef] = ACTIONS(5262),
    [anon_sym_enum] = ACTIONS(5262),
    [anon_sym_struct] = ACTIONS(5262),
    [anon_sym_union] = ACTIONS(5262),
    [anon_sym_nettype] = ACTIONS(5262),
    [anon_sym_automatic] = ACTIONS(5262),
    [anon_sym_string] = ACTIONS(5262),
    [anon_sym_chandle] = ACTIONS(5262),
    [anon_sym_event] = ACTIONS(5262),
    [anon_sym_byte] = ACTIONS(5262),
    [anon_sym_shortint] = ACTIONS(5262),
    [anon_sym_int] = ACTIONS(5262),
    [anon_sym_longint] = ACTIONS(5262),
    [anon_sym_integer] = ACTIONS(5262),
    [anon_sym_time] = ACTIONS(5262),
    [anon_sym_bit] = ACTIONS(5262),
    [anon_sym_logic] = ACTIONS(5262),
    [anon_sym_reg] = ACTIONS(5262),
    [anon_sym_shortreal] = ACTIONS(5262),
    [anon_sym_real] = ACTIONS(5262),
    [anon_sym_realtime] = ACTIONS(5262),
    [anon_sym_supply0] = ACTIONS(5262),
    [anon_sym_supply1] = ACTIONS(5262),
    [anon_sym_signed] = ACTIONS(5262),
    [anon_sym_unsigned] = ACTIONS(5262),
    [anon_sym_task] = ACTIONS(5262),
    [anon_sym_assert] = ACTIONS(5262),
    [anon_sym_property] = ACTIONS(5262),
    [anon_sym_assume] = ACTIONS(5262),
    [anon_sym_cover] = ACTIONS(5262),
    [anon_sym_sequence] = ACTIONS(5262),
    [anon_sym_restrict] = ACTIONS(5262),
    [anon_sym_not] = ACTIONS(5262),
    [anon_sym_or] = ACTIONS(5262),
    [anon_sym_and] = ACTIONS(5262),
    [anon_sym_case] = ACTIONS(5262),
    [anon_sym_always] = ACTIONS(5262),
    [anon_sym_covergroup] = ACTIONS(5262),
    [anon_sym_let] = ACTIONS(5262),
    [anon_sym_pulldown] = ACTIONS(5262),
    [anon_sym_pullup] = ACTIONS(5262),
    [anon_sym_cmos] = ACTIONS(5262),
    [anon_sym_rcmos] = ACTIONS(5262),
    [anon_sym_bufif0] = ACTIONS(5262),
    [anon_sym_bufif1] = ACTIONS(5262),
    [anon_sym_notif0] = ACTIONS(5262),
    [anon_sym_notif1] = ACTIONS(5262),
    [anon_sym_nmos] = ACTIONS(5262),
    [anon_sym_pmos] = ACTIONS(5262),
    [anon_sym_rnmos] = ACTIONS(5262),
    [anon_sym_rpmos] = ACTIONS(5262),
    [anon_sym_nand] = ACTIONS(5262),
    [anon_sym_nor] = ACTIONS(5262),
    [anon_sym_xor] = ACTIONS(5262),
    [anon_sym_xnor] = ACTIONS(5262),
    [anon_sym_buf] = ACTIONS(5262),
    [anon_sym_tranif0] = ACTIONS(5262),
    [anon_sym_tranif1] = ACTIONS(5262),
    [anon_sym_rtranif1] = ACTIONS(5262),
    [anon_sym_rtranif0] = ACTIONS(5262),
    [anon_sym_tran] = ACTIONS(5262),
    [anon_sym_rtran] = ACTIONS(5262),
    [anon_sym_generate] = ACTIONS(5262),
    [anon_sym_endgenerate] = ACTIONS(5262),
    [anon_sym_for] = ACTIONS(5262),
    [anon_sym_initial] = ACTIONS(5262),
    [anon_sym_assign] = ACTIONS(5262),
    [anon_sym_alias] = ACTIONS(5262),
    [anon_sym_always_comb] = ACTIONS(5262),
    [anon_sym_always_latch] = ACTIONS(5262),
    [anon_sym_always_ff] = ACTIONS(5262),
    [anon_sym_final] = ACTIONS(5262),
    [anon_sym_global] = ACTIONS(5262),
    [anon_sym_LPAREN_STAR] = ACTIONS(5260),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5260),
    [anon_sym_DOLLARunit] = ACTIONS(5260),
  },
  [4854] = {
    [sym_simple_identifier] = ACTIONS(4920),
    [anon_sym_wire] = ACTIONS(4920),
    [anon_sym_tri] = ACTIONS(4920),
    [anon_sym_tri0] = ACTIONS(4920),
    [anon_sym_tri1] = ACTIONS(4920),
    [anon_sym_wand] = ACTIONS(4920),
    [anon_sym_triand] = ACTIONS(4920),
    [anon_sym_wor] = ACTIONS(4920),
    [anon_sym_trior] = ACTIONS(4920),
    [anon_sym_trireg] = ACTIONS(4920),
    [anon_sym_uwire] = ACTIONS(4920),
    [anon_sym_SEMI] = ACTIONS(4918),
    [anon_sym_extern] = ACTIONS(4920),
    [anon_sym_interface] = ACTIONS(4920),
    [anon_sym_checker] = ACTIONS(4920),
    [anon_sym_virtual] = ACTIONS(4920),
    [anon_sym_class] = ACTIONS(4920),
    [anon_sym_type] = ACTIONS(4920),
    [anon_sym_DOLLARfatal] = ACTIONS(4918),
    [anon_sym_DOLLARerror] = ACTIONS(4918),
    [anon_sym_DOLLARwarning] = ACTIONS(4918),
    [anon_sym_DOLLARinfo] = ACTIONS(4918),
    [anon_sym_default] = ACTIONS(4920),
    [anon_sym_clocking] = ACTIONS(4920),
    [anon_sym_defparam] = ACTIONS(4920),
    [anon_sym_bind] = ACTIONS(4920),
    [anon_sym_rand] = ACTIONS(4920),
    [anon_sym_const] = ACTIONS(4920),
    [anon_sym_function] = ACTIONS(4920),
    [anon_sym_static] = ACTIONS(4920),
    [anon_sym_constraint] = ACTIONS(4920),
    [anon_sym_if] = ACTIONS(4920),
    [anon_sym_else] = ACTIONS(4920),
    [anon_sym_LBRACK] = ACTIONS(4918),
    [anon_sym_localparam] = ACTIONS(4920),
    [anon_sym_parameter] = ACTIONS(4920),
    [anon_sym_var] = ACTIONS(4920),
    [anon_sym_import] = ACTIONS(4920),
    [anon_sym_export] = ACTIONS(4920),
    [anon_sym_genvar] = ACTIONS(4920),
    [anon_sym_interconnect] = ACTIONS(4920),
    [anon_sym_typedef] = ACTIONS(4920),
    [anon_sym_enum] = ACTIONS(4920),
    [anon_sym_struct] = ACTIONS(4920),
    [anon_sym_union] = ACTIONS(4920),
    [anon_sym_nettype] = ACTIONS(4920),
    [anon_sym_automatic] = ACTIONS(4920),
    [anon_sym_string] = ACTIONS(4920),
    [anon_sym_chandle] = ACTIONS(4920),
    [anon_sym_event] = ACTIONS(4920),
    [anon_sym_byte] = ACTIONS(4920),
    [anon_sym_shortint] = ACTIONS(4920),
    [anon_sym_int] = ACTIONS(4920),
    [anon_sym_longint] = ACTIONS(4920),
    [anon_sym_integer] = ACTIONS(4920),
    [anon_sym_time] = ACTIONS(4920),
    [anon_sym_bit] = ACTIONS(4920),
    [anon_sym_logic] = ACTIONS(4920),
    [anon_sym_reg] = ACTIONS(4920),
    [anon_sym_shortreal] = ACTIONS(4920),
    [anon_sym_real] = ACTIONS(4920),
    [anon_sym_realtime] = ACTIONS(4920),
    [anon_sym_supply0] = ACTIONS(4920),
    [anon_sym_supply1] = ACTIONS(4920),
    [anon_sym_signed] = ACTIONS(4920),
    [anon_sym_unsigned] = ACTIONS(4920),
    [anon_sym_task] = ACTIONS(4920),
    [anon_sym_assert] = ACTIONS(4920),
    [anon_sym_property] = ACTIONS(4920),
    [anon_sym_assume] = ACTIONS(4920),
    [anon_sym_cover] = ACTIONS(4920),
    [anon_sym_sequence] = ACTIONS(4920),
    [anon_sym_restrict] = ACTIONS(4920),
    [anon_sym_not] = ACTIONS(4920),
    [anon_sym_or] = ACTIONS(4920),
    [anon_sym_and] = ACTIONS(4920),
    [anon_sym_case] = ACTIONS(4920),
    [anon_sym_always] = ACTIONS(4920),
    [anon_sym_covergroup] = ACTIONS(4920),
    [anon_sym_end] = ACTIONS(4920),
    [anon_sym_let] = ACTIONS(4920),
    [anon_sym_pulldown] = ACTIONS(4920),
    [anon_sym_pullup] = ACTIONS(4920),
    [anon_sym_cmos] = ACTIONS(4920),
    [anon_sym_rcmos] = ACTIONS(4920),
    [anon_sym_bufif0] = ACTIONS(4920),
    [anon_sym_bufif1] = ACTIONS(4920),
    [anon_sym_notif0] = ACTIONS(4920),
    [anon_sym_notif1] = ACTIONS(4920),
    [anon_sym_nmos] = ACTIONS(4920),
    [anon_sym_pmos] = ACTIONS(4920),
    [anon_sym_rnmos] = ACTIONS(4920),
    [anon_sym_rpmos] = ACTIONS(4920),
    [anon_sym_nand] = ACTIONS(4920),
    [anon_sym_nor] = ACTIONS(4920),
    [anon_sym_xor] = ACTIONS(4920),
    [anon_sym_xnor] = ACTIONS(4920),
    [anon_sym_buf] = ACTIONS(4920),
    [anon_sym_tranif0] = ACTIONS(4920),
    [anon_sym_tranif1] = ACTIONS(4920),
    [anon_sym_rtranif1] = ACTIONS(4920),
    [anon_sym_rtranif0] = ACTIONS(4920),
    [anon_sym_tran] = ACTIONS(4920),
    [anon_sym_rtran] = ACTIONS(4920),
    [anon_sym_generate] = ACTIONS(4920),
    [anon_sym_for] = ACTIONS(4920),
    [anon_sym_initial] = ACTIONS(4920),
    [anon_sym_assign] = ACTIONS(4920),
    [anon_sym_alias] = ACTIONS(4920),
    [anon_sym_always_comb] = ACTIONS(4920),
    [anon_sym_always_latch] = ACTIONS(4920),
    [anon_sym_always_ff] = ACTIONS(4920),
    [anon_sym_final] = ACTIONS(4920),
    [anon_sym_global] = ACTIONS(4920),
    [anon_sym_LPAREN_STAR] = ACTIONS(4918),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4918),
    [anon_sym_DOLLARunit] = ACTIONS(4918),
  },
  [4855] = {
    [sym_simple_identifier] = ACTIONS(5266),
    [anon_sym_wire] = ACTIONS(5266),
    [anon_sym_tri] = ACTIONS(5266),
    [anon_sym_tri0] = ACTIONS(5266),
    [anon_sym_tri1] = ACTIONS(5266),
    [anon_sym_wand] = ACTIONS(5266),
    [anon_sym_triand] = ACTIONS(5266),
    [anon_sym_wor] = ACTIONS(5266),
    [anon_sym_trior] = ACTIONS(5266),
    [anon_sym_trireg] = ACTIONS(5266),
    [anon_sym_uwire] = ACTIONS(5266),
    [anon_sym_SEMI] = ACTIONS(5264),
    [anon_sym_extern] = ACTIONS(5266),
    [anon_sym_interface] = ACTIONS(5266),
    [anon_sym_checker] = ACTIONS(5266),
    [anon_sym_virtual] = ACTIONS(5266),
    [anon_sym_class] = ACTIONS(5266),
    [anon_sym_type] = ACTIONS(5266),
    [anon_sym_DOLLARfatal] = ACTIONS(5264),
    [anon_sym_DOLLARerror] = ACTIONS(5264),
    [anon_sym_DOLLARwarning] = ACTIONS(5264),
    [anon_sym_DOLLARinfo] = ACTIONS(5264),
    [anon_sym_default] = ACTIONS(5266),
    [anon_sym_clocking] = ACTIONS(5266),
    [anon_sym_defparam] = ACTIONS(5266),
    [anon_sym_bind] = ACTIONS(5266),
    [anon_sym_rand] = ACTIONS(5266),
    [anon_sym_const] = ACTIONS(5266),
    [anon_sym_function] = ACTIONS(5266),
    [anon_sym_static] = ACTIONS(5266),
    [anon_sym_constraint] = ACTIONS(5266),
    [anon_sym_if] = ACTIONS(5266),
    [anon_sym_else] = ACTIONS(5266),
    [anon_sym_LBRACK] = ACTIONS(5264),
    [anon_sym_localparam] = ACTIONS(5266),
    [anon_sym_parameter] = ACTIONS(5266),
    [anon_sym_var] = ACTIONS(5266),
    [anon_sym_import] = ACTIONS(5266),
    [anon_sym_export] = ACTIONS(5266),
    [anon_sym_genvar] = ACTIONS(5266),
    [anon_sym_interconnect] = ACTIONS(5266),
    [anon_sym_typedef] = ACTIONS(5266),
    [anon_sym_enum] = ACTIONS(5266),
    [anon_sym_struct] = ACTIONS(5266),
    [anon_sym_union] = ACTIONS(5266),
    [anon_sym_nettype] = ACTIONS(5266),
    [anon_sym_automatic] = ACTIONS(5266),
    [anon_sym_string] = ACTIONS(5266),
    [anon_sym_chandle] = ACTIONS(5266),
    [anon_sym_event] = ACTIONS(5266),
    [anon_sym_byte] = ACTIONS(5266),
    [anon_sym_shortint] = ACTIONS(5266),
    [anon_sym_int] = ACTIONS(5266),
    [anon_sym_longint] = ACTIONS(5266),
    [anon_sym_integer] = ACTIONS(5266),
    [anon_sym_time] = ACTIONS(5266),
    [anon_sym_bit] = ACTIONS(5266),
    [anon_sym_logic] = ACTIONS(5266),
    [anon_sym_reg] = ACTIONS(5266),
    [anon_sym_shortreal] = ACTIONS(5266),
    [anon_sym_real] = ACTIONS(5266),
    [anon_sym_realtime] = ACTIONS(5266),
    [anon_sym_supply0] = ACTIONS(5266),
    [anon_sym_supply1] = ACTIONS(5266),
    [anon_sym_signed] = ACTIONS(5266),
    [anon_sym_unsigned] = ACTIONS(5266),
    [anon_sym_task] = ACTIONS(5266),
    [anon_sym_assert] = ACTIONS(5266),
    [anon_sym_property] = ACTIONS(5266),
    [anon_sym_assume] = ACTIONS(5266),
    [anon_sym_cover] = ACTIONS(5266),
    [anon_sym_sequence] = ACTIONS(5266),
    [anon_sym_restrict] = ACTIONS(5266),
    [anon_sym_not] = ACTIONS(5266),
    [anon_sym_or] = ACTIONS(5266),
    [anon_sym_and] = ACTIONS(5266),
    [anon_sym_case] = ACTIONS(5266),
    [anon_sym_always] = ACTIONS(5266),
    [anon_sym_covergroup] = ACTIONS(5266),
    [anon_sym_let] = ACTIONS(5266),
    [anon_sym_pulldown] = ACTIONS(5266),
    [anon_sym_pullup] = ACTIONS(5266),
    [anon_sym_cmos] = ACTIONS(5266),
    [anon_sym_rcmos] = ACTIONS(5266),
    [anon_sym_bufif0] = ACTIONS(5266),
    [anon_sym_bufif1] = ACTIONS(5266),
    [anon_sym_notif0] = ACTIONS(5266),
    [anon_sym_notif1] = ACTIONS(5266),
    [anon_sym_nmos] = ACTIONS(5266),
    [anon_sym_pmos] = ACTIONS(5266),
    [anon_sym_rnmos] = ACTIONS(5266),
    [anon_sym_rpmos] = ACTIONS(5266),
    [anon_sym_nand] = ACTIONS(5266),
    [anon_sym_nor] = ACTIONS(5266),
    [anon_sym_xor] = ACTIONS(5266),
    [anon_sym_xnor] = ACTIONS(5266),
    [anon_sym_buf] = ACTIONS(5266),
    [anon_sym_tranif0] = ACTIONS(5266),
    [anon_sym_tranif1] = ACTIONS(5266),
    [anon_sym_rtranif1] = ACTIONS(5266),
    [anon_sym_rtranif0] = ACTIONS(5266),
    [anon_sym_tran] = ACTIONS(5266),
    [anon_sym_rtran] = ACTIONS(5266),
    [anon_sym_generate] = ACTIONS(5266),
    [anon_sym_endgenerate] = ACTIONS(5266),
    [anon_sym_for] = ACTIONS(5266),
    [anon_sym_initial] = ACTIONS(5266),
    [anon_sym_assign] = ACTIONS(5266),
    [anon_sym_alias] = ACTIONS(5266),
    [anon_sym_always_comb] = ACTIONS(5266),
    [anon_sym_always_latch] = ACTIONS(5266),
    [anon_sym_always_ff] = ACTIONS(5266),
    [anon_sym_final] = ACTIONS(5266),
    [anon_sym_global] = ACTIONS(5266),
    [anon_sym_LPAREN_STAR] = ACTIONS(5264),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5264),
    [anon_sym_DOLLARunit] = ACTIONS(5264),
  },
  [4856] = {
    [sym_simple_identifier] = ACTIONS(4138),
    [anon_sym_wire] = ACTIONS(4138),
    [anon_sym_tri] = ACTIONS(4138),
    [anon_sym_tri0] = ACTIONS(4138),
    [anon_sym_tri1] = ACTIONS(4138),
    [anon_sym_wand] = ACTIONS(4138),
    [anon_sym_triand] = ACTIONS(4138),
    [anon_sym_wor] = ACTIONS(4138),
    [anon_sym_trior] = ACTIONS(4138),
    [anon_sym_trireg] = ACTIONS(4138),
    [anon_sym_uwire] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_extern] = ACTIONS(4138),
    [anon_sym_interface] = ACTIONS(4138),
    [anon_sym_checker] = ACTIONS(4138),
    [anon_sym_virtual] = ACTIONS(4138),
    [anon_sym_class] = ACTIONS(4138),
    [anon_sym_type] = ACTIONS(4138),
    [anon_sym_DOLLARfatal] = ACTIONS(4136),
    [anon_sym_DOLLARerror] = ACTIONS(4136),
    [anon_sym_DOLLARwarning] = ACTIONS(4136),
    [anon_sym_DOLLARinfo] = ACTIONS(4136),
    [anon_sym_default] = ACTIONS(4138),
    [anon_sym_clocking] = ACTIONS(4138),
    [anon_sym_defparam] = ACTIONS(4138),
    [anon_sym_bind] = ACTIONS(4138),
    [anon_sym_rand] = ACTIONS(4138),
    [anon_sym_const] = ACTIONS(4138),
    [anon_sym_function] = ACTIONS(4138),
    [anon_sym_static] = ACTIONS(4138),
    [anon_sym_constraint] = ACTIONS(4138),
    [anon_sym_if] = ACTIONS(4138),
    [anon_sym_else] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_localparam] = ACTIONS(4138),
    [anon_sym_parameter] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_import] = ACTIONS(4138),
    [anon_sym_export] = ACTIONS(4138),
    [anon_sym_genvar] = ACTIONS(4138),
    [anon_sym_interconnect] = ACTIONS(4138),
    [anon_sym_typedef] = ACTIONS(4138),
    [anon_sym_enum] = ACTIONS(4138),
    [anon_sym_struct] = ACTIONS(4138),
    [anon_sym_union] = ACTIONS(4138),
    [anon_sym_nettype] = ACTIONS(4138),
    [anon_sym_automatic] = ACTIONS(4138),
    [anon_sym_string] = ACTIONS(4138),
    [anon_sym_chandle] = ACTIONS(4138),
    [anon_sym_event] = ACTIONS(4138),
    [anon_sym_byte] = ACTIONS(4138),
    [anon_sym_shortint] = ACTIONS(4138),
    [anon_sym_int] = ACTIONS(4138),
    [anon_sym_longint] = ACTIONS(4138),
    [anon_sym_integer] = ACTIONS(4138),
    [anon_sym_time] = ACTIONS(4138),
    [anon_sym_bit] = ACTIONS(4138),
    [anon_sym_logic] = ACTIONS(4138),
    [anon_sym_reg] = ACTIONS(4138),
    [anon_sym_shortreal] = ACTIONS(4138),
    [anon_sym_real] = ACTIONS(4138),
    [anon_sym_realtime] = ACTIONS(4138),
    [anon_sym_supply0] = ACTIONS(4138),
    [anon_sym_supply1] = ACTIONS(4138),
    [anon_sym_signed] = ACTIONS(4138),
    [anon_sym_unsigned] = ACTIONS(4138),
    [anon_sym_task] = ACTIONS(4138),
    [anon_sym_assert] = ACTIONS(4138),
    [anon_sym_property] = ACTIONS(4138),
    [anon_sym_assume] = ACTIONS(4138),
    [anon_sym_cover] = ACTIONS(4138),
    [anon_sym_sequence] = ACTIONS(4138),
    [anon_sym_restrict] = ACTIONS(4138),
    [anon_sym_not] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_case] = ACTIONS(4138),
    [anon_sym_always] = ACTIONS(4138),
    [anon_sym_covergroup] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_pulldown] = ACTIONS(4138),
    [anon_sym_pullup] = ACTIONS(4138),
    [anon_sym_cmos] = ACTIONS(4138),
    [anon_sym_rcmos] = ACTIONS(4138),
    [anon_sym_bufif0] = ACTIONS(4138),
    [anon_sym_bufif1] = ACTIONS(4138),
    [anon_sym_notif0] = ACTIONS(4138),
    [anon_sym_notif1] = ACTIONS(4138),
    [anon_sym_nmos] = ACTIONS(4138),
    [anon_sym_pmos] = ACTIONS(4138),
    [anon_sym_rnmos] = ACTIONS(4138),
    [anon_sym_rpmos] = ACTIONS(4138),
    [anon_sym_nand] = ACTIONS(4138),
    [anon_sym_nor] = ACTIONS(4138),
    [anon_sym_xor] = ACTIONS(4138),
    [anon_sym_xnor] = ACTIONS(4138),
    [anon_sym_buf] = ACTIONS(4138),
    [anon_sym_tranif0] = ACTIONS(4138),
    [anon_sym_tranif1] = ACTIONS(4138),
    [anon_sym_rtranif1] = ACTIONS(4138),
    [anon_sym_rtranif0] = ACTIONS(4138),
    [anon_sym_tran] = ACTIONS(4138),
    [anon_sym_rtran] = ACTIONS(4138),
    [anon_sym_generate] = ACTIONS(4138),
    [anon_sym_endgenerate] = ACTIONS(4138),
    [anon_sym_for] = ACTIONS(4138),
    [anon_sym_initial] = ACTIONS(4138),
    [anon_sym_assign] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_always_comb] = ACTIONS(4138),
    [anon_sym_always_latch] = ACTIONS(4138),
    [anon_sym_always_ff] = ACTIONS(4138),
    [anon_sym_final] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LPAREN_STAR] = ACTIONS(4136),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4136),
    [anon_sym_DOLLARunit] = ACTIONS(4136),
  },
  [4857] = {
    [sym_simple_identifier] = ACTIONS(5270),
    [anon_sym_wire] = ACTIONS(5270),
    [anon_sym_tri] = ACTIONS(5270),
    [anon_sym_tri0] = ACTIONS(5270),
    [anon_sym_tri1] = ACTIONS(5270),
    [anon_sym_wand] = ACTIONS(5270),
    [anon_sym_triand] = ACTIONS(5270),
    [anon_sym_wor] = ACTIONS(5270),
    [anon_sym_trior] = ACTIONS(5270),
    [anon_sym_trireg] = ACTIONS(5270),
    [anon_sym_uwire] = ACTIONS(5270),
    [anon_sym_SEMI] = ACTIONS(5268),
    [anon_sym_extern] = ACTIONS(5270),
    [anon_sym_interface] = ACTIONS(5270),
    [anon_sym_checker] = ACTIONS(5270),
    [anon_sym_virtual] = ACTIONS(5270),
    [anon_sym_class] = ACTIONS(5270),
    [anon_sym_type] = ACTIONS(5270),
    [anon_sym_DOLLARfatal] = ACTIONS(5268),
    [anon_sym_DOLLARerror] = ACTIONS(5268),
    [anon_sym_DOLLARwarning] = ACTIONS(5268),
    [anon_sym_DOLLARinfo] = ACTIONS(5268),
    [anon_sym_default] = ACTIONS(5270),
    [anon_sym_clocking] = ACTIONS(5270),
    [anon_sym_defparam] = ACTIONS(5270),
    [anon_sym_bind] = ACTIONS(5270),
    [anon_sym_rand] = ACTIONS(5270),
    [anon_sym_const] = ACTIONS(5270),
    [anon_sym_function] = ACTIONS(5270),
    [anon_sym_static] = ACTIONS(5270),
    [anon_sym_constraint] = ACTIONS(5270),
    [anon_sym_if] = ACTIONS(5270),
    [anon_sym_else] = ACTIONS(5270),
    [anon_sym_LBRACK] = ACTIONS(5268),
    [anon_sym_localparam] = ACTIONS(5270),
    [anon_sym_parameter] = ACTIONS(5270),
    [anon_sym_var] = ACTIONS(5270),
    [anon_sym_import] = ACTIONS(5270),
    [anon_sym_export] = ACTIONS(5270),
    [anon_sym_genvar] = ACTIONS(5270),
    [anon_sym_interconnect] = ACTIONS(5270),
    [anon_sym_typedef] = ACTIONS(5270),
    [anon_sym_enum] = ACTIONS(5270),
    [anon_sym_struct] = ACTIONS(5270),
    [anon_sym_union] = ACTIONS(5270),
    [anon_sym_nettype] = ACTIONS(5270),
    [anon_sym_automatic] = ACTIONS(5270),
    [anon_sym_string] = ACTIONS(5270),
    [anon_sym_chandle] = ACTIONS(5270),
    [anon_sym_event] = ACTIONS(5270),
    [anon_sym_byte] = ACTIONS(5270),
    [anon_sym_shortint] = ACTIONS(5270),
    [anon_sym_int] = ACTIONS(5270),
    [anon_sym_longint] = ACTIONS(5270),
    [anon_sym_integer] = ACTIONS(5270),
    [anon_sym_time] = ACTIONS(5270),
    [anon_sym_bit] = ACTIONS(5270),
    [anon_sym_logic] = ACTIONS(5270),
    [anon_sym_reg] = ACTIONS(5270),
    [anon_sym_shortreal] = ACTIONS(5270),
    [anon_sym_real] = ACTIONS(5270),
    [anon_sym_realtime] = ACTIONS(5270),
    [anon_sym_supply0] = ACTIONS(5270),
    [anon_sym_supply1] = ACTIONS(5270),
    [anon_sym_signed] = ACTIONS(5270),
    [anon_sym_unsigned] = ACTIONS(5270),
    [anon_sym_task] = ACTIONS(5270),
    [anon_sym_assert] = ACTIONS(5270),
    [anon_sym_property] = ACTIONS(5270),
    [anon_sym_assume] = ACTIONS(5270),
    [anon_sym_cover] = ACTIONS(5270),
    [anon_sym_sequence] = ACTIONS(5270),
    [anon_sym_restrict] = ACTIONS(5270),
    [anon_sym_not] = ACTIONS(5270),
    [anon_sym_or] = ACTIONS(5270),
    [anon_sym_and] = ACTIONS(5270),
    [anon_sym_case] = ACTIONS(5270),
    [anon_sym_always] = ACTIONS(5270),
    [anon_sym_covergroup] = ACTIONS(5270),
    [anon_sym_let] = ACTIONS(5270),
    [anon_sym_pulldown] = ACTIONS(5270),
    [anon_sym_pullup] = ACTIONS(5270),
    [anon_sym_cmos] = ACTIONS(5270),
    [anon_sym_rcmos] = ACTIONS(5270),
    [anon_sym_bufif0] = ACTIONS(5270),
    [anon_sym_bufif1] = ACTIONS(5270),
    [anon_sym_notif0] = ACTIONS(5270),
    [anon_sym_notif1] = ACTIONS(5270),
    [anon_sym_nmos] = ACTIONS(5270),
    [anon_sym_pmos] = ACTIONS(5270),
    [anon_sym_rnmos] = ACTIONS(5270),
    [anon_sym_rpmos] = ACTIONS(5270),
    [anon_sym_nand] = ACTIONS(5270),
    [anon_sym_nor] = ACTIONS(5270),
    [anon_sym_xor] = ACTIONS(5270),
    [anon_sym_xnor] = ACTIONS(5270),
    [anon_sym_buf] = ACTIONS(5270),
    [anon_sym_tranif0] = ACTIONS(5270),
    [anon_sym_tranif1] = ACTIONS(5270),
    [anon_sym_rtranif1] = ACTIONS(5270),
    [anon_sym_rtranif0] = ACTIONS(5270),
    [anon_sym_tran] = ACTIONS(5270),
    [anon_sym_rtran] = ACTIONS(5270),
    [anon_sym_generate] = ACTIONS(5270),
    [anon_sym_endgenerate] = ACTIONS(5270),
    [anon_sym_for] = ACTIONS(5270),
    [anon_sym_initial] = ACTIONS(5270),
    [anon_sym_assign] = ACTIONS(5270),
    [anon_sym_alias] = ACTIONS(5270),
    [anon_sym_always_comb] = ACTIONS(5270),
    [anon_sym_always_latch] = ACTIONS(5270),
    [anon_sym_always_ff] = ACTIONS(5270),
    [anon_sym_final] = ACTIONS(5270),
    [anon_sym_global] = ACTIONS(5270),
    [anon_sym_LPAREN_STAR] = ACTIONS(5268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5268),
    [anon_sym_DOLLARunit] = ACTIONS(5268),
  },
  [4858] = {
    [sym_simple_identifier] = ACTIONS(6577),
    [anon_sym_wire] = ACTIONS(6577),
    [anon_sym_tri] = ACTIONS(6577),
    [anon_sym_tri0] = ACTIONS(6577),
    [anon_sym_tri1] = ACTIONS(6577),
    [anon_sym_wand] = ACTIONS(6577),
    [anon_sym_triand] = ACTIONS(6577),
    [anon_sym_wor] = ACTIONS(6577),
    [anon_sym_trior] = ACTIONS(6577),
    [anon_sym_trireg] = ACTIONS(6577),
    [anon_sym_uwire] = ACTIONS(6577),
    [anon_sym_SEMI] = ACTIONS(6579),
    [anon_sym_extern] = ACTIONS(6577),
    [anon_sym_interface] = ACTIONS(6577),
    [anon_sym_checker] = ACTIONS(6577),
    [anon_sym_virtual] = ACTIONS(6577),
    [anon_sym_class] = ACTIONS(6577),
    [anon_sym_type] = ACTIONS(6577),
    [anon_sym_DOLLARfatal] = ACTIONS(6579),
    [anon_sym_DOLLARerror] = ACTIONS(6579),
    [anon_sym_DOLLARwarning] = ACTIONS(6579),
    [anon_sym_DOLLARinfo] = ACTIONS(6579),
    [anon_sym_default] = ACTIONS(6577),
    [anon_sym_clocking] = ACTIONS(6577),
    [anon_sym_defparam] = ACTIONS(6577),
    [anon_sym_bind] = ACTIONS(6577),
    [anon_sym_rand] = ACTIONS(6577),
    [anon_sym_const] = ACTIONS(6577),
    [anon_sym_function] = ACTIONS(6577),
    [anon_sym_static] = ACTIONS(6577),
    [anon_sym_constraint] = ACTIONS(6577),
    [anon_sym_if] = ACTIONS(6577),
    [anon_sym_else] = ACTIONS(6577),
    [anon_sym_LBRACK] = ACTIONS(6579),
    [anon_sym_localparam] = ACTIONS(6577),
    [anon_sym_parameter] = ACTIONS(6577),
    [anon_sym_var] = ACTIONS(6577),
    [anon_sym_import] = ACTIONS(6577),
    [anon_sym_export] = ACTIONS(6577),
    [anon_sym_genvar] = ACTIONS(6577),
    [anon_sym_interconnect] = ACTIONS(6577),
    [anon_sym_typedef] = ACTIONS(6577),
    [anon_sym_enum] = ACTIONS(6577),
    [anon_sym_struct] = ACTIONS(6577),
    [anon_sym_union] = ACTIONS(6577),
    [anon_sym_nettype] = ACTIONS(6577),
    [anon_sym_automatic] = ACTIONS(6577),
    [anon_sym_string] = ACTIONS(6577),
    [anon_sym_chandle] = ACTIONS(6577),
    [anon_sym_event] = ACTIONS(6577),
    [anon_sym_byte] = ACTIONS(6577),
    [anon_sym_shortint] = ACTIONS(6577),
    [anon_sym_int] = ACTIONS(6577),
    [anon_sym_longint] = ACTIONS(6577),
    [anon_sym_integer] = ACTIONS(6577),
    [anon_sym_time] = ACTIONS(6577),
    [anon_sym_bit] = ACTIONS(6577),
    [anon_sym_logic] = ACTIONS(6577),
    [anon_sym_reg] = ACTIONS(6577),
    [anon_sym_shortreal] = ACTIONS(6577),
    [anon_sym_real] = ACTIONS(6577),
    [anon_sym_realtime] = ACTIONS(6577),
    [anon_sym_supply0] = ACTIONS(6577),
    [anon_sym_supply1] = ACTIONS(6577),
    [anon_sym_signed] = ACTIONS(6577),
    [anon_sym_unsigned] = ACTIONS(6577),
    [anon_sym_task] = ACTIONS(6577),
    [anon_sym_assert] = ACTIONS(6577),
    [anon_sym_property] = ACTIONS(6577),
    [anon_sym_assume] = ACTIONS(6577),
    [anon_sym_cover] = ACTIONS(6577),
    [anon_sym_sequence] = ACTIONS(6577),
    [anon_sym_restrict] = ACTIONS(6577),
    [anon_sym_not] = ACTIONS(6577),
    [anon_sym_or] = ACTIONS(6577),
    [anon_sym_and] = ACTIONS(6577),
    [anon_sym_case] = ACTIONS(6577),
    [anon_sym_always] = ACTIONS(6577),
    [anon_sym_covergroup] = ACTIONS(6577),
    [anon_sym_end] = ACTIONS(6577),
    [anon_sym_let] = ACTIONS(6577),
    [anon_sym_pulldown] = ACTIONS(6577),
    [anon_sym_pullup] = ACTIONS(6577),
    [anon_sym_cmos] = ACTIONS(6577),
    [anon_sym_rcmos] = ACTIONS(6577),
    [anon_sym_bufif0] = ACTIONS(6577),
    [anon_sym_bufif1] = ACTIONS(6577),
    [anon_sym_notif0] = ACTIONS(6577),
    [anon_sym_notif1] = ACTIONS(6577),
    [anon_sym_nmos] = ACTIONS(6577),
    [anon_sym_pmos] = ACTIONS(6577),
    [anon_sym_rnmos] = ACTIONS(6577),
    [anon_sym_rpmos] = ACTIONS(6577),
    [anon_sym_nand] = ACTIONS(6577),
    [anon_sym_nor] = ACTIONS(6577),
    [anon_sym_xor] = ACTIONS(6577),
    [anon_sym_xnor] = ACTIONS(6577),
    [anon_sym_buf] = ACTIONS(6577),
    [anon_sym_tranif0] = ACTIONS(6577),
    [anon_sym_tranif1] = ACTIONS(6577),
    [anon_sym_rtranif1] = ACTIONS(6577),
    [anon_sym_rtranif0] = ACTIONS(6577),
    [anon_sym_tran] = ACTIONS(6577),
    [anon_sym_rtran] = ACTIONS(6577),
    [anon_sym_generate] = ACTIONS(6577),
    [anon_sym_for] = ACTIONS(6577),
    [anon_sym_initial] = ACTIONS(6577),
    [anon_sym_assign] = ACTIONS(6577),
    [anon_sym_alias] = ACTIONS(6577),
    [anon_sym_always_comb] = ACTIONS(6577),
    [anon_sym_always_latch] = ACTIONS(6577),
    [anon_sym_always_ff] = ACTIONS(6577),
    [anon_sym_final] = ACTIONS(6577),
    [anon_sym_global] = ACTIONS(6577),
    [anon_sym_LPAREN_STAR] = ACTIONS(6579),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6579),
    [anon_sym_DOLLARunit] = ACTIONS(6579),
  },
  [4859] = {
    [sym_simple_identifier] = ACTIONS(6145),
    [anon_sym_wire] = ACTIONS(6145),
    [anon_sym_tri] = ACTIONS(6145),
    [anon_sym_tri0] = ACTIONS(6145),
    [anon_sym_tri1] = ACTIONS(6145),
    [anon_sym_wand] = ACTIONS(6145),
    [anon_sym_triand] = ACTIONS(6145),
    [anon_sym_wor] = ACTIONS(6145),
    [anon_sym_trior] = ACTIONS(6145),
    [anon_sym_trireg] = ACTIONS(6145),
    [anon_sym_uwire] = ACTIONS(6145),
    [anon_sym_SEMI] = ACTIONS(6147),
    [anon_sym_extern] = ACTIONS(6145),
    [anon_sym_interface] = ACTIONS(6145),
    [anon_sym_checker] = ACTIONS(6145),
    [anon_sym_virtual] = ACTIONS(6145),
    [anon_sym_class] = ACTIONS(6145),
    [anon_sym_type] = ACTIONS(6145),
    [anon_sym_DOLLARfatal] = ACTIONS(6147),
    [anon_sym_DOLLARerror] = ACTIONS(6147),
    [anon_sym_DOLLARwarning] = ACTIONS(6147),
    [anon_sym_DOLLARinfo] = ACTIONS(6147),
    [anon_sym_default] = ACTIONS(6145),
    [anon_sym_clocking] = ACTIONS(6145),
    [anon_sym_defparam] = ACTIONS(6145),
    [anon_sym_bind] = ACTIONS(6145),
    [anon_sym_rand] = ACTIONS(6145),
    [anon_sym_const] = ACTIONS(6145),
    [anon_sym_function] = ACTIONS(6145),
    [anon_sym_static] = ACTIONS(6145),
    [anon_sym_constraint] = ACTIONS(6145),
    [anon_sym_if] = ACTIONS(6145),
    [anon_sym_else] = ACTIONS(6145),
    [anon_sym_LBRACK] = ACTIONS(6147),
    [anon_sym_localparam] = ACTIONS(6145),
    [anon_sym_parameter] = ACTIONS(6145),
    [anon_sym_var] = ACTIONS(6145),
    [anon_sym_import] = ACTIONS(6145),
    [anon_sym_export] = ACTIONS(6145),
    [anon_sym_genvar] = ACTIONS(6145),
    [anon_sym_interconnect] = ACTIONS(6145),
    [anon_sym_typedef] = ACTIONS(6145),
    [anon_sym_enum] = ACTIONS(6145),
    [anon_sym_struct] = ACTIONS(6145),
    [anon_sym_union] = ACTIONS(6145),
    [anon_sym_nettype] = ACTIONS(6145),
    [anon_sym_automatic] = ACTIONS(6145),
    [anon_sym_string] = ACTIONS(6145),
    [anon_sym_chandle] = ACTIONS(6145),
    [anon_sym_event] = ACTIONS(6145),
    [anon_sym_byte] = ACTIONS(6145),
    [anon_sym_shortint] = ACTIONS(6145),
    [anon_sym_int] = ACTIONS(6145),
    [anon_sym_longint] = ACTIONS(6145),
    [anon_sym_integer] = ACTIONS(6145),
    [anon_sym_time] = ACTIONS(6145),
    [anon_sym_bit] = ACTIONS(6145),
    [anon_sym_logic] = ACTIONS(6145),
    [anon_sym_reg] = ACTIONS(6145),
    [anon_sym_shortreal] = ACTIONS(6145),
    [anon_sym_real] = ACTIONS(6145),
    [anon_sym_realtime] = ACTIONS(6145),
    [anon_sym_supply0] = ACTIONS(6145),
    [anon_sym_supply1] = ACTIONS(6145),
    [anon_sym_signed] = ACTIONS(6145),
    [anon_sym_unsigned] = ACTIONS(6145),
    [anon_sym_task] = ACTIONS(6145),
    [anon_sym_assert] = ACTIONS(6145),
    [anon_sym_property] = ACTIONS(6145),
    [anon_sym_assume] = ACTIONS(6145),
    [anon_sym_cover] = ACTIONS(6145),
    [anon_sym_sequence] = ACTIONS(6145),
    [anon_sym_restrict] = ACTIONS(6145),
    [anon_sym_not] = ACTIONS(6145),
    [anon_sym_or] = ACTIONS(6145),
    [anon_sym_and] = ACTIONS(6145),
    [anon_sym_case] = ACTIONS(6145),
    [anon_sym_always] = ACTIONS(6145),
    [anon_sym_covergroup] = ACTIONS(6145),
    [anon_sym_end] = ACTIONS(6145),
    [anon_sym_let] = ACTIONS(6145),
    [anon_sym_pulldown] = ACTIONS(6145),
    [anon_sym_pullup] = ACTIONS(6145),
    [anon_sym_cmos] = ACTIONS(6145),
    [anon_sym_rcmos] = ACTIONS(6145),
    [anon_sym_bufif0] = ACTIONS(6145),
    [anon_sym_bufif1] = ACTIONS(6145),
    [anon_sym_notif0] = ACTIONS(6145),
    [anon_sym_notif1] = ACTIONS(6145),
    [anon_sym_nmos] = ACTIONS(6145),
    [anon_sym_pmos] = ACTIONS(6145),
    [anon_sym_rnmos] = ACTIONS(6145),
    [anon_sym_rpmos] = ACTIONS(6145),
    [anon_sym_nand] = ACTIONS(6145),
    [anon_sym_nor] = ACTIONS(6145),
    [anon_sym_xor] = ACTIONS(6145),
    [anon_sym_xnor] = ACTIONS(6145),
    [anon_sym_buf] = ACTIONS(6145),
    [anon_sym_tranif0] = ACTIONS(6145),
    [anon_sym_tranif1] = ACTIONS(6145),
    [anon_sym_rtranif1] = ACTIONS(6145),
    [anon_sym_rtranif0] = ACTIONS(6145),
    [anon_sym_tran] = ACTIONS(6145),
    [anon_sym_rtran] = ACTIONS(6145),
    [anon_sym_generate] = ACTIONS(6145),
    [anon_sym_for] = ACTIONS(6145),
    [anon_sym_initial] = ACTIONS(6145),
    [anon_sym_assign] = ACTIONS(6145),
    [anon_sym_alias] = ACTIONS(6145),
    [anon_sym_always_comb] = ACTIONS(6145),
    [anon_sym_always_latch] = ACTIONS(6145),
    [anon_sym_always_ff] = ACTIONS(6145),
    [anon_sym_final] = ACTIONS(6145),
    [anon_sym_global] = ACTIONS(6145),
    [anon_sym_LPAREN_STAR] = ACTIONS(6147),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6147),
    [anon_sym_DOLLARunit] = ACTIONS(6147),
  },
  [4860] = {
    [sym_simple_identifier] = ACTIONS(6669),
    [anon_sym_wire] = ACTIONS(6669),
    [anon_sym_tri] = ACTIONS(6669),
    [anon_sym_tri0] = ACTIONS(6669),
    [anon_sym_tri1] = ACTIONS(6669),
    [anon_sym_wand] = ACTIONS(6669),
    [anon_sym_triand] = ACTIONS(6669),
    [anon_sym_wor] = ACTIONS(6669),
    [anon_sym_trior] = ACTIONS(6669),
    [anon_sym_trireg] = ACTIONS(6669),
    [anon_sym_uwire] = ACTIONS(6669),
    [anon_sym_SEMI] = ACTIONS(6671),
    [anon_sym_extern] = ACTIONS(6669),
    [anon_sym_interface] = ACTIONS(6669),
    [anon_sym_checker] = ACTIONS(6669),
    [anon_sym_virtual] = ACTIONS(6669),
    [anon_sym_class] = ACTIONS(6669),
    [anon_sym_type] = ACTIONS(6669),
    [anon_sym_DOLLARfatal] = ACTIONS(6671),
    [anon_sym_DOLLARerror] = ACTIONS(6671),
    [anon_sym_DOLLARwarning] = ACTIONS(6671),
    [anon_sym_DOLLARinfo] = ACTIONS(6671),
    [anon_sym_default] = ACTIONS(6669),
    [anon_sym_clocking] = ACTIONS(6669),
    [anon_sym_defparam] = ACTIONS(6669),
    [anon_sym_bind] = ACTIONS(6669),
    [anon_sym_rand] = ACTIONS(6669),
    [anon_sym_const] = ACTIONS(6669),
    [anon_sym_function] = ACTIONS(6669),
    [anon_sym_static] = ACTIONS(6669),
    [anon_sym_constraint] = ACTIONS(6669),
    [anon_sym_if] = ACTIONS(6669),
    [anon_sym_else] = ACTIONS(6669),
    [anon_sym_LBRACK] = ACTIONS(6671),
    [anon_sym_localparam] = ACTIONS(6669),
    [anon_sym_parameter] = ACTIONS(6669),
    [anon_sym_var] = ACTIONS(6669),
    [anon_sym_import] = ACTIONS(6669),
    [anon_sym_export] = ACTIONS(6669),
    [anon_sym_genvar] = ACTIONS(6669),
    [anon_sym_interconnect] = ACTIONS(6669),
    [anon_sym_typedef] = ACTIONS(6669),
    [anon_sym_enum] = ACTIONS(6669),
    [anon_sym_struct] = ACTIONS(6669),
    [anon_sym_union] = ACTIONS(6669),
    [anon_sym_nettype] = ACTIONS(6669),
    [anon_sym_automatic] = ACTIONS(6669),
    [anon_sym_string] = ACTIONS(6669),
    [anon_sym_chandle] = ACTIONS(6669),
    [anon_sym_event] = ACTIONS(6669),
    [anon_sym_byte] = ACTIONS(6669),
    [anon_sym_shortint] = ACTIONS(6669),
    [anon_sym_int] = ACTIONS(6669),
    [anon_sym_longint] = ACTIONS(6669),
    [anon_sym_integer] = ACTIONS(6669),
    [anon_sym_time] = ACTIONS(6669),
    [anon_sym_bit] = ACTIONS(6669),
    [anon_sym_logic] = ACTIONS(6669),
    [anon_sym_reg] = ACTIONS(6669),
    [anon_sym_shortreal] = ACTIONS(6669),
    [anon_sym_real] = ACTIONS(6669),
    [anon_sym_realtime] = ACTIONS(6669),
    [anon_sym_supply0] = ACTIONS(6669),
    [anon_sym_supply1] = ACTIONS(6669),
    [anon_sym_signed] = ACTIONS(6669),
    [anon_sym_unsigned] = ACTIONS(6669),
    [anon_sym_task] = ACTIONS(6669),
    [anon_sym_assert] = ACTIONS(6669),
    [anon_sym_property] = ACTIONS(6669),
    [anon_sym_assume] = ACTIONS(6669),
    [anon_sym_cover] = ACTIONS(6669),
    [anon_sym_sequence] = ACTIONS(6669),
    [anon_sym_restrict] = ACTIONS(6669),
    [anon_sym_not] = ACTIONS(6669),
    [anon_sym_or] = ACTIONS(6669),
    [anon_sym_and] = ACTIONS(6669),
    [anon_sym_case] = ACTIONS(6669),
    [anon_sym_always] = ACTIONS(6669),
    [anon_sym_covergroup] = ACTIONS(6669),
    [anon_sym_let] = ACTIONS(6669),
    [anon_sym_pulldown] = ACTIONS(6669),
    [anon_sym_pullup] = ACTIONS(6669),
    [anon_sym_cmos] = ACTIONS(6669),
    [anon_sym_rcmos] = ACTIONS(6669),
    [anon_sym_bufif0] = ACTIONS(6669),
    [anon_sym_bufif1] = ACTIONS(6669),
    [anon_sym_notif0] = ACTIONS(6669),
    [anon_sym_notif1] = ACTIONS(6669),
    [anon_sym_nmos] = ACTIONS(6669),
    [anon_sym_pmos] = ACTIONS(6669),
    [anon_sym_rnmos] = ACTIONS(6669),
    [anon_sym_rpmos] = ACTIONS(6669),
    [anon_sym_nand] = ACTIONS(6669),
    [anon_sym_nor] = ACTIONS(6669),
    [anon_sym_xor] = ACTIONS(6669),
    [anon_sym_xnor] = ACTIONS(6669),
    [anon_sym_buf] = ACTIONS(6669),
    [anon_sym_tranif0] = ACTIONS(6669),
    [anon_sym_tranif1] = ACTIONS(6669),
    [anon_sym_rtranif1] = ACTIONS(6669),
    [anon_sym_rtranif0] = ACTIONS(6669),
    [anon_sym_tran] = ACTIONS(6669),
    [anon_sym_rtran] = ACTIONS(6669),
    [anon_sym_generate] = ACTIONS(6669),
    [anon_sym_endgenerate] = ACTIONS(6669),
    [anon_sym_for] = ACTIONS(6669),
    [anon_sym_initial] = ACTIONS(6669),
    [anon_sym_assign] = ACTIONS(6669),
    [anon_sym_alias] = ACTIONS(6669),
    [anon_sym_always_comb] = ACTIONS(6669),
    [anon_sym_always_latch] = ACTIONS(6669),
    [anon_sym_always_ff] = ACTIONS(6669),
    [anon_sym_final] = ACTIONS(6669),
    [anon_sym_global] = ACTIONS(6669),
    [anon_sym_LPAREN_STAR] = ACTIONS(6671),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6671),
    [anon_sym_DOLLARunit] = ACTIONS(6671),
  },
  [4861] = {
    [sym_simple_identifier] = ACTIONS(4478),
    [anon_sym_wire] = ACTIONS(4478),
    [anon_sym_tri] = ACTIONS(4478),
    [anon_sym_tri0] = ACTIONS(4478),
    [anon_sym_tri1] = ACTIONS(4478),
    [anon_sym_wand] = ACTIONS(4478),
    [anon_sym_triand] = ACTIONS(4478),
    [anon_sym_wor] = ACTIONS(4478),
    [anon_sym_trior] = ACTIONS(4478),
    [anon_sym_trireg] = ACTIONS(4478),
    [anon_sym_uwire] = ACTIONS(4478),
    [anon_sym_SEMI] = ACTIONS(4476),
    [anon_sym_extern] = ACTIONS(4478),
    [anon_sym_interface] = ACTIONS(4478),
    [anon_sym_checker] = ACTIONS(4478),
    [anon_sym_virtual] = ACTIONS(4478),
    [anon_sym_class] = ACTIONS(4478),
    [anon_sym_type] = ACTIONS(4478),
    [anon_sym_DOLLARfatal] = ACTIONS(4476),
    [anon_sym_DOLLARerror] = ACTIONS(4476),
    [anon_sym_DOLLARwarning] = ACTIONS(4476),
    [anon_sym_DOLLARinfo] = ACTIONS(4476),
    [anon_sym_default] = ACTIONS(4478),
    [anon_sym_clocking] = ACTIONS(4478),
    [anon_sym_defparam] = ACTIONS(4478),
    [anon_sym_bind] = ACTIONS(4478),
    [anon_sym_rand] = ACTIONS(4478),
    [anon_sym_const] = ACTIONS(4478),
    [anon_sym_function] = ACTIONS(4478),
    [anon_sym_static] = ACTIONS(4478),
    [anon_sym_constraint] = ACTIONS(4478),
    [anon_sym_if] = ACTIONS(4478),
    [anon_sym_else] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4476),
    [anon_sym_localparam] = ACTIONS(4478),
    [anon_sym_parameter] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_import] = ACTIONS(4478),
    [anon_sym_export] = ACTIONS(4478),
    [anon_sym_genvar] = ACTIONS(4478),
    [anon_sym_interconnect] = ACTIONS(4478),
    [anon_sym_typedef] = ACTIONS(4478),
    [anon_sym_enum] = ACTIONS(4478),
    [anon_sym_struct] = ACTIONS(4478),
    [anon_sym_union] = ACTIONS(4478),
    [anon_sym_nettype] = ACTIONS(4478),
    [anon_sym_automatic] = ACTIONS(4478),
    [anon_sym_string] = ACTIONS(4478),
    [anon_sym_chandle] = ACTIONS(4478),
    [anon_sym_event] = ACTIONS(4478),
    [anon_sym_byte] = ACTIONS(4478),
    [anon_sym_shortint] = ACTIONS(4478),
    [anon_sym_int] = ACTIONS(4478),
    [anon_sym_longint] = ACTIONS(4478),
    [anon_sym_integer] = ACTIONS(4478),
    [anon_sym_time] = ACTIONS(4478),
    [anon_sym_bit] = ACTIONS(4478),
    [anon_sym_logic] = ACTIONS(4478),
    [anon_sym_reg] = ACTIONS(4478),
    [anon_sym_shortreal] = ACTIONS(4478),
    [anon_sym_real] = ACTIONS(4478),
    [anon_sym_realtime] = ACTIONS(4478),
    [anon_sym_supply0] = ACTIONS(4478),
    [anon_sym_supply1] = ACTIONS(4478),
    [anon_sym_signed] = ACTIONS(4478),
    [anon_sym_unsigned] = ACTIONS(4478),
    [anon_sym_task] = ACTIONS(4478),
    [anon_sym_assert] = ACTIONS(4478),
    [anon_sym_property] = ACTIONS(4478),
    [anon_sym_assume] = ACTIONS(4478),
    [anon_sym_cover] = ACTIONS(4478),
    [anon_sym_sequence] = ACTIONS(4478),
    [anon_sym_restrict] = ACTIONS(4478),
    [anon_sym_not] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_case] = ACTIONS(4478),
    [anon_sym_always] = ACTIONS(4478),
    [anon_sym_covergroup] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_pulldown] = ACTIONS(4478),
    [anon_sym_pullup] = ACTIONS(4478),
    [anon_sym_cmos] = ACTIONS(4478),
    [anon_sym_rcmos] = ACTIONS(4478),
    [anon_sym_bufif0] = ACTIONS(4478),
    [anon_sym_bufif1] = ACTIONS(4478),
    [anon_sym_notif0] = ACTIONS(4478),
    [anon_sym_notif1] = ACTIONS(4478),
    [anon_sym_nmos] = ACTIONS(4478),
    [anon_sym_pmos] = ACTIONS(4478),
    [anon_sym_rnmos] = ACTIONS(4478),
    [anon_sym_rpmos] = ACTIONS(4478),
    [anon_sym_nand] = ACTIONS(4478),
    [anon_sym_nor] = ACTIONS(4478),
    [anon_sym_xor] = ACTIONS(4478),
    [anon_sym_xnor] = ACTIONS(4478),
    [anon_sym_buf] = ACTIONS(4478),
    [anon_sym_tranif0] = ACTIONS(4478),
    [anon_sym_tranif1] = ACTIONS(4478),
    [anon_sym_rtranif1] = ACTIONS(4478),
    [anon_sym_rtranif0] = ACTIONS(4478),
    [anon_sym_tran] = ACTIONS(4478),
    [anon_sym_rtran] = ACTIONS(4478),
    [anon_sym_generate] = ACTIONS(4478),
    [anon_sym_endgenerate] = ACTIONS(4478),
    [anon_sym_for] = ACTIONS(4478),
    [anon_sym_initial] = ACTIONS(4478),
    [anon_sym_assign] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_always_comb] = ACTIONS(4478),
    [anon_sym_always_latch] = ACTIONS(4478),
    [anon_sym_always_ff] = ACTIONS(4478),
    [anon_sym_final] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LPAREN_STAR] = ACTIONS(4476),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4476),
    [anon_sym_DOLLARunit] = ACTIONS(4476),
  },
  [4862] = {
    [sym_simple_identifier] = ACTIONS(6601),
    [anon_sym_wire] = ACTIONS(6601),
    [anon_sym_tri] = ACTIONS(6601),
    [anon_sym_tri0] = ACTIONS(6601),
    [anon_sym_tri1] = ACTIONS(6601),
    [anon_sym_wand] = ACTIONS(6601),
    [anon_sym_triand] = ACTIONS(6601),
    [anon_sym_wor] = ACTIONS(6601),
    [anon_sym_trior] = ACTIONS(6601),
    [anon_sym_trireg] = ACTIONS(6601),
    [anon_sym_uwire] = ACTIONS(6601),
    [anon_sym_SEMI] = ACTIONS(6603),
    [anon_sym_extern] = ACTIONS(6601),
    [anon_sym_interface] = ACTIONS(6601),
    [anon_sym_checker] = ACTIONS(6601),
    [anon_sym_virtual] = ACTIONS(6601),
    [anon_sym_class] = ACTIONS(6601),
    [anon_sym_type] = ACTIONS(6601),
    [anon_sym_DOLLARfatal] = ACTIONS(6603),
    [anon_sym_DOLLARerror] = ACTIONS(6603),
    [anon_sym_DOLLARwarning] = ACTIONS(6603),
    [anon_sym_DOLLARinfo] = ACTIONS(6603),
    [anon_sym_default] = ACTIONS(6601),
    [anon_sym_clocking] = ACTIONS(6601),
    [anon_sym_defparam] = ACTIONS(6601),
    [anon_sym_bind] = ACTIONS(6601),
    [anon_sym_rand] = ACTIONS(6601),
    [anon_sym_const] = ACTIONS(6601),
    [anon_sym_function] = ACTIONS(6601),
    [anon_sym_static] = ACTIONS(6601),
    [anon_sym_constraint] = ACTIONS(6601),
    [anon_sym_if] = ACTIONS(6601),
    [anon_sym_else] = ACTIONS(6601),
    [anon_sym_LBRACK] = ACTIONS(6603),
    [anon_sym_localparam] = ACTIONS(6601),
    [anon_sym_parameter] = ACTIONS(6601),
    [anon_sym_var] = ACTIONS(6601),
    [anon_sym_import] = ACTIONS(6601),
    [anon_sym_export] = ACTIONS(6601),
    [anon_sym_genvar] = ACTIONS(6601),
    [anon_sym_interconnect] = ACTIONS(6601),
    [anon_sym_typedef] = ACTIONS(6601),
    [anon_sym_enum] = ACTIONS(6601),
    [anon_sym_struct] = ACTIONS(6601),
    [anon_sym_union] = ACTIONS(6601),
    [anon_sym_nettype] = ACTIONS(6601),
    [anon_sym_automatic] = ACTIONS(6601),
    [anon_sym_string] = ACTIONS(6601),
    [anon_sym_chandle] = ACTIONS(6601),
    [anon_sym_event] = ACTIONS(6601),
    [anon_sym_byte] = ACTIONS(6601),
    [anon_sym_shortint] = ACTIONS(6601),
    [anon_sym_int] = ACTIONS(6601),
    [anon_sym_longint] = ACTIONS(6601),
    [anon_sym_integer] = ACTIONS(6601),
    [anon_sym_time] = ACTIONS(6601),
    [anon_sym_bit] = ACTIONS(6601),
    [anon_sym_logic] = ACTIONS(6601),
    [anon_sym_reg] = ACTIONS(6601),
    [anon_sym_shortreal] = ACTIONS(6601),
    [anon_sym_real] = ACTIONS(6601),
    [anon_sym_realtime] = ACTIONS(6601),
    [anon_sym_supply0] = ACTIONS(6601),
    [anon_sym_supply1] = ACTIONS(6601),
    [anon_sym_signed] = ACTIONS(6601),
    [anon_sym_unsigned] = ACTIONS(6601),
    [anon_sym_task] = ACTIONS(6601),
    [anon_sym_assert] = ACTIONS(6601),
    [anon_sym_property] = ACTIONS(6601),
    [anon_sym_assume] = ACTIONS(6601),
    [anon_sym_cover] = ACTIONS(6601),
    [anon_sym_sequence] = ACTIONS(6601),
    [anon_sym_restrict] = ACTIONS(6601),
    [anon_sym_not] = ACTIONS(6601),
    [anon_sym_or] = ACTIONS(6601),
    [anon_sym_and] = ACTIONS(6601),
    [anon_sym_case] = ACTIONS(6601),
    [anon_sym_always] = ACTIONS(6601),
    [anon_sym_covergroup] = ACTIONS(6601),
    [anon_sym_end] = ACTIONS(6601),
    [anon_sym_let] = ACTIONS(6601),
    [anon_sym_pulldown] = ACTIONS(6601),
    [anon_sym_pullup] = ACTIONS(6601),
    [anon_sym_cmos] = ACTIONS(6601),
    [anon_sym_rcmos] = ACTIONS(6601),
    [anon_sym_bufif0] = ACTIONS(6601),
    [anon_sym_bufif1] = ACTIONS(6601),
    [anon_sym_notif0] = ACTIONS(6601),
    [anon_sym_notif1] = ACTIONS(6601),
    [anon_sym_nmos] = ACTIONS(6601),
    [anon_sym_pmos] = ACTIONS(6601),
    [anon_sym_rnmos] = ACTIONS(6601),
    [anon_sym_rpmos] = ACTIONS(6601),
    [anon_sym_nand] = ACTIONS(6601),
    [anon_sym_nor] = ACTIONS(6601),
    [anon_sym_xor] = ACTIONS(6601),
    [anon_sym_xnor] = ACTIONS(6601),
    [anon_sym_buf] = ACTIONS(6601),
    [anon_sym_tranif0] = ACTIONS(6601),
    [anon_sym_tranif1] = ACTIONS(6601),
    [anon_sym_rtranif1] = ACTIONS(6601),
    [anon_sym_rtranif0] = ACTIONS(6601),
    [anon_sym_tran] = ACTIONS(6601),
    [anon_sym_rtran] = ACTIONS(6601),
    [anon_sym_generate] = ACTIONS(6601),
    [anon_sym_for] = ACTIONS(6601),
    [anon_sym_initial] = ACTIONS(6601),
    [anon_sym_assign] = ACTIONS(6601),
    [anon_sym_alias] = ACTIONS(6601),
    [anon_sym_always_comb] = ACTIONS(6601),
    [anon_sym_always_latch] = ACTIONS(6601),
    [anon_sym_always_ff] = ACTIONS(6601),
    [anon_sym_final] = ACTIONS(6601),
    [anon_sym_global] = ACTIONS(6601),
    [anon_sym_LPAREN_STAR] = ACTIONS(6603),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6603),
    [anon_sym_DOLLARunit] = ACTIONS(6603),
  },
  [4863] = {
    [sym_simple_identifier] = ACTIONS(4912),
    [anon_sym_wire] = ACTIONS(4912),
    [anon_sym_tri] = ACTIONS(4912),
    [anon_sym_tri0] = ACTIONS(4912),
    [anon_sym_tri1] = ACTIONS(4912),
    [anon_sym_wand] = ACTIONS(4912),
    [anon_sym_triand] = ACTIONS(4912),
    [anon_sym_wor] = ACTIONS(4912),
    [anon_sym_trior] = ACTIONS(4912),
    [anon_sym_trireg] = ACTIONS(4912),
    [anon_sym_uwire] = ACTIONS(4912),
    [anon_sym_SEMI] = ACTIONS(4910),
    [anon_sym_extern] = ACTIONS(4912),
    [anon_sym_interface] = ACTIONS(4912),
    [anon_sym_checker] = ACTIONS(4912),
    [anon_sym_virtual] = ACTIONS(4912),
    [anon_sym_class] = ACTIONS(4912),
    [anon_sym_type] = ACTIONS(4912),
    [anon_sym_DOLLARfatal] = ACTIONS(4910),
    [anon_sym_DOLLARerror] = ACTIONS(4910),
    [anon_sym_DOLLARwarning] = ACTIONS(4910),
    [anon_sym_DOLLARinfo] = ACTIONS(4910),
    [anon_sym_default] = ACTIONS(4912),
    [anon_sym_clocking] = ACTIONS(4912),
    [anon_sym_defparam] = ACTIONS(4912),
    [anon_sym_bind] = ACTIONS(4912),
    [anon_sym_rand] = ACTIONS(4912),
    [anon_sym_const] = ACTIONS(4912),
    [anon_sym_function] = ACTIONS(4912),
    [anon_sym_static] = ACTIONS(4912),
    [anon_sym_constraint] = ACTIONS(4912),
    [anon_sym_if] = ACTIONS(4912),
    [anon_sym_else] = ACTIONS(4912),
    [anon_sym_LBRACK] = ACTIONS(4910),
    [anon_sym_localparam] = ACTIONS(4912),
    [anon_sym_parameter] = ACTIONS(4912),
    [anon_sym_var] = ACTIONS(4912),
    [anon_sym_import] = ACTIONS(4912),
    [anon_sym_export] = ACTIONS(4912),
    [anon_sym_genvar] = ACTIONS(4912),
    [anon_sym_interconnect] = ACTIONS(4912),
    [anon_sym_typedef] = ACTIONS(4912),
    [anon_sym_enum] = ACTIONS(4912),
    [anon_sym_struct] = ACTIONS(4912),
    [anon_sym_union] = ACTIONS(4912),
    [anon_sym_nettype] = ACTIONS(4912),
    [anon_sym_automatic] = ACTIONS(4912),
    [anon_sym_string] = ACTIONS(4912),
    [anon_sym_chandle] = ACTIONS(4912),
    [anon_sym_event] = ACTIONS(4912),
    [anon_sym_byte] = ACTIONS(4912),
    [anon_sym_shortint] = ACTIONS(4912),
    [anon_sym_int] = ACTIONS(4912),
    [anon_sym_longint] = ACTIONS(4912),
    [anon_sym_integer] = ACTIONS(4912),
    [anon_sym_time] = ACTIONS(4912),
    [anon_sym_bit] = ACTIONS(4912),
    [anon_sym_logic] = ACTIONS(4912),
    [anon_sym_reg] = ACTIONS(4912),
    [anon_sym_shortreal] = ACTIONS(4912),
    [anon_sym_real] = ACTIONS(4912),
    [anon_sym_realtime] = ACTIONS(4912),
    [anon_sym_supply0] = ACTIONS(4912),
    [anon_sym_supply1] = ACTIONS(4912),
    [anon_sym_signed] = ACTIONS(4912),
    [anon_sym_unsigned] = ACTIONS(4912),
    [anon_sym_task] = ACTIONS(4912),
    [anon_sym_assert] = ACTIONS(4912),
    [anon_sym_property] = ACTIONS(4912),
    [anon_sym_assume] = ACTIONS(4912),
    [anon_sym_cover] = ACTIONS(4912),
    [anon_sym_sequence] = ACTIONS(4912),
    [anon_sym_restrict] = ACTIONS(4912),
    [anon_sym_not] = ACTIONS(4912),
    [anon_sym_or] = ACTIONS(4912),
    [anon_sym_and] = ACTIONS(4912),
    [anon_sym_case] = ACTIONS(4912),
    [anon_sym_always] = ACTIONS(4912),
    [anon_sym_covergroup] = ACTIONS(4912),
    [anon_sym_let] = ACTIONS(4912),
    [anon_sym_pulldown] = ACTIONS(4912),
    [anon_sym_pullup] = ACTIONS(4912),
    [anon_sym_cmos] = ACTIONS(4912),
    [anon_sym_rcmos] = ACTIONS(4912),
    [anon_sym_bufif0] = ACTIONS(4912),
    [anon_sym_bufif1] = ACTIONS(4912),
    [anon_sym_notif0] = ACTIONS(4912),
    [anon_sym_notif1] = ACTIONS(4912),
    [anon_sym_nmos] = ACTIONS(4912),
    [anon_sym_pmos] = ACTIONS(4912),
    [anon_sym_rnmos] = ACTIONS(4912),
    [anon_sym_rpmos] = ACTIONS(4912),
    [anon_sym_nand] = ACTIONS(4912),
    [anon_sym_nor] = ACTIONS(4912),
    [anon_sym_xor] = ACTIONS(4912),
    [anon_sym_xnor] = ACTIONS(4912),
    [anon_sym_buf] = ACTIONS(4912),
    [anon_sym_tranif0] = ACTIONS(4912),
    [anon_sym_tranif1] = ACTIONS(4912),
    [anon_sym_rtranif1] = ACTIONS(4912),
    [anon_sym_rtranif0] = ACTIONS(4912),
    [anon_sym_tran] = ACTIONS(4912),
    [anon_sym_rtran] = ACTIONS(4912),
    [anon_sym_generate] = ACTIONS(4912),
    [anon_sym_endgenerate] = ACTIONS(4912),
    [anon_sym_for] = ACTIONS(4912),
    [anon_sym_initial] = ACTIONS(4912),
    [anon_sym_assign] = ACTIONS(4912),
    [anon_sym_alias] = ACTIONS(4912),
    [anon_sym_always_comb] = ACTIONS(4912),
    [anon_sym_always_latch] = ACTIONS(4912),
    [anon_sym_always_ff] = ACTIONS(4912),
    [anon_sym_final] = ACTIONS(4912),
    [anon_sym_global] = ACTIONS(4912),
    [anon_sym_LPAREN_STAR] = ACTIONS(4910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4910),
    [anon_sym_DOLLARunit] = ACTIONS(4910),
  },
  [4864] = {
    [sym_simple_identifier] = ACTIONS(5484),
    [anon_sym_wire] = ACTIONS(5484),
    [anon_sym_tri] = ACTIONS(5484),
    [anon_sym_tri0] = ACTIONS(5484),
    [anon_sym_tri1] = ACTIONS(5484),
    [anon_sym_wand] = ACTIONS(5484),
    [anon_sym_triand] = ACTIONS(5484),
    [anon_sym_wor] = ACTIONS(5484),
    [anon_sym_trior] = ACTIONS(5484),
    [anon_sym_trireg] = ACTIONS(5484),
    [anon_sym_uwire] = ACTIONS(5484),
    [anon_sym_SEMI] = ACTIONS(5482),
    [anon_sym_extern] = ACTIONS(5484),
    [anon_sym_interface] = ACTIONS(5484),
    [anon_sym_checker] = ACTIONS(5484),
    [anon_sym_virtual] = ACTIONS(5484),
    [anon_sym_class] = ACTIONS(5484),
    [anon_sym_type] = ACTIONS(5484),
    [anon_sym_DOLLARfatal] = ACTIONS(5482),
    [anon_sym_DOLLARerror] = ACTIONS(5482),
    [anon_sym_DOLLARwarning] = ACTIONS(5482),
    [anon_sym_DOLLARinfo] = ACTIONS(5482),
    [anon_sym_default] = ACTIONS(5484),
    [anon_sym_clocking] = ACTIONS(5484),
    [anon_sym_defparam] = ACTIONS(5484),
    [anon_sym_bind] = ACTIONS(5484),
    [anon_sym_rand] = ACTIONS(5484),
    [anon_sym_const] = ACTIONS(5484),
    [anon_sym_function] = ACTIONS(5484),
    [anon_sym_static] = ACTIONS(5484),
    [anon_sym_constraint] = ACTIONS(5484),
    [anon_sym_if] = ACTIONS(5484),
    [anon_sym_else] = ACTIONS(5484),
    [anon_sym_LBRACK] = ACTIONS(5482),
    [anon_sym_localparam] = ACTIONS(5484),
    [anon_sym_parameter] = ACTIONS(5484),
    [anon_sym_var] = ACTIONS(5484),
    [anon_sym_import] = ACTIONS(5484),
    [anon_sym_export] = ACTIONS(5484),
    [anon_sym_genvar] = ACTIONS(5484),
    [anon_sym_interconnect] = ACTIONS(5484),
    [anon_sym_typedef] = ACTIONS(5484),
    [anon_sym_enum] = ACTIONS(5484),
    [anon_sym_struct] = ACTIONS(5484),
    [anon_sym_union] = ACTIONS(5484),
    [anon_sym_nettype] = ACTIONS(5484),
    [anon_sym_automatic] = ACTIONS(5484),
    [anon_sym_string] = ACTIONS(5484),
    [anon_sym_chandle] = ACTIONS(5484),
    [anon_sym_event] = ACTIONS(5484),
    [anon_sym_byte] = ACTIONS(5484),
    [anon_sym_shortint] = ACTIONS(5484),
    [anon_sym_int] = ACTIONS(5484),
    [anon_sym_longint] = ACTIONS(5484),
    [anon_sym_integer] = ACTIONS(5484),
    [anon_sym_time] = ACTIONS(5484),
    [anon_sym_bit] = ACTIONS(5484),
    [anon_sym_logic] = ACTIONS(5484),
    [anon_sym_reg] = ACTIONS(5484),
    [anon_sym_shortreal] = ACTIONS(5484),
    [anon_sym_real] = ACTIONS(5484),
    [anon_sym_realtime] = ACTIONS(5484),
    [anon_sym_supply0] = ACTIONS(5484),
    [anon_sym_supply1] = ACTIONS(5484),
    [anon_sym_signed] = ACTIONS(5484),
    [anon_sym_unsigned] = ACTIONS(5484),
    [anon_sym_task] = ACTIONS(5484),
    [anon_sym_assert] = ACTIONS(5484),
    [anon_sym_property] = ACTIONS(5484),
    [anon_sym_assume] = ACTIONS(5484),
    [anon_sym_cover] = ACTIONS(5484),
    [anon_sym_sequence] = ACTIONS(5484),
    [anon_sym_restrict] = ACTIONS(5484),
    [anon_sym_not] = ACTIONS(5484),
    [anon_sym_or] = ACTIONS(5484),
    [anon_sym_and] = ACTIONS(5484),
    [anon_sym_case] = ACTIONS(5484),
    [anon_sym_always] = ACTIONS(5484),
    [anon_sym_covergroup] = ACTIONS(5484),
    [anon_sym_let] = ACTIONS(5484),
    [anon_sym_pulldown] = ACTIONS(5484),
    [anon_sym_pullup] = ACTIONS(5484),
    [anon_sym_cmos] = ACTIONS(5484),
    [anon_sym_rcmos] = ACTIONS(5484),
    [anon_sym_bufif0] = ACTIONS(5484),
    [anon_sym_bufif1] = ACTIONS(5484),
    [anon_sym_notif0] = ACTIONS(5484),
    [anon_sym_notif1] = ACTIONS(5484),
    [anon_sym_nmos] = ACTIONS(5484),
    [anon_sym_pmos] = ACTIONS(5484),
    [anon_sym_rnmos] = ACTIONS(5484),
    [anon_sym_rpmos] = ACTIONS(5484),
    [anon_sym_nand] = ACTIONS(5484),
    [anon_sym_nor] = ACTIONS(5484),
    [anon_sym_xor] = ACTIONS(5484),
    [anon_sym_xnor] = ACTIONS(5484),
    [anon_sym_buf] = ACTIONS(5484),
    [anon_sym_tranif0] = ACTIONS(5484),
    [anon_sym_tranif1] = ACTIONS(5484),
    [anon_sym_rtranif1] = ACTIONS(5484),
    [anon_sym_rtranif0] = ACTIONS(5484),
    [anon_sym_tran] = ACTIONS(5484),
    [anon_sym_rtran] = ACTIONS(5484),
    [anon_sym_generate] = ACTIONS(5484),
    [anon_sym_endgenerate] = ACTIONS(5484),
    [anon_sym_for] = ACTIONS(5484),
    [anon_sym_initial] = ACTIONS(5484),
    [anon_sym_assign] = ACTIONS(5484),
    [anon_sym_alias] = ACTIONS(5484),
    [anon_sym_always_comb] = ACTIONS(5484),
    [anon_sym_always_latch] = ACTIONS(5484),
    [anon_sym_always_ff] = ACTIONS(5484),
    [anon_sym_final] = ACTIONS(5484),
    [anon_sym_global] = ACTIONS(5484),
    [anon_sym_LPAREN_STAR] = ACTIONS(5482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5482),
    [anon_sym_DOLLARunit] = ACTIONS(5482),
  },
  [4865] = {
    [sym_simple_identifier] = ACTIONS(4196),
    [anon_sym_wire] = ACTIONS(4196),
    [anon_sym_tri] = ACTIONS(4196),
    [anon_sym_tri0] = ACTIONS(4196),
    [anon_sym_tri1] = ACTIONS(4196),
    [anon_sym_wand] = ACTIONS(4196),
    [anon_sym_triand] = ACTIONS(4196),
    [anon_sym_wor] = ACTIONS(4196),
    [anon_sym_trior] = ACTIONS(4196),
    [anon_sym_trireg] = ACTIONS(4196),
    [anon_sym_uwire] = ACTIONS(4196),
    [anon_sym_SEMI] = ACTIONS(4194),
    [anon_sym_extern] = ACTIONS(4196),
    [anon_sym_interface] = ACTIONS(4196),
    [anon_sym_checker] = ACTIONS(4196),
    [anon_sym_virtual] = ACTIONS(4196),
    [anon_sym_class] = ACTIONS(4196),
    [anon_sym_type] = ACTIONS(4196),
    [anon_sym_DOLLARfatal] = ACTIONS(4194),
    [anon_sym_DOLLARerror] = ACTIONS(4194),
    [anon_sym_DOLLARwarning] = ACTIONS(4194),
    [anon_sym_DOLLARinfo] = ACTIONS(4194),
    [anon_sym_default] = ACTIONS(4196),
    [anon_sym_clocking] = ACTIONS(4196),
    [anon_sym_defparam] = ACTIONS(4196),
    [anon_sym_bind] = ACTIONS(4196),
    [anon_sym_rand] = ACTIONS(4196),
    [anon_sym_const] = ACTIONS(4196),
    [anon_sym_function] = ACTIONS(4196),
    [anon_sym_static] = ACTIONS(4196),
    [anon_sym_constraint] = ACTIONS(4196),
    [anon_sym_if] = ACTIONS(4196),
    [anon_sym_else] = ACTIONS(4196),
    [anon_sym_LBRACK] = ACTIONS(4194),
    [anon_sym_localparam] = ACTIONS(4196),
    [anon_sym_parameter] = ACTIONS(4196),
    [anon_sym_var] = ACTIONS(4196),
    [anon_sym_import] = ACTIONS(4196),
    [anon_sym_export] = ACTIONS(4196),
    [anon_sym_genvar] = ACTIONS(4196),
    [anon_sym_interconnect] = ACTIONS(4196),
    [anon_sym_typedef] = ACTIONS(4196),
    [anon_sym_enum] = ACTIONS(4196),
    [anon_sym_struct] = ACTIONS(4196),
    [anon_sym_union] = ACTIONS(4196),
    [anon_sym_nettype] = ACTIONS(4196),
    [anon_sym_automatic] = ACTIONS(4196),
    [anon_sym_string] = ACTIONS(4196),
    [anon_sym_chandle] = ACTIONS(4196),
    [anon_sym_event] = ACTIONS(4196),
    [anon_sym_byte] = ACTIONS(4196),
    [anon_sym_shortint] = ACTIONS(4196),
    [anon_sym_int] = ACTIONS(4196),
    [anon_sym_longint] = ACTIONS(4196),
    [anon_sym_integer] = ACTIONS(4196),
    [anon_sym_time] = ACTIONS(4196),
    [anon_sym_bit] = ACTIONS(4196),
    [anon_sym_logic] = ACTIONS(4196),
    [anon_sym_reg] = ACTIONS(4196),
    [anon_sym_shortreal] = ACTIONS(4196),
    [anon_sym_real] = ACTIONS(4196),
    [anon_sym_realtime] = ACTIONS(4196),
    [anon_sym_supply0] = ACTIONS(4196),
    [anon_sym_supply1] = ACTIONS(4196),
    [anon_sym_signed] = ACTIONS(4196),
    [anon_sym_unsigned] = ACTIONS(4196),
    [anon_sym_task] = ACTIONS(4196),
    [anon_sym_assert] = ACTIONS(4196),
    [anon_sym_property] = ACTIONS(4196),
    [anon_sym_assume] = ACTIONS(4196),
    [anon_sym_cover] = ACTIONS(4196),
    [anon_sym_sequence] = ACTIONS(4196),
    [anon_sym_restrict] = ACTIONS(4196),
    [anon_sym_not] = ACTIONS(4196),
    [anon_sym_or] = ACTIONS(4196),
    [anon_sym_and] = ACTIONS(4196),
    [anon_sym_case] = ACTIONS(4196),
    [anon_sym_always] = ACTIONS(4196),
    [anon_sym_covergroup] = ACTIONS(4196),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_pulldown] = ACTIONS(4196),
    [anon_sym_pullup] = ACTIONS(4196),
    [anon_sym_cmos] = ACTIONS(4196),
    [anon_sym_rcmos] = ACTIONS(4196),
    [anon_sym_bufif0] = ACTIONS(4196),
    [anon_sym_bufif1] = ACTIONS(4196),
    [anon_sym_notif0] = ACTIONS(4196),
    [anon_sym_notif1] = ACTIONS(4196),
    [anon_sym_nmos] = ACTIONS(4196),
    [anon_sym_pmos] = ACTIONS(4196),
    [anon_sym_rnmos] = ACTIONS(4196),
    [anon_sym_rpmos] = ACTIONS(4196),
    [anon_sym_nand] = ACTIONS(4196),
    [anon_sym_nor] = ACTIONS(4196),
    [anon_sym_xor] = ACTIONS(4196),
    [anon_sym_xnor] = ACTIONS(4196),
    [anon_sym_buf] = ACTIONS(4196),
    [anon_sym_tranif0] = ACTIONS(4196),
    [anon_sym_tranif1] = ACTIONS(4196),
    [anon_sym_rtranif1] = ACTIONS(4196),
    [anon_sym_rtranif0] = ACTIONS(4196),
    [anon_sym_tran] = ACTIONS(4196),
    [anon_sym_rtran] = ACTIONS(4196),
    [anon_sym_generate] = ACTIONS(4196),
    [anon_sym_endgenerate] = ACTIONS(4196),
    [anon_sym_for] = ACTIONS(4196),
    [anon_sym_initial] = ACTIONS(4196),
    [anon_sym_assign] = ACTIONS(4196),
    [anon_sym_alias] = ACTIONS(4196),
    [anon_sym_always_comb] = ACTIONS(4196),
    [anon_sym_always_latch] = ACTIONS(4196),
    [anon_sym_always_ff] = ACTIONS(4196),
    [anon_sym_final] = ACTIONS(4196),
    [anon_sym_global] = ACTIONS(4196),
    [anon_sym_LPAREN_STAR] = ACTIONS(4194),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4194),
    [anon_sym_DOLLARunit] = ACTIONS(4194),
  },
  [4866] = {
    [sym_simple_identifier] = ACTIONS(5254),
    [anon_sym_wire] = ACTIONS(5254),
    [anon_sym_tri] = ACTIONS(5254),
    [anon_sym_tri0] = ACTIONS(5254),
    [anon_sym_tri1] = ACTIONS(5254),
    [anon_sym_wand] = ACTIONS(5254),
    [anon_sym_triand] = ACTIONS(5254),
    [anon_sym_wor] = ACTIONS(5254),
    [anon_sym_trior] = ACTIONS(5254),
    [anon_sym_trireg] = ACTIONS(5254),
    [anon_sym_uwire] = ACTIONS(5254),
    [anon_sym_SEMI] = ACTIONS(5252),
    [anon_sym_extern] = ACTIONS(5254),
    [anon_sym_interface] = ACTIONS(5254),
    [anon_sym_checker] = ACTIONS(5254),
    [anon_sym_virtual] = ACTIONS(5254),
    [anon_sym_class] = ACTIONS(5254),
    [anon_sym_type] = ACTIONS(5254),
    [anon_sym_DOLLARfatal] = ACTIONS(5252),
    [anon_sym_DOLLARerror] = ACTIONS(5252),
    [anon_sym_DOLLARwarning] = ACTIONS(5252),
    [anon_sym_DOLLARinfo] = ACTIONS(5252),
    [anon_sym_default] = ACTIONS(5254),
    [anon_sym_clocking] = ACTIONS(5254),
    [anon_sym_defparam] = ACTIONS(5254),
    [anon_sym_bind] = ACTIONS(5254),
    [anon_sym_rand] = ACTIONS(5254),
    [anon_sym_const] = ACTIONS(5254),
    [anon_sym_function] = ACTIONS(5254),
    [anon_sym_static] = ACTIONS(5254),
    [anon_sym_constraint] = ACTIONS(5254),
    [anon_sym_if] = ACTIONS(5254),
    [anon_sym_else] = ACTIONS(5254),
    [anon_sym_LBRACK] = ACTIONS(5252),
    [anon_sym_localparam] = ACTIONS(5254),
    [anon_sym_parameter] = ACTIONS(5254),
    [anon_sym_var] = ACTIONS(5254),
    [anon_sym_import] = ACTIONS(5254),
    [anon_sym_export] = ACTIONS(5254),
    [anon_sym_genvar] = ACTIONS(5254),
    [anon_sym_interconnect] = ACTIONS(5254),
    [anon_sym_typedef] = ACTIONS(5254),
    [anon_sym_enum] = ACTIONS(5254),
    [anon_sym_struct] = ACTIONS(5254),
    [anon_sym_union] = ACTIONS(5254),
    [anon_sym_nettype] = ACTIONS(5254),
    [anon_sym_automatic] = ACTIONS(5254),
    [anon_sym_string] = ACTIONS(5254),
    [anon_sym_chandle] = ACTIONS(5254),
    [anon_sym_event] = ACTIONS(5254),
    [anon_sym_byte] = ACTIONS(5254),
    [anon_sym_shortint] = ACTIONS(5254),
    [anon_sym_int] = ACTIONS(5254),
    [anon_sym_longint] = ACTIONS(5254),
    [anon_sym_integer] = ACTIONS(5254),
    [anon_sym_time] = ACTIONS(5254),
    [anon_sym_bit] = ACTIONS(5254),
    [anon_sym_logic] = ACTIONS(5254),
    [anon_sym_reg] = ACTIONS(5254),
    [anon_sym_shortreal] = ACTIONS(5254),
    [anon_sym_real] = ACTIONS(5254),
    [anon_sym_realtime] = ACTIONS(5254),
    [anon_sym_supply0] = ACTIONS(5254),
    [anon_sym_supply1] = ACTIONS(5254),
    [anon_sym_signed] = ACTIONS(5254),
    [anon_sym_unsigned] = ACTIONS(5254),
    [anon_sym_task] = ACTIONS(5254),
    [anon_sym_assert] = ACTIONS(5254),
    [anon_sym_property] = ACTIONS(5254),
    [anon_sym_assume] = ACTIONS(5254),
    [anon_sym_cover] = ACTIONS(5254),
    [anon_sym_sequence] = ACTIONS(5254),
    [anon_sym_restrict] = ACTIONS(5254),
    [anon_sym_not] = ACTIONS(5254),
    [anon_sym_or] = ACTIONS(5254),
    [anon_sym_and] = ACTIONS(5254),
    [anon_sym_case] = ACTIONS(5254),
    [anon_sym_always] = ACTIONS(5254),
    [anon_sym_covergroup] = ACTIONS(5254),
    [anon_sym_let] = ACTIONS(5254),
    [anon_sym_pulldown] = ACTIONS(5254),
    [anon_sym_pullup] = ACTIONS(5254),
    [anon_sym_cmos] = ACTIONS(5254),
    [anon_sym_rcmos] = ACTIONS(5254),
    [anon_sym_bufif0] = ACTIONS(5254),
    [anon_sym_bufif1] = ACTIONS(5254),
    [anon_sym_notif0] = ACTIONS(5254),
    [anon_sym_notif1] = ACTIONS(5254),
    [anon_sym_nmos] = ACTIONS(5254),
    [anon_sym_pmos] = ACTIONS(5254),
    [anon_sym_rnmos] = ACTIONS(5254),
    [anon_sym_rpmos] = ACTIONS(5254),
    [anon_sym_nand] = ACTIONS(5254),
    [anon_sym_nor] = ACTIONS(5254),
    [anon_sym_xor] = ACTIONS(5254),
    [anon_sym_xnor] = ACTIONS(5254),
    [anon_sym_buf] = ACTIONS(5254),
    [anon_sym_tranif0] = ACTIONS(5254),
    [anon_sym_tranif1] = ACTIONS(5254),
    [anon_sym_rtranif1] = ACTIONS(5254),
    [anon_sym_rtranif0] = ACTIONS(5254),
    [anon_sym_tran] = ACTIONS(5254),
    [anon_sym_rtran] = ACTIONS(5254),
    [anon_sym_generate] = ACTIONS(5254),
    [anon_sym_endgenerate] = ACTIONS(5254),
    [anon_sym_for] = ACTIONS(5254),
    [anon_sym_initial] = ACTIONS(5254),
    [anon_sym_assign] = ACTIONS(5254),
    [anon_sym_alias] = ACTIONS(5254),
    [anon_sym_always_comb] = ACTIONS(5254),
    [anon_sym_always_latch] = ACTIONS(5254),
    [anon_sym_always_ff] = ACTIONS(5254),
    [anon_sym_final] = ACTIONS(5254),
    [anon_sym_global] = ACTIONS(5254),
    [anon_sym_LPAREN_STAR] = ACTIONS(5252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5252),
    [anon_sym_DOLLARunit] = ACTIONS(5252),
  },
  [4867] = {
    [sym_simple_identifier] = ACTIONS(5186),
    [anon_sym_wire] = ACTIONS(5186),
    [anon_sym_tri] = ACTIONS(5186),
    [anon_sym_tri0] = ACTIONS(5186),
    [anon_sym_tri1] = ACTIONS(5186),
    [anon_sym_wand] = ACTIONS(5186),
    [anon_sym_triand] = ACTIONS(5186),
    [anon_sym_wor] = ACTIONS(5186),
    [anon_sym_trior] = ACTIONS(5186),
    [anon_sym_trireg] = ACTIONS(5186),
    [anon_sym_uwire] = ACTIONS(5186),
    [anon_sym_SEMI] = ACTIONS(5184),
    [anon_sym_extern] = ACTIONS(5186),
    [anon_sym_interface] = ACTIONS(5186),
    [anon_sym_checker] = ACTIONS(5186),
    [anon_sym_virtual] = ACTIONS(5186),
    [anon_sym_class] = ACTIONS(5186),
    [anon_sym_type] = ACTIONS(5186),
    [anon_sym_DOLLARfatal] = ACTIONS(5184),
    [anon_sym_DOLLARerror] = ACTIONS(5184),
    [anon_sym_DOLLARwarning] = ACTIONS(5184),
    [anon_sym_DOLLARinfo] = ACTIONS(5184),
    [anon_sym_default] = ACTIONS(5186),
    [anon_sym_clocking] = ACTIONS(5186),
    [anon_sym_defparam] = ACTIONS(5186),
    [anon_sym_bind] = ACTIONS(5186),
    [anon_sym_rand] = ACTIONS(5186),
    [anon_sym_const] = ACTIONS(5186),
    [anon_sym_function] = ACTIONS(5186),
    [anon_sym_static] = ACTIONS(5186),
    [anon_sym_constraint] = ACTIONS(5186),
    [anon_sym_if] = ACTIONS(5186),
    [anon_sym_else] = ACTIONS(5186),
    [anon_sym_LBRACK] = ACTIONS(5184),
    [anon_sym_localparam] = ACTIONS(5186),
    [anon_sym_parameter] = ACTIONS(5186),
    [anon_sym_var] = ACTIONS(5186),
    [anon_sym_import] = ACTIONS(5186),
    [anon_sym_export] = ACTIONS(5186),
    [anon_sym_genvar] = ACTIONS(5186),
    [anon_sym_interconnect] = ACTIONS(5186),
    [anon_sym_typedef] = ACTIONS(5186),
    [anon_sym_enum] = ACTIONS(5186),
    [anon_sym_struct] = ACTIONS(5186),
    [anon_sym_union] = ACTIONS(5186),
    [anon_sym_nettype] = ACTIONS(5186),
    [anon_sym_automatic] = ACTIONS(5186),
    [anon_sym_string] = ACTIONS(5186),
    [anon_sym_chandle] = ACTIONS(5186),
    [anon_sym_event] = ACTIONS(5186),
    [anon_sym_byte] = ACTIONS(5186),
    [anon_sym_shortint] = ACTIONS(5186),
    [anon_sym_int] = ACTIONS(5186),
    [anon_sym_longint] = ACTIONS(5186),
    [anon_sym_integer] = ACTIONS(5186),
    [anon_sym_time] = ACTIONS(5186),
    [anon_sym_bit] = ACTIONS(5186),
    [anon_sym_logic] = ACTIONS(5186),
    [anon_sym_reg] = ACTIONS(5186),
    [anon_sym_shortreal] = ACTIONS(5186),
    [anon_sym_real] = ACTIONS(5186),
    [anon_sym_realtime] = ACTIONS(5186),
    [anon_sym_supply0] = ACTIONS(5186),
    [anon_sym_supply1] = ACTIONS(5186),
    [anon_sym_signed] = ACTIONS(5186),
    [anon_sym_unsigned] = ACTIONS(5186),
    [anon_sym_task] = ACTIONS(5186),
    [anon_sym_assert] = ACTIONS(5186),
    [anon_sym_property] = ACTIONS(5186),
    [anon_sym_assume] = ACTIONS(5186),
    [anon_sym_cover] = ACTIONS(5186),
    [anon_sym_sequence] = ACTIONS(5186),
    [anon_sym_restrict] = ACTIONS(5186),
    [anon_sym_not] = ACTIONS(5186),
    [anon_sym_or] = ACTIONS(5186),
    [anon_sym_and] = ACTIONS(5186),
    [anon_sym_case] = ACTIONS(5186),
    [anon_sym_always] = ACTIONS(5186),
    [anon_sym_covergroup] = ACTIONS(5186),
    [anon_sym_let] = ACTIONS(5186),
    [anon_sym_pulldown] = ACTIONS(5186),
    [anon_sym_pullup] = ACTIONS(5186),
    [anon_sym_cmos] = ACTIONS(5186),
    [anon_sym_rcmos] = ACTIONS(5186),
    [anon_sym_bufif0] = ACTIONS(5186),
    [anon_sym_bufif1] = ACTIONS(5186),
    [anon_sym_notif0] = ACTIONS(5186),
    [anon_sym_notif1] = ACTIONS(5186),
    [anon_sym_nmos] = ACTIONS(5186),
    [anon_sym_pmos] = ACTIONS(5186),
    [anon_sym_rnmos] = ACTIONS(5186),
    [anon_sym_rpmos] = ACTIONS(5186),
    [anon_sym_nand] = ACTIONS(5186),
    [anon_sym_nor] = ACTIONS(5186),
    [anon_sym_xor] = ACTIONS(5186),
    [anon_sym_xnor] = ACTIONS(5186),
    [anon_sym_buf] = ACTIONS(5186),
    [anon_sym_tranif0] = ACTIONS(5186),
    [anon_sym_tranif1] = ACTIONS(5186),
    [anon_sym_rtranif1] = ACTIONS(5186),
    [anon_sym_rtranif0] = ACTIONS(5186),
    [anon_sym_tran] = ACTIONS(5186),
    [anon_sym_rtran] = ACTIONS(5186),
    [anon_sym_generate] = ACTIONS(5186),
    [anon_sym_endgenerate] = ACTIONS(5186),
    [anon_sym_for] = ACTIONS(5186),
    [anon_sym_initial] = ACTIONS(5186),
    [anon_sym_assign] = ACTIONS(5186),
    [anon_sym_alias] = ACTIONS(5186),
    [anon_sym_always_comb] = ACTIONS(5186),
    [anon_sym_always_latch] = ACTIONS(5186),
    [anon_sym_always_ff] = ACTIONS(5186),
    [anon_sym_final] = ACTIONS(5186),
    [anon_sym_global] = ACTIONS(5186),
    [anon_sym_LPAREN_STAR] = ACTIONS(5184),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5184),
    [anon_sym_DOLLARunit] = ACTIONS(5184),
  },
  [4868] = {
    [sym_simple_identifier] = ACTIONS(6035),
    [anon_sym_wire] = ACTIONS(6035),
    [anon_sym_tri] = ACTIONS(6035),
    [anon_sym_tri0] = ACTIONS(6035),
    [anon_sym_tri1] = ACTIONS(6035),
    [anon_sym_wand] = ACTIONS(6035),
    [anon_sym_triand] = ACTIONS(6035),
    [anon_sym_wor] = ACTIONS(6035),
    [anon_sym_trior] = ACTIONS(6035),
    [anon_sym_trireg] = ACTIONS(6035),
    [anon_sym_uwire] = ACTIONS(6035),
    [anon_sym_SEMI] = ACTIONS(6037),
    [anon_sym_extern] = ACTIONS(6035),
    [anon_sym_interface] = ACTIONS(6035),
    [anon_sym_checker] = ACTIONS(6035),
    [anon_sym_virtual] = ACTIONS(6035),
    [anon_sym_class] = ACTIONS(6035),
    [anon_sym_type] = ACTIONS(6035),
    [anon_sym_DOLLARfatal] = ACTIONS(6037),
    [anon_sym_DOLLARerror] = ACTIONS(6037),
    [anon_sym_DOLLARwarning] = ACTIONS(6037),
    [anon_sym_DOLLARinfo] = ACTIONS(6037),
    [anon_sym_default] = ACTIONS(6035),
    [anon_sym_clocking] = ACTIONS(6035),
    [anon_sym_defparam] = ACTIONS(6035),
    [anon_sym_bind] = ACTIONS(6035),
    [anon_sym_rand] = ACTIONS(6035),
    [anon_sym_const] = ACTIONS(6035),
    [anon_sym_function] = ACTIONS(6035),
    [anon_sym_static] = ACTIONS(6035),
    [anon_sym_constraint] = ACTIONS(6035),
    [anon_sym_if] = ACTIONS(6035),
    [anon_sym_else] = ACTIONS(6035),
    [anon_sym_LBRACK] = ACTIONS(6037),
    [anon_sym_localparam] = ACTIONS(6035),
    [anon_sym_parameter] = ACTIONS(6035),
    [anon_sym_var] = ACTIONS(6035),
    [anon_sym_import] = ACTIONS(6035),
    [anon_sym_export] = ACTIONS(6035),
    [anon_sym_genvar] = ACTIONS(6035),
    [anon_sym_interconnect] = ACTIONS(6035),
    [anon_sym_typedef] = ACTIONS(6035),
    [anon_sym_enum] = ACTIONS(6035),
    [anon_sym_struct] = ACTIONS(6035),
    [anon_sym_union] = ACTIONS(6035),
    [anon_sym_nettype] = ACTIONS(6035),
    [anon_sym_automatic] = ACTIONS(6035),
    [anon_sym_string] = ACTIONS(6035),
    [anon_sym_chandle] = ACTIONS(6035),
    [anon_sym_event] = ACTIONS(6035),
    [anon_sym_byte] = ACTIONS(6035),
    [anon_sym_shortint] = ACTIONS(6035),
    [anon_sym_int] = ACTIONS(6035),
    [anon_sym_longint] = ACTIONS(6035),
    [anon_sym_integer] = ACTIONS(6035),
    [anon_sym_time] = ACTIONS(6035),
    [anon_sym_bit] = ACTIONS(6035),
    [anon_sym_logic] = ACTIONS(6035),
    [anon_sym_reg] = ACTIONS(6035),
    [anon_sym_shortreal] = ACTIONS(6035),
    [anon_sym_real] = ACTIONS(6035),
    [anon_sym_realtime] = ACTIONS(6035),
    [anon_sym_supply0] = ACTIONS(6035),
    [anon_sym_supply1] = ACTIONS(6035),
    [anon_sym_signed] = ACTIONS(6035),
    [anon_sym_unsigned] = ACTIONS(6035),
    [anon_sym_task] = ACTIONS(6035),
    [anon_sym_assert] = ACTIONS(6035),
    [anon_sym_property] = ACTIONS(6035),
    [anon_sym_assume] = ACTIONS(6035),
    [anon_sym_cover] = ACTIONS(6035),
    [anon_sym_sequence] = ACTIONS(6035),
    [anon_sym_restrict] = ACTIONS(6035),
    [anon_sym_not] = ACTIONS(6035),
    [anon_sym_or] = ACTIONS(6035),
    [anon_sym_and] = ACTIONS(6035),
    [anon_sym_case] = ACTIONS(6035),
    [anon_sym_always] = ACTIONS(6035),
    [anon_sym_covergroup] = ACTIONS(6035),
    [anon_sym_let] = ACTIONS(6035),
    [anon_sym_pulldown] = ACTIONS(6035),
    [anon_sym_pullup] = ACTIONS(6035),
    [anon_sym_cmos] = ACTIONS(6035),
    [anon_sym_rcmos] = ACTIONS(6035),
    [anon_sym_bufif0] = ACTIONS(6035),
    [anon_sym_bufif1] = ACTIONS(6035),
    [anon_sym_notif0] = ACTIONS(6035),
    [anon_sym_notif1] = ACTIONS(6035),
    [anon_sym_nmos] = ACTIONS(6035),
    [anon_sym_pmos] = ACTIONS(6035),
    [anon_sym_rnmos] = ACTIONS(6035),
    [anon_sym_rpmos] = ACTIONS(6035),
    [anon_sym_nand] = ACTIONS(6035),
    [anon_sym_nor] = ACTIONS(6035),
    [anon_sym_xor] = ACTIONS(6035),
    [anon_sym_xnor] = ACTIONS(6035),
    [anon_sym_buf] = ACTIONS(6035),
    [anon_sym_tranif0] = ACTIONS(6035),
    [anon_sym_tranif1] = ACTIONS(6035),
    [anon_sym_rtranif1] = ACTIONS(6035),
    [anon_sym_rtranif0] = ACTIONS(6035),
    [anon_sym_tran] = ACTIONS(6035),
    [anon_sym_rtran] = ACTIONS(6035),
    [anon_sym_generate] = ACTIONS(6035),
    [anon_sym_endgenerate] = ACTIONS(6035),
    [anon_sym_for] = ACTIONS(6035),
    [anon_sym_initial] = ACTIONS(6035),
    [anon_sym_assign] = ACTIONS(6035),
    [anon_sym_alias] = ACTIONS(6035),
    [anon_sym_always_comb] = ACTIONS(6035),
    [anon_sym_always_latch] = ACTIONS(6035),
    [anon_sym_always_ff] = ACTIONS(6035),
    [anon_sym_final] = ACTIONS(6035),
    [anon_sym_global] = ACTIONS(6035),
    [anon_sym_LPAREN_STAR] = ACTIONS(6037),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6037),
    [anon_sym_DOLLARunit] = ACTIONS(6037),
  },
  [4869] = {
    [sym_simple_identifier] = ACTIONS(6149),
    [anon_sym_wire] = ACTIONS(6149),
    [anon_sym_tri] = ACTIONS(6149),
    [anon_sym_tri0] = ACTIONS(6149),
    [anon_sym_tri1] = ACTIONS(6149),
    [anon_sym_wand] = ACTIONS(6149),
    [anon_sym_triand] = ACTIONS(6149),
    [anon_sym_wor] = ACTIONS(6149),
    [anon_sym_trior] = ACTIONS(6149),
    [anon_sym_trireg] = ACTIONS(6149),
    [anon_sym_uwire] = ACTIONS(6149),
    [anon_sym_SEMI] = ACTIONS(6151),
    [anon_sym_extern] = ACTIONS(6149),
    [anon_sym_interface] = ACTIONS(6149),
    [anon_sym_checker] = ACTIONS(6149),
    [anon_sym_virtual] = ACTIONS(6149),
    [anon_sym_class] = ACTIONS(6149),
    [anon_sym_type] = ACTIONS(6149),
    [anon_sym_DOLLARfatal] = ACTIONS(6151),
    [anon_sym_DOLLARerror] = ACTIONS(6151),
    [anon_sym_DOLLARwarning] = ACTIONS(6151),
    [anon_sym_DOLLARinfo] = ACTIONS(6151),
    [anon_sym_default] = ACTIONS(6149),
    [anon_sym_clocking] = ACTIONS(6149),
    [anon_sym_defparam] = ACTIONS(6149),
    [anon_sym_bind] = ACTIONS(6149),
    [anon_sym_rand] = ACTIONS(6149),
    [anon_sym_const] = ACTIONS(6149),
    [anon_sym_function] = ACTIONS(6149),
    [anon_sym_static] = ACTIONS(6149),
    [anon_sym_constraint] = ACTIONS(6149),
    [anon_sym_if] = ACTIONS(6149),
    [anon_sym_else] = ACTIONS(6149),
    [anon_sym_LBRACK] = ACTIONS(6151),
    [anon_sym_localparam] = ACTIONS(6149),
    [anon_sym_parameter] = ACTIONS(6149),
    [anon_sym_var] = ACTIONS(6149),
    [anon_sym_import] = ACTIONS(6149),
    [anon_sym_export] = ACTIONS(6149),
    [anon_sym_genvar] = ACTIONS(6149),
    [anon_sym_interconnect] = ACTIONS(6149),
    [anon_sym_typedef] = ACTIONS(6149),
    [anon_sym_enum] = ACTIONS(6149),
    [anon_sym_struct] = ACTIONS(6149),
    [anon_sym_union] = ACTIONS(6149),
    [anon_sym_nettype] = ACTIONS(6149),
    [anon_sym_automatic] = ACTIONS(6149),
    [anon_sym_string] = ACTIONS(6149),
    [anon_sym_chandle] = ACTIONS(6149),
    [anon_sym_event] = ACTIONS(6149),
    [anon_sym_byte] = ACTIONS(6149),
    [anon_sym_shortint] = ACTIONS(6149),
    [anon_sym_int] = ACTIONS(6149),
    [anon_sym_longint] = ACTIONS(6149),
    [anon_sym_integer] = ACTIONS(6149),
    [anon_sym_time] = ACTIONS(6149),
    [anon_sym_bit] = ACTIONS(6149),
    [anon_sym_logic] = ACTIONS(6149),
    [anon_sym_reg] = ACTIONS(6149),
    [anon_sym_shortreal] = ACTIONS(6149),
    [anon_sym_real] = ACTIONS(6149),
    [anon_sym_realtime] = ACTIONS(6149),
    [anon_sym_supply0] = ACTIONS(6149),
    [anon_sym_supply1] = ACTIONS(6149),
    [anon_sym_signed] = ACTIONS(6149),
    [anon_sym_unsigned] = ACTIONS(6149),
    [anon_sym_task] = ACTIONS(6149),
    [anon_sym_assert] = ACTIONS(6149),
    [anon_sym_property] = ACTIONS(6149),
    [anon_sym_assume] = ACTIONS(6149),
    [anon_sym_cover] = ACTIONS(6149),
    [anon_sym_sequence] = ACTIONS(6149),
    [anon_sym_restrict] = ACTIONS(6149),
    [anon_sym_not] = ACTIONS(6149),
    [anon_sym_or] = ACTIONS(6149),
    [anon_sym_and] = ACTIONS(6149),
    [anon_sym_case] = ACTIONS(6149),
    [anon_sym_always] = ACTIONS(6149),
    [anon_sym_covergroup] = ACTIONS(6149),
    [anon_sym_end] = ACTIONS(6149),
    [anon_sym_let] = ACTIONS(6149),
    [anon_sym_pulldown] = ACTIONS(6149),
    [anon_sym_pullup] = ACTIONS(6149),
    [anon_sym_cmos] = ACTIONS(6149),
    [anon_sym_rcmos] = ACTIONS(6149),
    [anon_sym_bufif0] = ACTIONS(6149),
    [anon_sym_bufif1] = ACTIONS(6149),
    [anon_sym_notif0] = ACTIONS(6149),
    [anon_sym_notif1] = ACTIONS(6149),
    [anon_sym_nmos] = ACTIONS(6149),
    [anon_sym_pmos] = ACTIONS(6149),
    [anon_sym_rnmos] = ACTIONS(6149),
    [anon_sym_rpmos] = ACTIONS(6149),
    [anon_sym_nand] = ACTIONS(6149),
    [anon_sym_nor] = ACTIONS(6149),
    [anon_sym_xor] = ACTIONS(6149),
    [anon_sym_xnor] = ACTIONS(6149),
    [anon_sym_buf] = ACTIONS(6149),
    [anon_sym_tranif0] = ACTIONS(6149),
    [anon_sym_tranif1] = ACTIONS(6149),
    [anon_sym_rtranif1] = ACTIONS(6149),
    [anon_sym_rtranif0] = ACTIONS(6149),
    [anon_sym_tran] = ACTIONS(6149),
    [anon_sym_rtran] = ACTIONS(6149),
    [anon_sym_generate] = ACTIONS(6149),
    [anon_sym_for] = ACTIONS(6149),
    [anon_sym_initial] = ACTIONS(6149),
    [anon_sym_assign] = ACTIONS(6149),
    [anon_sym_alias] = ACTIONS(6149),
    [anon_sym_always_comb] = ACTIONS(6149),
    [anon_sym_always_latch] = ACTIONS(6149),
    [anon_sym_always_ff] = ACTIONS(6149),
    [anon_sym_final] = ACTIONS(6149),
    [anon_sym_global] = ACTIONS(6149),
    [anon_sym_LPAREN_STAR] = ACTIONS(6151),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6151),
    [anon_sym_DOLLARunit] = ACTIONS(6151),
  },
  [4870] = {
    [sym_simple_identifier] = ACTIONS(6275),
    [anon_sym_wire] = ACTIONS(6275),
    [anon_sym_tri] = ACTIONS(6275),
    [anon_sym_tri0] = ACTIONS(6275),
    [anon_sym_tri1] = ACTIONS(6275),
    [anon_sym_wand] = ACTIONS(6275),
    [anon_sym_triand] = ACTIONS(6275),
    [anon_sym_wor] = ACTIONS(6275),
    [anon_sym_trior] = ACTIONS(6275),
    [anon_sym_trireg] = ACTIONS(6275),
    [anon_sym_uwire] = ACTIONS(6275),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym_extern] = ACTIONS(6275),
    [anon_sym_interface] = ACTIONS(6275),
    [anon_sym_checker] = ACTIONS(6275),
    [anon_sym_virtual] = ACTIONS(6275),
    [anon_sym_class] = ACTIONS(6275),
    [anon_sym_type] = ACTIONS(6275),
    [anon_sym_DOLLARfatal] = ACTIONS(6277),
    [anon_sym_DOLLARerror] = ACTIONS(6277),
    [anon_sym_DOLLARwarning] = ACTIONS(6277),
    [anon_sym_DOLLARinfo] = ACTIONS(6277),
    [anon_sym_default] = ACTIONS(6275),
    [anon_sym_clocking] = ACTIONS(6275),
    [anon_sym_defparam] = ACTIONS(6275),
    [anon_sym_bind] = ACTIONS(6275),
    [anon_sym_rand] = ACTIONS(6275),
    [anon_sym_const] = ACTIONS(6275),
    [anon_sym_function] = ACTIONS(6275),
    [anon_sym_static] = ACTIONS(6275),
    [anon_sym_constraint] = ACTIONS(6275),
    [anon_sym_if] = ACTIONS(6275),
    [anon_sym_else] = ACTIONS(6275),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_localparam] = ACTIONS(6275),
    [anon_sym_parameter] = ACTIONS(6275),
    [anon_sym_var] = ACTIONS(6275),
    [anon_sym_import] = ACTIONS(6275),
    [anon_sym_export] = ACTIONS(6275),
    [anon_sym_genvar] = ACTIONS(6275),
    [anon_sym_interconnect] = ACTIONS(6275),
    [anon_sym_typedef] = ACTIONS(6275),
    [anon_sym_enum] = ACTIONS(6275),
    [anon_sym_struct] = ACTIONS(6275),
    [anon_sym_union] = ACTIONS(6275),
    [anon_sym_nettype] = ACTIONS(6275),
    [anon_sym_automatic] = ACTIONS(6275),
    [anon_sym_string] = ACTIONS(6275),
    [anon_sym_chandle] = ACTIONS(6275),
    [anon_sym_event] = ACTIONS(6275),
    [anon_sym_byte] = ACTIONS(6275),
    [anon_sym_shortint] = ACTIONS(6275),
    [anon_sym_int] = ACTIONS(6275),
    [anon_sym_longint] = ACTIONS(6275),
    [anon_sym_integer] = ACTIONS(6275),
    [anon_sym_time] = ACTIONS(6275),
    [anon_sym_bit] = ACTIONS(6275),
    [anon_sym_logic] = ACTIONS(6275),
    [anon_sym_reg] = ACTIONS(6275),
    [anon_sym_shortreal] = ACTIONS(6275),
    [anon_sym_real] = ACTIONS(6275),
    [anon_sym_realtime] = ACTIONS(6275),
    [anon_sym_supply0] = ACTIONS(6275),
    [anon_sym_supply1] = ACTIONS(6275),
    [anon_sym_signed] = ACTIONS(6275),
    [anon_sym_unsigned] = ACTIONS(6275),
    [anon_sym_task] = ACTIONS(6275),
    [anon_sym_assert] = ACTIONS(6275),
    [anon_sym_property] = ACTIONS(6275),
    [anon_sym_assume] = ACTIONS(6275),
    [anon_sym_cover] = ACTIONS(6275),
    [anon_sym_sequence] = ACTIONS(6275),
    [anon_sym_restrict] = ACTIONS(6275),
    [anon_sym_not] = ACTIONS(6275),
    [anon_sym_or] = ACTIONS(6275),
    [anon_sym_and] = ACTIONS(6275),
    [anon_sym_case] = ACTIONS(6275),
    [anon_sym_always] = ACTIONS(6275),
    [anon_sym_covergroup] = ACTIONS(6275),
    [anon_sym_end] = ACTIONS(6275),
    [anon_sym_let] = ACTIONS(6275),
    [anon_sym_pulldown] = ACTIONS(6275),
    [anon_sym_pullup] = ACTIONS(6275),
    [anon_sym_cmos] = ACTIONS(6275),
    [anon_sym_rcmos] = ACTIONS(6275),
    [anon_sym_bufif0] = ACTIONS(6275),
    [anon_sym_bufif1] = ACTIONS(6275),
    [anon_sym_notif0] = ACTIONS(6275),
    [anon_sym_notif1] = ACTIONS(6275),
    [anon_sym_nmos] = ACTIONS(6275),
    [anon_sym_pmos] = ACTIONS(6275),
    [anon_sym_rnmos] = ACTIONS(6275),
    [anon_sym_rpmos] = ACTIONS(6275),
    [anon_sym_nand] = ACTIONS(6275),
    [anon_sym_nor] = ACTIONS(6275),
    [anon_sym_xor] = ACTIONS(6275),
    [anon_sym_xnor] = ACTIONS(6275),
    [anon_sym_buf] = ACTIONS(6275),
    [anon_sym_tranif0] = ACTIONS(6275),
    [anon_sym_tranif1] = ACTIONS(6275),
    [anon_sym_rtranif1] = ACTIONS(6275),
    [anon_sym_rtranif0] = ACTIONS(6275),
    [anon_sym_tran] = ACTIONS(6275),
    [anon_sym_rtran] = ACTIONS(6275),
    [anon_sym_generate] = ACTIONS(6275),
    [anon_sym_for] = ACTIONS(6275),
    [anon_sym_initial] = ACTIONS(6275),
    [anon_sym_assign] = ACTIONS(6275),
    [anon_sym_alias] = ACTIONS(6275),
    [anon_sym_always_comb] = ACTIONS(6275),
    [anon_sym_always_latch] = ACTIONS(6275),
    [anon_sym_always_ff] = ACTIONS(6275),
    [anon_sym_final] = ACTIONS(6275),
    [anon_sym_global] = ACTIONS(6275),
    [anon_sym_LPAREN_STAR] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6277),
    [anon_sym_DOLLARunit] = ACTIONS(6277),
  },
  [4871] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11171),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4872] = {
    [sym_simple_identifier] = ACTIONS(6549),
    [anon_sym_wire] = ACTIONS(6549),
    [anon_sym_tri] = ACTIONS(6549),
    [anon_sym_tri0] = ACTIONS(6549),
    [anon_sym_tri1] = ACTIONS(6549),
    [anon_sym_wand] = ACTIONS(6549),
    [anon_sym_triand] = ACTIONS(6549),
    [anon_sym_wor] = ACTIONS(6549),
    [anon_sym_trior] = ACTIONS(6549),
    [anon_sym_trireg] = ACTIONS(6549),
    [anon_sym_uwire] = ACTIONS(6549),
    [anon_sym_SEMI] = ACTIONS(6551),
    [anon_sym_extern] = ACTIONS(6549),
    [anon_sym_interface] = ACTIONS(6549),
    [anon_sym_checker] = ACTIONS(6549),
    [anon_sym_virtual] = ACTIONS(6549),
    [anon_sym_class] = ACTIONS(6549),
    [anon_sym_type] = ACTIONS(6549),
    [anon_sym_DOLLARfatal] = ACTIONS(6551),
    [anon_sym_DOLLARerror] = ACTIONS(6551),
    [anon_sym_DOLLARwarning] = ACTIONS(6551),
    [anon_sym_DOLLARinfo] = ACTIONS(6551),
    [anon_sym_default] = ACTIONS(6549),
    [anon_sym_clocking] = ACTIONS(6549),
    [anon_sym_defparam] = ACTIONS(6549),
    [anon_sym_bind] = ACTIONS(6549),
    [anon_sym_rand] = ACTIONS(6549),
    [anon_sym_const] = ACTIONS(6549),
    [anon_sym_function] = ACTIONS(6549),
    [anon_sym_static] = ACTIONS(6549),
    [anon_sym_constraint] = ACTIONS(6549),
    [anon_sym_if] = ACTIONS(6549),
    [anon_sym_else] = ACTIONS(6549),
    [anon_sym_LBRACK] = ACTIONS(6551),
    [anon_sym_localparam] = ACTIONS(6549),
    [anon_sym_parameter] = ACTIONS(6549),
    [anon_sym_var] = ACTIONS(6549),
    [anon_sym_import] = ACTIONS(6549),
    [anon_sym_export] = ACTIONS(6549),
    [anon_sym_genvar] = ACTIONS(6549),
    [anon_sym_interconnect] = ACTIONS(6549),
    [anon_sym_typedef] = ACTIONS(6549),
    [anon_sym_enum] = ACTIONS(6549),
    [anon_sym_struct] = ACTIONS(6549),
    [anon_sym_union] = ACTIONS(6549),
    [anon_sym_nettype] = ACTIONS(6549),
    [anon_sym_automatic] = ACTIONS(6549),
    [anon_sym_string] = ACTIONS(6549),
    [anon_sym_chandle] = ACTIONS(6549),
    [anon_sym_event] = ACTIONS(6549),
    [anon_sym_byte] = ACTIONS(6549),
    [anon_sym_shortint] = ACTIONS(6549),
    [anon_sym_int] = ACTIONS(6549),
    [anon_sym_longint] = ACTIONS(6549),
    [anon_sym_integer] = ACTIONS(6549),
    [anon_sym_time] = ACTIONS(6549),
    [anon_sym_bit] = ACTIONS(6549),
    [anon_sym_logic] = ACTIONS(6549),
    [anon_sym_reg] = ACTIONS(6549),
    [anon_sym_shortreal] = ACTIONS(6549),
    [anon_sym_real] = ACTIONS(6549),
    [anon_sym_realtime] = ACTIONS(6549),
    [anon_sym_supply0] = ACTIONS(6549),
    [anon_sym_supply1] = ACTIONS(6549),
    [anon_sym_signed] = ACTIONS(6549),
    [anon_sym_unsigned] = ACTIONS(6549),
    [anon_sym_task] = ACTIONS(6549),
    [anon_sym_assert] = ACTIONS(6549),
    [anon_sym_property] = ACTIONS(6549),
    [anon_sym_assume] = ACTIONS(6549),
    [anon_sym_cover] = ACTIONS(6549),
    [anon_sym_sequence] = ACTIONS(6549),
    [anon_sym_restrict] = ACTIONS(6549),
    [anon_sym_not] = ACTIONS(6549),
    [anon_sym_or] = ACTIONS(6549),
    [anon_sym_and] = ACTIONS(6549),
    [anon_sym_case] = ACTIONS(6549),
    [anon_sym_always] = ACTIONS(6549),
    [anon_sym_covergroup] = ACTIONS(6549),
    [anon_sym_end] = ACTIONS(6549),
    [anon_sym_let] = ACTIONS(6549),
    [anon_sym_pulldown] = ACTIONS(6549),
    [anon_sym_pullup] = ACTIONS(6549),
    [anon_sym_cmos] = ACTIONS(6549),
    [anon_sym_rcmos] = ACTIONS(6549),
    [anon_sym_bufif0] = ACTIONS(6549),
    [anon_sym_bufif1] = ACTIONS(6549),
    [anon_sym_notif0] = ACTIONS(6549),
    [anon_sym_notif1] = ACTIONS(6549),
    [anon_sym_nmos] = ACTIONS(6549),
    [anon_sym_pmos] = ACTIONS(6549),
    [anon_sym_rnmos] = ACTIONS(6549),
    [anon_sym_rpmos] = ACTIONS(6549),
    [anon_sym_nand] = ACTIONS(6549),
    [anon_sym_nor] = ACTIONS(6549),
    [anon_sym_xor] = ACTIONS(6549),
    [anon_sym_xnor] = ACTIONS(6549),
    [anon_sym_buf] = ACTIONS(6549),
    [anon_sym_tranif0] = ACTIONS(6549),
    [anon_sym_tranif1] = ACTIONS(6549),
    [anon_sym_rtranif1] = ACTIONS(6549),
    [anon_sym_rtranif0] = ACTIONS(6549),
    [anon_sym_tran] = ACTIONS(6549),
    [anon_sym_rtran] = ACTIONS(6549),
    [anon_sym_generate] = ACTIONS(6549),
    [anon_sym_for] = ACTIONS(6549),
    [anon_sym_initial] = ACTIONS(6549),
    [anon_sym_assign] = ACTIONS(6549),
    [anon_sym_alias] = ACTIONS(6549),
    [anon_sym_always_comb] = ACTIONS(6549),
    [anon_sym_always_latch] = ACTIONS(6549),
    [anon_sym_always_ff] = ACTIONS(6549),
    [anon_sym_final] = ACTIONS(6549),
    [anon_sym_global] = ACTIONS(6549),
    [anon_sym_LPAREN_STAR] = ACTIONS(6551),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6551),
    [anon_sym_DOLLARunit] = ACTIONS(6551),
  },
  [4873] = {
    [sym_simple_identifier] = ACTIONS(4732),
    [anon_sym_wire] = ACTIONS(4732),
    [anon_sym_tri] = ACTIONS(4732),
    [anon_sym_tri0] = ACTIONS(4732),
    [anon_sym_tri1] = ACTIONS(4732),
    [anon_sym_wand] = ACTIONS(4732),
    [anon_sym_triand] = ACTIONS(4732),
    [anon_sym_wor] = ACTIONS(4732),
    [anon_sym_trior] = ACTIONS(4732),
    [anon_sym_trireg] = ACTIONS(4732),
    [anon_sym_uwire] = ACTIONS(4732),
    [anon_sym_SEMI] = ACTIONS(4730),
    [anon_sym_extern] = ACTIONS(4732),
    [anon_sym_interface] = ACTIONS(4732),
    [anon_sym_checker] = ACTIONS(4732),
    [anon_sym_virtual] = ACTIONS(4732),
    [anon_sym_class] = ACTIONS(4732),
    [anon_sym_type] = ACTIONS(4732),
    [anon_sym_DOLLARfatal] = ACTIONS(4730),
    [anon_sym_DOLLARerror] = ACTIONS(4730),
    [anon_sym_DOLLARwarning] = ACTIONS(4730),
    [anon_sym_DOLLARinfo] = ACTIONS(4730),
    [anon_sym_default] = ACTIONS(4732),
    [anon_sym_clocking] = ACTIONS(4732),
    [anon_sym_defparam] = ACTIONS(4732),
    [anon_sym_bind] = ACTIONS(4732),
    [anon_sym_rand] = ACTIONS(4732),
    [anon_sym_const] = ACTIONS(4732),
    [anon_sym_function] = ACTIONS(4732),
    [anon_sym_static] = ACTIONS(4732),
    [anon_sym_constraint] = ACTIONS(4732),
    [anon_sym_if] = ACTIONS(4732),
    [anon_sym_else] = ACTIONS(4732),
    [anon_sym_LBRACK] = ACTIONS(4730),
    [anon_sym_localparam] = ACTIONS(4732),
    [anon_sym_parameter] = ACTIONS(4732),
    [anon_sym_var] = ACTIONS(4732),
    [anon_sym_import] = ACTIONS(4732),
    [anon_sym_export] = ACTIONS(4732),
    [anon_sym_genvar] = ACTIONS(4732),
    [anon_sym_interconnect] = ACTIONS(4732),
    [anon_sym_typedef] = ACTIONS(4732),
    [anon_sym_enum] = ACTIONS(4732),
    [anon_sym_struct] = ACTIONS(4732),
    [anon_sym_union] = ACTIONS(4732),
    [anon_sym_nettype] = ACTIONS(4732),
    [anon_sym_automatic] = ACTIONS(4732),
    [anon_sym_string] = ACTIONS(4732),
    [anon_sym_chandle] = ACTIONS(4732),
    [anon_sym_event] = ACTIONS(4732),
    [anon_sym_byte] = ACTIONS(4732),
    [anon_sym_shortint] = ACTIONS(4732),
    [anon_sym_int] = ACTIONS(4732),
    [anon_sym_longint] = ACTIONS(4732),
    [anon_sym_integer] = ACTIONS(4732),
    [anon_sym_time] = ACTIONS(4732),
    [anon_sym_bit] = ACTIONS(4732),
    [anon_sym_logic] = ACTIONS(4732),
    [anon_sym_reg] = ACTIONS(4732),
    [anon_sym_shortreal] = ACTIONS(4732),
    [anon_sym_real] = ACTIONS(4732),
    [anon_sym_realtime] = ACTIONS(4732),
    [anon_sym_supply0] = ACTIONS(4732),
    [anon_sym_supply1] = ACTIONS(4732),
    [anon_sym_signed] = ACTIONS(4732),
    [anon_sym_unsigned] = ACTIONS(4732),
    [anon_sym_task] = ACTIONS(4732),
    [anon_sym_assert] = ACTIONS(4732),
    [anon_sym_property] = ACTIONS(4732),
    [anon_sym_assume] = ACTIONS(4732),
    [anon_sym_cover] = ACTIONS(4732),
    [anon_sym_sequence] = ACTIONS(4732),
    [anon_sym_restrict] = ACTIONS(4732),
    [anon_sym_not] = ACTIONS(4732),
    [anon_sym_or] = ACTIONS(4732),
    [anon_sym_and] = ACTIONS(4732),
    [anon_sym_case] = ACTIONS(4732),
    [anon_sym_always] = ACTIONS(4732),
    [anon_sym_covergroup] = ACTIONS(4732),
    [anon_sym_let] = ACTIONS(4732),
    [anon_sym_pulldown] = ACTIONS(4732),
    [anon_sym_pullup] = ACTIONS(4732),
    [anon_sym_cmos] = ACTIONS(4732),
    [anon_sym_rcmos] = ACTIONS(4732),
    [anon_sym_bufif0] = ACTIONS(4732),
    [anon_sym_bufif1] = ACTIONS(4732),
    [anon_sym_notif0] = ACTIONS(4732),
    [anon_sym_notif1] = ACTIONS(4732),
    [anon_sym_nmos] = ACTIONS(4732),
    [anon_sym_pmos] = ACTIONS(4732),
    [anon_sym_rnmos] = ACTIONS(4732),
    [anon_sym_rpmos] = ACTIONS(4732),
    [anon_sym_nand] = ACTIONS(4732),
    [anon_sym_nor] = ACTIONS(4732),
    [anon_sym_xor] = ACTIONS(4732),
    [anon_sym_xnor] = ACTIONS(4732),
    [anon_sym_buf] = ACTIONS(4732),
    [anon_sym_tranif0] = ACTIONS(4732),
    [anon_sym_tranif1] = ACTIONS(4732),
    [anon_sym_rtranif1] = ACTIONS(4732),
    [anon_sym_rtranif0] = ACTIONS(4732),
    [anon_sym_tran] = ACTIONS(4732),
    [anon_sym_rtran] = ACTIONS(4732),
    [anon_sym_generate] = ACTIONS(4732),
    [anon_sym_endgenerate] = ACTIONS(4732),
    [anon_sym_for] = ACTIONS(4732),
    [anon_sym_initial] = ACTIONS(4732),
    [anon_sym_assign] = ACTIONS(4732),
    [anon_sym_alias] = ACTIONS(4732),
    [anon_sym_always_comb] = ACTIONS(4732),
    [anon_sym_always_latch] = ACTIONS(4732),
    [anon_sym_always_ff] = ACTIONS(4732),
    [anon_sym_final] = ACTIONS(4732),
    [anon_sym_global] = ACTIONS(4732),
    [anon_sym_LPAREN_STAR] = ACTIONS(4730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4730),
    [anon_sym_DOLLARunit] = ACTIONS(4730),
  },
  [4874] = {
    [sym_simple_identifier] = ACTIONS(5294),
    [anon_sym_wire] = ACTIONS(5294),
    [anon_sym_tri] = ACTIONS(5294),
    [anon_sym_tri0] = ACTIONS(5294),
    [anon_sym_tri1] = ACTIONS(5294),
    [anon_sym_wand] = ACTIONS(5294),
    [anon_sym_triand] = ACTIONS(5294),
    [anon_sym_wor] = ACTIONS(5294),
    [anon_sym_trior] = ACTIONS(5294),
    [anon_sym_trireg] = ACTIONS(5294),
    [anon_sym_uwire] = ACTIONS(5294),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_extern] = ACTIONS(5294),
    [anon_sym_interface] = ACTIONS(5294),
    [anon_sym_checker] = ACTIONS(5294),
    [anon_sym_virtual] = ACTIONS(5294),
    [anon_sym_class] = ACTIONS(5294),
    [anon_sym_type] = ACTIONS(5294),
    [anon_sym_DOLLARfatal] = ACTIONS(5292),
    [anon_sym_DOLLARerror] = ACTIONS(5292),
    [anon_sym_DOLLARwarning] = ACTIONS(5292),
    [anon_sym_DOLLARinfo] = ACTIONS(5292),
    [anon_sym_default] = ACTIONS(5294),
    [anon_sym_clocking] = ACTIONS(5294),
    [anon_sym_defparam] = ACTIONS(5294),
    [anon_sym_bind] = ACTIONS(5294),
    [anon_sym_rand] = ACTIONS(5294),
    [anon_sym_const] = ACTIONS(5294),
    [anon_sym_function] = ACTIONS(5294),
    [anon_sym_static] = ACTIONS(5294),
    [anon_sym_constraint] = ACTIONS(5294),
    [anon_sym_if] = ACTIONS(5294),
    [anon_sym_else] = ACTIONS(5294),
    [anon_sym_LBRACK] = ACTIONS(5292),
    [anon_sym_localparam] = ACTIONS(5294),
    [anon_sym_parameter] = ACTIONS(5294),
    [anon_sym_var] = ACTIONS(5294),
    [anon_sym_import] = ACTIONS(5294),
    [anon_sym_export] = ACTIONS(5294),
    [anon_sym_genvar] = ACTIONS(5294),
    [anon_sym_interconnect] = ACTIONS(5294),
    [anon_sym_typedef] = ACTIONS(5294),
    [anon_sym_enum] = ACTIONS(5294),
    [anon_sym_struct] = ACTIONS(5294),
    [anon_sym_union] = ACTIONS(5294),
    [anon_sym_nettype] = ACTIONS(5294),
    [anon_sym_automatic] = ACTIONS(5294),
    [anon_sym_string] = ACTIONS(5294),
    [anon_sym_chandle] = ACTIONS(5294),
    [anon_sym_event] = ACTIONS(5294),
    [anon_sym_byte] = ACTIONS(5294),
    [anon_sym_shortint] = ACTIONS(5294),
    [anon_sym_int] = ACTIONS(5294),
    [anon_sym_longint] = ACTIONS(5294),
    [anon_sym_integer] = ACTIONS(5294),
    [anon_sym_time] = ACTIONS(5294),
    [anon_sym_bit] = ACTIONS(5294),
    [anon_sym_logic] = ACTIONS(5294),
    [anon_sym_reg] = ACTIONS(5294),
    [anon_sym_shortreal] = ACTIONS(5294),
    [anon_sym_real] = ACTIONS(5294),
    [anon_sym_realtime] = ACTIONS(5294),
    [anon_sym_supply0] = ACTIONS(5294),
    [anon_sym_supply1] = ACTIONS(5294),
    [anon_sym_signed] = ACTIONS(5294),
    [anon_sym_unsigned] = ACTIONS(5294),
    [anon_sym_task] = ACTIONS(5294),
    [anon_sym_assert] = ACTIONS(5294),
    [anon_sym_property] = ACTIONS(5294),
    [anon_sym_assume] = ACTIONS(5294),
    [anon_sym_cover] = ACTIONS(5294),
    [anon_sym_sequence] = ACTIONS(5294),
    [anon_sym_restrict] = ACTIONS(5294),
    [anon_sym_not] = ACTIONS(5294),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_and] = ACTIONS(5294),
    [anon_sym_case] = ACTIONS(5294),
    [anon_sym_always] = ACTIONS(5294),
    [anon_sym_covergroup] = ACTIONS(5294),
    [anon_sym_end] = ACTIONS(5294),
    [anon_sym_let] = ACTIONS(5294),
    [anon_sym_pulldown] = ACTIONS(5294),
    [anon_sym_pullup] = ACTIONS(5294),
    [anon_sym_cmos] = ACTIONS(5294),
    [anon_sym_rcmos] = ACTIONS(5294),
    [anon_sym_bufif0] = ACTIONS(5294),
    [anon_sym_bufif1] = ACTIONS(5294),
    [anon_sym_notif0] = ACTIONS(5294),
    [anon_sym_notif1] = ACTIONS(5294),
    [anon_sym_nmos] = ACTIONS(5294),
    [anon_sym_pmos] = ACTIONS(5294),
    [anon_sym_rnmos] = ACTIONS(5294),
    [anon_sym_rpmos] = ACTIONS(5294),
    [anon_sym_nand] = ACTIONS(5294),
    [anon_sym_nor] = ACTIONS(5294),
    [anon_sym_xor] = ACTIONS(5294),
    [anon_sym_xnor] = ACTIONS(5294),
    [anon_sym_buf] = ACTIONS(5294),
    [anon_sym_tranif0] = ACTIONS(5294),
    [anon_sym_tranif1] = ACTIONS(5294),
    [anon_sym_rtranif1] = ACTIONS(5294),
    [anon_sym_rtranif0] = ACTIONS(5294),
    [anon_sym_tran] = ACTIONS(5294),
    [anon_sym_rtran] = ACTIONS(5294),
    [anon_sym_generate] = ACTIONS(5294),
    [anon_sym_for] = ACTIONS(5294),
    [anon_sym_initial] = ACTIONS(5294),
    [anon_sym_assign] = ACTIONS(5294),
    [anon_sym_alias] = ACTIONS(5294),
    [anon_sym_always_comb] = ACTIONS(5294),
    [anon_sym_always_latch] = ACTIONS(5294),
    [anon_sym_always_ff] = ACTIONS(5294),
    [anon_sym_final] = ACTIONS(5294),
    [anon_sym_global] = ACTIONS(5294),
    [anon_sym_LPAREN_STAR] = ACTIONS(5292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5292),
    [anon_sym_DOLLARunit] = ACTIONS(5292),
  },
  [4875] = {
    [sym_simple_identifier] = ACTIONS(6279),
    [anon_sym_wire] = ACTIONS(6279),
    [anon_sym_tri] = ACTIONS(6279),
    [anon_sym_tri0] = ACTIONS(6279),
    [anon_sym_tri1] = ACTIONS(6279),
    [anon_sym_wand] = ACTIONS(6279),
    [anon_sym_triand] = ACTIONS(6279),
    [anon_sym_wor] = ACTIONS(6279),
    [anon_sym_trior] = ACTIONS(6279),
    [anon_sym_trireg] = ACTIONS(6279),
    [anon_sym_uwire] = ACTIONS(6279),
    [anon_sym_SEMI] = ACTIONS(6281),
    [anon_sym_extern] = ACTIONS(6279),
    [anon_sym_interface] = ACTIONS(6279),
    [anon_sym_checker] = ACTIONS(6279),
    [anon_sym_virtual] = ACTIONS(6279),
    [anon_sym_class] = ACTIONS(6279),
    [anon_sym_type] = ACTIONS(6279),
    [anon_sym_DOLLARfatal] = ACTIONS(6281),
    [anon_sym_DOLLARerror] = ACTIONS(6281),
    [anon_sym_DOLLARwarning] = ACTIONS(6281),
    [anon_sym_DOLLARinfo] = ACTIONS(6281),
    [anon_sym_default] = ACTIONS(6279),
    [anon_sym_clocking] = ACTIONS(6279),
    [anon_sym_defparam] = ACTIONS(6279),
    [anon_sym_bind] = ACTIONS(6279),
    [anon_sym_rand] = ACTIONS(6279),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_function] = ACTIONS(6279),
    [anon_sym_static] = ACTIONS(6279),
    [anon_sym_constraint] = ACTIONS(6279),
    [anon_sym_if] = ACTIONS(6279),
    [anon_sym_else] = ACTIONS(6279),
    [anon_sym_LBRACK] = ACTIONS(6281),
    [anon_sym_localparam] = ACTIONS(6279),
    [anon_sym_parameter] = ACTIONS(6279),
    [anon_sym_var] = ACTIONS(6279),
    [anon_sym_import] = ACTIONS(6279),
    [anon_sym_export] = ACTIONS(6279),
    [anon_sym_genvar] = ACTIONS(6279),
    [anon_sym_interconnect] = ACTIONS(6279),
    [anon_sym_typedef] = ACTIONS(6279),
    [anon_sym_enum] = ACTIONS(6279),
    [anon_sym_struct] = ACTIONS(6279),
    [anon_sym_union] = ACTIONS(6279),
    [anon_sym_nettype] = ACTIONS(6279),
    [anon_sym_automatic] = ACTIONS(6279),
    [anon_sym_string] = ACTIONS(6279),
    [anon_sym_chandle] = ACTIONS(6279),
    [anon_sym_event] = ACTIONS(6279),
    [anon_sym_byte] = ACTIONS(6279),
    [anon_sym_shortint] = ACTIONS(6279),
    [anon_sym_int] = ACTIONS(6279),
    [anon_sym_longint] = ACTIONS(6279),
    [anon_sym_integer] = ACTIONS(6279),
    [anon_sym_time] = ACTIONS(6279),
    [anon_sym_bit] = ACTIONS(6279),
    [anon_sym_logic] = ACTIONS(6279),
    [anon_sym_reg] = ACTIONS(6279),
    [anon_sym_shortreal] = ACTIONS(6279),
    [anon_sym_real] = ACTIONS(6279),
    [anon_sym_realtime] = ACTIONS(6279),
    [anon_sym_supply0] = ACTIONS(6279),
    [anon_sym_supply1] = ACTIONS(6279),
    [anon_sym_signed] = ACTIONS(6279),
    [anon_sym_unsigned] = ACTIONS(6279),
    [anon_sym_task] = ACTIONS(6279),
    [anon_sym_assert] = ACTIONS(6279),
    [anon_sym_property] = ACTIONS(6279),
    [anon_sym_assume] = ACTIONS(6279),
    [anon_sym_cover] = ACTIONS(6279),
    [anon_sym_sequence] = ACTIONS(6279),
    [anon_sym_restrict] = ACTIONS(6279),
    [anon_sym_not] = ACTIONS(6279),
    [anon_sym_or] = ACTIONS(6279),
    [anon_sym_and] = ACTIONS(6279),
    [anon_sym_case] = ACTIONS(6279),
    [anon_sym_always] = ACTIONS(6279),
    [anon_sym_covergroup] = ACTIONS(6279),
    [anon_sym_end] = ACTIONS(6279),
    [anon_sym_let] = ACTIONS(6279),
    [anon_sym_pulldown] = ACTIONS(6279),
    [anon_sym_pullup] = ACTIONS(6279),
    [anon_sym_cmos] = ACTIONS(6279),
    [anon_sym_rcmos] = ACTIONS(6279),
    [anon_sym_bufif0] = ACTIONS(6279),
    [anon_sym_bufif1] = ACTIONS(6279),
    [anon_sym_notif0] = ACTIONS(6279),
    [anon_sym_notif1] = ACTIONS(6279),
    [anon_sym_nmos] = ACTIONS(6279),
    [anon_sym_pmos] = ACTIONS(6279),
    [anon_sym_rnmos] = ACTIONS(6279),
    [anon_sym_rpmos] = ACTIONS(6279),
    [anon_sym_nand] = ACTIONS(6279),
    [anon_sym_nor] = ACTIONS(6279),
    [anon_sym_xor] = ACTIONS(6279),
    [anon_sym_xnor] = ACTIONS(6279),
    [anon_sym_buf] = ACTIONS(6279),
    [anon_sym_tranif0] = ACTIONS(6279),
    [anon_sym_tranif1] = ACTIONS(6279),
    [anon_sym_rtranif1] = ACTIONS(6279),
    [anon_sym_rtranif0] = ACTIONS(6279),
    [anon_sym_tran] = ACTIONS(6279),
    [anon_sym_rtran] = ACTIONS(6279),
    [anon_sym_generate] = ACTIONS(6279),
    [anon_sym_for] = ACTIONS(6279),
    [anon_sym_initial] = ACTIONS(6279),
    [anon_sym_assign] = ACTIONS(6279),
    [anon_sym_alias] = ACTIONS(6279),
    [anon_sym_always_comb] = ACTIONS(6279),
    [anon_sym_always_latch] = ACTIONS(6279),
    [anon_sym_always_ff] = ACTIONS(6279),
    [anon_sym_final] = ACTIONS(6279),
    [anon_sym_global] = ACTIONS(6279),
    [anon_sym_LPAREN_STAR] = ACTIONS(6281),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6281),
    [anon_sym_DOLLARunit] = ACTIONS(6281),
  },
  [4876] = {
    [sym_simple_identifier] = ACTIONS(4242),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_rand] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_end] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [4877] = {
    [sym_simple_identifier] = ACTIONS(6131),
    [anon_sym_wire] = ACTIONS(6131),
    [anon_sym_tri] = ACTIONS(6131),
    [anon_sym_tri0] = ACTIONS(6131),
    [anon_sym_tri1] = ACTIONS(6131),
    [anon_sym_wand] = ACTIONS(6131),
    [anon_sym_triand] = ACTIONS(6131),
    [anon_sym_wor] = ACTIONS(6131),
    [anon_sym_trior] = ACTIONS(6131),
    [anon_sym_trireg] = ACTIONS(6131),
    [anon_sym_uwire] = ACTIONS(6131),
    [anon_sym_SEMI] = ACTIONS(6133),
    [anon_sym_extern] = ACTIONS(6131),
    [anon_sym_interface] = ACTIONS(6131),
    [anon_sym_checker] = ACTIONS(6131),
    [anon_sym_virtual] = ACTIONS(6131),
    [anon_sym_class] = ACTIONS(6131),
    [anon_sym_type] = ACTIONS(6131),
    [anon_sym_DOLLARfatal] = ACTIONS(6133),
    [anon_sym_DOLLARerror] = ACTIONS(6133),
    [anon_sym_DOLLARwarning] = ACTIONS(6133),
    [anon_sym_DOLLARinfo] = ACTIONS(6133),
    [anon_sym_default] = ACTIONS(6131),
    [anon_sym_clocking] = ACTIONS(6131),
    [anon_sym_defparam] = ACTIONS(6131),
    [anon_sym_bind] = ACTIONS(6131),
    [anon_sym_rand] = ACTIONS(6131),
    [anon_sym_const] = ACTIONS(6131),
    [anon_sym_function] = ACTIONS(6131),
    [anon_sym_static] = ACTIONS(6131),
    [anon_sym_constraint] = ACTIONS(6131),
    [anon_sym_if] = ACTIONS(6131),
    [anon_sym_else] = ACTIONS(6131),
    [anon_sym_LBRACK] = ACTIONS(6133),
    [anon_sym_localparam] = ACTIONS(6131),
    [anon_sym_parameter] = ACTIONS(6131),
    [anon_sym_var] = ACTIONS(6131),
    [anon_sym_import] = ACTIONS(6131),
    [anon_sym_export] = ACTIONS(6131),
    [anon_sym_genvar] = ACTIONS(6131),
    [anon_sym_interconnect] = ACTIONS(6131),
    [anon_sym_typedef] = ACTIONS(6131),
    [anon_sym_enum] = ACTIONS(6131),
    [anon_sym_struct] = ACTIONS(6131),
    [anon_sym_union] = ACTIONS(6131),
    [anon_sym_nettype] = ACTIONS(6131),
    [anon_sym_automatic] = ACTIONS(6131),
    [anon_sym_string] = ACTIONS(6131),
    [anon_sym_chandle] = ACTIONS(6131),
    [anon_sym_event] = ACTIONS(6131),
    [anon_sym_byte] = ACTIONS(6131),
    [anon_sym_shortint] = ACTIONS(6131),
    [anon_sym_int] = ACTIONS(6131),
    [anon_sym_longint] = ACTIONS(6131),
    [anon_sym_integer] = ACTIONS(6131),
    [anon_sym_time] = ACTIONS(6131),
    [anon_sym_bit] = ACTIONS(6131),
    [anon_sym_logic] = ACTIONS(6131),
    [anon_sym_reg] = ACTIONS(6131),
    [anon_sym_shortreal] = ACTIONS(6131),
    [anon_sym_real] = ACTIONS(6131),
    [anon_sym_realtime] = ACTIONS(6131),
    [anon_sym_supply0] = ACTIONS(6131),
    [anon_sym_supply1] = ACTIONS(6131),
    [anon_sym_signed] = ACTIONS(6131),
    [anon_sym_unsigned] = ACTIONS(6131),
    [anon_sym_task] = ACTIONS(6131),
    [anon_sym_assert] = ACTIONS(6131),
    [anon_sym_property] = ACTIONS(6131),
    [anon_sym_assume] = ACTIONS(6131),
    [anon_sym_cover] = ACTIONS(6131),
    [anon_sym_sequence] = ACTIONS(6131),
    [anon_sym_restrict] = ACTIONS(6131),
    [anon_sym_not] = ACTIONS(6131),
    [anon_sym_or] = ACTIONS(6131),
    [anon_sym_and] = ACTIONS(6131),
    [anon_sym_case] = ACTIONS(6131),
    [anon_sym_always] = ACTIONS(6131),
    [anon_sym_covergroup] = ACTIONS(6131),
    [anon_sym_let] = ACTIONS(6131),
    [anon_sym_pulldown] = ACTIONS(6131),
    [anon_sym_pullup] = ACTIONS(6131),
    [anon_sym_cmos] = ACTIONS(6131),
    [anon_sym_rcmos] = ACTIONS(6131),
    [anon_sym_bufif0] = ACTIONS(6131),
    [anon_sym_bufif1] = ACTIONS(6131),
    [anon_sym_notif0] = ACTIONS(6131),
    [anon_sym_notif1] = ACTIONS(6131),
    [anon_sym_nmos] = ACTIONS(6131),
    [anon_sym_pmos] = ACTIONS(6131),
    [anon_sym_rnmos] = ACTIONS(6131),
    [anon_sym_rpmos] = ACTIONS(6131),
    [anon_sym_nand] = ACTIONS(6131),
    [anon_sym_nor] = ACTIONS(6131),
    [anon_sym_xor] = ACTIONS(6131),
    [anon_sym_xnor] = ACTIONS(6131),
    [anon_sym_buf] = ACTIONS(6131),
    [anon_sym_tranif0] = ACTIONS(6131),
    [anon_sym_tranif1] = ACTIONS(6131),
    [anon_sym_rtranif1] = ACTIONS(6131),
    [anon_sym_rtranif0] = ACTIONS(6131),
    [anon_sym_tran] = ACTIONS(6131),
    [anon_sym_rtran] = ACTIONS(6131),
    [anon_sym_generate] = ACTIONS(6131),
    [anon_sym_endgenerate] = ACTIONS(6131),
    [anon_sym_for] = ACTIONS(6131),
    [anon_sym_initial] = ACTIONS(6131),
    [anon_sym_assign] = ACTIONS(6131),
    [anon_sym_alias] = ACTIONS(6131),
    [anon_sym_always_comb] = ACTIONS(6131),
    [anon_sym_always_latch] = ACTIONS(6131),
    [anon_sym_always_ff] = ACTIONS(6131),
    [anon_sym_final] = ACTIONS(6131),
    [anon_sym_global] = ACTIONS(6131),
    [anon_sym_LPAREN_STAR] = ACTIONS(6133),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6133),
    [anon_sym_DOLLARunit] = ACTIONS(6133),
  },
  [4878] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_rand] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_end] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [4879] = {
    [sym_simple_identifier] = ACTIONS(5298),
    [anon_sym_wire] = ACTIONS(5298),
    [anon_sym_tri] = ACTIONS(5298),
    [anon_sym_tri0] = ACTIONS(5298),
    [anon_sym_tri1] = ACTIONS(5298),
    [anon_sym_wand] = ACTIONS(5298),
    [anon_sym_triand] = ACTIONS(5298),
    [anon_sym_wor] = ACTIONS(5298),
    [anon_sym_trior] = ACTIONS(5298),
    [anon_sym_trireg] = ACTIONS(5298),
    [anon_sym_uwire] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_extern] = ACTIONS(5298),
    [anon_sym_interface] = ACTIONS(5298),
    [anon_sym_checker] = ACTIONS(5298),
    [anon_sym_virtual] = ACTIONS(5298),
    [anon_sym_class] = ACTIONS(5298),
    [anon_sym_type] = ACTIONS(5298),
    [anon_sym_DOLLARfatal] = ACTIONS(5296),
    [anon_sym_DOLLARerror] = ACTIONS(5296),
    [anon_sym_DOLLARwarning] = ACTIONS(5296),
    [anon_sym_DOLLARinfo] = ACTIONS(5296),
    [anon_sym_default] = ACTIONS(5298),
    [anon_sym_clocking] = ACTIONS(5298),
    [anon_sym_defparam] = ACTIONS(5298),
    [anon_sym_bind] = ACTIONS(5298),
    [anon_sym_rand] = ACTIONS(5298),
    [anon_sym_const] = ACTIONS(5298),
    [anon_sym_function] = ACTIONS(5298),
    [anon_sym_static] = ACTIONS(5298),
    [anon_sym_constraint] = ACTIONS(5298),
    [anon_sym_if] = ACTIONS(5298),
    [anon_sym_else] = ACTIONS(5298),
    [anon_sym_LBRACK] = ACTIONS(5296),
    [anon_sym_localparam] = ACTIONS(5298),
    [anon_sym_parameter] = ACTIONS(5298),
    [anon_sym_var] = ACTIONS(5298),
    [anon_sym_import] = ACTIONS(5298),
    [anon_sym_export] = ACTIONS(5298),
    [anon_sym_genvar] = ACTIONS(5298),
    [anon_sym_interconnect] = ACTIONS(5298),
    [anon_sym_typedef] = ACTIONS(5298),
    [anon_sym_enum] = ACTIONS(5298),
    [anon_sym_struct] = ACTIONS(5298),
    [anon_sym_union] = ACTIONS(5298),
    [anon_sym_nettype] = ACTIONS(5298),
    [anon_sym_automatic] = ACTIONS(5298),
    [anon_sym_string] = ACTIONS(5298),
    [anon_sym_chandle] = ACTIONS(5298),
    [anon_sym_event] = ACTIONS(5298),
    [anon_sym_byte] = ACTIONS(5298),
    [anon_sym_shortint] = ACTIONS(5298),
    [anon_sym_int] = ACTIONS(5298),
    [anon_sym_longint] = ACTIONS(5298),
    [anon_sym_integer] = ACTIONS(5298),
    [anon_sym_time] = ACTIONS(5298),
    [anon_sym_bit] = ACTIONS(5298),
    [anon_sym_logic] = ACTIONS(5298),
    [anon_sym_reg] = ACTIONS(5298),
    [anon_sym_shortreal] = ACTIONS(5298),
    [anon_sym_real] = ACTIONS(5298),
    [anon_sym_realtime] = ACTIONS(5298),
    [anon_sym_supply0] = ACTIONS(5298),
    [anon_sym_supply1] = ACTIONS(5298),
    [anon_sym_signed] = ACTIONS(5298),
    [anon_sym_unsigned] = ACTIONS(5298),
    [anon_sym_task] = ACTIONS(5298),
    [anon_sym_assert] = ACTIONS(5298),
    [anon_sym_property] = ACTIONS(5298),
    [anon_sym_assume] = ACTIONS(5298),
    [anon_sym_cover] = ACTIONS(5298),
    [anon_sym_sequence] = ACTIONS(5298),
    [anon_sym_restrict] = ACTIONS(5298),
    [anon_sym_not] = ACTIONS(5298),
    [anon_sym_or] = ACTIONS(5298),
    [anon_sym_and] = ACTIONS(5298),
    [anon_sym_case] = ACTIONS(5298),
    [anon_sym_always] = ACTIONS(5298),
    [anon_sym_covergroup] = ACTIONS(5298),
    [anon_sym_end] = ACTIONS(5298),
    [anon_sym_let] = ACTIONS(5298),
    [anon_sym_pulldown] = ACTIONS(5298),
    [anon_sym_pullup] = ACTIONS(5298),
    [anon_sym_cmos] = ACTIONS(5298),
    [anon_sym_rcmos] = ACTIONS(5298),
    [anon_sym_bufif0] = ACTIONS(5298),
    [anon_sym_bufif1] = ACTIONS(5298),
    [anon_sym_notif0] = ACTIONS(5298),
    [anon_sym_notif1] = ACTIONS(5298),
    [anon_sym_nmos] = ACTIONS(5298),
    [anon_sym_pmos] = ACTIONS(5298),
    [anon_sym_rnmos] = ACTIONS(5298),
    [anon_sym_rpmos] = ACTIONS(5298),
    [anon_sym_nand] = ACTIONS(5298),
    [anon_sym_nor] = ACTIONS(5298),
    [anon_sym_xor] = ACTIONS(5298),
    [anon_sym_xnor] = ACTIONS(5298),
    [anon_sym_buf] = ACTIONS(5298),
    [anon_sym_tranif0] = ACTIONS(5298),
    [anon_sym_tranif1] = ACTIONS(5298),
    [anon_sym_rtranif1] = ACTIONS(5298),
    [anon_sym_rtranif0] = ACTIONS(5298),
    [anon_sym_tran] = ACTIONS(5298),
    [anon_sym_rtran] = ACTIONS(5298),
    [anon_sym_generate] = ACTIONS(5298),
    [anon_sym_for] = ACTIONS(5298),
    [anon_sym_initial] = ACTIONS(5298),
    [anon_sym_assign] = ACTIONS(5298),
    [anon_sym_alias] = ACTIONS(5298),
    [anon_sym_always_comb] = ACTIONS(5298),
    [anon_sym_always_latch] = ACTIONS(5298),
    [anon_sym_always_ff] = ACTIONS(5298),
    [anon_sym_final] = ACTIONS(5298),
    [anon_sym_global] = ACTIONS(5298),
    [anon_sym_LPAREN_STAR] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5296),
    [anon_sym_DOLLARunit] = ACTIONS(5296),
  },
  [4880] = {
    [sym_simple_identifier] = ACTIONS(5282),
    [anon_sym_wire] = ACTIONS(5282),
    [anon_sym_tri] = ACTIONS(5282),
    [anon_sym_tri0] = ACTIONS(5282),
    [anon_sym_tri1] = ACTIONS(5282),
    [anon_sym_wand] = ACTIONS(5282),
    [anon_sym_triand] = ACTIONS(5282),
    [anon_sym_wor] = ACTIONS(5282),
    [anon_sym_trior] = ACTIONS(5282),
    [anon_sym_trireg] = ACTIONS(5282),
    [anon_sym_uwire] = ACTIONS(5282),
    [anon_sym_SEMI] = ACTIONS(5280),
    [anon_sym_extern] = ACTIONS(5282),
    [anon_sym_interface] = ACTIONS(5282),
    [anon_sym_checker] = ACTIONS(5282),
    [anon_sym_virtual] = ACTIONS(5282),
    [anon_sym_class] = ACTIONS(5282),
    [anon_sym_type] = ACTIONS(5282),
    [anon_sym_DOLLARfatal] = ACTIONS(5280),
    [anon_sym_DOLLARerror] = ACTIONS(5280),
    [anon_sym_DOLLARwarning] = ACTIONS(5280),
    [anon_sym_DOLLARinfo] = ACTIONS(5280),
    [anon_sym_default] = ACTIONS(5282),
    [anon_sym_clocking] = ACTIONS(5282),
    [anon_sym_defparam] = ACTIONS(5282),
    [anon_sym_bind] = ACTIONS(5282),
    [anon_sym_rand] = ACTIONS(5282),
    [anon_sym_const] = ACTIONS(5282),
    [anon_sym_function] = ACTIONS(5282),
    [anon_sym_static] = ACTIONS(5282),
    [anon_sym_constraint] = ACTIONS(5282),
    [anon_sym_if] = ACTIONS(5282),
    [anon_sym_else] = ACTIONS(5282),
    [anon_sym_LBRACK] = ACTIONS(5280),
    [anon_sym_localparam] = ACTIONS(5282),
    [anon_sym_parameter] = ACTIONS(5282),
    [anon_sym_var] = ACTIONS(5282),
    [anon_sym_import] = ACTIONS(5282),
    [anon_sym_export] = ACTIONS(5282),
    [anon_sym_genvar] = ACTIONS(5282),
    [anon_sym_interconnect] = ACTIONS(5282),
    [anon_sym_typedef] = ACTIONS(5282),
    [anon_sym_enum] = ACTIONS(5282),
    [anon_sym_struct] = ACTIONS(5282),
    [anon_sym_union] = ACTIONS(5282),
    [anon_sym_nettype] = ACTIONS(5282),
    [anon_sym_automatic] = ACTIONS(5282),
    [anon_sym_string] = ACTIONS(5282),
    [anon_sym_chandle] = ACTIONS(5282),
    [anon_sym_event] = ACTIONS(5282),
    [anon_sym_byte] = ACTIONS(5282),
    [anon_sym_shortint] = ACTIONS(5282),
    [anon_sym_int] = ACTIONS(5282),
    [anon_sym_longint] = ACTIONS(5282),
    [anon_sym_integer] = ACTIONS(5282),
    [anon_sym_time] = ACTIONS(5282),
    [anon_sym_bit] = ACTIONS(5282),
    [anon_sym_logic] = ACTIONS(5282),
    [anon_sym_reg] = ACTIONS(5282),
    [anon_sym_shortreal] = ACTIONS(5282),
    [anon_sym_real] = ACTIONS(5282),
    [anon_sym_realtime] = ACTIONS(5282),
    [anon_sym_supply0] = ACTIONS(5282),
    [anon_sym_supply1] = ACTIONS(5282),
    [anon_sym_signed] = ACTIONS(5282),
    [anon_sym_unsigned] = ACTIONS(5282),
    [anon_sym_task] = ACTIONS(5282),
    [anon_sym_assert] = ACTIONS(5282),
    [anon_sym_property] = ACTIONS(5282),
    [anon_sym_assume] = ACTIONS(5282),
    [anon_sym_cover] = ACTIONS(5282),
    [anon_sym_sequence] = ACTIONS(5282),
    [anon_sym_restrict] = ACTIONS(5282),
    [anon_sym_not] = ACTIONS(5282),
    [anon_sym_or] = ACTIONS(5282),
    [anon_sym_and] = ACTIONS(5282),
    [anon_sym_case] = ACTIONS(5282),
    [anon_sym_always] = ACTIONS(5282),
    [anon_sym_covergroup] = ACTIONS(5282),
    [anon_sym_let] = ACTIONS(5282),
    [anon_sym_pulldown] = ACTIONS(5282),
    [anon_sym_pullup] = ACTIONS(5282),
    [anon_sym_cmos] = ACTIONS(5282),
    [anon_sym_rcmos] = ACTIONS(5282),
    [anon_sym_bufif0] = ACTIONS(5282),
    [anon_sym_bufif1] = ACTIONS(5282),
    [anon_sym_notif0] = ACTIONS(5282),
    [anon_sym_notif1] = ACTIONS(5282),
    [anon_sym_nmos] = ACTIONS(5282),
    [anon_sym_pmos] = ACTIONS(5282),
    [anon_sym_rnmos] = ACTIONS(5282),
    [anon_sym_rpmos] = ACTIONS(5282),
    [anon_sym_nand] = ACTIONS(5282),
    [anon_sym_nor] = ACTIONS(5282),
    [anon_sym_xor] = ACTIONS(5282),
    [anon_sym_xnor] = ACTIONS(5282),
    [anon_sym_buf] = ACTIONS(5282),
    [anon_sym_tranif0] = ACTIONS(5282),
    [anon_sym_tranif1] = ACTIONS(5282),
    [anon_sym_rtranif1] = ACTIONS(5282),
    [anon_sym_rtranif0] = ACTIONS(5282),
    [anon_sym_tran] = ACTIONS(5282),
    [anon_sym_rtran] = ACTIONS(5282),
    [anon_sym_generate] = ACTIONS(5282),
    [anon_sym_endgenerate] = ACTIONS(5282),
    [anon_sym_for] = ACTIONS(5282),
    [anon_sym_initial] = ACTIONS(5282),
    [anon_sym_assign] = ACTIONS(5282),
    [anon_sym_alias] = ACTIONS(5282),
    [anon_sym_always_comb] = ACTIONS(5282),
    [anon_sym_always_latch] = ACTIONS(5282),
    [anon_sym_always_ff] = ACTIONS(5282),
    [anon_sym_final] = ACTIONS(5282),
    [anon_sym_global] = ACTIONS(5282),
    [anon_sym_LPAREN_STAR] = ACTIONS(5280),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5280),
    [anon_sym_DOLLARunit] = ACTIONS(5280),
  },
  [4881] = {
    [sym_simple_identifier] = ACTIONS(6283),
    [anon_sym_wire] = ACTIONS(6283),
    [anon_sym_tri] = ACTIONS(6283),
    [anon_sym_tri0] = ACTIONS(6283),
    [anon_sym_tri1] = ACTIONS(6283),
    [anon_sym_wand] = ACTIONS(6283),
    [anon_sym_triand] = ACTIONS(6283),
    [anon_sym_wor] = ACTIONS(6283),
    [anon_sym_trior] = ACTIONS(6283),
    [anon_sym_trireg] = ACTIONS(6283),
    [anon_sym_uwire] = ACTIONS(6283),
    [anon_sym_SEMI] = ACTIONS(6285),
    [anon_sym_extern] = ACTIONS(6283),
    [anon_sym_interface] = ACTIONS(6283),
    [anon_sym_checker] = ACTIONS(6283),
    [anon_sym_virtual] = ACTIONS(6283),
    [anon_sym_class] = ACTIONS(6283),
    [anon_sym_type] = ACTIONS(6283),
    [anon_sym_DOLLARfatal] = ACTIONS(6285),
    [anon_sym_DOLLARerror] = ACTIONS(6285),
    [anon_sym_DOLLARwarning] = ACTIONS(6285),
    [anon_sym_DOLLARinfo] = ACTIONS(6285),
    [anon_sym_default] = ACTIONS(6283),
    [anon_sym_clocking] = ACTIONS(6283),
    [anon_sym_defparam] = ACTIONS(6283),
    [anon_sym_bind] = ACTIONS(6283),
    [anon_sym_rand] = ACTIONS(6283),
    [anon_sym_const] = ACTIONS(6283),
    [anon_sym_function] = ACTIONS(6283),
    [anon_sym_static] = ACTIONS(6283),
    [anon_sym_constraint] = ACTIONS(6283),
    [anon_sym_if] = ACTIONS(6283),
    [anon_sym_else] = ACTIONS(6283),
    [anon_sym_LBRACK] = ACTIONS(6285),
    [anon_sym_localparam] = ACTIONS(6283),
    [anon_sym_parameter] = ACTIONS(6283),
    [anon_sym_var] = ACTIONS(6283),
    [anon_sym_import] = ACTIONS(6283),
    [anon_sym_export] = ACTIONS(6283),
    [anon_sym_genvar] = ACTIONS(6283),
    [anon_sym_interconnect] = ACTIONS(6283),
    [anon_sym_typedef] = ACTIONS(6283),
    [anon_sym_enum] = ACTIONS(6283),
    [anon_sym_struct] = ACTIONS(6283),
    [anon_sym_union] = ACTIONS(6283),
    [anon_sym_nettype] = ACTIONS(6283),
    [anon_sym_automatic] = ACTIONS(6283),
    [anon_sym_string] = ACTIONS(6283),
    [anon_sym_chandle] = ACTIONS(6283),
    [anon_sym_event] = ACTIONS(6283),
    [anon_sym_byte] = ACTIONS(6283),
    [anon_sym_shortint] = ACTIONS(6283),
    [anon_sym_int] = ACTIONS(6283),
    [anon_sym_longint] = ACTIONS(6283),
    [anon_sym_integer] = ACTIONS(6283),
    [anon_sym_time] = ACTIONS(6283),
    [anon_sym_bit] = ACTIONS(6283),
    [anon_sym_logic] = ACTIONS(6283),
    [anon_sym_reg] = ACTIONS(6283),
    [anon_sym_shortreal] = ACTIONS(6283),
    [anon_sym_real] = ACTIONS(6283),
    [anon_sym_realtime] = ACTIONS(6283),
    [anon_sym_supply0] = ACTIONS(6283),
    [anon_sym_supply1] = ACTIONS(6283),
    [anon_sym_signed] = ACTIONS(6283),
    [anon_sym_unsigned] = ACTIONS(6283),
    [anon_sym_task] = ACTIONS(6283),
    [anon_sym_assert] = ACTIONS(6283),
    [anon_sym_property] = ACTIONS(6283),
    [anon_sym_assume] = ACTIONS(6283),
    [anon_sym_cover] = ACTIONS(6283),
    [anon_sym_sequence] = ACTIONS(6283),
    [anon_sym_restrict] = ACTIONS(6283),
    [anon_sym_not] = ACTIONS(6283),
    [anon_sym_or] = ACTIONS(6283),
    [anon_sym_and] = ACTIONS(6283),
    [anon_sym_case] = ACTIONS(6283),
    [anon_sym_always] = ACTIONS(6283),
    [anon_sym_covergroup] = ACTIONS(6283),
    [anon_sym_end] = ACTIONS(6283),
    [anon_sym_let] = ACTIONS(6283),
    [anon_sym_pulldown] = ACTIONS(6283),
    [anon_sym_pullup] = ACTIONS(6283),
    [anon_sym_cmos] = ACTIONS(6283),
    [anon_sym_rcmos] = ACTIONS(6283),
    [anon_sym_bufif0] = ACTIONS(6283),
    [anon_sym_bufif1] = ACTIONS(6283),
    [anon_sym_notif0] = ACTIONS(6283),
    [anon_sym_notif1] = ACTIONS(6283),
    [anon_sym_nmos] = ACTIONS(6283),
    [anon_sym_pmos] = ACTIONS(6283),
    [anon_sym_rnmos] = ACTIONS(6283),
    [anon_sym_rpmos] = ACTIONS(6283),
    [anon_sym_nand] = ACTIONS(6283),
    [anon_sym_nor] = ACTIONS(6283),
    [anon_sym_xor] = ACTIONS(6283),
    [anon_sym_xnor] = ACTIONS(6283),
    [anon_sym_buf] = ACTIONS(6283),
    [anon_sym_tranif0] = ACTIONS(6283),
    [anon_sym_tranif1] = ACTIONS(6283),
    [anon_sym_rtranif1] = ACTIONS(6283),
    [anon_sym_rtranif0] = ACTIONS(6283),
    [anon_sym_tran] = ACTIONS(6283),
    [anon_sym_rtran] = ACTIONS(6283),
    [anon_sym_generate] = ACTIONS(6283),
    [anon_sym_for] = ACTIONS(6283),
    [anon_sym_initial] = ACTIONS(6283),
    [anon_sym_assign] = ACTIONS(6283),
    [anon_sym_alias] = ACTIONS(6283),
    [anon_sym_always_comb] = ACTIONS(6283),
    [anon_sym_always_latch] = ACTIONS(6283),
    [anon_sym_always_ff] = ACTIONS(6283),
    [anon_sym_final] = ACTIONS(6283),
    [anon_sym_global] = ACTIONS(6283),
    [anon_sym_LPAREN_STAR] = ACTIONS(6285),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6285),
    [anon_sym_DOLLARunit] = ACTIONS(6285),
  },
  [4882] = {
    [sym_simple_identifier] = ACTIONS(5965),
    [anon_sym_wire] = ACTIONS(5965),
    [anon_sym_tri] = ACTIONS(5965),
    [anon_sym_tri0] = ACTIONS(5965),
    [anon_sym_tri1] = ACTIONS(5965),
    [anon_sym_wand] = ACTIONS(5965),
    [anon_sym_triand] = ACTIONS(5965),
    [anon_sym_wor] = ACTIONS(5965),
    [anon_sym_trior] = ACTIONS(5965),
    [anon_sym_trireg] = ACTIONS(5965),
    [anon_sym_uwire] = ACTIONS(5965),
    [anon_sym_SEMI] = ACTIONS(5967),
    [anon_sym_extern] = ACTIONS(5965),
    [anon_sym_interface] = ACTIONS(5965),
    [anon_sym_checker] = ACTIONS(5965),
    [anon_sym_virtual] = ACTIONS(5965),
    [anon_sym_class] = ACTIONS(5965),
    [anon_sym_type] = ACTIONS(5965),
    [anon_sym_DOLLARfatal] = ACTIONS(5967),
    [anon_sym_DOLLARerror] = ACTIONS(5967),
    [anon_sym_DOLLARwarning] = ACTIONS(5967),
    [anon_sym_DOLLARinfo] = ACTIONS(5967),
    [anon_sym_default] = ACTIONS(5965),
    [anon_sym_clocking] = ACTIONS(5965),
    [anon_sym_defparam] = ACTIONS(5965),
    [anon_sym_bind] = ACTIONS(5965),
    [anon_sym_rand] = ACTIONS(5965),
    [anon_sym_const] = ACTIONS(5965),
    [anon_sym_function] = ACTIONS(5965),
    [anon_sym_static] = ACTIONS(5965),
    [anon_sym_constraint] = ACTIONS(5965),
    [anon_sym_if] = ACTIONS(5965),
    [anon_sym_else] = ACTIONS(11173),
    [anon_sym_LBRACK] = ACTIONS(5967),
    [anon_sym_localparam] = ACTIONS(5965),
    [anon_sym_parameter] = ACTIONS(5965),
    [anon_sym_var] = ACTIONS(5965),
    [anon_sym_import] = ACTIONS(5965),
    [anon_sym_export] = ACTIONS(5965),
    [anon_sym_genvar] = ACTIONS(5965),
    [anon_sym_interconnect] = ACTIONS(5965),
    [anon_sym_typedef] = ACTIONS(5965),
    [anon_sym_enum] = ACTIONS(5965),
    [anon_sym_struct] = ACTIONS(5965),
    [anon_sym_union] = ACTIONS(5965),
    [anon_sym_nettype] = ACTIONS(5965),
    [anon_sym_automatic] = ACTIONS(5965),
    [anon_sym_string] = ACTIONS(5965),
    [anon_sym_chandle] = ACTIONS(5965),
    [anon_sym_event] = ACTIONS(5965),
    [anon_sym_byte] = ACTIONS(5965),
    [anon_sym_shortint] = ACTIONS(5965),
    [anon_sym_int] = ACTIONS(5965),
    [anon_sym_longint] = ACTIONS(5965),
    [anon_sym_integer] = ACTIONS(5965),
    [anon_sym_time] = ACTIONS(5965),
    [anon_sym_bit] = ACTIONS(5965),
    [anon_sym_logic] = ACTIONS(5965),
    [anon_sym_reg] = ACTIONS(5965),
    [anon_sym_shortreal] = ACTIONS(5965),
    [anon_sym_real] = ACTIONS(5965),
    [anon_sym_realtime] = ACTIONS(5965),
    [anon_sym_supply0] = ACTIONS(5965),
    [anon_sym_supply1] = ACTIONS(5965),
    [anon_sym_signed] = ACTIONS(5965),
    [anon_sym_unsigned] = ACTIONS(5965),
    [anon_sym_task] = ACTIONS(5965),
    [anon_sym_assert] = ACTIONS(5965),
    [anon_sym_property] = ACTIONS(5965),
    [anon_sym_assume] = ACTIONS(5965),
    [anon_sym_cover] = ACTIONS(5965),
    [anon_sym_sequence] = ACTIONS(5965),
    [anon_sym_restrict] = ACTIONS(5965),
    [anon_sym_not] = ACTIONS(5965),
    [anon_sym_or] = ACTIONS(5965),
    [anon_sym_and] = ACTIONS(5965),
    [anon_sym_case] = ACTIONS(5965),
    [anon_sym_always] = ACTIONS(5965),
    [anon_sym_covergroup] = ACTIONS(5965),
    [anon_sym_let] = ACTIONS(5965),
    [anon_sym_pulldown] = ACTIONS(5965),
    [anon_sym_pullup] = ACTIONS(5965),
    [anon_sym_cmos] = ACTIONS(5965),
    [anon_sym_rcmos] = ACTIONS(5965),
    [anon_sym_bufif0] = ACTIONS(5965),
    [anon_sym_bufif1] = ACTIONS(5965),
    [anon_sym_notif0] = ACTIONS(5965),
    [anon_sym_notif1] = ACTIONS(5965),
    [anon_sym_nmos] = ACTIONS(5965),
    [anon_sym_pmos] = ACTIONS(5965),
    [anon_sym_rnmos] = ACTIONS(5965),
    [anon_sym_rpmos] = ACTIONS(5965),
    [anon_sym_nand] = ACTIONS(5965),
    [anon_sym_nor] = ACTIONS(5965),
    [anon_sym_xor] = ACTIONS(5965),
    [anon_sym_xnor] = ACTIONS(5965),
    [anon_sym_buf] = ACTIONS(5965),
    [anon_sym_tranif0] = ACTIONS(5965),
    [anon_sym_tranif1] = ACTIONS(5965),
    [anon_sym_rtranif1] = ACTIONS(5965),
    [anon_sym_rtranif0] = ACTIONS(5965),
    [anon_sym_tran] = ACTIONS(5965),
    [anon_sym_rtran] = ACTIONS(5965),
    [anon_sym_generate] = ACTIONS(5965),
    [anon_sym_endgenerate] = ACTIONS(5965),
    [anon_sym_for] = ACTIONS(5965),
    [anon_sym_initial] = ACTIONS(5965),
    [anon_sym_assign] = ACTIONS(5965),
    [anon_sym_alias] = ACTIONS(5965),
    [anon_sym_always_comb] = ACTIONS(5965),
    [anon_sym_always_latch] = ACTIONS(5965),
    [anon_sym_always_ff] = ACTIONS(5965),
    [anon_sym_final] = ACTIONS(5965),
    [anon_sym_global] = ACTIONS(5965),
    [anon_sym_LPAREN_STAR] = ACTIONS(5967),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5967),
    [anon_sym_DOLLARunit] = ACTIONS(5967),
  },
  [4883] = {
    [sym_simple_identifier] = ACTIONS(4300),
    [anon_sym_wire] = ACTIONS(4300),
    [anon_sym_tri] = ACTIONS(4300),
    [anon_sym_tri0] = ACTIONS(4300),
    [anon_sym_tri1] = ACTIONS(4300),
    [anon_sym_wand] = ACTIONS(4300),
    [anon_sym_triand] = ACTIONS(4300),
    [anon_sym_wor] = ACTIONS(4300),
    [anon_sym_trior] = ACTIONS(4300),
    [anon_sym_trireg] = ACTIONS(4300),
    [anon_sym_uwire] = ACTIONS(4300),
    [anon_sym_SEMI] = ACTIONS(4298),
    [anon_sym_extern] = ACTIONS(4300),
    [anon_sym_interface] = ACTIONS(4300),
    [anon_sym_checker] = ACTIONS(4300),
    [anon_sym_virtual] = ACTIONS(4300),
    [anon_sym_class] = ACTIONS(4300),
    [anon_sym_type] = ACTIONS(4300),
    [anon_sym_DOLLARfatal] = ACTIONS(4298),
    [anon_sym_DOLLARerror] = ACTIONS(4298),
    [anon_sym_DOLLARwarning] = ACTIONS(4298),
    [anon_sym_DOLLARinfo] = ACTIONS(4298),
    [anon_sym_default] = ACTIONS(4300),
    [anon_sym_clocking] = ACTIONS(4300),
    [anon_sym_defparam] = ACTIONS(4300),
    [anon_sym_bind] = ACTIONS(4300),
    [anon_sym_rand] = ACTIONS(4300),
    [anon_sym_const] = ACTIONS(4300),
    [anon_sym_function] = ACTIONS(4300),
    [anon_sym_static] = ACTIONS(4300),
    [anon_sym_constraint] = ACTIONS(4300),
    [anon_sym_if] = ACTIONS(4300),
    [anon_sym_else] = ACTIONS(4300),
    [anon_sym_LBRACK] = ACTIONS(4298),
    [anon_sym_localparam] = ACTIONS(4300),
    [anon_sym_parameter] = ACTIONS(4300),
    [anon_sym_var] = ACTIONS(4300),
    [anon_sym_import] = ACTIONS(4300),
    [anon_sym_export] = ACTIONS(4300),
    [anon_sym_genvar] = ACTIONS(4300),
    [anon_sym_interconnect] = ACTIONS(4300),
    [anon_sym_typedef] = ACTIONS(4300),
    [anon_sym_enum] = ACTIONS(4300),
    [anon_sym_struct] = ACTIONS(4300),
    [anon_sym_union] = ACTIONS(4300),
    [anon_sym_nettype] = ACTIONS(4300),
    [anon_sym_automatic] = ACTIONS(4300),
    [anon_sym_string] = ACTIONS(4300),
    [anon_sym_chandle] = ACTIONS(4300),
    [anon_sym_event] = ACTIONS(4300),
    [anon_sym_byte] = ACTIONS(4300),
    [anon_sym_shortint] = ACTIONS(4300),
    [anon_sym_int] = ACTIONS(4300),
    [anon_sym_longint] = ACTIONS(4300),
    [anon_sym_integer] = ACTIONS(4300),
    [anon_sym_time] = ACTIONS(4300),
    [anon_sym_bit] = ACTIONS(4300),
    [anon_sym_logic] = ACTIONS(4300),
    [anon_sym_reg] = ACTIONS(4300),
    [anon_sym_shortreal] = ACTIONS(4300),
    [anon_sym_real] = ACTIONS(4300),
    [anon_sym_realtime] = ACTIONS(4300),
    [anon_sym_supply0] = ACTIONS(4300),
    [anon_sym_supply1] = ACTIONS(4300),
    [anon_sym_signed] = ACTIONS(4300),
    [anon_sym_unsigned] = ACTIONS(4300),
    [anon_sym_task] = ACTIONS(4300),
    [anon_sym_assert] = ACTIONS(4300),
    [anon_sym_property] = ACTIONS(4300),
    [anon_sym_assume] = ACTIONS(4300),
    [anon_sym_cover] = ACTIONS(4300),
    [anon_sym_sequence] = ACTIONS(4300),
    [anon_sym_restrict] = ACTIONS(4300),
    [anon_sym_not] = ACTIONS(4300),
    [anon_sym_or] = ACTIONS(4300),
    [anon_sym_and] = ACTIONS(4300),
    [anon_sym_case] = ACTIONS(4300),
    [anon_sym_always] = ACTIONS(4300),
    [anon_sym_covergroup] = ACTIONS(4300),
    [anon_sym_let] = ACTIONS(4300),
    [anon_sym_pulldown] = ACTIONS(4300),
    [anon_sym_pullup] = ACTIONS(4300),
    [anon_sym_cmos] = ACTIONS(4300),
    [anon_sym_rcmos] = ACTIONS(4300),
    [anon_sym_bufif0] = ACTIONS(4300),
    [anon_sym_bufif1] = ACTIONS(4300),
    [anon_sym_notif0] = ACTIONS(4300),
    [anon_sym_notif1] = ACTIONS(4300),
    [anon_sym_nmos] = ACTIONS(4300),
    [anon_sym_pmos] = ACTIONS(4300),
    [anon_sym_rnmos] = ACTIONS(4300),
    [anon_sym_rpmos] = ACTIONS(4300),
    [anon_sym_nand] = ACTIONS(4300),
    [anon_sym_nor] = ACTIONS(4300),
    [anon_sym_xor] = ACTIONS(4300),
    [anon_sym_xnor] = ACTIONS(4300),
    [anon_sym_buf] = ACTIONS(4300),
    [anon_sym_tranif0] = ACTIONS(4300),
    [anon_sym_tranif1] = ACTIONS(4300),
    [anon_sym_rtranif1] = ACTIONS(4300),
    [anon_sym_rtranif0] = ACTIONS(4300),
    [anon_sym_tran] = ACTIONS(4300),
    [anon_sym_rtran] = ACTIONS(4300),
    [anon_sym_generate] = ACTIONS(4300),
    [anon_sym_endgenerate] = ACTIONS(4300),
    [anon_sym_for] = ACTIONS(4300),
    [anon_sym_initial] = ACTIONS(4300),
    [anon_sym_assign] = ACTIONS(4300),
    [anon_sym_alias] = ACTIONS(4300),
    [anon_sym_always_comb] = ACTIONS(4300),
    [anon_sym_always_latch] = ACTIONS(4300),
    [anon_sym_always_ff] = ACTIONS(4300),
    [anon_sym_final] = ACTIONS(4300),
    [anon_sym_global] = ACTIONS(4300),
    [anon_sym_LPAREN_STAR] = ACTIONS(4298),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4298),
    [anon_sym_DOLLARunit] = ACTIONS(4298),
  },
  [4884] = {
    [sym_simple_identifier] = ACTIONS(6457),
    [anon_sym_wire] = ACTIONS(6457),
    [anon_sym_tri] = ACTIONS(6457),
    [anon_sym_tri0] = ACTIONS(6457),
    [anon_sym_tri1] = ACTIONS(6457),
    [anon_sym_wand] = ACTIONS(6457),
    [anon_sym_triand] = ACTIONS(6457),
    [anon_sym_wor] = ACTIONS(6457),
    [anon_sym_trior] = ACTIONS(6457),
    [anon_sym_trireg] = ACTIONS(6457),
    [anon_sym_uwire] = ACTIONS(6457),
    [anon_sym_SEMI] = ACTIONS(6459),
    [anon_sym_extern] = ACTIONS(6457),
    [anon_sym_interface] = ACTIONS(6457),
    [anon_sym_checker] = ACTIONS(6457),
    [anon_sym_virtual] = ACTIONS(6457),
    [anon_sym_class] = ACTIONS(6457),
    [anon_sym_type] = ACTIONS(6457),
    [anon_sym_DOLLARfatal] = ACTIONS(6459),
    [anon_sym_DOLLARerror] = ACTIONS(6459),
    [anon_sym_DOLLARwarning] = ACTIONS(6459),
    [anon_sym_DOLLARinfo] = ACTIONS(6459),
    [anon_sym_default] = ACTIONS(6457),
    [anon_sym_clocking] = ACTIONS(6457),
    [anon_sym_defparam] = ACTIONS(6457),
    [anon_sym_bind] = ACTIONS(6457),
    [anon_sym_rand] = ACTIONS(6457),
    [anon_sym_const] = ACTIONS(6457),
    [anon_sym_function] = ACTIONS(6457),
    [anon_sym_static] = ACTIONS(6457),
    [anon_sym_constraint] = ACTIONS(6457),
    [anon_sym_if] = ACTIONS(6457),
    [anon_sym_else] = ACTIONS(6457),
    [anon_sym_LBRACK] = ACTIONS(6459),
    [anon_sym_localparam] = ACTIONS(6457),
    [anon_sym_parameter] = ACTIONS(6457),
    [anon_sym_var] = ACTIONS(6457),
    [anon_sym_import] = ACTIONS(6457),
    [anon_sym_export] = ACTIONS(6457),
    [anon_sym_genvar] = ACTIONS(6457),
    [anon_sym_interconnect] = ACTIONS(6457),
    [anon_sym_typedef] = ACTIONS(6457),
    [anon_sym_enum] = ACTIONS(6457),
    [anon_sym_struct] = ACTIONS(6457),
    [anon_sym_union] = ACTIONS(6457),
    [anon_sym_nettype] = ACTIONS(6457),
    [anon_sym_automatic] = ACTIONS(6457),
    [anon_sym_string] = ACTIONS(6457),
    [anon_sym_chandle] = ACTIONS(6457),
    [anon_sym_event] = ACTIONS(6457),
    [anon_sym_byte] = ACTIONS(6457),
    [anon_sym_shortint] = ACTIONS(6457),
    [anon_sym_int] = ACTIONS(6457),
    [anon_sym_longint] = ACTIONS(6457),
    [anon_sym_integer] = ACTIONS(6457),
    [anon_sym_time] = ACTIONS(6457),
    [anon_sym_bit] = ACTIONS(6457),
    [anon_sym_logic] = ACTIONS(6457),
    [anon_sym_reg] = ACTIONS(6457),
    [anon_sym_shortreal] = ACTIONS(6457),
    [anon_sym_real] = ACTIONS(6457),
    [anon_sym_realtime] = ACTIONS(6457),
    [anon_sym_supply0] = ACTIONS(6457),
    [anon_sym_supply1] = ACTIONS(6457),
    [anon_sym_signed] = ACTIONS(6457),
    [anon_sym_unsigned] = ACTIONS(6457),
    [anon_sym_task] = ACTIONS(6457),
    [anon_sym_assert] = ACTIONS(6457),
    [anon_sym_property] = ACTIONS(6457),
    [anon_sym_assume] = ACTIONS(6457),
    [anon_sym_cover] = ACTIONS(6457),
    [anon_sym_sequence] = ACTIONS(6457),
    [anon_sym_restrict] = ACTIONS(6457),
    [anon_sym_not] = ACTIONS(6457),
    [anon_sym_or] = ACTIONS(6457),
    [anon_sym_and] = ACTIONS(6457),
    [anon_sym_case] = ACTIONS(6457),
    [anon_sym_always] = ACTIONS(6457),
    [anon_sym_covergroup] = ACTIONS(6457),
    [anon_sym_let] = ACTIONS(6457),
    [anon_sym_pulldown] = ACTIONS(6457),
    [anon_sym_pullup] = ACTIONS(6457),
    [anon_sym_cmos] = ACTIONS(6457),
    [anon_sym_rcmos] = ACTIONS(6457),
    [anon_sym_bufif0] = ACTIONS(6457),
    [anon_sym_bufif1] = ACTIONS(6457),
    [anon_sym_notif0] = ACTIONS(6457),
    [anon_sym_notif1] = ACTIONS(6457),
    [anon_sym_nmos] = ACTIONS(6457),
    [anon_sym_pmos] = ACTIONS(6457),
    [anon_sym_rnmos] = ACTIONS(6457),
    [anon_sym_rpmos] = ACTIONS(6457),
    [anon_sym_nand] = ACTIONS(6457),
    [anon_sym_nor] = ACTIONS(6457),
    [anon_sym_xor] = ACTIONS(6457),
    [anon_sym_xnor] = ACTIONS(6457),
    [anon_sym_buf] = ACTIONS(6457),
    [anon_sym_tranif0] = ACTIONS(6457),
    [anon_sym_tranif1] = ACTIONS(6457),
    [anon_sym_rtranif1] = ACTIONS(6457),
    [anon_sym_rtranif0] = ACTIONS(6457),
    [anon_sym_tran] = ACTIONS(6457),
    [anon_sym_rtran] = ACTIONS(6457),
    [anon_sym_generate] = ACTIONS(6457),
    [anon_sym_endgenerate] = ACTIONS(6457),
    [anon_sym_for] = ACTIONS(6457),
    [anon_sym_initial] = ACTIONS(6457),
    [anon_sym_assign] = ACTIONS(6457),
    [anon_sym_alias] = ACTIONS(6457),
    [anon_sym_always_comb] = ACTIONS(6457),
    [anon_sym_always_latch] = ACTIONS(6457),
    [anon_sym_always_ff] = ACTIONS(6457),
    [anon_sym_final] = ACTIONS(6457),
    [anon_sym_global] = ACTIONS(6457),
    [anon_sym_LPAREN_STAR] = ACTIONS(6459),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6459),
    [anon_sym_DOLLARunit] = ACTIONS(6459),
  },
  [4885] = {
    [sym_simple_identifier] = ACTIONS(5186),
    [anon_sym_wire] = ACTIONS(5186),
    [anon_sym_tri] = ACTIONS(5186),
    [anon_sym_tri0] = ACTIONS(5186),
    [anon_sym_tri1] = ACTIONS(5186),
    [anon_sym_wand] = ACTIONS(5186),
    [anon_sym_triand] = ACTIONS(5186),
    [anon_sym_wor] = ACTIONS(5186),
    [anon_sym_trior] = ACTIONS(5186),
    [anon_sym_trireg] = ACTIONS(5186),
    [anon_sym_uwire] = ACTIONS(5186),
    [anon_sym_SEMI] = ACTIONS(5184),
    [anon_sym_extern] = ACTIONS(5186),
    [anon_sym_interface] = ACTIONS(5186),
    [anon_sym_checker] = ACTIONS(5186),
    [anon_sym_virtual] = ACTIONS(5186),
    [anon_sym_class] = ACTIONS(5186),
    [anon_sym_type] = ACTIONS(5186),
    [anon_sym_DOLLARfatal] = ACTIONS(5184),
    [anon_sym_DOLLARerror] = ACTIONS(5184),
    [anon_sym_DOLLARwarning] = ACTIONS(5184),
    [anon_sym_DOLLARinfo] = ACTIONS(5184),
    [anon_sym_default] = ACTIONS(5186),
    [anon_sym_clocking] = ACTIONS(5186),
    [anon_sym_defparam] = ACTIONS(5186),
    [anon_sym_bind] = ACTIONS(5186),
    [anon_sym_rand] = ACTIONS(5186),
    [anon_sym_const] = ACTIONS(5186),
    [anon_sym_function] = ACTIONS(5186),
    [anon_sym_static] = ACTIONS(5186),
    [anon_sym_constraint] = ACTIONS(5186),
    [anon_sym_if] = ACTIONS(5186),
    [anon_sym_else] = ACTIONS(5186),
    [anon_sym_LBRACK] = ACTIONS(5184),
    [anon_sym_localparam] = ACTIONS(5186),
    [anon_sym_parameter] = ACTIONS(5186),
    [anon_sym_var] = ACTIONS(5186),
    [anon_sym_import] = ACTIONS(5186),
    [anon_sym_export] = ACTIONS(5186),
    [anon_sym_genvar] = ACTIONS(5186),
    [anon_sym_interconnect] = ACTIONS(5186),
    [anon_sym_typedef] = ACTIONS(5186),
    [anon_sym_enum] = ACTIONS(5186),
    [anon_sym_struct] = ACTIONS(5186),
    [anon_sym_union] = ACTIONS(5186),
    [anon_sym_nettype] = ACTIONS(5186),
    [anon_sym_automatic] = ACTIONS(5186),
    [anon_sym_string] = ACTIONS(5186),
    [anon_sym_chandle] = ACTIONS(5186),
    [anon_sym_event] = ACTIONS(5186),
    [anon_sym_byte] = ACTIONS(5186),
    [anon_sym_shortint] = ACTIONS(5186),
    [anon_sym_int] = ACTIONS(5186),
    [anon_sym_longint] = ACTIONS(5186),
    [anon_sym_integer] = ACTIONS(5186),
    [anon_sym_time] = ACTIONS(5186),
    [anon_sym_bit] = ACTIONS(5186),
    [anon_sym_logic] = ACTIONS(5186),
    [anon_sym_reg] = ACTIONS(5186),
    [anon_sym_shortreal] = ACTIONS(5186),
    [anon_sym_real] = ACTIONS(5186),
    [anon_sym_realtime] = ACTIONS(5186),
    [anon_sym_supply0] = ACTIONS(5186),
    [anon_sym_supply1] = ACTIONS(5186),
    [anon_sym_signed] = ACTIONS(5186),
    [anon_sym_unsigned] = ACTIONS(5186),
    [anon_sym_task] = ACTIONS(5186),
    [anon_sym_assert] = ACTIONS(5186),
    [anon_sym_property] = ACTIONS(5186),
    [anon_sym_assume] = ACTIONS(5186),
    [anon_sym_cover] = ACTIONS(5186),
    [anon_sym_sequence] = ACTIONS(5186),
    [anon_sym_restrict] = ACTIONS(5186),
    [anon_sym_not] = ACTIONS(5186),
    [anon_sym_or] = ACTIONS(5186),
    [anon_sym_and] = ACTIONS(5186),
    [anon_sym_case] = ACTIONS(5186),
    [anon_sym_always] = ACTIONS(5186),
    [anon_sym_covergroup] = ACTIONS(5186),
    [anon_sym_end] = ACTIONS(5186),
    [anon_sym_let] = ACTIONS(5186),
    [anon_sym_pulldown] = ACTIONS(5186),
    [anon_sym_pullup] = ACTIONS(5186),
    [anon_sym_cmos] = ACTIONS(5186),
    [anon_sym_rcmos] = ACTIONS(5186),
    [anon_sym_bufif0] = ACTIONS(5186),
    [anon_sym_bufif1] = ACTIONS(5186),
    [anon_sym_notif0] = ACTIONS(5186),
    [anon_sym_notif1] = ACTIONS(5186),
    [anon_sym_nmos] = ACTIONS(5186),
    [anon_sym_pmos] = ACTIONS(5186),
    [anon_sym_rnmos] = ACTIONS(5186),
    [anon_sym_rpmos] = ACTIONS(5186),
    [anon_sym_nand] = ACTIONS(5186),
    [anon_sym_nor] = ACTIONS(5186),
    [anon_sym_xor] = ACTIONS(5186),
    [anon_sym_xnor] = ACTIONS(5186),
    [anon_sym_buf] = ACTIONS(5186),
    [anon_sym_tranif0] = ACTIONS(5186),
    [anon_sym_tranif1] = ACTIONS(5186),
    [anon_sym_rtranif1] = ACTIONS(5186),
    [anon_sym_rtranif0] = ACTIONS(5186),
    [anon_sym_tran] = ACTIONS(5186),
    [anon_sym_rtran] = ACTIONS(5186),
    [anon_sym_generate] = ACTIONS(5186),
    [anon_sym_for] = ACTIONS(5186),
    [anon_sym_initial] = ACTIONS(5186),
    [anon_sym_assign] = ACTIONS(5186),
    [anon_sym_alias] = ACTIONS(5186),
    [anon_sym_always_comb] = ACTIONS(5186),
    [anon_sym_always_latch] = ACTIONS(5186),
    [anon_sym_always_ff] = ACTIONS(5186),
    [anon_sym_final] = ACTIONS(5186),
    [anon_sym_global] = ACTIONS(5186),
    [anon_sym_LPAREN_STAR] = ACTIONS(5184),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5184),
    [anon_sym_DOLLARunit] = ACTIONS(5184),
  },
  [4886] = {
    [sym_simple_identifier] = ACTIONS(6287),
    [anon_sym_wire] = ACTIONS(6287),
    [anon_sym_tri] = ACTIONS(6287),
    [anon_sym_tri0] = ACTIONS(6287),
    [anon_sym_tri1] = ACTIONS(6287),
    [anon_sym_wand] = ACTIONS(6287),
    [anon_sym_triand] = ACTIONS(6287),
    [anon_sym_wor] = ACTIONS(6287),
    [anon_sym_trior] = ACTIONS(6287),
    [anon_sym_trireg] = ACTIONS(6287),
    [anon_sym_uwire] = ACTIONS(6287),
    [anon_sym_SEMI] = ACTIONS(6289),
    [anon_sym_extern] = ACTIONS(6287),
    [anon_sym_interface] = ACTIONS(6287),
    [anon_sym_checker] = ACTIONS(6287),
    [anon_sym_virtual] = ACTIONS(6287),
    [anon_sym_class] = ACTIONS(6287),
    [anon_sym_type] = ACTIONS(6287),
    [anon_sym_DOLLARfatal] = ACTIONS(6289),
    [anon_sym_DOLLARerror] = ACTIONS(6289),
    [anon_sym_DOLLARwarning] = ACTIONS(6289),
    [anon_sym_DOLLARinfo] = ACTIONS(6289),
    [anon_sym_default] = ACTIONS(6287),
    [anon_sym_clocking] = ACTIONS(6287),
    [anon_sym_defparam] = ACTIONS(6287),
    [anon_sym_bind] = ACTIONS(6287),
    [anon_sym_rand] = ACTIONS(6287),
    [anon_sym_const] = ACTIONS(6287),
    [anon_sym_function] = ACTIONS(6287),
    [anon_sym_static] = ACTIONS(6287),
    [anon_sym_constraint] = ACTIONS(6287),
    [anon_sym_if] = ACTIONS(6287),
    [anon_sym_else] = ACTIONS(6287),
    [anon_sym_LBRACK] = ACTIONS(6289),
    [anon_sym_localparam] = ACTIONS(6287),
    [anon_sym_parameter] = ACTIONS(6287),
    [anon_sym_var] = ACTIONS(6287),
    [anon_sym_import] = ACTIONS(6287),
    [anon_sym_export] = ACTIONS(6287),
    [anon_sym_genvar] = ACTIONS(6287),
    [anon_sym_interconnect] = ACTIONS(6287),
    [anon_sym_typedef] = ACTIONS(6287),
    [anon_sym_enum] = ACTIONS(6287),
    [anon_sym_struct] = ACTIONS(6287),
    [anon_sym_union] = ACTIONS(6287),
    [anon_sym_nettype] = ACTIONS(6287),
    [anon_sym_automatic] = ACTIONS(6287),
    [anon_sym_string] = ACTIONS(6287),
    [anon_sym_chandle] = ACTIONS(6287),
    [anon_sym_event] = ACTIONS(6287),
    [anon_sym_byte] = ACTIONS(6287),
    [anon_sym_shortint] = ACTIONS(6287),
    [anon_sym_int] = ACTIONS(6287),
    [anon_sym_longint] = ACTIONS(6287),
    [anon_sym_integer] = ACTIONS(6287),
    [anon_sym_time] = ACTIONS(6287),
    [anon_sym_bit] = ACTIONS(6287),
    [anon_sym_logic] = ACTIONS(6287),
    [anon_sym_reg] = ACTIONS(6287),
    [anon_sym_shortreal] = ACTIONS(6287),
    [anon_sym_real] = ACTIONS(6287),
    [anon_sym_realtime] = ACTIONS(6287),
    [anon_sym_supply0] = ACTIONS(6287),
    [anon_sym_supply1] = ACTIONS(6287),
    [anon_sym_signed] = ACTIONS(6287),
    [anon_sym_unsigned] = ACTIONS(6287),
    [anon_sym_task] = ACTIONS(6287),
    [anon_sym_assert] = ACTIONS(6287),
    [anon_sym_property] = ACTIONS(6287),
    [anon_sym_assume] = ACTIONS(6287),
    [anon_sym_cover] = ACTIONS(6287),
    [anon_sym_sequence] = ACTIONS(6287),
    [anon_sym_restrict] = ACTIONS(6287),
    [anon_sym_not] = ACTIONS(6287),
    [anon_sym_or] = ACTIONS(6287),
    [anon_sym_and] = ACTIONS(6287),
    [anon_sym_case] = ACTIONS(6287),
    [anon_sym_always] = ACTIONS(6287),
    [anon_sym_covergroup] = ACTIONS(6287),
    [anon_sym_end] = ACTIONS(6287),
    [anon_sym_let] = ACTIONS(6287),
    [anon_sym_pulldown] = ACTIONS(6287),
    [anon_sym_pullup] = ACTIONS(6287),
    [anon_sym_cmos] = ACTIONS(6287),
    [anon_sym_rcmos] = ACTIONS(6287),
    [anon_sym_bufif0] = ACTIONS(6287),
    [anon_sym_bufif1] = ACTIONS(6287),
    [anon_sym_notif0] = ACTIONS(6287),
    [anon_sym_notif1] = ACTIONS(6287),
    [anon_sym_nmos] = ACTIONS(6287),
    [anon_sym_pmos] = ACTIONS(6287),
    [anon_sym_rnmos] = ACTIONS(6287),
    [anon_sym_rpmos] = ACTIONS(6287),
    [anon_sym_nand] = ACTIONS(6287),
    [anon_sym_nor] = ACTIONS(6287),
    [anon_sym_xor] = ACTIONS(6287),
    [anon_sym_xnor] = ACTIONS(6287),
    [anon_sym_buf] = ACTIONS(6287),
    [anon_sym_tranif0] = ACTIONS(6287),
    [anon_sym_tranif1] = ACTIONS(6287),
    [anon_sym_rtranif1] = ACTIONS(6287),
    [anon_sym_rtranif0] = ACTIONS(6287),
    [anon_sym_tran] = ACTIONS(6287),
    [anon_sym_rtran] = ACTIONS(6287),
    [anon_sym_generate] = ACTIONS(6287),
    [anon_sym_for] = ACTIONS(6287),
    [anon_sym_initial] = ACTIONS(6287),
    [anon_sym_assign] = ACTIONS(6287),
    [anon_sym_alias] = ACTIONS(6287),
    [anon_sym_always_comb] = ACTIONS(6287),
    [anon_sym_always_latch] = ACTIONS(6287),
    [anon_sym_always_ff] = ACTIONS(6287),
    [anon_sym_final] = ACTIONS(6287),
    [anon_sym_global] = ACTIONS(6287),
    [anon_sym_LPAREN_STAR] = ACTIONS(6289),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6289),
    [anon_sym_DOLLARunit] = ACTIONS(6289),
  },
  [4887] = {
    [sym_simple_identifier] = ACTIONS(4956),
    [anon_sym_wire] = ACTIONS(4956),
    [anon_sym_tri] = ACTIONS(4956),
    [anon_sym_tri0] = ACTIONS(4956),
    [anon_sym_tri1] = ACTIONS(4956),
    [anon_sym_wand] = ACTIONS(4956),
    [anon_sym_triand] = ACTIONS(4956),
    [anon_sym_wor] = ACTIONS(4956),
    [anon_sym_trior] = ACTIONS(4956),
    [anon_sym_trireg] = ACTIONS(4956),
    [anon_sym_uwire] = ACTIONS(4956),
    [anon_sym_SEMI] = ACTIONS(4954),
    [anon_sym_extern] = ACTIONS(4956),
    [anon_sym_interface] = ACTIONS(4956),
    [anon_sym_checker] = ACTIONS(4956),
    [anon_sym_virtual] = ACTIONS(4956),
    [anon_sym_class] = ACTIONS(4956),
    [anon_sym_type] = ACTIONS(4956),
    [anon_sym_DOLLARfatal] = ACTIONS(4954),
    [anon_sym_DOLLARerror] = ACTIONS(4954),
    [anon_sym_DOLLARwarning] = ACTIONS(4954),
    [anon_sym_DOLLARinfo] = ACTIONS(4954),
    [anon_sym_default] = ACTIONS(4956),
    [anon_sym_clocking] = ACTIONS(4956),
    [anon_sym_defparam] = ACTIONS(4956),
    [anon_sym_bind] = ACTIONS(4956),
    [anon_sym_rand] = ACTIONS(4956),
    [anon_sym_const] = ACTIONS(4956),
    [anon_sym_function] = ACTIONS(4956),
    [anon_sym_static] = ACTIONS(4956),
    [anon_sym_constraint] = ACTIONS(4956),
    [anon_sym_if] = ACTIONS(4956),
    [anon_sym_else] = ACTIONS(4956),
    [anon_sym_LBRACK] = ACTIONS(4954),
    [anon_sym_localparam] = ACTIONS(4956),
    [anon_sym_parameter] = ACTIONS(4956),
    [anon_sym_var] = ACTIONS(4956),
    [anon_sym_import] = ACTIONS(4956),
    [anon_sym_export] = ACTIONS(4956),
    [anon_sym_genvar] = ACTIONS(4956),
    [anon_sym_interconnect] = ACTIONS(4956),
    [anon_sym_typedef] = ACTIONS(4956),
    [anon_sym_enum] = ACTIONS(4956),
    [anon_sym_struct] = ACTIONS(4956),
    [anon_sym_union] = ACTIONS(4956),
    [anon_sym_nettype] = ACTIONS(4956),
    [anon_sym_automatic] = ACTIONS(4956),
    [anon_sym_string] = ACTIONS(4956),
    [anon_sym_chandle] = ACTIONS(4956),
    [anon_sym_event] = ACTIONS(4956),
    [anon_sym_byte] = ACTIONS(4956),
    [anon_sym_shortint] = ACTIONS(4956),
    [anon_sym_int] = ACTIONS(4956),
    [anon_sym_longint] = ACTIONS(4956),
    [anon_sym_integer] = ACTIONS(4956),
    [anon_sym_time] = ACTIONS(4956),
    [anon_sym_bit] = ACTIONS(4956),
    [anon_sym_logic] = ACTIONS(4956),
    [anon_sym_reg] = ACTIONS(4956),
    [anon_sym_shortreal] = ACTIONS(4956),
    [anon_sym_real] = ACTIONS(4956),
    [anon_sym_realtime] = ACTIONS(4956),
    [anon_sym_supply0] = ACTIONS(4956),
    [anon_sym_supply1] = ACTIONS(4956),
    [anon_sym_signed] = ACTIONS(4956),
    [anon_sym_unsigned] = ACTIONS(4956),
    [anon_sym_task] = ACTIONS(4956),
    [anon_sym_assert] = ACTIONS(4956),
    [anon_sym_property] = ACTIONS(4956),
    [anon_sym_assume] = ACTIONS(4956),
    [anon_sym_cover] = ACTIONS(4956),
    [anon_sym_sequence] = ACTIONS(4956),
    [anon_sym_restrict] = ACTIONS(4956),
    [anon_sym_not] = ACTIONS(4956),
    [anon_sym_or] = ACTIONS(4956),
    [anon_sym_and] = ACTIONS(4956),
    [anon_sym_case] = ACTIONS(4956),
    [anon_sym_always] = ACTIONS(4956),
    [anon_sym_covergroup] = ACTIONS(4956),
    [anon_sym_end] = ACTIONS(4956),
    [anon_sym_let] = ACTIONS(4956),
    [anon_sym_pulldown] = ACTIONS(4956),
    [anon_sym_pullup] = ACTIONS(4956),
    [anon_sym_cmos] = ACTIONS(4956),
    [anon_sym_rcmos] = ACTIONS(4956),
    [anon_sym_bufif0] = ACTIONS(4956),
    [anon_sym_bufif1] = ACTIONS(4956),
    [anon_sym_notif0] = ACTIONS(4956),
    [anon_sym_notif1] = ACTIONS(4956),
    [anon_sym_nmos] = ACTIONS(4956),
    [anon_sym_pmos] = ACTIONS(4956),
    [anon_sym_rnmos] = ACTIONS(4956),
    [anon_sym_rpmos] = ACTIONS(4956),
    [anon_sym_nand] = ACTIONS(4956),
    [anon_sym_nor] = ACTIONS(4956),
    [anon_sym_xor] = ACTIONS(4956),
    [anon_sym_xnor] = ACTIONS(4956),
    [anon_sym_buf] = ACTIONS(4956),
    [anon_sym_tranif0] = ACTIONS(4956),
    [anon_sym_tranif1] = ACTIONS(4956),
    [anon_sym_rtranif1] = ACTIONS(4956),
    [anon_sym_rtranif0] = ACTIONS(4956),
    [anon_sym_tran] = ACTIONS(4956),
    [anon_sym_rtran] = ACTIONS(4956),
    [anon_sym_generate] = ACTIONS(4956),
    [anon_sym_for] = ACTIONS(4956),
    [anon_sym_initial] = ACTIONS(4956),
    [anon_sym_assign] = ACTIONS(4956),
    [anon_sym_alias] = ACTIONS(4956),
    [anon_sym_always_comb] = ACTIONS(4956),
    [anon_sym_always_latch] = ACTIONS(4956),
    [anon_sym_always_ff] = ACTIONS(4956),
    [anon_sym_final] = ACTIONS(4956),
    [anon_sym_global] = ACTIONS(4956),
    [anon_sym_LPAREN_STAR] = ACTIONS(4954),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4954),
    [anon_sym_DOLLARunit] = ACTIONS(4954),
  },
  [4888] = {
    [sym_simple_identifier] = ACTIONS(6605),
    [anon_sym_wire] = ACTIONS(6605),
    [anon_sym_tri] = ACTIONS(6605),
    [anon_sym_tri0] = ACTIONS(6605),
    [anon_sym_tri1] = ACTIONS(6605),
    [anon_sym_wand] = ACTIONS(6605),
    [anon_sym_triand] = ACTIONS(6605),
    [anon_sym_wor] = ACTIONS(6605),
    [anon_sym_trior] = ACTIONS(6605),
    [anon_sym_trireg] = ACTIONS(6605),
    [anon_sym_uwire] = ACTIONS(6605),
    [anon_sym_SEMI] = ACTIONS(6607),
    [anon_sym_extern] = ACTIONS(6605),
    [anon_sym_interface] = ACTIONS(6605),
    [anon_sym_checker] = ACTIONS(6605),
    [anon_sym_virtual] = ACTIONS(6605),
    [anon_sym_class] = ACTIONS(6605),
    [anon_sym_type] = ACTIONS(6605),
    [anon_sym_DOLLARfatal] = ACTIONS(6607),
    [anon_sym_DOLLARerror] = ACTIONS(6607),
    [anon_sym_DOLLARwarning] = ACTIONS(6607),
    [anon_sym_DOLLARinfo] = ACTIONS(6607),
    [anon_sym_default] = ACTIONS(6605),
    [anon_sym_clocking] = ACTIONS(6605),
    [anon_sym_defparam] = ACTIONS(6605),
    [anon_sym_bind] = ACTIONS(6605),
    [anon_sym_rand] = ACTIONS(6605),
    [anon_sym_const] = ACTIONS(6605),
    [anon_sym_function] = ACTIONS(6605),
    [anon_sym_static] = ACTIONS(6605),
    [anon_sym_constraint] = ACTIONS(6605),
    [anon_sym_if] = ACTIONS(6605),
    [anon_sym_else] = ACTIONS(6605),
    [anon_sym_LBRACK] = ACTIONS(6607),
    [anon_sym_localparam] = ACTIONS(6605),
    [anon_sym_parameter] = ACTIONS(6605),
    [anon_sym_var] = ACTIONS(6605),
    [anon_sym_import] = ACTIONS(6605),
    [anon_sym_export] = ACTIONS(6605),
    [anon_sym_genvar] = ACTIONS(6605),
    [anon_sym_interconnect] = ACTIONS(6605),
    [anon_sym_typedef] = ACTIONS(6605),
    [anon_sym_enum] = ACTIONS(6605),
    [anon_sym_struct] = ACTIONS(6605),
    [anon_sym_union] = ACTIONS(6605),
    [anon_sym_nettype] = ACTIONS(6605),
    [anon_sym_automatic] = ACTIONS(6605),
    [anon_sym_string] = ACTIONS(6605),
    [anon_sym_chandle] = ACTIONS(6605),
    [anon_sym_event] = ACTIONS(6605),
    [anon_sym_byte] = ACTIONS(6605),
    [anon_sym_shortint] = ACTIONS(6605),
    [anon_sym_int] = ACTIONS(6605),
    [anon_sym_longint] = ACTIONS(6605),
    [anon_sym_integer] = ACTIONS(6605),
    [anon_sym_time] = ACTIONS(6605),
    [anon_sym_bit] = ACTIONS(6605),
    [anon_sym_logic] = ACTIONS(6605),
    [anon_sym_reg] = ACTIONS(6605),
    [anon_sym_shortreal] = ACTIONS(6605),
    [anon_sym_real] = ACTIONS(6605),
    [anon_sym_realtime] = ACTIONS(6605),
    [anon_sym_supply0] = ACTIONS(6605),
    [anon_sym_supply1] = ACTIONS(6605),
    [anon_sym_signed] = ACTIONS(6605),
    [anon_sym_unsigned] = ACTIONS(6605),
    [anon_sym_task] = ACTIONS(6605),
    [anon_sym_assert] = ACTIONS(6605),
    [anon_sym_property] = ACTIONS(6605),
    [anon_sym_assume] = ACTIONS(6605),
    [anon_sym_cover] = ACTIONS(6605),
    [anon_sym_sequence] = ACTIONS(6605),
    [anon_sym_restrict] = ACTIONS(6605),
    [anon_sym_not] = ACTIONS(6605),
    [anon_sym_or] = ACTIONS(6605),
    [anon_sym_and] = ACTIONS(6605),
    [anon_sym_case] = ACTIONS(6605),
    [anon_sym_always] = ACTIONS(6605),
    [anon_sym_covergroup] = ACTIONS(6605),
    [anon_sym_let] = ACTIONS(6605),
    [anon_sym_pulldown] = ACTIONS(6605),
    [anon_sym_pullup] = ACTIONS(6605),
    [anon_sym_cmos] = ACTIONS(6605),
    [anon_sym_rcmos] = ACTIONS(6605),
    [anon_sym_bufif0] = ACTIONS(6605),
    [anon_sym_bufif1] = ACTIONS(6605),
    [anon_sym_notif0] = ACTIONS(6605),
    [anon_sym_notif1] = ACTIONS(6605),
    [anon_sym_nmos] = ACTIONS(6605),
    [anon_sym_pmos] = ACTIONS(6605),
    [anon_sym_rnmos] = ACTIONS(6605),
    [anon_sym_rpmos] = ACTIONS(6605),
    [anon_sym_nand] = ACTIONS(6605),
    [anon_sym_nor] = ACTIONS(6605),
    [anon_sym_xor] = ACTIONS(6605),
    [anon_sym_xnor] = ACTIONS(6605),
    [anon_sym_buf] = ACTIONS(6605),
    [anon_sym_tranif0] = ACTIONS(6605),
    [anon_sym_tranif1] = ACTIONS(6605),
    [anon_sym_rtranif1] = ACTIONS(6605),
    [anon_sym_rtranif0] = ACTIONS(6605),
    [anon_sym_tran] = ACTIONS(6605),
    [anon_sym_rtran] = ACTIONS(6605),
    [anon_sym_generate] = ACTIONS(6605),
    [anon_sym_endgenerate] = ACTIONS(6605),
    [anon_sym_for] = ACTIONS(6605),
    [anon_sym_initial] = ACTIONS(6605),
    [anon_sym_assign] = ACTIONS(6605),
    [anon_sym_alias] = ACTIONS(6605),
    [anon_sym_always_comb] = ACTIONS(6605),
    [anon_sym_always_latch] = ACTIONS(6605),
    [anon_sym_always_ff] = ACTIONS(6605),
    [anon_sym_final] = ACTIONS(6605),
    [anon_sym_global] = ACTIONS(6605),
    [anon_sym_LPAREN_STAR] = ACTIONS(6607),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6607),
    [anon_sym_DOLLARunit] = ACTIONS(6607),
  },
  [4889] = {
    [sym_simple_identifier] = ACTIONS(4932),
    [anon_sym_wire] = ACTIONS(4932),
    [anon_sym_tri] = ACTIONS(4932),
    [anon_sym_tri0] = ACTIONS(4932),
    [anon_sym_tri1] = ACTIONS(4932),
    [anon_sym_wand] = ACTIONS(4932),
    [anon_sym_triand] = ACTIONS(4932),
    [anon_sym_wor] = ACTIONS(4932),
    [anon_sym_trior] = ACTIONS(4932),
    [anon_sym_trireg] = ACTIONS(4932),
    [anon_sym_uwire] = ACTIONS(4932),
    [anon_sym_SEMI] = ACTIONS(4930),
    [anon_sym_extern] = ACTIONS(4932),
    [anon_sym_interface] = ACTIONS(4932),
    [anon_sym_checker] = ACTIONS(4932),
    [anon_sym_virtual] = ACTIONS(4932),
    [anon_sym_class] = ACTIONS(4932),
    [anon_sym_type] = ACTIONS(4932),
    [anon_sym_DOLLARfatal] = ACTIONS(4930),
    [anon_sym_DOLLARerror] = ACTIONS(4930),
    [anon_sym_DOLLARwarning] = ACTIONS(4930),
    [anon_sym_DOLLARinfo] = ACTIONS(4930),
    [anon_sym_default] = ACTIONS(4932),
    [anon_sym_clocking] = ACTIONS(4932),
    [anon_sym_defparam] = ACTIONS(4932),
    [anon_sym_bind] = ACTIONS(4932),
    [anon_sym_rand] = ACTIONS(4932),
    [anon_sym_const] = ACTIONS(4932),
    [anon_sym_function] = ACTIONS(4932),
    [anon_sym_static] = ACTIONS(4932),
    [anon_sym_constraint] = ACTIONS(4932),
    [anon_sym_if] = ACTIONS(4932),
    [anon_sym_else] = ACTIONS(4932),
    [anon_sym_LBRACK] = ACTIONS(4930),
    [anon_sym_localparam] = ACTIONS(4932),
    [anon_sym_parameter] = ACTIONS(4932),
    [anon_sym_var] = ACTIONS(4932),
    [anon_sym_import] = ACTIONS(4932),
    [anon_sym_export] = ACTIONS(4932),
    [anon_sym_genvar] = ACTIONS(4932),
    [anon_sym_interconnect] = ACTIONS(4932),
    [anon_sym_typedef] = ACTIONS(4932),
    [anon_sym_enum] = ACTIONS(4932),
    [anon_sym_struct] = ACTIONS(4932),
    [anon_sym_union] = ACTIONS(4932),
    [anon_sym_nettype] = ACTIONS(4932),
    [anon_sym_automatic] = ACTIONS(4932),
    [anon_sym_string] = ACTIONS(4932),
    [anon_sym_chandle] = ACTIONS(4932),
    [anon_sym_event] = ACTIONS(4932),
    [anon_sym_byte] = ACTIONS(4932),
    [anon_sym_shortint] = ACTIONS(4932),
    [anon_sym_int] = ACTIONS(4932),
    [anon_sym_longint] = ACTIONS(4932),
    [anon_sym_integer] = ACTIONS(4932),
    [anon_sym_time] = ACTIONS(4932),
    [anon_sym_bit] = ACTIONS(4932),
    [anon_sym_logic] = ACTIONS(4932),
    [anon_sym_reg] = ACTIONS(4932),
    [anon_sym_shortreal] = ACTIONS(4932),
    [anon_sym_real] = ACTIONS(4932),
    [anon_sym_realtime] = ACTIONS(4932),
    [anon_sym_supply0] = ACTIONS(4932),
    [anon_sym_supply1] = ACTIONS(4932),
    [anon_sym_signed] = ACTIONS(4932),
    [anon_sym_unsigned] = ACTIONS(4932),
    [anon_sym_task] = ACTIONS(4932),
    [anon_sym_assert] = ACTIONS(4932),
    [anon_sym_property] = ACTIONS(4932),
    [anon_sym_assume] = ACTIONS(4932),
    [anon_sym_cover] = ACTIONS(4932),
    [anon_sym_sequence] = ACTIONS(4932),
    [anon_sym_restrict] = ACTIONS(4932),
    [anon_sym_not] = ACTIONS(4932),
    [anon_sym_or] = ACTIONS(4932),
    [anon_sym_and] = ACTIONS(4932),
    [anon_sym_case] = ACTIONS(4932),
    [anon_sym_always] = ACTIONS(4932),
    [anon_sym_covergroup] = ACTIONS(4932),
    [anon_sym_end] = ACTIONS(4932),
    [anon_sym_let] = ACTIONS(4932),
    [anon_sym_pulldown] = ACTIONS(4932),
    [anon_sym_pullup] = ACTIONS(4932),
    [anon_sym_cmos] = ACTIONS(4932),
    [anon_sym_rcmos] = ACTIONS(4932),
    [anon_sym_bufif0] = ACTIONS(4932),
    [anon_sym_bufif1] = ACTIONS(4932),
    [anon_sym_notif0] = ACTIONS(4932),
    [anon_sym_notif1] = ACTIONS(4932),
    [anon_sym_nmos] = ACTIONS(4932),
    [anon_sym_pmos] = ACTIONS(4932),
    [anon_sym_rnmos] = ACTIONS(4932),
    [anon_sym_rpmos] = ACTIONS(4932),
    [anon_sym_nand] = ACTIONS(4932),
    [anon_sym_nor] = ACTIONS(4932),
    [anon_sym_xor] = ACTIONS(4932),
    [anon_sym_xnor] = ACTIONS(4932),
    [anon_sym_buf] = ACTIONS(4932),
    [anon_sym_tranif0] = ACTIONS(4932),
    [anon_sym_tranif1] = ACTIONS(4932),
    [anon_sym_rtranif1] = ACTIONS(4932),
    [anon_sym_rtranif0] = ACTIONS(4932),
    [anon_sym_tran] = ACTIONS(4932),
    [anon_sym_rtran] = ACTIONS(4932),
    [anon_sym_generate] = ACTIONS(4932),
    [anon_sym_for] = ACTIONS(4932),
    [anon_sym_initial] = ACTIONS(4932),
    [anon_sym_assign] = ACTIONS(4932),
    [anon_sym_alias] = ACTIONS(4932),
    [anon_sym_always_comb] = ACTIONS(4932),
    [anon_sym_always_latch] = ACTIONS(4932),
    [anon_sym_always_ff] = ACTIONS(4932),
    [anon_sym_final] = ACTIONS(4932),
    [anon_sym_global] = ACTIONS(4932),
    [anon_sym_LPAREN_STAR] = ACTIONS(4930),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4930),
    [anon_sym_DOLLARunit] = ACTIONS(4930),
  },
  [4890] = {
    [sym_simple_identifier] = ACTIONS(6471),
    [anon_sym_wire] = ACTIONS(6471),
    [anon_sym_tri] = ACTIONS(6471),
    [anon_sym_tri0] = ACTIONS(6471),
    [anon_sym_tri1] = ACTIONS(6471),
    [anon_sym_wand] = ACTIONS(6471),
    [anon_sym_triand] = ACTIONS(6471),
    [anon_sym_wor] = ACTIONS(6471),
    [anon_sym_trior] = ACTIONS(6471),
    [anon_sym_trireg] = ACTIONS(6471),
    [anon_sym_uwire] = ACTIONS(6471),
    [anon_sym_SEMI] = ACTIONS(6473),
    [anon_sym_extern] = ACTIONS(6471),
    [anon_sym_interface] = ACTIONS(6471),
    [anon_sym_checker] = ACTIONS(6471),
    [anon_sym_virtual] = ACTIONS(6471),
    [anon_sym_class] = ACTIONS(6471),
    [anon_sym_type] = ACTIONS(6471),
    [anon_sym_DOLLARfatal] = ACTIONS(6473),
    [anon_sym_DOLLARerror] = ACTIONS(6473),
    [anon_sym_DOLLARwarning] = ACTIONS(6473),
    [anon_sym_DOLLARinfo] = ACTIONS(6473),
    [anon_sym_default] = ACTIONS(6471),
    [anon_sym_clocking] = ACTIONS(6471),
    [anon_sym_defparam] = ACTIONS(6471),
    [anon_sym_bind] = ACTIONS(6471),
    [anon_sym_rand] = ACTIONS(6471),
    [anon_sym_const] = ACTIONS(6471),
    [anon_sym_function] = ACTIONS(6471),
    [anon_sym_static] = ACTIONS(6471),
    [anon_sym_constraint] = ACTIONS(6471),
    [anon_sym_if] = ACTIONS(6471),
    [anon_sym_else] = ACTIONS(6471),
    [anon_sym_LBRACK] = ACTIONS(6473),
    [anon_sym_localparam] = ACTIONS(6471),
    [anon_sym_parameter] = ACTIONS(6471),
    [anon_sym_var] = ACTIONS(6471),
    [anon_sym_import] = ACTIONS(6471),
    [anon_sym_export] = ACTIONS(6471),
    [anon_sym_genvar] = ACTIONS(6471),
    [anon_sym_interconnect] = ACTIONS(6471),
    [anon_sym_typedef] = ACTIONS(6471),
    [anon_sym_enum] = ACTIONS(6471),
    [anon_sym_struct] = ACTIONS(6471),
    [anon_sym_union] = ACTIONS(6471),
    [anon_sym_nettype] = ACTIONS(6471),
    [anon_sym_automatic] = ACTIONS(6471),
    [anon_sym_string] = ACTIONS(6471),
    [anon_sym_chandle] = ACTIONS(6471),
    [anon_sym_event] = ACTIONS(6471),
    [anon_sym_byte] = ACTIONS(6471),
    [anon_sym_shortint] = ACTIONS(6471),
    [anon_sym_int] = ACTIONS(6471),
    [anon_sym_longint] = ACTIONS(6471),
    [anon_sym_integer] = ACTIONS(6471),
    [anon_sym_time] = ACTIONS(6471),
    [anon_sym_bit] = ACTIONS(6471),
    [anon_sym_logic] = ACTIONS(6471),
    [anon_sym_reg] = ACTIONS(6471),
    [anon_sym_shortreal] = ACTIONS(6471),
    [anon_sym_real] = ACTIONS(6471),
    [anon_sym_realtime] = ACTIONS(6471),
    [anon_sym_supply0] = ACTIONS(6471),
    [anon_sym_supply1] = ACTIONS(6471),
    [anon_sym_signed] = ACTIONS(6471),
    [anon_sym_unsigned] = ACTIONS(6471),
    [anon_sym_task] = ACTIONS(6471),
    [anon_sym_assert] = ACTIONS(6471),
    [anon_sym_property] = ACTIONS(6471),
    [anon_sym_assume] = ACTIONS(6471),
    [anon_sym_cover] = ACTIONS(6471),
    [anon_sym_sequence] = ACTIONS(6471),
    [anon_sym_restrict] = ACTIONS(6471),
    [anon_sym_not] = ACTIONS(6471),
    [anon_sym_or] = ACTIONS(6471),
    [anon_sym_and] = ACTIONS(6471),
    [anon_sym_case] = ACTIONS(6471),
    [anon_sym_always] = ACTIONS(6471),
    [anon_sym_covergroup] = ACTIONS(6471),
    [anon_sym_let] = ACTIONS(6471),
    [anon_sym_pulldown] = ACTIONS(6471),
    [anon_sym_pullup] = ACTIONS(6471),
    [anon_sym_cmos] = ACTIONS(6471),
    [anon_sym_rcmos] = ACTIONS(6471),
    [anon_sym_bufif0] = ACTIONS(6471),
    [anon_sym_bufif1] = ACTIONS(6471),
    [anon_sym_notif0] = ACTIONS(6471),
    [anon_sym_notif1] = ACTIONS(6471),
    [anon_sym_nmos] = ACTIONS(6471),
    [anon_sym_pmos] = ACTIONS(6471),
    [anon_sym_rnmos] = ACTIONS(6471),
    [anon_sym_rpmos] = ACTIONS(6471),
    [anon_sym_nand] = ACTIONS(6471),
    [anon_sym_nor] = ACTIONS(6471),
    [anon_sym_xor] = ACTIONS(6471),
    [anon_sym_xnor] = ACTIONS(6471),
    [anon_sym_buf] = ACTIONS(6471),
    [anon_sym_tranif0] = ACTIONS(6471),
    [anon_sym_tranif1] = ACTIONS(6471),
    [anon_sym_rtranif1] = ACTIONS(6471),
    [anon_sym_rtranif0] = ACTIONS(6471),
    [anon_sym_tran] = ACTIONS(6471),
    [anon_sym_rtran] = ACTIONS(6471),
    [anon_sym_generate] = ACTIONS(6471),
    [anon_sym_endgenerate] = ACTIONS(6471),
    [anon_sym_for] = ACTIONS(6471),
    [anon_sym_initial] = ACTIONS(6471),
    [anon_sym_assign] = ACTIONS(6471),
    [anon_sym_alias] = ACTIONS(6471),
    [anon_sym_always_comb] = ACTIONS(6471),
    [anon_sym_always_latch] = ACTIONS(6471),
    [anon_sym_always_ff] = ACTIONS(6471),
    [anon_sym_final] = ACTIONS(6471),
    [anon_sym_global] = ACTIONS(6471),
    [anon_sym_LPAREN_STAR] = ACTIONS(6473),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6473),
    [anon_sym_DOLLARunit] = ACTIONS(6473),
  },
  [4891] = {
    [sym_simple_identifier] = ACTIONS(5258),
    [anon_sym_wire] = ACTIONS(5258),
    [anon_sym_tri] = ACTIONS(5258),
    [anon_sym_tri0] = ACTIONS(5258),
    [anon_sym_tri1] = ACTIONS(5258),
    [anon_sym_wand] = ACTIONS(5258),
    [anon_sym_triand] = ACTIONS(5258),
    [anon_sym_wor] = ACTIONS(5258),
    [anon_sym_trior] = ACTIONS(5258),
    [anon_sym_trireg] = ACTIONS(5258),
    [anon_sym_uwire] = ACTIONS(5258),
    [anon_sym_SEMI] = ACTIONS(5256),
    [anon_sym_extern] = ACTIONS(5258),
    [anon_sym_interface] = ACTIONS(5258),
    [anon_sym_checker] = ACTIONS(5258),
    [anon_sym_virtual] = ACTIONS(5258),
    [anon_sym_class] = ACTIONS(5258),
    [anon_sym_type] = ACTIONS(5258),
    [anon_sym_DOLLARfatal] = ACTIONS(5256),
    [anon_sym_DOLLARerror] = ACTIONS(5256),
    [anon_sym_DOLLARwarning] = ACTIONS(5256),
    [anon_sym_DOLLARinfo] = ACTIONS(5256),
    [anon_sym_default] = ACTIONS(5258),
    [anon_sym_clocking] = ACTIONS(5258),
    [anon_sym_defparam] = ACTIONS(5258),
    [anon_sym_bind] = ACTIONS(5258),
    [anon_sym_rand] = ACTIONS(5258),
    [anon_sym_const] = ACTIONS(5258),
    [anon_sym_function] = ACTIONS(5258),
    [anon_sym_static] = ACTIONS(5258),
    [anon_sym_constraint] = ACTIONS(5258),
    [anon_sym_if] = ACTIONS(5258),
    [anon_sym_else] = ACTIONS(5258),
    [anon_sym_LBRACK] = ACTIONS(5256),
    [anon_sym_localparam] = ACTIONS(5258),
    [anon_sym_parameter] = ACTIONS(5258),
    [anon_sym_var] = ACTIONS(5258),
    [anon_sym_import] = ACTIONS(5258),
    [anon_sym_export] = ACTIONS(5258),
    [anon_sym_genvar] = ACTIONS(5258),
    [anon_sym_interconnect] = ACTIONS(5258),
    [anon_sym_typedef] = ACTIONS(5258),
    [anon_sym_enum] = ACTIONS(5258),
    [anon_sym_struct] = ACTIONS(5258),
    [anon_sym_union] = ACTIONS(5258),
    [anon_sym_nettype] = ACTIONS(5258),
    [anon_sym_automatic] = ACTIONS(5258),
    [anon_sym_string] = ACTIONS(5258),
    [anon_sym_chandle] = ACTIONS(5258),
    [anon_sym_event] = ACTIONS(5258),
    [anon_sym_byte] = ACTIONS(5258),
    [anon_sym_shortint] = ACTIONS(5258),
    [anon_sym_int] = ACTIONS(5258),
    [anon_sym_longint] = ACTIONS(5258),
    [anon_sym_integer] = ACTIONS(5258),
    [anon_sym_time] = ACTIONS(5258),
    [anon_sym_bit] = ACTIONS(5258),
    [anon_sym_logic] = ACTIONS(5258),
    [anon_sym_reg] = ACTIONS(5258),
    [anon_sym_shortreal] = ACTIONS(5258),
    [anon_sym_real] = ACTIONS(5258),
    [anon_sym_realtime] = ACTIONS(5258),
    [anon_sym_supply0] = ACTIONS(5258),
    [anon_sym_supply1] = ACTIONS(5258),
    [anon_sym_signed] = ACTIONS(5258),
    [anon_sym_unsigned] = ACTIONS(5258),
    [anon_sym_task] = ACTIONS(5258),
    [anon_sym_assert] = ACTIONS(5258),
    [anon_sym_property] = ACTIONS(5258),
    [anon_sym_assume] = ACTIONS(5258),
    [anon_sym_cover] = ACTIONS(5258),
    [anon_sym_sequence] = ACTIONS(5258),
    [anon_sym_restrict] = ACTIONS(5258),
    [anon_sym_not] = ACTIONS(5258),
    [anon_sym_or] = ACTIONS(5258),
    [anon_sym_and] = ACTIONS(5258),
    [anon_sym_case] = ACTIONS(5258),
    [anon_sym_always] = ACTIONS(5258),
    [anon_sym_covergroup] = ACTIONS(5258),
    [anon_sym_let] = ACTIONS(5258),
    [anon_sym_pulldown] = ACTIONS(5258),
    [anon_sym_pullup] = ACTIONS(5258),
    [anon_sym_cmos] = ACTIONS(5258),
    [anon_sym_rcmos] = ACTIONS(5258),
    [anon_sym_bufif0] = ACTIONS(5258),
    [anon_sym_bufif1] = ACTIONS(5258),
    [anon_sym_notif0] = ACTIONS(5258),
    [anon_sym_notif1] = ACTIONS(5258),
    [anon_sym_nmos] = ACTIONS(5258),
    [anon_sym_pmos] = ACTIONS(5258),
    [anon_sym_rnmos] = ACTIONS(5258),
    [anon_sym_rpmos] = ACTIONS(5258),
    [anon_sym_nand] = ACTIONS(5258),
    [anon_sym_nor] = ACTIONS(5258),
    [anon_sym_xor] = ACTIONS(5258),
    [anon_sym_xnor] = ACTIONS(5258),
    [anon_sym_buf] = ACTIONS(5258),
    [anon_sym_tranif0] = ACTIONS(5258),
    [anon_sym_tranif1] = ACTIONS(5258),
    [anon_sym_rtranif1] = ACTIONS(5258),
    [anon_sym_rtranif0] = ACTIONS(5258),
    [anon_sym_tran] = ACTIONS(5258),
    [anon_sym_rtran] = ACTIONS(5258),
    [anon_sym_generate] = ACTIONS(5258),
    [anon_sym_endgenerate] = ACTIONS(5258),
    [anon_sym_for] = ACTIONS(5258),
    [anon_sym_initial] = ACTIONS(5258),
    [anon_sym_assign] = ACTIONS(5258),
    [anon_sym_alias] = ACTIONS(5258),
    [anon_sym_always_comb] = ACTIONS(5258),
    [anon_sym_always_latch] = ACTIONS(5258),
    [anon_sym_always_ff] = ACTIONS(5258),
    [anon_sym_final] = ACTIONS(5258),
    [anon_sym_global] = ACTIONS(5258),
    [anon_sym_LPAREN_STAR] = ACTIONS(5256),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5256),
    [anon_sym_DOLLARunit] = ACTIONS(5256),
  },
  [4892] = {
    [sym_simple_identifier] = ACTIONS(5274),
    [anon_sym_wire] = ACTIONS(5274),
    [anon_sym_tri] = ACTIONS(5274),
    [anon_sym_tri0] = ACTIONS(5274),
    [anon_sym_tri1] = ACTIONS(5274),
    [anon_sym_wand] = ACTIONS(5274),
    [anon_sym_triand] = ACTIONS(5274),
    [anon_sym_wor] = ACTIONS(5274),
    [anon_sym_trior] = ACTIONS(5274),
    [anon_sym_trireg] = ACTIONS(5274),
    [anon_sym_uwire] = ACTIONS(5274),
    [anon_sym_SEMI] = ACTIONS(5272),
    [anon_sym_extern] = ACTIONS(5274),
    [anon_sym_interface] = ACTIONS(5274),
    [anon_sym_checker] = ACTIONS(5274),
    [anon_sym_virtual] = ACTIONS(5274),
    [anon_sym_class] = ACTIONS(5274),
    [anon_sym_type] = ACTIONS(5274),
    [anon_sym_DOLLARfatal] = ACTIONS(5272),
    [anon_sym_DOLLARerror] = ACTIONS(5272),
    [anon_sym_DOLLARwarning] = ACTIONS(5272),
    [anon_sym_DOLLARinfo] = ACTIONS(5272),
    [anon_sym_default] = ACTIONS(5274),
    [anon_sym_clocking] = ACTIONS(5274),
    [anon_sym_defparam] = ACTIONS(5274),
    [anon_sym_bind] = ACTIONS(5274),
    [anon_sym_rand] = ACTIONS(5274),
    [anon_sym_const] = ACTIONS(5274),
    [anon_sym_function] = ACTIONS(5274),
    [anon_sym_static] = ACTIONS(5274),
    [anon_sym_constraint] = ACTIONS(5274),
    [anon_sym_if] = ACTIONS(5274),
    [anon_sym_else] = ACTIONS(5274),
    [anon_sym_LBRACK] = ACTIONS(5272),
    [anon_sym_localparam] = ACTIONS(5274),
    [anon_sym_parameter] = ACTIONS(5274),
    [anon_sym_var] = ACTIONS(5274),
    [anon_sym_import] = ACTIONS(5274),
    [anon_sym_export] = ACTIONS(5274),
    [anon_sym_genvar] = ACTIONS(5274),
    [anon_sym_interconnect] = ACTIONS(5274),
    [anon_sym_typedef] = ACTIONS(5274),
    [anon_sym_enum] = ACTIONS(5274),
    [anon_sym_struct] = ACTIONS(5274),
    [anon_sym_union] = ACTIONS(5274),
    [anon_sym_nettype] = ACTIONS(5274),
    [anon_sym_automatic] = ACTIONS(5274),
    [anon_sym_string] = ACTIONS(5274),
    [anon_sym_chandle] = ACTIONS(5274),
    [anon_sym_event] = ACTIONS(5274),
    [anon_sym_byte] = ACTIONS(5274),
    [anon_sym_shortint] = ACTIONS(5274),
    [anon_sym_int] = ACTIONS(5274),
    [anon_sym_longint] = ACTIONS(5274),
    [anon_sym_integer] = ACTIONS(5274),
    [anon_sym_time] = ACTIONS(5274),
    [anon_sym_bit] = ACTIONS(5274),
    [anon_sym_logic] = ACTIONS(5274),
    [anon_sym_reg] = ACTIONS(5274),
    [anon_sym_shortreal] = ACTIONS(5274),
    [anon_sym_real] = ACTIONS(5274),
    [anon_sym_realtime] = ACTIONS(5274),
    [anon_sym_supply0] = ACTIONS(5274),
    [anon_sym_supply1] = ACTIONS(5274),
    [anon_sym_signed] = ACTIONS(5274),
    [anon_sym_unsigned] = ACTIONS(5274),
    [anon_sym_task] = ACTIONS(5274),
    [anon_sym_assert] = ACTIONS(5274),
    [anon_sym_property] = ACTIONS(5274),
    [anon_sym_assume] = ACTIONS(5274),
    [anon_sym_cover] = ACTIONS(5274),
    [anon_sym_sequence] = ACTIONS(5274),
    [anon_sym_restrict] = ACTIONS(5274),
    [anon_sym_not] = ACTIONS(5274),
    [anon_sym_or] = ACTIONS(5274),
    [anon_sym_and] = ACTIONS(5274),
    [anon_sym_case] = ACTIONS(5274),
    [anon_sym_always] = ACTIONS(5274),
    [anon_sym_covergroup] = ACTIONS(5274),
    [anon_sym_let] = ACTIONS(5274),
    [anon_sym_pulldown] = ACTIONS(5274),
    [anon_sym_pullup] = ACTIONS(5274),
    [anon_sym_cmos] = ACTIONS(5274),
    [anon_sym_rcmos] = ACTIONS(5274),
    [anon_sym_bufif0] = ACTIONS(5274),
    [anon_sym_bufif1] = ACTIONS(5274),
    [anon_sym_notif0] = ACTIONS(5274),
    [anon_sym_notif1] = ACTIONS(5274),
    [anon_sym_nmos] = ACTIONS(5274),
    [anon_sym_pmos] = ACTIONS(5274),
    [anon_sym_rnmos] = ACTIONS(5274),
    [anon_sym_rpmos] = ACTIONS(5274),
    [anon_sym_nand] = ACTIONS(5274),
    [anon_sym_nor] = ACTIONS(5274),
    [anon_sym_xor] = ACTIONS(5274),
    [anon_sym_xnor] = ACTIONS(5274),
    [anon_sym_buf] = ACTIONS(5274),
    [anon_sym_tranif0] = ACTIONS(5274),
    [anon_sym_tranif1] = ACTIONS(5274),
    [anon_sym_rtranif1] = ACTIONS(5274),
    [anon_sym_rtranif0] = ACTIONS(5274),
    [anon_sym_tran] = ACTIONS(5274),
    [anon_sym_rtran] = ACTIONS(5274),
    [anon_sym_generate] = ACTIONS(5274),
    [anon_sym_endgenerate] = ACTIONS(5274),
    [anon_sym_for] = ACTIONS(5274),
    [anon_sym_initial] = ACTIONS(5274),
    [anon_sym_assign] = ACTIONS(5274),
    [anon_sym_alias] = ACTIONS(5274),
    [anon_sym_always_comb] = ACTIONS(5274),
    [anon_sym_always_latch] = ACTIONS(5274),
    [anon_sym_always_ff] = ACTIONS(5274),
    [anon_sym_final] = ACTIONS(5274),
    [anon_sym_global] = ACTIONS(5274),
    [anon_sym_LPAREN_STAR] = ACTIONS(5272),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5272),
    [anon_sym_DOLLARunit] = ACTIONS(5272),
  },
  [4893] = {
    [sym_simple_identifier] = ACTIONS(5786),
    [anon_sym_wire] = ACTIONS(5786),
    [anon_sym_tri] = ACTIONS(5786),
    [anon_sym_tri0] = ACTIONS(5786),
    [anon_sym_tri1] = ACTIONS(5786),
    [anon_sym_wand] = ACTIONS(5786),
    [anon_sym_triand] = ACTIONS(5786),
    [anon_sym_wor] = ACTIONS(5786),
    [anon_sym_trior] = ACTIONS(5786),
    [anon_sym_trireg] = ACTIONS(5786),
    [anon_sym_uwire] = ACTIONS(5786),
    [anon_sym_SEMI] = ACTIONS(5788),
    [anon_sym_extern] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(5786),
    [anon_sym_checker] = ACTIONS(5786),
    [anon_sym_virtual] = ACTIONS(5786),
    [anon_sym_class] = ACTIONS(5786),
    [anon_sym_type] = ACTIONS(5786),
    [anon_sym_DOLLARfatal] = ACTIONS(5788),
    [anon_sym_DOLLARerror] = ACTIONS(5788),
    [anon_sym_DOLLARwarning] = ACTIONS(5788),
    [anon_sym_DOLLARinfo] = ACTIONS(5788),
    [anon_sym_default] = ACTIONS(5786),
    [anon_sym_clocking] = ACTIONS(5786),
    [anon_sym_defparam] = ACTIONS(5786),
    [anon_sym_bind] = ACTIONS(5786),
    [anon_sym_rand] = ACTIONS(5786),
    [anon_sym_const] = ACTIONS(5786),
    [anon_sym_function] = ACTIONS(5786),
    [anon_sym_static] = ACTIONS(5786),
    [anon_sym_constraint] = ACTIONS(5786),
    [anon_sym_if] = ACTIONS(5786),
    [anon_sym_else] = ACTIONS(5786),
    [anon_sym_LBRACK] = ACTIONS(5788),
    [anon_sym_localparam] = ACTIONS(5786),
    [anon_sym_parameter] = ACTIONS(5786),
    [anon_sym_var] = ACTIONS(5786),
    [anon_sym_import] = ACTIONS(5786),
    [anon_sym_export] = ACTIONS(5786),
    [anon_sym_genvar] = ACTIONS(5786),
    [anon_sym_interconnect] = ACTIONS(5786),
    [anon_sym_typedef] = ACTIONS(5786),
    [anon_sym_enum] = ACTIONS(5786),
    [anon_sym_struct] = ACTIONS(5786),
    [anon_sym_union] = ACTIONS(5786),
    [anon_sym_nettype] = ACTIONS(5786),
    [anon_sym_automatic] = ACTIONS(5786),
    [anon_sym_string] = ACTIONS(5786),
    [anon_sym_chandle] = ACTIONS(5786),
    [anon_sym_event] = ACTIONS(5786),
    [anon_sym_byte] = ACTIONS(5786),
    [anon_sym_shortint] = ACTIONS(5786),
    [anon_sym_int] = ACTIONS(5786),
    [anon_sym_longint] = ACTIONS(5786),
    [anon_sym_integer] = ACTIONS(5786),
    [anon_sym_time] = ACTIONS(5786),
    [anon_sym_bit] = ACTIONS(5786),
    [anon_sym_logic] = ACTIONS(5786),
    [anon_sym_reg] = ACTIONS(5786),
    [anon_sym_shortreal] = ACTIONS(5786),
    [anon_sym_real] = ACTIONS(5786),
    [anon_sym_realtime] = ACTIONS(5786),
    [anon_sym_supply0] = ACTIONS(5786),
    [anon_sym_supply1] = ACTIONS(5786),
    [anon_sym_signed] = ACTIONS(5786),
    [anon_sym_unsigned] = ACTIONS(5786),
    [anon_sym_task] = ACTIONS(5786),
    [anon_sym_assert] = ACTIONS(5786),
    [anon_sym_property] = ACTIONS(5786),
    [anon_sym_assume] = ACTIONS(5786),
    [anon_sym_cover] = ACTIONS(5786),
    [anon_sym_sequence] = ACTIONS(5786),
    [anon_sym_restrict] = ACTIONS(5786),
    [anon_sym_not] = ACTIONS(5786),
    [anon_sym_or] = ACTIONS(5786),
    [anon_sym_and] = ACTIONS(5786),
    [anon_sym_case] = ACTIONS(5786),
    [anon_sym_always] = ACTIONS(5786),
    [anon_sym_covergroup] = ACTIONS(5786),
    [anon_sym_let] = ACTIONS(5786),
    [anon_sym_pulldown] = ACTIONS(5786),
    [anon_sym_pullup] = ACTIONS(5786),
    [anon_sym_cmos] = ACTIONS(5786),
    [anon_sym_rcmos] = ACTIONS(5786),
    [anon_sym_bufif0] = ACTIONS(5786),
    [anon_sym_bufif1] = ACTIONS(5786),
    [anon_sym_notif0] = ACTIONS(5786),
    [anon_sym_notif1] = ACTIONS(5786),
    [anon_sym_nmos] = ACTIONS(5786),
    [anon_sym_pmos] = ACTIONS(5786),
    [anon_sym_rnmos] = ACTIONS(5786),
    [anon_sym_rpmos] = ACTIONS(5786),
    [anon_sym_nand] = ACTIONS(5786),
    [anon_sym_nor] = ACTIONS(5786),
    [anon_sym_xor] = ACTIONS(5786),
    [anon_sym_xnor] = ACTIONS(5786),
    [anon_sym_buf] = ACTIONS(5786),
    [anon_sym_tranif0] = ACTIONS(5786),
    [anon_sym_tranif1] = ACTIONS(5786),
    [anon_sym_rtranif1] = ACTIONS(5786),
    [anon_sym_rtranif0] = ACTIONS(5786),
    [anon_sym_tran] = ACTIONS(5786),
    [anon_sym_rtran] = ACTIONS(5786),
    [anon_sym_generate] = ACTIONS(5786),
    [anon_sym_endgenerate] = ACTIONS(5786),
    [anon_sym_for] = ACTIONS(5786),
    [anon_sym_initial] = ACTIONS(5786),
    [anon_sym_assign] = ACTIONS(5786),
    [anon_sym_alias] = ACTIONS(5786),
    [anon_sym_always_comb] = ACTIONS(5786),
    [anon_sym_always_latch] = ACTIONS(5786),
    [anon_sym_always_ff] = ACTIONS(5786),
    [anon_sym_final] = ACTIONS(5786),
    [anon_sym_global] = ACTIONS(5786),
    [anon_sym_LPAREN_STAR] = ACTIONS(5788),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5788),
    [anon_sym_DOLLARunit] = ACTIONS(5788),
  },
  [4894] = {
    [sym_simple_identifier] = ACTIONS(4658),
    [anon_sym_wire] = ACTIONS(4658),
    [anon_sym_tri] = ACTIONS(4658),
    [anon_sym_tri0] = ACTIONS(4658),
    [anon_sym_tri1] = ACTIONS(4658),
    [anon_sym_wand] = ACTIONS(4658),
    [anon_sym_triand] = ACTIONS(4658),
    [anon_sym_wor] = ACTIONS(4658),
    [anon_sym_trior] = ACTIONS(4658),
    [anon_sym_trireg] = ACTIONS(4658),
    [anon_sym_uwire] = ACTIONS(4658),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_extern] = ACTIONS(4658),
    [anon_sym_interface] = ACTIONS(4658),
    [anon_sym_checker] = ACTIONS(4658),
    [anon_sym_virtual] = ACTIONS(4658),
    [anon_sym_class] = ACTIONS(4658),
    [anon_sym_type] = ACTIONS(4658),
    [anon_sym_DOLLARfatal] = ACTIONS(4656),
    [anon_sym_DOLLARerror] = ACTIONS(4656),
    [anon_sym_DOLLARwarning] = ACTIONS(4656),
    [anon_sym_DOLLARinfo] = ACTIONS(4656),
    [anon_sym_default] = ACTIONS(4658),
    [anon_sym_clocking] = ACTIONS(4658),
    [anon_sym_defparam] = ACTIONS(4658),
    [anon_sym_bind] = ACTIONS(4658),
    [anon_sym_rand] = ACTIONS(4658),
    [anon_sym_const] = ACTIONS(4658),
    [anon_sym_function] = ACTIONS(4658),
    [anon_sym_static] = ACTIONS(4658),
    [anon_sym_constraint] = ACTIONS(4658),
    [anon_sym_if] = ACTIONS(4658),
    [anon_sym_else] = ACTIONS(4658),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [anon_sym_localparam] = ACTIONS(4658),
    [anon_sym_parameter] = ACTIONS(4658),
    [anon_sym_var] = ACTIONS(4658),
    [anon_sym_import] = ACTIONS(4658),
    [anon_sym_export] = ACTIONS(4658),
    [anon_sym_genvar] = ACTIONS(4658),
    [anon_sym_interconnect] = ACTIONS(4658),
    [anon_sym_typedef] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_struct] = ACTIONS(4658),
    [anon_sym_union] = ACTIONS(4658),
    [anon_sym_nettype] = ACTIONS(4658),
    [anon_sym_automatic] = ACTIONS(4658),
    [anon_sym_string] = ACTIONS(4658),
    [anon_sym_chandle] = ACTIONS(4658),
    [anon_sym_event] = ACTIONS(4658),
    [anon_sym_byte] = ACTIONS(4658),
    [anon_sym_shortint] = ACTIONS(4658),
    [anon_sym_int] = ACTIONS(4658),
    [anon_sym_longint] = ACTIONS(4658),
    [anon_sym_integer] = ACTIONS(4658),
    [anon_sym_time] = ACTIONS(4658),
    [anon_sym_bit] = ACTIONS(4658),
    [anon_sym_logic] = ACTIONS(4658),
    [anon_sym_reg] = ACTIONS(4658),
    [anon_sym_shortreal] = ACTIONS(4658),
    [anon_sym_real] = ACTIONS(4658),
    [anon_sym_realtime] = ACTIONS(4658),
    [anon_sym_supply0] = ACTIONS(4658),
    [anon_sym_supply1] = ACTIONS(4658),
    [anon_sym_signed] = ACTIONS(4658),
    [anon_sym_unsigned] = ACTIONS(4658),
    [anon_sym_task] = ACTIONS(4658),
    [anon_sym_assert] = ACTIONS(4658),
    [anon_sym_property] = ACTIONS(4658),
    [anon_sym_assume] = ACTIONS(4658),
    [anon_sym_cover] = ACTIONS(4658),
    [anon_sym_sequence] = ACTIONS(4658),
    [anon_sym_restrict] = ACTIONS(4658),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_or] = ACTIONS(4658),
    [anon_sym_and] = ACTIONS(4658),
    [anon_sym_case] = ACTIONS(4658),
    [anon_sym_always] = ACTIONS(4658),
    [anon_sym_covergroup] = ACTIONS(4658),
    [anon_sym_end] = ACTIONS(4658),
    [anon_sym_let] = ACTIONS(4658),
    [anon_sym_pulldown] = ACTIONS(4658),
    [anon_sym_pullup] = ACTIONS(4658),
    [anon_sym_cmos] = ACTIONS(4658),
    [anon_sym_rcmos] = ACTIONS(4658),
    [anon_sym_bufif0] = ACTIONS(4658),
    [anon_sym_bufif1] = ACTIONS(4658),
    [anon_sym_notif0] = ACTIONS(4658),
    [anon_sym_notif1] = ACTIONS(4658),
    [anon_sym_nmos] = ACTIONS(4658),
    [anon_sym_pmos] = ACTIONS(4658),
    [anon_sym_rnmos] = ACTIONS(4658),
    [anon_sym_rpmos] = ACTIONS(4658),
    [anon_sym_nand] = ACTIONS(4658),
    [anon_sym_nor] = ACTIONS(4658),
    [anon_sym_xor] = ACTIONS(4658),
    [anon_sym_xnor] = ACTIONS(4658),
    [anon_sym_buf] = ACTIONS(4658),
    [anon_sym_tranif0] = ACTIONS(4658),
    [anon_sym_tranif1] = ACTIONS(4658),
    [anon_sym_rtranif1] = ACTIONS(4658),
    [anon_sym_rtranif0] = ACTIONS(4658),
    [anon_sym_tran] = ACTIONS(4658),
    [anon_sym_rtran] = ACTIONS(4658),
    [anon_sym_generate] = ACTIONS(4658),
    [anon_sym_for] = ACTIONS(4658),
    [anon_sym_initial] = ACTIONS(4658),
    [anon_sym_assign] = ACTIONS(4658),
    [anon_sym_alias] = ACTIONS(4658),
    [anon_sym_always_comb] = ACTIONS(4658),
    [anon_sym_always_latch] = ACTIONS(4658),
    [anon_sym_always_ff] = ACTIONS(4658),
    [anon_sym_final] = ACTIONS(4658),
    [anon_sym_global] = ACTIONS(4658),
    [anon_sym_LPAREN_STAR] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4656),
    [anon_sym_DOLLARunit] = ACTIONS(4656),
  },
  [4895] = {
    [sym_simple_identifier] = ACTIONS(6375),
    [anon_sym_wire] = ACTIONS(6375),
    [anon_sym_tri] = ACTIONS(6375),
    [anon_sym_tri0] = ACTIONS(6375),
    [anon_sym_tri1] = ACTIONS(6375),
    [anon_sym_wand] = ACTIONS(6375),
    [anon_sym_triand] = ACTIONS(6375),
    [anon_sym_wor] = ACTIONS(6375),
    [anon_sym_trior] = ACTIONS(6375),
    [anon_sym_trireg] = ACTIONS(6375),
    [anon_sym_uwire] = ACTIONS(6375),
    [anon_sym_SEMI] = ACTIONS(6377),
    [anon_sym_extern] = ACTIONS(6375),
    [anon_sym_interface] = ACTIONS(6375),
    [anon_sym_checker] = ACTIONS(6375),
    [anon_sym_virtual] = ACTIONS(6375),
    [anon_sym_class] = ACTIONS(6375),
    [anon_sym_type] = ACTIONS(6375),
    [anon_sym_DOLLARfatal] = ACTIONS(6377),
    [anon_sym_DOLLARerror] = ACTIONS(6377),
    [anon_sym_DOLLARwarning] = ACTIONS(6377),
    [anon_sym_DOLLARinfo] = ACTIONS(6377),
    [anon_sym_default] = ACTIONS(6375),
    [anon_sym_clocking] = ACTIONS(6375),
    [anon_sym_defparam] = ACTIONS(6375),
    [anon_sym_bind] = ACTIONS(6375),
    [anon_sym_rand] = ACTIONS(6375),
    [anon_sym_const] = ACTIONS(6375),
    [anon_sym_function] = ACTIONS(6375),
    [anon_sym_static] = ACTIONS(6375),
    [anon_sym_constraint] = ACTIONS(6375),
    [anon_sym_if] = ACTIONS(6375),
    [anon_sym_else] = ACTIONS(6375),
    [anon_sym_LBRACK] = ACTIONS(6377),
    [anon_sym_localparam] = ACTIONS(6375),
    [anon_sym_parameter] = ACTIONS(6375),
    [anon_sym_var] = ACTIONS(6375),
    [anon_sym_import] = ACTIONS(6375),
    [anon_sym_export] = ACTIONS(6375),
    [anon_sym_genvar] = ACTIONS(6375),
    [anon_sym_interconnect] = ACTIONS(6375),
    [anon_sym_typedef] = ACTIONS(6375),
    [anon_sym_enum] = ACTIONS(6375),
    [anon_sym_struct] = ACTIONS(6375),
    [anon_sym_union] = ACTIONS(6375),
    [anon_sym_nettype] = ACTIONS(6375),
    [anon_sym_automatic] = ACTIONS(6375),
    [anon_sym_string] = ACTIONS(6375),
    [anon_sym_chandle] = ACTIONS(6375),
    [anon_sym_event] = ACTIONS(6375),
    [anon_sym_byte] = ACTIONS(6375),
    [anon_sym_shortint] = ACTIONS(6375),
    [anon_sym_int] = ACTIONS(6375),
    [anon_sym_longint] = ACTIONS(6375),
    [anon_sym_integer] = ACTIONS(6375),
    [anon_sym_time] = ACTIONS(6375),
    [anon_sym_bit] = ACTIONS(6375),
    [anon_sym_logic] = ACTIONS(6375),
    [anon_sym_reg] = ACTIONS(6375),
    [anon_sym_shortreal] = ACTIONS(6375),
    [anon_sym_real] = ACTIONS(6375),
    [anon_sym_realtime] = ACTIONS(6375),
    [anon_sym_supply0] = ACTIONS(6375),
    [anon_sym_supply1] = ACTIONS(6375),
    [anon_sym_signed] = ACTIONS(6375),
    [anon_sym_unsigned] = ACTIONS(6375),
    [anon_sym_task] = ACTIONS(6375),
    [anon_sym_assert] = ACTIONS(6375),
    [anon_sym_property] = ACTIONS(6375),
    [anon_sym_assume] = ACTIONS(6375),
    [anon_sym_cover] = ACTIONS(6375),
    [anon_sym_sequence] = ACTIONS(6375),
    [anon_sym_restrict] = ACTIONS(6375),
    [anon_sym_not] = ACTIONS(6375),
    [anon_sym_or] = ACTIONS(6375),
    [anon_sym_and] = ACTIONS(6375),
    [anon_sym_case] = ACTIONS(6375),
    [anon_sym_always] = ACTIONS(6375),
    [anon_sym_covergroup] = ACTIONS(6375),
    [anon_sym_end] = ACTIONS(6375),
    [anon_sym_let] = ACTIONS(6375),
    [anon_sym_pulldown] = ACTIONS(6375),
    [anon_sym_pullup] = ACTIONS(6375),
    [anon_sym_cmos] = ACTIONS(6375),
    [anon_sym_rcmos] = ACTIONS(6375),
    [anon_sym_bufif0] = ACTIONS(6375),
    [anon_sym_bufif1] = ACTIONS(6375),
    [anon_sym_notif0] = ACTIONS(6375),
    [anon_sym_notif1] = ACTIONS(6375),
    [anon_sym_nmos] = ACTIONS(6375),
    [anon_sym_pmos] = ACTIONS(6375),
    [anon_sym_rnmos] = ACTIONS(6375),
    [anon_sym_rpmos] = ACTIONS(6375),
    [anon_sym_nand] = ACTIONS(6375),
    [anon_sym_nor] = ACTIONS(6375),
    [anon_sym_xor] = ACTIONS(6375),
    [anon_sym_xnor] = ACTIONS(6375),
    [anon_sym_buf] = ACTIONS(6375),
    [anon_sym_tranif0] = ACTIONS(6375),
    [anon_sym_tranif1] = ACTIONS(6375),
    [anon_sym_rtranif1] = ACTIONS(6375),
    [anon_sym_rtranif0] = ACTIONS(6375),
    [anon_sym_tran] = ACTIONS(6375),
    [anon_sym_rtran] = ACTIONS(6375),
    [anon_sym_generate] = ACTIONS(6375),
    [anon_sym_for] = ACTIONS(6375),
    [anon_sym_initial] = ACTIONS(6375),
    [anon_sym_assign] = ACTIONS(6375),
    [anon_sym_alias] = ACTIONS(6375),
    [anon_sym_always_comb] = ACTIONS(6375),
    [anon_sym_always_latch] = ACTIONS(6375),
    [anon_sym_always_ff] = ACTIONS(6375),
    [anon_sym_final] = ACTIONS(6375),
    [anon_sym_global] = ACTIONS(6375),
    [anon_sym_LPAREN_STAR] = ACTIONS(6377),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6377),
    [anon_sym_DOLLARunit] = ACTIONS(6377),
  },
  [4896] = {
    [sym_simple_identifier] = ACTIONS(5496),
    [anon_sym_wire] = ACTIONS(5496),
    [anon_sym_tri] = ACTIONS(5496),
    [anon_sym_tri0] = ACTIONS(5496),
    [anon_sym_tri1] = ACTIONS(5496),
    [anon_sym_wand] = ACTIONS(5496),
    [anon_sym_triand] = ACTIONS(5496),
    [anon_sym_wor] = ACTIONS(5496),
    [anon_sym_trior] = ACTIONS(5496),
    [anon_sym_trireg] = ACTIONS(5496),
    [anon_sym_uwire] = ACTIONS(5496),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_extern] = ACTIONS(5496),
    [anon_sym_interface] = ACTIONS(5496),
    [anon_sym_checker] = ACTIONS(5496),
    [anon_sym_virtual] = ACTIONS(5496),
    [anon_sym_class] = ACTIONS(5496),
    [anon_sym_type] = ACTIONS(5496),
    [anon_sym_DOLLARfatal] = ACTIONS(5494),
    [anon_sym_DOLLARerror] = ACTIONS(5494),
    [anon_sym_DOLLARwarning] = ACTIONS(5494),
    [anon_sym_DOLLARinfo] = ACTIONS(5494),
    [anon_sym_default] = ACTIONS(5496),
    [anon_sym_clocking] = ACTIONS(5496),
    [anon_sym_defparam] = ACTIONS(5496),
    [anon_sym_bind] = ACTIONS(5496),
    [anon_sym_rand] = ACTIONS(5496),
    [anon_sym_const] = ACTIONS(5496),
    [anon_sym_function] = ACTIONS(5496),
    [anon_sym_static] = ACTIONS(5496),
    [anon_sym_constraint] = ACTIONS(5496),
    [anon_sym_if] = ACTIONS(5496),
    [anon_sym_else] = ACTIONS(5496),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_localparam] = ACTIONS(5496),
    [anon_sym_parameter] = ACTIONS(5496),
    [anon_sym_var] = ACTIONS(5496),
    [anon_sym_import] = ACTIONS(5496),
    [anon_sym_export] = ACTIONS(5496),
    [anon_sym_genvar] = ACTIONS(5496),
    [anon_sym_interconnect] = ACTIONS(5496),
    [anon_sym_typedef] = ACTIONS(5496),
    [anon_sym_enum] = ACTIONS(5496),
    [anon_sym_struct] = ACTIONS(5496),
    [anon_sym_union] = ACTIONS(5496),
    [anon_sym_nettype] = ACTIONS(5496),
    [anon_sym_automatic] = ACTIONS(5496),
    [anon_sym_string] = ACTIONS(5496),
    [anon_sym_chandle] = ACTIONS(5496),
    [anon_sym_event] = ACTIONS(5496),
    [anon_sym_byte] = ACTIONS(5496),
    [anon_sym_shortint] = ACTIONS(5496),
    [anon_sym_int] = ACTIONS(5496),
    [anon_sym_longint] = ACTIONS(5496),
    [anon_sym_integer] = ACTIONS(5496),
    [anon_sym_time] = ACTIONS(5496),
    [anon_sym_bit] = ACTIONS(5496),
    [anon_sym_logic] = ACTIONS(5496),
    [anon_sym_reg] = ACTIONS(5496),
    [anon_sym_shortreal] = ACTIONS(5496),
    [anon_sym_real] = ACTIONS(5496),
    [anon_sym_realtime] = ACTIONS(5496),
    [anon_sym_supply0] = ACTIONS(5496),
    [anon_sym_supply1] = ACTIONS(5496),
    [anon_sym_signed] = ACTIONS(5496),
    [anon_sym_unsigned] = ACTIONS(5496),
    [anon_sym_task] = ACTIONS(5496),
    [anon_sym_assert] = ACTIONS(5496),
    [anon_sym_property] = ACTIONS(5496),
    [anon_sym_assume] = ACTIONS(5496),
    [anon_sym_cover] = ACTIONS(5496),
    [anon_sym_sequence] = ACTIONS(5496),
    [anon_sym_restrict] = ACTIONS(5496),
    [anon_sym_not] = ACTIONS(5496),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_and] = ACTIONS(5496),
    [anon_sym_case] = ACTIONS(5496),
    [anon_sym_always] = ACTIONS(5496),
    [anon_sym_covergroup] = ACTIONS(5496),
    [anon_sym_let] = ACTIONS(5496),
    [anon_sym_pulldown] = ACTIONS(5496),
    [anon_sym_pullup] = ACTIONS(5496),
    [anon_sym_cmos] = ACTIONS(5496),
    [anon_sym_rcmos] = ACTIONS(5496),
    [anon_sym_bufif0] = ACTIONS(5496),
    [anon_sym_bufif1] = ACTIONS(5496),
    [anon_sym_notif0] = ACTIONS(5496),
    [anon_sym_notif1] = ACTIONS(5496),
    [anon_sym_nmos] = ACTIONS(5496),
    [anon_sym_pmos] = ACTIONS(5496),
    [anon_sym_rnmos] = ACTIONS(5496),
    [anon_sym_rpmos] = ACTIONS(5496),
    [anon_sym_nand] = ACTIONS(5496),
    [anon_sym_nor] = ACTIONS(5496),
    [anon_sym_xor] = ACTIONS(5496),
    [anon_sym_xnor] = ACTIONS(5496),
    [anon_sym_buf] = ACTIONS(5496),
    [anon_sym_tranif0] = ACTIONS(5496),
    [anon_sym_tranif1] = ACTIONS(5496),
    [anon_sym_rtranif1] = ACTIONS(5496),
    [anon_sym_rtranif0] = ACTIONS(5496),
    [anon_sym_tran] = ACTIONS(5496),
    [anon_sym_rtran] = ACTIONS(5496),
    [anon_sym_generate] = ACTIONS(5496),
    [anon_sym_endgenerate] = ACTIONS(5496),
    [anon_sym_for] = ACTIONS(5496),
    [anon_sym_initial] = ACTIONS(5496),
    [anon_sym_assign] = ACTIONS(5496),
    [anon_sym_alias] = ACTIONS(5496),
    [anon_sym_always_comb] = ACTIONS(5496),
    [anon_sym_always_latch] = ACTIONS(5496),
    [anon_sym_always_ff] = ACTIONS(5496),
    [anon_sym_final] = ACTIONS(5496),
    [anon_sym_global] = ACTIONS(5496),
    [anon_sym_LPAREN_STAR] = ACTIONS(5494),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5494),
    [anon_sym_DOLLARunit] = ACTIONS(5494),
  },
  [4897] = {
    [sym_simple_identifier] = ACTIONS(5206),
    [anon_sym_wire] = ACTIONS(5206),
    [anon_sym_tri] = ACTIONS(5206),
    [anon_sym_tri0] = ACTIONS(5206),
    [anon_sym_tri1] = ACTIONS(5206),
    [anon_sym_wand] = ACTIONS(5206),
    [anon_sym_triand] = ACTIONS(5206),
    [anon_sym_wor] = ACTIONS(5206),
    [anon_sym_trior] = ACTIONS(5206),
    [anon_sym_trireg] = ACTIONS(5206),
    [anon_sym_uwire] = ACTIONS(5206),
    [anon_sym_SEMI] = ACTIONS(5204),
    [anon_sym_extern] = ACTIONS(5206),
    [anon_sym_interface] = ACTIONS(5206),
    [anon_sym_checker] = ACTIONS(5206),
    [anon_sym_virtual] = ACTIONS(5206),
    [anon_sym_class] = ACTIONS(5206),
    [anon_sym_type] = ACTIONS(5206),
    [anon_sym_DOLLARfatal] = ACTIONS(5204),
    [anon_sym_DOLLARerror] = ACTIONS(5204),
    [anon_sym_DOLLARwarning] = ACTIONS(5204),
    [anon_sym_DOLLARinfo] = ACTIONS(5204),
    [anon_sym_default] = ACTIONS(5206),
    [anon_sym_clocking] = ACTIONS(5206),
    [anon_sym_defparam] = ACTIONS(5206),
    [anon_sym_bind] = ACTIONS(5206),
    [anon_sym_rand] = ACTIONS(5206),
    [anon_sym_const] = ACTIONS(5206),
    [anon_sym_function] = ACTIONS(5206),
    [anon_sym_static] = ACTIONS(5206),
    [anon_sym_constraint] = ACTIONS(5206),
    [anon_sym_if] = ACTIONS(5206),
    [anon_sym_else] = ACTIONS(5206),
    [anon_sym_LBRACK] = ACTIONS(5204),
    [anon_sym_localparam] = ACTIONS(5206),
    [anon_sym_parameter] = ACTIONS(5206),
    [anon_sym_var] = ACTIONS(5206),
    [anon_sym_import] = ACTIONS(5206),
    [anon_sym_export] = ACTIONS(5206),
    [anon_sym_genvar] = ACTIONS(5206),
    [anon_sym_interconnect] = ACTIONS(5206),
    [anon_sym_typedef] = ACTIONS(5206),
    [anon_sym_enum] = ACTIONS(5206),
    [anon_sym_struct] = ACTIONS(5206),
    [anon_sym_union] = ACTIONS(5206),
    [anon_sym_nettype] = ACTIONS(5206),
    [anon_sym_automatic] = ACTIONS(5206),
    [anon_sym_string] = ACTIONS(5206),
    [anon_sym_chandle] = ACTIONS(5206),
    [anon_sym_event] = ACTIONS(5206),
    [anon_sym_byte] = ACTIONS(5206),
    [anon_sym_shortint] = ACTIONS(5206),
    [anon_sym_int] = ACTIONS(5206),
    [anon_sym_longint] = ACTIONS(5206),
    [anon_sym_integer] = ACTIONS(5206),
    [anon_sym_time] = ACTIONS(5206),
    [anon_sym_bit] = ACTIONS(5206),
    [anon_sym_logic] = ACTIONS(5206),
    [anon_sym_reg] = ACTIONS(5206),
    [anon_sym_shortreal] = ACTIONS(5206),
    [anon_sym_real] = ACTIONS(5206),
    [anon_sym_realtime] = ACTIONS(5206),
    [anon_sym_supply0] = ACTIONS(5206),
    [anon_sym_supply1] = ACTIONS(5206),
    [anon_sym_signed] = ACTIONS(5206),
    [anon_sym_unsigned] = ACTIONS(5206),
    [anon_sym_task] = ACTIONS(5206),
    [anon_sym_assert] = ACTIONS(5206),
    [anon_sym_property] = ACTIONS(5206),
    [anon_sym_assume] = ACTIONS(5206),
    [anon_sym_cover] = ACTIONS(5206),
    [anon_sym_sequence] = ACTIONS(5206),
    [anon_sym_restrict] = ACTIONS(5206),
    [anon_sym_not] = ACTIONS(5206),
    [anon_sym_or] = ACTIONS(5206),
    [anon_sym_and] = ACTIONS(5206),
    [anon_sym_case] = ACTIONS(5206),
    [anon_sym_always] = ACTIONS(5206),
    [anon_sym_covergroup] = ACTIONS(5206),
    [anon_sym_let] = ACTIONS(5206),
    [anon_sym_pulldown] = ACTIONS(5206),
    [anon_sym_pullup] = ACTIONS(5206),
    [anon_sym_cmos] = ACTIONS(5206),
    [anon_sym_rcmos] = ACTIONS(5206),
    [anon_sym_bufif0] = ACTIONS(5206),
    [anon_sym_bufif1] = ACTIONS(5206),
    [anon_sym_notif0] = ACTIONS(5206),
    [anon_sym_notif1] = ACTIONS(5206),
    [anon_sym_nmos] = ACTIONS(5206),
    [anon_sym_pmos] = ACTIONS(5206),
    [anon_sym_rnmos] = ACTIONS(5206),
    [anon_sym_rpmos] = ACTIONS(5206),
    [anon_sym_nand] = ACTIONS(5206),
    [anon_sym_nor] = ACTIONS(5206),
    [anon_sym_xor] = ACTIONS(5206),
    [anon_sym_xnor] = ACTIONS(5206),
    [anon_sym_buf] = ACTIONS(5206),
    [anon_sym_tranif0] = ACTIONS(5206),
    [anon_sym_tranif1] = ACTIONS(5206),
    [anon_sym_rtranif1] = ACTIONS(5206),
    [anon_sym_rtranif0] = ACTIONS(5206),
    [anon_sym_tran] = ACTIONS(5206),
    [anon_sym_rtran] = ACTIONS(5206),
    [anon_sym_generate] = ACTIONS(5206),
    [anon_sym_endgenerate] = ACTIONS(5206),
    [anon_sym_for] = ACTIONS(5206),
    [anon_sym_initial] = ACTIONS(5206),
    [anon_sym_assign] = ACTIONS(5206),
    [anon_sym_alias] = ACTIONS(5206),
    [anon_sym_always_comb] = ACTIONS(5206),
    [anon_sym_always_latch] = ACTIONS(5206),
    [anon_sym_always_ff] = ACTIONS(5206),
    [anon_sym_final] = ACTIONS(5206),
    [anon_sym_global] = ACTIONS(5206),
    [anon_sym_LPAREN_STAR] = ACTIONS(5204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5204),
    [anon_sym_DOLLARunit] = ACTIONS(5204),
  },
  [4898] = {
    [sym_simple_identifier] = ACTIONS(4880),
    [anon_sym_wire] = ACTIONS(4880),
    [anon_sym_tri] = ACTIONS(4880),
    [anon_sym_tri0] = ACTIONS(4880),
    [anon_sym_tri1] = ACTIONS(4880),
    [anon_sym_wand] = ACTIONS(4880),
    [anon_sym_triand] = ACTIONS(4880),
    [anon_sym_wor] = ACTIONS(4880),
    [anon_sym_trior] = ACTIONS(4880),
    [anon_sym_trireg] = ACTIONS(4880),
    [anon_sym_uwire] = ACTIONS(4880),
    [anon_sym_SEMI] = ACTIONS(4878),
    [anon_sym_extern] = ACTIONS(4880),
    [anon_sym_interface] = ACTIONS(4880),
    [anon_sym_checker] = ACTIONS(4880),
    [anon_sym_virtual] = ACTIONS(4880),
    [anon_sym_class] = ACTIONS(4880),
    [anon_sym_type] = ACTIONS(4880),
    [anon_sym_DOLLARfatal] = ACTIONS(4878),
    [anon_sym_DOLLARerror] = ACTIONS(4878),
    [anon_sym_DOLLARwarning] = ACTIONS(4878),
    [anon_sym_DOLLARinfo] = ACTIONS(4878),
    [anon_sym_default] = ACTIONS(4880),
    [anon_sym_clocking] = ACTIONS(4880),
    [anon_sym_defparam] = ACTIONS(4880),
    [anon_sym_bind] = ACTIONS(4880),
    [anon_sym_rand] = ACTIONS(4880),
    [anon_sym_const] = ACTIONS(4880),
    [anon_sym_function] = ACTIONS(4880),
    [anon_sym_static] = ACTIONS(4880),
    [anon_sym_constraint] = ACTIONS(4880),
    [anon_sym_if] = ACTIONS(4880),
    [anon_sym_else] = ACTIONS(4880),
    [anon_sym_LBRACK] = ACTIONS(4878),
    [anon_sym_localparam] = ACTIONS(4880),
    [anon_sym_parameter] = ACTIONS(4880),
    [anon_sym_var] = ACTIONS(4880),
    [anon_sym_import] = ACTIONS(4880),
    [anon_sym_export] = ACTIONS(4880),
    [anon_sym_genvar] = ACTIONS(4880),
    [anon_sym_interconnect] = ACTIONS(4880),
    [anon_sym_typedef] = ACTIONS(4880),
    [anon_sym_enum] = ACTIONS(4880),
    [anon_sym_struct] = ACTIONS(4880),
    [anon_sym_union] = ACTIONS(4880),
    [anon_sym_nettype] = ACTIONS(4880),
    [anon_sym_automatic] = ACTIONS(4880),
    [anon_sym_string] = ACTIONS(4880),
    [anon_sym_chandle] = ACTIONS(4880),
    [anon_sym_event] = ACTIONS(4880),
    [anon_sym_byte] = ACTIONS(4880),
    [anon_sym_shortint] = ACTIONS(4880),
    [anon_sym_int] = ACTIONS(4880),
    [anon_sym_longint] = ACTIONS(4880),
    [anon_sym_integer] = ACTIONS(4880),
    [anon_sym_time] = ACTIONS(4880),
    [anon_sym_bit] = ACTIONS(4880),
    [anon_sym_logic] = ACTIONS(4880),
    [anon_sym_reg] = ACTIONS(4880),
    [anon_sym_shortreal] = ACTIONS(4880),
    [anon_sym_real] = ACTIONS(4880),
    [anon_sym_realtime] = ACTIONS(4880),
    [anon_sym_supply0] = ACTIONS(4880),
    [anon_sym_supply1] = ACTIONS(4880),
    [anon_sym_signed] = ACTIONS(4880),
    [anon_sym_unsigned] = ACTIONS(4880),
    [anon_sym_task] = ACTIONS(4880),
    [anon_sym_assert] = ACTIONS(4880),
    [anon_sym_property] = ACTIONS(4880),
    [anon_sym_assume] = ACTIONS(4880),
    [anon_sym_cover] = ACTIONS(4880),
    [anon_sym_sequence] = ACTIONS(4880),
    [anon_sym_restrict] = ACTIONS(4880),
    [anon_sym_not] = ACTIONS(4880),
    [anon_sym_or] = ACTIONS(4880),
    [anon_sym_and] = ACTIONS(4880),
    [anon_sym_case] = ACTIONS(4880),
    [anon_sym_always] = ACTIONS(4880),
    [anon_sym_covergroup] = ACTIONS(4880),
    [anon_sym_let] = ACTIONS(4880),
    [anon_sym_pulldown] = ACTIONS(4880),
    [anon_sym_pullup] = ACTIONS(4880),
    [anon_sym_cmos] = ACTIONS(4880),
    [anon_sym_rcmos] = ACTIONS(4880),
    [anon_sym_bufif0] = ACTIONS(4880),
    [anon_sym_bufif1] = ACTIONS(4880),
    [anon_sym_notif0] = ACTIONS(4880),
    [anon_sym_notif1] = ACTIONS(4880),
    [anon_sym_nmos] = ACTIONS(4880),
    [anon_sym_pmos] = ACTIONS(4880),
    [anon_sym_rnmos] = ACTIONS(4880),
    [anon_sym_rpmos] = ACTIONS(4880),
    [anon_sym_nand] = ACTIONS(4880),
    [anon_sym_nor] = ACTIONS(4880),
    [anon_sym_xor] = ACTIONS(4880),
    [anon_sym_xnor] = ACTIONS(4880),
    [anon_sym_buf] = ACTIONS(4880),
    [anon_sym_tranif0] = ACTIONS(4880),
    [anon_sym_tranif1] = ACTIONS(4880),
    [anon_sym_rtranif1] = ACTIONS(4880),
    [anon_sym_rtranif0] = ACTIONS(4880),
    [anon_sym_tran] = ACTIONS(4880),
    [anon_sym_rtran] = ACTIONS(4880),
    [anon_sym_generate] = ACTIONS(4880),
    [anon_sym_endgenerate] = ACTIONS(4880),
    [anon_sym_for] = ACTIONS(4880),
    [anon_sym_initial] = ACTIONS(4880),
    [anon_sym_assign] = ACTIONS(4880),
    [anon_sym_alias] = ACTIONS(4880),
    [anon_sym_always_comb] = ACTIONS(4880),
    [anon_sym_always_latch] = ACTIONS(4880),
    [anon_sym_always_ff] = ACTIONS(4880),
    [anon_sym_final] = ACTIONS(4880),
    [anon_sym_global] = ACTIONS(4880),
    [anon_sym_LPAREN_STAR] = ACTIONS(4878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4878),
    [anon_sym_DOLLARunit] = ACTIONS(4878),
  },
  [4899] = {
    [sym_simple_identifier] = ACTIONS(5802),
    [anon_sym_wire] = ACTIONS(5802),
    [anon_sym_tri] = ACTIONS(5802),
    [anon_sym_tri0] = ACTIONS(5802),
    [anon_sym_tri1] = ACTIONS(5802),
    [anon_sym_wand] = ACTIONS(5802),
    [anon_sym_triand] = ACTIONS(5802),
    [anon_sym_wor] = ACTIONS(5802),
    [anon_sym_trior] = ACTIONS(5802),
    [anon_sym_trireg] = ACTIONS(5802),
    [anon_sym_uwire] = ACTIONS(5802),
    [anon_sym_SEMI] = ACTIONS(5804),
    [anon_sym_extern] = ACTIONS(5802),
    [anon_sym_interface] = ACTIONS(5802),
    [anon_sym_checker] = ACTIONS(5802),
    [anon_sym_virtual] = ACTIONS(5802),
    [anon_sym_class] = ACTIONS(5802),
    [anon_sym_type] = ACTIONS(5802),
    [anon_sym_DOLLARfatal] = ACTIONS(5804),
    [anon_sym_DOLLARerror] = ACTIONS(5804),
    [anon_sym_DOLLARwarning] = ACTIONS(5804),
    [anon_sym_DOLLARinfo] = ACTIONS(5804),
    [anon_sym_default] = ACTIONS(5802),
    [anon_sym_clocking] = ACTIONS(5802),
    [anon_sym_defparam] = ACTIONS(5802),
    [anon_sym_bind] = ACTIONS(5802),
    [anon_sym_rand] = ACTIONS(5802),
    [anon_sym_const] = ACTIONS(5802),
    [anon_sym_function] = ACTIONS(5802),
    [anon_sym_static] = ACTIONS(5802),
    [anon_sym_constraint] = ACTIONS(5802),
    [anon_sym_if] = ACTIONS(5802),
    [anon_sym_else] = ACTIONS(5802),
    [anon_sym_LBRACK] = ACTIONS(5804),
    [anon_sym_localparam] = ACTIONS(5802),
    [anon_sym_parameter] = ACTIONS(5802),
    [anon_sym_var] = ACTIONS(5802),
    [anon_sym_import] = ACTIONS(5802),
    [anon_sym_export] = ACTIONS(5802),
    [anon_sym_genvar] = ACTIONS(5802),
    [anon_sym_interconnect] = ACTIONS(5802),
    [anon_sym_typedef] = ACTIONS(5802),
    [anon_sym_enum] = ACTIONS(5802),
    [anon_sym_struct] = ACTIONS(5802),
    [anon_sym_union] = ACTIONS(5802),
    [anon_sym_nettype] = ACTIONS(5802),
    [anon_sym_automatic] = ACTIONS(5802),
    [anon_sym_string] = ACTIONS(5802),
    [anon_sym_chandle] = ACTIONS(5802),
    [anon_sym_event] = ACTIONS(5802),
    [anon_sym_byte] = ACTIONS(5802),
    [anon_sym_shortint] = ACTIONS(5802),
    [anon_sym_int] = ACTIONS(5802),
    [anon_sym_longint] = ACTIONS(5802),
    [anon_sym_integer] = ACTIONS(5802),
    [anon_sym_time] = ACTIONS(5802),
    [anon_sym_bit] = ACTIONS(5802),
    [anon_sym_logic] = ACTIONS(5802),
    [anon_sym_reg] = ACTIONS(5802),
    [anon_sym_shortreal] = ACTIONS(5802),
    [anon_sym_real] = ACTIONS(5802),
    [anon_sym_realtime] = ACTIONS(5802),
    [anon_sym_supply0] = ACTIONS(5802),
    [anon_sym_supply1] = ACTIONS(5802),
    [anon_sym_signed] = ACTIONS(5802),
    [anon_sym_unsigned] = ACTIONS(5802),
    [anon_sym_task] = ACTIONS(5802),
    [anon_sym_assert] = ACTIONS(5802),
    [anon_sym_property] = ACTIONS(5802),
    [anon_sym_assume] = ACTIONS(5802),
    [anon_sym_cover] = ACTIONS(5802),
    [anon_sym_sequence] = ACTIONS(5802),
    [anon_sym_restrict] = ACTIONS(5802),
    [anon_sym_not] = ACTIONS(5802),
    [anon_sym_or] = ACTIONS(5802),
    [anon_sym_and] = ACTIONS(5802),
    [anon_sym_case] = ACTIONS(5802),
    [anon_sym_always] = ACTIONS(5802),
    [anon_sym_covergroup] = ACTIONS(5802),
    [anon_sym_let] = ACTIONS(5802),
    [anon_sym_pulldown] = ACTIONS(5802),
    [anon_sym_pullup] = ACTIONS(5802),
    [anon_sym_cmos] = ACTIONS(5802),
    [anon_sym_rcmos] = ACTIONS(5802),
    [anon_sym_bufif0] = ACTIONS(5802),
    [anon_sym_bufif1] = ACTIONS(5802),
    [anon_sym_notif0] = ACTIONS(5802),
    [anon_sym_notif1] = ACTIONS(5802),
    [anon_sym_nmos] = ACTIONS(5802),
    [anon_sym_pmos] = ACTIONS(5802),
    [anon_sym_rnmos] = ACTIONS(5802),
    [anon_sym_rpmos] = ACTIONS(5802),
    [anon_sym_nand] = ACTIONS(5802),
    [anon_sym_nor] = ACTIONS(5802),
    [anon_sym_xor] = ACTIONS(5802),
    [anon_sym_xnor] = ACTIONS(5802),
    [anon_sym_buf] = ACTIONS(5802),
    [anon_sym_tranif0] = ACTIONS(5802),
    [anon_sym_tranif1] = ACTIONS(5802),
    [anon_sym_rtranif1] = ACTIONS(5802),
    [anon_sym_rtranif0] = ACTIONS(5802),
    [anon_sym_tran] = ACTIONS(5802),
    [anon_sym_rtran] = ACTIONS(5802),
    [anon_sym_generate] = ACTIONS(5802),
    [anon_sym_endgenerate] = ACTIONS(5802),
    [anon_sym_for] = ACTIONS(5802),
    [anon_sym_initial] = ACTIONS(5802),
    [anon_sym_assign] = ACTIONS(5802),
    [anon_sym_alias] = ACTIONS(5802),
    [anon_sym_always_comb] = ACTIONS(5802),
    [anon_sym_always_latch] = ACTIONS(5802),
    [anon_sym_always_ff] = ACTIONS(5802),
    [anon_sym_final] = ACTIONS(5802),
    [anon_sym_global] = ACTIONS(5802),
    [anon_sym_LPAREN_STAR] = ACTIONS(5804),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5804),
    [anon_sym_DOLLARunit] = ACTIONS(5804),
  },
  [4900] = {
    [sym_simple_identifier] = ACTIONS(5302),
    [anon_sym_wire] = ACTIONS(5302),
    [anon_sym_tri] = ACTIONS(5302),
    [anon_sym_tri0] = ACTIONS(5302),
    [anon_sym_tri1] = ACTIONS(5302),
    [anon_sym_wand] = ACTIONS(5302),
    [anon_sym_triand] = ACTIONS(5302),
    [anon_sym_wor] = ACTIONS(5302),
    [anon_sym_trior] = ACTIONS(5302),
    [anon_sym_trireg] = ACTIONS(5302),
    [anon_sym_uwire] = ACTIONS(5302),
    [anon_sym_SEMI] = ACTIONS(5300),
    [anon_sym_extern] = ACTIONS(5302),
    [anon_sym_interface] = ACTIONS(5302),
    [anon_sym_checker] = ACTIONS(5302),
    [anon_sym_virtual] = ACTIONS(5302),
    [anon_sym_class] = ACTIONS(5302),
    [anon_sym_type] = ACTIONS(5302),
    [anon_sym_DOLLARfatal] = ACTIONS(5300),
    [anon_sym_DOLLARerror] = ACTIONS(5300),
    [anon_sym_DOLLARwarning] = ACTIONS(5300),
    [anon_sym_DOLLARinfo] = ACTIONS(5300),
    [anon_sym_default] = ACTIONS(5302),
    [anon_sym_clocking] = ACTIONS(5302),
    [anon_sym_defparam] = ACTIONS(5302),
    [anon_sym_bind] = ACTIONS(5302),
    [anon_sym_rand] = ACTIONS(5302),
    [anon_sym_const] = ACTIONS(5302),
    [anon_sym_function] = ACTIONS(5302),
    [anon_sym_static] = ACTIONS(5302),
    [anon_sym_constraint] = ACTIONS(5302),
    [anon_sym_if] = ACTIONS(5302),
    [anon_sym_else] = ACTIONS(5302),
    [anon_sym_LBRACK] = ACTIONS(5300),
    [anon_sym_localparam] = ACTIONS(5302),
    [anon_sym_parameter] = ACTIONS(5302),
    [anon_sym_var] = ACTIONS(5302),
    [anon_sym_import] = ACTIONS(5302),
    [anon_sym_export] = ACTIONS(5302),
    [anon_sym_genvar] = ACTIONS(5302),
    [anon_sym_interconnect] = ACTIONS(5302),
    [anon_sym_typedef] = ACTIONS(5302),
    [anon_sym_enum] = ACTIONS(5302),
    [anon_sym_struct] = ACTIONS(5302),
    [anon_sym_union] = ACTIONS(5302),
    [anon_sym_nettype] = ACTIONS(5302),
    [anon_sym_automatic] = ACTIONS(5302),
    [anon_sym_string] = ACTIONS(5302),
    [anon_sym_chandle] = ACTIONS(5302),
    [anon_sym_event] = ACTIONS(5302),
    [anon_sym_byte] = ACTIONS(5302),
    [anon_sym_shortint] = ACTIONS(5302),
    [anon_sym_int] = ACTIONS(5302),
    [anon_sym_longint] = ACTIONS(5302),
    [anon_sym_integer] = ACTIONS(5302),
    [anon_sym_time] = ACTIONS(5302),
    [anon_sym_bit] = ACTIONS(5302),
    [anon_sym_logic] = ACTIONS(5302),
    [anon_sym_reg] = ACTIONS(5302),
    [anon_sym_shortreal] = ACTIONS(5302),
    [anon_sym_real] = ACTIONS(5302),
    [anon_sym_realtime] = ACTIONS(5302),
    [anon_sym_supply0] = ACTIONS(5302),
    [anon_sym_supply1] = ACTIONS(5302),
    [anon_sym_signed] = ACTIONS(5302),
    [anon_sym_unsigned] = ACTIONS(5302),
    [anon_sym_task] = ACTIONS(5302),
    [anon_sym_assert] = ACTIONS(5302),
    [anon_sym_property] = ACTIONS(5302),
    [anon_sym_assume] = ACTIONS(5302),
    [anon_sym_cover] = ACTIONS(5302),
    [anon_sym_sequence] = ACTIONS(5302),
    [anon_sym_restrict] = ACTIONS(5302),
    [anon_sym_not] = ACTIONS(5302),
    [anon_sym_or] = ACTIONS(5302),
    [anon_sym_and] = ACTIONS(5302),
    [anon_sym_case] = ACTIONS(5302),
    [anon_sym_always] = ACTIONS(5302),
    [anon_sym_covergroup] = ACTIONS(5302),
    [anon_sym_end] = ACTIONS(5302),
    [anon_sym_let] = ACTIONS(5302),
    [anon_sym_pulldown] = ACTIONS(5302),
    [anon_sym_pullup] = ACTIONS(5302),
    [anon_sym_cmos] = ACTIONS(5302),
    [anon_sym_rcmos] = ACTIONS(5302),
    [anon_sym_bufif0] = ACTIONS(5302),
    [anon_sym_bufif1] = ACTIONS(5302),
    [anon_sym_notif0] = ACTIONS(5302),
    [anon_sym_notif1] = ACTIONS(5302),
    [anon_sym_nmos] = ACTIONS(5302),
    [anon_sym_pmos] = ACTIONS(5302),
    [anon_sym_rnmos] = ACTIONS(5302),
    [anon_sym_rpmos] = ACTIONS(5302),
    [anon_sym_nand] = ACTIONS(5302),
    [anon_sym_nor] = ACTIONS(5302),
    [anon_sym_xor] = ACTIONS(5302),
    [anon_sym_xnor] = ACTIONS(5302),
    [anon_sym_buf] = ACTIONS(5302),
    [anon_sym_tranif0] = ACTIONS(5302),
    [anon_sym_tranif1] = ACTIONS(5302),
    [anon_sym_rtranif1] = ACTIONS(5302),
    [anon_sym_rtranif0] = ACTIONS(5302),
    [anon_sym_tran] = ACTIONS(5302),
    [anon_sym_rtran] = ACTIONS(5302),
    [anon_sym_generate] = ACTIONS(5302),
    [anon_sym_for] = ACTIONS(5302),
    [anon_sym_initial] = ACTIONS(5302),
    [anon_sym_assign] = ACTIONS(5302),
    [anon_sym_alias] = ACTIONS(5302),
    [anon_sym_always_comb] = ACTIONS(5302),
    [anon_sym_always_latch] = ACTIONS(5302),
    [anon_sym_always_ff] = ACTIONS(5302),
    [anon_sym_final] = ACTIONS(5302),
    [anon_sym_global] = ACTIONS(5302),
    [anon_sym_LPAREN_STAR] = ACTIONS(5300),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5300),
    [anon_sym_DOLLARunit] = ACTIONS(5300),
  },
  [4901] = {
    [sym_simple_identifier] = ACTIONS(6665),
    [anon_sym_wire] = ACTIONS(6665),
    [anon_sym_tri] = ACTIONS(6665),
    [anon_sym_tri0] = ACTIONS(6665),
    [anon_sym_tri1] = ACTIONS(6665),
    [anon_sym_wand] = ACTIONS(6665),
    [anon_sym_triand] = ACTIONS(6665),
    [anon_sym_wor] = ACTIONS(6665),
    [anon_sym_trior] = ACTIONS(6665),
    [anon_sym_trireg] = ACTIONS(6665),
    [anon_sym_uwire] = ACTIONS(6665),
    [anon_sym_SEMI] = ACTIONS(6667),
    [anon_sym_extern] = ACTIONS(6665),
    [anon_sym_interface] = ACTIONS(6665),
    [anon_sym_checker] = ACTIONS(6665),
    [anon_sym_virtual] = ACTIONS(6665),
    [anon_sym_class] = ACTIONS(6665),
    [anon_sym_type] = ACTIONS(6665),
    [anon_sym_DOLLARfatal] = ACTIONS(6667),
    [anon_sym_DOLLARerror] = ACTIONS(6667),
    [anon_sym_DOLLARwarning] = ACTIONS(6667),
    [anon_sym_DOLLARinfo] = ACTIONS(6667),
    [anon_sym_default] = ACTIONS(6665),
    [anon_sym_clocking] = ACTIONS(6665),
    [anon_sym_defparam] = ACTIONS(6665),
    [anon_sym_bind] = ACTIONS(6665),
    [anon_sym_rand] = ACTIONS(6665),
    [anon_sym_const] = ACTIONS(6665),
    [anon_sym_function] = ACTIONS(6665),
    [anon_sym_static] = ACTIONS(6665),
    [anon_sym_constraint] = ACTIONS(6665),
    [anon_sym_if] = ACTIONS(6665),
    [anon_sym_else] = ACTIONS(6665),
    [anon_sym_LBRACK] = ACTIONS(6667),
    [anon_sym_localparam] = ACTIONS(6665),
    [anon_sym_parameter] = ACTIONS(6665),
    [anon_sym_var] = ACTIONS(6665),
    [anon_sym_import] = ACTIONS(6665),
    [anon_sym_export] = ACTIONS(6665),
    [anon_sym_genvar] = ACTIONS(6665),
    [anon_sym_interconnect] = ACTIONS(6665),
    [anon_sym_typedef] = ACTIONS(6665),
    [anon_sym_enum] = ACTIONS(6665),
    [anon_sym_struct] = ACTIONS(6665),
    [anon_sym_union] = ACTIONS(6665),
    [anon_sym_nettype] = ACTIONS(6665),
    [anon_sym_automatic] = ACTIONS(6665),
    [anon_sym_string] = ACTIONS(6665),
    [anon_sym_chandle] = ACTIONS(6665),
    [anon_sym_event] = ACTIONS(6665),
    [anon_sym_byte] = ACTIONS(6665),
    [anon_sym_shortint] = ACTIONS(6665),
    [anon_sym_int] = ACTIONS(6665),
    [anon_sym_longint] = ACTIONS(6665),
    [anon_sym_integer] = ACTIONS(6665),
    [anon_sym_time] = ACTIONS(6665),
    [anon_sym_bit] = ACTIONS(6665),
    [anon_sym_logic] = ACTIONS(6665),
    [anon_sym_reg] = ACTIONS(6665),
    [anon_sym_shortreal] = ACTIONS(6665),
    [anon_sym_real] = ACTIONS(6665),
    [anon_sym_realtime] = ACTIONS(6665),
    [anon_sym_supply0] = ACTIONS(6665),
    [anon_sym_supply1] = ACTIONS(6665),
    [anon_sym_signed] = ACTIONS(6665),
    [anon_sym_unsigned] = ACTIONS(6665),
    [anon_sym_task] = ACTIONS(6665),
    [anon_sym_assert] = ACTIONS(6665),
    [anon_sym_property] = ACTIONS(6665),
    [anon_sym_assume] = ACTIONS(6665),
    [anon_sym_cover] = ACTIONS(6665),
    [anon_sym_sequence] = ACTIONS(6665),
    [anon_sym_restrict] = ACTIONS(6665),
    [anon_sym_not] = ACTIONS(6665),
    [anon_sym_or] = ACTIONS(6665),
    [anon_sym_and] = ACTIONS(6665),
    [anon_sym_case] = ACTIONS(6665),
    [anon_sym_always] = ACTIONS(6665),
    [anon_sym_covergroup] = ACTIONS(6665),
    [anon_sym_let] = ACTIONS(6665),
    [anon_sym_pulldown] = ACTIONS(6665),
    [anon_sym_pullup] = ACTIONS(6665),
    [anon_sym_cmos] = ACTIONS(6665),
    [anon_sym_rcmos] = ACTIONS(6665),
    [anon_sym_bufif0] = ACTIONS(6665),
    [anon_sym_bufif1] = ACTIONS(6665),
    [anon_sym_notif0] = ACTIONS(6665),
    [anon_sym_notif1] = ACTIONS(6665),
    [anon_sym_nmos] = ACTIONS(6665),
    [anon_sym_pmos] = ACTIONS(6665),
    [anon_sym_rnmos] = ACTIONS(6665),
    [anon_sym_rpmos] = ACTIONS(6665),
    [anon_sym_nand] = ACTIONS(6665),
    [anon_sym_nor] = ACTIONS(6665),
    [anon_sym_xor] = ACTIONS(6665),
    [anon_sym_xnor] = ACTIONS(6665),
    [anon_sym_buf] = ACTIONS(6665),
    [anon_sym_tranif0] = ACTIONS(6665),
    [anon_sym_tranif1] = ACTIONS(6665),
    [anon_sym_rtranif1] = ACTIONS(6665),
    [anon_sym_rtranif0] = ACTIONS(6665),
    [anon_sym_tran] = ACTIONS(6665),
    [anon_sym_rtran] = ACTIONS(6665),
    [anon_sym_generate] = ACTIONS(6665),
    [anon_sym_endgenerate] = ACTIONS(6665),
    [anon_sym_for] = ACTIONS(6665),
    [anon_sym_initial] = ACTIONS(6665),
    [anon_sym_assign] = ACTIONS(6665),
    [anon_sym_alias] = ACTIONS(6665),
    [anon_sym_always_comb] = ACTIONS(6665),
    [anon_sym_always_latch] = ACTIONS(6665),
    [anon_sym_always_ff] = ACTIONS(6665),
    [anon_sym_final] = ACTIONS(6665),
    [anon_sym_global] = ACTIONS(6665),
    [anon_sym_LPAREN_STAR] = ACTIONS(6667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6667),
    [anon_sym_DOLLARunit] = ACTIONS(6667),
  },
  [4902] = {
    [sym_simple_identifier] = ACTIONS(5816),
    [anon_sym_wire] = ACTIONS(5816),
    [anon_sym_tri] = ACTIONS(5816),
    [anon_sym_tri0] = ACTIONS(5816),
    [anon_sym_tri1] = ACTIONS(5816),
    [anon_sym_wand] = ACTIONS(5816),
    [anon_sym_triand] = ACTIONS(5816),
    [anon_sym_wor] = ACTIONS(5816),
    [anon_sym_trior] = ACTIONS(5816),
    [anon_sym_trireg] = ACTIONS(5816),
    [anon_sym_uwire] = ACTIONS(5816),
    [anon_sym_SEMI] = ACTIONS(5818),
    [anon_sym_extern] = ACTIONS(5816),
    [anon_sym_interface] = ACTIONS(5816),
    [anon_sym_checker] = ACTIONS(5816),
    [anon_sym_virtual] = ACTIONS(5816),
    [anon_sym_class] = ACTIONS(5816),
    [anon_sym_type] = ACTIONS(5816),
    [anon_sym_DOLLARfatal] = ACTIONS(5818),
    [anon_sym_DOLLARerror] = ACTIONS(5818),
    [anon_sym_DOLLARwarning] = ACTIONS(5818),
    [anon_sym_DOLLARinfo] = ACTIONS(5818),
    [anon_sym_default] = ACTIONS(5816),
    [anon_sym_clocking] = ACTIONS(5816),
    [anon_sym_defparam] = ACTIONS(5816),
    [anon_sym_bind] = ACTIONS(5816),
    [anon_sym_rand] = ACTIONS(5816),
    [anon_sym_const] = ACTIONS(5816),
    [anon_sym_function] = ACTIONS(5816),
    [anon_sym_static] = ACTIONS(5816),
    [anon_sym_constraint] = ACTIONS(5816),
    [anon_sym_if] = ACTIONS(5816),
    [anon_sym_else] = ACTIONS(5816),
    [anon_sym_LBRACK] = ACTIONS(5818),
    [anon_sym_localparam] = ACTIONS(5816),
    [anon_sym_parameter] = ACTIONS(5816),
    [anon_sym_var] = ACTIONS(5816),
    [anon_sym_import] = ACTIONS(5816),
    [anon_sym_export] = ACTIONS(5816),
    [anon_sym_genvar] = ACTIONS(5816),
    [anon_sym_interconnect] = ACTIONS(5816),
    [anon_sym_typedef] = ACTIONS(5816),
    [anon_sym_enum] = ACTIONS(5816),
    [anon_sym_struct] = ACTIONS(5816),
    [anon_sym_union] = ACTIONS(5816),
    [anon_sym_nettype] = ACTIONS(5816),
    [anon_sym_automatic] = ACTIONS(5816),
    [anon_sym_string] = ACTIONS(5816),
    [anon_sym_chandle] = ACTIONS(5816),
    [anon_sym_event] = ACTIONS(5816),
    [anon_sym_byte] = ACTIONS(5816),
    [anon_sym_shortint] = ACTIONS(5816),
    [anon_sym_int] = ACTIONS(5816),
    [anon_sym_longint] = ACTIONS(5816),
    [anon_sym_integer] = ACTIONS(5816),
    [anon_sym_time] = ACTIONS(5816),
    [anon_sym_bit] = ACTIONS(5816),
    [anon_sym_logic] = ACTIONS(5816),
    [anon_sym_reg] = ACTIONS(5816),
    [anon_sym_shortreal] = ACTIONS(5816),
    [anon_sym_real] = ACTIONS(5816),
    [anon_sym_realtime] = ACTIONS(5816),
    [anon_sym_supply0] = ACTIONS(5816),
    [anon_sym_supply1] = ACTIONS(5816),
    [anon_sym_signed] = ACTIONS(5816),
    [anon_sym_unsigned] = ACTIONS(5816),
    [anon_sym_task] = ACTIONS(5816),
    [anon_sym_assert] = ACTIONS(5816),
    [anon_sym_property] = ACTIONS(5816),
    [anon_sym_assume] = ACTIONS(5816),
    [anon_sym_cover] = ACTIONS(5816),
    [anon_sym_sequence] = ACTIONS(5816),
    [anon_sym_restrict] = ACTIONS(5816),
    [anon_sym_not] = ACTIONS(5816),
    [anon_sym_or] = ACTIONS(5816),
    [anon_sym_and] = ACTIONS(5816),
    [anon_sym_case] = ACTIONS(5816),
    [anon_sym_always] = ACTIONS(5816),
    [anon_sym_covergroup] = ACTIONS(5816),
    [anon_sym_let] = ACTIONS(5816),
    [anon_sym_pulldown] = ACTIONS(5816),
    [anon_sym_pullup] = ACTIONS(5816),
    [anon_sym_cmos] = ACTIONS(5816),
    [anon_sym_rcmos] = ACTIONS(5816),
    [anon_sym_bufif0] = ACTIONS(5816),
    [anon_sym_bufif1] = ACTIONS(5816),
    [anon_sym_notif0] = ACTIONS(5816),
    [anon_sym_notif1] = ACTIONS(5816),
    [anon_sym_nmos] = ACTIONS(5816),
    [anon_sym_pmos] = ACTIONS(5816),
    [anon_sym_rnmos] = ACTIONS(5816),
    [anon_sym_rpmos] = ACTIONS(5816),
    [anon_sym_nand] = ACTIONS(5816),
    [anon_sym_nor] = ACTIONS(5816),
    [anon_sym_xor] = ACTIONS(5816),
    [anon_sym_xnor] = ACTIONS(5816),
    [anon_sym_buf] = ACTIONS(5816),
    [anon_sym_tranif0] = ACTIONS(5816),
    [anon_sym_tranif1] = ACTIONS(5816),
    [anon_sym_rtranif1] = ACTIONS(5816),
    [anon_sym_rtranif0] = ACTIONS(5816),
    [anon_sym_tran] = ACTIONS(5816),
    [anon_sym_rtran] = ACTIONS(5816),
    [anon_sym_generate] = ACTIONS(5816),
    [anon_sym_endgenerate] = ACTIONS(5816),
    [anon_sym_for] = ACTIONS(5816),
    [anon_sym_initial] = ACTIONS(5816),
    [anon_sym_assign] = ACTIONS(5816),
    [anon_sym_alias] = ACTIONS(5816),
    [anon_sym_always_comb] = ACTIONS(5816),
    [anon_sym_always_latch] = ACTIONS(5816),
    [anon_sym_always_ff] = ACTIONS(5816),
    [anon_sym_final] = ACTIONS(5816),
    [anon_sym_global] = ACTIONS(5816),
    [anon_sym_LPAREN_STAR] = ACTIONS(5818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5818),
    [anon_sym_DOLLARunit] = ACTIONS(5818),
  },
  [4903] = {
    [sym_simple_identifier] = ACTIONS(5820),
    [anon_sym_wire] = ACTIONS(5820),
    [anon_sym_tri] = ACTIONS(5820),
    [anon_sym_tri0] = ACTIONS(5820),
    [anon_sym_tri1] = ACTIONS(5820),
    [anon_sym_wand] = ACTIONS(5820),
    [anon_sym_triand] = ACTIONS(5820),
    [anon_sym_wor] = ACTIONS(5820),
    [anon_sym_trior] = ACTIONS(5820),
    [anon_sym_trireg] = ACTIONS(5820),
    [anon_sym_uwire] = ACTIONS(5820),
    [anon_sym_SEMI] = ACTIONS(5822),
    [anon_sym_extern] = ACTIONS(5820),
    [anon_sym_interface] = ACTIONS(5820),
    [anon_sym_checker] = ACTIONS(5820),
    [anon_sym_virtual] = ACTIONS(5820),
    [anon_sym_class] = ACTIONS(5820),
    [anon_sym_type] = ACTIONS(5820),
    [anon_sym_DOLLARfatal] = ACTIONS(5822),
    [anon_sym_DOLLARerror] = ACTIONS(5822),
    [anon_sym_DOLLARwarning] = ACTIONS(5822),
    [anon_sym_DOLLARinfo] = ACTIONS(5822),
    [anon_sym_default] = ACTIONS(5820),
    [anon_sym_clocking] = ACTIONS(5820),
    [anon_sym_defparam] = ACTIONS(5820),
    [anon_sym_bind] = ACTIONS(5820),
    [anon_sym_rand] = ACTIONS(5820),
    [anon_sym_const] = ACTIONS(5820),
    [anon_sym_function] = ACTIONS(5820),
    [anon_sym_static] = ACTIONS(5820),
    [anon_sym_constraint] = ACTIONS(5820),
    [anon_sym_if] = ACTIONS(5820),
    [anon_sym_else] = ACTIONS(5820),
    [anon_sym_LBRACK] = ACTIONS(5822),
    [anon_sym_localparam] = ACTIONS(5820),
    [anon_sym_parameter] = ACTIONS(5820),
    [anon_sym_var] = ACTIONS(5820),
    [anon_sym_import] = ACTIONS(5820),
    [anon_sym_export] = ACTIONS(5820),
    [anon_sym_genvar] = ACTIONS(5820),
    [anon_sym_interconnect] = ACTIONS(5820),
    [anon_sym_typedef] = ACTIONS(5820),
    [anon_sym_enum] = ACTIONS(5820),
    [anon_sym_struct] = ACTIONS(5820),
    [anon_sym_union] = ACTIONS(5820),
    [anon_sym_nettype] = ACTIONS(5820),
    [anon_sym_automatic] = ACTIONS(5820),
    [anon_sym_string] = ACTIONS(5820),
    [anon_sym_chandle] = ACTIONS(5820),
    [anon_sym_event] = ACTIONS(5820),
    [anon_sym_byte] = ACTIONS(5820),
    [anon_sym_shortint] = ACTIONS(5820),
    [anon_sym_int] = ACTIONS(5820),
    [anon_sym_longint] = ACTIONS(5820),
    [anon_sym_integer] = ACTIONS(5820),
    [anon_sym_time] = ACTIONS(5820),
    [anon_sym_bit] = ACTIONS(5820),
    [anon_sym_logic] = ACTIONS(5820),
    [anon_sym_reg] = ACTIONS(5820),
    [anon_sym_shortreal] = ACTIONS(5820),
    [anon_sym_real] = ACTIONS(5820),
    [anon_sym_realtime] = ACTIONS(5820),
    [anon_sym_supply0] = ACTIONS(5820),
    [anon_sym_supply1] = ACTIONS(5820),
    [anon_sym_signed] = ACTIONS(5820),
    [anon_sym_unsigned] = ACTIONS(5820),
    [anon_sym_task] = ACTIONS(5820),
    [anon_sym_assert] = ACTIONS(5820),
    [anon_sym_property] = ACTIONS(5820),
    [anon_sym_assume] = ACTIONS(5820),
    [anon_sym_cover] = ACTIONS(5820),
    [anon_sym_sequence] = ACTIONS(5820),
    [anon_sym_restrict] = ACTIONS(5820),
    [anon_sym_not] = ACTIONS(5820),
    [anon_sym_or] = ACTIONS(5820),
    [anon_sym_and] = ACTIONS(5820),
    [anon_sym_case] = ACTIONS(5820),
    [anon_sym_always] = ACTIONS(5820),
    [anon_sym_covergroup] = ACTIONS(5820),
    [anon_sym_let] = ACTIONS(5820),
    [anon_sym_pulldown] = ACTIONS(5820),
    [anon_sym_pullup] = ACTIONS(5820),
    [anon_sym_cmos] = ACTIONS(5820),
    [anon_sym_rcmos] = ACTIONS(5820),
    [anon_sym_bufif0] = ACTIONS(5820),
    [anon_sym_bufif1] = ACTIONS(5820),
    [anon_sym_notif0] = ACTIONS(5820),
    [anon_sym_notif1] = ACTIONS(5820),
    [anon_sym_nmos] = ACTIONS(5820),
    [anon_sym_pmos] = ACTIONS(5820),
    [anon_sym_rnmos] = ACTIONS(5820),
    [anon_sym_rpmos] = ACTIONS(5820),
    [anon_sym_nand] = ACTIONS(5820),
    [anon_sym_nor] = ACTIONS(5820),
    [anon_sym_xor] = ACTIONS(5820),
    [anon_sym_xnor] = ACTIONS(5820),
    [anon_sym_buf] = ACTIONS(5820),
    [anon_sym_tranif0] = ACTIONS(5820),
    [anon_sym_tranif1] = ACTIONS(5820),
    [anon_sym_rtranif1] = ACTIONS(5820),
    [anon_sym_rtranif0] = ACTIONS(5820),
    [anon_sym_tran] = ACTIONS(5820),
    [anon_sym_rtran] = ACTIONS(5820),
    [anon_sym_generate] = ACTIONS(5820),
    [anon_sym_endgenerate] = ACTIONS(5820),
    [anon_sym_for] = ACTIONS(5820),
    [anon_sym_initial] = ACTIONS(5820),
    [anon_sym_assign] = ACTIONS(5820),
    [anon_sym_alias] = ACTIONS(5820),
    [anon_sym_always_comb] = ACTIONS(5820),
    [anon_sym_always_latch] = ACTIONS(5820),
    [anon_sym_always_ff] = ACTIONS(5820),
    [anon_sym_final] = ACTIONS(5820),
    [anon_sym_global] = ACTIONS(5820),
    [anon_sym_LPAREN_STAR] = ACTIONS(5822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5822),
    [anon_sym_DOLLARunit] = ACTIONS(5822),
  },
  [4904] = {
    [sym_simple_identifier] = ACTIONS(5824),
    [anon_sym_wire] = ACTIONS(5824),
    [anon_sym_tri] = ACTIONS(5824),
    [anon_sym_tri0] = ACTIONS(5824),
    [anon_sym_tri1] = ACTIONS(5824),
    [anon_sym_wand] = ACTIONS(5824),
    [anon_sym_triand] = ACTIONS(5824),
    [anon_sym_wor] = ACTIONS(5824),
    [anon_sym_trior] = ACTIONS(5824),
    [anon_sym_trireg] = ACTIONS(5824),
    [anon_sym_uwire] = ACTIONS(5824),
    [anon_sym_SEMI] = ACTIONS(5826),
    [anon_sym_extern] = ACTIONS(5824),
    [anon_sym_interface] = ACTIONS(5824),
    [anon_sym_checker] = ACTIONS(5824),
    [anon_sym_virtual] = ACTIONS(5824),
    [anon_sym_class] = ACTIONS(5824),
    [anon_sym_type] = ACTIONS(5824),
    [anon_sym_DOLLARfatal] = ACTIONS(5826),
    [anon_sym_DOLLARerror] = ACTIONS(5826),
    [anon_sym_DOLLARwarning] = ACTIONS(5826),
    [anon_sym_DOLLARinfo] = ACTIONS(5826),
    [anon_sym_default] = ACTIONS(5824),
    [anon_sym_clocking] = ACTIONS(5824),
    [anon_sym_defparam] = ACTIONS(5824),
    [anon_sym_bind] = ACTIONS(5824),
    [anon_sym_rand] = ACTIONS(5824),
    [anon_sym_const] = ACTIONS(5824),
    [anon_sym_function] = ACTIONS(5824),
    [anon_sym_static] = ACTIONS(5824),
    [anon_sym_constraint] = ACTIONS(5824),
    [anon_sym_if] = ACTIONS(5824),
    [anon_sym_else] = ACTIONS(5824),
    [anon_sym_LBRACK] = ACTIONS(5826),
    [anon_sym_localparam] = ACTIONS(5824),
    [anon_sym_parameter] = ACTIONS(5824),
    [anon_sym_var] = ACTIONS(5824),
    [anon_sym_import] = ACTIONS(5824),
    [anon_sym_export] = ACTIONS(5824),
    [anon_sym_genvar] = ACTIONS(5824),
    [anon_sym_interconnect] = ACTIONS(5824),
    [anon_sym_typedef] = ACTIONS(5824),
    [anon_sym_enum] = ACTIONS(5824),
    [anon_sym_struct] = ACTIONS(5824),
    [anon_sym_union] = ACTIONS(5824),
    [anon_sym_nettype] = ACTIONS(5824),
    [anon_sym_automatic] = ACTIONS(5824),
    [anon_sym_string] = ACTIONS(5824),
    [anon_sym_chandle] = ACTIONS(5824),
    [anon_sym_event] = ACTIONS(5824),
    [anon_sym_byte] = ACTIONS(5824),
    [anon_sym_shortint] = ACTIONS(5824),
    [anon_sym_int] = ACTIONS(5824),
    [anon_sym_longint] = ACTIONS(5824),
    [anon_sym_integer] = ACTIONS(5824),
    [anon_sym_time] = ACTIONS(5824),
    [anon_sym_bit] = ACTIONS(5824),
    [anon_sym_logic] = ACTIONS(5824),
    [anon_sym_reg] = ACTIONS(5824),
    [anon_sym_shortreal] = ACTIONS(5824),
    [anon_sym_real] = ACTIONS(5824),
    [anon_sym_realtime] = ACTIONS(5824),
    [anon_sym_supply0] = ACTIONS(5824),
    [anon_sym_supply1] = ACTIONS(5824),
    [anon_sym_signed] = ACTIONS(5824),
    [anon_sym_unsigned] = ACTIONS(5824),
    [anon_sym_task] = ACTIONS(5824),
    [anon_sym_assert] = ACTIONS(5824),
    [anon_sym_property] = ACTIONS(5824),
    [anon_sym_assume] = ACTIONS(5824),
    [anon_sym_cover] = ACTIONS(5824),
    [anon_sym_sequence] = ACTIONS(5824),
    [anon_sym_restrict] = ACTIONS(5824),
    [anon_sym_not] = ACTIONS(5824),
    [anon_sym_or] = ACTIONS(5824),
    [anon_sym_and] = ACTIONS(5824),
    [anon_sym_case] = ACTIONS(5824),
    [anon_sym_always] = ACTIONS(5824),
    [anon_sym_covergroup] = ACTIONS(5824),
    [anon_sym_let] = ACTIONS(5824),
    [anon_sym_pulldown] = ACTIONS(5824),
    [anon_sym_pullup] = ACTIONS(5824),
    [anon_sym_cmos] = ACTIONS(5824),
    [anon_sym_rcmos] = ACTIONS(5824),
    [anon_sym_bufif0] = ACTIONS(5824),
    [anon_sym_bufif1] = ACTIONS(5824),
    [anon_sym_notif0] = ACTIONS(5824),
    [anon_sym_notif1] = ACTIONS(5824),
    [anon_sym_nmos] = ACTIONS(5824),
    [anon_sym_pmos] = ACTIONS(5824),
    [anon_sym_rnmos] = ACTIONS(5824),
    [anon_sym_rpmos] = ACTIONS(5824),
    [anon_sym_nand] = ACTIONS(5824),
    [anon_sym_nor] = ACTIONS(5824),
    [anon_sym_xor] = ACTIONS(5824),
    [anon_sym_xnor] = ACTIONS(5824),
    [anon_sym_buf] = ACTIONS(5824),
    [anon_sym_tranif0] = ACTIONS(5824),
    [anon_sym_tranif1] = ACTIONS(5824),
    [anon_sym_rtranif1] = ACTIONS(5824),
    [anon_sym_rtranif0] = ACTIONS(5824),
    [anon_sym_tran] = ACTIONS(5824),
    [anon_sym_rtran] = ACTIONS(5824),
    [anon_sym_generate] = ACTIONS(5824),
    [anon_sym_endgenerate] = ACTIONS(5824),
    [anon_sym_for] = ACTIONS(5824),
    [anon_sym_initial] = ACTIONS(5824),
    [anon_sym_assign] = ACTIONS(5824),
    [anon_sym_alias] = ACTIONS(5824),
    [anon_sym_always_comb] = ACTIONS(5824),
    [anon_sym_always_latch] = ACTIONS(5824),
    [anon_sym_always_ff] = ACTIONS(5824),
    [anon_sym_final] = ACTIONS(5824),
    [anon_sym_global] = ACTIONS(5824),
    [anon_sym_LPAREN_STAR] = ACTIONS(5826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5826),
    [anon_sym_DOLLARunit] = ACTIONS(5826),
  },
  [4905] = {
    [sym_simple_identifier] = ACTIONS(5828),
    [anon_sym_wire] = ACTIONS(5828),
    [anon_sym_tri] = ACTIONS(5828),
    [anon_sym_tri0] = ACTIONS(5828),
    [anon_sym_tri1] = ACTIONS(5828),
    [anon_sym_wand] = ACTIONS(5828),
    [anon_sym_triand] = ACTIONS(5828),
    [anon_sym_wor] = ACTIONS(5828),
    [anon_sym_trior] = ACTIONS(5828),
    [anon_sym_trireg] = ACTIONS(5828),
    [anon_sym_uwire] = ACTIONS(5828),
    [anon_sym_SEMI] = ACTIONS(5830),
    [anon_sym_extern] = ACTIONS(5828),
    [anon_sym_interface] = ACTIONS(5828),
    [anon_sym_checker] = ACTIONS(5828),
    [anon_sym_virtual] = ACTIONS(5828),
    [anon_sym_class] = ACTIONS(5828),
    [anon_sym_type] = ACTIONS(5828),
    [anon_sym_DOLLARfatal] = ACTIONS(5830),
    [anon_sym_DOLLARerror] = ACTIONS(5830),
    [anon_sym_DOLLARwarning] = ACTIONS(5830),
    [anon_sym_DOLLARinfo] = ACTIONS(5830),
    [anon_sym_default] = ACTIONS(5828),
    [anon_sym_clocking] = ACTIONS(5828),
    [anon_sym_defparam] = ACTIONS(5828),
    [anon_sym_bind] = ACTIONS(5828),
    [anon_sym_rand] = ACTIONS(5828),
    [anon_sym_const] = ACTIONS(5828),
    [anon_sym_function] = ACTIONS(5828),
    [anon_sym_static] = ACTIONS(5828),
    [anon_sym_constraint] = ACTIONS(5828),
    [anon_sym_if] = ACTIONS(5828),
    [anon_sym_else] = ACTIONS(5828),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_localparam] = ACTIONS(5828),
    [anon_sym_parameter] = ACTIONS(5828),
    [anon_sym_var] = ACTIONS(5828),
    [anon_sym_import] = ACTIONS(5828),
    [anon_sym_export] = ACTIONS(5828),
    [anon_sym_genvar] = ACTIONS(5828),
    [anon_sym_interconnect] = ACTIONS(5828),
    [anon_sym_typedef] = ACTIONS(5828),
    [anon_sym_enum] = ACTIONS(5828),
    [anon_sym_struct] = ACTIONS(5828),
    [anon_sym_union] = ACTIONS(5828),
    [anon_sym_nettype] = ACTIONS(5828),
    [anon_sym_automatic] = ACTIONS(5828),
    [anon_sym_string] = ACTIONS(5828),
    [anon_sym_chandle] = ACTIONS(5828),
    [anon_sym_event] = ACTIONS(5828),
    [anon_sym_byte] = ACTIONS(5828),
    [anon_sym_shortint] = ACTIONS(5828),
    [anon_sym_int] = ACTIONS(5828),
    [anon_sym_longint] = ACTIONS(5828),
    [anon_sym_integer] = ACTIONS(5828),
    [anon_sym_time] = ACTIONS(5828),
    [anon_sym_bit] = ACTIONS(5828),
    [anon_sym_logic] = ACTIONS(5828),
    [anon_sym_reg] = ACTIONS(5828),
    [anon_sym_shortreal] = ACTIONS(5828),
    [anon_sym_real] = ACTIONS(5828),
    [anon_sym_realtime] = ACTIONS(5828),
    [anon_sym_supply0] = ACTIONS(5828),
    [anon_sym_supply1] = ACTIONS(5828),
    [anon_sym_signed] = ACTIONS(5828),
    [anon_sym_unsigned] = ACTIONS(5828),
    [anon_sym_task] = ACTIONS(5828),
    [anon_sym_assert] = ACTIONS(5828),
    [anon_sym_property] = ACTIONS(5828),
    [anon_sym_assume] = ACTIONS(5828),
    [anon_sym_cover] = ACTIONS(5828),
    [anon_sym_sequence] = ACTIONS(5828),
    [anon_sym_restrict] = ACTIONS(5828),
    [anon_sym_not] = ACTIONS(5828),
    [anon_sym_or] = ACTIONS(5828),
    [anon_sym_and] = ACTIONS(5828),
    [anon_sym_case] = ACTIONS(5828),
    [anon_sym_always] = ACTIONS(5828),
    [anon_sym_covergroup] = ACTIONS(5828),
    [anon_sym_let] = ACTIONS(5828),
    [anon_sym_pulldown] = ACTIONS(5828),
    [anon_sym_pullup] = ACTIONS(5828),
    [anon_sym_cmos] = ACTIONS(5828),
    [anon_sym_rcmos] = ACTIONS(5828),
    [anon_sym_bufif0] = ACTIONS(5828),
    [anon_sym_bufif1] = ACTIONS(5828),
    [anon_sym_notif0] = ACTIONS(5828),
    [anon_sym_notif1] = ACTIONS(5828),
    [anon_sym_nmos] = ACTIONS(5828),
    [anon_sym_pmos] = ACTIONS(5828),
    [anon_sym_rnmos] = ACTIONS(5828),
    [anon_sym_rpmos] = ACTIONS(5828),
    [anon_sym_nand] = ACTIONS(5828),
    [anon_sym_nor] = ACTIONS(5828),
    [anon_sym_xor] = ACTIONS(5828),
    [anon_sym_xnor] = ACTIONS(5828),
    [anon_sym_buf] = ACTIONS(5828),
    [anon_sym_tranif0] = ACTIONS(5828),
    [anon_sym_tranif1] = ACTIONS(5828),
    [anon_sym_rtranif1] = ACTIONS(5828),
    [anon_sym_rtranif0] = ACTIONS(5828),
    [anon_sym_tran] = ACTIONS(5828),
    [anon_sym_rtran] = ACTIONS(5828),
    [anon_sym_generate] = ACTIONS(5828),
    [anon_sym_endgenerate] = ACTIONS(5828),
    [anon_sym_for] = ACTIONS(5828),
    [anon_sym_initial] = ACTIONS(5828),
    [anon_sym_assign] = ACTIONS(5828),
    [anon_sym_alias] = ACTIONS(5828),
    [anon_sym_always_comb] = ACTIONS(5828),
    [anon_sym_always_latch] = ACTIONS(5828),
    [anon_sym_always_ff] = ACTIONS(5828),
    [anon_sym_final] = ACTIONS(5828),
    [anon_sym_global] = ACTIONS(5828),
    [anon_sym_LPAREN_STAR] = ACTIONS(5830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5830),
    [anon_sym_DOLLARunit] = ACTIONS(5830),
  },
  [4906] = {
    [sym_simple_identifier] = ACTIONS(5832),
    [anon_sym_wire] = ACTIONS(5832),
    [anon_sym_tri] = ACTIONS(5832),
    [anon_sym_tri0] = ACTIONS(5832),
    [anon_sym_tri1] = ACTIONS(5832),
    [anon_sym_wand] = ACTIONS(5832),
    [anon_sym_triand] = ACTIONS(5832),
    [anon_sym_wor] = ACTIONS(5832),
    [anon_sym_trior] = ACTIONS(5832),
    [anon_sym_trireg] = ACTIONS(5832),
    [anon_sym_uwire] = ACTIONS(5832),
    [anon_sym_SEMI] = ACTIONS(5834),
    [anon_sym_extern] = ACTIONS(5832),
    [anon_sym_interface] = ACTIONS(5832),
    [anon_sym_checker] = ACTIONS(5832),
    [anon_sym_virtual] = ACTIONS(5832),
    [anon_sym_class] = ACTIONS(5832),
    [anon_sym_type] = ACTIONS(5832),
    [anon_sym_DOLLARfatal] = ACTIONS(5834),
    [anon_sym_DOLLARerror] = ACTIONS(5834),
    [anon_sym_DOLLARwarning] = ACTIONS(5834),
    [anon_sym_DOLLARinfo] = ACTIONS(5834),
    [anon_sym_default] = ACTIONS(5832),
    [anon_sym_clocking] = ACTIONS(5832),
    [anon_sym_defparam] = ACTIONS(5832),
    [anon_sym_bind] = ACTIONS(5832),
    [anon_sym_rand] = ACTIONS(5832),
    [anon_sym_const] = ACTIONS(5832),
    [anon_sym_function] = ACTIONS(5832),
    [anon_sym_static] = ACTIONS(5832),
    [anon_sym_constraint] = ACTIONS(5832),
    [anon_sym_if] = ACTIONS(5832),
    [anon_sym_else] = ACTIONS(5832),
    [anon_sym_LBRACK] = ACTIONS(5834),
    [anon_sym_localparam] = ACTIONS(5832),
    [anon_sym_parameter] = ACTIONS(5832),
    [anon_sym_var] = ACTIONS(5832),
    [anon_sym_import] = ACTIONS(5832),
    [anon_sym_export] = ACTIONS(5832),
    [anon_sym_genvar] = ACTIONS(5832),
    [anon_sym_interconnect] = ACTIONS(5832),
    [anon_sym_typedef] = ACTIONS(5832),
    [anon_sym_enum] = ACTIONS(5832),
    [anon_sym_struct] = ACTIONS(5832),
    [anon_sym_union] = ACTIONS(5832),
    [anon_sym_nettype] = ACTIONS(5832),
    [anon_sym_automatic] = ACTIONS(5832),
    [anon_sym_string] = ACTIONS(5832),
    [anon_sym_chandle] = ACTIONS(5832),
    [anon_sym_event] = ACTIONS(5832),
    [anon_sym_byte] = ACTIONS(5832),
    [anon_sym_shortint] = ACTIONS(5832),
    [anon_sym_int] = ACTIONS(5832),
    [anon_sym_longint] = ACTIONS(5832),
    [anon_sym_integer] = ACTIONS(5832),
    [anon_sym_time] = ACTIONS(5832),
    [anon_sym_bit] = ACTIONS(5832),
    [anon_sym_logic] = ACTIONS(5832),
    [anon_sym_reg] = ACTIONS(5832),
    [anon_sym_shortreal] = ACTIONS(5832),
    [anon_sym_real] = ACTIONS(5832),
    [anon_sym_realtime] = ACTIONS(5832),
    [anon_sym_supply0] = ACTIONS(5832),
    [anon_sym_supply1] = ACTIONS(5832),
    [anon_sym_signed] = ACTIONS(5832),
    [anon_sym_unsigned] = ACTIONS(5832),
    [anon_sym_task] = ACTIONS(5832),
    [anon_sym_assert] = ACTIONS(5832),
    [anon_sym_property] = ACTIONS(5832),
    [anon_sym_assume] = ACTIONS(5832),
    [anon_sym_cover] = ACTIONS(5832),
    [anon_sym_sequence] = ACTIONS(5832),
    [anon_sym_restrict] = ACTIONS(5832),
    [anon_sym_not] = ACTIONS(5832),
    [anon_sym_or] = ACTIONS(5832),
    [anon_sym_and] = ACTIONS(5832),
    [anon_sym_case] = ACTIONS(5832),
    [anon_sym_always] = ACTIONS(5832),
    [anon_sym_covergroup] = ACTIONS(5832),
    [anon_sym_let] = ACTIONS(5832),
    [anon_sym_pulldown] = ACTIONS(5832),
    [anon_sym_pullup] = ACTIONS(5832),
    [anon_sym_cmos] = ACTIONS(5832),
    [anon_sym_rcmos] = ACTIONS(5832),
    [anon_sym_bufif0] = ACTIONS(5832),
    [anon_sym_bufif1] = ACTIONS(5832),
    [anon_sym_notif0] = ACTIONS(5832),
    [anon_sym_notif1] = ACTIONS(5832),
    [anon_sym_nmos] = ACTIONS(5832),
    [anon_sym_pmos] = ACTIONS(5832),
    [anon_sym_rnmos] = ACTIONS(5832),
    [anon_sym_rpmos] = ACTIONS(5832),
    [anon_sym_nand] = ACTIONS(5832),
    [anon_sym_nor] = ACTIONS(5832),
    [anon_sym_xor] = ACTIONS(5832),
    [anon_sym_xnor] = ACTIONS(5832),
    [anon_sym_buf] = ACTIONS(5832),
    [anon_sym_tranif0] = ACTIONS(5832),
    [anon_sym_tranif1] = ACTIONS(5832),
    [anon_sym_rtranif1] = ACTIONS(5832),
    [anon_sym_rtranif0] = ACTIONS(5832),
    [anon_sym_tran] = ACTIONS(5832),
    [anon_sym_rtran] = ACTIONS(5832),
    [anon_sym_generate] = ACTIONS(5832),
    [anon_sym_endgenerate] = ACTIONS(5832),
    [anon_sym_for] = ACTIONS(5832),
    [anon_sym_initial] = ACTIONS(5832),
    [anon_sym_assign] = ACTIONS(5832),
    [anon_sym_alias] = ACTIONS(5832),
    [anon_sym_always_comb] = ACTIONS(5832),
    [anon_sym_always_latch] = ACTIONS(5832),
    [anon_sym_always_ff] = ACTIONS(5832),
    [anon_sym_final] = ACTIONS(5832),
    [anon_sym_global] = ACTIONS(5832),
    [anon_sym_LPAREN_STAR] = ACTIONS(5834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5834),
    [anon_sym_DOLLARunit] = ACTIONS(5834),
  },
  [4907] = {
    [sym_simple_identifier] = ACTIONS(4642),
    [anon_sym_wire] = ACTIONS(4642),
    [anon_sym_tri] = ACTIONS(4642),
    [anon_sym_tri0] = ACTIONS(4642),
    [anon_sym_tri1] = ACTIONS(4642),
    [anon_sym_wand] = ACTIONS(4642),
    [anon_sym_triand] = ACTIONS(4642),
    [anon_sym_wor] = ACTIONS(4642),
    [anon_sym_trior] = ACTIONS(4642),
    [anon_sym_trireg] = ACTIONS(4642),
    [anon_sym_uwire] = ACTIONS(4642),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_extern] = ACTIONS(4642),
    [anon_sym_interface] = ACTIONS(4642),
    [anon_sym_checker] = ACTIONS(4642),
    [anon_sym_virtual] = ACTIONS(4642),
    [anon_sym_class] = ACTIONS(4642),
    [anon_sym_type] = ACTIONS(4642),
    [anon_sym_DOLLARfatal] = ACTIONS(4640),
    [anon_sym_DOLLARerror] = ACTIONS(4640),
    [anon_sym_DOLLARwarning] = ACTIONS(4640),
    [anon_sym_DOLLARinfo] = ACTIONS(4640),
    [anon_sym_default] = ACTIONS(4642),
    [anon_sym_clocking] = ACTIONS(4642),
    [anon_sym_defparam] = ACTIONS(4642),
    [anon_sym_bind] = ACTIONS(4642),
    [anon_sym_rand] = ACTIONS(4642),
    [anon_sym_const] = ACTIONS(4642),
    [anon_sym_function] = ACTIONS(4642),
    [anon_sym_static] = ACTIONS(4642),
    [anon_sym_constraint] = ACTIONS(4642),
    [anon_sym_if] = ACTIONS(4642),
    [anon_sym_else] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_localparam] = ACTIONS(4642),
    [anon_sym_parameter] = ACTIONS(4642),
    [anon_sym_var] = ACTIONS(4642),
    [anon_sym_import] = ACTIONS(4642),
    [anon_sym_export] = ACTIONS(4642),
    [anon_sym_genvar] = ACTIONS(4642),
    [anon_sym_interconnect] = ACTIONS(4642),
    [anon_sym_typedef] = ACTIONS(4642),
    [anon_sym_enum] = ACTIONS(4642),
    [anon_sym_struct] = ACTIONS(4642),
    [anon_sym_union] = ACTIONS(4642),
    [anon_sym_nettype] = ACTIONS(4642),
    [anon_sym_automatic] = ACTIONS(4642),
    [anon_sym_string] = ACTIONS(4642),
    [anon_sym_chandle] = ACTIONS(4642),
    [anon_sym_event] = ACTIONS(4642),
    [anon_sym_byte] = ACTIONS(4642),
    [anon_sym_shortint] = ACTIONS(4642),
    [anon_sym_int] = ACTIONS(4642),
    [anon_sym_longint] = ACTIONS(4642),
    [anon_sym_integer] = ACTIONS(4642),
    [anon_sym_time] = ACTIONS(4642),
    [anon_sym_bit] = ACTIONS(4642),
    [anon_sym_logic] = ACTIONS(4642),
    [anon_sym_reg] = ACTIONS(4642),
    [anon_sym_shortreal] = ACTIONS(4642),
    [anon_sym_real] = ACTIONS(4642),
    [anon_sym_realtime] = ACTIONS(4642),
    [anon_sym_supply0] = ACTIONS(4642),
    [anon_sym_supply1] = ACTIONS(4642),
    [anon_sym_signed] = ACTIONS(4642),
    [anon_sym_unsigned] = ACTIONS(4642),
    [anon_sym_task] = ACTIONS(4642),
    [anon_sym_assert] = ACTIONS(4642),
    [anon_sym_property] = ACTIONS(4642),
    [anon_sym_assume] = ACTIONS(4642),
    [anon_sym_cover] = ACTIONS(4642),
    [anon_sym_sequence] = ACTIONS(4642),
    [anon_sym_restrict] = ACTIONS(4642),
    [anon_sym_not] = ACTIONS(4642),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_and] = ACTIONS(4642),
    [anon_sym_case] = ACTIONS(4642),
    [anon_sym_always] = ACTIONS(4642),
    [anon_sym_covergroup] = ACTIONS(4642),
    [anon_sym_end] = ACTIONS(4642),
    [anon_sym_let] = ACTIONS(4642),
    [anon_sym_pulldown] = ACTIONS(4642),
    [anon_sym_pullup] = ACTIONS(4642),
    [anon_sym_cmos] = ACTIONS(4642),
    [anon_sym_rcmos] = ACTIONS(4642),
    [anon_sym_bufif0] = ACTIONS(4642),
    [anon_sym_bufif1] = ACTIONS(4642),
    [anon_sym_notif0] = ACTIONS(4642),
    [anon_sym_notif1] = ACTIONS(4642),
    [anon_sym_nmos] = ACTIONS(4642),
    [anon_sym_pmos] = ACTIONS(4642),
    [anon_sym_rnmos] = ACTIONS(4642),
    [anon_sym_rpmos] = ACTIONS(4642),
    [anon_sym_nand] = ACTIONS(4642),
    [anon_sym_nor] = ACTIONS(4642),
    [anon_sym_xor] = ACTIONS(4642),
    [anon_sym_xnor] = ACTIONS(4642),
    [anon_sym_buf] = ACTIONS(4642),
    [anon_sym_tranif0] = ACTIONS(4642),
    [anon_sym_tranif1] = ACTIONS(4642),
    [anon_sym_rtranif1] = ACTIONS(4642),
    [anon_sym_rtranif0] = ACTIONS(4642),
    [anon_sym_tran] = ACTIONS(4642),
    [anon_sym_rtran] = ACTIONS(4642),
    [anon_sym_generate] = ACTIONS(4642),
    [anon_sym_for] = ACTIONS(4642),
    [anon_sym_initial] = ACTIONS(4642),
    [anon_sym_assign] = ACTIONS(4642),
    [anon_sym_alias] = ACTIONS(4642),
    [anon_sym_always_comb] = ACTIONS(4642),
    [anon_sym_always_latch] = ACTIONS(4642),
    [anon_sym_always_ff] = ACTIONS(4642),
    [anon_sym_final] = ACTIONS(4642),
    [anon_sym_global] = ACTIONS(4642),
    [anon_sym_LPAREN_STAR] = ACTIONS(4640),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4640),
    [anon_sym_DOLLARunit] = ACTIONS(4640),
  },
  [4908] = {
    [sym_simple_identifier] = ACTIONS(6777),
    [anon_sym_wire] = ACTIONS(6777),
    [anon_sym_tri] = ACTIONS(6777),
    [anon_sym_tri0] = ACTIONS(6777),
    [anon_sym_tri1] = ACTIONS(6777),
    [anon_sym_wand] = ACTIONS(6777),
    [anon_sym_triand] = ACTIONS(6777),
    [anon_sym_wor] = ACTIONS(6777),
    [anon_sym_trior] = ACTIONS(6777),
    [anon_sym_trireg] = ACTIONS(6777),
    [anon_sym_uwire] = ACTIONS(6777),
    [anon_sym_SEMI] = ACTIONS(6780),
    [anon_sym_extern] = ACTIONS(6777),
    [anon_sym_interface] = ACTIONS(6777),
    [anon_sym_checker] = ACTIONS(6777),
    [anon_sym_virtual] = ACTIONS(6777),
    [anon_sym_class] = ACTIONS(6777),
    [anon_sym_type] = ACTIONS(6777),
    [anon_sym_DOLLARfatal] = ACTIONS(6780),
    [anon_sym_DOLLARerror] = ACTIONS(6780),
    [anon_sym_DOLLARwarning] = ACTIONS(6780),
    [anon_sym_DOLLARinfo] = ACTIONS(6780),
    [anon_sym_default] = ACTIONS(6777),
    [anon_sym_clocking] = ACTIONS(6777),
    [anon_sym_defparam] = ACTIONS(6777),
    [anon_sym_bind] = ACTIONS(6777),
    [anon_sym_rand] = ACTIONS(6777),
    [anon_sym_const] = ACTIONS(6777),
    [anon_sym_function] = ACTIONS(6777),
    [anon_sym_static] = ACTIONS(6777),
    [anon_sym_constraint] = ACTIONS(6777),
    [anon_sym_if] = ACTIONS(6777),
    [anon_sym_else] = ACTIONS(6777),
    [anon_sym_LBRACK] = ACTIONS(6780),
    [anon_sym_localparam] = ACTIONS(6777),
    [anon_sym_parameter] = ACTIONS(6777),
    [anon_sym_var] = ACTIONS(6777),
    [anon_sym_import] = ACTIONS(6777),
    [anon_sym_export] = ACTIONS(6777),
    [anon_sym_genvar] = ACTIONS(6777),
    [anon_sym_interconnect] = ACTIONS(6777),
    [anon_sym_typedef] = ACTIONS(6777),
    [anon_sym_enum] = ACTIONS(6777),
    [anon_sym_struct] = ACTIONS(6777),
    [anon_sym_union] = ACTIONS(6777),
    [anon_sym_nettype] = ACTIONS(6777),
    [anon_sym_automatic] = ACTIONS(6777),
    [anon_sym_string] = ACTIONS(6777),
    [anon_sym_chandle] = ACTIONS(6777),
    [anon_sym_event] = ACTIONS(6777),
    [anon_sym_byte] = ACTIONS(6777),
    [anon_sym_shortint] = ACTIONS(6777),
    [anon_sym_int] = ACTIONS(6777),
    [anon_sym_longint] = ACTIONS(6777),
    [anon_sym_integer] = ACTIONS(6777),
    [anon_sym_time] = ACTIONS(6777),
    [anon_sym_bit] = ACTIONS(6777),
    [anon_sym_logic] = ACTIONS(6777),
    [anon_sym_reg] = ACTIONS(6777),
    [anon_sym_shortreal] = ACTIONS(6777),
    [anon_sym_real] = ACTIONS(6777),
    [anon_sym_realtime] = ACTIONS(6777),
    [anon_sym_supply0] = ACTIONS(6777),
    [anon_sym_supply1] = ACTIONS(6777),
    [anon_sym_signed] = ACTIONS(6777),
    [anon_sym_unsigned] = ACTIONS(6777),
    [anon_sym_task] = ACTIONS(6777),
    [anon_sym_assert] = ACTIONS(6777),
    [anon_sym_property] = ACTIONS(6777),
    [anon_sym_assume] = ACTIONS(6777),
    [anon_sym_cover] = ACTIONS(6777),
    [anon_sym_sequence] = ACTIONS(6777),
    [anon_sym_restrict] = ACTIONS(6777),
    [anon_sym_not] = ACTIONS(6777),
    [anon_sym_or] = ACTIONS(6777),
    [anon_sym_and] = ACTIONS(6777),
    [anon_sym_case] = ACTIONS(6777),
    [anon_sym_always] = ACTIONS(6777),
    [anon_sym_covergroup] = ACTIONS(6777),
    [anon_sym_let] = ACTIONS(6777),
    [anon_sym_pulldown] = ACTIONS(6777),
    [anon_sym_pullup] = ACTIONS(6777),
    [anon_sym_cmos] = ACTIONS(6777),
    [anon_sym_rcmos] = ACTIONS(6777),
    [anon_sym_bufif0] = ACTIONS(6777),
    [anon_sym_bufif1] = ACTIONS(6777),
    [anon_sym_notif0] = ACTIONS(6777),
    [anon_sym_notif1] = ACTIONS(6777),
    [anon_sym_nmos] = ACTIONS(6777),
    [anon_sym_pmos] = ACTIONS(6777),
    [anon_sym_rnmos] = ACTIONS(6777),
    [anon_sym_rpmos] = ACTIONS(6777),
    [anon_sym_nand] = ACTIONS(6777),
    [anon_sym_nor] = ACTIONS(6777),
    [anon_sym_xor] = ACTIONS(6777),
    [anon_sym_xnor] = ACTIONS(6777),
    [anon_sym_buf] = ACTIONS(6777),
    [anon_sym_tranif0] = ACTIONS(6777),
    [anon_sym_tranif1] = ACTIONS(6777),
    [anon_sym_rtranif1] = ACTIONS(6777),
    [anon_sym_rtranif0] = ACTIONS(6777),
    [anon_sym_tran] = ACTIONS(6777),
    [anon_sym_rtran] = ACTIONS(6777),
    [anon_sym_generate] = ACTIONS(6777),
    [anon_sym_endgenerate] = ACTIONS(6777),
    [anon_sym_for] = ACTIONS(6777),
    [anon_sym_initial] = ACTIONS(6777),
    [anon_sym_assign] = ACTIONS(6777),
    [anon_sym_alias] = ACTIONS(6777),
    [anon_sym_always_comb] = ACTIONS(6777),
    [anon_sym_always_latch] = ACTIONS(6777),
    [anon_sym_always_ff] = ACTIONS(6777),
    [anon_sym_final] = ACTIONS(6777),
    [anon_sym_global] = ACTIONS(6777),
    [anon_sym_LPAREN_STAR] = ACTIONS(6780),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6780),
    [anon_sym_DOLLARunit] = ACTIONS(6780),
  },
  [4909] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(5154),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4671),
    [sym_package_or_generate_item_declaration] = STATE(4671),
    [sym_anonymous_program] = STATE(4671),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4671),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4671),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11175),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4910] = {
    [sym_simple_identifier] = ACTIONS(6291),
    [anon_sym_wire] = ACTIONS(6291),
    [anon_sym_tri] = ACTIONS(6291),
    [anon_sym_tri0] = ACTIONS(6291),
    [anon_sym_tri1] = ACTIONS(6291),
    [anon_sym_wand] = ACTIONS(6291),
    [anon_sym_triand] = ACTIONS(6291),
    [anon_sym_wor] = ACTIONS(6291),
    [anon_sym_trior] = ACTIONS(6291),
    [anon_sym_trireg] = ACTIONS(6291),
    [anon_sym_uwire] = ACTIONS(6291),
    [anon_sym_SEMI] = ACTIONS(6293),
    [anon_sym_extern] = ACTIONS(6291),
    [anon_sym_interface] = ACTIONS(6291),
    [anon_sym_checker] = ACTIONS(6291),
    [anon_sym_virtual] = ACTIONS(6291),
    [anon_sym_class] = ACTIONS(6291),
    [anon_sym_type] = ACTIONS(6291),
    [anon_sym_DOLLARfatal] = ACTIONS(6293),
    [anon_sym_DOLLARerror] = ACTIONS(6293),
    [anon_sym_DOLLARwarning] = ACTIONS(6293),
    [anon_sym_DOLLARinfo] = ACTIONS(6293),
    [anon_sym_default] = ACTIONS(6291),
    [anon_sym_clocking] = ACTIONS(6291),
    [anon_sym_defparam] = ACTIONS(6291),
    [anon_sym_bind] = ACTIONS(6291),
    [anon_sym_rand] = ACTIONS(6291),
    [anon_sym_const] = ACTIONS(6291),
    [anon_sym_function] = ACTIONS(6291),
    [anon_sym_static] = ACTIONS(6291),
    [anon_sym_constraint] = ACTIONS(6291),
    [anon_sym_if] = ACTIONS(6291),
    [anon_sym_else] = ACTIONS(6291),
    [anon_sym_LBRACK] = ACTIONS(6293),
    [anon_sym_localparam] = ACTIONS(6291),
    [anon_sym_parameter] = ACTIONS(6291),
    [anon_sym_var] = ACTIONS(6291),
    [anon_sym_import] = ACTIONS(6291),
    [anon_sym_export] = ACTIONS(6291),
    [anon_sym_genvar] = ACTIONS(6291),
    [anon_sym_interconnect] = ACTIONS(6291),
    [anon_sym_typedef] = ACTIONS(6291),
    [anon_sym_enum] = ACTIONS(6291),
    [anon_sym_struct] = ACTIONS(6291),
    [anon_sym_union] = ACTIONS(6291),
    [anon_sym_nettype] = ACTIONS(6291),
    [anon_sym_automatic] = ACTIONS(6291),
    [anon_sym_string] = ACTIONS(6291),
    [anon_sym_chandle] = ACTIONS(6291),
    [anon_sym_event] = ACTIONS(6291),
    [anon_sym_byte] = ACTIONS(6291),
    [anon_sym_shortint] = ACTIONS(6291),
    [anon_sym_int] = ACTIONS(6291),
    [anon_sym_longint] = ACTIONS(6291),
    [anon_sym_integer] = ACTIONS(6291),
    [anon_sym_time] = ACTIONS(6291),
    [anon_sym_bit] = ACTIONS(6291),
    [anon_sym_logic] = ACTIONS(6291),
    [anon_sym_reg] = ACTIONS(6291),
    [anon_sym_shortreal] = ACTIONS(6291),
    [anon_sym_real] = ACTIONS(6291),
    [anon_sym_realtime] = ACTIONS(6291),
    [anon_sym_supply0] = ACTIONS(6291),
    [anon_sym_supply1] = ACTIONS(6291),
    [anon_sym_signed] = ACTIONS(6291),
    [anon_sym_unsigned] = ACTIONS(6291),
    [anon_sym_task] = ACTIONS(6291),
    [anon_sym_assert] = ACTIONS(6291),
    [anon_sym_property] = ACTIONS(6291),
    [anon_sym_assume] = ACTIONS(6291),
    [anon_sym_cover] = ACTIONS(6291),
    [anon_sym_sequence] = ACTIONS(6291),
    [anon_sym_restrict] = ACTIONS(6291),
    [anon_sym_not] = ACTIONS(6291),
    [anon_sym_or] = ACTIONS(6291),
    [anon_sym_and] = ACTIONS(6291),
    [anon_sym_case] = ACTIONS(6291),
    [anon_sym_always] = ACTIONS(6291),
    [anon_sym_covergroup] = ACTIONS(6291),
    [anon_sym_end] = ACTIONS(6291),
    [anon_sym_let] = ACTIONS(6291),
    [anon_sym_pulldown] = ACTIONS(6291),
    [anon_sym_pullup] = ACTIONS(6291),
    [anon_sym_cmos] = ACTIONS(6291),
    [anon_sym_rcmos] = ACTIONS(6291),
    [anon_sym_bufif0] = ACTIONS(6291),
    [anon_sym_bufif1] = ACTIONS(6291),
    [anon_sym_notif0] = ACTIONS(6291),
    [anon_sym_notif1] = ACTIONS(6291),
    [anon_sym_nmos] = ACTIONS(6291),
    [anon_sym_pmos] = ACTIONS(6291),
    [anon_sym_rnmos] = ACTIONS(6291),
    [anon_sym_rpmos] = ACTIONS(6291),
    [anon_sym_nand] = ACTIONS(6291),
    [anon_sym_nor] = ACTIONS(6291),
    [anon_sym_xor] = ACTIONS(6291),
    [anon_sym_xnor] = ACTIONS(6291),
    [anon_sym_buf] = ACTIONS(6291),
    [anon_sym_tranif0] = ACTIONS(6291),
    [anon_sym_tranif1] = ACTIONS(6291),
    [anon_sym_rtranif1] = ACTIONS(6291),
    [anon_sym_rtranif0] = ACTIONS(6291),
    [anon_sym_tran] = ACTIONS(6291),
    [anon_sym_rtran] = ACTIONS(6291),
    [anon_sym_generate] = ACTIONS(6291),
    [anon_sym_for] = ACTIONS(6291),
    [anon_sym_initial] = ACTIONS(6291),
    [anon_sym_assign] = ACTIONS(6291),
    [anon_sym_alias] = ACTIONS(6291),
    [anon_sym_always_comb] = ACTIONS(6291),
    [anon_sym_always_latch] = ACTIONS(6291),
    [anon_sym_always_ff] = ACTIONS(6291),
    [anon_sym_final] = ACTIONS(6291),
    [anon_sym_global] = ACTIONS(6291),
    [anon_sym_LPAREN_STAR] = ACTIONS(6293),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6293),
    [anon_sym_DOLLARunit] = ACTIONS(6293),
  },
  [4911] = {
    [sym_simple_identifier] = ACTIONS(5238),
    [anon_sym_wire] = ACTIONS(5238),
    [anon_sym_tri] = ACTIONS(5238),
    [anon_sym_tri0] = ACTIONS(5238),
    [anon_sym_tri1] = ACTIONS(5238),
    [anon_sym_wand] = ACTIONS(5238),
    [anon_sym_triand] = ACTIONS(5238),
    [anon_sym_wor] = ACTIONS(5238),
    [anon_sym_trior] = ACTIONS(5238),
    [anon_sym_trireg] = ACTIONS(5238),
    [anon_sym_uwire] = ACTIONS(5238),
    [anon_sym_SEMI] = ACTIONS(5236),
    [anon_sym_extern] = ACTIONS(5238),
    [anon_sym_interface] = ACTIONS(5238),
    [anon_sym_checker] = ACTIONS(5238),
    [anon_sym_virtual] = ACTIONS(5238),
    [anon_sym_class] = ACTIONS(5238),
    [anon_sym_type] = ACTIONS(5238),
    [anon_sym_DOLLARfatal] = ACTIONS(5236),
    [anon_sym_DOLLARerror] = ACTIONS(5236),
    [anon_sym_DOLLARwarning] = ACTIONS(5236),
    [anon_sym_DOLLARinfo] = ACTIONS(5236),
    [anon_sym_default] = ACTIONS(5238),
    [anon_sym_clocking] = ACTIONS(5238),
    [anon_sym_defparam] = ACTIONS(5238),
    [anon_sym_bind] = ACTIONS(5238),
    [anon_sym_rand] = ACTIONS(5238),
    [anon_sym_const] = ACTIONS(5238),
    [anon_sym_function] = ACTIONS(5238),
    [anon_sym_static] = ACTIONS(5238),
    [anon_sym_constraint] = ACTIONS(5238),
    [anon_sym_if] = ACTIONS(5238),
    [anon_sym_else] = ACTIONS(5238),
    [anon_sym_LBRACK] = ACTIONS(5236),
    [anon_sym_localparam] = ACTIONS(5238),
    [anon_sym_parameter] = ACTIONS(5238),
    [anon_sym_var] = ACTIONS(5238),
    [anon_sym_import] = ACTIONS(5238),
    [anon_sym_export] = ACTIONS(5238),
    [anon_sym_genvar] = ACTIONS(5238),
    [anon_sym_interconnect] = ACTIONS(5238),
    [anon_sym_typedef] = ACTIONS(5238),
    [anon_sym_enum] = ACTIONS(5238),
    [anon_sym_struct] = ACTIONS(5238),
    [anon_sym_union] = ACTIONS(5238),
    [anon_sym_nettype] = ACTIONS(5238),
    [anon_sym_automatic] = ACTIONS(5238),
    [anon_sym_string] = ACTIONS(5238),
    [anon_sym_chandle] = ACTIONS(5238),
    [anon_sym_event] = ACTIONS(5238),
    [anon_sym_byte] = ACTIONS(5238),
    [anon_sym_shortint] = ACTIONS(5238),
    [anon_sym_int] = ACTIONS(5238),
    [anon_sym_longint] = ACTIONS(5238),
    [anon_sym_integer] = ACTIONS(5238),
    [anon_sym_time] = ACTIONS(5238),
    [anon_sym_bit] = ACTIONS(5238),
    [anon_sym_logic] = ACTIONS(5238),
    [anon_sym_reg] = ACTIONS(5238),
    [anon_sym_shortreal] = ACTIONS(5238),
    [anon_sym_real] = ACTIONS(5238),
    [anon_sym_realtime] = ACTIONS(5238),
    [anon_sym_supply0] = ACTIONS(5238),
    [anon_sym_supply1] = ACTIONS(5238),
    [anon_sym_signed] = ACTIONS(5238),
    [anon_sym_unsigned] = ACTIONS(5238),
    [anon_sym_task] = ACTIONS(5238),
    [anon_sym_assert] = ACTIONS(5238),
    [anon_sym_property] = ACTIONS(5238),
    [anon_sym_assume] = ACTIONS(5238),
    [anon_sym_cover] = ACTIONS(5238),
    [anon_sym_sequence] = ACTIONS(5238),
    [anon_sym_restrict] = ACTIONS(5238),
    [anon_sym_not] = ACTIONS(5238),
    [anon_sym_or] = ACTIONS(5238),
    [anon_sym_and] = ACTIONS(5238),
    [anon_sym_case] = ACTIONS(5238),
    [anon_sym_always] = ACTIONS(5238),
    [anon_sym_covergroup] = ACTIONS(5238),
    [anon_sym_end] = ACTIONS(5238),
    [anon_sym_let] = ACTIONS(5238),
    [anon_sym_pulldown] = ACTIONS(5238),
    [anon_sym_pullup] = ACTIONS(5238),
    [anon_sym_cmos] = ACTIONS(5238),
    [anon_sym_rcmos] = ACTIONS(5238),
    [anon_sym_bufif0] = ACTIONS(5238),
    [anon_sym_bufif1] = ACTIONS(5238),
    [anon_sym_notif0] = ACTIONS(5238),
    [anon_sym_notif1] = ACTIONS(5238),
    [anon_sym_nmos] = ACTIONS(5238),
    [anon_sym_pmos] = ACTIONS(5238),
    [anon_sym_rnmos] = ACTIONS(5238),
    [anon_sym_rpmos] = ACTIONS(5238),
    [anon_sym_nand] = ACTIONS(5238),
    [anon_sym_nor] = ACTIONS(5238),
    [anon_sym_xor] = ACTIONS(5238),
    [anon_sym_xnor] = ACTIONS(5238),
    [anon_sym_buf] = ACTIONS(5238),
    [anon_sym_tranif0] = ACTIONS(5238),
    [anon_sym_tranif1] = ACTIONS(5238),
    [anon_sym_rtranif1] = ACTIONS(5238),
    [anon_sym_rtranif0] = ACTIONS(5238),
    [anon_sym_tran] = ACTIONS(5238),
    [anon_sym_rtran] = ACTIONS(5238),
    [anon_sym_generate] = ACTIONS(5238),
    [anon_sym_for] = ACTIONS(5238),
    [anon_sym_initial] = ACTIONS(5238),
    [anon_sym_assign] = ACTIONS(5238),
    [anon_sym_alias] = ACTIONS(5238),
    [anon_sym_always_comb] = ACTIONS(5238),
    [anon_sym_always_latch] = ACTIONS(5238),
    [anon_sym_always_ff] = ACTIONS(5238),
    [anon_sym_final] = ACTIONS(5238),
    [anon_sym_global] = ACTIONS(5238),
    [anon_sym_LPAREN_STAR] = ACTIONS(5236),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5236),
    [anon_sym_DOLLARunit] = ACTIONS(5236),
  },
  [4912] = {
    [sym_simple_identifier] = ACTIONS(6295),
    [anon_sym_wire] = ACTIONS(6295),
    [anon_sym_tri] = ACTIONS(6295),
    [anon_sym_tri0] = ACTIONS(6295),
    [anon_sym_tri1] = ACTIONS(6295),
    [anon_sym_wand] = ACTIONS(6295),
    [anon_sym_triand] = ACTIONS(6295),
    [anon_sym_wor] = ACTIONS(6295),
    [anon_sym_trior] = ACTIONS(6295),
    [anon_sym_trireg] = ACTIONS(6295),
    [anon_sym_uwire] = ACTIONS(6295),
    [anon_sym_SEMI] = ACTIONS(6297),
    [anon_sym_extern] = ACTIONS(6295),
    [anon_sym_interface] = ACTIONS(6295),
    [anon_sym_checker] = ACTIONS(6295),
    [anon_sym_virtual] = ACTIONS(6295),
    [anon_sym_class] = ACTIONS(6295),
    [anon_sym_type] = ACTIONS(6295),
    [anon_sym_DOLLARfatal] = ACTIONS(6297),
    [anon_sym_DOLLARerror] = ACTIONS(6297),
    [anon_sym_DOLLARwarning] = ACTIONS(6297),
    [anon_sym_DOLLARinfo] = ACTIONS(6297),
    [anon_sym_default] = ACTIONS(6295),
    [anon_sym_clocking] = ACTIONS(6295),
    [anon_sym_defparam] = ACTIONS(6295),
    [anon_sym_bind] = ACTIONS(6295),
    [anon_sym_rand] = ACTIONS(6295),
    [anon_sym_const] = ACTIONS(6295),
    [anon_sym_function] = ACTIONS(6295),
    [anon_sym_static] = ACTIONS(6295),
    [anon_sym_constraint] = ACTIONS(6295),
    [anon_sym_if] = ACTIONS(6295),
    [anon_sym_else] = ACTIONS(6295),
    [anon_sym_LBRACK] = ACTIONS(6297),
    [anon_sym_localparam] = ACTIONS(6295),
    [anon_sym_parameter] = ACTIONS(6295),
    [anon_sym_var] = ACTIONS(6295),
    [anon_sym_import] = ACTIONS(6295),
    [anon_sym_export] = ACTIONS(6295),
    [anon_sym_genvar] = ACTIONS(6295),
    [anon_sym_interconnect] = ACTIONS(6295),
    [anon_sym_typedef] = ACTIONS(6295),
    [anon_sym_enum] = ACTIONS(6295),
    [anon_sym_struct] = ACTIONS(6295),
    [anon_sym_union] = ACTIONS(6295),
    [anon_sym_nettype] = ACTIONS(6295),
    [anon_sym_automatic] = ACTIONS(6295),
    [anon_sym_string] = ACTIONS(6295),
    [anon_sym_chandle] = ACTIONS(6295),
    [anon_sym_event] = ACTIONS(6295),
    [anon_sym_byte] = ACTIONS(6295),
    [anon_sym_shortint] = ACTIONS(6295),
    [anon_sym_int] = ACTIONS(6295),
    [anon_sym_longint] = ACTIONS(6295),
    [anon_sym_integer] = ACTIONS(6295),
    [anon_sym_time] = ACTIONS(6295),
    [anon_sym_bit] = ACTIONS(6295),
    [anon_sym_logic] = ACTIONS(6295),
    [anon_sym_reg] = ACTIONS(6295),
    [anon_sym_shortreal] = ACTIONS(6295),
    [anon_sym_real] = ACTIONS(6295),
    [anon_sym_realtime] = ACTIONS(6295),
    [anon_sym_supply0] = ACTIONS(6295),
    [anon_sym_supply1] = ACTIONS(6295),
    [anon_sym_signed] = ACTIONS(6295),
    [anon_sym_unsigned] = ACTIONS(6295),
    [anon_sym_task] = ACTIONS(6295),
    [anon_sym_assert] = ACTIONS(6295),
    [anon_sym_property] = ACTIONS(6295),
    [anon_sym_assume] = ACTIONS(6295),
    [anon_sym_cover] = ACTIONS(6295),
    [anon_sym_sequence] = ACTIONS(6295),
    [anon_sym_restrict] = ACTIONS(6295),
    [anon_sym_not] = ACTIONS(6295),
    [anon_sym_or] = ACTIONS(6295),
    [anon_sym_and] = ACTIONS(6295),
    [anon_sym_case] = ACTIONS(6295),
    [anon_sym_always] = ACTIONS(6295),
    [anon_sym_covergroup] = ACTIONS(6295),
    [anon_sym_end] = ACTIONS(6295),
    [anon_sym_let] = ACTIONS(6295),
    [anon_sym_pulldown] = ACTIONS(6295),
    [anon_sym_pullup] = ACTIONS(6295),
    [anon_sym_cmos] = ACTIONS(6295),
    [anon_sym_rcmos] = ACTIONS(6295),
    [anon_sym_bufif0] = ACTIONS(6295),
    [anon_sym_bufif1] = ACTIONS(6295),
    [anon_sym_notif0] = ACTIONS(6295),
    [anon_sym_notif1] = ACTIONS(6295),
    [anon_sym_nmos] = ACTIONS(6295),
    [anon_sym_pmos] = ACTIONS(6295),
    [anon_sym_rnmos] = ACTIONS(6295),
    [anon_sym_rpmos] = ACTIONS(6295),
    [anon_sym_nand] = ACTIONS(6295),
    [anon_sym_nor] = ACTIONS(6295),
    [anon_sym_xor] = ACTIONS(6295),
    [anon_sym_xnor] = ACTIONS(6295),
    [anon_sym_buf] = ACTIONS(6295),
    [anon_sym_tranif0] = ACTIONS(6295),
    [anon_sym_tranif1] = ACTIONS(6295),
    [anon_sym_rtranif1] = ACTIONS(6295),
    [anon_sym_rtranif0] = ACTIONS(6295),
    [anon_sym_tran] = ACTIONS(6295),
    [anon_sym_rtran] = ACTIONS(6295),
    [anon_sym_generate] = ACTIONS(6295),
    [anon_sym_for] = ACTIONS(6295),
    [anon_sym_initial] = ACTIONS(6295),
    [anon_sym_assign] = ACTIONS(6295),
    [anon_sym_alias] = ACTIONS(6295),
    [anon_sym_always_comb] = ACTIONS(6295),
    [anon_sym_always_latch] = ACTIONS(6295),
    [anon_sym_always_ff] = ACTIONS(6295),
    [anon_sym_final] = ACTIONS(6295),
    [anon_sym_global] = ACTIONS(6295),
    [anon_sym_LPAREN_STAR] = ACTIONS(6297),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6297),
    [anon_sym_DOLLARunit] = ACTIONS(6297),
  },
  [4913] = {
    [sym_simple_identifier] = ACTIONS(5836),
    [anon_sym_wire] = ACTIONS(5836),
    [anon_sym_tri] = ACTIONS(5836),
    [anon_sym_tri0] = ACTIONS(5836),
    [anon_sym_tri1] = ACTIONS(5836),
    [anon_sym_wand] = ACTIONS(5836),
    [anon_sym_triand] = ACTIONS(5836),
    [anon_sym_wor] = ACTIONS(5836),
    [anon_sym_trior] = ACTIONS(5836),
    [anon_sym_trireg] = ACTIONS(5836),
    [anon_sym_uwire] = ACTIONS(5836),
    [anon_sym_SEMI] = ACTIONS(5838),
    [anon_sym_extern] = ACTIONS(5836),
    [anon_sym_interface] = ACTIONS(5836),
    [anon_sym_checker] = ACTIONS(5836),
    [anon_sym_virtual] = ACTIONS(5836),
    [anon_sym_class] = ACTIONS(5836),
    [anon_sym_type] = ACTIONS(5836),
    [anon_sym_DOLLARfatal] = ACTIONS(5838),
    [anon_sym_DOLLARerror] = ACTIONS(5838),
    [anon_sym_DOLLARwarning] = ACTIONS(5838),
    [anon_sym_DOLLARinfo] = ACTIONS(5838),
    [anon_sym_default] = ACTIONS(5836),
    [anon_sym_clocking] = ACTIONS(5836),
    [anon_sym_defparam] = ACTIONS(5836),
    [anon_sym_bind] = ACTIONS(5836),
    [anon_sym_rand] = ACTIONS(5836),
    [anon_sym_const] = ACTIONS(5836),
    [anon_sym_function] = ACTIONS(5836),
    [anon_sym_static] = ACTIONS(5836),
    [anon_sym_constraint] = ACTIONS(5836),
    [anon_sym_if] = ACTIONS(5836),
    [anon_sym_else] = ACTIONS(5836),
    [anon_sym_LBRACK] = ACTIONS(5838),
    [anon_sym_localparam] = ACTIONS(5836),
    [anon_sym_parameter] = ACTIONS(5836),
    [anon_sym_var] = ACTIONS(5836),
    [anon_sym_import] = ACTIONS(5836),
    [anon_sym_export] = ACTIONS(5836),
    [anon_sym_genvar] = ACTIONS(5836),
    [anon_sym_interconnect] = ACTIONS(5836),
    [anon_sym_typedef] = ACTIONS(5836),
    [anon_sym_enum] = ACTIONS(5836),
    [anon_sym_struct] = ACTIONS(5836),
    [anon_sym_union] = ACTIONS(5836),
    [anon_sym_nettype] = ACTIONS(5836),
    [anon_sym_automatic] = ACTIONS(5836),
    [anon_sym_string] = ACTIONS(5836),
    [anon_sym_chandle] = ACTIONS(5836),
    [anon_sym_event] = ACTIONS(5836),
    [anon_sym_byte] = ACTIONS(5836),
    [anon_sym_shortint] = ACTIONS(5836),
    [anon_sym_int] = ACTIONS(5836),
    [anon_sym_longint] = ACTIONS(5836),
    [anon_sym_integer] = ACTIONS(5836),
    [anon_sym_time] = ACTIONS(5836),
    [anon_sym_bit] = ACTIONS(5836),
    [anon_sym_logic] = ACTIONS(5836),
    [anon_sym_reg] = ACTIONS(5836),
    [anon_sym_shortreal] = ACTIONS(5836),
    [anon_sym_real] = ACTIONS(5836),
    [anon_sym_realtime] = ACTIONS(5836),
    [anon_sym_supply0] = ACTIONS(5836),
    [anon_sym_supply1] = ACTIONS(5836),
    [anon_sym_signed] = ACTIONS(5836),
    [anon_sym_unsigned] = ACTIONS(5836),
    [anon_sym_task] = ACTIONS(5836),
    [anon_sym_assert] = ACTIONS(5836),
    [anon_sym_property] = ACTIONS(5836),
    [anon_sym_assume] = ACTIONS(5836),
    [anon_sym_cover] = ACTIONS(5836),
    [anon_sym_sequence] = ACTIONS(5836),
    [anon_sym_restrict] = ACTIONS(5836),
    [anon_sym_not] = ACTIONS(5836),
    [anon_sym_or] = ACTIONS(5836),
    [anon_sym_and] = ACTIONS(5836),
    [anon_sym_case] = ACTIONS(5836),
    [anon_sym_always] = ACTIONS(5836),
    [anon_sym_covergroup] = ACTIONS(5836),
    [anon_sym_let] = ACTIONS(5836),
    [anon_sym_pulldown] = ACTIONS(5836),
    [anon_sym_pullup] = ACTIONS(5836),
    [anon_sym_cmos] = ACTIONS(5836),
    [anon_sym_rcmos] = ACTIONS(5836),
    [anon_sym_bufif0] = ACTIONS(5836),
    [anon_sym_bufif1] = ACTIONS(5836),
    [anon_sym_notif0] = ACTIONS(5836),
    [anon_sym_notif1] = ACTIONS(5836),
    [anon_sym_nmos] = ACTIONS(5836),
    [anon_sym_pmos] = ACTIONS(5836),
    [anon_sym_rnmos] = ACTIONS(5836),
    [anon_sym_rpmos] = ACTIONS(5836),
    [anon_sym_nand] = ACTIONS(5836),
    [anon_sym_nor] = ACTIONS(5836),
    [anon_sym_xor] = ACTIONS(5836),
    [anon_sym_xnor] = ACTIONS(5836),
    [anon_sym_buf] = ACTIONS(5836),
    [anon_sym_tranif0] = ACTIONS(5836),
    [anon_sym_tranif1] = ACTIONS(5836),
    [anon_sym_rtranif1] = ACTIONS(5836),
    [anon_sym_rtranif0] = ACTIONS(5836),
    [anon_sym_tran] = ACTIONS(5836),
    [anon_sym_rtran] = ACTIONS(5836),
    [anon_sym_generate] = ACTIONS(5836),
    [anon_sym_endgenerate] = ACTIONS(5836),
    [anon_sym_for] = ACTIONS(5836),
    [anon_sym_initial] = ACTIONS(5836),
    [anon_sym_assign] = ACTIONS(5836),
    [anon_sym_alias] = ACTIONS(5836),
    [anon_sym_always_comb] = ACTIONS(5836),
    [anon_sym_always_latch] = ACTIONS(5836),
    [anon_sym_always_ff] = ACTIONS(5836),
    [anon_sym_final] = ACTIONS(5836),
    [anon_sym_global] = ACTIONS(5836),
    [anon_sym_LPAREN_STAR] = ACTIONS(5838),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5838),
    [anon_sym_DOLLARunit] = ACTIONS(5838),
  },
  [4914] = {
    [sym_simple_identifier] = ACTIONS(5278),
    [anon_sym_wire] = ACTIONS(5278),
    [anon_sym_tri] = ACTIONS(5278),
    [anon_sym_tri0] = ACTIONS(5278),
    [anon_sym_tri1] = ACTIONS(5278),
    [anon_sym_wand] = ACTIONS(5278),
    [anon_sym_triand] = ACTIONS(5278),
    [anon_sym_wor] = ACTIONS(5278),
    [anon_sym_trior] = ACTIONS(5278),
    [anon_sym_trireg] = ACTIONS(5278),
    [anon_sym_uwire] = ACTIONS(5278),
    [anon_sym_SEMI] = ACTIONS(5276),
    [anon_sym_extern] = ACTIONS(5278),
    [anon_sym_interface] = ACTIONS(5278),
    [anon_sym_checker] = ACTIONS(5278),
    [anon_sym_virtual] = ACTIONS(5278),
    [anon_sym_class] = ACTIONS(5278),
    [anon_sym_type] = ACTIONS(5278),
    [anon_sym_DOLLARfatal] = ACTIONS(5276),
    [anon_sym_DOLLARerror] = ACTIONS(5276),
    [anon_sym_DOLLARwarning] = ACTIONS(5276),
    [anon_sym_DOLLARinfo] = ACTIONS(5276),
    [anon_sym_default] = ACTIONS(5278),
    [anon_sym_clocking] = ACTIONS(5278),
    [anon_sym_defparam] = ACTIONS(5278),
    [anon_sym_bind] = ACTIONS(5278),
    [anon_sym_rand] = ACTIONS(5278),
    [anon_sym_const] = ACTIONS(5278),
    [anon_sym_function] = ACTIONS(5278),
    [anon_sym_static] = ACTIONS(5278),
    [anon_sym_constraint] = ACTIONS(5278),
    [anon_sym_if] = ACTIONS(5278),
    [anon_sym_else] = ACTIONS(5278),
    [anon_sym_LBRACK] = ACTIONS(5276),
    [anon_sym_localparam] = ACTIONS(5278),
    [anon_sym_parameter] = ACTIONS(5278),
    [anon_sym_var] = ACTIONS(5278),
    [anon_sym_import] = ACTIONS(5278),
    [anon_sym_export] = ACTIONS(5278),
    [anon_sym_genvar] = ACTIONS(5278),
    [anon_sym_interconnect] = ACTIONS(5278),
    [anon_sym_typedef] = ACTIONS(5278),
    [anon_sym_enum] = ACTIONS(5278),
    [anon_sym_struct] = ACTIONS(5278),
    [anon_sym_union] = ACTIONS(5278),
    [anon_sym_nettype] = ACTIONS(5278),
    [anon_sym_automatic] = ACTIONS(5278),
    [anon_sym_string] = ACTIONS(5278),
    [anon_sym_chandle] = ACTIONS(5278),
    [anon_sym_event] = ACTIONS(5278),
    [anon_sym_byte] = ACTIONS(5278),
    [anon_sym_shortint] = ACTIONS(5278),
    [anon_sym_int] = ACTIONS(5278),
    [anon_sym_longint] = ACTIONS(5278),
    [anon_sym_integer] = ACTIONS(5278),
    [anon_sym_time] = ACTIONS(5278),
    [anon_sym_bit] = ACTIONS(5278),
    [anon_sym_logic] = ACTIONS(5278),
    [anon_sym_reg] = ACTIONS(5278),
    [anon_sym_shortreal] = ACTIONS(5278),
    [anon_sym_real] = ACTIONS(5278),
    [anon_sym_realtime] = ACTIONS(5278),
    [anon_sym_supply0] = ACTIONS(5278),
    [anon_sym_supply1] = ACTIONS(5278),
    [anon_sym_signed] = ACTIONS(5278),
    [anon_sym_unsigned] = ACTIONS(5278),
    [anon_sym_task] = ACTIONS(5278),
    [anon_sym_assert] = ACTIONS(5278),
    [anon_sym_property] = ACTIONS(5278),
    [anon_sym_assume] = ACTIONS(5278),
    [anon_sym_cover] = ACTIONS(5278),
    [anon_sym_sequence] = ACTIONS(5278),
    [anon_sym_restrict] = ACTIONS(5278),
    [anon_sym_not] = ACTIONS(5278),
    [anon_sym_or] = ACTIONS(5278),
    [anon_sym_and] = ACTIONS(5278),
    [anon_sym_case] = ACTIONS(5278),
    [anon_sym_always] = ACTIONS(5278),
    [anon_sym_covergroup] = ACTIONS(5278),
    [anon_sym_end] = ACTIONS(5278),
    [anon_sym_let] = ACTIONS(5278),
    [anon_sym_pulldown] = ACTIONS(5278),
    [anon_sym_pullup] = ACTIONS(5278),
    [anon_sym_cmos] = ACTIONS(5278),
    [anon_sym_rcmos] = ACTIONS(5278),
    [anon_sym_bufif0] = ACTIONS(5278),
    [anon_sym_bufif1] = ACTIONS(5278),
    [anon_sym_notif0] = ACTIONS(5278),
    [anon_sym_notif1] = ACTIONS(5278),
    [anon_sym_nmos] = ACTIONS(5278),
    [anon_sym_pmos] = ACTIONS(5278),
    [anon_sym_rnmos] = ACTIONS(5278),
    [anon_sym_rpmos] = ACTIONS(5278),
    [anon_sym_nand] = ACTIONS(5278),
    [anon_sym_nor] = ACTIONS(5278),
    [anon_sym_xor] = ACTIONS(5278),
    [anon_sym_xnor] = ACTIONS(5278),
    [anon_sym_buf] = ACTIONS(5278),
    [anon_sym_tranif0] = ACTIONS(5278),
    [anon_sym_tranif1] = ACTIONS(5278),
    [anon_sym_rtranif1] = ACTIONS(5278),
    [anon_sym_rtranif0] = ACTIONS(5278),
    [anon_sym_tran] = ACTIONS(5278),
    [anon_sym_rtran] = ACTIONS(5278),
    [anon_sym_generate] = ACTIONS(5278),
    [anon_sym_for] = ACTIONS(5278),
    [anon_sym_initial] = ACTIONS(5278),
    [anon_sym_assign] = ACTIONS(5278),
    [anon_sym_alias] = ACTIONS(5278),
    [anon_sym_always_comb] = ACTIONS(5278),
    [anon_sym_always_latch] = ACTIONS(5278),
    [anon_sym_always_ff] = ACTIONS(5278),
    [anon_sym_final] = ACTIONS(5278),
    [anon_sym_global] = ACTIONS(5278),
    [anon_sym_LPAREN_STAR] = ACTIONS(5276),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5276),
    [anon_sym_DOLLARunit] = ACTIONS(5276),
  },
  [4915] = {
    [sym_simple_identifier] = ACTIONS(5840),
    [anon_sym_wire] = ACTIONS(5840),
    [anon_sym_tri] = ACTIONS(5840),
    [anon_sym_tri0] = ACTIONS(5840),
    [anon_sym_tri1] = ACTIONS(5840),
    [anon_sym_wand] = ACTIONS(5840),
    [anon_sym_triand] = ACTIONS(5840),
    [anon_sym_wor] = ACTIONS(5840),
    [anon_sym_trior] = ACTIONS(5840),
    [anon_sym_trireg] = ACTIONS(5840),
    [anon_sym_uwire] = ACTIONS(5840),
    [anon_sym_SEMI] = ACTIONS(5842),
    [anon_sym_extern] = ACTIONS(5840),
    [anon_sym_interface] = ACTIONS(5840),
    [anon_sym_checker] = ACTIONS(5840),
    [anon_sym_virtual] = ACTIONS(5840),
    [anon_sym_class] = ACTIONS(5840),
    [anon_sym_type] = ACTIONS(5840),
    [anon_sym_DOLLARfatal] = ACTIONS(5842),
    [anon_sym_DOLLARerror] = ACTIONS(5842),
    [anon_sym_DOLLARwarning] = ACTIONS(5842),
    [anon_sym_DOLLARinfo] = ACTIONS(5842),
    [anon_sym_default] = ACTIONS(5840),
    [anon_sym_clocking] = ACTIONS(5840),
    [anon_sym_defparam] = ACTIONS(5840),
    [anon_sym_bind] = ACTIONS(5840),
    [anon_sym_rand] = ACTIONS(5840),
    [anon_sym_const] = ACTIONS(5840),
    [anon_sym_function] = ACTIONS(5840),
    [anon_sym_static] = ACTIONS(5840),
    [anon_sym_constraint] = ACTIONS(5840),
    [anon_sym_if] = ACTIONS(5840),
    [anon_sym_else] = ACTIONS(5840),
    [anon_sym_LBRACK] = ACTIONS(5842),
    [anon_sym_localparam] = ACTIONS(5840),
    [anon_sym_parameter] = ACTIONS(5840),
    [anon_sym_var] = ACTIONS(5840),
    [anon_sym_import] = ACTIONS(5840),
    [anon_sym_export] = ACTIONS(5840),
    [anon_sym_genvar] = ACTIONS(5840),
    [anon_sym_interconnect] = ACTIONS(5840),
    [anon_sym_typedef] = ACTIONS(5840),
    [anon_sym_enum] = ACTIONS(5840),
    [anon_sym_struct] = ACTIONS(5840),
    [anon_sym_union] = ACTIONS(5840),
    [anon_sym_nettype] = ACTIONS(5840),
    [anon_sym_automatic] = ACTIONS(5840),
    [anon_sym_string] = ACTIONS(5840),
    [anon_sym_chandle] = ACTIONS(5840),
    [anon_sym_event] = ACTIONS(5840),
    [anon_sym_byte] = ACTIONS(5840),
    [anon_sym_shortint] = ACTIONS(5840),
    [anon_sym_int] = ACTIONS(5840),
    [anon_sym_longint] = ACTIONS(5840),
    [anon_sym_integer] = ACTIONS(5840),
    [anon_sym_time] = ACTIONS(5840),
    [anon_sym_bit] = ACTIONS(5840),
    [anon_sym_logic] = ACTIONS(5840),
    [anon_sym_reg] = ACTIONS(5840),
    [anon_sym_shortreal] = ACTIONS(5840),
    [anon_sym_real] = ACTIONS(5840),
    [anon_sym_realtime] = ACTIONS(5840),
    [anon_sym_supply0] = ACTIONS(5840),
    [anon_sym_supply1] = ACTIONS(5840),
    [anon_sym_signed] = ACTIONS(5840),
    [anon_sym_unsigned] = ACTIONS(5840),
    [anon_sym_task] = ACTIONS(5840),
    [anon_sym_assert] = ACTIONS(5840),
    [anon_sym_property] = ACTIONS(5840),
    [anon_sym_assume] = ACTIONS(5840),
    [anon_sym_cover] = ACTIONS(5840),
    [anon_sym_sequence] = ACTIONS(5840),
    [anon_sym_restrict] = ACTIONS(5840),
    [anon_sym_not] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5840),
    [anon_sym_and] = ACTIONS(5840),
    [anon_sym_case] = ACTIONS(5840),
    [anon_sym_always] = ACTIONS(5840),
    [anon_sym_covergroup] = ACTIONS(5840),
    [anon_sym_let] = ACTIONS(5840),
    [anon_sym_pulldown] = ACTIONS(5840),
    [anon_sym_pullup] = ACTIONS(5840),
    [anon_sym_cmos] = ACTIONS(5840),
    [anon_sym_rcmos] = ACTIONS(5840),
    [anon_sym_bufif0] = ACTIONS(5840),
    [anon_sym_bufif1] = ACTIONS(5840),
    [anon_sym_notif0] = ACTIONS(5840),
    [anon_sym_notif1] = ACTIONS(5840),
    [anon_sym_nmos] = ACTIONS(5840),
    [anon_sym_pmos] = ACTIONS(5840),
    [anon_sym_rnmos] = ACTIONS(5840),
    [anon_sym_rpmos] = ACTIONS(5840),
    [anon_sym_nand] = ACTIONS(5840),
    [anon_sym_nor] = ACTIONS(5840),
    [anon_sym_xor] = ACTIONS(5840),
    [anon_sym_xnor] = ACTIONS(5840),
    [anon_sym_buf] = ACTIONS(5840),
    [anon_sym_tranif0] = ACTIONS(5840),
    [anon_sym_tranif1] = ACTIONS(5840),
    [anon_sym_rtranif1] = ACTIONS(5840),
    [anon_sym_rtranif0] = ACTIONS(5840),
    [anon_sym_tran] = ACTIONS(5840),
    [anon_sym_rtran] = ACTIONS(5840),
    [anon_sym_generate] = ACTIONS(5840),
    [anon_sym_endgenerate] = ACTIONS(5840),
    [anon_sym_for] = ACTIONS(5840),
    [anon_sym_initial] = ACTIONS(5840),
    [anon_sym_assign] = ACTIONS(5840),
    [anon_sym_alias] = ACTIONS(5840),
    [anon_sym_always_comb] = ACTIONS(5840),
    [anon_sym_always_latch] = ACTIONS(5840),
    [anon_sym_always_ff] = ACTIONS(5840),
    [anon_sym_final] = ACTIONS(5840),
    [anon_sym_global] = ACTIONS(5840),
    [anon_sym_LPAREN_STAR] = ACTIONS(5842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5842),
    [anon_sym_DOLLARunit] = ACTIONS(5842),
  },
  [4916] = {
    [sym_simple_identifier] = ACTIONS(6601),
    [anon_sym_wire] = ACTIONS(6601),
    [anon_sym_tri] = ACTIONS(6601),
    [anon_sym_tri0] = ACTIONS(6601),
    [anon_sym_tri1] = ACTIONS(6601),
    [anon_sym_wand] = ACTIONS(6601),
    [anon_sym_triand] = ACTIONS(6601),
    [anon_sym_wor] = ACTIONS(6601),
    [anon_sym_trior] = ACTIONS(6601),
    [anon_sym_trireg] = ACTIONS(6601),
    [anon_sym_uwire] = ACTIONS(6601),
    [anon_sym_SEMI] = ACTIONS(6603),
    [anon_sym_extern] = ACTIONS(6601),
    [anon_sym_interface] = ACTIONS(6601),
    [anon_sym_checker] = ACTIONS(6601),
    [anon_sym_virtual] = ACTIONS(6601),
    [anon_sym_class] = ACTIONS(6601),
    [anon_sym_type] = ACTIONS(6601),
    [anon_sym_DOLLARfatal] = ACTIONS(6603),
    [anon_sym_DOLLARerror] = ACTIONS(6603),
    [anon_sym_DOLLARwarning] = ACTIONS(6603),
    [anon_sym_DOLLARinfo] = ACTIONS(6603),
    [anon_sym_default] = ACTIONS(6601),
    [anon_sym_clocking] = ACTIONS(6601),
    [anon_sym_defparam] = ACTIONS(6601),
    [anon_sym_bind] = ACTIONS(6601),
    [anon_sym_rand] = ACTIONS(6601),
    [anon_sym_const] = ACTIONS(6601),
    [anon_sym_function] = ACTIONS(6601),
    [anon_sym_static] = ACTIONS(6601),
    [anon_sym_constraint] = ACTIONS(6601),
    [anon_sym_if] = ACTIONS(6601),
    [anon_sym_else] = ACTIONS(6601),
    [anon_sym_LBRACK] = ACTIONS(6603),
    [anon_sym_localparam] = ACTIONS(6601),
    [anon_sym_parameter] = ACTIONS(6601),
    [anon_sym_var] = ACTIONS(6601),
    [anon_sym_import] = ACTIONS(6601),
    [anon_sym_export] = ACTIONS(6601),
    [anon_sym_genvar] = ACTIONS(6601),
    [anon_sym_interconnect] = ACTIONS(6601),
    [anon_sym_typedef] = ACTIONS(6601),
    [anon_sym_enum] = ACTIONS(6601),
    [anon_sym_struct] = ACTIONS(6601),
    [anon_sym_union] = ACTIONS(6601),
    [anon_sym_nettype] = ACTIONS(6601),
    [anon_sym_automatic] = ACTIONS(6601),
    [anon_sym_string] = ACTIONS(6601),
    [anon_sym_chandle] = ACTIONS(6601),
    [anon_sym_event] = ACTIONS(6601),
    [anon_sym_byte] = ACTIONS(6601),
    [anon_sym_shortint] = ACTIONS(6601),
    [anon_sym_int] = ACTIONS(6601),
    [anon_sym_longint] = ACTIONS(6601),
    [anon_sym_integer] = ACTIONS(6601),
    [anon_sym_time] = ACTIONS(6601),
    [anon_sym_bit] = ACTIONS(6601),
    [anon_sym_logic] = ACTIONS(6601),
    [anon_sym_reg] = ACTIONS(6601),
    [anon_sym_shortreal] = ACTIONS(6601),
    [anon_sym_real] = ACTIONS(6601),
    [anon_sym_realtime] = ACTIONS(6601),
    [anon_sym_supply0] = ACTIONS(6601),
    [anon_sym_supply1] = ACTIONS(6601),
    [anon_sym_signed] = ACTIONS(6601),
    [anon_sym_unsigned] = ACTIONS(6601),
    [anon_sym_task] = ACTIONS(6601),
    [anon_sym_assert] = ACTIONS(6601),
    [anon_sym_property] = ACTIONS(6601),
    [anon_sym_assume] = ACTIONS(6601),
    [anon_sym_cover] = ACTIONS(6601),
    [anon_sym_sequence] = ACTIONS(6601),
    [anon_sym_restrict] = ACTIONS(6601),
    [anon_sym_not] = ACTIONS(6601),
    [anon_sym_or] = ACTIONS(6601),
    [anon_sym_and] = ACTIONS(6601),
    [anon_sym_case] = ACTIONS(6601),
    [anon_sym_always] = ACTIONS(6601),
    [anon_sym_covergroup] = ACTIONS(6601),
    [anon_sym_let] = ACTIONS(6601),
    [anon_sym_pulldown] = ACTIONS(6601),
    [anon_sym_pullup] = ACTIONS(6601),
    [anon_sym_cmos] = ACTIONS(6601),
    [anon_sym_rcmos] = ACTIONS(6601),
    [anon_sym_bufif0] = ACTIONS(6601),
    [anon_sym_bufif1] = ACTIONS(6601),
    [anon_sym_notif0] = ACTIONS(6601),
    [anon_sym_notif1] = ACTIONS(6601),
    [anon_sym_nmos] = ACTIONS(6601),
    [anon_sym_pmos] = ACTIONS(6601),
    [anon_sym_rnmos] = ACTIONS(6601),
    [anon_sym_rpmos] = ACTIONS(6601),
    [anon_sym_nand] = ACTIONS(6601),
    [anon_sym_nor] = ACTIONS(6601),
    [anon_sym_xor] = ACTIONS(6601),
    [anon_sym_xnor] = ACTIONS(6601),
    [anon_sym_buf] = ACTIONS(6601),
    [anon_sym_tranif0] = ACTIONS(6601),
    [anon_sym_tranif1] = ACTIONS(6601),
    [anon_sym_rtranif1] = ACTIONS(6601),
    [anon_sym_rtranif0] = ACTIONS(6601),
    [anon_sym_tran] = ACTIONS(6601),
    [anon_sym_rtran] = ACTIONS(6601),
    [anon_sym_generate] = ACTIONS(6601),
    [anon_sym_endgenerate] = ACTIONS(6601),
    [anon_sym_for] = ACTIONS(6601),
    [anon_sym_initial] = ACTIONS(6601),
    [anon_sym_assign] = ACTIONS(6601),
    [anon_sym_alias] = ACTIONS(6601),
    [anon_sym_always_comb] = ACTIONS(6601),
    [anon_sym_always_latch] = ACTIONS(6601),
    [anon_sym_always_ff] = ACTIONS(6601),
    [anon_sym_final] = ACTIONS(6601),
    [anon_sym_global] = ACTIONS(6601),
    [anon_sym_LPAREN_STAR] = ACTIONS(6603),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6603),
    [anon_sym_DOLLARunit] = ACTIONS(6603),
  },
  [4917] = {
    [sym_simple_identifier] = ACTIONS(6039),
    [anon_sym_wire] = ACTIONS(6039),
    [anon_sym_tri] = ACTIONS(6039),
    [anon_sym_tri0] = ACTIONS(6039),
    [anon_sym_tri1] = ACTIONS(6039),
    [anon_sym_wand] = ACTIONS(6039),
    [anon_sym_triand] = ACTIONS(6039),
    [anon_sym_wor] = ACTIONS(6039),
    [anon_sym_trior] = ACTIONS(6039),
    [anon_sym_trireg] = ACTIONS(6039),
    [anon_sym_uwire] = ACTIONS(6039),
    [anon_sym_SEMI] = ACTIONS(6041),
    [anon_sym_extern] = ACTIONS(6039),
    [anon_sym_interface] = ACTIONS(6039),
    [anon_sym_checker] = ACTIONS(6039),
    [anon_sym_virtual] = ACTIONS(6039),
    [anon_sym_class] = ACTIONS(6039),
    [anon_sym_type] = ACTIONS(6039),
    [anon_sym_DOLLARfatal] = ACTIONS(6041),
    [anon_sym_DOLLARerror] = ACTIONS(6041),
    [anon_sym_DOLLARwarning] = ACTIONS(6041),
    [anon_sym_DOLLARinfo] = ACTIONS(6041),
    [anon_sym_default] = ACTIONS(6039),
    [anon_sym_clocking] = ACTIONS(6039),
    [anon_sym_defparam] = ACTIONS(6039),
    [anon_sym_bind] = ACTIONS(6039),
    [anon_sym_rand] = ACTIONS(6039),
    [anon_sym_const] = ACTIONS(6039),
    [anon_sym_function] = ACTIONS(6039),
    [anon_sym_static] = ACTIONS(6039),
    [anon_sym_constraint] = ACTIONS(6039),
    [anon_sym_if] = ACTIONS(6039),
    [anon_sym_else] = ACTIONS(6039),
    [anon_sym_LBRACK] = ACTIONS(6041),
    [anon_sym_localparam] = ACTIONS(6039),
    [anon_sym_parameter] = ACTIONS(6039),
    [anon_sym_var] = ACTIONS(6039),
    [anon_sym_import] = ACTIONS(6039),
    [anon_sym_export] = ACTIONS(6039),
    [anon_sym_genvar] = ACTIONS(6039),
    [anon_sym_interconnect] = ACTIONS(6039),
    [anon_sym_typedef] = ACTIONS(6039),
    [anon_sym_enum] = ACTIONS(6039),
    [anon_sym_struct] = ACTIONS(6039),
    [anon_sym_union] = ACTIONS(6039),
    [anon_sym_nettype] = ACTIONS(6039),
    [anon_sym_automatic] = ACTIONS(6039),
    [anon_sym_string] = ACTIONS(6039),
    [anon_sym_chandle] = ACTIONS(6039),
    [anon_sym_event] = ACTIONS(6039),
    [anon_sym_byte] = ACTIONS(6039),
    [anon_sym_shortint] = ACTIONS(6039),
    [anon_sym_int] = ACTIONS(6039),
    [anon_sym_longint] = ACTIONS(6039),
    [anon_sym_integer] = ACTIONS(6039),
    [anon_sym_time] = ACTIONS(6039),
    [anon_sym_bit] = ACTIONS(6039),
    [anon_sym_logic] = ACTIONS(6039),
    [anon_sym_reg] = ACTIONS(6039),
    [anon_sym_shortreal] = ACTIONS(6039),
    [anon_sym_real] = ACTIONS(6039),
    [anon_sym_realtime] = ACTIONS(6039),
    [anon_sym_supply0] = ACTIONS(6039),
    [anon_sym_supply1] = ACTIONS(6039),
    [anon_sym_signed] = ACTIONS(6039),
    [anon_sym_unsigned] = ACTIONS(6039),
    [anon_sym_task] = ACTIONS(6039),
    [anon_sym_assert] = ACTIONS(6039),
    [anon_sym_property] = ACTIONS(6039),
    [anon_sym_assume] = ACTIONS(6039),
    [anon_sym_cover] = ACTIONS(6039),
    [anon_sym_sequence] = ACTIONS(6039),
    [anon_sym_restrict] = ACTIONS(6039),
    [anon_sym_not] = ACTIONS(6039),
    [anon_sym_or] = ACTIONS(6039),
    [anon_sym_and] = ACTIONS(6039),
    [anon_sym_case] = ACTIONS(6039),
    [anon_sym_always] = ACTIONS(6039),
    [anon_sym_covergroup] = ACTIONS(6039),
    [anon_sym_let] = ACTIONS(6039),
    [anon_sym_pulldown] = ACTIONS(6039),
    [anon_sym_pullup] = ACTIONS(6039),
    [anon_sym_cmos] = ACTIONS(6039),
    [anon_sym_rcmos] = ACTIONS(6039),
    [anon_sym_bufif0] = ACTIONS(6039),
    [anon_sym_bufif1] = ACTIONS(6039),
    [anon_sym_notif0] = ACTIONS(6039),
    [anon_sym_notif1] = ACTIONS(6039),
    [anon_sym_nmos] = ACTIONS(6039),
    [anon_sym_pmos] = ACTIONS(6039),
    [anon_sym_rnmos] = ACTIONS(6039),
    [anon_sym_rpmos] = ACTIONS(6039),
    [anon_sym_nand] = ACTIONS(6039),
    [anon_sym_nor] = ACTIONS(6039),
    [anon_sym_xor] = ACTIONS(6039),
    [anon_sym_xnor] = ACTIONS(6039),
    [anon_sym_buf] = ACTIONS(6039),
    [anon_sym_tranif0] = ACTIONS(6039),
    [anon_sym_tranif1] = ACTIONS(6039),
    [anon_sym_rtranif1] = ACTIONS(6039),
    [anon_sym_rtranif0] = ACTIONS(6039),
    [anon_sym_tran] = ACTIONS(6039),
    [anon_sym_rtran] = ACTIONS(6039),
    [anon_sym_generate] = ACTIONS(6039),
    [anon_sym_endgenerate] = ACTIONS(6039),
    [anon_sym_for] = ACTIONS(6039),
    [anon_sym_initial] = ACTIONS(6039),
    [anon_sym_assign] = ACTIONS(6039),
    [anon_sym_alias] = ACTIONS(6039),
    [anon_sym_always_comb] = ACTIONS(6039),
    [anon_sym_always_latch] = ACTIONS(6039),
    [anon_sym_always_ff] = ACTIONS(6039),
    [anon_sym_final] = ACTIONS(6039),
    [anon_sym_global] = ACTIONS(6039),
    [anon_sym_LPAREN_STAR] = ACTIONS(6041),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6041),
    [anon_sym_DOLLARunit] = ACTIONS(6041),
  },
  [4918] = {
    [sym_simple_identifier] = ACTIONS(4936),
    [anon_sym_wire] = ACTIONS(4936),
    [anon_sym_tri] = ACTIONS(4936),
    [anon_sym_tri0] = ACTIONS(4936),
    [anon_sym_tri1] = ACTIONS(4936),
    [anon_sym_wand] = ACTIONS(4936),
    [anon_sym_triand] = ACTIONS(4936),
    [anon_sym_wor] = ACTIONS(4936),
    [anon_sym_trior] = ACTIONS(4936),
    [anon_sym_trireg] = ACTIONS(4936),
    [anon_sym_uwire] = ACTIONS(4936),
    [anon_sym_SEMI] = ACTIONS(4934),
    [anon_sym_extern] = ACTIONS(4936),
    [anon_sym_interface] = ACTIONS(4936),
    [anon_sym_checker] = ACTIONS(4936),
    [anon_sym_virtual] = ACTIONS(4936),
    [anon_sym_class] = ACTIONS(4936),
    [anon_sym_type] = ACTIONS(4936),
    [anon_sym_DOLLARfatal] = ACTIONS(4934),
    [anon_sym_DOLLARerror] = ACTIONS(4934),
    [anon_sym_DOLLARwarning] = ACTIONS(4934),
    [anon_sym_DOLLARinfo] = ACTIONS(4934),
    [anon_sym_default] = ACTIONS(4936),
    [anon_sym_clocking] = ACTIONS(4936),
    [anon_sym_defparam] = ACTIONS(4936),
    [anon_sym_bind] = ACTIONS(4936),
    [anon_sym_rand] = ACTIONS(4936),
    [anon_sym_const] = ACTIONS(4936),
    [anon_sym_function] = ACTIONS(4936),
    [anon_sym_static] = ACTIONS(4936),
    [anon_sym_constraint] = ACTIONS(4936),
    [anon_sym_if] = ACTIONS(4936),
    [anon_sym_else] = ACTIONS(4936),
    [anon_sym_LBRACK] = ACTIONS(4934),
    [anon_sym_localparam] = ACTIONS(4936),
    [anon_sym_parameter] = ACTIONS(4936),
    [anon_sym_var] = ACTIONS(4936),
    [anon_sym_import] = ACTIONS(4936),
    [anon_sym_export] = ACTIONS(4936),
    [anon_sym_genvar] = ACTIONS(4936),
    [anon_sym_interconnect] = ACTIONS(4936),
    [anon_sym_typedef] = ACTIONS(4936),
    [anon_sym_enum] = ACTIONS(4936),
    [anon_sym_struct] = ACTIONS(4936),
    [anon_sym_union] = ACTIONS(4936),
    [anon_sym_nettype] = ACTIONS(4936),
    [anon_sym_automatic] = ACTIONS(4936),
    [anon_sym_string] = ACTIONS(4936),
    [anon_sym_chandle] = ACTIONS(4936),
    [anon_sym_event] = ACTIONS(4936),
    [anon_sym_byte] = ACTIONS(4936),
    [anon_sym_shortint] = ACTIONS(4936),
    [anon_sym_int] = ACTIONS(4936),
    [anon_sym_longint] = ACTIONS(4936),
    [anon_sym_integer] = ACTIONS(4936),
    [anon_sym_time] = ACTIONS(4936),
    [anon_sym_bit] = ACTIONS(4936),
    [anon_sym_logic] = ACTIONS(4936),
    [anon_sym_reg] = ACTIONS(4936),
    [anon_sym_shortreal] = ACTIONS(4936),
    [anon_sym_real] = ACTIONS(4936),
    [anon_sym_realtime] = ACTIONS(4936),
    [anon_sym_supply0] = ACTIONS(4936),
    [anon_sym_supply1] = ACTIONS(4936),
    [anon_sym_signed] = ACTIONS(4936),
    [anon_sym_unsigned] = ACTIONS(4936),
    [anon_sym_task] = ACTIONS(4936),
    [anon_sym_assert] = ACTIONS(4936),
    [anon_sym_property] = ACTIONS(4936),
    [anon_sym_assume] = ACTIONS(4936),
    [anon_sym_cover] = ACTIONS(4936),
    [anon_sym_sequence] = ACTIONS(4936),
    [anon_sym_restrict] = ACTIONS(4936),
    [anon_sym_not] = ACTIONS(4936),
    [anon_sym_or] = ACTIONS(4936),
    [anon_sym_and] = ACTIONS(4936),
    [anon_sym_case] = ACTIONS(4936),
    [anon_sym_always] = ACTIONS(4936),
    [anon_sym_covergroup] = ACTIONS(4936),
    [anon_sym_end] = ACTIONS(4936),
    [anon_sym_let] = ACTIONS(4936),
    [anon_sym_pulldown] = ACTIONS(4936),
    [anon_sym_pullup] = ACTIONS(4936),
    [anon_sym_cmos] = ACTIONS(4936),
    [anon_sym_rcmos] = ACTIONS(4936),
    [anon_sym_bufif0] = ACTIONS(4936),
    [anon_sym_bufif1] = ACTIONS(4936),
    [anon_sym_notif0] = ACTIONS(4936),
    [anon_sym_notif1] = ACTIONS(4936),
    [anon_sym_nmos] = ACTIONS(4936),
    [anon_sym_pmos] = ACTIONS(4936),
    [anon_sym_rnmos] = ACTIONS(4936),
    [anon_sym_rpmos] = ACTIONS(4936),
    [anon_sym_nand] = ACTIONS(4936),
    [anon_sym_nor] = ACTIONS(4936),
    [anon_sym_xor] = ACTIONS(4936),
    [anon_sym_xnor] = ACTIONS(4936),
    [anon_sym_buf] = ACTIONS(4936),
    [anon_sym_tranif0] = ACTIONS(4936),
    [anon_sym_tranif1] = ACTIONS(4936),
    [anon_sym_rtranif1] = ACTIONS(4936),
    [anon_sym_rtranif0] = ACTIONS(4936),
    [anon_sym_tran] = ACTIONS(4936),
    [anon_sym_rtran] = ACTIONS(4936),
    [anon_sym_generate] = ACTIONS(4936),
    [anon_sym_for] = ACTIONS(4936),
    [anon_sym_initial] = ACTIONS(4936),
    [anon_sym_assign] = ACTIONS(4936),
    [anon_sym_alias] = ACTIONS(4936),
    [anon_sym_always_comb] = ACTIONS(4936),
    [anon_sym_always_latch] = ACTIONS(4936),
    [anon_sym_always_ff] = ACTIONS(4936),
    [anon_sym_final] = ACTIONS(4936),
    [anon_sym_global] = ACTIONS(4936),
    [anon_sym_LPAREN_STAR] = ACTIONS(4934),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4934),
    [anon_sym_DOLLARunit] = ACTIONS(4934),
  },
  [4919] = {
    [sym_simple_identifier] = ACTIONS(5278),
    [anon_sym_wire] = ACTIONS(5278),
    [anon_sym_tri] = ACTIONS(5278),
    [anon_sym_tri0] = ACTIONS(5278),
    [anon_sym_tri1] = ACTIONS(5278),
    [anon_sym_wand] = ACTIONS(5278),
    [anon_sym_triand] = ACTIONS(5278),
    [anon_sym_wor] = ACTIONS(5278),
    [anon_sym_trior] = ACTIONS(5278),
    [anon_sym_trireg] = ACTIONS(5278),
    [anon_sym_uwire] = ACTIONS(5278),
    [anon_sym_SEMI] = ACTIONS(5276),
    [anon_sym_extern] = ACTIONS(5278),
    [anon_sym_interface] = ACTIONS(5278),
    [anon_sym_checker] = ACTIONS(5278),
    [anon_sym_virtual] = ACTIONS(5278),
    [anon_sym_class] = ACTIONS(5278),
    [anon_sym_type] = ACTIONS(5278),
    [anon_sym_DOLLARfatal] = ACTIONS(5276),
    [anon_sym_DOLLARerror] = ACTIONS(5276),
    [anon_sym_DOLLARwarning] = ACTIONS(5276),
    [anon_sym_DOLLARinfo] = ACTIONS(5276),
    [anon_sym_default] = ACTIONS(5278),
    [anon_sym_clocking] = ACTIONS(5278),
    [anon_sym_defparam] = ACTIONS(5278),
    [anon_sym_bind] = ACTIONS(5278),
    [anon_sym_rand] = ACTIONS(5278),
    [anon_sym_const] = ACTIONS(5278),
    [anon_sym_function] = ACTIONS(5278),
    [anon_sym_static] = ACTIONS(5278),
    [anon_sym_constraint] = ACTIONS(5278),
    [anon_sym_if] = ACTIONS(5278),
    [anon_sym_else] = ACTIONS(5278),
    [anon_sym_LBRACK] = ACTIONS(5276),
    [anon_sym_localparam] = ACTIONS(5278),
    [anon_sym_parameter] = ACTIONS(5278),
    [anon_sym_var] = ACTIONS(5278),
    [anon_sym_import] = ACTIONS(5278),
    [anon_sym_export] = ACTIONS(5278),
    [anon_sym_genvar] = ACTIONS(5278),
    [anon_sym_interconnect] = ACTIONS(5278),
    [anon_sym_typedef] = ACTIONS(5278),
    [anon_sym_enum] = ACTIONS(5278),
    [anon_sym_struct] = ACTIONS(5278),
    [anon_sym_union] = ACTIONS(5278),
    [anon_sym_nettype] = ACTIONS(5278),
    [anon_sym_automatic] = ACTIONS(5278),
    [anon_sym_string] = ACTIONS(5278),
    [anon_sym_chandle] = ACTIONS(5278),
    [anon_sym_event] = ACTIONS(5278),
    [anon_sym_byte] = ACTIONS(5278),
    [anon_sym_shortint] = ACTIONS(5278),
    [anon_sym_int] = ACTIONS(5278),
    [anon_sym_longint] = ACTIONS(5278),
    [anon_sym_integer] = ACTIONS(5278),
    [anon_sym_time] = ACTIONS(5278),
    [anon_sym_bit] = ACTIONS(5278),
    [anon_sym_logic] = ACTIONS(5278),
    [anon_sym_reg] = ACTIONS(5278),
    [anon_sym_shortreal] = ACTIONS(5278),
    [anon_sym_real] = ACTIONS(5278),
    [anon_sym_realtime] = ACTIONS(5278),
    [anon_sym_supply0] = ACTIONS(5278),
    [anon_sym_supply1] = ACTIONS(5278),
    [anon_sym_signed] = ACTIONS(5278),
    [anon_sym_unsigned] = ACTIONS(5278),
    [anon_sym_task] = ACTIONS(5278),
    [anon_sym_assert] = ACTIONS(5278),
    [anon_sym_property] = ACTIONS(5278),
    [anon_sym_assume] = ACTIONS(5278),
    [anon_sym_cover] = ACTIONS(5278),
    [anon_sym_sequence] = ACTIONS(5278),
    [anon_sym_restrict] = ACTIONS(5278),
    [anon_sym_not] = ACTIONS(5278),
    [anon_sym_or] = ACTIONS(5278),
    [anon_sym_and] = ACTIONS(5278),
    [anon_sym_case] = ACTIONS(5278),
    [anon_sym_always] = ACTIONS(5278),
    [anon_sym_covergroup] = ACTIONS(5278),
    [anon_sym_let] = ACTIONS(5278),
    [anon_sym_pulldown] = ACTIONS(5278),
    [anon_sym_pullup] = ACTIONS(5278),
    [anon_sym_cmos] = ACTIONS(5278),
    [anon_sym_rcmos] = ACTIONS(5278),
    [anon_sym_bufif0] = ACTIONS(5278),
    [anon_sym_bufif1] = ACTIONS(5278),
    [anon_sym_notif0] = ACTIONS(5278),
    [anon_sym_notif1] = ACTIONS(5278),
    [anon_sym_nmos] = ACTIONS(5278),
    [anon_sym_pmos] = ACTIONS(5278),
    [anon_sym_rnmos] = ACTIONS(5278),
    [anon_sym_rpmos] = ACTIONS(5278),
    [anon_sym_nand] = ACTIONS(5278),
    [anon_sym_nor] = ACTIONS(5278),
    [anon_sym_xor] = ACTIONS(5278),
    [anon_sym_xnor] = ACTIONS(5278),
    [anon_sym_buf] = ACTIONS(5278),
    [anon_sym_tranif0] = ACTIONS(5278),
    [anon_sym_tranif1] = ACTIONS(5278),
    [anon_sym_rtranif1] = ACTIONS(5278),
    [anon_sym_rtranif0] = ACTIONS(5278),
    [anon_sym_tran] = ACTIONS(5278),
    [anon_sym_rtran] = ACTIONS(5278),
    [anon_sym_generate] = ACTIONS(5278),
    [anon_sym_endgenerate] = ACTIONS(5278),
    [anon_sym_for] = ACTIONS(5278),
    [anon_sym_initial] = ACTIONS(5278),
    [anon_sym_assign] = ACTIONS(5278),
    [anon_sym_alias] = ACTIONS(5278),
    [anon_sym_always_comb] = ACTIONS(5278),
    [anon_sym_always_latch] = ACTIONS(5278),
    [anon_sym_always_ff] = ACTIONS(5278),
    [anon_sym_final] = ACTIONS(5278),
    [anon_sym_global] = ACTIONS(5278),
    [anon_sym_LPAREN_STAR] = ACTIONS(5276),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5276),
    [anon_sym_DOLLARunit] = ACTIONS(5276),
  },
  [4920] = {
    [sym_simple_identifier] = ACTIONS(6137),
    [anon_sym_wire] = ACTIONS(6137),
    [anon_sym_tri] = ACTIONS(6137),
    [anon_sym_tri0] = ACTIONS(6137),
    [anon_sym_tri1] = ACTIONS(6137),
    [anon_sym_wand] = ACTIONS(6137),
    [anon_sym_triand] = ACTIONS(6137),
    [anon_sym_wor] = ACTIONS(6137),
    [anon_sym_trior] = ACTIONS(6137),
    [anon_sym_trireg] = ACTIONS(6137),
    [anon_sym_uwire] = ACTIONS(6137),
    [anon_sym_SEMI] = ACTIONS(6139),
    [anon_sym_extern] = ACTIONS(6137),
    [anon_sym_interface] = ACTIONS(6137),
    [anon_sym_checker] = ACTIONS(6137),
    [anon_sym_virtual] = ACTIONS(6137),
    [anon_sym_class] = ACTIONS(6137),
    [anon_sym_type] = ACTIONS(6137),
    [anon_sym_DOLLARfatal] = ACTIONS(6139),
    [anon_sym_DOLLARerror] = ACTIONS(6139),
    [anon_sym_DOLLARwarning] = ACTIONS(6139),
    [anon_sym_DOLLARinfo] = ACTIONS(6139),
    [anon_sym_default] = ACTIONS(6137),
    [anon_sym_clocking] = ACTIONS(6137),
    [anon_sym_defparam] = ACTIONS(6137),
    [anon_sym_bind] = ACTIONS(6137),
    [anon_sym_rand] = ACTIONS(6137),
    [anon_sym_const] = ACTIONS(6137),
    [anon_sym_function] = ACTIONS(6137),
    [anon_sym_static] = ACTIONS(6137),
    [anon_sym_constraint] = ACTIONS(6137),
    [anon_sym_if] = ACTIONS(6137),
    [anon_sym_else] = ACTIONS(6137),
    [anon_sym_LBRACK] = ACTIONS(6139),
    [anon_sym_localparam] = ACTIONS(6137),
    [anon_sym_parameter] = ACTIONS(6137),
    [anon_sym_var] = ACTIONS(6137),
    [anon_sym_import] = ACTIONS(6137),
    [anon_sym_export] = ACTIONS(6137),
    [anon_sym_genvar] = ACTIONS(6137),
    [anon_sym_interconnect] = ACTIONS(6137),
    [anon_sym_typedef] = ACTIONS(6137),
    [anon_sym_enum] = ACTIONS(6137),
    [anon_sym_struct] = ACTIONS(6137),
    [anon_sym_union] = ACTIONS(6137),
    [anon_sym_nettype] = ACTIONS(6137),
    [anon_sym_automatic] = ACTIONS(6137),
    [anon_sym_string] = ACTIONS(6137),
    [anon_sym_chandle] = ACTIONS(6137),
    [anon_sym_event] = ACTIONS(6137),
    [anon_sym_byte] = ACTIONS(6137),
    [anon_sym_shortint] = ACTIONS(6137),
    [anon_sym_int] = ACTIONS(6137),
    [anon_sym_longint] = ACTIONS(6137),
    [anon_sym_integer] = ACTIONS(6137),
    [anon_sym_time] = ACTIONS(6137),
    [anon_sym_bit] = ACTIONS(6137),
    [anon_sym_logic] = ACTIONS(6137),
    [anon_sym_reg] = ACTIONS(6137),
    [anon_sym_shortreal] = ACTIONS(6137),
    [anon_sym_real] = ACTIONS(6137),
    [anon_sym_realtime] = ACTIONS(6137),
    [anon_sym_supply0] = ACTIONS(6137),
    [anon_sym_supply1] = ACTIONS(6137),
    [anon_sym_signed] = ACTIONS(6137),
    [anon_sym_unsigned] = ACTIONS(6137),
    [anon_sym_task] = ACTIONS(6137),
    [anon_sym_assert] = ACTIONS(6137),
    [anon_sym_property] = ACTIONS(6137),
    [anon_sym_assume] = ACTIONS(6137),
    [anon_sym_cover] = ACTIONS(6137),
    [anon_sym_sequence] = ACTIONS(6137),
    [anon_sym_restrict] = ACTIONS(6137),
    [anon_sym_not] = ACTIONS(6137),
    [anon_sym_or] = ACTIONS(6137),
    [anon_sym_and] = ACTIONS(6137),
    [anon_sym_case] = ACTIONS(6137),
    [anon_sym_always] = ACTIONS(6137),
    [anon_sym_covergroup] = ACTIONS(6137),
    [anon_sym_let] = ACTIONS(6137),
    [anon_sym_pulldown] = ACTIONS(6137),
    [anon_sym_pullup] = ACTIONS(6137),
    [anon_sym_cmos] = ACTIONS(6137),
    [anon_sym_rcmos] = ACTIONS(6137),
    [anon_sym_bufif0] = ACTIONS(6137),
    [anon_sym_bufif1] = ACTIONS(6137),
    [anon_sym_notif0] = ACTIONS(6137),
    [anon_sym_notif1] = ACTIONS(6137),
    [anon_sym_nmos] = ACTIONS(6137),
    [anon_sym_pmos] = ACTIONS(6137),
    [anon_sym_rnmos] = ACTIONS(6137),
    [anon_sym_rpmos] = ACTIONS(6137),
    [anon_sym_nand] = ACTIONS(6137),
    [anon_sym_nor] = ACTIONS(6137),
    [anon_sym_xor] = ACTIONS(6137),
    [anon_sym_xnor] = ACTIONS(6137),
    [anon_sym_buf] = ACTIONS(6137),
    [anon_sym_tranif0] = ACTIONS(6137),
    [anon_sym_tranif1] = ACTIONS(6137),
    [anon_sym_rtranif1] = ACTIONS(6137),
    [anon_sym_rtranif0] = ACTIONS(6137),
    [anon_sym_tran] = ACTIONS(6137),
    [anon_sym_rtran] = ACTIONS(6137),
    [anon_sym_generate] = ACTIONS(6137),
    [anon_sym_endgenerate] = ACTIONS(6137),
    [anon_sym_for] = ACTIONS(6137),
    [anon_sym_initial] = ACTIONS(6137),
    [anon_sym_assign] = ACTIONS(6137),
    [anon_sym_alias] = ACTIONS(6137),
    [anon_sym_always_comb] = ACTIONS(6137),
    [anon_sym_always_latch] = ACTIONS(6137),
    [anon_sym_always_ff] = ACTIONS(6137),
    [anon_sym_final] = ACTIONS(6137),
    [anon_sym_global] = ACTIONS(6137),
    [anon_sym_LPAREN_STAR] = ACTIONS(6139),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6139),
    [anon_sym_DOLLARunit] = ACTIONS(6139),
  },
  [4921] = {
    [sym_simple_identifier] = ACTIONS(6043),
    [anon_sym_wire] = ACTIONS(6043),
    [anon_sym_tri] = ACTIONS(6043),
    [anon_sym_tri0] = ACTIONS(6043),
    [anon_sym_tri1] = ACTIONS(6043),
    [anon_sym_wand] = ACTIONS(6043),
    [anon_sym_triand] = ACTIONS(6043),
    [anon_sym_wor] = ACTIONS(6043),
    [anon_sym_trior] = ACTIONS(6043),
    [anon_sym_trireg] = ACTIONS(6043),
    [anon_sym_uwire] = ACTIONS(6043),
    [anon_sym_SEMI] = ACTIONS(6045),
    [anon_sym_extern] = ACTIONS(6043),
    [anon_sym_interface] = ACTIONS(6043),
    [anon_sym_checker] = ACTIONS(6043),
    [anon_sym_virtual] = ACTIONS(6043),
    [anon_sym_class] = ACTIONS(6043),
    [anon_sym_type] = ACTIONS(6043),
    [anon_sym_DOLLARfatal] = ACTIONS(6045),
    [anon_sym_DOLLARerror] = ACTIONS(6045),
    [anon_sym_DOLLARwarning] = ACTIONS(6045),
    [anon_sym_DOLLARinfo] = ACTIONS(6045),
    [anon_sym_default] = ACTIONS(6043),
    [anon_sym_clocking] = ACTIONS(6043),
    [anon_sym_defparam] = ACTIONS(6043),
    [anon_sym_bind] = ACTIONS(6043),
    [anon_sym_rand] = ACTIONS(6043),
    [anon_sym_const] = ACTIONS(6043),
    [anon_sym_function] = ACTIONS(6043),
    [anon_sym_static] = ACTIONS(6043),
    [anon_sym_constraint] = ACTIONS(6043),
    [anon_sym_if] = ACTIONS(6043),
    [anon_sym_else] = ACTIONS(6043),
    [anon_sym_LBRACK] = ACTIONS(6045),
    [anon_sym_localparam] = ACTIONS(6043),
    [anon_sym_parameter] = ACTIONS(6043),
    [anon_sym_var] = ACTIONS(6043),
    [anon_sym_import] = ACTIONS(6043),
    [anon_sym_export] = ACTIONS(6043),
    [anon_sym_genvar] = ACTIONS(6043),
    [anon_sym_interconnect] = ACTIONS(6043),
    [anon_sym_typedef] = ACTIONS(6043),
    [anon_sym_enum] = ACTIONS(6043),
    [anon_sym_struct] = ACTIONS(6043),
    [anon_sym_union] = ACTIONS(6043),
    [anon_sym_nettype] = ACTIONS(6043),
    [anon_sym_automatic] = ACTIONS(6043),
    [anon_sym_string] = ACTIONS(6043),
    [anon_sym_chandle] = ACTIONS(6043),
    [anon_sym_event] = ACTIONS(6043),
    [anon_sym_byte] = ACTIONS(6043),
    [anon_sym_shortint] = ACTIONS(6043),
    [anon_sym_int] = ACTIONS(6043),
    [anon_sym_longint] = ACTIONS(6043),
    [anon_sym_integer] = ACTIONS(6043),
    [anon_sym_time] = ACTIONS(6043),
    [anon_sym_bit] = ACTIONS(6043),
    [anon_sym_logic] = ACTIONS(6043),
    [anon_sym_reg] = ACTIONS(6043),
    [anon_sym_shortreal] = ACTIONS(6043),
    [anon_sym_real] = ACTIONS(6043),
    [anon_sym_realtime] = ACTIONS(6043),
    [anon_sym_supply0] = ACTIONS(6043),
    [anon_sym_supply1] = ACTIONS(6043),
    [anon_sym_signed] = ACTIONS(6043),
    [anon_sym_unsigned] = ACTIONS(6043),
    [anon_sym_task] = ACTIONS(6043),
    [anon_sym_assert] = ACTIONS(6043),
    [anon_sym_property] = ACTIONS(6043),
    [anon_sym_assume] = ACTIONS(6043),
    [anon_sym_cover] = ACTIONS(6043),
    [anon_sym_sequence] = ACTIONS(6043),
    [anon_sym_restrict] = ACTIONS(6043),
    [anon_sym_not] = ACTIONS(6043),
    [anon_sym_or] = ACTIONS(6043),
    [anon_sym_and] = ACTIONS(6043),
    [anon_sym_case] = ACTIONS(6043),
    [anon_sym_always] = ACTIONS(6043),
    [anon_sym_covergroup] = ACTIONS(6043),
    [anon_sym_let] = ACTIONS(6043),
    [anon_sym_pulldown] = ACTIONS(6043),
    [anon_sym_pullup] = ACTIONS(6043),
    [anon_sym_cmos] = ACTIONS(6043),
    [anon_sym_rcmos] = ACTIONS(6043),
    [anon_sym_bufif0] = ACTIONS(6043),
    [anon_sym_bufif1] = ACTIONS(6043),
    [anon_sym_notif0] = ACTIONS(6043),
    [anon_sym_notif1] = ACTIONS(6043),
    [anon_sym_nmos] = ACTIONS(6043),
    [anon_sym_pmos] = ACTIONS(6043),
    [anon_sym_rnmos] = ACTIONS(6043),
    [anon_sym_rpmos] = ACTIONS(6043),
    [anon_sym_nand] = ACTIONS(6043),
    [anon_sym_nor] = ACTIONS(6043),
    [anon_sym_xor] = ACTIONS(6043),
    [anon_sym_xnor] = ACTIONS(6043),
    [anon_sym_buf] = ACTIONS(6043),
    [anon_sym_tranif0] = ACTIONS(6043),
    [anon_sym_tranif1] = ACTIONS(6043),
    [anon_sym_rtranif1] = ACTIONS(6043),
    [anon_sym_rtranif0] = ACTIONS(6043),
    [anon_sym_tran] = ACTIONS(6043),
    [anon_sym_rtran] = ACTIONS(6043),
    [anon_sym_generate] = ACTIONS(6043),
    [anon_sym_endgenerate] = ACTIONS(6043),
    [anon_sym_for] = ACTIONS(6043),
    [anon_sym_initial] = ACTIONS(6043),
    [anon_sym_assign] = ACTIONS(6043),
    [anon_sym_alias] = ACTIONS(6043),
    [anon_sym_always_comb] = ACTIONS(6043),
    [anon_sym_always_latch] = ACTIONS(6043),
    [anon_sym_always_ff] = ACTIONS(6043),
    [anon_sym_final] = ACTIONS(6043),
    [anon_sym_global] = ACTIONS(6043),
    [anon_sym_LPAREN_STAR] = ACTIONS(6045),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6045),
    [anon_sym_DOLLARunit] = ACTIONS(6045),
  },
  [4922] = {
    [sym_simple_identifier] = ACTIONS(5218),
    [anon_sym_wire] = ACTIONS(5218),
    [anon_sym_tri] = ACTIONS(5218),
    [anon_sym_tri0] = ACTIONS(5218),
    [anon_sym_tri1] = ACTIONS(5218),
    [anon_sym_wand] = ACTIONS(5218),
    [anon_sym_triand] = ACTIONS(5218),
    [anon_sym_wor] = ACTIONS(5218),
    [anon_sym_trior] = ACTIONS(5218),
    [anon_sym_trireg] = ACTIONS(5218),
    [anon_sym_uwire] = ACTIONS(5218),
    [anon_sym_SEMI] = ACTIONS(5216),
    [anon_sym_extern] = ACTIONS(5218),
    [anon_sym_interface] = ACTIONS(5218),
    [anon_sym_checker] = ACTIONS(5218),
    [anon_sym_virtual] = ACTIONS(5218),
    [anon_sym_class] = ACTIONS(5218),
    [anon_sym_type] = ACTIONS(5218),
    [anon_sym_DOLLARfatal] = ACTIONS(5216),
    [anon_sym_DOLLARerror] = ACTIONS(5216),
    [anon_sym_DOLLARwarning] = ACTIONS(5216),
    [anon_sym_DOLLARinfo] = ACTIONS(5216),
    [anon_sym_default] = ACTIONS(5218),
    [anon_sym_clocking] = ACTIONS(5218),
    [anon_sym_defparam] = ACTIONS(5218),
    [anon_sym_bind] = ACTIONS(5218),
    [anon_sym_rand] = ACTIONS(5218),
    [anon_sym_const] = ACTIONS(5218),
    [anon_sym_function] = ACTIONS(5218),
    [anon_sym_static] = ACTIONS(5218),
    [anon_sym_constraint] = ACTIONS(5218),
    [anon_sym_if] = ACTIONS(5218),
    [anon_sym_else] = ACTIONS(5218),
    [anon_sym_LBRACK] = ACTIONS(5216),
    [anon_sym_localparam] = ACTIONS(5218),
    [anon_sym_parameter] = ACTIONS(5218),
    [anon_sym_var] = ACTIONS(5218),
    [anon_sym_import] = ACTIONS(5218),
    [anon_sym_export] = ACTIONS(5218),
    [anon_sym_genvar] = ACTIONS(5218),
    [anon_sym_interconnect] = ACTIONS(5218),
    [anon_sym_typedef] = ACTIONS(5218),
    [anon_sym_enum] = ACTIONS(5218),
    [anon_sym_struct] = ACTIONS(5218),
    [anon_sym_union] = ACTIONS(5218),
    [anon_sym_nettype] = ACTIONS(5218),
    [anon_sym_automatic] = ACTIONS(5218),
    [anon_sym_string] = ACTIONS(5218),
    [anon_sym_chandle] = ACTIONS(5218),
    [anon_sym_event] = ACTIONS(5218),
    [anon_sym_byte] = ACTIONS(5218),
    [anon_sym_shortint] = ACTIONS(5218),
    [anon_sym_int] = ACTIONS(5218),
    [anon_sym_longint] = ACTIONS(5218),
    [anon_sym_integer] = ACTIONS(5218),
    [anon_sym_time] = ACTIONS(5218),
    [anon_sym_bit] = ACTIONS(5218),
    [anon_sym_logic] = ACTIONS(5218),
    [anon_sym_reg] = ACTIONS(5218),
    [anon_sym_shortreal] = ACTIONS(5218),
    [anon_sym_real] = ACTIONS(5218),
    [anon_sym_realtime] = ACTIONS(5218),
    [anon_sym_supply0] = ACTIONS(5218),
    [anon_sym_supply1] = ACTIONS(5218),
    [anon_sym_signed] = ACTIONS(5218),
    [anon_sym_unsigned] = ACTIONS(5218),
    [anon_sym_task] = ACTIONS(5218),
    [anon_sym_assert] = ACTIONS(5218),
    [anon_sym_property] = ACTIONS(5218),
    [anon_sym_assume] = ACTIONS(5218),
    [anon_sym_cover] = ACTIONS(5218),
    [anon_sym_sequence] = ACTIONS(5218),
    [anon_sym_restrict] = ACTIONS(5218),
    [anon_sym_not] = ACTIONS(5218),
    [anon_sym_or] = ACTIONS(5218),
    [anon_sym_and] = ACTIONS(5218),
    [anon_sym_case] = ACTIONS(5218),
    [anon_sym_always] = ACTIONS(5218),
    [anon_sym_covergroup] = ACTIONS(5218),
    [anon_sym_let] = ACTIONS(5218),
    [anon_sym_pulldown] = ACTIONS(5218),
    [anon_sym_pullup] = ACTIONS(5218),
    [anon_sym_cmos] = ACTIONS(5218),
    [anon_sym_rcmos] = ACTIONS(5218),
    [anon_sym_bufif0] = ACTIONS(5218),
    [anon_sym_bufif1] = ACTIONS(5218),
    [anon_sym_notif0] = ACTIONS(5218),
    [anon_sym_notif1] = ACTIONS(5218),
    [anon_sym_nmos] = ACTIONS(5218),
    [anon_sym_pmos] = ACTIONS(5218),
    [anon_sym_rnmos] = ACTIONS(5218),
    [anon_sym_rpmos] = ACTIONS(5218),
    [anon_sym_nand] = ACTIONS(5218),
    [anon_sym_nor] = ACTIONS(5218),
    [anon_sym_xor] = ACTIONS(5218),
    [anon_sym_xnor] = ACTIONS(5218),
    [anon_sym_buf] = ACTIONS(5218),
    [anon_sym_tranif0] = ACTIONS(5218),
    [anon_sym_tranif1] = ACTIONS(5218),
    [anon_sym_rtranif1] = ACTIONS(5218),
    [anon_sym_rtranif0] = ACTIONS(5218),
    [anon_sym_tran] = ACTIONS(5218),
    [anon_sym_rtran] = ACTIONS(5218),
    [anon_sym_generate] = ACTIONS(5218),
    [anon_sym_endgenerate] = ACTIONS(5218),
    [anon_sym_for] = ACTIONS(5218),
    [anon_sym_initial] = ACTIONS(5218),
    [anon_sym_assign] = ACTIONS(5218),
    [anon_sym_alias] = ACTIONS(5218),
    [anon_sym_always_comb] = ACTIONS(5218),
    [anon_sym_always_latch] = ACTIONS(5218),
    [anon_sym_always_ff] = ACTIONS(5218),
    [anon_sym_final] = ACTIONS(5218),
    [anon_sym_global] = ACTIONS(5218),
    [anon_sym_LPAREN_STAR] = ACTIONS(5216),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5216),
    [anon_sym_DOLLARunit] = ACTIONS(5216),
  },
  [4923] = {
    [sym_simple_identifier] = ACTIONS(6053),
    [anon_sym_wire] = ACTIONS(6053),
    [anon_sym_tri] = ACTIONS(6053),
    [anon_sym_tri0] = ACTIONS(6053),
    [anon_sym_tri1] = ACTIONS(6053),
    [anon_sym_wand] = ACTIONS(6053),
    [anon_sym_triand] = ACTIONS(6053),
    [anon_sym_wor] = ACTIONS(6053),
    [anon_sym_trior] = ACTIONS(6053),
    [anon_sym_trireg] = ACTIONS(6053),
    [anon_sym_uwire] = ACTIONS(6053),
    [anon_sym_SEMI] = ACTIONS(6055),
    [anon_sym_extern] = ACTIONS(6053),
    [anon_sym_interface] = ACTIONS(6053),
    [anon_sym_checker] = ACTIONS(6053),
    [anon_sym_virtual] = ACTIONS(6053),
    [anon_sym_class] = ACTIONS(6053),
    [anon_sym_type] = ACTIONS(6053),
    [anon_sym_DOLLARfatal] = ACTIONS(6055),
    [anon_sym_DOLLARerror] = ACTIONS(6055),
    [anon_sym_DOLLARwarning] = ACTIONS(6055),
    [anon_sym_DOLLARinfo] = ACTIONS(6055),
    [anon_sym_default] = ACTIONS(6053),
    [anon_sym_clocking] = ACTIONS(6053),
    [anon_sym_defparam] = ACTIONS(6053),
    [anon_sym_bind] = ACTIONS(6053),
    [anon_sym_rand] = ACTIONS(6053),
    [anon_sym_const] = ACTIONS(6053),
    [anon_sym_function] = ACTIONS(6053),
    [anon_sym_static] = ACTIONS(6053),
    [anon_sym_constraint] = ACTIONS(6053),
    [anon_sym_if] = ACTIONS(6053),
    [anon_sym_else] = ACTIONS(6053),
    [anon_sym_LBRACK] = ACTIONS(6055),
    [anon_sym_localparam] = ACTIONS(6053),
    [anon_sym_parameter] = ACTIONS(6053),
    [anon_sym_var] = ACTIONS(6053),
    [anon_sym_import] = ACTIONS(6053),
    [anon_sym_export] = ACTIONS(6053),
    [anon_sym_genvar] = ACTIONS(6053),
    [anon_sym_interconnect] = ACTIONS(6053),
    [anon_sym_typedef] = ACTIONS(6053),
    [anon_sym_enum] = ACTIONS(6053),
    [anon_sym_struct] = ACTIONS(6053),
    [anon_sym_union] = ACTIONS(6053),
    [anon_sym_nettype] = ACTIONS(6053),
    [anon_sym_automatic] = ACTIONS(6053),
    [anon_sym_string] = ACTIONS(6053),
    [anon_sym_chandle] = ACTIONS(6053),
    [anon_sym_event] = ACTIONS(6053),
    [anon_sym_byte] = ACTIONS(6053),
    [anon_sym_shortint] = ACTIONS(6053),
    [anon_sym_int] = ACTIONS(6053),
    [anon_sym_longint] = ACTIONS(6053),
    [anon_sym_integer] = ACTIONS(6053),
    [anon_sym_time] = ACTIONS(6053),
    [anon_sym_bit] = ACTIONS(6053),
    [anon_sym_logic] = ACTIONS(6053),
    [anon_sym_reg] = ACTIONS(6053),
    [anon_sym_shortreal] = ACTIONS(6053),
    [anon_sym_real] = ACTIONS(6053),
    [anon_sym_realtime] = ACTIONS(6053),
    [anon_sym_supply0] = ACTIONS(6053),
    [anon_sym_supply1] = ACTIONS(6053),
    [anon_sym_signed] = ACTIONS(6053),
    [anon_sym_unsigned] = ACTIONS(6053),
    [anon_sym_task] = ACTIONS(6053),
    [anon_sym_assert] = ACTIONS(6053),
    [anon_sym_property] = ACTIONS(6053),
    [anon_sym_assume] = ACTIONS(6053),
    [anon_sym_cover] = ACTIONS(6053),
    [anon_sym_sequence] = ACTIONS(6053),
    [anon_sym_restrict] = ACTIONS(6053),
    [anon_sym_not] = ACTIONS(6053),
    [anon_sym_or] = ACTIONS(6053),
    [anon_sym_and] = ACTIONS(6053),
    [anon_sym_case] = ACTIONS(6053),
    [anon_sym_always] = ACTIONS(6053),
    [anon_sym_covergroup] = ACTIONS(6053),
    [anon_sym_let] = ACTIONS(6053),
    [anon_sym_pulldown] = ACTIONS(6053),
    [anon_sym_pullup] = ACTIONS(6053),
    [anon_sym_cmos] = ACTIONS(6053),
    [anon_sym_rcmos] = ACTIONS(6053),
    [anon_sym_bufif0] = ACTIONS(6053),
    [anon_sym_bufif1] = ACTIONS(6053),
    [anon_sym_notif0] = ACTIONS(6053),
    [anon_sym_notif1] = ACTIONS(6053),
    [anon_sym_nmos] = ACTIONS(6053),
    [anon_sym_pmos] = ACTIONS(6053),
    [anon_sym_rnmos] = ACTIONS(6053),
    [anon_sym_rpmos] = ACTIONS(6053),
    [anon_sym_nand] = ACTIONS(6053),
    [anon_sym_nor] = ACTIONS(6053),
    [anon_sym_xor] = ACTIONS(6053),
    [anon_sym_xnor] = ACTIONS(6053),
    [anon_sym_buf] = ACTIONS(6053),
    [anon_sym_tranif0] = ACTIONS(6053),
    [anon_sym_tranif1] = ACTIONS(6053),
    [anon_sym_rtranif1] = ACTIONS(6053),
    [anon_sym_rtranif0] = ACTIONS(6053),
    [anon_sym_tran] = ACTIONS(6053),
    [anon_sym_rtran] = ACTIONS(6053),
    [anon_sym_generate] = ACTIONS(6053),
    [anon_sym_endgenerate] = ACTIONS(6053),
    [anon_sym_for] = ACTIONS(6053),
    [anon_sym_initial] = ACTIONS(6053),
    [anon_sym_assign] = ACTIONS(6053),
    [anon_sym_alias] = ACTIONS(6053),
    [anon_sym_always_comb] = ACTIONS(6053),
    [anon_sym_always_latch] = ACTIONS(6053),
    [anon_sym_always_ff] = ACTIONS(6053),
    [anon_sym_final] = ACTIONS(6053),
    [anon_sym_global] = ACTIONS(6053),
    [anon_sym_LPAREN_STAR] = ACTIONS(6055),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6055),
    [anon_sym_DOLLARunit] = ACTIONS(6055),
  },
  [4924] = {
    [sym_simple_identifier] = ACTIONS(6735),
    [anon_sym_wire] = ACTIONS(6735),
    [anon_sym_tri] = ACTIONS(6735),
    [anon_sym_tri0] = ACTIONS(6735),
    [anon_sym_tri1] = ACTIONS(6735),
    [anon_sym_wand] = ACTIONS(6735),
    [anon_sym_triand] = ACTIONS(6735),
    [anon_sym_wor] = ACTIONS(6735),
    [anon_sym_trior] = ACTIONS(6735),
    [anon_sym_trireg] = ACTIONS(6735),
    [anon_sym_uwire] = ACTIONS(6735),
    [anon_sym_SEMI] = ACTIONS(6737),
    [anon_sym_extern] = ACTIONS(6735),
    [anon_sym_interface] = ACTIONS(6735),
    [anon_sym_checker] = ACTIONS(6735),
    [anon_sym_virtual] = ACTIONS(6735),
    [anon_sym_class] = ACTIONS(6735),
    [anon_sym_type] = ACTIONS(6735),
    [anon_sym_DOLLARfatal] = ACTIONS(6737),
    [anon_sym_DOLLARerror] = ACTIONS(6737),
    [anon_sym_DOLLARwarning] = ACTIONS(6737),
    [anon_sym_DOLLARinfo] = ACTIONS(6737),
    [anon_sym_default] = ACTIONS(6735),
    [anon_sym_clocking] = ACTIONS(6735),
    [anon_sym_defparam] = ACTIONS(6735),
    [anon_sym_bind] = ACTIONS(6735),
    [anon_sym_rand] = ACTIONS(6735),
    [anon_sym_const] = ACTIONS(6735),
    [anon_sym_function] = ACTIONS(6735),
    [anon_sym_static] = ACTIONS(6735),
    [anon_sym_constraint] = ACTIONS(6735),
    [anon_sym_if] = ACTIONS(6735),
    [anon_sym_else] = ACTIONS(6735),
    [anon_sym_LBRACK] = ACTIONS(6737),
    [anon_sym_localparam] = ACTIONS(6735),
    [anon_sym_parameter] = ACTIONS(6735),
    [anon_sym_var] = ACTIONS(6735),
    [anon_sym_import] = ACTIONS(6735),
    [anon_sym_export] = ACTIONS(6735),
    [anon_sym_genvar] = ACTIONS(6735),
    [anon_sym_interconnect] = ACTIONS(6735),
    [anon_sym_typedef] = ACTIONS(6735),
    [anon_sym_enum] = ACTIONS(6735),
    [anon_sym_struct] = ACTIONS(6735),
    [anon_sym_union] = ACTIONS(6735),
    [anon_sym_nettype] = ACTIONS(6735),
    [anon_sym_automatic] = ACTIONS(6735),
    [anon_sym_string] = ACTIONS(6735),
    [anon_sym_chandle] = ACTIONS(6735),
    [anon_sym_event] = ACTIONS(6735),
    [anon_sym_byte] = ACTIONS(6735),
    [anon_sym_shortint] = ACTIONS(6735),
    [anon_sym_int] = ACTIONS(6735),
    [anon_sym_longint] = ACTIONS(6735),
    [anon_sym_integer] = ACTIONS(6735),
    [anon_sym_time] = ACTIONS(6735),
    [anon_sym_bit] = ACTIONS(6735),
    [anon_sym_logic] = ACTIONS(6735),
    [anon_sym_reg] = ACTIONS(6735),
    [anon_sym_shortreal] = ACTIONS(6735),
    [anon_sym_real] = ACTIONS(6735),
    [anon_sym_realtime] = ACTIONS(6735),
    [anon_sym_supply0] = ACTIONS(6735),
    [anon_sym_supply1] = ACTIONS(6735),
    [anon_sym_signed] = ACTIONS(6735),
    [anon_sym_unsigned] = ACTIONS(6735),
    [anon_sym_task] = ACTIONS(6735),
    [anon_sym_assert] = ACTIONS(6735),
    [anon_sym_property] = ACTIONS(6735),
    [anon_sym_assume] = ACTIONS(6735),
    [anon_sym_cover] = ACTIONS(6735),
    [anon_sym_sequence] = ACTIONS(6735),
    [anon_sym_restrict] = ACTIONS(6735),
    [anon_sym_not] = ACTIONS(6735),
    [anon_sym_or] = ACTIONS(6735),
    [anon_sym_and] = ACTIONS(6735),
    [anon_sym_case] = ACTIONS(6735),
    [anon_sym_always] = ACTIONS(6735),
    [anon_sym_covergroup] = ACTIONS(6735),
    [anon_sym_let] = ACTIONS(6735),
    [anon_sym_pulldown] = ACTIONS(6735),
    [anon_sym_pullup] = ACTIONS(6735),
    [anon_sym_cmos] = ACTIONS(6735),
    [anon_sym_rcmos] = ACTIONS(6735),
    [anon_sym_bufif0] = ACTIONS(6735),
    [anon_sym_bufif1] = ACTIONS(6735),
    [anon_sym_notif0] = ACTIONS(6735),
    [anon_sym_notif1] = ACTIONS(6735),
    [anon_sym_nmos] = ACTIONS(6735),
    [anon_sym_pmos] = ACTIONS(6735),
    [anon_sym_rnmos] = ACTIONS(6735),
    [anon_sym_rpmos] = ACTIONS(6735),
    [anon_sym_nand] = ACTIONS(6735),
    [anon_sym_nor] = ACTIONS(6735),
    [anon_sym_xor] = ACTIONS(6735),
    [anon_sym_xnor] = ACTIONS(6735),
    [anon_sym_buf] = ACTIONS(6735),
    [anon_sym_tranif0] = ACTIONS(6735),
    [anon_sym_tranif1] = ACTIONS(6735),
    [anon_sym_rtranif1] = ACTIONS(6735),
    [anon_sym_rtranif0] = ACTIONS(6735),
    [anon_sym_tran] = ACTIONS(6735),
    [anon_sym_rtran] = ACTIONS(6735),
    [anon_sym_generate] = ACTIONS(6735),
    [anon_sym_endgenerate] = ACTIONS(6735),
    [anon_sym_for] = ACTIONS(6735),
    [anon_sym_initial] = ACTIONS(6735),
    [anon_sym_assign] = ACTIONS(6735),
    [anon_sym_alias] = ACTIONS(6735),
    [anon_sym_always_comb] = ACTIONS(6735),
    [anon_sym_always_latch] = ACTIONS(6735),
    [anon_sym_always_ff] = ACTIONS(6735),
    [anon_sym_final] = ACTIONS(6735),
    [anon_sym_global] = ACTIONS(6735),
    [anon_sym_LPAREN_STAR] = ACTIONS(6737),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6737),
    [anon_sym_DOLLARunit] = ACTIONS(6737),
  },
  [4925] = {
    [sym_simple_identifier] = ACTIONS(4524),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_rand] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_endgenerate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [4926] = {
    [sym_simple_identifier] = ACTIONS(5230),
    [anon_sym_wire] = ACTIONS(5230),
    [anon_sym_tri] = ACTIONS(5230),
    [anon_sym_tri0] = ACTIONS(5230),
    [anon_sym_tri1] = ACTIONS(5230),
    [anon_sym_wand] = ACTIONS(5230),
    [anon_sym_triand] = ACTIONS(5230),
    [anon_sym_wor] = ACTIONS(5230),
    [anon_sym_trior] = ACTIONS(5230),
    [anon_sym_trireg] = ACTIONS(5230),
    [anon_sym_uwire] = ACTIONS(5230),
    [anon_sym_SEMI] = ACTIONS(5228),
    [anon_sym_extern] = ACTIONS(5230),
    [anon_sym_interface] = ACTIONS(5230),
    [anon_sym_checker] = ACTIONS(5230),
    [anon_sym_virtual] = ACTIONS(5230),
    [anon_sym_class] = ACTIONS(5230),
    [anon_sym_type] = ACTIONS(5230),
    [anon_sym_DOLLARfatal] = ACTIONS(5228),
    [anon_sym_DOLLARerror] = ACTIONS(5228),
    [anon_sym_DOLLARwarning] = ACTIONS(5228),
    [anon_sym_DOLLARinfo] = ACTIONS(5228),
    [anon_sym_default] = ACTIONS(5230),
    [anon_sym_clocking] = ACTIONS(5230),
    [anon_sym_defparam] = ACTIONS(5230),
    [anon_sym_bind] = ACTIONS(5230),
    [anon_sym_rand] = ACTIONS(5230),
    [anon_sym_const] = ACTIONS(5230),
    [anon_sym_function] = ACTIONS(5230),
    [anon_sym_static] = ACTIONS(5230),
    [anon_sym_constraint] = ACTIONS(5230),
    [anon_sym_if] = ACTIONS(5230),
    [anon_sym_else] = ACTIONS(5230),
    [anon_sym_LBRACK] = ACTIONS(5228),
    [anon_sym_localparam] = ACTIONS(5230),
    [anon_sym_parameter] = ACTIONS(5230),
    [anon_sym_var] = ACTIONS(5230),
    [anon_sym_import] = ACTIONS(5230),
    [anon_sym_export] = ACTIONS(5230),
    [anon_sym_genvar] = ACTIONS(5230),
    [anon_sym_interconnect] = ACTIONS(5230),
    [anon_sym_typedef] = ACTIONS(5230),
    [anon_sym_enum] = ACTIONS(5230),
    [anon_sym_struct] = ACTIONS(5230),
    [anon_sym_union] = ACTIONS(5230),
    [anon_sym_nettype] = ACTIONS(5230),
    [anon_sym_automatic] = ACTIONS(5230),
    [anon_sym_string] = ACTIONS(5230),
    [anon_sym_chandle] = ACTIONS(5230),
    [anon_sym_event] = ACTIONS(5230),
    [anon_sym_byte] = ACTIONS(5230),
    [anon_sym_shortint] = ACTIONS(5230),
    [anon_sym_int] = ACTIONS(5230),
    [anon_sym_longint] = ACTIONS(5230),
    [anon_sym_integer] = ACTIONS(5230),
    [anon_sym_time] = ACTIONS(5230),
    [anon_sym_bit] = ACTIONS(5230),
    [anon_sym_logic] = ACTIONS(5230),
    [anon_sym_reg] = ACTIONS(5230),
    [anon_sym_shortreal] = ACTIONS(5230),
    [anon_sym_real] = ACTIONS(5230),
    [anon_sym_realtime] = ACTIONS(5230),
    [anon_sym_supply0] = ACTIONS(5230),
    [anon_sym_supply1] = ACTIONS(5230),
    [anon_sym_signed] = ACTIONS(5230),
    [anon_sym_unsigned] = ACTIONS(5230),
    [anon_sym_task] = ACTIONS(5230),
    [anon_sym_assert] = ACTIONS(5230),
    [anon_sym_property] = ACTIONS(5230),
    [anon_sym_assume] = ACTIONS(5230),
    [anon_sym_cover] = ACTIONS(5230),
    [anon_sym_sequence] = ACTIONS(5230),
    [anon_sym_restrict] = ACTIONS(5230),
    [anon_sym_not] = ACTIONS(5230),
    [anon_sym_or] = ACTIONS(5230),
    [anon_sym_and] = ACTIONS(5230),
    [anon_sym_case] = ACTIONS(5230),
    [anon_sym_always] = ACTIONS(5230),
    [anon_sym_covergroup] = ACTIONS(5230),
    [anon_sym_let] = ACTIONS(5230),
    [anon_sym_pulldown] = ACTIONS(5230),
    [anon_sym_pullup] = ACTIONS(5230),
    [anon_sym_cmos] = ACTIONS(5230),
    [anon_sym_rcmos] = ACTIONS(5230),
    [anon_sym_bufif0] = ACTIONS(5230),
    [anon_sym_bufif1] = ACTIONS(5230),
    [anon_sym_notif0] = ACTIONS(5230),
    [anon_sym_notif1] = ACTIONS(5230),
    [anon_sym_nmos] = ACTIONS(5230),
    [anon_sym_pmos] = ACTIONS(5230),
    [anon_sym_rnmos] = ACTIONS(5230),
    [anon_sym_rpmos] = ACTIONS(5230),
    [anon_sym_nand] = ACTIONS(5230),
    [anon_sym_nor] = ACTIONS(5230),
    [anon_sym_xor] = ACTIONS(5230),
    [anon_sym_xnor] = ACTIONS(5230),
    [anon_sym_buf] = ACTIONS(5230),
    [anon_sym_tranif0] = ACTIONS(5230),
    [anon_sym_tranif1] = ACTIONS(5230),
    [anon_sym_rtranif1] = ACTIONS(5230),
    [anon_sym_rtranif0] = ACTIONS(5230),
    [anon_sym_tran] = ACTIONS(5230),
    [anon_sym_rtran] = ACTIONS(5230),
    [anon_sym_generate] = ACTIONS(5230),
    [anon_sym_endgenerate] = ACTIONS(5230),
    [anon_sym_for] = ACTIONS(5230),
    [anon_sym_initial] = ACTIONS(5230),
    [anon_sym_assign] = ACTIONS(5230),
    [anon_sym_alias] = ACTIONS(5230),
    [anon_sym_always_comb] = ACTIONS(5230),
    [anon_sym_always_latch] = ACTIONS(5230),
    [anon_sym_always_ff] = ACTIONS(5230),
    [anon_sym_final] = ACTIONS(5230),
    [anon_sym_global] = ACTIONS(5230),
    [anon_sym_LPAREN_STAR] = ACTIONS(5228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5228),
    [anon_sym_DOLLARunit] = ACTIONS(5228),
  },
  [4927] = {
    [sym_simple_identifier] = ACTIONS(4180),
    [anon_sym_wire] = ACTIONS(4180),
    [anon_sym_tri] = ACTIONS(4180),
    [anon_sym_tri0] = ACTIONS(4180),
    [anon_sym_tri1] = ACTIONS(4180),
    [anon_sym_wand] = ACTIONS(4180),
    [anon_sym_triand] = ACTIONS(4180),
    [anon_sym_wor] = ACTIONS(4180),
    [anon_sym_trior] = ACTIONS(4180),
    [anon_sym_trireg] = ACTIONS(4180),
    [anon_sym_uwire] = ACTIONS(4180),
    [anon_sym_SEMI] = ACTIONS(4178),
    [anon_sym_extern] = ACTIONS(4180),
    [anon_sym_interface] = ACTIONS(4180),
    [anon_sym_checker] = ACTIONS(4180),
    [anon_sym_virtual] = ACTIONS(4180),
    [anon_sym_class] = ACTIONS(4180),
    [anon_sym_type] = ACTIONS(4180),
    [anon_sym_DOLLARfatal] = ACTIONS(4178),
    [anon_sym_DOLLARerror] = ACTIONS(4178),
    [anon_sym_DOLLARwarning] = ACTIONS(4178),
    [anon_sym_DOLLARinfo] = ACTIONS(4178),
    [anon_sym_default] = ACTIONS(4180),
    [anon_sym_clocking] = ACTIONS(4180),
    [anon_sym_defparam] = ACTIONS(4180),
    [anon_sym_bind] = ACTIONS(4180),
    [anon_sym_rand] = ACTIONS(4180),
    [anon_sym_const] = ACTIONS(4180),
    [anon_sym_function] = ACTIONS(4180),
    [anon_sym_static] = ACTIONS(4180),
    [anon_sym_constraint] = ACTIONS(4180),
    [anon_sym_if] = ACTIONS(4180),
    [anon_sym_else] = ACTIONS(4180),
    [anon_sym_LBRACK] = ACTIONS(4178),
    [anon_sym_localparam] = ACTIONS(4180),
    [anon_sym_parameter] = ACTIONS(4180),
    [anon_sym_var] = ACTIONS(4180),
    [anon_sym_import] = ACTIONS(4180),
    [anon_sym_export] = ACTIONS(4180),
    [anon_sym_genvar] = ACTIONS(4180),
    [anon_sym_interconnect] = ACTIONS(4180),
    [anon_sym_typedef] = ACTIONS(4180),
    [anon_sym_enum] = ACTIONS(4180),
    [anon_sym_struct] = ACTIONS(4180),
    [anon_sym_union] = ACTIONS(4180),
    [anon_sym_nettype] = ACTIONS(4180),
    [anon_sym_automatic] = ACTIONS(4180),
    [anon_sym_string] = ACTIONS(4180),
    [anon_sym_chandle] = ACTIONS(4180),
    [anon_sym_event] = ACTIONS(4180),
    [anon_sym_byte] = ACTIONS(4180),
    [anon_sym_shortint] = ACTIONS(4180),
    [anon_sym_int] = ACTIONS(4180),
    [anon_sym_longint] = ACTIONS(4180),
    [anon_sym_integer] = ACTIONS(4180),
    [anon_sym_time] = ACTIONS(4180),
    [anon_sym_bit] = ACTIONS(4180),
    [anon_sym_logic] = ACTIONS(4180),
    [anon_sym_reg] = ACTIONS(4180),
    [anon_sym_shortreal] = ACTIONS(4180),
    [anon_sym_real] = ACTIONS(4180),
    [anon_sym_realtime] = ACTIONS(4180),
    [anon_sym_supply0] = ACTIONS(4180),
    [anon_sym_supply1] = ACTIONS(4180),
    [anon_sym_signed] = ACTIONS(4180),
    [anon_sym_unsigned] = ACTIONS(4180),
    [anon_sym_task] = ACTIONS(4180),
    [anon_sym_assert] = ACTIONS(4180),
    [anon_sym_property] = ACTIONS(4180),
    [anon_sym_assume] = ACTIONS(4180),
    [anon_sym_cover] = ACTIONS(4180),
    [anon_sym_sequence] = ACTIONS(4180),
    [anon_sym_restrict] = ACTIONS(4180),
    [anon_sym_not] = ACTIONS(4180),
    [anon_sym_or] = ACTIONS(4180),
    [anon_sym_and] = ACTIONS(4180),
    [anon_sym_case] = ACTIONS(4180),
    [anon_sym_always] = ACTIONS(4180),
    [anon_sym_covergroup] = ACTIONS(4180),
    [anon_sym_let] = ACTIONS(4180),
    [anon_sym_pulldown] = ACTIONS(4180),
    [anon_sym_pullup] = ACTIONS(4180),
    [anon_sym_cmos] = ACTIONS(4180),
    [anon_sym_rcmos] = ACTIONS(4180),
    [anon_sym_bufif0] = ACTIONS(4180),
    [anon_sym_bufif1] = ACTIONS(4180),
    [anon_sym_notif0] = ACTIONS(4180),
    [anon_sym_notif1] = ACTIONS(4180),
    [anon_sym_nmos] = ACTIONS(4180),
    [anon_sym_pmos] = ACTIONS(4180),
    [anon_sym_rnmos] = ACTIONS(4180),
    [anon_sym_rpmos] = ACTIONS(4180),
    [anon_sym_nand] = ACTIONS(4180),
    [anon_sym_nor] = ACTIONS(4180),
    [anon_sym_xor] = ACTIONS(4180),
    [anon_sym_xnor] = ACTIONS(4180),
    [anon_sym_buf] = ACTIONS(4180),
    [anon_sym_tranif0] = ACTIONS(4180),
    [anon_sym_tranif1] = ACTIONS(4180),
    [anon_sym_rtranif1] = ACTIONS(4180),
    [anon_sym_rtranif0] = ACTIONS(4180),
    [anon_sym_tran] = ACTIONS(4180),
    [anon_sym_rtran] = ACTIONS(4180),
    [anon_sym_generate] = ACTIONS(4180),
    [anon_sym_endgenerate] = ACTIONS(4180),
    [anon_sym_for] = ACTIONS(4180),
    [anon_sym_initial] = ACTIONS(4180),
    [anon_sym_assign] = ACTIONS(4180),
    [anon_sym_alias] = ACTIONS(4180),
    [anon_sym_always_comb] = ACTIONS(4180),
    [anon_sym_always_latch] = ACTIONS(4180),
    [anon_sym_always_ff] = ACTIONS(4180),
    [anon_sym_final] = ACTIONS(4180),
    [anon_sym_global] = ACTIONS(4180),
    [anon_sym_LPAREN_STAR] = ACTIONS(4178),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4178),
    [anon_sym_DOLLARunit] = ACTIONS(4178),
  },
  [4928] = {
    [sym_simple_identifier] = ACTIONS(6731),
    [anon_sym_wire] = ACTIONS(6731),
    [anon_sym_tri] = ACTIONS(6731),
    [anon_sym_tri0] = ACTIONS(6731),
    [anon_sym_tri1] = ACTIONS(6731),
    [anon_sym_wand] = ACTIONS(6731),
    [anon_sym_triand] = ACTIONS(6731),
    [anon_sym_wor] = ACTIONS(6731),
    [anon_sym_trior] = ACTIONS(6731),
    [anon_sym_trireg] = ACTIONS(6731),
    [anon_sym_uwire] = ACTIONS(6731),
    [anon_sym_SEMI] = ACTIONS(6733),
    [anon_sym_extern] = ACTIONS(6731),
    [anon_sym_interface] = ACTIONS(6731),
    [anon_sym_checker] = ACTIONS(6731),
    [anon_sym_virtual] = ACTIONS(6731),
    [anon_sym_class] = ACTIONS(6731),
    [anon_sym_type] = ACTIONS(6731),
    [anon_sym_DOLLARfatal] = ACTIONS(6733),
    [anon_sym_DOLLARerror] = ACTIONS(6733),
    [anon_sym_DOLLARwarning] = ACTIONS(6733),
    [anon_sym_DOLLARinfo] = ACTIONS(6733),
    [anon_sym_default] = ACTIONS(6731),
    [anon_sym_clocking] = ACTIONS(6731),
    [anon_sym_defparam] = ACTIONS(6731),
    [anon_sym_bind] = ACTIONS(6731),
    [anon_sym_rand] = ACTIONS(6731),
    [anon_sym_const] = ACTIONS(6731),
    [anon_sym_function] = ACTIONS(6731),
    [anon_sym_static] = ACTIONS(6731),
    [anon_sym_constraint] = ACTIONS(6731),
    [anon_sym_if] = ACTIONS(6731),
    [anon_sym_else] = ACTIONS(6731),
    [anon_sym_LBRACK] = ACTIONS(6733),
    [anon_sym_localparam] = ACTIONS(6731),
    [anon_sym_parameter] = ACTIONS(6731),
    [anon_sym_var] = ACTIONS(6731),
    [anon_sym_import] = ACTIONS(6731),
    [anon_sym_export] = ACTIONS(6731),
    [anon_sym_genvar] = ACTIONS(6731),
    [anon_sym_interconnect] = ACTIONS(6731),
    [anon_sym_typedef] = ACTIONS(6731),
    [anon_sym_enum] = ACTIONS(6731),
    [anon_sym_struct] = ACTIONS(6731),
    [anon_sym_union] = ACTIONS(6731),
    [anon_sym_nettype] = ACTIONS(6731),
    [anon_sym_automatic] = ACTIONS(6731),
    [anon_sym_string] = ACTIONS(6731),
    [anon_sym_chandle] = ACTIONS(6731),
    [anon_sym_event] = ACTIONS(6731),
    [anon_sym_byte] = ACTIONS(6731),
    [anon_sym_shortint] = ACTIONS(6731),
    [anon_sym_int] = ACTIONS(6731),
    [anon_sym_longint] = ACTIONS(6731),
    [anon_sym_integer] = ACTIONS(6731),
    [anon_sym_time] = ACTIONS(6731),
    [anon_sym_bit] = ACTIONS(6731),
    [anon_sym_logic] = ACTIONS(6731),
    [anon_sym_reg] = ACTIONS(6731),
    [anon_sym_shortreal] = ACTIONS(6731),
    [anon_sym_real] = ACTIONS(6731),
    [anon_sym_realtime] = ACTIONS(6731),
    [anon_sym_supply0] = ACTIONS(6731),
    [anon_sym_supply1] = ACTIONS(6731),
    [anon_sym_signed] = ACTIONS(6731),
    [anon_sym_unsigned] = ACTIONS(6731),
    [anon_sym_task] = ACTIONS(6731),
    [anon_sym_assert] = ACTIONS(6731),
    [anon_sym_property] = ACTIONS(6731),
    [anon_sym_assume] = ACTIONS(6731),
    [anon_sym_cover] = ACTIONS(6731),
    [anon_sym_sequence] = ACTIONS(6731),
    [anon_sym_restrict] = ACTIONS(6731),
    [anon_sym_not] = ACTIONS(6731),
    [anon_sym_or] = ACTIONS(6731),
    [anon_sym_and] = ACTIONS(6731),
    [anon_sym_case] = ACTIONS(6731),
    [anon_sym_always] = ACTIONS(6731),
    [anon_sym_covergroup] = ACTIONS(6731),
    [anon_sym_let] = ACTIONS(6731),
    [anon_sym_pulldown] = ACTIONS(6731),
    [anon_sym_pullup] = ACTIONS(6731),
    [anon_sym_cmos] = ACTIONS(6731),
    [anon_sym_rcmos] = ACTIONS(6731),
    [anon_sym_bufif0] = ACTIONS(6731),
    [anon_sym_bufif1] = ACTIONS(6731),
    [anon_sym_notif0] = ACTIONS(6731),
    [anon_sym_notif1] = ACTIONS(6731),
    [anon_sym_nmos] = ACTIONS(6731),
    [anon_sym_pmos] = ACTIONS(6731),
    [anon_sym_rnmos] = ACTIONS(6731),
    [anon_sym_rpmos] = ACTIONS(6731),
    [anon_sym_nand] = ACTIONS(6731),
    [anon_sym_nor] = ACTIONS(6731),
    [anon_sym_xor] = ACTIONS(6731),
    [anon_sym_xnor] = ACTIONS(6731),
    [anon_sym_buf] = ACTIONS(6731),
    [anon_sym_tranif0] = ACTIONS(6731),
    [anon_sym_tranif1] = ACTIONS(6731),
    [anon_sym_rtranif1] = ACTIONS(6731),
    [anon_sym_rtranif0] = ACTIONS(6731),
    [anon_sym_tran] = ACTIONS(6731),
    [anon_sym_rtran] = ACTIONS(6731),
    [anon_sym_generate] = ACTIONS(6731),
    [anon_sym_endgenerate] = ACTIONS(6731),
    [anon_sym_for] = ACTIONS(6731),
    [anon_sym_initial] = ACTIONS(6731),
    [anon_sym_assign] = ACTIONS(6731),
    [anon_sym_alias] = ACTIONS(6731),
    [anon_sym_always_comb] = ACTIONS(6731),
    [anon_sym_always_latch] = ACTIONS(6731),
    [anon_sym_always_ff] = ACTIONS(6731),
    [anon_sym_final] = ACTIONS(6731),
    [anon_sym_global] = ACTIONS(6731),
    [anon_sym_LPAREN_STAR] = ACTIONS(6733),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6733),
    [anon_sym_DOLLARunit] = ACTIONS(6733),
  },
  [4929] = {
    [sym_simple_identifier] = ACTIONS(5888),
    [anon_sym_wire] = ACTIONS(5888),
    [anon_sym_tri] = ACTIONS(5888),
    [anon_sym_tri0] = ACTIONS(5888),
    [anon_sym_tri1] = ACTIONS(5888),
    [anon_sym_wand] = ACTIONS(5888),
    [anon_sym_triand] = ACTIONS(5888),
    [anon_sym_wor] = ACTIONS(5888),
    [anon_sym_trior] = ACTIONS(5888),
    [anon_sym_trireg] = ACTIONS(5888),
    [anon_sym_uwire] = ACTIONS(5888),
    [anon_sym_SEMI] = ACTIONS(5890),
    [anon_sym_extern] = ACTIONS(5888),
    [anon_sym_interface] = ACTIONS(5888),
    [anon_sym_checker] = ACTIONS(5888),
    [anon_sym_virtual] = ACTIONS(5888),
    [anon_sym_class] = ACTIONS(5888),
    [anon_sym_type] = ACTIONS(5888),
    [anon_sym_DOLLARfatal] = ACTIONS(5890),
    [anon_sym_DOLLARerror] = ACTIONS(5890),
    [anon_sym_DOLLARwarning] = ACTIONS(5890),
    [anon_sym_DOLLARinfo] = ACTIONS(5890),
    [anon_sym_default] = ACTIONS(5888),
    [anon_sym_clocking] = ACTIONS(5888),
    [anon_sym_defparam] = ACTIONS(5888),
    [anon_sym_bind] = ACTIONS(5888),
    [anon_sym_rand] = ACTIONS(5888),
    [anon_sym_const] = ACTIONS(5888),
    [anon_sym_function] = ACTIONS(5888),
    [anon_sym_static] = ACTIONS(5888),
    [anon_sym_constraint] = ACTIONS(5888),
    [anon_sym_if] = ACTIONS(5888),
    [anon_sym_else] = ACTIONS(5888),
    [anon_sym_LBRACK] = ACTIONS(5890),
    [anon_sym_localparam] = ACTIONS(5888),
    [anon_sym_parameter] = ACTIONS(5888),
    [anon_sym_var] = ACTIONS(5888),
    [anon_sym_import] = ACTIONS(5888),
    [anon_sym_export] = ACTIONS(5888),
    [anon_sym_genvar] = ACTIONS(5888),
    [anon_sym_interconnect] = ACTIONS(5888),
    [anon_sym_typedef] = ACTIONS(5888),
    [anon_sym_enum] = ACTIONS(5888),
    [anon_sym_struct] = ACTIONS(5888),
    [anon_sym_union] = ACTIONS(5888),
    [anon_sym_nettype] = ACTIONS(5888),
    [anon_sym_automatic] = ACTIONS(5888),
    [anon_sym_string] = ACTIONS(5888),
    [anon_sym_chandle] = ACTIONS(5888),
    [anon_sym_event] = ACTIONS(5888),
    [anon_sym_byte] = ACTIONS(5888),
    [anon_sym_shortint] = ACTIONS(5888),
    [anon_sym_int] = ACTIONS(5888),
    [anon_sym_longint] = ACTIONS(5888),
    [anon_sym_integer] = ACTIONS(5888),
    [anon_sym_time] = ACTIONS(5888),
    [anon_sym_bit] = ACTIONS(5888),
    [anon_sym_logic] = ACTIONS(5888),
    [anon_sym_reg] = ACTIONS(5888),
    [anon_sym_shortreal] = ACTIONS(5888),
    [anon_sym_real] = ACTIONS(5888),
    [anon_sym_realtime] = ACTIONS(5888),
    [anon_sym_supply0] = ACTIONS(5888),
    [anon_sym_supply1] = ACTIONS(5888),
    [anon_sym_signed] = ACTIONS(5888),
    [anon_sym_unsigned] = ACTIONS(5888),
    [anon_sym_task] = ACTIONS(5888),
    [anon_sym_assert] = ACTIONS(5888),
    [anon_sym_property] = ACTIONS(5888),
    [anon_sym_assume] = ACTIONS(5888),
    [anon_sym_cover] = ACTIONS(5888),
    [anon_sym_sequence] = ACTIONS(5888),
    [anon_sym_restrict] = ACTIONS(5888),
    [anon_sym_not] = ACTIONS(5888),
    [anon_sym_or] = ACTIONS(5888),
    [anon_sym_and] = ACTIONS(5888),
    [anon_sym_case] = ACTIONS(5888),
    [anon_sym_always] = ACTIONS(5888),
    [anon_sym_covergroup] = ACTIONS(5888),
    [anon_sym_let] = ACTIONS(5888),
    [anon_sym_pulldown] = ACTIONS(5888),
    [anon_sym_pullup] = ACTIONS(5888),
    [anon_sym_cmos] = ACTIONS(5888),
    [anon_sym_rcmos] = ACTIONS(5888),
    [anon_sym_bufif0] = ACTIONS(5888),
    [anon_sym_bufif1] = ACTIONS(5888),
    [anon_sym_notif0] = ACTIONS(5888),
    [anon_sym_notif1] = ACTIONS(5888),
    [anon_sym_nmos] = ACTIONS(5888),
    [anon_sym_pmos] = ACTIONS(5888),
    [anon_sym_rnmos] = ACTIONS(5888),
    [anon_sym_rpmos] = ACTIONS(5888),
    [anon_sym_nand] = ACTIONS(5888),
    [anon_sym_nor] = ACTIONS(5888),
    [anon_sym_xor] = ACTIONS(5888),
    [anon_sym_xnor] = ACTIONS(5888),
    [anon_sym_buf] = ACTIONS(5888),
    [anon_sym_tranif0] = ACTIONS(5888),
    [anon_sym_tranif1] = ACTIONS(5888),
    [anon_sym_rtranif1] = ACTIONS(5888),
    [anon_sym_rtranif0] = ACTIONS(5888),
    [anon_sym_tran] = ACTIONS(5888),
    [anon_sym_rtran] = ACTIONS(5888),
    [anon_sym_generate] = ACTIONS(5888),
    [anon_sym_endgenerate] = ACTIONS(5888),
    [anon_sym_for] = ACTIONS(5888),
    [anon_sym_initial] = ACTIONS(5888),
    [anon_sym_assign] = ACTIONS(5888),
    [anon_sym_alias] = ACTIONS(5888),
    [anon_sym_always_comb] = ACTIONS(5888),
    [anon_sym_always_latch] = ACTIONS(5888),
    [anon_sym_always_ff] = ACTIONS(5888),
    [anon_sym_final] = ACTIONS(5888),
    [anon_sym_global] = ACTIONS(5888),
    [anon_sym_LPAREN_STAR] = ACTIONS(5890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5890),
    [anon_sym_DOLLARunit] = ACTIONS(5890),
  },
  [4930] = {
    [sym_simple_identifier] = ACTIONS(4624),
    [anon_sym_wire] = ACTIONS(4624),
    [anon_sym_tri] = ACTIONS(4624),
    [anon_sym_tri0] = ACTIONS(4624),
    [anon_sym_tri1] = ACTIONS(4624),
    [anon_sym_wand] = ACTIONS(4624),
    [anon_sym_triand] = ACTIONS(4624),
    [anon_sym_wor] = ACTIONS(4624),
    [anon_sym_trior] = ACTIONS(4624),
    [anon_sym_trireg] = ACTIONS(4624),
    [anon_sym_uwire] = ACTIONS(4624),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_extern] = ACTIONS(4624),
    [anon_sym_interface] = ACTIONS(4624),
    [anon_sym_checker] = ACTIONS(4624),
    [anon_sym_virtual] = ACTIONS(4624),
    [anon_sym_class] = ACTIONS(4624),
    [anon_sym_type] = ACTIONS(4624),
    [anon_sym_DOLLARfatal] = ACTIONS(4622),
    [anon_sym_DOLLARerror] = ACTIONS(4622),
    [anon_sym_DOLLARwarning] = ACTIONS(4622),
    [anon_sym_DOLLARinfo] = ACTIONS(4622),
    [anon_sym_default] = ACTIONS(4624),
    [anon_sym_clocking] = ACTIONS(4624),
    [anon_sym_defparam] = ACTIONS(4624),
    [anon_sym_bind] = ACTIONS(4624),
    [anon_sym_rand] = ACTIONS(4624),
    [anon_sym_const] = ACTIONS(4624),
    [anon_sym_function] = ACTIONS(4624),
    [anon_sym_static] = ACTIONS(4624),
    [anon_sym_constraint] = ACTIONS(4624),
    [anon_sym_if] = ACTIONS(4624),
    [anon_sym_else] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_localparam] = ACTIONS(4624),
    [anon_sym_parameter] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_import] = ACTIONS(4624),
    [anon_sym_export] = ACTIONS(4624),
    [anon_sym_genvar] = ACTIONS(4624),
    [anon_sym_interconnect] = ACTIONS(4624),
    [anon_sym_typedef] = ACTIONS(4624),
    [anon_sym_enum] = ACTIONS(4624),
    [anon_sym_struct] = ACTIONS(4624),
    [anon_sym_union] = ACTIONS(4624),
    [anon_sym_nettype] = ACTIONS(4624),
    [anon_sym_automatic] = ACTIONS(4624),
    [anon_sym_string] = ACTIONS(4624),
    [anon_sym_chandle] = ACTIONS(4624),
    [anon_sym_event] = ACTIONS(4624),
    [anon_sym_byte] = ACTIONS(4624),
    [anon_sym_shortint] = ACTIONS(4624),
    [anon_sym_int] = ACTIONS(4624),
    [anon_sym_longint] = ACTIONS(4624),
    [anon_sym_integer] = ACTIONS(4624),
    [anon_sym_time] = ACTIONS(4624),
    [anon_sym_bit] = ACTIONS(4624),
    [anon_sym_logic] = ACTIONS(4624),
    [anon_sym_reg] = ACTIONS(4624),
    [anon_sym_shortreal] = ACTIONS(4624),
    [anon_sym_real] = ACTIONS(4624),
    [anon_sym_realtime] = ACTIONS(4624),
    [anon_sym_supply0] = ACTIONS(4624),
    [anon_sym_supply1] = ACTIONS(4624),
    [anon_sym_signed] = ACTIONS(4624),
    [anon_sym_unsigned] = ACTIONS(4624),
    [anon_sym_task] = ACTIONS(4624),
    [anon_sym_assert] = ACTIONS(4624),
    [anon_sym_property] = ACTIONS(4624),
    [anon_sym_assume] = ACTIONS(4624),
    [anon_sym_cover] = ACTIONS(4624),
    [anon_sym_sequence] = ACTIONS(4624),
    [anon_sym_restrict] = ACTIONS(4624),
    [anon_sym_not] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_case] = ACTIONS(4624),
    [anon_sym_always] = ACTIONS(4624),
    [anon_sym_covergroup] = ACTIONS(4624),
    [anon_sym_end] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_pulldown] = ACTIONS(4624),
    [anon_sym_pullup] = ACTIONS(4624),
    [anon_sym_cmos] = ACTIONS(4624),
    [anon_sym_rcmos] = ACTIONS(4624),
    [anon_sym_bufif0] = ACTIONS(4624),
    [anon_sym_bufif1] = ACTIONS(4624),
    [anon_sym_notif0] = ACTIONS(4624),
    [anon_sym_notif1] = ACTIONS(4624),
    [anon_sym_nmos] = ACTIONS(4624),
    [anon_sym_pmos] = ACTIONS(4624),
    [anon_sym_rnmos] = ACTIONS(4624),
    [anon_sym_rpmos] = ACTIONS(4624),
    [anon_sym_nand] = ACTIONS(4624),
    [anon_sym_nor] = ACTIONS(4624),
    [anon_sym_xor] = ACTIONS(4624),
    [anon_sym_xnor] = ACTIONS(4624),
    [anon_sym_buf] = ACTIONS(4624),
    [anon_sym_tranif0] = ACTIONS(4624),
    [anon_sym_tranif1] = ACTIONS(4624),
    [anon_sym_rtranif1] = ACTIONS(4624),
    [anon_sym_rtranif0] = ACTIONS(4624),
    [anon_sym_tran] = ACTIONS(4624),
    [anon_sym_rtran] = ACTIONS(4624),
    [anon_sym_generate] = ACTIONS(4624),
    [anon_sym_for] = ACTIONS(4624),
    [anon_sym_initial] = ACTIONS(4624),
    [anon_sym_assign] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_always_comb] = ACTIONS(4624),
    [anon_sym_always_latch] = ACTIONS(4624),
    [anon_sym_always_ff] = ACTIONS(4624),
    [anon_sym_final] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LPAREN_STAR] = ACTIONS(4622),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4622),
    [anon_sym_DOLLARunit] = ACTIONS(4622),
  },
  [4931] = {
    [sym_simple_identifier] = ACTIONS(6061),
    [anon_sym_wire] = ACTIONS(6061),
    [anon_sym_tri] = ACTIONS(6061),
    [anon_sym_tri0] = ACTIONS(6061),
    [anon_sym_tri1] = ACTIONS(6061),
    [anon_sym_wand] = ACTIONS(6061),
    [anon_sym_triand] = ACTIONS(6061),
    [anon_sym_wor] = ACTIONS(6061),
    [anon_sym_trior] = ACTIONS(6061),
    [anon_sym_trireg] = ACTIONS(6061),
    [anon_sym_uwire] = ACTIONS(6061),
    [anon_sym_SEMI] = ACTIONS(6063),
    [anon_sym_extern] = ACTIONS(6061),
    [anon_sym_interface] = ACTIONS(6061),
    [anon_sym_checker] = ACTIONS(6061),
    [anon_sym_virtual] = ACTIONS(6061),
    [anon_sym_class] = ACTIONS(6061),
    [anon_sym_type] = ACTIONS(6061),
    [anon_sym_DOLLARfatal] = ACTIONS(6063),
    [anon_sym_DOLLARerror] = ACTIONS(6063),
    [anon_sym_DOLLARwarning] = ACTIONS(6063),
    [anon_sym_DOLLARinfo] = ACTIONS(6063),
    [anon_sym_default] = ACTIONS(6061),
    [anon_sym_clocking] = ACTIONS(6061),
    [anon_sym_defparam] = ACTIONS(6061),
    [anon_sym_bind] = ACTIONS(6061),
    [anon_sym_rand] = ACTIONS(6061),
    [anon_sym_const] = ACTIONS(6061),
    [anon_sym_function] = ACTIONS(6061),
    [anon_sym_static] = ACTIONS(6061),
    [anon_sym_constraint] = ACTIONS(6061),
    [anon_sym_if] = ACTIONS(6061),
    [anon_sym_else] = ACTIONS(6061),
    [anon_sym_LBRACK] = ACTIONS(6063),
    [anon_sym_localparam] = ACTIONS(6061),
    [anon_sym_parameter] = ACTIONS(6061),
    [anon_sym_var] = ACTIONS(6061),
    [anon_sym_import] = ACTIONS(6061),
    [anon_sym_export] = ACTIONS(6061),
    [anon_sym_genvar] = ACTIONS(6061),
    [anon_sym_interconnect] = ACTIONS(6061),
    [anon_sym_typedef] = ACTIONS(6061),
    [anon_sym_enum] = ACTIONS(6061),
    [anon_sym_struct] = ACTIONS(6061),
    [anon_sym_union] = ACTIONS(6061),
    [anon_sym_nettype] = ACTIONS(6061),
    [anon_sym_automatic] = ACTIONS(6061),
    [anon_sym_string] = ACTIONS(6061),
    [anon_sym_chandle] = ACTIONS(6061),
    [anon_sym_event] = ACTIONS(6061),
    [anon_sym_byte] = ACTIONS(6061),
    [anon_sym_shortint] = ACTIONS(6061),
    [anon_sym_int] = ACTIONS(6061),
    [anon_sym_longint] = ACTIONS(6061),
    [anon_sym_integer] = ACTIONS(6061),
    [anon_sym_time] = ACTIONS(6061),
    [anon_sym_bit] = ACTIONS(6061),
    [anon_sym_logic] = ACTIONS(6061),
    [anon_sym_reg] = ACTIONS(6061),
    [anon_sym_shortreal] = ACTIONS(6061),
    [anon_sym_real] = ACTIONS(6061),
    [anon_sym_realtime] = ACTIONS(6061),
    [anon_sym_supply0] = ACTIONS(6061),
    [anon_sym_supply1] = ACTIONS(6061),
    [anon_sym_signed] = ACTIONS(6061),
    [anon_sym_unsigned] = ACTIONS(6061),
    [anon_sym_task] = ACTIONS(6061),
    [anon_sym_assert] = ACTIONS(6061),
    [anon_sym_property] = ACTIONS(6061),
    [anon_sym_assume] = ACTIONS(6061),
    [anon_sym_cover] = ACTIONS(6061),
    [anon_sym_sequence] = ACTIONS(6061),
    [anon_sym_restrict] = ACTIONS(6061),
    [anon_sym_not] = ACTIONS(6061),
    [anon_sym_or] = ACTIONS(6061),
    [anon_sym_and] = ACTIONS(6061),
    [anon_sym_case] = ACTIONS(6061),
    [anon_sym_always] = ACTIONS(6061),
    [anon_sym_covergroup] = ACTIONS(6061),
    [anon_sym_let] = ACTIONS(6061),
    [anon_sym_pulldown] = ACTIONS(6061),
    [anon_sym_pullup] = ACTIONS(6061),
    [anon_sym_cmos] = ACTIONS(6061),
    [anon_sym_rcmos] = ACTIONS(6061),
    [anon_sym_bufif0] = ACTIONS(6061),
    [anon_sym_bufif1] = ACTIONS(6061),
    [anon_sym_notif0] = ACTIONS(6061),
    [anon_sym_notif1] = ACTIONS(6061),
    [anon_sym_nmos] = ACTIONS(6061),
    [anon_sym_pmos] = ACTIONS(6061),
    [anon_sym_rnmos] = ACTIONS(6061),
    [anon_sym_rpmos] = ACTIONS(6061),
    [anon_sym_nand] = ACTIONS(6061),
    [anon_sym_nor] = ACTIONS(6061),
    [anon_sym_xor] = ACTIONS(6061),
    [anon_sym_xnor] = ACTIONS(6061),
    [anon_sym_buf] = ACTIONS(6061),
    [anon_sym_tranif0] = ACTIONS(6061),
    [anon_sym_tranif1] = ACTIONS(6061),
    [anon_sym_rtranif1] = ACTIONS(6061),
    [anon_sym_rtranif0] = ACTIONS(6061),
    [anon_sym_tran] = ACTIONS(6061),
    [anon_sym_rtran] = ACTIONS(6061),
    [anon_sym_generate] = ACTIONS(6061),
    [anon_sym_endgenerate] = ACTIONS(6061),
    [anon_sym_for] = ACTIONS(6061),
    [anon_sym_initial] = ACTIONS(6061),
    [anon_sym_assign] = ACTIONS(6061),
    [anon_sym_alias] = ACTIONS(6061),
    [anon_sym_always_comb] = ACTIONS(6061),
    [anon_sym_always_latch] = ACTIONS(6061),
    [anon_sym_always_ff] = ACTIONS(6061),
    [anon_sym_final] = ACTIONS(6061),
    [anon_sym_global] = ACTIONS(6061),
    [anon_sym_LPAREN_STAR] = ACTIONS(6063),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6063),
    [anon_sym_DOLLARunit] = ACTIONS(6063),
  },
  [4932] = {
    [sym_simple_identifier] = ACTIONS(5896),
    [anon_sym_wire] = ACTIONS(5896),
    [anon_sym_tri] = ACTIONS(5896),
    [anon_sym_tri0] = ACTIONS(5896),
    [anon_sym_tri1] = ACTIONS(5896),
    [anon_sym_wand] = ACTIONS(5896),
    [anon_sym_triand] = ACTIONS(5896),
    [anon_sym_wor] = ACTIONS(5896),
    [anon_sym_trior] = ACTIONS(5896),
    [anon_sym_trireg] = ACTIONS(5896),
    [anon_sym_uwire] = ACTIONS(5896),
    [anon_sym_SEMI] = ACTIONS(5898),
    [anon_sym_extern] = ACTIONS(5896),
    [anon_sym_interface] = ACTIONS(5896),
    [anon_sym_checker] = ACTIONS(5896),
    [anon_sym_virtual] = ACTIONS(5896),
    [anon_sym_class] = ACTIONS(5896),
    [anon_sym_type] = ACTIONS(5896),
    [anon_sym_DOLLARfatal] = ACTIONS(5898),
    [anon_sym_DOLLARerror] = ACTIONS(5898),
    [anon_sym_DOLLARwarning] = ACTIONS(5898),
    [anon_sym_DOLLARinfo] = ACTIONS(5898),
    [anon_sym_default] = ACTIONS(5896),
    [anon_sym_clocking] = ACTIONS(5896),
    [anon_sym_defparam] = ACTIONS(5896),
    [anon_sym_bind] = ACTIONS(5896),
    [anon_sym_rand] = ACTIONS(5896),
    [anon_sym_const] = ACTIONS(5896),
    [anon_sym_function] = ACTIONS(5896),
    [anon_sym_static] = ACTIONS(5896),
    [anon_sym_constraint] = ACTIONS(5896),
    [anon_sym_if] = ACTIONS(5896),
    [anon_sym_else] = ACTIONS(5896),
    [anon_sym_LBRACK] = ACTIONS(5898),
    [anon_sym_localparam] = ACTIONS(5896),
    [anon_sym_parameter] = ACTIONS(5896),
    [anon_sym_var] = ACTIONS(5896),
    [anon_sym_import] = ACTIONS(5896),
    [anon_sym_export] = ACTIONS(5896),
    [anon_sym_genvar] = ACTIONS(5896),
    [anon_sym_interconnect] = ACTIONS(5896),
    [anon_sym_typedef] = ACTIONS(5896),
    [anon_sym_enum] = ACTIONS(5896),
    [anon_sym_struct] = ACTIONS(5896),
    [anon_sym_union] = ACTIONS(5896),
    [anon_sym_nettype] = ACTIONS(5896),
    [anon_sym_automatic] = ACTIONS(5896),
    [anon_sym_string] = ACTIONS(5896),
    [anon_sym_chandle] = ACTIONS(5896),
    [anon_sym_event] = ACTIONS(5896),
    [anon_sym_byte] = ACTIONS(5896),
    [anon_sym_shortint] = ACTIONS(5896),
    [anon_sym_int] = ACTIONS(5896),
    [anon_sym_longint] = ACTIONS(5896),
    [anon_sym_integer] = ACTIONS(5896),
    [anon_sym_time] = ACTIONS(5896),
    [anon_sym_bit] = ACTIONS(5896),
    [anon_sym_logic] = ACTIONS(5896),
    [anon_sym_reg] = ACTIONS(5896),
    [anon_sym_shortreal] = ACTIONS(5896),
    [anon_sym_real] = ACTIONS(5896),
    [anon_sym_realtime] = ACTIONS(5896),
    [anon_sym_supply0] = ACTIONS(5896),
    [anon_sym_supply1] = ACTIONS(5896),
    [anon_sym_signed] = ACTIONS(5896),
    [anon_sym_unsigned] = ACTIONS(5896),
    [anon_sym_task] = ACTIONS(5896),
    [anon_sym_assert] = ACTIONS(5896),
    [anon_sym_property] = ACTIONS(5896),
    [anon_sym_assume] = ACTIONS(5896),
    [anon_sym_cover] = ACTIONS(5896),
    [anon_sym_sequence] = ACTIONS(5896),
    [anon_sym_restrict] = ACTIONS(5896),
    [anon_sym_not] = ACTIONS(5896),
    [anon_sym_or] = ACTIONS(5896),
    [anon_sym_and] = ACTIONS(5896),
    [anon_sym_case] = ACTIONS(5896),
    [anon_sym_always] = ACTIONS(5896),
    [anon_sym_covergroup] = ACTIONS(5896),
    [anon_sym_let] = ACTIONS(5896),
    [anon_sym_pulldown] = ACTIONS(5896),
    [anon_sym_pullup] = ACTIONS(5896),
    [anon_sym_cmos] = ACTIONS(5896),
    [anon_sym_rcmos] = ACTIONS(5896),
    [anon_sym_bufif0] = ACTIONS(5896),
    [anon_sym_bufif1] = ACTIONS(5896),
    [anon_sym_notif0] = ACTIONS(5896),
    [anon_sym_notif1] = ACTIONS(5896),
    [anon_sym_nmos] = ACTIONS(5896),
    [anon_sym_pmos] = ACTIONS(5896),
    [anon_sym_rnmos] = ACTIONS(5896),
    [anon_sym_rpmos] = ACTIONS(5896),
    [anon_sym_nand] = ACTIONS(5896),
    [anon_sym_nor] = ACTIONS(5896),
    [anon_sym_xor] = ACTIONS(5896),
    [anon_sym_xnor] = ACTIONS(5896),
    [anon_sym_buf] = ACTIONS(5896),
    [anon_sym_tranif0] = ACTIONS(5896),
    [anon_sym_tranif1] = ACTIONS(5896),
    [anon_sym_rtranif1] = ACTIONS(5896),
    [anon_sym_rtranif0] = ACTIONS(5896),
    [anon_sym_tran] = ACTIONS(5896),
    [anon_sym_rtran] = ACTIONS(5896),
    [anon_sym_generate] = ACTIONS(5896),
    [anon_sym_endgenerate] = ACTIONS(5896),
    [anon_sym_for] = ACTIONS(5896),
    [anon_sym_initial] = ACTIONS(5896),
    [anon_sym_assign] = ACTIONS(5896),
    [anon_sym_alias] = ACTIONS(5896),
    [anon_sym_always_comb] = ACTIONS(5896),
    [anon_sym_always_latch] = ACTIONS(5896),
    [anon_sym_always_ff] = ACTIONS(5896),
    [anon_sym_final] = ACTIONS(5896),
    [anon_sym_global] = ACTIONS(5896),
    [anon_sym_LPAREN_STAR] = ACTIONS(5898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5898),
    [anon_sym_DOLLARunit] = ACTIONS(5898),
  },
  [4933] = {
    [sym_simple_identifier] = ACTIONS(5290),
    [anon_sym_wire] = ACTIONS(5290),
    [anon_sym_tri] = ACTIONS(5290),
    [anon_sym_tri0] = ACTIONS(5290),
    [anon_sym_tri1] = ACTIONS(5290),
    [anon_sym_wand] = ACTIONS(5290),
    [anon_sym_triand] = ACTIONS(5290),
    [anon_sym_wor] = ACTIONS(5290),
    [anon_sym_trior] = ACTIONS(5290),
    [anon_sym_trireg] = ACTIONS(5290),
    [anon_sym_uwire] = ACTIONS(5290),
    [anon_sym_SEMI] = ACTIONS(5288),
    [anon_sym_extern] = ACTIONS(5290),
    [anon_sym_interface] = ACTIONS(5290),
    [anon_sym_checker] = ACTIONS(5290),
    [anon_sym_virtual] = ACTIONS(5290),
    [anon_sym_class] = ACTIONS(5290),
    [anon_sym_type] = ACTIONS(5290),
    [anon_sym_DOLLARfatal] = ACTIONS(5288),
    [anon_sym_DOLLARerror] = ACTIONS(5288),
    [anon_sym_DOLLARwarning] = ACTIONS(5288),
    [anon_sym_DOLLARinfo] = ACTIONS(5288),
    [anon_sym_default] = ACTIONS(5290),
    [anon_sym_clocking] = ACTIONS(5290),
    [anon_sym_defparam] = ACTIONS(5290),
    [anon_sym_bind] = ACTIONS(5290),
    [anon_sym_rand] = ACTIONS(5290),
    [anon_sym_const] = ACTIONS(5290),
    [anon_sym_function] = ACTIONS(5290),
    [anon_sym_static] = ACTIONS(5290),
    [anon_sym_constraint] = ACTIONS(5290),
    [anon_sym_if] = ACTIONS(5290),
    [anon_sym_else] = ACTIONS(5290),
    [anon_sym_LBRACK] = ACTIONS(5288),
    [anon_sym_localparam] = ACTIONS(5290),
    [anon_sym_parameter] = ACTIONS(5290),
    [anon_sym_var] = ACTIONS(5290),
    [anon_sym_import] = ACTIONS(5290),
    [anon_sym_export] = ACTIONS(5290),
    [anon_sym_genvar] = ACTIONS(5290),
    [anon_sym_interconnect] = ACTIONS(5290),
    [anon_sym_typedef] = ACTIONS(5290),
    [anon_sym_enum] = ACTIONS(5290),
    [anon_sym_struct] = ACTIONS(5290),
    [anon_sym_union] = ACTIONS(5290),
    [anon_sym_nettype] = ACTIONS(5290),
    [anon_sym_automatic] = ACTIONS(5290),
    [anon_sym_string] = ACTIONS(5290),
    [anon_sym_chandle] = ACTIONS(5290),
    [anon_sym_event] = ACTIONS(5290),
    [anon_sym_byte] = ACTIONS(5290),
    [anon_sym_shortint] = ACTIONS(5290),
    [anon_sym_int] = ACTIONS(5290),
    [anon_sym_longint] = ACTIONS(5290),
    [anon_sym_integer] = ACTIONS(5290),
    [anon_sym_time] = ACTIONS(5290),
    [anon_sym_bit] = ACTIONS(5290),
    [anon_sym_logic] = ACTIONS(5290),
    [anon_sym_reg] = ACTIONS(5290),
    [anon_sym_shortreal] = ACTIONS(5290),
    [anon_sym_real] = ACTIONS(5290),
    [anon_sym_realtime] = ACTIONS(5290),
    [anon_sym_supply0] = ACTIONS(5290),
    [anon_sym_supply1] = ACTIONS(5290),
    [anon_sym_signed] = ACTIONS(5290),
    [anon_sym_unsigned] = ACTIONS(5290),
    [anon_sym_task] = ACTIONS(5290),
    [anon_sym_assert] = ACTIONS(5290),
    [anon_sym_property] = ACTIONS(5290),
    [anon_sym_assume] = ACTIONS(5290),
    [anon_sym_cover] = ACTIONS(5290),
    [anon_sym_sequence] = ACTIONS(5290),
    [anon_sym_restrict] = ACTIONS(5290),
    [anon_sym_not] = ACTIONS(5290),
    [anon_sym_or] = ACTIONS(5290),
    [anon_sym_and] = ACTIONS(5290),
    [anon_sym_case] = ACTIONS(5290),
    [anon_sym_always] = ACTIONS(5290),
    [anon_sym_covergroup] = ACTIONS(5290),
    [anon_sym_let] = ACTIONS(5290),
    [anon_sym_pulldown] = ACTIONS(5290),
    [anon_sym_pullup] = ACTIONS(5290),
    [anon_sym_cmos] = ACTIONS(5290),
    [anon_sym_rcmos] = ACTIONS(5290),
    [anon_sym_bufif0] = ACTIONS(5290),
    [anon_sym_bufif1] = ACTIONS(5290),
    [anon_sym_notif0] = ACTIONS(5290),
    [anon_sym_notif1] = ACTIONS(5290),
    [anon_sym_nmos] = ACTIONS(5290),
    [anon_sym_pmos] = ACTIONS(5290),
    [anon_sym_rnmos] = ACTIONS(5290),
    [anon_sym_rpmos] = ACTIONS(5290),
    [anon_sym_nand] = ACTIONS(5290),
    [anon_sym_nor] = ACTIONS(5290),
    [anon_sym_xor] = ACTIONS(5290),
    [anon_sym_xnor] = ACTIONS(5290),
    [anon_sym_buf] = ACTIONS(5290),
    [anon_sym_tranif0] = ACTIONS(5290),
    [anon_sym_tranif1] = ACTIONS(5290),
    [anon_sym_rtranif1] = ACTIONS(5290),
    [anon_sym_rtranif0] = ACTIONS(5290),
    [anon_sym_tran] = ACTIONS(5290),
    [anon_sym_rtran] = ACTIONS(5290),
    [anon_sym_generate] = ACTIONS(5290),
    [anon_sym_endgenerate] = ACTIONS(5290),
    [anon_sym_for] = ACTIONS(5290),
    [anon_sym_initial] = ACTIONS(5290),
    [anon_sym_assign] = ACTIONS(5290),
    [anon_sym_alias] = ACTIONS(5290),
    [anon_sym_always_comb] = ACTIONS(5290),
    [anon_sym_always_latch] = ACTIONS(5290),
    [anon_sym_always_ff] = ACTIONS(5290),
    [anon_sym_final] = ACTIONS(5290),
    [anon_sym_global] = ACTIONS(5290),
    [anon_sym_LPAREN_STAR] = ACTIONS(5288),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5288),
    [anon_sym_DOLLARunit] = ACTIONS(5288),
  },
  [4934] = {
    [sym_simple_identifier] = ACTIONS(5294),
    [anon_sym_wire] = ACTIONS(5294),
    [anon_sym_tri] = ACTIONS(5294),
    [anon_sym_tri0] = ACTIONS(5294),
    [anon_sym_tri1] = ACTIONS(5294),
    [anon_sym_wand] = ACTIONS(5294),
    [anon_sym_triand] = ACTIONS(5294),
    [anon_sym_wor] = ACTIONS(5294),
    [anon_sym_trior] = ACTIONS(5294),
    [anon_sym_trireg] = ACTIONS(5294),
    [anon_sym_uwire] = ACTIONS(5294),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_extern] = ACTIONS(5294),
    [anon_sym_interface] = ACTIONS(5294),
    [anon_sym_checker] = ACTIONS(5294),
    [anon_sym_virtual] = ACTIONS(5294),
    [anon_sym_class] = ACTIONS(5294),
    [anon_sym_type] = ACTIONS(5294),
    [anon_sym_DOLLARfatal] = ACTIONS(5292),
    [anon_sym_DOLLARerror] = ACTIONS(5292),
    [anon_sym_DOLLARwarning] = ACTIONS(5292),
    [anon_sym_DOLLARinfo] = ACTIONS(5292),
    [anon_sym_default] = ACTIONS(5294),
    [anon_sym_clocking] = ACTIONS(5294),
    [anon_sym_defparam] = ACTIONS(5294),
    [anon_sym_bind] = ACTIONS(5294),
    [anon_sym_rand] = ACTIONS(5294),
    [anon_sym_const] = ACTIONS(5294),
    [anon_sym_function] = ACTIONS(5294),
    [anon_sym_static] = ACTIONS(5294),
    [anon_sym_constraint] = ACTIONS(5294),
    [anon_sym_if] = ACTIONS(5294),
    [anon_sym_else] = ACTIONS(5294),
    [anon_sym_LBRACK] = ACTIONS(5292),
    [anon_sym_localparam] = ACTIONS(5294),
    [anon_sym_parameter] = ACTIONS(5294),
    [anon_sym_var] = ACTIONS(5294),
    [anon_sym_import] = ACTIONS(5294),
    [anon_sym_export] = ACTIONS(5294),
    [anon_sym_genvar] = ACTIONS(5294),
    [anon_sym_interconnect] = ACTIONS(5294),
    [anon_sym_typedef] = ACTIONS(5294),
    [anon_sym_enum] = ACTIONS(5294),
    [anon_sym_struct] = ACTIONS(5294),
    [anon_sym_union] = ACTIONS(5294),
    [anon_sym_nettype] = ACTIONS(5294),
    [anon_sym_automatic] = ACTIONS(5294),
    [anon_sym_string] = ACTIONS(5294),
    [anon_sym_chandle] = ACTIONS(5294),
    [anon_sym_event] = ACTIONS(5294),
    [anon_sym_byte] = ACTIONS(5294),
    [anon_sym_shortint] = ACTIONS(5294),
    [anon_sym_int] = ACTIONS(5294),
    [anon_sym_longint] = ACTIONS(5294),
    [anon_sym_integer] = ACTIONS(5294),
    [anon_sym_time] = ACTIONS(5294),
    [anon_sym_bit] = ACTIONS(5294),
    [anon_sym_logic] = ACTIONS(5294),
    [anon_sym_reg] = ACTIONS(5294),
    [anon_sym_shortreal] = ACTIONS(5294),
    [anon_sym_real] = ACTIONS(5294),
    [anon_sym_realtime] = ACTIONS(5294),
    [anon_sym_supply0] = ACTIONS(5294),
    [anon_sym_supply1] = ACTIONS(5294),
    [anon_sym_signed] = ACTIONS(5294),
    [anon_sym_unsigned] = ACTIONS(5294),
    [anon_sym_task] = ACTIONS(5294),
    [anon_sym_assert] = ACTIONS(5294),
    [anon_sym_property] = ACTIONS(5294),
    [anon_sym_assume] = ACTIONS(5294),
    [anon_sym_cover] = ACTIONS(5294),
    [anon_sym_sequence] = ACTIONS(5294),
    [anon_sym_restrict] = ACTIONS(5294),
    [anon_sym_not] = ACTIONS(5294),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_and] = ACTIONS(5294),
    [anon_sym_case] = ACTIONS(5294),
    [anon_sym_always] = ACTIONS(5294),
    [anon_sym_covergroup] = ACTIONS(5294),
    [anon_sym_let] = ACTIONS(5294),
    [anon_sym_pulldown] = ACTIONS(5294),
    [anon_sym_pullup] = ACTIONS(5294),
    [anon_sym_cmos] = ACTIONS(5294),
    [anon_sym_rcmos] = ACTIONS(5294),
    [anon_sym_bufif0] = ACTIONS(5294),
    [anon_sym_bufif1] = ACTIONS(5294),
    [anon_sym_notif0] = ACTIONS(5294),
    [anon_sym_notif1] = ACTIONS(5294),
    [anon_sym_nmos] = ACTIONS(5294),
    [anon_sym_pmos] = ACTIONS(5294),
    [anon_sym_rnmos] = ACTIONS(5294),
    [anon_sym_rpmos] = ACTIONS(5294),
    [anon_sym_nand] = ACTIONS(5294),
    [anon_sym_nor] = ACTIONS(5294),
    [anon_sym_xor] = ACTIONS(5294),
    [anon_sym_xnor] = ACTIONS(5294),
    [anon_sym_buf] = ACTIONS(5294),
    [anon_sym_tranif0] = ACTIONS(5294),
    [anon_sym_tranif1] = ACTIONS(5294),
    [anon_sym_rtranif1] = ACTIONS(5294),
    [anon_sym_rtranif0] = ACTIONS(5294),
    [anon_sym_tran] = ACTIONS(5294),
    [anon_sym_rtran] = ACTIONS(5294),
    [anon_sym_generate] = ACTIONS(5294),
    [anon_sym_endgenerate] = ACTIONS(5294),
    [anon_sym_for] = ACTIONS(5294),
    [anon_sym_initial] = ACTIONS(5294),
    [anon_sym_assign] = ACTIONS(5294),
    [anon_sym_alias] = ACTIONS(5294),
    [anon_sym_always_comb] = ACTIONS(5294),
    [anon_sym_always_latch] = ACTIONS(5294),
    [anon_sym_always_ff] = ACTIONS(5294),
    [anon_sym_final] = ACTIONS(5294),
    [anon_sym_global] = ACTIONS(5294),
    [anon_sym_LPAREN_STAR] = ACTIONS(5292),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5292),
    [anon_sym_DOLLARunit] = ACTIONS(5292),
  },
  [4935] = {
    [sym_simple_identifier] = ACTIONS(6755),
    [anon_sym_wire] = ACTIONS(6755),
    [anon_sym_tri] = ACTIONS(6755),
    [anon_sym_tri0] = ACTIONS(6755),
    [anon_sym_tri1] = ACTIONS(6755),
    [anon_sym_wand] = ACTIONS(6755),
    [anon_sym_triand] = ACTIONS(6755),
    [anon_sym_wor] = ACTIONS(6755),
    [anon_sym_trior] = ACTIONS(6755),
    [anon_sym_trireg] = ACTIONS(6755),
    [anon_sym_uwire] = ACTIONS(6755),
    [anon_sym_SEMI] = ACTIONS(6757),
    [anon_sym_extern] = ACTIONS(6755),
    [anon_sym_interface] = ACTIONS(6755),
    [anon_sym_checker] = ACTIONS(6755),
    [anon_sym_virtual] = ACTIONS(6755),
    [anon_sym_class] = ACTIONS(6755),
    [anon_sym_type] = ACTIONS(6755),
    [anon_sym_DOLLARfatal] = ACTIONS(6757),
    [anon_sym_DOLLARerror] = ACTIONS(6757),
    [anon_sym_DOLLARwarning] = ACTIONS(6757),
    [anon_sym_DOLLARinfo] = ACTIONS(6757),
    [anon_sym_default] = ACTIONS(6755),
    [anon_sym_clocking] = ACTIONS(6755),
    [anon_sym_defparam] = ACTIONS(6755),
    [anon_sym_bind] = ACTIONS(6755),
    [anon_sym_rand] = ACTIONS(6755),
    [anon_sym_const] = ACTIONS(6755),
    [anon_sym_function] = ACTIONS(6755),
    [anon_sym_static] = ACTIONS(6755),
    [anon_sym_constraint] = ACTIONS(6755),
    [anon_sym_if] = ACTIONS(6755),
    [anon_sym_else] = ACTIONS(6755),
    [anon_sym_LBRACK] = ACTIONS(6757),
    [anon_sym_localparam] = ACTIONS(6755),
    [anon_sym_parameter] = ACTIONS(6755),
    [anon_sym_var] = ACTIONS(6755),
    [anon_sym_import] = ACTIONS(6755),
    [anon_sym_export] = ACTIONS(6755),
    [anon_sym_genvar] = ACTIONS(6755),
    [anon_sym_interconnect] = ACTIONS(6755),
    [anon_sym_typedef] = ACTIONS(6755),
    [anon_sym_enum] = ACTIONS(6755),
    [anon_sym_struct] = ACTIONS(6755),
    [anon_sym_union] = ACTIONS(6755),
    [anon_sym_nettype] = ACTIONS(6755),
    [anon_sym_automatic] = ACTIONS(6755),
    [anon_sym_string] = ACTIONS(6755),
    [anon_sym_chandle] = ACTIONS(6755),
    [anon_sym_event] = ACTIONS(6755),
    [anon_sym_byte] = ACTIONS(6755),
    [anon_sym_shortint] = ACTIONS(6755),
    [anon_sym_int] = ACTIONS(6755),
    [anon_sym_longint] = ACTIONS(6755),
    [anon_sym_integer] = ACTIONS(6755),
    [anon_sym_time] = ACTIONS(6755),
    [anon_sym_bit] = ACTIONS(6755),
    [anon_sym_logic] = ACTIONS(6755),
    [anon_sym_reg] = ACTIONS(6755),
    [anon_sym_shortreal] = ACTIONS(6755),
    [anon_sym_real] = ACTIONS(6755),
    [anon_sym_realtime] = ACTIONS(6755),
    [anon_sym_supply0] = ACTIONS(6755),
    [anon_sym_supply1] = ACTIONS(6755),
    [anon_sym_signed] = ACTIONS(6755),
    [anon_sym_unsigned] = ACTIONS(6755),
    [anon_sym_task] = ACTIONS(6755),
    [anon_sym_assert] = ACTIONS(6755),
    [anon_sym_property] = ACTIONS(6755),
    [anon_sym_assume] = ACTIONS(6755),
    [anon_sym_cover] = ACTIONS(6755),
    [anon_sym_sequence] = ACTIONS(6755),
    [anon_sym_restrict] = ACTIONS(6755),
    [anon_sym_not] = ACTIONS(6755),
    [anon_sym_or] = ACTIONS(6755),
    [anon_sym_and] = ACTIONS(6755),
    [anon_sym_case] = ACTIONS(6755),
    [anon_sym_always] = ACTIONS(6755),
    [anon_sym_covergroup] = ACTIONS(6755),
    [anon_sym_end] = ACTIONS(6755),
    [anon_sym_let] = ACTIONS(6755),
    [anon_sym_pulldown] = ACTIONS(6755),
    [anon_sym_pullup] = ACTIONS(6755),
    [anon_sym_cmos] = ACTIONS(6755),
    [anon_sym_rcmos] = ACTIONS(6755),
    [anon_sym_bufif0] = ACTIONS(6755),
    [anon_sym_bufif1] = ACTIONS(6755),
    [anon_sym_notif0] = ACTIONS(6755),
    [anon_sym_notif1] = ACTIONS(6755),
    [anon_sym_nmos] = ACTIONS(6755),
    [anon_sym_pmos] = ACTIONS(6755),
    [anon_sym_rnmos] = ACTIONS(6755),
    [anon_sym_rpmos] = ACTIONS(6755),
    [anon_sym_nand] = ACTIONS(6755),
    [anon_sym_nor] = ACTIONS(6755),
    [anon_sym_xor] = ACTIONS(6755),
    [anon_sym_xnor] = ACTIONS(6755),
    [anon_sym_buf] = ACTIONS(6755),
    [anon_sym_tranif0] = ACTIONS(6755),
    [anon_sym_tranif1] = ACTIONS(6755),
    [anon_sym_rtranif1] = ACTIONS(6755),
    [anon_sym_rtranif0] = ACTIONS(6755),
    [anon_sym_tran] = ACTIONS(6755),
    [anon_sym_rtran] = ACTIONS(6755),
    [anon_sym_generate] = ACTIONS(6755),
    [anon_sym_for] = ACTIONS(6755),
    [anon_sym_initial] = ACTIONS(6755),
    [anon_sym_assign] = ACTIONS(6755),
    [anon_sym_alias] = ACTIONS(6755),
    [anon_sym_always_comb] = ACTIONS(6755),
    [anon_sym_always_latch] = ACTIONS(6755),
    [anon_sym_always_ff] = ACTIONS(6755),
    [anon_sym_final] = ACTIONS(6755),
    [anon_sym_global] = ACTIONS(6755),
    [anon_sym_LPAREN_STAR] = ACTIONS(6757),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6757),
    [anon_sym_DOLLARunit] = ACTIONS(6757),
  },
  [4936] = {
    [sym_simple_identifier] = ACTIONS(5298),
    [anon_sym_wire] = ACTIONS(5298),
    [anon_sym_tri] = ACTIONS(5298),
    [anon_sym_tri0] = ACTIONS(5298),
    [anon_sym_tri1] = ACTIONS(5298),
    [anon_sym_wand] = ACTIONS(5298),
    [anon_sym_triand] = ACTIONS(5298),
    [anon_sym_wor] = ACTIONS(5298),
    [anon_sym_trior] = ACTIONS(5298),
    [anon_sym_trireg] = ACTIONS(5298),
    [anon_sym_uwire] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_extern] = ACTIONS(5298),
    [anon_sym_interface] = ACTIONS(5298),
    [anon_sym_checker] = ACTIONS(5298),
    [anon_sym_virtual] = ACTIONS(5298),
    [anon_sym_class] = ACTIONS(5298),
    [anon_sym_type] = ACTIONS(5298),
    [anon_sym_DOLLARfatal] = ACTIONS(5296),
    [anon_sym_DOLLARerror] = ACTIONS(5296),
    [anon_sym_DOLLARwarning] = ACTIONS(5296),
    [anon_sym_DOLLARinfo] = ACTIONS(5296),
    [anon_sym_default] = ACTIONS(5298),
    [anon_sym_clocking] = ACTIONS(5298),
    [anon_sym_defparam] = ACTIONS(5298),
    [anon_sym_bind] = ACTIONS(5298),
    [anon_sym_rand] = ACTIONS(5298),
    [anon_sym_const] = ACTIONS(5298),
    [anon_sym_function] = ACTIONS(5298),
    [anon_sym_static] = ACTIONS(5298),
    [anon_sym_constraint] = ACTIONS(5298),
    [anon_sym_if] = ACTIONS(5298),
    [anon_sym_else] = ACTIONS(5298),
    [anon_sym_LBRACK] = ACTIONS(5296),
    [anon_sym_localparam] = ACTIONS(5298),
    [anon_sym_parameter] = ACTIONS(5298),
    [anon_sym_var] = ACTIONS(5298),
    [anon_sym_import] = ACTIONS(5298),
    [anon_sym_export] = ACTIONS(5298),
    [anon_sym_genvar] = ACTIONS(5298),
    [anon_sym_interconnect] = ACTIONS(5298),
    [anon_sym_typedef] = ACTIONS(5298),
    [anon_sym_enum] = ACTIONS(5298),
    [anon_sym_struct] = ACTIONS(5298),
    [anon_sym_union] = ACTIONS(5298),
    [anon_sym_nettype] = ACTIONS(5298),
    [anon_sym_automatic] = ACTIONS(5298),
    [anon_sym_string] = ACTIONS(5298),
    [anon_sym_chandle] = ACTIONS(5298),
    [anon_sym_event] = ACTIONS(5298),
    [anon_sym_byte] = ACTIONS(5298),
    [anon_sym_shortint] = ACTIONS(5298),
    [anon_sym_int] = ACTIONS(5298),
    [anon_sym_longint] = ACTIONS(5298),
    [anon_sym_integer] = ACTIONS(5298),
    [anon_sym_time] = ACTIONS(5298),
    [anon_sym_bit] = ACTIONS(5298),
    [anon_sym_logic] = ACTIONS(5298),
    [anon_sym_reg] = ACTIONS(5298),
    [anon_sym_shortreal] = ACTIONS(5298),
    [anon_sym_real] = ACTIONS(5298),
    [anon_sym_realtime] = ACTIONS(5298),
    [anon_sym_supply0] = ACTIONS(5298),
    [anon_sym_supply1] = ACTIONS(5298),
    [anon_sym_signed] = ACTIONS(5298),
    [anon_sym_unsigned] = ACTIONS(5298),
    [anon_sym_task] = ACTIONS(5298),
    [anon_sym_assert] = ACTIONS(5298),
    [anon_sym_property] = ACTIONS(5298),
    [anon_sym_assume] = ACTIONS(5298),
    [anon_sym_cover] = ACTIONS(5298),
    [anon_sym_sequence] = ACTIONS(5298),
    [anon_sym_restrict] = ACTIONS(5298),
    [anon_sym_not] = ACTIONS(5298),
    [anon_sym_or] = ACTIONS(5298),
    [anon_sym_and] = ACTIONS(5298),
    [anon_sym_case] = ACTIONS(5298),
    [anon_sym_always] = ACTIONS(5298),
    [anon_sym_covergroup] = ACTIONS(5298),
    [anon_sym_let] = ACTIONS(5298),
    [anon_sym_pulldown] = ACTIONS(5298),
    [anon_sym_pullup] = ACTIONS(5298),
    [anon_sym_cmos] = ACTIONS(5298),
    [anon_sym_rcmos] = ACTIONS(5298),
    [anon_sym_bufif0] = ACTIONS(5298),
    [anon_sym_bufif1] = ACTIONS(5298),
    [anon_sym_notif0] = ACTIONS(5298),
    [anon_sym_notif1] = ACTIONS(5298),
    [anon_sym_nmos] = ACTIONS(5298),
    [anon_sym_pmos] = ACTIONS(5298),
    [anon_sym_rnmos] = ACTIONS(5298),
    [anon_sym_rpmos] = ACTIONS(5298),
    [anon_sym_nand] = ACTIONS(5298),
    [anon_sym_nor] = ACTIONS(5298),
    [anon_sym_xor] = ACTIONS(5298),
    [anon_sym_xnor] = ACTIONS(5298),
    [anon_sym_buf] = ACTIONS(5298),
    [anon_sym_tranif0] = ACTIONS(5298),
    [anon_sym_tranif1] = ACTIONS(5298),
    [anon_sym_rtranif1] = ACTIONS(5298),
    [anon_sym_rtranif0] = ACTIONS(5298),
    [anon_sym_tran] = ACTIONS(5298),
    [anon_sym_rtran] = ACTIONS(5298),
    [anon_sym_generate] = ACTIONS(5298),
    [anon_sym_endgenerate] = ACTIONS(5298),
    [anon_sym_for] = ACTIONS(5298),
    [anon_sym_initial] = ACTIONS(5298),
    [anon_sym_assign] = ACTIONS(5298),
    [anon_sym_alias] = ACTIONS(5298),
    [anon_sym_always_comb] = ACTIONS(5298),
    [anon_sym_always_latch] = ACTIONS(5298),
    [anon_sym_always_ff] = ACTIONS(5298),
    [anon_sym_final] = ACTIONS(5298),
    [anon_sym_global] = ACTIONS(5298),
    [anon_sym_LPAREN_STAR] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5296),
    [anon_sym_DOLLARunit] = ACTIONS(5296),
  },
  [4937] = {
    [sym_simple_identifier] = ACTIONS(6065),
    [anon_sym_wire] = ACTIONS(6065),
    [anon_sym_tri] = ACTIONS(6065),
    [anon_sym_tri0] = ACTIONS(6065),
    [anon_sym_tri1] = ACTIONS(6065),
    [anon_sym_wand] = ACTIONS(6065),
    [anon_sym_triand] = ACTIONS(6065),
    [anon_sym_wor] = ACTIONS(6065),
    [anon_sym_trior] = ACTIONS(6065),
    [anon_sym_trireg] = ACTIONS(6065),
    [anon_sym_uwire] = ACTIONS(6065),
    [anon_sym_SEMI] = ACTIONS(6067),
    [anon_sym_extern] = ACTIONS(6065),
    [anon_sym_interface] = ACTIONS(6065),
    [anon_sym_checker] = ACTIONS(6065),
    [anon_sym_virtual] = ACTIONS(6065),
    [anon_sym_class] = ACTIONS(6065),
    [anon_sym_type] = ACTIONS(6065),
    [anon_sym_DOLLARfatal] = ACTIONS(6067),
    [anon_sym_DOLLARerror] = ACTIONS(6067),
    [anon_sym_DOLLARwarning] = ACTIONS(6067),
    [anon_sym_DOLLARinfo] = ACTIONS(6067),
    [anon_sym_default] = ACTIONS(6065),
    [anon_sym_clocking] = ACTIONS(6065),
    [anon_sym_defparam] = ACTIONS(6065),
    [anon_sym_bind] = ACTIONS(6065),
    [anon_sym_rand] = ACTIONS(6065),
    [anon_sym_const] = ACTIONS(6065),
    [anon_sym_function] = ACTIONS(6065),
    [anon_sym_static] = ACTIONS(6065),
    [anon_sym_constraint] = ACTIONS(6065),
    [anon_sym_if] = ACTIONS(6065),
    [anon_sym_else] = ACTIONS(6065),
    [anon_sym_LBRACK] = ACTIONS(6067),
    [anon_sym_localparam] = ACTIONS(6065),
    [anon_sym_parameter] = ACTIONS(6065),
    [anon_sym_var] = ACTIONS(6065),
    [anon_sym_import] = ACTIONS(6065),
    [anon_sym_export] = ACTIONS(6065),
    [anon_sym_genvar] = ACTIONS(6065),
    [anon_sym_interconnect] = ACTIONS(6065),
    [anon_sym_typedef] = ACTIONS(6065),
    [anon_sym_enum] = ACTIONS(6065),
    [anon_sym_struct] = ACTIONS(6065),
    [anon_sym_union] = ACTIONS(6065),
    [anon_sym_nettype] = ACTIONS(6065),
    [anon_sym_automatic] = ACTIONS(6065),
    [anon_sym_string] = ACTIONS(6065),
    [anon_sym_chandle] = ACTIONS(6065),
    [anon_sym_event] = ACTIONS(6065),
    [anon_sym_byte] = ACTIONS(6065),
    [anon_sym_shortint] = ACTIONS(6065),
    [anon_sym_int] = ACTIONS(6065),
    [anon_sym_longint] = ACTIONS(6065),
    [anon_sym_integer] = ACTIONS(6065),
    [anon_sym_time] = ACTIONS(6065),
    [anon_sym_bit] = ACTIONS(6065),
    [anon_sym_logic] = ACTIONS(6065),
    [anon_sym_reg] = ACTIONS(6065),
    [anon_sym_shortreal] = ACTIONS(6065),
    [anon_sym_real] = ACTIONS(6065),
    [anon_sym_realtime] = ACTIONS(6065),
    [anon_sym_supply0] = ACTIONS(6065),
    [anon_sym_supply1] = ACTIONS(6065),
    [anon_sym_signed] = ACTIONS(6065),
    [anon_sym_unsigned] = ACTIONS(6065),
    [anon_sym_task] = ACTIONS(6065),
    [anon_sym_assert] = ACTIONS(6065),
    [anon_sym_property] = ACTIONS(6065),
    [anon_sym_assume] = ACTIONS(6065),
    [anon_sym_cover] = ACTIONS(6065),
    [anon_sym_sequence] = ACTIONS(6065),
    [anon_sym_restrict] = ACTIONS(6065),
    [anon_sym_not] = ACTIONS(6065),
    [anon_sym_or] = ACTIONS(6065),
    [anon_sym_and] = ACTIONS(6065),
    [anon_sym_case] = ACTIONS(6065),
    [anon_sym_always] = ACTIONS(6065),
    [anon_sym_covergroup] = ACTIONS(6065),
    [anon_sym_let] = ACTIONS(6065),
    [anon_sym_pulldown] = ACTIONS(6065),
    [anon_sym_pullup] = ACTIONS(6065),
    [anon_sym_cmos] = ACTIONS(6065),
    [anon_sym_rcmos] = ACTIONS(6065),
    [anon_sym_bufif0] = ACTIONS(6065),
    [anon_sym_bufif1] = ACTIONS(6065),
    [anon_sym_notif0] = ACTIONS(6065),
    [anon_sym_notif1] = ACTIONS(6065),
    [anon_sym_nmos] = ACTIONS(6065),
    [anon_sym_pmos] = ACTIONS(6065),
    [anon_sym_rnmos] = ACTIONS(6065),
    [anon_sym_rpmos] = ACTIONS(6065),
    [anon_sym_nand] = ACTIONS(6065),
    [anon_sym_nor] = ACTIONS(6065),
    [anon_sym_xor] = ACTIONS(6065),
    [anon_sym_xnor] = ACTIONS(6065),
    [anon_sym_buf] = ACTIONS(6065),
    [anon_sym_tranif0] = ACTIONS(6065),
    [anon_sym_tranif1] = ACTIONS(6065),
    [anon_sym_rtranif1] = ACTIONS(6065),
    [anon_sym_rtranif0] = ACTIONS(6065),
    [anon_sym_tran] = ACTIONS(6065),
    [anon_sym_rtran] = ACTIONS(6065),
    [anon_sym_generate] = ACTIONS(6065),
    [anon_sym_endgenerate] = ACTIONS(6065),
    [anon_sym_for] = ACTIONS(6065),
    [anon_sym_initial] = ACTIONS(6065),
    [anon_sym_assign] = ACTIONS(6065),
    [anon_sym_alias] = ACTIONS(6065),
    [anon_sym_always_comb] = ACTIONS(6065),
    [anon_sym_always_latch] = ACTIONS(6065),
    [anon_sym_always_ff] = ACTIONS(6065),
    [anon_sym_final] = ACTIONS(6065),
    [anon_sym_global] = ACTIONS(6065),
    [anon_sym_LPAREN_STAR] = ACTIONS(6067),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6067),
    [anon_sym_DOLLARunit] = ACTIONS(6067),
  },
  [4938] = {
    [sym_simple_identifier] = ACTIONS(6433),
    [anon_sym_wire] = ACTIONS(6433),
    [anon_sym_tri] = ACTIONS(6433),
    [anon_sym_tri0] = ACTIONS(6433),
    [anon_sym_tri1] = ACTIONS(6433),
    [anon_sym_wand] = ACTIONS(6433),
    [anon_sym_triand] = ACTIONS(6433),
    [anon_sym_wor] = ACTIONS(6433),
    [anon_sym_trior] = ACTIONS(6433),
    [anon_sym_trireg] = ACTIONS(6433),
    [anon_sym_uwire] = ACTIONS(6433),
    [anon_sym_SEMI] = ACTIONS(6435),
    [anon_sym_extern] = ACTIONS(6433),
    [anon_sym_interface] = ACTIONS(6433),
    [anon_sym_checker] = ACTIONS(6433),
    [anon_sym_virtual] = ACTIONS(6433),
    [anon_sym_class] = ACTIONS(6433),
    [anon_sym_type] = ACTIONS(6433),
    [anon_sym_DOLLARfatal] = ACTIONS(6435),
    [anon_sym_DOLLARerror] = ACTIONS(6435),
    [anon_sym_DOLLARwarning] = ACTIONS(6435),
    [anon_sym_DOLLARinfo] = ACTIONS(6435),
    [anon_sym_default] = ACTIONS(6433),
    [anon_sym_clocking] = ACTIONS(6433),
    [anon_sym_defparam] = ACTIONS(6433),
    [anon_sym_bind] = ACTIONS(6433),
    [anon_sym_rand] = ACTIONS(6433),
    [anon_sym_const] = ACTIONS(6433),
    [anon_sym_function] = ACTIONS(6433),
    [anon_sym_static] = ACTIONS(6433),
    [anon_sym_constraint] = ACTIONS(6433),
    [anon_sym_if] = ACTIONS(6433),
    [anon_sym_else] = ACTIONS(6433),
    [anon_sym_LBRACK] = ACTIONS(6435),
    [anon_sym_localparam] = ACTIONS(6433),
    [anon_sym_parameter] = ACTIONS(6433),
    [anon_sym_var] = ACTIONS(6433),
    [anon_sym_import] = ACTIONS(6433),
    [anon_sym_export] = ACTIONS(6433),
    [anon_sym_genvar] = ACTIONS(6433),
    [anon_sym_interconnect] = ACTIONS(6433),
    [anon_sym_typedef] = ACTIONS(6433),
    [anon_sym_enum] = ACTIONS(6433),
    [anon_sym_struct] = ACTIONS(6433),
    [anon_sym_union] = ACTIONS(6433),
    [anon_sym_nettype] = ACTIONS(6433),
    [anon_sym_automatic] = ACTIONS(6433),
    [anon_sym_string] = ACTIONS(6433),
    [anon_sym_chandle] = ACTIONS(6433),
    [anon_sym_event] = ACTIONS(6433),
    [anon_sym_byte] = ACTIONS(6433),
    [anon_sym_shortint] = ACTIONS(6433),
    [anon_sym_int] = ACTIONS(6433),
    [anon_sym_longint] = ACTIONS(6433),
    [anon_sym_integer] = ACTIONS(6433),
    [anon_sym_time] = ACTIONS(6433),
    [anon_sym_bit] = ACTIONS(6433),
    [anon_sym_logic] = ACTIONS(6433),
    [anon_sym_reg] = ACTIONS(6433),
    [anon_sym_shortreal] = ACTIONS(6433),
    [anon_sym_real] = ACTIONS(6433),
    [anon_sym_realtime] = ACTIONS(6433),
    [anon_sym_supply0] = ACTIONS(6433),
    [anon_sym_supply1] = ACTIONS(6433),
    [anon_sym_signed] = ACTIONS(6433),
    [anon_sym_unsigned] = ACTIONS(6433),
    [anon_sym_task] = ACTIONS(6433),
    [anon_sym_assert] = ACTIONS(6433),
    [anon_sym_property] = ACTIONS(6433),
    [anon_sym_assume] = ACTIONS(6433),
    [anon_sym_cover] = ACTIONS(6433),
    [anon_sym_sequence] = ACTIONS(6433),
    [anon_sym_restrict] = ACTIONS(6433),
    [anon_sym_not] = ACTIONS(6433),
    [anon_sym_or] = ACTIONS(6433),
    [anon_sym_and] = ACTIONS(6433),
    [anon_sym_case] = ACTIONS(6433),
    [anon_sym_always] = ACTIONS(6433),
    [anon_sym_covergroup] = ACTIONS(6433),
    [anon_sym_end] = ACTIONS(6433),
    [anon_sym_let] = ACTIONS(6433),
    [anon_sym_pulldown] = ACTIONS(6433),
    [anon_sym_pullup] = ACTIONS(6433),
    [anon_sym_cmos] = ACTIONS(6433),
    [anon_sym_rcmos] = ACTIONS(6433),
    [anon_sym_bufif0] = ACTIONS(6433),
    [anon_sym_bufif1] = ACTIONS(6433),
    [anon_sym_notif0] = ACTIONS(6433),
    [anon_sym_notif1] = ACTIONS(6433),
    [anon_sym_nmos] = ACTIONS(6433),
    [anon_sym_pmos] = ACTIONS(6433),
    [anon_sym_rnmos] = ACTIONS(6433),
    [anon_sym_rpmos] = ACTIONS(6433),
    [anon_sym_nand] = ACTIONS(6433),
    [anon_sym_nor] = ACTIONS(6433),
    [anon_sym_xor] = ACTIONS(6433),
    [anon_sym_xnor] = ACTIONS(6433),
    [anon_sym_buf] = ACTIONS(6433),
    [anon_sym_tranif0] = ACTIONS(6433),
    [anon_sym_tranif1] = ACTIONS(6433),
    [anon_sym_rtranif1] = ACTIONS(6433),
    [anon_sym_rtranif0] = ACTIONS(6433),
    [anon_sym_tran] = ACTIONS(6433),
    [anon_sym_rtran] = ACTIONS(6433),
    [anon_sym_generate] = ACTIONS(6433),
    [anon_sym_for] = ACTIONS(6433),
    [anon_sym_initial] = ACTIONS(6433),
    [anon_sym_assign] = ACTIONS(6433),
    [anon_sym_alias] = ACTIONS(6433),
    [anon_sym_always_comb] = ACTIONS(6433),
    [anon_sym_always_latch] = ACTIONS(6433),
    [anon_sym_always_ff] = ACTIONS(6433),
    [anon_sym_final] = ACTIONS(6433),
    [anon_sym_global] = ACTIONS(6433),
    [anon_sym_LPAREN_STAR] = ACTIONS(6435),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6435),
    [anon_sym_DOLLARunit] = ACTIONS(6435),
  },
  [4939] = {
    [sym_simple_identifier] = ACTIONS(4960),
    [anon_sym_wire] = ACTIONS(4960),
    [anon_sym_tri] = ACTIONS(4960),
    [anon_sym_tri0] = ACTIONS(4960),
    [anon_sym_tri1] = ACTIONS(4960),
    [anon_sym_wand] = ACTIONS(4960),
    [anon_sym_triand] = ACTIONS(4960),
    [anon_sym_wor] = ACTIONS(4960),
    [anon_sym_trior] = ACTIONS(4960),
    [anon_sym_trireg] = ACTIONS(4960),
    [anon_sym_uwire] = ACTIONS(4960),
    [anon_sym_SEMI] = ACTIONS(4958),
    [anon_sym_extern] = ACTIONS(4960),
    [anon_sym_interface] = ACTIONS(4960),
    [anon_sym_checker] = ACTIONS(4960),
    [anon_sym_virtual] = ACTIONS(4960),
    [anon_sym_class] = ACTIONS(4960),
    [anon_sym_type] = ACTIONS(4960),
    [anon_sym_DOLLARfatal] = ACTIONS(4958),
    [anon_sym_DOLLARerror] = ACTIONS(4958),
    [anon_sym_DOLLARwarning] = ACTIONS(4958),
    [anon_sym_DOLLARinfo] = ACTIONS(4958),
    [anon_sym_default] = ACTIONS(4960),
    [anon_sym_clocking] = ACTIONS(4960),
    [anon_sym_defparam] = ACTIONS(4960),
    [anon_sym_bind] = ACTIONS(4960),
    [anon_sym_rand] = ACTIONS(4960),
    [anon_sym_const] = ACTIONS(4960),
    [anon_sym_function] = ACTIONS(4960),
    [anon_sym_static] = ACTIONS(4960),
    [anon_sym_constraint] = ACTIONS(4960),
    [anon_sym_if] = ACTIONS(4960),
    [anon_sym_else] = ACTIONS(4960),
    [anon_sym_LBRACK] = ACTIONS(4958),
    [anon_sym_localparam] = ACTIONS(4960),
    [anon_sym_parameter] = ACTIONS(4960),
    [anon_sym_var] = ACTIONS(4960),
    [anon_sym_import] = ACTIONS(4960),
    [anon_sym_export] = ACTIONS(4960),
    [anon_sym_genvar] = ACTIONS(4960),
    [anon_sym_interconnect] = ACTIONS(4960),
    [anon_sym_typedef] = ACTIONS(4960),
    [anon_sym_enum] = ACTIONS(4960),
    [anon_sym_struct] = ACTIONS(4960),
    [anon_sym_union] = ACTIONS(4960),
    [anon_sym_nettype] = ACTIONS(4960),
    [anon_sym_automatic] = ACTIONS(4960),
    [anon_sym_string] = ACTIONS(4960),
    [anon_sym_chandle] = ACTIONS(4960),
    [anon_sym_event] = ACTIONS(4960),
    [anon_sym_byte] = ACTIONS(4960),
    [anon_sym_shortint] = ACTIONS(4960),
    [anon_sym_int] = ACTIONS(4960),
    [anon_sym_longint] = ACTIONS(4960),
    [anon_sym_integer] = ACTIONS(4960),
    [anon_sym_time] = ACTIONS(4960),
    [anon_sym_bit] = ACTIONS(4960),
    [anon_sym_logic] = ACTIONS(4960),
    [anon_sym_reg] = ACTIONS(4960),
    [anon_sym_shortreal] = ACTIONS(4960),
    [anon_sym_real] = ACTIONS(4960),
    [anon_sym_realtime] = ACTIONS(4960),
    [anon_sym_supply0] = ACTIONS(4960),
    [anon_sym_supply1] = ACTIONS(4960),
    [anon_sym_signed] = ACTIONS(4960),
    [anon_sym_unsigned] = ACTIONS(4960),
    [anon_sym_task] = ACTIONS(4960),
    [anon_sym_assert] = ACTIONS(4960),
    [anon_sym_property] = ACTIONS(4960),
    [anon_sym_assume] = ACTIONS(4960),
    [anon_sym_cover] = ACTIONS(4960),
    [anon_sym_sequence] = ACTIONS(4960),
    [anon_sym_restrict] = ACTIONS(4960),
    [anon_sym_not] = ACTIONS(4960),
    [anon_sym_or] = ACTIONS(4960),
    [anon_sym_and] = ACTIONS(4960),
    [anon_sym_case] = ACTIONS(4960),
    [anon_sym_always] = ACTIONS(4960),
    [anon_sym_covergroup] = ACTIONS(4960),
    [anon_sym_end] = ACTIONS(4960),
    [anon_sym_let] = ACTIONS(4960),
    [anon_sym_pulldown] = ACTIONS(4960),
    [anon_sym_pullup] = ACTIONS(4960),
    [anon_sym_cmos] = ACTIONS(4960),
    [anon_sym_rcmos] = ACTIONS(4960),
    [anon_sym_bufif0] = ACTIONS(4960),
    [anon_sym_bufif1] = ACTIONS(4960),
    [anon_sym_notif0] = ACTIONS(4960),
    [anon_sym_notif1] = ACTIONS(4960),
    [anon_sym_nmos] = ACTIONS(4960),
    [anon_sym_pmos] = ACTIONS(4960),
    [anon_sym_rnmos] = ACTIONS(4960),
    [anon_sym_rpmos] = ACTIONS(4960),
    [anon_sym_nand] = ACTIONS(4960),
    [anon_sym_nor] = ACTIONS(4960),
    [anon_sym_xor] = ACTIONS(4960),
    [anon_sym_xnor] = ACTIONS(4960),
    [anon_sym_buf] = ACTIONS(4960),
    [anon_sym_tranif0] = ACTIONS(4960),
    [anon_sym_tranif1] = ACTIONS(4960),
    [anon_sym_rtranif1] = ACTIONS(4960),
    [anon_sym_rtranif0] = ACTIONS(4960),
    [anon_sym_tran] = ACTIONS(4960),
    [anon_sym_rtran] = ACTIONS(4960),
    [anon_sym_generate] = ACTIONS(4960),
    [anon_sym_for] = ACTIONS(4960),
    [anon_sym_initial] = ACTIONS(4960),
    [anon_sym_assign] = ACTIONS(4960),
    [anon_sym_alias] = ACTIONS(4960),
    [anon_sym_always_comb] = ACTIONS(4960),
    [anon_sym_always_latch] = ACTIONS(4960),
    [anon_sym_always_ff] = ACTIONS(4960),
    [anon_sym_final] = ACTIONS(4960),
    [anon_sym_global] = ACTIONS(4960),
    [anon_sym_LPAREN_STAR] = ACTIONS(4958),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4958),
    [anon_sym_DOLLARunit] = ACTIONS(4958),
  },
  [4940] = {
    [sym_simple_identifier] = ACTIONS(5302),
    [anon_sym_wire] = ACTIONS(5302),
    [anon_sym_tri] = ACTIONS(5302),
    [anon_sym_tri0] = ACTIONS(5302),
    [anon_sym_tri1] = ACTIONS(5302),
    [anon_sym_wand] = ACTIONS(5302),
    [anon_sym_triand] = ACTIONS(5302),
    [anon_sym_wor] = ACTIONS(5302),
    [anon_sym_trior] = ACTIONS(5302),
    [anon_sym_trireg] = ACTIONS(5302),
    [anon_sym_uwire] = ACTIONS(5302),
    [anon_sym_SEMI] = ACTIONS(5300),
    [anon_sym_extern] = ACTIONS(5302),
    [anon_sym_interface] = ACTIONS(5302),
    [anon_sym_checker] = ACTIONS(5302),
    [anon_sym_virtual] = ACTIONS(5302),
    [anon_sym_class] = ACTIONS(5302),
    [anon_sym_type] = ACTIONS(5302),
    [anon_sym_DOLLARfatal] = ACTIONS(5300),
    [anon_sym_DOLLARerror] = ACTIONS(5300),
    [anon_sym_DOLLARwarning] = ACTIONS(5300),
    [anon_sym_DOLLARinfo] = ACTIONS(5300),
    [anon_sym_default] = ACTIONS(5302),
    [anon_sym_clocking] = ACTIONS(5302),
    [anon_sym_defparam] = ACTIONS(5302),
    [anon_sym_bind] = ACTIONS(5302),
    [anon_sym_rand] = ACTIONS(5302),
    [anon_sym_const] = ACTIONS(5302),
    [anon_sym_function] = ACTIONS(5302),
    [anon_sym_static] = ACTIONS(5302),
    [anon_sym_constraint] = ACTIONS(5302),
    [anon_sym_if] = ACTIONS(5302),
    [anon_sym_else] = ACTIONS(5302),
    [anon_sym_LBRACK] = ACTIONS(5300),
    [anon_sym_localparam] = ACTIONS(5302),
    [anon_sym_parameter] = ACTIONS(5302),
    [anon_sym_var] = ACTIONS(5302),
    [anon_sym_import] = ACTIONS(5302),
    [anon_sym_export] = ACTIONS(5302),
    [anon_sym_genvar] = ACTIONS(5302),
    [anon_sym_interconnect] = ACTIONS(5302),
    [anon_sym_typedef] = ACTIONS(5302),
    [anon_sym_enum] = ACTIONS(5302),
    [anon_sym_struct] = ACTIONS(5302),
    [anon_sym_union] = ACTIONS(5302),
    [anon_sym_nettype] = ACTIONS(5302),
    [anon_sym_automatic] = ACTIONS(5302),
    [anon_sym_string] = ACTIONS(5302),
    [anon_sym_chandle] = ACTIONS(5302),
    [anon_sym_event] = ACTIONS(5302),
    [anon_sym_byte] = ACTIONS(5302),
    [anon_sym_shortint] = ACTIONS(5302),
    [anon_sym_int] = ACTIONS(5302),
    [anon_sym_longint] = ACTIONS(5302),
    [anon_sym_integer] = ACTIONS(5302),
    [anon_sym_time] = ACTIONS(5302),
    [anon_sym_bit] = ACTIONS(5302),
    [anon_sym_logic] = ACTIONS(5302),
    [anon_sym_reg] = ACTIONS(5302),
    [anon_sym_shortreal] = ACTIONS(5302),
    [anon_sym_real] = ACTIONS(5302),
    [anon_sym_realtime] = ACTIONS(5302),
    [anon_sym_supply0] = ACTIONS(5302),
    [anon_sym_supply1] = ACTIONS(5302),
    [anon_sym_signed] = ACTIONS(5302),
    [anon_sym_unsigned] = ACTIONS(5302),
    [anon_sym_task] = ACTIONS(5302),
    [anon_sym_assert] = ACTIONS(5302),
    [anon_sym_property] = ACTIONS(5302),
    [anon_sym_assume] = ACTIONS(5302),
    [anon_sym_cover] = ACTIONS(5302),
    [anon_sym_sequence] = ACTIONS(5302),
    [anon_sym_restrict] = ACTIONS(5302),
    [anon_sym_not] = ACTIONS(5302),
    [anon_sym_or] = ACTIONS(5302),
    [anon_sym_and] = ACTIONS(5302),
    [anon_sym_case] = ACTIONS(5302),
    [anon_sym_always] = ACTIONS(5302),
    [anon_sym_covergroup] = ACTIONS(5302),
    [anon_sym_let] = ACTIONS(5302),
    [anon_sym_pulldown] = ACTIONS(5302),
    [anon_sym_pullup] = ACTIONS(5302),
    [anon_sym_cmos] = ACTIONS(5302),
    [anon_sym_rcmos] = ACTIONS(5302),
    [anon_sym_bufif0] = ACTIONS(5302),
    [anon_sym_bufif1] = ACTIONS(5302),
    [anon_sym_notif0] = ACTIONS(5302),
    [anon_sym_notif1] = ACTIONS(5302),
    [anon_sym_nmos] = ACTIONS(5302),
    [anon_sym_pmos] = ACTIONS(5302),
    [anon_sym_rnmos] = ACTIONS(5302),
    [anon_sym_rpmos] = ACTIONS(5302),
    [anon_sym_nand] = ACTIONS(5302),
    [anon_sym_nor] = ACTIONS(5302),
    [anon_sym_xor] = ACTIONS(5302),
    [anon_sym_xnor] = ACTIONS(5302),
    [anon_sym_buf] = ACTIONS(5302),
    [anon_sym_tranif0] = ACTIONS(5302),
    [anon_sym_tranif1] = ACTIONS(5302),
    [anon_sym_rtranif1] = ACTIONS(5302),
    [anon_sym_rtranif0] = ACTIONS(5302),
    [anon_sym_tran] = ACTIONS(5302),
    [anon_sym_rtran] = ACTIONS(5302),
    [anon_sym_generate] = ACTIONS(5302),
    [anon_sym_endgenerate] = ACTIONS(5302),
    [anon_sym_for] = ACTIONS(5302),
    [anon_sym_initial] = ACTIONS(5302),
    [anon_sym_assign] = ACTIONS(5302),
    [anon_sym_alias] = ACTIONS(5302),
    [anon_sym_always_comb] = ACTIONS(5302),
    [anon_sym_always_latch] = ACTIONS(5302),
    [anon_sym_always_ff] = ACTIONS(5302),
    [anon_sym_final] = ACTIONS(5302),
    [anon_sym_global] = ACTIONS(5302),
    [anon_sym_LPAREN_STAR] = ACTIONS(5300),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5300),
    [anon_sym_DOLLARunit] = ACTIONS(5300),
  },
  [4941] = {
    [sym_simple_identifier] = ACTIONS(5328),
    [anon_sym_wire] = ACTIONS(5328),
    [anon_sym_tri] = ACTIONS(5328),
    [anon_sym_tri0] = ACTIONS(5328),
    [anon_sym_tri1] = ACTIONS(5328),
    [anon_sym_wand] = ACTIONS(5328),
    [anon_sym_triand] = ACTIONS(5328),
    [anon_sym_wor] = ACTIONS(5328),
    [anon_sym_trior] = ACTIONS(5328),
    [anon_sym_trireg] = ACTIONS(5328),
    [anon_sym_uwire] = ACTIONS(5328),
    [anon_sym_SEMI] = ACTIONS(5326),
    [anon_sym_extern] = ACTIONS(5328),
    [anon_sym_interface] = ACTIONS(5328),
    [anon_sym_checker] = ACTIONS(5328),
    [anon_sym_virtual] = ACTIONS(5328),
    [anon_sym_class] = ACTIONS(5328),
    [anon_sym_type] = ACTIONS(5328),
    [anon_sym_DOLLARfatal] = ACTIONS(5326),
    [anon_sym_DOLLARerror] = ACTIONS(5326),
    [anon_sym_DOLLARwarning] = ACTIONS(5326),
    [anon_sym_DOLLARinfo] = ACTIONS(5326),
    [anon_sym_default] = ACTIONS(5328),
    [anon_sym_clocking] = ACTIONS(5328),
    [anon_sym_defparam] = ACTIONS(5328),
    [anon_sym_bind] = ACTIONS(5328),
    [anon_sym_rand] = ACTIONS(5328),
    [anon_sym_const] = ACTIONS(5328),
    [anon_sym_function] = ACTIONS(5328),
    [anon_sym_static] = ACTIONS(5328),
    [anon_sym_constraint] = ACTIONS(5328),
    [anon_sym_if] = ACTIONS(5328),
    [anon_sym_else] = ACTIONS(5328),
    [anon_sym_LBRACK] = ACTIONS(5326),
    [anon_sym_localparam] = ACTIONS(5328),
    [anon_sym_parameter] = ACTIONS(5328),
    [anon_sym_var] = ACTIONS(5328),
    [anon_sym_import] = ACTIONS(5328),
    [anon_sym_export] = ACTIONS(5328),
    [anon_sym_genvar] = ACTIONS(5328),
    [anon_sym_interconnect] = ACTIONS(5328),
    [anon_sym_typedef] = ACTIONS(5328),
    [anon_sym_enum] = ACTIONS(5328),
    [anon_sym_struct] = ACTIONS(5328),
    [anon_sym_union] = ACTIONS(5328),
    [anon_sym_nettype] = ACTIONS(5328),
    [anon_sym_automatic] = ACTIONS(5328),
    [anon_sym_string] = ACTIONS(5328),
    [anon_sym_chandle] = ACTIONS(5328),
    [anon_sym_event] = ACTIONS(5328),
    [anon_sym_byte] = ACTIONS(5328),
    [anon_sym_shortint] = ACTIONS(5328),
    [anon_sym_int] = ACTIONS(5328),
    [anon_sym_longint] = ACTIONS(5328),
    [anon_sym_integer] = ACTIONS(5328),
    [anon_sym_time] = ACTIONS(5328),
    [anon_sym_bit] = ACTIONS(5328),
    [anon_sym_logic] = ACTIONS(5328),
    [anon_sym_reg] = ACTIONS(5328),
    [anon_sym_shortreal] = ACTIONS(5328),
    [anon_sym_real] = ACTIONS(5328),
    [anon_sym_realtime] = ACTIONS(5328),
    [anon_sym_supply0] = ACTIONS(5328),
    [anon_sym_supply1] = ACTIONS(5328),
    [anon_sym_signed] = ACTIONS(5328),
    [anon_sym_unsigned] = ACTIONS(5328),
    [anon_sym_task] = ACTIONS(5328),
    [anon_sym_assert] = ACTIONS(5328),
    [anon_sym_property] = ACTIONS(5328),
    [anon_sym_assume] = ACTIONS(5328),
    [anon_sym_cover] = ACTIONS(5328),
    [anon_sym_sequence] = ACTIONS(5328),
    [anon_sym_restrict] = ACTIONS(5328),
    [anon_sym_not] = ACTIONS(5328),
    [anon_sym_or] = ACTIONS(5328),
    [anon_sym_and] = ACTIONS(5328),
    [anon_sym_case] = ACTIONS(5328),
    [anon_sym_always] = ACTIONS(5328),
    [anon_sym_covergroup] = ACTIONS(5328),
    [anon_sym_end] = ACTIONS(5328),
    [anon_sym_let] = ACTIONS(5328),
    [anon_sym_pulldown] = ACTIONS(5328),
    [anon_sym_pullup] = ACTIONS(5328),
    [anon_sym_cmos] = ACTIONS(5328),
    [anon_sym_rcmos] = ACTIONS(5328),
    [anon_sym_bufif0] = ACTIONS(5328),
    [anon_sym_bufif1] = ACTIONS(5328),
    [anon_sym_notif0] = ACTIONS(5328),
    [anon_sym_notif1] = ACTIONS(5328),
    [anon_sym_nmos] = ACTIONS(5328),
    [anon_sym_pmos] = ACTIONS(5328),
    [anon_sym_rnmos] = ACTIONS(5328),
    [anon_sym_rpmos] = ACTIONS(5328),
    [anon_sym_nand] = ACTIONS(5328),
    [anon_sym_nor] = ACTIONS(5328),
    [anon_sym_xor] = ACTIONS(5328),
    [anon_sym_xnor] = ACTIONS(5328),
    [anon_sym_buf] = ACTIONS(5328),
    [anon_sym_tranif0] = ACTIONS(5328),
    [anon_sym_tranif1] = ACTIONS(5328),
    [anon_sym_rtranif1] = ACTIONS(5328),
    [anon_sym_rtranif0] = ACTIONS(5328),
    [anon_sym_tran] = ACTIONS(5328),
    [anon_sym_rtran] = ACTIONS(5328),
    [anon_sym_generate] = ACTIONS(5328),
    [anon_sym_for] = ACTIONS(5328),
    [anon_sym_initial] = ACTIONS(5328),
    [anon_sym_assign] = ACTIONS(5328),
    [anon_sym_alias] = ACTIONS(5328),
    [anon_sym_always_comb] = ACTIONS(5328),
    [anon_sym_always_latch] = ACTIONS(5328),
    [anon_sym_always_ff] = ACTIONS(5328),
    [anon_sym_final] = ACTIONS(5328),
    [anon_sym_global] = ACTIONS(5328),
    [anon_sym_LPAREN_STAR] = ACTIONS(5326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5326),
    [anon_sym_DOLLARunit] = ACTIONS(5326),
  },
  [4942] = {
    [sym_simple_identifier] = ACTIONS(6517),
    [anon_sym_wire] = ACTIONS(6517),
    [anon_sym_tri] = ACTIONS(6517),
    [anon_sym_tri0] = ACTIONS(6517),
    [anon_sym_tri1] = ACTIONS(6517),
    [anon_sym_wand] = ACTIONS(6517),
    [anon_sym_triand] = ACTIONS(6517),
    [anon_sym_wor] = ACTIONS(6517),
    [anon_sym_trior] = ACTIONS(6517),
    [anon_sym_trireg] = ACTIONS(6517),
    [anon_sym_uwire] = ACTIONS(6517),
    [anon_sym_SEMI] = ACTIONS(6520),
    [anon_sym_extern] = ACTIONS(6517),
    [anon_sym_interface] = ACTIONS(6517),
    [anon_sym_checker] = ACTIONS(6517),
    [anon_sym_virtual] = ACTIONS(6517),
    [anon_sym_class] = ACTIONS(6517),
    [anon_sym_type] = ACTIONS(6517),
    [anon_sym_DOLLARfatal] = ACTIONS(6520),
    [anon_sym_DOLLARerror] = ACTIONS(6520),
    [anon_sym_DOLLARwarning] = ACTIONS(6520),
    [anon_sym_DOLLARinfo] = ACTIONS(6520),
    [anon_sym_default] = ACTIONS(6517),
    [anon_sym_clocking] = ACTIONS(6517),
    [anon_sym_defparam] = ACTIONS(6517),
    [anon_sym_bind] = ACTIONS(6517),
    [anon_sym_rand] = ACTIONS(6517),
    [anon_sym_const] = ACTIONS(6517),
    [anon_sym_function] = ACTIONS(6517),
    [anon_sym_static] = ACTIONS(6517),
    [anon_sym_constraint] = ACTIONS(6517),
    [anon_sym_if] = ACTIONS(6517),
    [anon_sym_else] = ACTIONS(6517),
    [anon_sym_LBRACK] = ACTIONS(6520),
    [anon_sym_localparam] = ACTIONS(6517),
    [anon_sym_parameter] = ACTIONS(6517),
    [anon_sym_var] = ACTIONS(6517),
    [anon_sym_import] = ACTIONS(6517),
    [anon_sym_export] = ACTIONS(6517),
    [anon_sym_genvar] = ACTIONS(6517),
    [anon_sym_interconnect] = ACTIONS(6517),
    [anon_sym_typedef] = ACTIONS(6517),
    [anon_sym_enum] = ACTIONS(6517),
    [anon_sym_struct] = ACTIONS(6517),
    [anon_sym_union] = ACTIONS(6517),
    [anon_sym_nettype] = ACTIONS(6517),
    [anon_sym_automatic] = ACTIONS(6517),
    [anon_sym_string] = ACTIONS(6517),
    [anon_sym_chandle] = ACTIONS(6517),
    [anon_sym_event] = ACTIONS(6517),
    [anon_sym_byte] = ACTIONS(6517),
    [anon_sym_shortint] = ACTIONS(6517),
    [anon_sym_int] = ACTIONS(6517),
    [anon_sym_longint] = ACTIONS(6517),
    [anon_sym_integer] = ACTIONS(6517),
    [anon_sym_time] = ACTIONS(6517),
    [anon_sym_bit] = ACTIONS(6517),
    [anon_sym_logic] = ACTIONS(6517),
    [anon_sym_reg] = ACTIONS(6517),
    [anon_sym_shortreal] = ACTIONS(6517),
    [anon_sym_real] = ACTIONS(6517),
    [anon_sym_realtime] = ACTIONS(6517),
    [anon_sym_supply0] = ACTIONS(6517),
    [anon_sym_supply1] = ACTIONS(6517),
    [anon_sym_signed] = ACTIONS(6517),
    [anon_sym_unsigned] = ACTIONS(6517),
    [anon_sym_task] = ACTIONS(6517),
    [anon_sym_assert] = ACTIONS(6517),
    [anon_sym_property] = ACTIONS(6517),
    [anon_sym_assume] = ACTIONS(6517),
    [anon_sym_cover] = ACTIONS(6517),
    [anon_sym_sequence] = ACTIONS(6517),
    [anon_sym_restrict] = ACTIONS(6517),
    [anon_sym_not] = ACTIONS(6517),
    [anon_sym_or] = ACTIONS(6517),
    [anon_sym_and] = ACTIONS(6517),
    [anon_sym_case] = ACTIONS(6517),
    [anon_sym_always] = ACTIONS(6517),
    [anon_sym_covergroup] = ACTIONS(6517),
    [anon_sym_let] = ACTIONS(6517),
    [anon_sym_pulldown] = ACTIONS(6517),
    [anon_sym_pullup] = ACTIONS(6517),
    [anon_sym_cmos] = ACTIONS(6517),
    [anon_sym_rcmos] = ACTIONS(6517),
    [anon_sym_bufif0] = ACTIONS(6517),
    [anon_sym_bufif1] = ACTIONS(6517),
    [anon_sym_notif0] = ACTIONS(6517),
    [anon_sym_notif1] = ACTIONS(6517),
    [anon_sym_nmos] = ACTIONS(6517),
    [anon_sym_pmos] = ACTIONS(6517),
    [anon_sym_rnmos] = ACTIONS(6517),
    [anon_sym_rpmos] = ACTIONS(6517),
    [anon_sym_nand] = ACTIONS(6517),
    [anon_sym_nor] = ACTIONS(6517),
    [anon_sym_xor] = ACTIONS(6517),
    [anon_sym_xnor] = ACTIONS(6517),
    [anon_sym_buf] = ACTIONS(6517),
    [anon_sym_tranif0] = ACTIONS(6517),
    [anon_sym_tranif1] = ACTIONS(6517),
    [anon_sym_rtranif1] = ACTIONS(6517),
    [anon_sym_rtranif0] = ACTIONS(6517),
    [anon_sym_tran] = ACTIONS(6517),
    [anon_sym_rtran] = ACTIONS(6517),
    [anon_sym_generate] = ACTIONS(6517),
    [anon_sym_endgenerate] = ACTIONS(6517),
    [anon_sym_for] = ACTIONS(6517),
    [anon_sym_initial] = ACTIONS(6517),
    [anon_sym_assign] = ACTIONS(6517),
    [anon_sym_alias] = ACTIONS(6517),
    [anon_sym_always_comb] = ACTIONS(6517),
    [anon_sym_always_latch] = ACTIONS(6517),
    [anon_sym_always_ff] = ACTIONS(6517),
    [anon_sym_final] = ACTIONS(6517),
    [anon_sym_global] = ACTIONS(6517),
    [anon_sym_LPAREN_STAR] = ACTIONS(6520),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6520),
    [anon_sym_DOLLARunit] = ACTIONS(6520),
  },
  [4943] = {
    [sym_simple_identifier] = ACTIONS(4618),
    [anon_sym_wire] = ACTIONS(4618),
    [anon_sym_tri] = ACTIONS(4618),
    [anon_sym_tri0] = ACTIONS(4618),
    [anon_sym_tri1] = ACTIONS(4618),
    [anon_sym_wand] = ACTIONS(4618),
    [anon_sym_triand] = ACTIONS(4618),
    [anon_sym_wor] = ACTIONS(4618),
    [anon_sym_trior] = ACTIONS(4618),
    [anon_sym_trireg] = ACTIONS(4618),
    [anon_sym_uwire] = ACTIONS(4618),
    [anon_sym_SEMI] = ACTIONS(4616),
    [anon_sym_extern] = ACTIONS(4618),
    [anon_sym_interface] = ACTIONS(4618),
    [anon_sym_checker] = ACTIONS(4618),
    [anon_sym_virtual] = ACTIONS(4618),
    [anon_sym_class] = ACTIONS(4618),
    [anon_sym_type] = ACTIONS(4618),
    [anon_sym_DOLLARfatal] = ACTIONS(4616),
    [anon_sym_DOLLARerror] = ACTIONS(4616),
    [anon_sym_DOLLARwarning] = ACTIONS(4616),
    [anon_sym_DOLLARinfo] = ACTIONS(4616),
    [anon_sym_default] = ACTIONS(4618),
    [anon_sym_clocking] = ACTIONS(4618),
    [anon_sym_defparam] = ACTIONS(4618),
    [anon_sym_bind] = ACTIONS(4618),
    [anon_sym_rand] = ACTIONS(4618),
    [anon_sym_const] = ACTIONS(4618),
    [anon_sym_function] = ACTIONS(4618),
    [anon_sym_static] = ACTIONS(4618),
    [anon_sym_constraint] = ACTIONS(4618),
    [anon_sym_if] = ACTIONS(4618),
    [anon_sym_else] = ACTIONS(4618),
    [anon_sym_LBRACK] = ACTIONS(4616),
    [anon_sym_localparam] = ACTIONS(4618),
    [anon_sym_parameter] = ACTIONS(4618),
    [anon_sym_var] = ACTIONS(4618),
    [anon_sym_import] = ACTIONS(4618),
    [anon_sym_export] = ACTIONS(4618),
    [anon_sym_genvar] = ACTIONS(4618),
    [anon_sym_interconnect] = ACTIONS(4618),
    [anon_sym_typedef] = ACTIONS(4618),
    [anon_sym_enum] = ACTIONS(4618),
    [anon_sym_struct] = ACTIONS(4618),
    [anon_sym_union] = ACTIONS(4618),
    [anon_sym_nettype] = ACTIONS(4618),
    [anon_sym_automatic] = ACTIONS(4618),
    [anon_sym_string] = ACTIONS(4618),
    [anon_sym_chandle] = ACTIONS(4618),
    [anon_sym_event] = ACTIONS(4618),
    [anon_sym_byte] = ACTIONS(4618),
    [anon_sym_shortint] = ACTIONS(4618),
    [anon_sym_int] = ACTIONS(4618),
    [anon_sym_longint] = ACTIONS(4618),
    [anon_sym_integer] = ACTIONS(4618),
    [anon_sym_time] = ACTIONS(4618),
    [anon_sym_bit] = ACTIONS(4618),
    [anon_sym_logic] = ACTIONS(4618),
    [anon_sym_reg] = ACTIONS(4618),
    [anon_sym_shortreal] = ACTIONS(4618),
    [anon_sym_real] = ACTIONS(4618),
    [anon_sym_realtime] = ACTIONS(4618),
    [anon_sym_supply0] = ACTIONS(4618),
    [anon_sym_supply1] = ACTIONS(4618),
    [anon_sym_signed] = ACTIONS(4618),
    [anon_sym_unsigned] = ACTIONS(4618),
    [anon_sym_task] = ACTIONS(4618),
    [anon_sym_assert] = ACTIONS(4618),
    [anon_sym_property] = ACTIONS(4618),
    [anon_sym_assume] = ACTIONS(4618),
    [anon_sym_cover] = ACTIONS(4618),
    [anon_sym_sequence] = ACTIONS(4618),
    [anon_sym_restrict] = ACTIONS(4618),
    [anon_sym_not] = ACTIONS(4618),
    [anon_sym_or] = ACTIONS(4618),
    [anon_sym_and] = ACTIONS(4618),
    [anon_sym_case] = ACTIONS(4618),
    [anon_sym_always] = ACTIONS(4618),
    [anon_sym_covergroup] = ACTIONS(4618),
    [anon_sym_end] = ACTIONS(4618),
    [anon_sym_let] = ACTIONS(4618),
    [anon_sym_pulldown] = ACTIONS(4618),
    [anon_sym_pullup] = ACTIONS(4618),
    [anon_sym_cmos] = ACTIONS(4618),
    [anon_sym_rcmos] = ACTIONS(4618),
    [anon_sym_bufif0] = ACTIONS(4618),
    [anon_sym_bufif1] = ACTIONS(4618),
    [anon_sym_notif0] = ACTIONS(4618),
    [anon_sym_notif1] = ACTIONS(4618),
    [anon_sym_nmos] = ACTIONS(4618),
    [anon_sym_pmos] = ACTIONS(4618),
    [anon_sym_rnmos] = ACTIONS(4618),
    [anon_sym_rpmos] = ACTIONS(4618),
    [anon_sym_nand] = ACTIONS(4618),
    [anon_sym_nor] = ACTIONS(4618),
    [anon_sym_xor] = ACTIONS(4618),
    [anon_sym_xnor] = ACTIONS(4618),
    [anon_sym_buf] = ACTIONS(4618),
    [anon_sym_tranif0] = ACTIONS(4618),
    [anon_sym_tranif1] = ACTIONS(4618),
    [anon_sym_rtranif1] = ACTIONS(4618),
    [anon_sym_rtranif0] = ACTIONS(4618),
    [anon_sym_tran] = ACTIONS(4618),
    [anon_sym_rtran] = ACTIONS(4618),
    [anon_sym_generate] = ACTIONS(4618),
    [anon_sym_for] = ACTIONS(4618),
    [anon_sym_initial] = ACTIONS(4618),
    [anon_sym_assign] = ACTIONS(4618),
    [anon_sym_alias] = ACTIONS(4618),
    [anon_sym_always_comb] = ACTIONS(4618),
    [anon_sym_always_latch] = ACTIONS(4618),
    [anon_sym_always_ff] = ACTIONS(4618),
    [anon_sym_final] = ACTIONS(4618),
    [anon_sym_global] = ACTIONS(4618),
    [anon_sym_LPAREN_STAR] = ACTIONS(4616),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4616),
    [anon_sym_DOLLARunit] = ACTIONS(4616),
  },
  [4944] = {
    [sym_simple_identifier] = ACTIONS(6747),
    [anon_sym_wire] = ACTIONS(6747),
    [anon_sym_tri] = ACTIONS(6747),
    [anon_sym_tri0] = ACTIONS(6747),
    [anon_sym_tri1] = ACTIONS(6747),
    [anon_sym_wand] = ACTIONS(6747),
    [anon_sym_triand] = ACTIONS(6747),
    [anon_sym_wor] = ACTIONS(6747),
    [anon_sym_trior] = ACTIONS(6747),
    [anon_sym_trireg] = ACTIONS(6747),
    [anon_sym_uwire] = ACTIONS(6747),
    [anon_sym_SEMI] = ACTIONS(6749),
    [anon_sym_extern] = ACTIONS(6747),
    [anon_sym_interface] = ACTIONS(6747),
    [anon_sym_checker] = ACTIONS(6747),
    [anon_sym_virtual] = ACTIONS(6747),
    [anon_sym_class] = ACTIONS(6747),
    [anon_sym_type] = ACTIONS(6747),
    [anon_sym_DOLLARfatal] = ACTIONS(6749),
    [anon_sym_DOLLARerror] = ACTIONS(6749),
    [anon_sym_DOLLARwarning] = ACTIONS(6749),
    [anon_sym_DOLLARinfo] = ACTIONS(6749),
    [anon_sym_default] = ACTIONS(6747),
    [anon_sym_clocking] = ACTIONS(6747),
    [anon_sym_defparam] = ACTIONS(6747),
    [anon_sym_bind] = ACTIONS(6747),
    [anon_sym_rand] = ACTIONS(6747),
    [anon_sym_const] = ACTIONS(6747),
    [anon_sym_function] = ACTIONS(6747),
    [anon_sym_static] = ACTIONS(6747),
    [anon_sym_constraint] = ACTIONS(6747),
    [anon_sym_if] = ACTIONS(6747),
    [anon_sym_else] = ACTIONS(6747),
    [anon_sym_LBRACK] = ACTIONS(6749),
    [anon_sym_localparam] = ACTIONS(6747),
    [anon_sym_parameter] = ACTIONS(6747),
    [anon_sym_var] = ACTIONS(6747),
    [anon_sym_import] = ACTIONS(6747),
    [anon_sym_export] = ACTIONS(6747),
    [anon_sym_genvar] = ACTIONS(6747),
    [anon_sym_interconnect] = ACTIONS(6747),
    [anon_sym_typedef] = ACTIONS(6747),
    [anon_sym_enum] = ACTIONS(6747),
    [anon_sym_struct] = ACTIONS(6747),
    [anon_sym_union] = ACTIONS(6747),
    [anon_sym_nettype] = ACTIONS(6747),
    [anon_sym_automatic] = ACTIONS(6747),
    [anon_sym_string] = ACTIONS(6747),
    [anon_sym_chandle] = ACTIONS(6747),
    [anon_sym_event] = ACTIONS(6747),
    [anon_sym_byte] = ACTIONS(6747),
    [anon_sym_shortint] = ACTIONS(6747),
    [anon_sym_int] = ACTIONS(6747),
    [anon_sym_longint] = ACTIONS(6747),
    [anon_sym_integer] = ACTIONS(6747),
    [anon_sym_time] = ACTIONS(6747),
    [anon_sym_bit] = ACTIONS(6747),
    [anon_sym_logic] = ACTIONS(6747),
    [anon_sym_reg] = ACTIONS(6747),
    [anon_sym_shortreal] = ACTIONS(6747),
    [anon_sym_real] = ACTIONS(6747),
    [anon_sym_realtime] = ACTIONS(6747),
    [anon_sym_supply0] = ACTIONS(6747),
    [anon_sym_supply1] = ACTIONS(6747),
    [anon_sym_signed] = ACTIONS(6747),
    [anon_sym_unsigned] = ACTIONS(6747),
    [anon_sym_task] = ACTIONS(6747),
    [anon_sym_assert] = ACTIONS(6747),
    [anon_sym_property] = ACTIONS(6747),
    [anon_sym_assume] = ACTIONS(6747),
    [anon_sym_cover] = ACTIONS(6747),
    [anon_sym_sequence] = ACTIONS(6747),
    [anon_sym_restrict] = ACTIONS(6747),
    [anon_sym_not] = ACTIONS(6747),
    [anon_sym_or] = ACTIONS(6747),
    [anon_sym_and] = ACTIONS(6747),
    [anon_sym_case] = ACTIONS(6747),
    [anon_sym_always] = ACTIONS(6747),
    [anon_sym_covergroup] = ACTIONS(6747),
    [anon_sym_let] = ACTIONS(6747),
    [anon_sym_pulldown] = ACTIONS(6747),
    [anon_sym_pullup] = ACTIONS(6747),
    [anon_sym_cmos] = ACTIONS(6747),
    [anon_sym_rcmos] = ACTIONS(6747),
    [anon_sym_bufif0] = ACTIONS(6747),
    [anon_sym_bufif1] = ACTIONS(6747),
    [anon_sym_notif0] = ACTIONS(6747),
    [anon_sym_notif1] = ACTIONS(6747),
    [anon_sym_nmos] = ACTIONS(6747),
    [anon_sym_pmos] = ACTIONS(6747),
    [anon_sym_rnmos] = ACTIONS(6747),
    [anon_sym_rpmos] = ACTIONS(6747),
    [anon_sym_nand] = ACTIONS(6747),
    [anon_sym_nor] = ACTIONS(6747),
    [anon_sym_xor] = ACTIONS(6747),
    [anon_sym_xnor] = ACTIONS(6747),
    [anon_sym_buf] = ACTIONS(6747),
    [anon_sym_tranif0] = ACTIONS(6747),
    [anon_sym_tranif1] = ACTIONS(6747),
    [anon_sym_rtranif1] = ACTIONS(6747),
    [anon_sym_rtranif0] = ACTIONS(6747),
    [anon_sym_tran] = ACTIONS(6747),
    [anon_sym_rtran] = ACTIONS(6747),
    [anon_sym_generate] = ACTIONS(6747),
    [anon_sym_endgenerate] = ACTIONS(6747),
    [anon_sym_for] = ACTIONS(6747),
    [anon_sym_initial] = ACTIONS(6747),
    [anon_sym_assign] = ACTIONS(6747),
    [anon_sym_alias] = ACTIONS(6747),
    [anon_sym_always_comb] = ACTIONS(6747),
    [anon_sym_always_latch] = ACTIONS(6747),
    [anon_sym_always_ff] = ACTIONS(6747),
    [anon_sym_final] = ACTIONS(6747),
    [anon_sym_global] = ACTIONS(6747),
    [anon_sym_LPAREN_STAR] = ACTIONS(6749),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6749),
    [anon_sym_DOLLARunit] = ACTIONS(6749),
  },
  [4945] = {
    [sym_simple_identifier] = ACTIONS(6385),
    [anon_sym_wire] = ACTIONS(6385),
    [anon_sym_tri] = ACTIONS(6385),
    [anon_sym_tri0] = ACTIONS(6385),
    [anon_sym_tri1] = ACTIONS(6385),
    [anon_sym_wand] = ACTIONS(6385),
    [anon_sym_triand] = ACTIONS(6385),
    [anon_sym_wor] = ACTIONS(6385),
    [anon_sym_trior] = ACTIONS(6385),
    [anon_sym_trireg] = ACTIONS(6385),
    [anon_sym_uwire] = ACTIONS(6385),
    [anon_sym_SEMI] = ACTIONS(6387),
    [anon_sym_extern] = ACTIONS(6385),
    [anon_sym_interface] = ACTIONS(6385),
    [anon_sym_checker] = ACTIONS(6385),
    [anon_sym_virtual] = ACTIONS(6385),
    [anon_sym_class] = ACTIONS(6385),
    [anon_sym_type] = ACTIONS(6385),
    [anon_sym_DOLLARfatal] = ACTIONS(6387),
    [anon_sym_DOLLARerror] = ACTIONS(6387),
    [anon_sym_DOLLARwarning] = ACTIONS(6387),
    [anon_sym_DOLLARinfo] = ACTIONS(6387),
    [anon_sym_default] = ACTIONS(6385),
    [anon_sym_clocking] = ACTIONS(6385),
    [anon_sym_defparam] = ACTIONS(6385),
    [anon_sym_bind] = ACTIONS(6385),
    [anon_sym_rand] = ACTIONS(6385),
    [anon_sym_const] = ACTIONS(6385),
    [anon_sym_function] = ACTIONS(6385),
    [anon_sym_static] = ACTIONS(6385),
    [anon_sym_constraint] = ACTIONS(6385),
    [anon_sym_if] = ACTIONS(6385),
    [anon_sym_else] = ACTIONS(6385),
    [anon_sym_LBRACK] = ACTIONS(6387),
    [anon_sym_localparam] = ACTIONS(6385),
    [anon_sym_parameter] = ACTIONS(6385),
    [anon_sym_var] = ACTIONS(6385),
    [anon_sym_import] = ACTIONS(6385),
    [anon_sym_export] = ACTIONS(6385),
    [anon_sym_genvar] = ACTIONS(6385),
    [anon_sym_interconnect] = ACTIONS(6385),
    [anon_sym_typedef] = ACTIONS(6385),
    [anon_sym_enum] = ACTIONS(6385),
    [anon_sym_struct] = ACTIONS(6385),
    [anon_sym_union] = ACTIONS(6385),
    [anon_sym_nettype] = ACTIONS(6385),
    [anon_sym_automatic] = ACTIONS(6385),
    [anon_sym_string] = ACTIONS(6385),
    [anon_sym_chandle] = ACTIONS(6385),
    [anon_sym_event] = ACTIONS(6385),
    [anon_sym_byte] = ACTIONS(6385),
    [anon_sym_shortint] = ACTIONS(6385),
    [anon_sym_int] = ACTIONS(6385),
    [anon_sym_longint] = ACTIONS(6385),
    [anon_sym_integer] = ACTIONS(6385),
    [anon_sym_time] = ACTIONS(6385),
    [anon_sym_bit] = ACTIONS(6385),
    [anon_sym_logic] = ACTIONS(6385),
    [anon_sym_reg] = ACTIONS(6385),
    [anon_sym_shortreal] = ACTIONS(6385),
    [anon_sym_real] = ACTIONS(6385),
    [anon_sym_realtime] = ACTIONS(6385),
    [anon_sym_supply0] = ACTIONS(6385),
    [anon_sym_supply1] = ACTIONS(6385),
    [anon_sym_signed] = ACTIONS(6385),
    [anon_sym_unsigned] = ACTIONS(6385),
    [anon_sym_task] = ACTIONS(6385),
    [anon_sym_assert] = ACTIONS(6385),
    [anon_sym_property] = ACTIONS(6385),
    [anon_sym_assume] = ACTIONS(6385),
    [anon_sym_cover] = ACTIONS(6385),
    [anon_sym_sequence] = ACTIONS(6385),
    [anon_sym_restrict] = ACTIONS(6385),
    [anon_sym_not] = ACTIONS(6385),
    [anon_sym_or] = ACTIONS(6385),
    [anon_sym_and] = ACTIONS(6385),
    [anon_sym_case] = ACTIONS(6385),
    [anon_sym_always] = ACTIONS(6385),
    [anon_sym_covergroup] = ACTIONS(6385),
    [anon_sym_let] = ACTIONS(6385),
    [anon_sym_pulldown] = ACTIONS(6385),
    [anon_sym_pullup] = ACTIONS(6385),
    [anon_sym_cmos] = ACTIONS(6385),
    [anon_sym_rcmos] = ACTIONS(6385),
    [anon_sym_bufif0] = ACTIONS(6385),
    [anon_sym_bufif1] = ACTIONS(6385),
    [anon_sym_notif0] = ACTIONS(6385),
    [anon_sym_notif1] = ACTIONS(6385),
    [anon_sym_nmos] = ACTIONS(6385),
    [anon_sym_pmos] = ACTIONS(6385),
    [anon_sym_rnmos] = ACTIONS(6385),
    [anon_sym_rpmos] = ACTIONS(6385),
    [anon_sym_nand] = ACTIONS(6385),
    [anon_sym_nor] = ACTIONS(6385),
    [anon_sym_xor] = ACTIONS(6385),
    [anon_sym_xnor] = ACTIONS(6385),
    [anon_sym_buf] = ACTIONS(6385),
    [anon_sym_tranif0] = ACTIONS(6385),
    [anon_sym_tranif1] = ACTIONS(6385),
    [anon_sym_rtranif1] = ACTIONS(6385),
    [anon_sym_rtranif0] = ACTIONS(6385),
    [anon_sym_tran] = ACTIONS(6385),
    [anon_sym_rtran] = ACTIONS(6385),
    [anon_sym_generate] = ACTIONS(6385),
    [anon_sym_endgenerate] = ACTIONS(6385),
    [anon_sym_for] = ACTIONS(6385),
    [anon_sym_initial] = ACTIONS(6385),
    [anon_sym_assign] = ACTIONS(6385),
    [anon_sym_alias] = ACTIONS(6385),
    [anon_sym_always_comb] = ACTIONS(6385),
    [anon_sym_always_latch] = ACTIONS(6385),
    [anon_sym_always_ff] = ACTIONS(6385),
    [anon_sym_final] = ACTIONS(6385),
    [anon_sym_global] = ACTIONS(6385),
    [anon_sym_LPAREN_STAR] = ACTIONS(6387),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6387),
    [anon_sym_DOLLARunit] = ACTIONS(6387),
  },
  [4946] = {
    [sym_simple_identifier] = ACTIONS(5234),
    [anon_sym_wire] = ACTIONS(5234),
    [anon_sym_tri] = ACTIONS(5234),
    [anon_sym_tri0] = ACTIONS(5234),
    [anon_sym_tri1] = ACTIONS(5234),
    [anon_sym_wand] = ACTIONS(5234),
    [anon_sym_triand] = ACTIONS(5234),
    [anon_sym_wor] = ACTIONS(5234),
    [anon_sym_trior] = ACTIONS(5234),
    [anon_sym_trireg] = ACTIONS(5234),
    [anon_sym_uwire] = ACTIONS(5234),
    [anon_sym_SEMI] = ACTIONS(5232),
    [anon_sym_extern] = ACTIONS(5234),
    [anon_sym_interface] = ACTIONS(5234),
    [anon_sym_checker] = ACTIONS(5234),
    [anon_sym_virtual] = ACTIONS(5234),
    [anon_sym_class] = ACTIONS(5234),
    [anon_sym_type] = ACTIONS(5234),
    [anon_sym_DOLLARfatal] = ACTIONS(5232),
    [anon_sym_DOLLARerror] = ACTIONS(5232),
    [anon_sym_DOLLARwarning] = ACTIONS(5232),
    [anon_sym_DOLLARinfo] = ACTIONS(5232),
    [anon_sym_default] = ACTIONS(5234),
    [anon_sym_clocking] = ACTIONS(5234),
    [anon_sym_defparam] = ACTIONS(5234),
    [anon_sym_bind] = ACTIONS(5234),
    [anon_sym_rand] = ACTIONS(5234),
    [anon_sym_const] = ACTIONS(5234),
    [anon_sym_function] = ACTIONS(5234),
    [anon_sym_static] = ACTIONS(5234),
    [anon_sym_constraint] = ACTIONS(5234),
    [anon_sym_if] = ACTIONS(5234),
    [anon_sym_else] = ACTIONS(5234),
    [anon_sym_LBRACK] = ACTIONS(5232),
    [anon_sym_localparam] = ACTIONS(5234),
    [anon_sym_parameter] = ACTIONS(5234),
    [anon_sym_var] = ACTIONS(5234),
    [anon_sym_import] = ACTIONS(5234),
    [anon_sym_export] = ACTIONS(5234),
    [anon_sym_genvar] = ACTIONS(5234),
    [anon_sym_interconnect] = ACTIONS(5234),
    [anon_sym_typedef] = ACTIONS(5234),
    [anon_sym_enum] = ACTIONS(5234),
    [anon_sym_struct] = ACTIONS(5234),
    [anon_sym_union] = ACTIONS(5234),
    [anon_sym_nettype] = ACTIONS(5234),
    [anon_sym_automatic] = ACTIONS(5234),
    [anon_sym_string] = ACTIONS(5234),
    [anon_sym_chandle] = ACTIONS(5234),
    [anon_sym_event] = ACTIONS(5234),
    [anon_sym_byte] = ACTIONS(5234),
    [anon_sym_shortint] = ACTIONS(5234),
    [anon_sym_int] = ACTIONS(5234),
    [anon_sym_longint] = ACTIONS(5234),
    [anon_sym_integer] = ACTIONS(5234),
    [anon_sym_time] = ACTIONS(5234),
    [anon_sym_bit] = ACTIONS(5234),
    [anon_sym_logic] = ACTIONS(5234),
    [anon_sym_reg] = ACTIONS(5234),
    [anon_sym_shortreal] = ACTIONS(5234),
    [anon_sym_real] = ACTIONS(5234),
    [anon_sym_realtime] = ACTIONS(5234),
    [anon_sym_supply0] = ACTIONS(5234),
    [anon_sym_supply1] = ACTIONS(5234),
    [anon_sym_signed] = ACTIONS(5234),
    [anon_sym_unsigned] = ACTIONS(5234),
    [anon_sym_task] = ACTIONS(5234),
    [anon_sym_assert] = ACTIONS(5234),
    [anon_sym_property] = ACTIONS(5234),
    [anon_sym_assume] = ACTIONS(5234),
    [anon_sym_cover] = ACTIONS(5234),
    [anon_sym_sequence] = ACTIONS(5234),
    [anon_sym_restrict] = ACTIONS(5234),
    [anon_sym_not] = ACTIONS(5234),
    [anon_sym_or] = ACTIONS(5234),
    [anon_sym_and] = ACTIONS(5234),
    [anon_sym_case] = ACTIONS(5234),
    [anon_sym_always] = ACTIONS(5234),
    [anon_sym_covergroup] = ACTIONS(5234),
    [anon_sym_let] = ACTIONS(5234),
    [anon_sym_pulldown] = ACTIONS(5234),
    [anon_sym_pullup] = ACTIONS(5234),
    [anon_sym_cmos] = ACTIONS(5234),
    [anon_sym_rcmos] = ACTIONS(5234),
    [anon_sym_bufif0] = ACTIONS(5234),
    [anon_sym_bufif1] = ACTIONS(5234),
    [anon_sym_notif0] = ACTIONS(5234),
    [anon_sym_notif1] = ACTIONS(5234),
    [anon_sym_nmos] = ACTIONS(5234),
    [anon_sym_pmos] = ACTIONS(5234),
    [anon_sym_rnmos] = ACTIONS(5234),
    [anon_sym_rpmos] = ACTIONS(5234),
    [anon_sym_nand] = ACTIONS(5234),
    [anon_sym_nor] = ACTIONS(5234),
    [anon_sym_xor] = ACTIONS(5234),
    [anon_sym_xnor] = ACTIONS(5234),
    [anon_sym_buf] = ACTIONS(5234),
    [anon_sym_tranif0] = ACTIONS(5234),
    [anon_sym_tranif1] = ACTIONS(5234),
    [anon_sym_rtranif1] = ACTIONS(5234),
    [anon_sym_rtranif0] = ACTIONS(5234),
    [anon_sym_tran] = ACTIONS(5234),
    [anon_sym_rtran] = ACTIONS(5234),
    [anon_sym_generate] = ACTIONS(5234),
    [anon_sym_endgenerate] = ACTIONS(5234),
    [anon_sym_for] = ACTIONS(5234),
    [anon_sym_initial] = ACTIONS(5234),
    [anon_sym_assign] = ACTIONS(5234),
    [anon_sym_alias] = ACTIONS(5234),
    [anon_sym_always_comb] = ACTIONS(5234),
    [anon_sym_always_latch] = ACTIONS(5234),
    [anon_sym_always_ff] = ACTIONS(5234),
    [anon_sym_final] = ACTIONS(5234),
    [anon_sym_global] = ACTIONS(5234),
    [anon_sym_LPAREN_STAR] = ACTIONS(5232),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5232),
    [anon_sym_DOLLARunit] = ACTIONS(5232),
  },
  [4947] = {
    [sym_simple_identifier] = ACTIONS(5306),
    [anon_sym_wire] = ACTIONS(5306),
    [anon_sym_tri] = ACTIONS(5306),
    [anon_sym_tri0] = ACTIONS(5306),
    [anon_sym_tri1] = ACTIONS(5306),
    [anon_sym_wand] = ACTIONS(5306),
    [anon_sym_triand] = ACTIONS(5306),
    [anon_sym_wor] = ACTIONS(5306),
    [anon_sym_trior] = ACTIONS(5306),
    [anon_sym_trireg] = ACTIONS(5306),
    [anon_sym_uwire] = ACTIONS(5306),
    [anon_sym_SEMI] = ACTIONS(5304),
    [anon_sym_extern] = ACTIONS(5306),
    [anon_sym_interface] = ACTIONS(5306),
    [anon_sym_checker] = ACTIONS(5306),
    [anon_sym_virtual] = ACTIONS(5306),
    [anon_sym_class] = ACTIONS(5306),
    [anon_sym_type] = ACTIONS(5306),
    [anon_sym_DOLLARfatal] = ACTIONS(5304),
    [anon_sym_DOLLARerror] = ACTIONS(5304),
    [anon_sym_DOLLARwarning] = ACTIONS(5304),
    [anon_sym_DOLLARinfo] = ACTIONS(5304),
    [anon_sym_default] = ACTIONS(5306),
    [anon_sym_clocking] = ACTIONS(5306),
    [anon_sym_defparam] = ACTIONS(5306),
    [anon_sym_bind] = ACTIONS(5306),
    [anon_sym_rand] = ACTIONS(5306),
    [anon_sym_const] = ACTIONS(5306),
    [anon_sym_function] = ACTIONS(5306),
    [anon_sym_static] = ACTIONS(5306),
    [anon_sym_constraint] = ACTIONS(5306),
    [anon_sym_if] = ACTIONS(5306),
    [anon_sym_else] = ACTIONS(5306),
    [anon_sym_LBRACK] = ACTIONS(5304),
    [anon_sym_localparam] = ACTIONS(5306),
    [anon_sym_parameter] = ACTIONS(5306),
    [anon_sym_var] = ACTIONS(5306),
    [anon_sym_import] = ACTIONS(5306),
    [anon_sym_export] = ACTIONS(5306),
    [anon_sym_genvar] = ACTIONS(5306),
    [anon_sym_interconnect] = ACTIONS(5306),
    [anon_sym_typedef] = ACTIONS(5306),
    [anon_sym_enum] = ACTIONS(5306),
    [anon_sym_struct] = ACTIONS(5306),
    [anon_sym_union] = ACTIONS(5306),
    [anon_sym_nettype] = ACTIONS(5306),
    [anon_sym_automatic] = ACTIONS(5306),
    [anon_sym_string] = ACTIONS(5306),
    [anon_sym_chandle] = ACTIONS(5306),
    [anon_sym_event] = ACTIONS(5306),
    [anon_sym_byte] = ACTIONS(5306),
    [anon_sym_shortint] = ACTIONS(5306),
    [anon_sym_int] = ACTIONS(5306),
    [anon_sym_longint] = ACTIONS(5306),
    [anon_sym_integer] = ACTIONS(5306),
    [anon_sym_time] = ACTIONS(5306),
    [anon_sym_bit] = ACTIONS(5306),
    [anon_sym_logic] = ACTIONS(5306),
    [anon_sym_reg] = ACTIONS(5306),
    [anon_sym_shortreal] = ACTIONS(5306),
    [anon_sym_real] = ACTIONS(5306),
    [anon_sym_realtime] = ACTIONS(5306),
    [anon_sym_supply0] = ACTIONS(5306),
    [anon_sym_supply1] = ACTIONS(5306),
    [anon_sym_signed] = ACTIONS(5306),
    [anon_sym_unsigned] = ACTIONS(5306),
    [anon_sym_task] = ACTIONS(5306),
    [anon_sym_assert] = ACTIONS(5306),
    [anon_sym_property] = ACTIONS(5306),
    [anon_sym_assume] = ACTIONS(5306),
    [anon_sym_cover] = ACTIONS(5306),
    [anon_sym_sequence] = ACTIONS(5306),
    [anon_sym_restrict] = ACTIONS(5306),
    [anon_sym_not] = ACTIONS(5306),
    [anon_sym_or] = ACTIONS(5306),
    [anon_sym_and] = ACTIONS(5306),
    [anon_sym_case] = ACTIONS(5306),
    [anon_sym_always] = ACTIONS(5306),
    [anon_sym_covergroup] = ACTIONS(5306),
    [anon_sym_let] = ACTIONS(5306),
    [anon_sym_pulldown] = ACTIONS(5306),
    [anon_sym_pullup] = ACTIONS(5306),
    [anon_sym_cmos] = ACTIONS(5306),
    [anon_sym_rcmos] = ACTIONS(5306),
    [anon_sym_bufif0] = ACTIONS(5306),
    [anon_sym_bufif1] = ACTIONS(5306),
    [anon_sym_notif0] = ACTIONS(5306),
    [anon_sym_notif1] = ACTIONS(5306),
    [anon_sym_nmos] = ACTIONS(5306),
    [anon_sym_pmos] = ACTIONS(5306),
    [anon_sym_rnmos] = ACTIONS(5306),
    [anon_sym_rpmos] = ACTIONS(5306),
    [anon_sym_nand] = ACTIONS(5306),
    [anon_sym_nor] = ACTIONS(5306),
    [anon_sym_xor] = ACTIONS(5306),
    [anon_sym_xnor] = ACTIONS(5306),
    [anon_sym_buf] = ACTIONS(5306),
    [anon_sym_tranif0] = ACTIONS(5306),
    [anon_sym_tranif1] = ACTIONS(5306),
    [anon_sym_rtranif1] = ACTIONS(5306),
    [anon_sym_rtranif0] = ACTIONS(5306),
    [anon_sym_tran] = ACTIONS(5306),
    [anon_sym_rtran] = ACTIONS(5306),
    [anon_sym_generate] = ACTIONS(5306),
    [anon_sym_endgenerate] = ACTIONS(5306),
    [anon_sym_for] = ACTIONS(5306),
    [anon_sym_initial] = ACTIONS(5306),
    [anon_sym_assign] = ACTIONS(5306),
    [anon_sym_alias] = ACTIONS(5306),
    [anon_sym_always_comb] = ACTIONS(5306),
    [anon_sym_always_latch] = ACTIONS(5306),
    [anon_sym_always_ff] = ACTIONS(5306),
    [anon_sym_final] = ACTIONS(5306),
    [anon_sym_global] = ACTIONS(5306),
    [anon_sym_LPAREN_STAR] = ACTIONS(5304),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5304),
    [anon_sym_DOLLARunit] = ACTIONS(5304),
  },
  [4948] = {
    [sym_simple_identifier] = ACTIONS(4200),
    [anon_sym_wire] = ACTIONS(4200),
    [anon_sym_tri] = ACTIONS(4200),
    [anon_sym_tri0] = ACTIONS(4200),
    [anon_sym_tri1] = ACTIONS(4200),
    [anon_sym_wand] = ACTIONS(4200),
    [anon_sym_triand] = ACTIONS(4200),
    [anon_sym_wor] = ACTIONS(4200),
    [anon_sym_trior] = ACTIONS(4200),
    [anon_sym_trireg] = ACTIONS(4200),
    [anon_sym_uwire] = ACTIONS(4200),
    [anon_sym_SEMI] = ACTIONS(4198),
    [anon_sym_extern] = ACTIONS(4200),
    [anon_sym_interface] = ACTIONS(4200),
    [anon_sym_checker] = ACTIONS(4200),
    [anon_sym_virtual] = ACTIONS(4200),
    [anon_sym_class] = ACTIONS(4200),
    [anon_sym_type] = ACTIONS(4200),
    [anon_sym_DOLLARfatal] = ACTIONS(4198),
    [anon_sym_DOLLARerror] = ACTIONS(4198),
    [anon_sym_DOLLARwarning] = ACTIONS(4198),
    [anon_sym_DOLLARinfo] = ACTIONS(4198),
    [anon_sym_default] = ACTIONS(4200),
    [anon_sym_clocking] = ACTIONS(4200),
    [anon_sym_defparam] = ACTIONS(4200),
    [anon_sym_bind] = ACTIONS(4200),
    [anon_sym_rand] = ACTIONS(4200),
    [anon_sym_const] = ACTIONS(4200),
    [anon_sym_function] = ACTIONS(4200),
    [anon_sym_static] = ACTIONS(4200),
    [anon_sym_constraint] = ACTIONS(4200),
    [anon_sym_if] = ACTIONS(4200),
    [anon_sym_else] = ACTIONS(4200),
    [anon_sym_LBRACK] = ACTIONS(4198),
    [anon_sym_localparam] = ACTIONS(4200),
    [anon_sym_parameter] = ACTIONS(4200),
    [anon_sym_var] = ACTIONS(4200),
    [anon_sym_import] = ACTIONS(4200),
    [anon_sym_export] = ACTIONS(4200),
    [anon_sym_genvar] = ACTIONS(4200),
    [anon_sym_interconnect] = ACTIONS(4200),
    [anon_sym_typedef] = ACTIONS(4200),
    [anon_sym_enum] = ACTIONS(4200),
    [anon_sym_struct] = ACTIONS(4200),
    [anon_sym_union] = ACTIONS(4200),
    [anon_sym_nettype] = ACTIONS(4200),
    [anon_sym_automatic] = ACTIONS(4200),
    [anon_sym_string] = ACTIONS(4200),
    [anon_sym_chandle] = ACTIONS(4200),
    [anon_sym_event] = ACTIONS(4200),
    [anon_sym_byte] = ACTIONS(4200),
    [anon_sym_shortint] = ACTIONS(4200),
    [anon_sym_int] = ACTIONS(4200),
    [anon_sym_longint] = ACTIONS(4200),
    [anon_sym_integer] = ACTIONS(4200),
    [anon_sym_time] = ACTIONS(4200),
    [anon_sym_bit] = ACTIONS(4200),
    [anon_sym_logic] = ACTIONS(4200),
    [anon_sym_reg] = ACTIONS(4200),
    [anon_sym_shortreal] = ACTIONS(4200),
    [anon_sym_real] = ACTIONS(4200),
    [anon_sym_realtime] = ACTIONS(4200),
    [anon_sym_supply0] = ACTIONS(4200),
    [anon_sym_supply1] = ACTIONS(4200),
    [anon_sym_signed] = ACTIONS(4200),
    [anon_sym_unsigned] = ACTIONS(4200),
    [anon_sym_task] = ACTIONS(4200),
    [anon_sym_assert] = ACTIONS(4200),
    [anon_sym_property] = ACTIONS(4200),
    [anon_sym_assume] = ACTIONS(4200),
    [anon_sym_cover] = ACTIONS(4200),
    [anon_sym_sequence] = ACTIONS(4200),
    [anon_sym_restrict] = ACTIONS(4200),
    [anon_sym_not] = ACTIONS(4200),
    [anon_sym_or] = ACTIONS(4200),
    [anon_sym_and] = ACTIONS(4200),
    [anon_sym_case] = ACTIONS(4200),
    [anon_sym_always] = ACTIONS(4200),
    [anon_sym_covergroup] = ACTIONS(4200),
    [anon_sym_end] = ACTIONS(4200),
    [anon_sym_let] = ACTIONS(4200),
    [anon_sym_pulldown] = ACTIONS(4200),
    [anon_sym_pullup] = ACTIONS(4200),
    [anon_sym_cmos] = ACTIONS(4200),
    [anon_sym_rcmos] = ACTIONS(4200),
    [anon_sym_bufif0] = ACTIONS(4200),
    [anon_sym_bufif1] = ACTIONS(4200),
    [anon_sym_notif0] = ACTIONS(4200),
    [anon_sym_notif1] = ACTIONS(4200),
    [anon_sym_nmos] = ACTIONS(4200),
    [anon_sym_pmos] = ACTIONS(4200),
    [anon_sym_rnmos] = ACTIONS(4200),
    [anon_sym_rpmos] = ACTIONS(4200),
    [anon_sym_nand] = ACTIONS(4200),
    [anon_sym_nor] = ACTIONS(4200),
    [anon_sym_xor] = ACTIONS(4200),
    [anon_sym_xnor] = ACTIONS(4200),
    [anon_sym_buf] = ACTIONS(4200),
    [anon_sym_tranif0] = ACTIONS(4200),
    [anon_sym_tranif1] = ACTIONS(4200),
    [anon_sym_rtranif1] = ACTIONS(4200),
    [anon_sym_rtranif0] = ACTIONS(4200),
    [anon_sym_tran] = ACTIONS(4200),
    [anon_sym_rtran] = ACTIONS(4200),
    [anon_sym_generate] = ACTIONS(4200),
    [anon_sym_for] = ACTIONS(4200),
    [anon_sym_initial] = ACTIONS(4200),
    [anon_sym_assign] = ACTIONS(4200),
    [anon_sym_alias] = ACTIONS(4200),
    [anon_sym_always_comb] = ACTIONS(4200),
    [anon_sym_always_latch] = ACTIONS(4200),
    [anon_sym_always_ff] = ACTIONS(4200),
    [anon_sym_final] = ACTIONS(4200),
    [anon_sym_global] = ACTIONS(4200),
    [anon_sym_LPAREN_STAR] = ACTIONS(4198),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4198),
    [anon_sym_DOLLARunit] = ACTIONS(4198),
  },
  [4949] = {
    [sym_simple_identifier] = ACTIONS(4940),
    [anon_sym_wire] = ACTIONS(4940),
    [anon_sym_tri] = ACTIONS(4940),
    [anon_sym_tri0] = ACTIONS(4940),
    [anon_sym_tri1] = ACTIONS(4940),
    [anon_sym_wand] = ACTIONS(4940),
    [anon_sym_triand] = ACTIONS(4940),
    [anon_sym_wor] = ACTIONS(4940),
    [anon_sym_trior] = ACTIONS(4940),
    [anon_sym_trireg] = ACTIONS(4940),
    [anon_sym_uwire] = ACTIONS(4940),
    [anon_sym_SEMI] = ACTIONS(4938),
    [anon_sym_extern] = ACTIONS(4940),
    [anon_sym_interface] = ACTIONS(4940),
    [anon_sym_checker] = ACTIONS(4940),
    [anon_sym_virtual] = ACTIONS(4940),
    [anon_sym_class] = ACTIONS(4940),
    [anon_sym_type] = ACTIONS(4940),
    [anon_sym_DOLLARfatal] = ACTIONS(4938),
    [anon_sym_DOLLARerror] = ACTIONS(4938),
    [anon_sym_DOLLARwarning] = ACTIONS(4938),
    [anon_sym_DOLLARinfo] = ACTIONS(4938),
    [anon_sym_default] = ACTIONS(4940),
    [anon_sym_clocking] = ACTIONS(4940),
    [anon_sym_defparam] = ACTIONS(4940),
    [anon_sym_bind] = ACTIONS(4940),
    [anon_sym_rand] = ACTIONS(4940),
    [anon_sym_const] = ACTIONS(4940),
    [anon_sym_function] = ACTIONS(4940),
    [anon_sym_static] = ACTIONS(4940),
    [anon_sym_constraint] = ACTIONS(4940),
    [anon_sym_if] = ACTIONS(4940),
    [anon_sym_else] = ACTIONS(4940),
    [anon_sym_LBRACK] = ACTIONS(4938),
    [anon_sym_localparam] = ACTIONS(4940),
    [anon_sym_parameter] = ACTIONS(4940),
    [anon_sym_var] = ACTIONS(4940),
    [anon_sym_import] = ACTIONS(4940),
    [anon_sym_export] = ACTIONS(4940),
    [anon_sym_genvar] = ACTIONS(4940),
    [anon_sym_interconnect] = ACTIONS(4940),
    [anon_sym_typedef] = ACTIONS(4940),
    [anon_sym_enum] = ACTIONS(4940),
    [anon_sym_struct] = ACTIONS(4940),
    [anon_sym_union] = ACTIONS(4940),
    [anon_sym_nettype] = ACTIONS(4940),
    [anon_sym_automatic] = ACTIONS(4940),
    [anon_sym_string] = ACTIONS(4940),
    [anon_sym_chandle] = ACTIONS(4940),
    [anon_sym_event] = ACTIONS(4940),
    [anon_sym_byte] = ACTIONS(4940),
    [anon_sym_shortint] = ACTIONS(4940),
    [anon_sym_int] = ACTIONS(4940),
    [anon_sym_longint] = ACTIONS(4940),
    [anon_sym_integer] = ACTIONS(4940),
    [anon_sym_time] = ACTIONS(4940),
    [anon_sym_bit] = ACTIONS(4940),
    [anon_sym_logic] = ACTIONS(4940),
    [anon_sym_reg] = ACTIONS(4940),
    [anon_sym_shortreal] = ACTIONS(4940),
    [anon_sym_real] = ACTIONS(4940),
    [anon_sym_realtime] = ACTIONS(4940),
    [anon_sym_supply0] = ACTIONS(4940),
    [anon_sym_supply1] = ACTIONS(4940),
    [anon_sym_signed] = ACTIONS(4940),
    [anon_sym_unsigned] = ACTIONS(4940),
    [anon_sym_task] = ACTIONS(4940),
    [anon_sym_assert] = ACTIONS(4940),
    [anon_sym_property] = ACTIONS(4940),
    [anon_sym_assume] = ACTIONS(4940),
    [anon_sym_cover] = ACTIONS(4940),
    [anon_sym_sequence] = ACTIONS(4940),
    [anon_sym_restrict] = ACTIONS(4940),
    [anon_sym_not] = ACTIONS(4940),
    [anon_sym_or] = ACTIONS(4940),
    [anon_sym_and] = ACTIONS(4940),
    [anon_sym_case] = ACTIONS(4940),
    [anon_sym_always] = ACTIONS(4940),
    [anon_sym_covergroup] = ACTIONS(4940),
    [anon_sym_end] = ACTIONS(4940),
    [anon_sym_let] = ACTIONS(4940),
    [anon_sym_pulldown] = ACTIONS(4940),
    [anon_sym_pullup] = ACTIONS(4940),
    [anon_sym_cmos] = ACTIONS(4940),
    [anon_sym_rcmos] = ACTIONS(4940),
    [anon_sym_bufif0] = ACTIONS(4940),
    [anon_sym_bufif1] = ACTIONS(4940),
    [anon_sym_notif0] = ACTIONS(4940),
    [anon_sym_notif1] = ACTIONS(4940),
    [anon_sym_nmos] = ACTIONS(4940),
    [anon_sym_pmos] = ACTIONS(4940),
    [anon_sym_rnmos] = ACTIONS(4940),
    [anon_sym_rpmos] = ACTIONS(4940),
    [anon_sym_nand] = ACTIONS(4940),
    [anon_sym_nor] = ACTIONS(4940),
    [anon_sym_xor] = ACTIONS(4940),
    [anon_sym_xnor] = ACTIONS(4940),
    [anon_sym_buf] = ACTIONS(4940),
    [anon_sym_tranif0] = ACTIONS(4940),
    [anon_sym_tranif1] = ACTIONS(4940),
    [anon_sym_rtranif1] = ACTIONS(4940),
    [anon_sym_rtranif0] = ACTIONS(4940),
    [anon_sym_tran] = ACTIONS(4940),
    [anon_sym_rtran] = ACTIONS(4940),
    [anon_sym_generate] = ACTIONS(4940),
    [anon_sym_for] = ACTIONS(4940),
    [anon_sym_initial] = ACTIONS(4940),
    [anon_sym_assign] = ACTIONS(4940),
    [anon_sym_alias] = ACTIONS(4940),
    [anon_sym_always_comb] = ACTIONS(4940),
    [anon_sym_always_latch] = ACTIONS(4940),
    [anon_sym_always_ff] = ACTIONS(4940),
    [anon_sym_final] = ACTIONS(4940),
    [anon_sym_global] = ACTIONS(4940),
    [anon_sym_LPAREN_STAR] = ACTIONS(4938),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4938),
    [anon_sym_DOLLARunit] = ACTIONS(4938),
  },
  [4950] = {
    [sym_simple_identifier] = ACTIONS(4512),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_rand] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_endgenerate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [4951] = {
    [sym_simple_identifier] = ACTIONS(6225),
    [anon_sym_wire] = ACTIONS(6225),
    [anon_sym_tri] = ACTIONS(6225),
    [anon_sym_tri0] = ACTIONS(6225),
    [anon_sym_tri1] = ACTIONS(6225),
    [anon_sym_wand] = ACTIONS(6225),
    [anon_sym_triand] = ACTIONS(6225),
    [anon_sym_wor] = ACTIONS(6225),
    [anon_sym_trior] = ACTIONS(6225),
    [anon_sym_trireg] = ACTIONS(6225),
    [anon_sym_uwire] = ACTIONS(6225),
    [anon_sym_SEMI] = ACTIONS(6227),
    [anon_sym_extern] = ACTIONS(6225),
    [anon_sym_interface] = ACTIONS(6225),
    [anon_sym_checker] = ACTIONS(6225),
    [anon_sym_virtual] = ACTIONS(6225),
    [anon_sym_class] = ACTIONS(6225),
    [anon_sym_type] = ACTIONS(6225),
    [anon_sym_DOLLARfatal] = ACTIONS(6227),
    [anon_sym_DOLLARerror] = ACTIONS(6227),
    [anon_sym_DOLLARwarning] = ACTIONS(6227),
    [anon_sym_DOLLARinfo] = ACTIONS(6227),
    [anon_sym_default] = ACTIONS(6225),
    [anon_sym_clocking] = ACTIONS(6225),
    [anon_sym_defparam] = ACTIONS(6225),
    [anon_sym_bind] = ACTIONS(6225),
    [anon_sym_rand] = ACTIONS(6225),
    [anon_sym_const] = ACTIONS(6225),
    [anon_sym_function] = ACTIONS(6225),
    [anon_sym_static] = ACTIONS(6225),
    [anon_sym_constraint] = ACTIONS(6225),
    [anon_sym_if] = ACTIONS(6225),
    [anon_sym_else] = ACTIONS(6225),
    [anon_sym_LBRACK] = ACTIONS(6227),
    [anon_sym_localparam] = ACTIONS(6225),
    [anon_sym_parameter] = ACTIONS(6225),
    [anon_sym_var] = ACTIONS(6225),
    [anon_sym_import] = ACTIONS(6225),
    [anon_sym_export] = ACTIONS(6225),
    [anon_sym_genvar] = ACTIONS(6225),
    [anon_sym_interconnect] = ACTIONS(6225),
    [anon_sym_typedef] = ACTIONS(6225),
    [anon_sym_enum] = ACTIONS(6225),
    [anon_sym_struct] = ACTIONS(6225),
    [anon_sym_union] = ACTIONS(6225),
    [anon_sym_nettype] = ACTIONS(6225),
    [anon_sym_automatic] = ACTIONS(6225),
    [anon_sym_string] = ACTIONS(6225),
    [anon_sym_chandle] = ACTIONS(6225),
    [anon_sym_event] = ACTIONS(6225),
    [anon_sym_byte] = ACTIONS(6225),
    [anon_sym_shortint] = ACTIONS(6225),
    [anon_sym_int] = ACTIONS(6225),
    [anon_sym_longint] = ACTIONS(6225),
    [anon_sym_integer] = ACTIONS(6225),
    [anon_sym_time] = ACTIONS(6225),
    [anon_sym_bit] = ACTIONS(6225),
    [anon_sym_logic] = ACTIONS(6225),
    [anon_sym_reg] = ACTIONS(6225),
    [anon_sym_shortreal] = ACTIONS(6225),
    [anon_sym_real] = ACTIONS(6225),
    [anon_sym_realtime] = ACTIONS(6225),
    [anon_sym_supply0] = ACTIONS(6225),
    [anon_sym_supply1] = ACTIONS(6225),
    [anon_sym_signed] = ACTIONS(6225),
    [anon_sym_unsigned] = ACTIONS(6225),
    [anon_sym_task] = ACTIONS(6225),
    [anon_sym_assert] = ACTIONS(6225),
    [anon_sym_property] = ACTIONS(6225),
    [anon_sym_assume] = ACTIONS(6225),
    [anon_sym_cover] = ACTIONS(6225),
    [anon_sym_sequence] = ACTIONS(6225),
    [anon_sym_restrict] = ACTIONS(6225),
    [anon_sym_not] = ACTIONS(6225),
    [anon_sym_or] = ACTIONS(6225),
    [anon_sym_and] = ACTIONS(6225),
    [anon_sym_case] = ACTIONS(6225),
    [anon_sym_always] = ACTIONS(6225),
    [anon_sym_covergroup] = ACTIONS(6225),
    [anon_sym_end] = ACTIONS(6225),
    [anon_sym_let] = ACTIONS(6225),
    [anon_sym_pulldown] = ACTIONS(6225),
    [anon_sym_pullup] = ACTIONS(6225),
    [anon_sym_cmos] = ACTIONS(6225),
    [anon_sym_rcmos] = ACTIONS(6225),
    [anon_sym_bufif0] = ACTIONS(6225),
    [anon_sym_bufif1] = ACTIONS(6225),
    [anon_sym_notif0] = ACTIONS(6225),
    [anon_sym_notif1] = ACTIONS(6225),
    [anon_sym_nmos] = ACTIONS(6225),
    [anon_sym_pmos] = ACTIONS(6225),
    [anon_sym_rnmos] = ACTIONS(6225),
    [anon_sym_rpmos] = ACTIONS(6225),
    [anon_sym_nand] = ACTIONS(6225),
    [anon_sym_nor] = ACTIONS(6225),
    [anon_sym_xor] = ACTIONS(6225),
    [anon_sym_xnor] = ACTIONS(6225),
    [anon_sym_buf] = ACTIONS(6225),
    [anon_sym_tranif0] = ACTIONS(6225),
    [anon_sym_tranif1] = ACTIONS(6225),
    [anon_sym_rtranif1] = ACTIONS(6225),
    [anon_sym_rtranif0] = ACTIONS(6225),
    [anon_sym_tran] = ACTIONS(6225),
    [anon_sym_rtran] = ACTIONS(6225),
    [anon_sym_generate] = ACTIONS(6225),
    [anon_sym_for] = ACTIONS(6225),
    [anon_sym_initial] = ACTIONS(6225),
    [anon_sym_assign] = ACTIONS(6225),
    [anon_sym_alias] = ACTIONS(6225),
    [anon_sym_always_comb] = ACTIONS(6225),
    [anon_sym_always_latch] = ACTIONS(6225),
    [anon_sym_always_ff] = ACTIONS(6225),
    [anon_sym_final] = ACTIONS(6225),
    [anon_sym_global] = ACTIONS(6225),
    [anon_sym_LPAREN_STAR] = ACTIONS(6227),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6227),
    [anon_sym_DOLLARunit] = ACTIONS(6227),
  },
  [4952] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11177),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [4953] = {
    [sym_simple_identifier] = ACTIONS(6799),
    [anon_sym_wire] = ACTIONS(6799),
    [anon_sym_tri] = ACTIONS(6799),
    [anon_sym_tri0] = ACTIONS(6799),
    [anon_sym_tri1] = ACTIONS(6799),
    [anon_sym_wand] = ACTIONS(6799),
    [anon_sym_triand] = ACTIONS(6799),
    [anon_sym_wor] = ACTIONS(6799),
    [anon_sym_trior] = ACTIONS(6799),
    [anon_sym_trireg] = ACTIONS(6799),
    [anon_sym_uwire] = ACTIONS(6799),
    [anon_sym_SEMI] = ACTIONS(6801),
    [anon_sym_extern] = ACTIONS(6799),
    [anon_sym_interface] = ACTIONS(6799),
    [anon_sym_checker] = ACTIONS(6799),
    [anon_sym_virtual] = ACTIONS(6799),
    [anon_sym_class] = ACTIONS(6799),
    [anon_sym_type] = ACTIONS(6799),
    [anon_sym_DOLLARfatal] = ACTIONS(6801),
    [anon_sym_DOLLARerror] = ACTIONS(6801),
    [anon_sym_DOLLARwarning] = ACTIONS(6801),
    [anon_sym_DOLLARinfo] = ACTIONS(6801),
    [anon_sym_default] = ACTIONS(6799),
    [anon_sym_clocking] = ACTIONS(6799),
    [anon_sym_defparam] = ACTIONS(6799),
    [anon_sym_bind] = ACTIONS(6799),
    [anon_sym_rand] = ACTIONS(6799),
    [anon_sym_const] = ACTIONS(6799),
    [anon_sym_function] = ACTIONS(6799),
    [anon_sym_static] = ACTIONS(6799),
    [anon_sym_constraint] = ACTIONS(6799),
    [anon_sym_if] = ACTIONS(6799),
    [anon_sym_else] = ACTIONS(6799),
    [anon_sym_LBRACK] = ACTIONS(6801),
    [anon_sym_localparam] = ACTIONS(6799),
    [anon_sym_parameter] = ACTIONS(6799),
    [anon_sym_var] = ACTIONS(6799),
    [anon_sym_import] = ACTIONS(6799),
    [anon_sym_export] = ACTIONS(6799),
    [anon_sym_genvar] = ACTIONS(6799),
    [anon_sym_interconnect] = ACTIONS(6799),
    [anon_sym_typedef] = ACTIONS(6799),
    [anon_sym_enum] = ACTIONS(6799),
    [anon_sym_struct] = ACTIONS(6799),
    [anon_sym_union] = ACTIONS(6799),
    [anon_sym_nettype] = ACTIONS(6799),
    [anon_sym_automatic] = ACTIONS(6799),
    [anon_sym_string] = ACTIONS(6799),
    [anon_sym_chandle] = ACTIONS(6799),
    [anon_sym_event] = ACTIONS(6799),
    [anon_sym_byte] = ACTIONS(6799),
    [anon_sym_shortint] = ACTIONS(6799),
    [anon_sym_int] = ACTIONS(6799),
    [anon_sym_longint] = ACTIONS(6799),
    [anon_sym_integer] = ACTIONS(6799),
    [anon_sym_time] = ACTIONS(6799),
    [anon_sym_bit] = ACTIONS(6799),
    [anon_sym_logic] = ACTIONS(6799),
    [anon_sym_reg] = ACTIONS(6799),
    [anon_sym_shortreal] = ACTIONS(6799),
    [anon_sym_real] = ACTIONS(6799),
    [anon_sym_realtime] = ACTIONS(6799),
    [anon_sym_supply0] = ACTIONS(6799),
    [anon_sym_supply1] = ACTIONS(6799),
    [anon_sym_signed] = ACTIONS(6799),
    [anon_sym_unsigned] = ACTIONS(6799),
    [anon_sym_task] = ACTIONS(6799),
    [anon_sym_assert] = ACTIONS(6799),
    [anon_sym_property] = ACTIONS(6799),
    [anon_sym_assume] = ACTIONS(6799),
    [anon_sym_cover] = ACTIONS(6799),
    [anon_sym_sequence] = ACTIONS(6799),
    [anon_sym_restrict] = ACTIONS(6799),
    [anon_sym_not] = ACTIONS(6799),
    [anon_sym_or] = ACTIONS(6799),
    [anon_sym_and] = ACTIONS(6799),
    [anon_sym_case] = ACTIONS(6799),
    [anon_sym_always] = ACTIONS(6799),
    [anon_sym_covergroup] = ACTIONS(6799),
    [anon_sym_let] = ACTIONS(6799),
    [anon_sym_pulldown] = ACTIONS(6799),
    [anon_sym_pullup] = ACTIONS(6799),
    [anon_sym_cmos] = ACTIONS(6799),
    [anon_sym_rcmos] = ACTIONS(6799),
    [anon_sym_bufif0] = ACTIONS(6799),
    [anon_sym_bufif1] = ACTIONS(6799),
    [anon_sym_notif0] = ACTIONS(6799),
    [anon_sym_notif1] = ACTIONS(6799),
    [anon_sym_nmos] = ACTIONS(6799),
    [anon_sym_pmos] = ACTIONS(6799),
    [anon_sym_rnmos] = ACTIONS(6799),
    [anon_sym_rpmos] = ACTIONS(6799),
    [anon_sym_nand] = ACTIONS(6799),
    [anon_sym_nor] = ACTIONS(6799),
    [anon_sym_xor] = ACTIONS(6799),
    [anon_sym_xnor] = ACTIONS(6799),
    [anon_sym_buf] = ACTIONS(6799),
    [anon_sym_tranif0] = ACTIONS(6799),
    [anon_sym_tranif1] = ACTIONS(6799),
    [anon_sym_rtranif1] = ACTIONS(6799),
    [anon_sym_rtranif0] = ACTIONS(6799),
    [anon_sym_tran] = ACTIONS(6799),
    [anon_sym_rtran] = ACTIONS(6799),
    [anon_sym_generate] = ACTIONS(6799),
    [anon_sym_endgenerate] = ACTIONS(6799),
    [anon_sym_for] = ACTIONS(6799),
    [anon_sym_initial] = ACTIONS(6799),
    [anon_sym_assign] = ACTIONS(6799),
    [anon_sym_alias] = ACTIONS(6799),
    [anon_sym_always_comb] = ACTIONS(6799),
    [anon_sym_always_latch] = ACTIONS(6799),
    [anon_sym_always_ff] = ACTIONS(6799),
    [anon_sym_final] = ACTIONS(6799),
    [anon_sym_global] = ACTIONS(6799),
    [anon_sym_LPAREN_STAR] = ACTIONS(6801),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6801),
    [anon_sym_DOLLARunit] = ACTIONS(6801),
  },
  [4954] = {
    [sym_simple_identifier] = ACTIONS(6523),
    [anon_sym_wire] = ACTIONS(6523),
    [anon_sym_tri] = ACTIONS(6523),
    [anon_sym_tri0] = ACTIONS(6523),
    [anon_sym_tri1] = ACTIONS(6523),
    [anon_sym_wand] = ACTIONS(6523),
    [anon_sym_triand] = ACTIONS(6523),
    [anon_sym_wor] = ACTIONS(6523),
    [anon_sym_trior] = ACTIONS(6523),
    [anon_sym_trireg] = ACTIONS(6523),
    [anon_sym_uwire] = ACTIONS(6523),
    [anon_sym_SEMI] = ACTIONS(6526),
    [anon_sym_extern] = ACTIONS(6523),
    [anon_sym_interface] = ACTIONS(6523),
    [anon_sym_checker] = ACTIONS(6523),
    [anon_sym_virtual] = ACTIONS(6523),
    [anon_sym_class] = ACTIONS(6523),
    [anon_sym_type] = ACTIONS(6523),
    [anon_sym_DOLLARfatal] = ACTIONS(6526),
    [anon_sym_DOLLARerror] = ACTIONS(6526),
    [anon_sym_DOLLARwarning] = ACTIONS(6526),
    [anon_sym_DOLLARinfo] = ACTIONS(6526),
    [anon_sym_default] = ACTIONS(6523),
    [anon_sym_clocking] = ACTIONS(6523),
    [anon_sym_defparam] = ACTIONS(6523),
    [anon_sym_bind] = ACTIONS(6523),
    [anon_sym_rand] = ACTIONS(6523),
    [anon_sym_const] = ACTIONS(6523),
    [anon_sym_function] = ACTIONS(6523),
    [anon_sym_static] = ACTIONS(6523),
    [anon_sym_constraint] = ACTIONS(6523),
    [anon_sym_if] = ACTIONS(6523),
    [anon_sym_else] = ACTIONS(6523),
    [anon_sym_LBRACK] = ACTIONS(6526),
    [anon_sym_localparam] = ACTIONS(6523),
    [anon_sym_parameter] = ACTIONS(6523),
    [anon_sym_var] = ACTIONS(6523),
    [anon_sym_import] = ACTIONS(6523),
    [anon_sym_export] = ACTIONS(6523),
    [anon_sym_genvar] = ACTIONS(6523),
    [anon_sym_interconnect] = ACTIONS(6523),
    [anon_sym_typedef] = ACTIONS(6523),
    [anon_sym_enum] = ACTIONS(6523),
    [anon_sym_struct] = ACTIONS(6523),
    [anon_sym_union] = ACTIONS(6523),
    [anon_sym_nettype] = ACTIONS(6523),
    [anon_sym_automatic] = ACTIONS(6523),
    [anon_sym_string] = ACTIONS(6523),
    [anon_sym_chandle] = ACTIONS(6523),
    [anon_sym_event] = ACTIONS(6523),
    [anon_sym_byte] = ACTIONS(6523),
    [anon_sym_shortint] = ACTIONS(6523),
    [anon_sym_int] = ACTIONS(6523),
    [anon_sym_longint] = ACTIONS(6523),
    [anon_sym_integer] = ACTIONS(6523),
    [anon_sym_time] = ACTIONS(6523),
    [anon_sym_bit] = ACTIONS(6523),
    [anon_sym_logic] = ACTIONS(6523),
    [anon_sym_reg] = ACTIONS(6523),
    [anon_sym_shortreal] = ACTIONS(6523),
    [anon_sym_real] = ACTIONS(6523),
    [anon_sym_realtime] = ACTIONS(6523),
    [anon_sym_supply0] = ACTIONS(6523),
    [anon_sym_supply1] = ACTIONS(6523),
    [anon_sym_signed] = ACTIONS(6523),
    [anon_sym_unsigned] = ACTIONS(6523),
    [anon_sym_task] = ACTIONS(6523),
    [anon_sym_assert] = ACTIONS(6523),
    [anon_sym_property] = ACTIONS(6523),
    [anon_sym_assume] = ACTIONS(6523),
    [anon_sym_cover] = ACTIONS(6523),
    [anon_sym_sequence] = ACTIONS(6523),
    [anon_sym_restrict] = ACTIONS(6523),
    [anon_sym_not] = ACTIONS(6523),
    [anon_sym_or] = ACTIONS(6523),
    [anon_sym_and] = ACTIONS(6523),
    [anon_sym_case] = ACTIONS(6523),
    [anon_sym_always] = ACTIONS(6523),
    [anon_sym_covergroup] = ACTIONS(6523),
    [anon_sym_let] = ACTIONS(6523),
    [anon_sym_pulldown] = ACTIONS(6523),
    [anon_sym_pullup] = ACTIONS(6523),
    [anon_sym_cmos] = ACTIONS(6523),
    [anon_sym_rcmos] = ACTIONS(6523),
    [anon_sym_bufif0] = ACTIONS(6523),
    [anon_sym_bufif1] = ACTIONS(6523),
    [anon_sym_notif0] = ACTIONS(6523),
    [anon_sym_notif1] = ACTIONS(6523),
    [anon_sym_nmos] = ACTIONS(6523),
    [anon_sym_pmos] = ACTIONS(6523),
    [anon_sym_rnmos] = ACTIONS(6523),
    [anon_sym_rpmos] = ACTIONS(6523),
    [anon_sym_nand] = ACTIONS(6523),
    [anon_sym_nor] = ACTIONS(6523),
    [anon_sym_xor] = ACTIONS(6523),
    [anon_sym_xnor] = ACTIONS(6523),
    [anon_sym_buf] = ACTIONS(6523),
    [anon_sym_tranif0] = ACTIONS(6523),
    [anon_sym_tranif1] = ACTIONS(6523),
    [anon_sym_rtranif1] = ACTIONS(6523),
    [anon_sym_rtranif0] = ACTIONS(6523),
    [anon_sym_tran] = ACTIONS(6523),
    [anon_sym_rtran] = ACTIONS(6523),
    [anon_sym_generate] = ACTIONS(6523),
    [anon_sym_endgenerate] = ACTIONS(6523),
    [anon_sym_for] = ACTIONS(6523),
    [anon_sym_initial] = ACTIONS(6523),
    [anon_sym_assign] = ACTIONS(6523),
    [anon_sym_alias] = ACTIONS(6523),
    [anon_sym_always_comb] = ACTIONS(6523),
    [anon_sym_always_latch] = ACTIONS(6523),
    [anon_sym_always_ff] = ACTIONS(6523),
    [anon_sym_final] = ACTIONS(6523),
    [anon_sym_global] = ACTIONS(6523),
    [anon_sym_LPAREN_STAR] = ACTIONS(6526),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6526),
    [anon_sym_DOLLARunit] = ACTIONS(6526),
  },
  [4955] = {
    [sym_simple_identifier] = ACTIONS(4964),
    [anon_sym_wire] = ACTIONS(4964),
    [anon_sym_tri] = ACTIONS(4964),
    [anon_sym_tri0] = ACTIONS(4964),
    [anon_sym_tri1] = ACTIONS(4964),
    [anon_sym_wand] = ACTIONS(4964),
    [anon_sym_triand] = ACTIONS(4964),
    [anon_sym_wor] = ACTIONS(4964),
    [anon_sym_trior] = ACTIONS(4964),
    [anon_sym_trireg] = ACTIONS(4964),
    [anon_sym_uwire] = ACTIONS(4964),
    [anon_sym_SEMI] = ACTIONS(4962),
    [anon_sym_extern] = ACTIONS(4964),
    [anon_sym_interface] = ACTIONS(4964),
    [anon_sym_checker] = ACTIONS(4964),
    [anon_sym_virtual] = ACTIONS(4964),
    [anon_sym_class] = ACTIONS(4964),
    [anon_sym_type] = ACTIONS(4964),
    [anon_sym_DOLLARfatal] = ACTIONS(4962),
    [anon_sym_DOLLARerror] = ACTIONS(4962),
    [anon_sym_DOLLARwarning] = ACTIONS(4962),
    [anon_sym_DOLLARinfo] = ACTIONS(4962),
    [anon_sym_default] = ACTIONS(4964),
    [anon_sym_clocking] = ACTIONS(4964),
    [anon_sym_defparam] = ACTIONS(4964),
    [anon_sym_bind] = ACTIONS(4964),
    [anon_sym_rand] = ACTIONS(4964),
    [anon_sym_const] = ACTIONS(4964),
    [anon_sym_function] = ACTIONS(4964),
    [anon_sym_static] = ACTIONS(4964),
    [anon_sym_constraint] = ACTIONS(4964),
    [anon_sym_if] = ACTIONS(4964),
    [anon_sym_else] = ACTIONS(4964),
    [anon_sym_LBRACK] = ACTIONS(4962),
    [anon_sym_localparam] = ACTIONS(4964),
    [anon_sym_parameter] = ACTIONS(4964),
    [anon_sym_var] = ACTIONS(4964),
    [anon_sym_import] = ACTIONS(4964),
    [anon_sym_export] = ACTIONS(4964),
    [anon_sym_genvar] = ACTIONS(4964),
    [anon_sym_interconnect] = ACTIONS(4964),
    [anon_sym_typedef] = ACTIONS(4964),
    [anon_sym_enum] = ACTIONS(4964),
    [anon_sym_struct] = ACTIONS(4964),
    [anon_sym_union] = ACTIONS(4964),
    [anon_sym_nettype] = ACTIONS(4964),
    [anon_sym_automatic] = ACTIONS(4964),
    [anon_sym_string] = ACTIONS(4964),
    [anon_sym_chandle] = ACTIONS(4964),
    [anon_sym_event] = ACTIONS(4964),
    [anon_sym_byte] = ACTIONS(4964),
    [anon_sym_shortint] = ACTIONS(4964),
    [anon_sym_int] = ACTIONS(4964),
    [anon_sym_longint] = ACTIONS(4964),
    [anon_sym_integer] = ACTIONS(4964),
    [anon_sym_time] = ACTIONS(4964),
    [anon_sym_bit] = ACTIONS(4964),
    [anon_sym_logic] = ACTIONS(4964),
    [anon_sym_reg] = ACTIONS(4964),
    [anon_sym_shortreal] = ACTIONS(4964),
    [anon_sym_real] = ACTIONS(4964),
    [anon_sym_realtime] = ACTIONS(4964),
    [anon_sym_supply0] = ACTIONS(4964),
    [anon_sym_supply1] = ACTIONS(4964),
    [anon_sym_signed] = ACTIONS(4964),
    [anon_sym_unsigned] = ACTIONS(4964),
    [anon_sym_task] = ACTIONS(4964),
    [anon_sym_assert] = ACTIONS(4964),
    [anon_sym_property] = ACTIONS(4964),
    [anon_sym_assume] = ACTIONS(4964),
    [anon_sym_cover] = ACTIONS(4964),
    [anon_sym_sequence] = ACTIONS(4964),
    [anon_sym_restrict] = ACTIONS(4964),
    [anon_sym_not] = ACTIONS(4964),
    [anon_sym_or] = ACTIONS(4964),
    [anon_sym_and] = ACTIONS(4964),
    [anon_sym_case] = ACTIONS(4964),
    [anon_sym_always] = ACTIONS(4964),
    [anon_sym_covergroup] = ACTIONS(4964),
    [anon_sym_let] = ACTIONS(4964),
    [anon_sym_pulldown] = ACTIONS(4964),
    [anon_sym_pullup] = ACTIONS(4964),
    [anon_sym_cmos] = ACTIONS(4964),
    [anon_sym_rcmos] = ACTIONS(4964),
    [anon_sym_bufif0] = ACTIONS(4964),
    [anon_sym_bufif1] = ACTIONS(4964),
    [anon_sym_notif0] = ACTIONS(4964),
    [anon_sym_notif1] = ACTIONS(4964),
    [anon_sym_nmos] = ACTIONS(4964),
    [anon_sym_pmos] = ACTIONS(4964),
    [anon_sym_rnmos] = ACTIONS(4964),
    [anon_sym_rpmos] = ACTIONS(4964),
    [anon_sym_nand] = ACTIONS(4964),
    [anon_sym_nor] = ACTIONS(4964),
    [anon_sym_xor] = ACTIONS(4964),
    [anon_sym_xnor] = ACTIONS(4964),
    [anon_sym_buf] = ACTIONS(4964),
    [anon_sym_tranif0] = ACTIONS(4964),
    [anon_sym_tranif1] = ACTIONS(4964),
    [anon_sym_rtranif1] = ACTIONS(4964),
    [anon_sym_rtranif0] = ACTIONS(4964),
    [anon_sym_tran] = ACTIONS(4964),
    [anon_sym_rtran] = ACTIONS(4964),
    [anon_sym_generate] = ACTIONS(4964),
    [anon_sym_endgenerate] = ACTIONS(4964),
    [anon_sym_for] = ACTIONS(4964),
    [anon_sym_initial] = ACTIONS(4964),
    [anon_sym_assign] = ACTIONS(4964),
    [anon_sym_alias] = ACTIONS(4964),
    [anon_sym_always_comb] = ACTIONS(4964),
    [anon_sym_always_latch] = ACTIONS(4964),
    [anon_sym_always_ff] = ACTIONS(4964),
    [anon_sym_final] = ACTIONS(4964),
    [anon_sym_global] = ACTIONS(4964),
    [anon_sym_LPAREN_STAR] = ACTIONS(4962),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4962),
    [anon_sym_DOLLARunit] = ACTIONS(4962),
  },
  [4956] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4759),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4759),
    [sym_package_or_generate_item_declaration] = STATE(4759),
    [sym_anonymous_program] = STATE(4759),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4759),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4759),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(10893),
    [anon_sym_wire] = ACTIONS(10896),
    [anon_sym_tri] = ACTIONS(10896),
    [anon_sym_tri0] = ACTIONS(10896),
    [anon_sym_tri1] = ACTIONS(10896),
    [anon_sym_wand] = ACTIONS(10896),
    [anon_sym_triand] = ACTIONS(10896),
    [anon_sym_wor] = ACTIONS(10896),
    [anon_sym_trior] = ACTIONS(10896),
    [anon_sym_trireg] = ACTIONS(10896),
    [anon_sym_uwire] = ACTIONS(10896),
    [anon_sym_SEMI] = ACTIONS(10899),
    [anon_sym_interface] = ACTIONS(10902),
    [anon_sym_program] = ACTIONS(10905),
    [anon_sym_checker] = ACTIONS(10908),
    [anon_sym_virtual] = ACTIONS(10911),
    [anon_sym_class] = ACTIONS(10914),
    [anon_sym_endpackage] = ACTIONS(11179),
    [anon_sym_timeunit] = ACTIONS(10920),
    [anon_sym_timeprecision] = ACTIONS(10923),
    [anon_sym_type] = ACTIONS(10926),
    [anon_sym_bind] = ACTIONS(10929),
    [anon_sym_const] = ACTIONS(10932),
    [anon_sym_function] = ACTIONS(10935),
    [anon_sym_static] = ACTIONS(10938),
    [anon_sym_constraint] = ACTIONS(10941),
    [anon_sym_LBRACK] = ACTIONS(10944),
    [anon_sym_localparam] = ACTIONS(10947),
    [anon_sym_parameter] = ACTIONS(10950),
    [anon_sym_var] = ACTIONS(10953),
    [anon_sym_import] = ACTIONS(10956),
    [anon_sym_export] = ACTIONS(10959),
    [anon_sym_interconnect] = ACTIONS(10962),
    [anon_sym_typedef] = ACTIONS(10965),
    [anon_sym_enum] = ACTIONS(10968),
    [anon_sym_struct] = ACTIONS(10971),
    [anon_sym_union] = ACTIONS(10974),
    [anon_sym_nettype] = ACTIONS(10977),
    [anon_sym_automatic] = ACTIONS(10980),
    [anon_sym_string] = ACTIONS(10983),
    [anon_sym_chandle] = ACTIONS(10983),
    [anon_sym_event] = ACTIONS(10983),
    [anon_sym_byte] = ACTIONS(10986),
    [anon_sym_shortint] = ACTIONS(10986),
    [anon_sym_int] = ACTIONS(10986),
    [anon_sym_longint] = ACTIONS(10986),
    [anon_sym_integer] = ACTIONS(10986),
    [anon_sym_time] = ACTIONS(10986),
    [anon_sym_bit] = ACTIONS(10989),
    [anon_sym_logic] = ACTIONS(10989),
    [anon_sym_reg] = ACTIONS(10989),
    [anon_sym_shortreal] = ACTIONS(10992),
    [anon_sym_real] = ACTIONS(10992),
    [anon_sym_realtime] = ACTIONS(10992),
    [anon_sym_supply0] = ACTIONS(10896),
    [anon_sym_supply1] = ACTIONS(10896),
    [anon_sym_signed] = ACTIONS(10995),
    [anon_sym_unsigned] = ACTIONS(10995),
    [anon_sym_task] = ACTIONS(10998),
    [anon_sym_property] = ACTIONS(11001),
    [anon_sym_sequence] = ACTIONS(11004),
    [anon_sym_covergroup] = ACTIONS(11007),
    [anon_sym_let] = ACTIONS(11010),
    [anon_sym_LPAREN_STAR] = ACTIONS(11013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11016),
    [anon_sym_DOLLARunit] = ACTIONS(11019),
  },
  [4957] = {
    [sym_simple_identifier] = ACTIONS(6569),
    [anon_sym_wire] = ACTIONS(6569),
    [anon_sym_tri] = ACTIONS(6569),
    [anon_sym_tri0] = ACTIONS(6569),
    [anon_sym_tri1] = ACTIONS(6569),
    [anon_sym_wand] = ACTIONS(6569),
    [anon_sym_triand] = ACTIONS(6569),
    [anon_sym_wor] = ACTIONS(6569),
    [anon_sym_trior] = ACTIONS(6569),
    [anon_sym_trireg] = ACTIONS(6569),
    [anon_sym_uwire] = ACTIONS(6569),
    [anon_sym_SEMI] = ACTIONS(6571),
    [anon_sym_extern] = ACTIONS(6569),
    [anon_sym_interface] = ACTIONS(6569),
    [anon_sym_checker] = ACTIONS(6569),
    [anon_sym_virtual] = ACTIONS(6569),
    [anon_sym_class] = ACTIONS(6569),
    [anon_sym_type] = ACTIONS(6569),
    [anon_sym_DOLLARfatal] = ACTIONS(6571),
    [anon_sym_DOLLARerror] = ACTIONS(6571),
    [anon_sym_DOLLARwarning] = ACTIONS(6571),
    [anon_sym_DOLLARinfo] = ACTIONS(6571),
    [anon_sym_default] = ACTIONS(6569),
    [anon_sym_clocking] = ACTIONS(6569),
    [anon_sym_defparam] = ACTIONS(6569),
    [anon_sym_bind] = ACTIONS(6569),
    [anon_sym_rand] = ACTIONS(6569),
    [anon_sym_const] = ACTIONS(6569),
    [anon_sym_function] = ACTIONS(6569),
    [anon_sym_static] = ACTIONS(6569),
    [anon_sym_constraint] = ACTIONS(6569),
    [anon_sym_if] = ACTIONS(6569),
    [anon_sym_else] = ACTIONS(6569),
    [anon_sym_LBRACK] = ACTIONS(6571),
    [anon_sym_localparam] = ACTIONS(6569),
    [anon_sym_parameter] = ACTIONS(6569),
    [anon_sym_var] = ACTIONS(6569),
    [anon_sym_import] = ACTIONS(6569),
    [anon_sym_export] = ACTIONS(6569),
    [anon_sym_genvar] = ACTIONS(6569),
    [anon_sym_interconnect] = ACTIONS(6569),
    [anon_sym_typedef] = ACTIONS(6569),
    [anon_sym_enum] = ACTIONS(6569),
    [anon_sym_struct] = ACTIONS(6569),
    [anon_sym_union] = ACTIONS(6569),
    [anon_sym_nettype] = ACTIONS(6569),
    [anon_sym_automatic] = ACTIONS(6569),
    [anon_sym_string] = ACTIONS(6569),
    [anon_sym_chandle] = ACTIONS(6569),
    [anon_sym_event] = ACTIONS(6569),
    [anon_sym_byte] = ACTIONS(6569),
    [anon_sym_shortint] = ACTIONS(6569),
    [anon_sym_int] = ACTIONS(6569),
    [anon_sym_longint] = ACTIONS(6569),
    [anon_sym_integer] = ACTIONS(6569),
    [anon_sym_time] = ACTIONS(6569),
    [anon_sym_bit] = ACTIONS(6569),
    [anon_sym_logic] = ACTIONS(6569),
    [anon_sym_reg] = ACTIONS(6569),
    [anon_sym_shortreal] = ACTIONS(6569),
    [anon_sym_real] = ACTIONS(6569),
    [anon_sym_realtime] = ACTIONS(6569),
    [anon_sym_supply0] = ACTIONS(6569),
    [anon_sym_supply1] = ACTIONS(6569),
    [anon_sym_signed] = ACTIONS(6569),
    [anon_sym_unsigned] = ACTIONS(6569),
    [anon_sym_task] = ACTIONS(6569),
    [anon_sym_assert] = ACTIONS(6569),
    [anon_sym_property] = ACTIONS(6569),
    [anon_sym_assume] = ACTIONS(6569),
    [anon_sym_cover] = ACTIONS(6569),
    [anon_sym_sequence] = ACTIONS(6569),
    [anon_sym_restrict] = ACTIONS(6569),
    [anon_sym_not] = ACTIONS(6569),
    [anon_sym_or] = ACTIONS(6569),
    [anon_sym_and] = ACTIONS(6569),
    [anon_sym_case] = ACTIONS(6569),
    [anon_sym_always] = ACTIONS(6569),
    [anon_sym_covergroup] = ACTIONS(6569),
    [anon_sym_end] = ACTIONS(6569),
    [anon_sym_let] = ACTIONS(6569),
    [anon_sym_pulldown] = ACTIONS(6569),
    [anon_sym_pullup] = ACTIONS(6569),
    [anon_sym_cmos] = ACTIONS(6569),
    [anon_sym_rcmos] = ACTIONS(6569),
    [anon_sym_bufif0] = ACTIONS(6569),
    [anon_sym_bufif1] = ACTIONS(6569),
    [anon_sym_notif0] = ACTIONS(6569),
    [anon_sym_notif1] = ACTIONS(6569),
    [anon_sym_nmos] = ACTIONS(6569),
    [anon_sym_pmos] = ACTIONS(6569),
    [anon_sym_rnmos] = ACTIONS(6569),
    [anon_sym_rpmos] = ACTIONS(6569),
    [anon_sym_nand] = ACTIONS(6569),
    [anon_sym_nor] = ACTIONS(6569),
    [anon_sym_xor] = ACTIONS(6569),
    [anon_sym_xnor] = ACTIONS(6569),
    [anon_sym_buf] = ACTIONS(6569),
    [anon_sym_tranif0] = ACTIONS(6569),
    [anon_sym_tranif1] = ACTIONS(6569),
    [anon_sym_rtranif1] = ACTIONS(6569),
    [anon_sym_rtranif0] = ACTIONS(6569),
    [anon_sym_tran] = ACTIONS(6569),
    [anon_sym_rtran] = ACTIONS(6569),
    [anon_sym_generate] = ACTIONS(6569),
    [anon_sym_for] = ACTIONS(6569),
    [anon_sym_initial] = ACTIONS(6569),
    [anon_sym_assign] = ACTIONS(6569),
    [anon_sym_alias] = ACTIONS(6569),
    [anon_sym_always_comb] = ACTIONS(6569),
    [anon_sym_always_latch] = ACTIONS(6569),
    [anon_sym_always_ff] = ACTIONS(6569),
    [anon_sym_final] = ACTIONS(6569),
    [anon_sym_global] = ACTIONS(6569),
    [anon_sym_LPAREN_STAR] = ACTIONS(6571),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6571),
    [anon_sym_DOLLARunit] = ACTIONS(6571),
  },
  [4958] = {
    [sym_simple_identifier] = ACTIONS(4242),
    [anon_sym_wire] = ACTIONS(4242),
    [anon_sym_tri] = ACTIONS(4242),
    [anon_sym_tri0] = ACTIONS(4242),
    [anon_sym_tri1] = ACTIONS(4242),
    [anon_sym_wand] = ACTIONS(4242),
    [anon_sym_triand] = ACTIONS(4242),
    [anon_sym_wor] = ACTIONS(4242),
    [anon_sym_trior] = ACTIONS(4242),
    [anon_sym_trireg] = ACTIONS(4242),
    [anon_sym_uwire] = ACTIONS(4242),
    [anon_sym_SEMI] = ACTIONS(4240),
    [anon_sym_extern] = ACTIONS(4242),
    [anon_sym_interface] = ACTIONS(4242),
    [anon_sym_checker] = ACTIONS(4242),
    [anon_sym_virtual] = ACTIONS(4242),
    [anon_sym_class] = ACTIONS(4242),
    [anon_sym_type] = ACTIONS(4242),
    [anon_sym_DOLLARfatal] = ACTIONS(4240),
    [anon_sym_DOLLARerror] = ACTIONS(4240),
    [anon_sym_DOLLARwarning] = ACTIONS(4240),
    [anon_sym_DOLLARinfo] = ACTIONS(4240),
    [anon_sym_default] = ACTIONS(4242),
    [anon_sym_clocking] = ACTIONS(4242),
    [anon_sym_defparam] = ACTIONS(4242),
    [anon_sym_bind] = ACTIONS(4242),
    [anon_sym_rand] = ACTIONS(4242),
    [anon_sym_const] = ACTIONS(4242),
    [anon_sym_function] = ACTIONS(4242),
    [anon_sym_static] = ACTIONS(4242),
    [anon_sym_constraint] = ACTIONS(4242),
    [anon_sym_if] = ACTIONS(4242),
    [anon_sym_else] = ACTIONS(4242),
    [anon_sym_LBRACK] = ACTIONS(4240),
    [anon_sym_localparam] = ACTIONS(4242),
    [anon_sym_parameter] = ACTIONS(4242),
    [anon_sym_var] = ACTIONS(4242),
    [anon_sym_import] = ACTIONS(4242),
    [anon_sym_export] = ACTIONS(4242),
    [anon_sym_genvar] = ACTIONS(4242),
    [anon_sym_interconnect] = ACTIONS(4242),
    [anon_sym_typedef] = ACTIONS(4242),
    [anon_sym_enum] = ACTIONS(4242),
    [anon_sym_struct] = ACTIONS(4242),
    [anon_sym_union] = ACTIONS(4242),
    [anon_sym_nettype] = ACTIONS(4242),
    [anon_sym_automatic] = ACTIONS(4242),
    [anon_sym_string] = ACTIONS(4242),
    [anon_sym_chandle] = ACTIONS(4242),
    [anon_sym_event] = ACTIONS(4242),
    [anon_sym_byte] = ACTIONS(4242),
    [anon_sym_shortint] = ACTIONS(4242),
    [anon_sym_int] = ACTIONS(4242),
    [anon_sym_longint] = ACTIONS(4242),
    [anon_sym_integer] = ACTIONS(4242),
    [anon_sym_time] = ACTIONS(4242),
    [anon_sym_bit] = ACTIONS(4242),
    [anon_sym_logic] = ACTIONS(4242),
    [anon_sym_reg] = ACTIONS(4242),
    [anon_sym_shortreal] = ACTIONS(4242),
    [anon_sym_real] = ACTIONS(4242),
    [anon_sym_realtime] = ACTIONS(4242),
    [anon_sym_supply0] = ACTIONS(4242),
    [anon_sym_supply1] = ACTIONS(4242),
    [anon_sym_signed] = ACTIONS(4242),
    [anon_sym_unsigned] = ACTIONS(4242),
    [anon_sym_task] = ACTIONS(4242),
    [anon_sym_assert] = ACTIONS(4242),
    [anon_sym_property] = ACTIONS(4242),
    [anon_sym_assume] = ACTIONS(4242),
    [anon_sym_cover] = ACTIONS(4242),
    [anon_sym_sequence] = ACTIONS(4242),
    [anon_sym_restrict] = ACTIONS(4242),
    [anon_sym_not] = ACTIONS(4242),
    [anon_sym_or] = ACTIONS(4242),
    [anon_sym_and] = ACTIONS(4242),
    [anon_sym_case] = ACTIONS(4242),
    [anon_sym_always] = ACTIONS(4242),
    [anon_sym_covergroup] = ACTIONS(4242),
    [anon_sym_let] = ACTIONS(4242),
    [anon_sym_pulldown] = ACTIONS(4242),
    [anon_sym_pullup] = ACTIONS(4242),
    [anon_sym_cmos] = ACTIONS(4242),
    [anon_sym_rcmos] = ACTIONS(4242),
    [anon_sym_bufif0] = ACTIONS(4242),
    [anon_sym_bufif1] = ACTIONS(4242),
    [anon_sym_notif0] = ACTIONS(4242),
    [anon_sym_notif1] = ACTIONS(4242),
    [anon_sym_nmos] = ACTIONS(4242),
    [anon_sym_pmos] = ACTIONS(4242),
    [anon_sym_rnmos] = ACTIONS(4242),
    [anon_sym_rpmos] = ACTIONS(4242),
    [anon_sym_nand] = ACTIONS(4242),
    [anon_sym_nor] = ACTIONS(4242),
    [anon_sym_xor] = ACTIONS(4242),
    [anon_sym_xnor] = ACTIONS(4242),
    [anon_sym_buf] = ACTIONS(4242),
    [anon_sym_tranif0] = ACTIONS(4242),
    [anon_sym_tranif1] = ACTIONS(4242),
    [anon_sym_rtranif1] = ACTIONS(4242),
    [anon_sym_rtranif0] = ACTIONS(4242),
    [anon_sym_tran] = ACTIONS(4242),
    [anon_sym_rtran] = ACTIONS(4242),
    [anon_sym_generate] = ACTIONS(4242),
    [anon_sym_endgenerate] = ACTIONS(4242),
    [anon_sym_for] = ACTIONS(4242),
    [anon_sym_initial] = ACTIONS(4242),
    [anon_sym_assign] = ACTIONS(4242),
    [anon_sym_alias] = ACTIONS(4242),
    [anon_sym_always_comb] = ACTIONS(4242),
    [anon_sym_always_latch] = ACTIONS(4242),
    [anon_sym_always_ff] = ACTIONS(4242),
    [anon_sym_final] = ACTIONS(4242),
    [anon_sym_global] = ACTIONS(4242),
    [anon_sym_LPAREN_STAR] = ACTIONS(4240),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4240),
    [anon_sym_DOLLARunit] = ACTIONS(4240),
  },
  [4959] = {
    [sym_simple_identifier] = ACTIONS(5258),
    [anon_sym_wire] = ACTIONS(5258),
    [anon_sym_tri] = ACTIONS(5258),
    [anon_sym_tri0] = ACTIONS(5258),
    [anon_sym_tri1] = ACTIONS(5258),
    [anon_sym_wand] = ACTIONS(5258),
    [anon_sym_triand] = ACTIONS(5258),
    [anon_sym_wor] = ACTIONS(5258),
    [anon_sym_trior] = ACTIONS(5258),
    [anon_sym_trireg] = ACTIONS(5258),
    [anon_sym_uwire] = ACTIONS(5258),
    [anon_sym_SEMI] = ACTIONS(5256),
    [anon_sym_extern] = ACTIONS(5258),
    [anon_sym_interface] = ACTIONS(5258),
    [anon_sym_checker] = ACTIONS(5258),
    [anon_sym_virtual] = ACTIONS(5258),
    [anon_sym_class] = ACTIONS(5258),
    [anon_sym_type] = ACTIONS(5258),
    [anon_sym_DOLLARfatal] = ACTIONS(5256),
    [anon_sym_DOLLARerror] = ACTIONS(5256),
    [anon_sym_DOLLARwarning] = ACTIONS(5256),
    [anon_sym_DOLLARinfo] = ACTIONS(5256),
    [anon_sym_default] = ACTIONS(5258),
    [anon_sym_clocking] = ACTIONS(5258),
    [anon_sym_defparam] = ACTIONS(5258),
    [anon_sym_bind] = ACTIONS(5258),
    [anon_sym_rand] = ACTIONS(5258),
    [anon_sym_const] = ACTIONS(5258),
    [anon_sym_function] = ACTIONS(5258),
    [anon_sym_static] = ACTIONS(5258),
    [anon_sym_constraint] = ACTIONS(5258),
    [anon_sym_if] = ACTIONS(5258),
    [anon_sym_else] = ACTIONS(5258),
    [anon_sym_LBRACK] = ACTIONS(5256),
    [anon_sym_localparam] = ACTIONS(5258),
    [anon_sym_parameter] = ACTIONS(5258),
    [anon_sym_var] = ACTIONS(5258),
    [anon_sym_import] = ACTIONS(5258),
    [anon_sym_export] = ACTIONS(5258),
    [anon_sym_genvar] = ACTIONS(5258),
    [anon_sym_interconnect] = ACTIONS(5258),
    [anon_sym_typedef] = ACTIONS(5258),
    [anon_sym_enum] = ACTIONS(5258),
    [anon_sym_struct] = ACTIONS(5258),
    [anon_sym_union] = ACTIONS(5258),
    [anon_sym_nettype] = ACTIONS(5258),
    [anon_sym_automatic] = ACTIONS(5258),
    [anon_sym_string] = ACTIONS(5258),
    [anon_sym_chandle] = ACTIONS(5258),
    [anon_sym_event] = ACTIONS(5258),
    [anon_sym_byte] = ACTIONS(5258),
    [anon_sym_shortint] = ACTIONS(5258),
    [anon_sym_int] = ACTIONS(5258),
    [anon_sym_longint] = ACTIONS(5258),
    [anon_sym_integer] = ACTIONS(5258),
    [anon_sym_time] = ACTIONS(5258),
    [anon_sym_bit] = ACTIONS(5258),
    [anon_sym_logic] = ACTIONS(5258),
    [anon_sym_reg] = ACTIONS(5258),
    [anon_sym_shortreal] = ACTIONS(5258),
    [anon_sym_real] = ACTIONS(5258),
    [anon_sym_realtime] = ACTIONS(5258),
    [anon_sym_supply0] = ACTIONS(5258),
    [anon_sym_supply1] = ACTIONS(5258),
    [anon_sym_signed] = ACTIONS(5258),
    [anon_sym_unsigned] = ACTIONS(5258),
    [anon_sym_task] = ACTIONS(5258),
    [anon_sym_assert] = ACTIONS(5258),
    [anon_sym_property] = ACTIONS(5258),
    [anon_sym_assume] = ACTIONS(5258),
    [anon_sym_cover] = ACTIONS(5258),
    [anon_sym_sequence] = ACTIONS(5258),
    [anon_sym_restrict] = ACTIONS(5258),
    [anon_sym_not] = ACTIONS(5258),
    [anon_sym_or] = ACTIONS(5258),
    [anon_sym_and] = ACTIONS(5258),
    [anon_sym_case] = ACTIONS(5258),
    [anon_sym_always] = ACTIONS(5258),
    [anon_sym_covergroup] = ACTIONS(5258),
    [anon_sym_end] = ACTIONS(5258),
    [anon_sym_let] = ACTIONS(5258),
    [anon_sym_pulldown] = ACTIONS(5258),
    [anon_sym_pullup] = ACTIONS(5258),
    [anon_sym_cmos] = ACTIONS(5258),
    [anon_sym_rcmos] = ACTIONS(5258),
    [anon_sym_bufif0] = ACTIONS(5258),
    [anon_sym_bufif1] = ACTIONS(5258),
    [anon_sym_notif0] = ACTIONS(5258),
    [anon_sym_notif1] = ACTIONS(5258),
    [anon_sym_nmos] = ACTIONS(5258),
    [anon_sym_pmos] = ACTIONS(5258),
    [anon_sym_rnmos] = ACTIONS(5258),
    [anon_sym_rpmos] = ACTIONS(5258),
    [anon_sym_nand] = ACTIONS(5258),
    [anon_sym_nor] = ACTIONS(5258),
    [anon_sym_xor] = ACTIONS(5258),
    [anon_sym_xnor] = ACTIONS(5258),
    [anon_sym_buf] = ACTIONS(5258),
    [anon_sym_tranif0] = ACTIONS(5258),
    [anon_sym_tranif1] = ACTIONS(5258),
    [anon_sym_rtranif1] = ACTIONS(5258),
    [anon_sym_rtranif0] = ACTIONS(5258),
    [anon_sym_tran] = ACTIONS(5258),
    [anon_sym_rtran] = ACTIONS(5258),
    [anon_sym_generate] = ACTIONS(5258),
    [anon_sym_for] = ACTIONS(5258),
    [anon_sym_initial] = ACTIONS(5258),
    [anon_sym_assign] = ACTIONS(5258),
    [anon_sym_alias] = ACTIONS(5258),
    [anon_sym_always_comb] = ACTIONS(5258),
    [anon_sym_always_latch] = ACTIONS(5258),
    [anon_sym_always_ff] = ACTIONS(5258),
    [anon_sym_final] = ACTIONS(5258),
    [anon_sym_global] = ACTIONS(5258),
    [anon_sym_LPAREN_STAR] = ACTIONS(5256),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5256),
    [anon_sym_DOLLARunit] = ACTIONS(5256),
  },
  [4960] = {
    [sym_simple_identifier] = ACTIONS(6389),
    [anon_sym_wire] = ACTIONS(6389),
    [anon_sym_tri] = ACTIONS(6389),
    [anon_sym_tri0] = ACTIONS(6389),
    [anon_sym_tri1] = ACTIONS(6389),
    [anon_sym_wand] = ACTIONS(6389),
    [anon_sym_triand] = ACTIONS(6389),
    [anon_sym_wor] = ACTIONS(6389),
    [anon_sym_trior] = ACTIONS(6389),
    [anon_sym_trireg] = ACTIONS(6389),
    [anon_sym_uwire] = ACTIONS(6389),
    [anon_sym_SEMI] = ACTIONS(6391),
    [anon_sym_extern] = ACTIONS(6389),
    [anon_sym_interface] = ACTIONS(6389),
    [anon_sym_checker] = ACTIONS(6389),
    [anon_sym_virtual] = ACTIONS(6389),
    [anon_sym_class] = ACTIONS(6389),
    [anon_sym_type] = ACTIONS(6389),
    [anon_sym_DOLLARfatal] = ACTIONS(6391),
    [anon_sym_DOLLARerror] = ACTIONS(6391),
    [anon_sym_DOLLARwarning] = ACTIONS(6391),
    [anon_sym_DOLLARinfo] = ACTIONS(6391),
    [anon_sym_default] = ACTIONS(6389),
    [anon_sym_clocking] = ACTIONS(6389),
    [anon_sym_defparam] = ACTIONS(6389),
    [anon_sym_bind] = ACTIONS(6389),
    [anon_sym_rand] = ACTIONS(6389),
    [anon_sym_const] = ACTIONS(6389),
    [anon_sym_function] = ACTIONS(6389),
    [anon_sym_static] = ACTIONS(6389),
    [anon_sym_constraint] = ACTIONS(6389),
    [anon_sym_if] = ACTIONS(6389),
    [anon_sym_else] = ACTIONS(6389),
    [anon_sym_LBRACK] = ACTIONS(6391),
    [anon_sym_localparam] = ACTIONS(6389),
    [anon_sym_parameter] = ACTIONS(6389),
    [anon_sym_var] = ACTIONS(6389),
    [anon_sym_import] = ACTIONS(6389),
    [anon_sym_export] = ACTIONS(6389),
    [anon_sym_genvar] = ACTIONS(6389),
    [anon_sym_interconnect] = ACTIONS(6389),
    [anon_sym_typedef] = ACTIONS(6389),
    [anon_sym_enum] = ACTIONS(6389),
    [anon_sym_struct] = ACTIONS(6389),
    [anon_sym_union] = ACTIONS(6389),
    [anon_sym_nettype] = ACTIONS(6389),
    [anon_sym_automatic] = ACTIONS(6389),
    [anon_sym_string] = ACTIONS(6389),
    [anon_sym_chandle] = ACTIONS(6389),
    [anon_sym_event] = ACTIONS(6389),
    [anon_sym_byte] = ACTIONS(6389),
    [anon_sym_shortint] = ACTIONS(6389),
    [anon_sym_int] = ACTIONS(6389),
    [anon_sym_longint] = ACTIONS(6389),
    [anon_sym_integer] = ACTIONS(6389),
    [anon_sym_time] = ACTIONS(6389),
    [anon_sym_bit] = ACTIONS(6389),
    [anon_sym_logic] = ACTIONS(6389),
    [anon_sym_reg] = ACTIONS(6389),
    [anon_sym_shortreal] = ACTIONS(6389),
    [anon_sym_real] = ACTIONS(6389),
    [anon_sym_realtime] = ACTIONS(6389),
    [anon_sym_supply0] = ACTIONS(6389),
    [anon_sym_supply1] = ACTIONS(6389),
    [anon_sym_signed] = ACTIONS(6389),
    [anon_sym_unsigned] = ACTIONS(6389),
    [anon_sym_task] = ACTIONS(6389),
    [anon_sym_assert] = ACTIONS(6389),
    [anon_sym_property] = ACTIONS(6389),
    [anon_sym_assume] = ACTIONS(6389),
    [anon_sym_cover] = ACTIONS(6389),
    [anon_sym_sequence] = ACTIONS(6389),
    [anon_sym_restrict] = ACTIONS(6389),
    [anon_sym_not] = ACTIONS(6389),
    [anon_sym_or] = ACTIONS(6389),
    [anon_sym_and] = ACTIONS(6389),
    [anon_sym_case] = ACTIONS(6389),
    [anon_sym_always] = ACTIONS(6389),
    [anon_sym_covergroup] = ACTIONS(6389),
    [anon_sym_let] = ACTIONS(6389),
    [anon_sym_pulldown] = ACTIONS(6389),
    [anon_sym_pullup] = ACTIONS(6389),
    [anon_sym_cmos] = ACTIONS(6389),
    [anon_sym_rcmos] = ACTIONS(6389),
    [anon_sym_bufif0] = ACTIONS(6389),
    [anon_sym_bufif1] = ACTIONS(6389),
    [anon_sym_notif0] = ACTIONS(6389),
    [anon_sym_notif1] = ACTIONS(6389),
    [anon_sym_nmos] = ACTIONS(6389),
    [anon_sym_pmos] = ACTIONS(6389),
    [anon_sym_rnmos] = ACTIONS(6389),
    [anon_sym_rpmos] = ACTIONS(6389),
    [anon_sym_nand] = ACTIONS(6389),
    [anon_sym_nor] = ACTIONS(6389),
    [anon_sym_xor] = ACTIONS(6389),
    [anon_sym_xnor] = ACTIONS(6389),
    [anon_sym_buf] = ACTIONS(6389),
    [anon_sym_tranif0] = ACTIONS(6389),
    [anon_sym_tranif1] = ACTIONS(6389),
    [anon_sym_rtranif1] = ACTIONS(6389),
    [anon_sym_rtranif0] = ACTIONS(6389),
    [anon_sym_tran] = ACTIONS(6389),
    [anon_sym_rtran] = ACTIONS(6389),
    [anon_sym_generate] = ACTIONS(6389),
    [anon_sym_endgenerate] = ACTIONS(6389),
    [anon_sym_for] = ACTIONS(6389),
    [anon_sym_initial] = ACTIONS(6389),
    [anon_sym_assign] = ACTIONS(6389),
    [anon_sym_alias] = ACTIONS(6389),
    [anon_sym_always_comb] = ACTIONS(6389),
    [anon_sym_always_latch] = ACTIONS(6389),
    [anon_sym_always_ff] = ACTIONS(6389),
    [anon_sym_final] = ACTIONS(6389),
    [anon_sym_global] = ACTIONS(6389),
    [anon_sym_LPAREN_STAR] = ACTIONS(6391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6391),
    [anon_sym_DOLLARunit] = ACTIONS(6391),
  },
  [4961] = {
    [sym_simple_identifier] = ACTIONS(6361),
    [anon_sym_wire] = ACTIONS(6361),
    [anon_sym_tri] = ACTIONS(6361),
    [anon_sym_tri0] = ACTIONS(6361),
    [anon_sym_tri1] = ACTIONS(6361),
    [anon_sym_wand] = ACTIONS(6361),
    [anon_sym_triand] = ACTIONS(6361),
    [anon_sym_wor] = ACTIONS(6361),
    [anon_sym_trior] = ACTIONS(6361),
    [anon_sym_trireg] = ACTIONS(6361),
    [anon_sym_uwire] = ACTIONS(6361),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_extern] = ACTIONS(6361),
    [anon_sym_interface] = ACTIONS(6361),
    [anon_sym_checker] = ACTIONS(6361),
    [anon_sym_virtual] = ACTIONS(6361),
    [anon_sym_class] = ACTIONS(6361),
    [anon_sym_type] = ACTIONS(6361),
    [anon_sym_DOLLARfatal] = ACTIONS(6363),
    [anon_sym_DOLLARerror] = ACTIONS(6363),
    [anon_sym_DOLLARwarning] = ACTIONS(6363),
    [anon_sym_DOLLARinfo] = ACTIONS(6363),
    [anon_sym_default] = ACTIONS(6361),
    [anon_sym_clocking] = ACTIONS(6361),
    [anon_sym_defparam] = ACTIONS(6361),
    [anon_sym_bind] = ACTIONS(6361),
    [anon_sym_rand] = ACTIONS(6361),
    [anon_sym_const] = ACTIONS(6361),
    [anon_sym_function] = ACTIONS(6361),
    [anon_sym_static] = ACTIONS(6361),
    [anon_sym_constraint] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6361),
    [anon_sym_else] = ACTIONS(6361),
    [anon_sym_LBRACK] = ACTIONS(6363),
    [anon_sym_localparam] = ACTIONS(6361),
    [anon_sym_parameter] = ACTIONS(6361),
    [anon_sym_var] = ACTIONS(6361),
    [anon_sym_import] = ACTIONS(6361),
    [anon_sym_export] = ACTIONS(6361),
    [anon_sym_genvar] = ACTIONS(6361),
    [anon_sym_interconnect] = ACTIONS(6361),
    [anon_sym_typedef] = ACTIONS(6361),
    [anon_sym_enum] = ACTIONS(6361),
    [anon_sym_struct] = ACTIONS(6361),
    [anon_sym_union] = ACTIONS(6361),
    [anon_sym_nettype] = ACTIONS(6361),
    [anon_sym_automatic] = ACTIONS(6361),
    [anon_sym_string] = ACTIONS(6361),
    [anon_sym_chandle] = ACTIONS(6361),
    [anon_sym_event] = ACTIONS(6361),
    [anon_sym_byte] = ACTIONS(6361),
    [anon_sym_shortint] = ACTIONS(6361),
    [anon_sym_int] = ACTIONS(6361),
    [anon_sym_longint] = ACTIONS(6361),
    [anon_sym_integer] = ACTIONS(6361),
    [anon_sym_time] = ACTIONS(6361),
    [anon_sym_bit] = ACTIONS(6361),
    [anon_sym_logic] = ACTIONS(6361),
    [anon_sym_reg] = ACTIONS(6361),
    [anon_sym_shortreal] = ACTIONS(6361),
    [anon_sym_real] = ACTIONS(6361),
    [anon_sym_realtime] = ACTIONS(6361),
    [anon_sym_supply0] = ACTIONS(6361),
    [anon_sym_supply1] = ACTIONS(6361),
    [anon_sym_signed] = ACTIONS(6361),
    [anon_sym_unsigned] = ACTIONS(6361),
    [anon_sym_task] = ACTIONS(6361),
    [anon_sym_assert] = ACTIONS(6361),
    [anon_sym_property] = ACTIONS(6361),
    [anon_sym_assume] = ACTIONS(6361),
    [anon_sym_cover] = ACTIONS(6361),
    [anon_sym_sequence] = ACTIONS(6361),
    [anon_sym_restrict] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6361),
    [anon_sym_or] = ACTIONS(6361),
    [anon_sym_and] = ACTIONS(6361),
    [anon_sym_case] = ACTIONS(6361),
    [anon_sym_always] = ACTIONS(6361),
    [anon_sym_covergroup] = ACTIONS(6361),
    [anon_sym_let] = ACTIONS(6361),
    [anon_sym_pulldown] = ACTIONS(6361),
    [anon_sym_pullup] = ACTIONS(6361),
    [anon_sym_cmos] = ACTIONS(6361),
    [anon_sym_rcmos] = ACTIONS(6361),
    [anon_sym_bufif0] = ACTIONS(6361),
    [anon_sym_bufif1] = ACTIONS(6361),
    [anon_sym_notif0] = ACTIONS(6361),
    [anon_sym_notif1] = ACTIONS(6361),
    [anon_sym_nmos] = ACTIONS(6361),
    [anon_sym_pmos] = ACTIONS(6361),
    [anon_sym_rnmos] = ACTIONS(6361),
    [anon_sym_rpmos] = ACTIONS(6361),
    [anon_sym_nand] = ACTIONS(6361),
    [anon_sym_nor] = ACTIONS(6361),
    [anon_sym_xor] = ACTIONS(6361),
    [anon_sym_xnor] = ACTIONS(6361),
    [anon_sym_buf] = ACTIONS(6361),
    [anon_sym_tranif0] = ACTIONS(6361),
    [anon_sym_tranif1] = ACTIONS(6361),
    [anon_sym_rtranif1] = ACTIONS(6361),
    [anon_sym_rtranif0] = ACTIONS(6361),
    [anon_sym_tran] = ACTIONS(6361),
    [anon_sym_rtran] = ACTIONS(6361),
    [anon_sym_generate] = ACTIONS(6361),
    [anon_sym_endgenerate] = ACTIONS(6361),
    [anon_sym_for] = ACTIONS(6361),
    [anon_sym_initial] = ACTIONS(6361),
    [anon_sym_assign] = ACTIONS(6361),
    [anon_sym_alias] = ACTIONS(6361),
    [anon_sym_always_comb] = ACTIONS(6361),
    [anon_sym_always_latch] = ACTIONS(6361),
    [anon_sym_always_ff] = ACTIONS(6361),
    [anon_sym_final] = ACTIONS(6361),
    [anon_sym_global] = ACTIONS(6361),
    [anon_sym_LPAREN_STAR] = ACTIONS(6363),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6363),
    [anon_sym_DOLLARunit] = ACTIONS(6363),
  },
  [4962] = {
    [sym_simple_identifier] = ACTIONS(6173),
    [anon_sym_wire] = ACTIONS(6173),
    [anon_sym_tri] = ACTIONS(6173),
    [anon_sym_tri0] = ACTIONS(6173),
    [anon_sym_tri1] = ACTIONS(6173),
    [anon_sym_wand] = ACTIONS(6173),
    [anon_sym_triand] = ACTIONS(6173),
    [anon_sym_wor] = ACTIONS(6173),
    [anon_sym_trior] = ACTIONS(6173),
    [anon_sym_trireg] = ACTIONS(6173),
    [anon_sym_uwire] = ACTIONS(6173),
    [anon_sym_SEMI] = ACTIONS(6175),
    [anon_sym_extern] = ACTIONS(6173),
    [anon_sym_interface] = ACTIONS(6173),
    [anon_sym_checker] = ACTIONS(6173),
    [anon_sym_virtual] = ACTIONS(6173),
    [anon_sym_class] = ACTIONS(6173),
    [anon_sym_type] = ACTIONS(6173),
    [anon_sym_DOLLARfatal] = ACTIONS(6175),
    [anon_sym_DOLLARerror] = ACTIONS(6175),
    [anon_sym_DOLLARwarning] = ACTIONS(6175),
    [anon_sym_DOLLARinfo] = ACTIONS(6175),
    [anon_sym_default] = ACTIONS(6173),
    [anon_sym_clocking] = ACTIONS(6173),
    [anon_sym_defparam] = ACTIONS(6173),
    [anon_sym_bind] = ACTIONS(6173),
    [anon_sym_rand] = ACTIONS(6173),
    [anon_sym_const] = ACTIONS(6173),
    [anon_sym_function] = ACTIONS(6173),
    [anon_sym_static] = ACTIONS(6173),
    [anon_sym_constraint] = ACTIONS(6173),
    [anon_sym_if] = ACTIONS(6173),
    [anon_sym_else] = ACTIONS(6173),
    [anon_sym_LBRACK] = ACTIONS(6175),
    [anon_sym_localparam] = ACTIONS(6173),
    [anon_sym_parameter] = ACTIONS(6173),
    [anon_sym_var] = ACTIONS(6173),
    [anon_sym_import] = ACTIONS(6173),
    [anon_sym_export] = ACTIONS(6173),
    [anon_sym_genvar] = ACTIONS(6173),
    [anon_sym_interconnect] = ACTIONS(6173),
    [anon_sym_typedef] = ACTIONS(6173),
    [anon_sym_enum] = ACTIONS(6173),
    [anon_sym_struct] = ACTIONS(6173),
    [anon_sym_union] = ACTIONS(6173),
    [anon_sym_nettype] = ACTIONS(6173),
    [anon_sym_automatic] = ACTIONS(6173),
    [anon_sym_string] = ACTIONS(6173),
    [anon_sym_chandle] = ACTIONS(6173),
    [anon_sym_event] = ACTIONS(6173),
    [anon_sym_byte] = ACTIONS(6173),
    [anon_sym_shortint] = ACTIONS(6173),
    [anon_sym_int] = ACTIONS(6173),
    [anon_sym_longint] = ACTIONS(6173),
    [anon_sym_integer] = ACTIONS(6173),
    [anon_sym_time] = ACTIONS(6173),
    [anon_sym_bit] = ACTIONS(6173),
    [anon_sym_logic] = ACTIONS(6173),
    [anon_sym_reg] = ACTIONS(6173),
    [anon_sym_shortreal] = ACTIONS(6173),
    [anon_sym_real] = ACTIONS(6173),
    [anon_sym_realtime] = ACTIONS(6173),
    [anon_sym_supply0] = ACTIONS(6173),
    [anon_sym_supply1] = ACTIONS(6173),
    [anon_sym_signed] = ACTIONS(6173),
    [anon_sym_unsigned] = ACTIONS(6173),
    [anon_sym_task] = ACTIONS(6173),
    [anon_sym_assert] = ACTIONS(6173),
    [anon_sym_property] = ACTIONS(6173),
    [anon_sym_assume] = ACTIONS(6173),
    [anon_sym_cover] = ACTIONS(6173),
    [anon_sym_sequence] = ACTIONS(6173),
    [anon_sym_restrict] = ACTIONS(6173),
    [anon_sym_not] = ACTIONS(6173),
    [anon_sym_or] = ACTIONS(6173),
    [anon_sym_and] = ACTIONS(6173),
    [anon_sym_case] = ACTIONS(6173),
    [anon_sym_always] = ACTIONS(6173),
    [anon_sym_covergroup] = ACTIONS(6173),
    [anon_sym_end] = ACTIONS(6173),
    [anon_sym_let] = ACTIONS(6173),
    [anon_sym_pulldown] = ACTIONS(6173),
    [anon_sym_pullup] = ACTIONS(6173),
    [anon_sym_cmos] = ACTIONS(6173),
    [anon_sym_rcmos] = ACTIONS(6173),
    [anon_sym_bufif0] = ACTIONS(6173),
    [anon_sym_bufif1] = ACTIONS(6173),
    [anon_sym_notif0] = ACTIONS(6173),
    [anon_sym_notif1] = ACTIONS(6173),
    [anon_sym_nmos] = ACTIONS(6173),
    [anon_sym_pmos] = ACTIONS(6173),
    [anon_sym_rnmos] = ACTIONS(6173),
    [anon_sym_rpmos] = ACTIONS(6173),
    [anon_sym_nand] = ACTIONS(6173),
    [anon_sym_nor] = ACTIONS(6173),
    [anon_sym_xor] = ACTIONS(6173),
    [anon_sym_xnor] = ACTIONS(6173),
    [anon_sym_buf] = ACTIONS(6173),
    [anon_sym_tranif0] = ACTIONS(6173),
    [anon_sym_tranif1] = ACTIONS(6173),
    [anon_sym_rtranif1] = ACTIONS(6173),
    [anon_sym_rtranif0] = ACTIONS(6173),
    [anon_sym_tran] = ACTIONS(6173),
    [anon_sym_rtran] = ACTIONS(6173),
    [anon_sym_generate] = ACTIONS(6173),
    [anon_sym_for] = ACTIONS(6173),
    [anon_sym_initial] = ACTIONS(6173),
    [anon_sym_assign] = ACTIONS(6173),
    [anon_sym_alias] = ACTIONS(6173),
    [anon_sym_always_comb] = ACTIONS(6173),
    [anon_sym_always_latch] = ACTIONS(6173),
    [anon_sym_always_ff] = ACTIONS(6173),
    [anon_sym_final] = ACTIONS(6173),
    [anon_sym_global] = ACTIONS(6173),
    [anon_sym_LPAREN_STAR] = ACTIONS(6175),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6175),
    [anon_sym_DOLLARunit] = ACTIONS(6175),
  },
  [4963] = {
    [sym_simple_identifier] = ACTIONS(4708),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_rand] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_endgenerate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [4964] = {
    [sym_simple_identifier] = ACTIONS(5314),
    [anon_sym_wire] = ACTIONS(5314),
    [anon_sym_tri] = ACTIONS(5314),
    [anon_sym_tri0] = ACTIONS(5314),
    [anon_sym_tri1] = ACTIONS(5314),
    [anon_sym_wand] = ACTIONS(5314),
    [anon_sym_triand] = ACTIONS(5314),
    [anon_sym_wor] = ACTIONS(5314),
    [anon_sym_trior] = ACTIONS(5314),
    [anon_sym_trireg] = ACTIONS(5314),
    [anon_sym_uwire] = ACTIONS(5314),
    [anon_sym_SEMI] = ACTIONS(5312),
    [anon_sym_extern] = ACTIONS(5314),
    [anon_sym_interface] = ACTIONS(5314),
    [anon_sym_checker] = ACTIONS(5314),
    [anon_sym_virtual] = ACTIONS(5314),
    [anon_sym_class] = ACTIONS(5314),
    [anon_sym_type] = ACTIONS(5314),
    [anon_sym_DOLLARfatal] = ACTIONS(5312),
    [anon_sym_DOLLARerror] = ACTIONS(5312),
    [anon_sym_DOLLARwarning] = ACTIONS(5312),
    [anon_sym_DOLLARinfo] = ACTIONS(5312),
    [anon_sym_default] = ACTIONS(5314),
    [anon_sym_clocking] = ACTIONS(5314),
    [anon_sym_defparam] = ACTIONS(5314),
    [anon_sym_bind] = ACTIONS(5314),
    [anon_sym_rand] = ACTIONS(5314),
    [anon_sym_const] = ACTIONS(5314),
    [anon_sym_function] = ACTIONS(5314),
    [anon_sym_static] = ACTIONS(5314),
    [anon_sym_constraint] = ACTIONS(5314),
    [anon_sym_if] = ACTIONS(5314),
    [anon_sym_else] = ACTIONS(5314),
    [anon_sym_LBRACK] = ACTIONS(5312),
    [anon_sym_localparam] = ACTIONS(5314),
    [anon_sym_parameter] = ACTIONS(5314),
    [anon_sym_var] = ACTIONS(5314),
    [anon_sym_import] = ACTIONS(5314),
    [anon_sym_export] = ACTIONS(5314),
    [anon_sym_genvar] = ACTIONS(5314),
    [anon_sym_interconnect] = ACTIONS(5314),
    [anon_sym_typedef] = ACTIONS(5314),
    [anon_sym_enum] = ACTIONS(5314),
    [anon_sym_struct] = ACTIONS(5314),
    [anon_sym_union] = ACTIONS(5314),
    [anon_sym_nettype] = ACTIONS(5314),
    [anon_sym_automatic] = ACTIONS(5314),
    [anon_sym_string] = ACTIONS(5314),
    [anon_sym_chandle] = ACTIONS(5314),
    [anon_sym_event] = ACTIONS(5314),
    [anon_sym_byte] = ACTIONS(5314),
    [anon_sym_shortint] = ACTIONS(5314),
    [anon_sym_int] = ACTIONS(5314),
    [anon_sym_longint] = ACTIONS(5314),
    [anon_sym_integer] = ACTIONS(5314),
    [anon_sym_time] = ACTIONS(5314),
    [anon_sym_bit] = ACTIONS(5314),
    [anon_sym_logic] = ACTIONS(5314),
    [anon_sym_reg] = ACTIONS(5314),
    [anon_sym_shortreal] = ACTIONS(5314),
    [anon_sym_real] = ACTIONS(5314),
    [anon_sym_realtime] = ACTIONS(5314),
    [anon_sym_supply0] = ACTIONS(5314),
    [anon_sym_supply1] = ACTIONS(5314),
    [anon_sym_signed] = ACTIONS(5314),
    [anon_sym_unsigned] = ACTIONS(5314),
    [anon_sym_task] = ACTIONS(5314),
    [anon_sym_assert] = ACTIONS(5314),
    [anon_sym_property] = ACTIONS(5314),
    [anon_sym_assume] = ACTIONS(5314),
    [anon_sym_cover] = ACTIONS(5314),
    [anon_sym_sequence] = ACTIONS(5314),
    [anon_sym_restrict] = ACTIONS(5314),
    [anon_sym_not] = ACTIONS(5314),
    [anon_sym_or] = ACTIONS(5314),
    [anon_sym_and] = ACTIONS(5314),
    [anon_sym_case] = ACTIONS(5314),
    [anon_sym_always] = ACTIONS(5314),
    [anon_sym_covergroup] = ACTIONS(5314),
    [anon_sym_let] = ACTIONS(5314),
    [anon_sym_pulldown] = ACTIONS(5314),
    [anon_sym_pullup] = ACTIONS(5314),
    [anon_sym_cmos] = ACTIONS(5314),
    [anon_sym_rcmos] = ACTIONS(5314),
    [anon_sym_bufif0] = ACTIONS(5314),
    [anon_sym_bufif1] = ACTIONS(5314),
    [anon_sym_notif0] = ACTIONS(5314),
    [anon_sym_notif1] = ACTIONS(5314),
    [anon_sym_nmos] = ACTIONS(5314),
    [anon_sym_pmos] = ACTIONS(5314),
    [anon_sym_rnmos] = ACTIONS(5314),
    [anon_sym_rpmos] = ACTIONS(5314),
    [anon_sym_nand] = ACTIONS(5314),
    [anon_sym_nor] = ACTIONS(5314),
    [anon_sym_xor] = ACTIONS(5314),
    [anon_sym_xnor] = ACTIONS(5314),
    [anon_sym_buf] = ACTIONS(5314),
    [anon_sym_tranif0] = ACTIONS(5314),
    [anon_sym_tranif1] = ACTIONS(5314),
    [anon_sym_rtranif1] = ACTIONS(5314),
    [anon_sym_rtranif0] = ACTIONS(5314),
    [anon_sym_tran] = ACTIONS(5314),
    [anon_sym_rtran] = ACTIONS(5314),
    [anon_sym_generate] = ACTIONS(5314),
    [anon_sym_endgenerate] = ACTIONS(5314),
    [anon_sym_for] = ACTIONS(5314),
    [anon_sym_initial] = ACTIONS(5314),
    [anon_sym_assign] = ACTIONS(5314),
    [anon_sym_alias] = ACTIONS(5314),
    [anon_sym_always_comb] = ACTIONS(5314),
    [anon_sym_always_latch] = ACTIONS(5314),
    [anon_sym_always_ff] = ACTIONS(5314),
    [anon_sym_final] = ACTIONS(5314),
    [anon_sym_global] = ACTIONS(5314),
    [anon_sym_LPAREN_STAR] = ACTIONS(5312),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5312),
    [anon_sym_DOLLARunit] = ACTIONS(5312),
  },
  [4965] = {
    [sym_simple_identifier] = ACTIONS(6393),
    [anon_sym_wire] = ACTIONS(6393),
    [anon_sym_tri] = ACTIONS(6393),
    [anon_sym_tri0] = ACTIONS(6393),
    [anon_sym_tri1] = ACTIONS(6393),
    [anon_sym_wand] = ACTIONS(6393),
    [anon_sym_triand] = ACTIONS(6393),
    [anon_sym_wor] = ACTIONS(6393),
    [anon_sym_trior] = ACTIONS(6393),
    [anon_sym_trireg] = ACTIONS(6393),
    [anon_sym_uwire] = ACTIONS(6393),
    [anon_sym_SEMI] = ACTIONS(6395),
    [anon_sym_extern] = ACTIONS(6393),
    [anon_sym_interface] = ACTIONS(6393),
    [anon_sym_checker] = ACTIONS(6393),
    [anon_sym_virtual] = ACTIONS(6393),
    [anon_sym_class] = ACTIONS(6393),
    [anon_sym_type] = ACTIONS(6393),
    [anon_sym_DOLLARfatal] = ACTIONS(6395),
    [anon_sym_DOLLARerror] = ACTIONS(6395),
    [anon_sym_DOLLARwarning] = ACTIONS(6395),
    [anon_sym_DOLLARinfo] = ACTIONS(6395),
    [anon_sym_default] = ACTIONS(6393),
    [anon_sym_clocking] = ACTIONS(6393),
    [anon_sym_defparam] = ACTIONS(6393),
    [anon_sym_bind] = ACTIONS(6393),
    [anon_sym_rand] = ACTIONS(6393),
    [anon_sym_const] = ACTIONS(6393),
    [anon_sym_function] = ACTIONS(6393),
    [anon_sym_static] = ACTIONS(6393),
    [anon_sym_constraint] = ACTIONS(6393),
    [anon_sym_if] = ACTIONS(6393),
    [anon_sym_else] = ACTIONS(6393),
    [anon_sym_LBRACK] = ACTIONS(6395),
    [anon_sym_localparam] = ACTIONS(6393),
    [anon_sym_parameter] = ACTIONS(6393),
    [anon_sym_var] = ACTIONS(6393),
    [anon_sym_import] = ACTIONS(6393),
    [anon_sym_export] = ACTIONS(6393),
    [anon_sym_genvar] = ACTIONS(6393),
    [anon_sym_interconnect] = ACTIONS(6393),
    [anon_sym_typedef] = ACTIONS(6393),
    [anon_sym_enum] = ACTIONS(6393),
    [anon_sym_struct] = ACTIONS(6393),
    [anon_sym_union] = ACTIONS(6393),
    [anon_sym_nettype] = ACTIONS(6393),
    [anon_sym_automatic] = ACTIONS(6393),
    [anon_sym_string] = ACTIONS(6393),
    [anon_sym_chandle] = ACTIONS(6393),
    [anon_sym_event] = ACTIONS(6393),
    [anon_sym_byte] = ACTIONS(6393),
    [anon_sym_shortint] = ACTIONS(6393),
    [anon_sym_int] = ACTIONS(6393),
    [anon_sym_longint] = ACTIONS(6393),
    [anon_sym_integer] = ACTIONS(6393),
    [anon_sym_time] = ACTIONS(6393),
    [anon_sym_bit] = ACTIONS(6393),
    [anon_sym_logic] = ACTIONS(6393),
    [anon_sym_reg] = ACTIONS(6393),
    [anon_sym_shortreal] = ACTIONS(6393),
    [anon_sym_real] = ACTIONS(6393),
    [anon_sym_realtime] = ACTIONS(6393),
    [anon_sym_supply0] = ACTIONS(6393),
    [anon_sym_supply1] = ACTIONS(6393),
    [anon_sym_signed] = ACTIONS(6393),
    [anon_sym_unsigned] = ACTIONS(6393),
    [anon_sym_task] = ACTIONS(6393),
    [anon_sym_assert] = ACTIONS(6393),
    [anon_sym_property] = ACTIONS(6393),
    [anon_sym_assume] = ACTIONS(6393),
    [anon_sym_cover] = ACTIONS(6393),
    [anon_sym_sequence] = ACTIONS(6393),
    [anon_sym_restrict] = ACTIONS(6393),
    [anon_sym_not] = ACTIONS(6393),
    [anon_sym_or] = ACTIONS(6393),
    [anon_sym_and] = ACTIONS(6393),
    [anon_sym_case] = ACTIONS(6393),
    [anon_sym_always] = ACTIONS(6393),
    [anon_sym_covergroup] = ACTIONS(6393),
    [anon_sym_let] = ACTIONS(6393),
    [anon_sym_pulldown] = ACTIONS(6393),
    [anon_sym_pullup] = ACTIONS(6393),
    [anon_sym_cmos] = ACTIONS(6393),
    [anon_sym_rcmos] = ACTIONS(6393),
    [anon_sym_bufif0] = ACTIONS(6393),
    [anon_sym_bufif1] = ACTIONS(6393),
    [anon_sym_notif0] = ACTIONS(6393),
    [anon_sym_notif1] = ACTIONS(6393),
    [anon_sym_nmos] = ACTIONS(6393),
    [anon_sym_pmos] = ACTIONS(6393),
    [anon_sym_rnmos] = ACTIONS(6393),
    [anon_sym_rpmos] = ACTIONS(6393),
    [anon_sym_nand] = ACTIONS(6393),
    [anon_sym_nor] = ACTIONS(6393),
    [anon_sym_xor] = ACTIONS(6393),
    [anon_sym_xnor] = ACTIONS(6393),
    [anon_sym_buf] = ACTIONS(6393),
    [anon_sym_tranif0] = ACTIONS(6393),
    [anon_sym_tranif1] = ACTIONS(6393),
    [anon_sym_rtranif1] = ACTIONS(6393),
    [anon_sym_rtranif0] = ACTIONS(6393),
    [anon_sym_tran] = ACTIONS(6393),
    [anon_sym_rtran] = ACTIONS(6393),
    [anon_sym_generate] = ACTIONS(6393),
    [anon_sym_endgenerate] = ACTIONS(6393),
    [anon_sym_for] = ACTIONS(6393),
    [anon_sym_initial] = ACTIONS(6393),
    [anon_sym_assign] = ACTIONS(6393),
    [anon_sym_alias] = ACTIONS(6393),
    [anon_sym_always_comb] = ACTIONS(6393),
    [anon_sym_always_latch] = ACTIONS(6393),
    [anon_sym_always_ff] = ACTIONS(6393),
    [anon_sym_final] = ACTIONS(6393),
    [anon_sym_global] = ACTIONS(6393),
    [anon_sym_LPAREN_STAR] = ACTIONS(6395),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6395),
    [anon_sym_DOLLARunit] = ACTIONS(6395),
  },
  [4966] = {
    [sym_simple_identifier] = ACTIONS(4322),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_rand] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_endgenerate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [4967] = {
    [sym_simple_identifier] = ACTIONS(6265),
    [anon_sym_wire] = ACTIONS(6265),
    [anon_sym_tri] = ACTIONS(6265),
    [anon_sym_tri0] = ACTIONS(6265),
    [anon_sym_tri1] = ACTIONS(6265),
    [anon_sym_wand] = ACTIONS(6265),
    [anon_sym_triand] = ACTIONS(6265),
    [anon_sym_wor] = ACTIONS(6265),
    [anon_sym_trior] = ACTIONS(6265),
    [anon_sym_trireg] = ACTIONS(6265),
    [anon_sym_uwire] = ACTIONS(6265),
    [anon_sym_SEMI] = ACTIONS(6267),
    [anon_sym_extern] = ACTIONS(6265),
    [anon_sym_interface] = ACTIONS(6265),
    [anon_sym_checker] = ACTIONS(6265),
    [anon_sym_virtual] = ACTIONS(6265),
    [anon_sym_class] = ACTIONS(6265),
    [anon_sym_type] = ACTIONS(6265),
    [anon_sym_DOLLARfatal] = ACTIONS(6267),
    [anon_sym_DOLLARerror] = ACTIONS(6267),
    [anon_sym_DOLLARwarning] = ACTIONS(6267),
    [anon_sym_DOLLARinfo] = ACTIONS(6267),
    [anon_sym_default] = ACTIONS(6265),
    [anon_sym_clocking] = ACTIONS(6265),
    [anon_sym_defparam] = ACTIONS(6265),
    [anon_sym_bind] = ACTIONS(6265),
    [anon_sym_rand] = ACTIONS(6265),
    [anon_sym_const] = ACTIONS(6265),
    [anon_sym_function] = ACTIONS(6265),
    [anon_sym_static] = ACTIONS(6265),
    [anon_sym_constraint] = ACTIONS(6265),
    [anon_sym_if] = ACTIONS(6265),
    [anon_sym_else] = ACTIONS(6265),
    [anon_sym_LBRACK] = ACTIONS(6267),
    [anon_sym_localparam] = ACTIONS(6265),
    [anon_sym_parameter] = ACTIONS(6265),
    [anon_sym_var] = ACTIONS(6265),
    [anon_sym_import] = ACTIONS(6265),
    [anon_sym_export] = ACTIONS(6265),
    [anon_sym_genvar] = ACTIONS(6265),
    [anon_sym_interconnect] = ACTIONS(6265),
    [anon_sym_typedef] = ACTIONS(6265),
    [anon_sym_enum] = ACTIONS(6265),
    [anon_sym_struct] = ACTIONS(6265),
    [anon_sym_union] = ACTIONS(6265),
    [anon_sym_nettype] = ACTIONS(6265),
    [anon_sym_automatic] = ACTIONS(6265),
    [anon_sym_string] = ACTIONS(6265),
    [anon_sym_chandle] = ACTIONS(6265),
    [anon_sym_event] = ACTIONS(6265),
    [anon_sym_byte] = ACTIONS(6265),
    [anon_sym_shortint] = ACTIONS(6265),
    [anon_sym_int] = ACTIONS(6265),
    [anon_sym_longint] = ACTIONS(6265),
    [anon_sym_integer] = ACTIONS(6265),
    [anon_sym_time] = ACTIONS(6265),
    [anon_sym_bit] = ACTIONS(6265),
    [anon_sym_logic] = ACTIONS(6265),
    [anon_sym_reg] = ACTIONS(6265),
    [anon_sym_shortreal] = ACTIONS(6265),
    [anon_sym_real] = ACTIONS(6265),
    [anon_sym_realtime] = ACTIONS(6265),
    [anon_sym_supply0] = ACTIONS(6265),
    [anon_sym_supply1] = ACTIONS(6265),
    [anon_sym_signed] = ACTIONS(6265),
    [anon_sym_unsigned] = ACTIONS(6265),
    [anon_sym_task] = ACTIONS(6265),
    [anon_sym_assert] = ACTIONS(6265),
    [anon_sym_property] = ACTIONS(6265),
    [anon_sym_assume] = ACTIONS(6265),
    [anon_sym_cover] = ACTIONS(6265),
    [anon_sym_sequence] = ACTIONS(6265),
    [anon_sym_restrict] = ACTIONS(6265),
    [anon_sym_not] = ACTIONS(6265),
    [anon_sym_or] = ACTIONS(6265),
    [anon_sym_and] = ACTIONS(6265),
    [anon_sym_case] = ACTIONS(6265),
    [anon_sym_always] = ACTIONS(6265),
    [anon_sym_covergroup] = ACTIONS(6265),
    [anon_sym_let] = ACTIONS(6265),
    [anon_sym_pulldown] = ACTIONS(6265),
    [anon_sym_pullup] = ACTIONS(6265),
    [anon_sym_cmos] = ACTIONS(6265),
    [anon_sym_rcmos] = ACTIONS(6265),
    [anon_sym_bufif0] = ACTIONS(6265),
    [anon_sym_bufif1] = ACTIONS(6265),
    [anon_sym_notif0] = ACTIONS(6265),
    [anon_sym_notif1] = ACTIONS(6265),
    [anon_sym_nmos] = ACTIONS(6265),
    [anon_sym_pmos] = ACTIONS(6265),
    [anon_sym_rnmos] = ACTIONS(6265),
    [anon_sym_rpmos] = ACTIONS(6265),
    [anon_sym_nand] = ACTIONS(6265),
    [anon_sym_nor] = ACTIONS(6265),
    [anon_sym_xor] = ACTIONS(6265),
    [anon_sym_xnor] = ACTIONS(6265),
    [anon_sym_buf] = ACTIONS(6265),
    [anon_sym_tranif0] = ACTIONS(6265),
    [anon_sym_tranif1] = ACTIONS(6265),
    [anon_sym_rtranif1] = ACTIONS(6265),
    [anon_sym_rtranif0] = ACTIONS(6265),
    [anon_sym_tran] = ACTIONS(6265),
    [anon_sym_rtran] = ACTIONS(6265),
    [anon_sym_generate] = ACTIONS(6265),
    [anon_sym_endgenerate] = ACTIONS(6265),
    [anon_sym_for] = ACTIONS(6265),
    [anon_sym_initial] = ACTIONS(6265),
    [anon_sym_assign] = ACTIONS(6265),
    [anon_sym_alias] = ACTIONS(6265),
    [anon_sym_always_comb] = ACTIONS(6265),
    [anon_sym_always_latch] = ACTIONS(6265),
    [anon_sym_always_ff] = ACTIONS(6265),
    [anon_sym_final] = ACTIONS(6265),
    [anon_sym_global] = ACTIONS(6265),
    [anon_sym_LPAREN_STAR] = ACTIONS(6267),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6267),
    [anon_sym_DOLLARunit] = ACTIONS(6267),
  },
  [4968] = {
    [sym_simple_identifier] = ACTIONS(6375),
    [anon_sym_wire] = ACTIONS(6375),
    [anon_sym_tri] = ACTIONS(6375),
    [anon_sym_tri0] = ACTIONS(6375),
    [anon_sym_tri1] = ACTIONS(6375),
    [anon_sym_wand] = ACTIONS(6375),
    [anon_sym_triand] = ACTIONS(6375),
    [anon_sym_wor] = ACTIONS(6375),
    [anon_sym_trior] = ACTIONS(6375),
    [anon_sym_trireg] = ACTIONS(6375),
    [anon_sym_uwire] = ACTIONS(6375),
    [anon_sym_SEMI] = ACTIONS(6377),
    [anon_sym_extern] = ACTIONS(6375),
    [anon_sym_interface] = ACTIONS(6375),
    [anon_sym_checker] = ACTIONS(6375),
    [anon_sym_virtual] = ACTIONS(6375),
    [anon_sym_class] = ACTIONS(6375),
    [anon_sym_type] = ACTIONS(6375),
    [anon_sym_DOLLARfatal] = ACTIONS(6377),
    [anon_sym_DOLLARerror] = ACTIONS(6377),
    [anon_sym_DOLLARwarning] = ACTIONS(6377),
    [anon_sym_DOLLARinfo] = ACTIONS(6377),
    [anon_sym_default] = ACTIONS(6375),
    [anon_sym_clocking] = ACTIONS(6375),
    [anon_sym_defparam] = ACTIONS(6375),
    [anon_sym_bind] = ACTIONS(6375),
    [anon_sym_rand] = ACTIONS(6375),
    [anon_sym_const] = ACTIONS(6375),
    [anon_sym_function] = ACTIONS(6375),
    [anon_sym_static] = ACTIONS(6375),
    [anon_sym_constraint] = ACTIONS(6375),
    [anon_sym_if] = ACTIONS(6375),
    [anon_sym_else] = ACTIONS(6375),
    [anon_sym_LBRACK] = ACTIONS(6377),
    [anon_sym_localparam] = ACTIONS(6375),
    [anon_sym_parameter] = ACTIONS(6375),
    [anon_sym_var] = ACTIONS(6375),
    [anon_sym_import] = ACTIONS(6375),
    [anon_sym_export] = ACTIONS(6375),
    [anon_sym_genvar] = ACTIONS(6375),
    [anon_sym_interconnect] = ACTIONS(6375),
    [anon_sym_typedef] = ACTIONS(6375),
    [anon_sym_enum] = ACTIONS(6375),
    [anon_sym_struct] = ACTIONS(6375),
    [anon_sym_union] = ACTIONS(6375),
    [anon_sym_nettype] = ACTIONS(6375),
    [anon_sym_automatic] = ACTIONS(6375),
    [anon_sym_string] = ACTIONS(6375),
    [anon_sym_chandle] = ACTIONS(6375),
    [anon_sym_event] = ACTIONS(6375),
    [anon_sym_byte] = ACTIONS(6375),
    [anon_sym_shortint] = ACTIONS(6375),
    [anon_sym_int] = ACTIONS(6375),
    [anon_sym_longint] = ACTIONS(6375),
    [anon_sym_integer] = ACTIONS(6375),
    [anon_sym_time] = ACTIONS(6375),
    [anon_sym_bit] = ACTIONS(6375),
    [anon_sym_logic] = ACTIONS(6375),
    [anon_sym_reg] = ACTIONS(6375),
    [anon_sym_shortreal] = ACTIONS(6375),
    [anon_sym_real] = ACTIONS(6375),
    [anon_sym_realtime] = ACTIONS(6375),
    [anon_sym_supply0] = ACTIONS(6375),
    [anon_sym_supply1] = ACTIONS(6375),
    [anon_sym_signed] = ACTIONS(6375),
    [anon_sym_unsigned] = ACTIONS(6375),
    [anon_sym_task] = ACTIONS(6375),
    [anon_sym_assert] = ACTIONS(6375),
    [anon_sym_property] = ACTIONS(6375),
    [anon_sym_assume] = ACTIONS(6375),
    [anon_sym_cover] = ACTIONS(6375),
    [anon_sym_sequence] = ACTIONS(6375),
    [anon_sym_restrict] = ACTIONS(6375),
    [anon_sym_not] = ACTIONS(6375),
    [anon_sym_or] = ACTIONS(6375),
    [anon_sym_and] = ACTIONS(6375),
    [anon_sym_case] = ACTIONS(6375),
    [anon_sym_always] = ACTIONS(6375),
    [anon_sym_covergroup] = ACTIONS(6375),
    [anon_sym_let] = ACTIONS(6375),
    [anon_sym_pulldown] = ACTIONS(6375),
    [anon_sym_pullup] = ACTIONS(6375),
    [anon_sym_cmos] = ACTIONS(6375),
    [anon_sym_rcmos] = ACTIONS(6375),
    [anon_sym_bufif0] = ACTIONS(6375),
    [anon_sym_bufif1] = ACTIONS(6375),
    [anon_sym_notif0] = ACTIONS(6375),
    [anon_sym_notif1] = ACTIONS(6375),
    [anon_sym_nmos] = ACTIONS(6375),
    [anon_sym_pmos] = ACTIONS(6375),
    [anon_sym_rnmos] = ACTIONS(6375),
    [anon_sym_rpmos] = ACTIONS(6375),
    [anon_sym_nand] = ACTIONS(6375),
    [anon_sym_nor] = ACTIONS(6375),
    [anon_sym_xor] = ACTIONS(6375),
    [anon_sym_xnor] = ACTIONS(6375),
    [anon_sym_buf] = ACTIONS(6375),
    [anon_sym_tranif0] = ACTIONS(6375),
    [anon_sym_tranif1] = ACTIONS(6375),
    [anon_sym_rtranif1] = ACTIONS(6375),
    [anon_sym_rtranif0] = ACTIONS(6375),
    [anon_sym_tran] = ACTIONS(6375),
    [anon_sym_rtran] = ACTIONS(6375),
    [anon_sym_generate] = ACTIONS(6375),
    [anon_sym_endgenerate] = ACTIONS(6375),
    [anon_sym_for] = ACTIONS(6375),
    [anon_sym_initial] = ACTIONS(6375),
    [anon_sym_assign] = ACTIONS(6375),
    [anon_sym_alias] = ACTIONS(6375),
    [anon_sym_always_comb] = ACTIONS(6375),
    [anon_sym_always_latch] = ACTIONS(6375),
    [anon_sym_always_ff] = ACTIONS(6375),
    [anon_sym_final] = ACTIONS(6375),
    [anon_sym_global] = ACTIONS(6375),
    [anon_sym_LPAREN_STAR] = ACTIONS(6377),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6377),
    [anon_sym_DOLLARunit] = ACTIONS(6377),
  },
  [4969] = {
    [sym_simple_identifier] = ACTIONS(4916),
    [anon_sym_wire] = ACTIONS(4916),
    [anon_sym_tri] = ACTIONS(4916),
    [anon_sym_tri0] = ACTIONS(4916),
    [anon_sym_tri1] = ACTIONS(4916),
    [anon_sym_wand] = ACTIONS(4916),
    [anon_sym_triand] = ACTIONS(4916),
    [anon_sym_wor] = ACTIONS(4916),
    [anon_sym_trior] = ACTIONS(4916),
    [anon_sym_trireg] = ACTIONS(4916),
    [anon_sym_uwire] = ACTIONS(4916),
    [anon_sym_SEMI] = ACTIONS(4914),
    [anon_sym_extern] = ACTIONS(4916),
    [anon_sym_interface] = ACTIONS(4916),
    [anon_sym_checker] = ACTIONS(4916),
    [anon_sym_virtual] = ACTIONS(4916),
    [anon_sym_class] = ACTIONS(4916),
    [anon_sym_type] = ACTIONS(4916),
    [anon_sym_DOLLARfatal] = ACTIONS(4914),
    [anon_sym_DOLLARerror] = ACTIONS(4914),
    [anon_sym_DOLLARwarning] = ACTIONS(4914),
    [anon_sym_DOLLARinfo] = ACTIONS(4914),
    [anon_sym_default] = ACTIONS(4916),
    [anon_sym_clocking] = ACTIONS(4916),
    [anon_sym_defparam] = ACTIONS(4916),
    [anon_sym_bind] = ACTIONS(4916),
    [anon_sym_rand] = ACTIONS(4916),
    [anon_sym_const] = ACTIONS(4916),
    [anon_sym_function] = ACTIONS(4916),
    [anon_sym_static] = ACTIONS(4916),
    [anon_sym_constraint] = ACTIONS(4916),
    [anon_sym_if] = ACTIONS(4916),
    [anon_sym_else] = ACTIONS(4916),
    [anon_sym_LBRACK] = ACTIONS(4914),
    [anon_sym_localparam] = ACTIONS(4916),
    [anon_sym_parameter] = ACTIONS(4916),
    [anon_sym_var] = ACTIONS(4916),
    [anon_sym_import] = ACTIONS(4916),
    [anon_sym_export] = ACTIONS(4916),
    [anon_sym_genvar] = ACTIONS(4916),
    [anon_sym_interconnect] = ACTIONS(4916),
    [anon_sym_typedef] = ACTIONS(4916),
    [anon_sym_enum] = ACTIONS(4916),
    [anon_sym_struct] = ACTIONS(4916),
    [anon_sym_union] = ACTIONS(4916),
    [anon_sym_nettype] = ACTIONS(4916),
    [anon_sym_automatic] = ACTIONS(4916),
    [anon_sym_string] = ACTIONS(4916),
    [anon_sym_chandle] = ACTIONS(4916),
    [anon_sym_event] = ACTIONS(4916),
    [anon_sym_byte] = ACTIONS(4916),
    [anon_sym_shortint] = ACTIONS(4916),
    [anon_sym_int] = ACTIONS(4916),
    [anon_sym_longint] = ACTIONS(4916),
    [anon_sym_integer] = ACTIONS(4916),
    [anon_sym_time] = ACTIONS(4916),
    [anon_sym_bit] = ACTIONS(4916),
    [anon_sym_logic] = ACTIONS(4916),
    [anon_sym_reg] = ACTIONS(4916),
    [anon_sym_shortreal] = ACTIONS(4916),
    [anon_sym_real] = ACTIONS(4916),
    [anon_sym_realtime] = ACTIONS(4916),
    [anon_sym_supply0] = ACTIONS(4916),
    [anon_sym_supply1] = ACTIONS(4916),
    [anon_sym_signed] = ACTIONS(4916),
    [anon_sym_unsigned] = ACTIONS(4916),
    [anon_sym_task] = ACTIONS(4916),
    [anon_sym_assert] = ACTIONS(4916),
    [anon_sym_property] = ACTIONS(4916),
    [anon_sym_assume] = ACTIONS(4916),
    [anon_sym_cover] = ACTIONS(4916),
    [anon_sym_sequence] = ACTIONS(4916),
    [anon_sym_restrict] = ACTIONS(4916),
    [anon_sym_not] = ACTIONS(4916),
    [anon_sym_or] = ACTIONS(4916),
    [anon_sym_and] = ACTIONS(4916),
    [anon_sym_case] = ACTIONS(4916),
    [anon_sym_always] = ACTIONS(4916),
    [anon_sym_covergroup] = ACTIONS(4916),
    [anon_sym_let] = ACTIONS(4916),
    [anon_sym_pulldown] = ACTIONS(4916),
    [anon_sym_pullup] = ACTIONS(4916),
    [anon_sym_cmos] = ACTIONS(4916),
    [anon_sym_rcmos] = ACTIONS(4916),
    [anon_sym_bufif0] = ACTIONS(4916),
    [anon_sym_bufif1] = ACTIONS(4916),
    [anon_sym_notif0] = ACTIONS(4916),
    [anon_sym_notif1] = ACTIONS(4916),
    [anon_sym_nmos] = ACTIONS(4916),
    [anon_sym_pmos] = ACTIONS(4916),
    [anon_sym_rnmos] = ACTIONS(4916),
    [anon_sym_rpmos] = ACTIONS(4916),
    [anon_sym_nand] = ACTIONS(4916),
    [anon_sym_nor] = ACTIONS(4916),
    [anon_sym_xor] = ACTIONS(4916),
    [anon_sym_xnor] = ACTIONS(4916),
    [anon_sym_buf] = ACTIONS(4916),
    [anon_sym_tranif0] = ACTIONS(4916),
    [anon_sym_tranif1] = ACTIONS(4916),
    [anon_sym_rtranif1] = ACTIONS(4916),
    [anon_sym_rtranif0] = ACTIONS(4916),
    [anon_sym_tran] = ACTIONS(4916),
    [anon_sym_rtran] = ACTIONS(4916),
    [anon_sym_generate] = ACTIONS(4916),
    [anon_sym_endgenerate] = ACTIONS(4916),
    [anon_sym_for] = ACTIONS(4916),
    [anon_sym_initial] = ACTIONS(4916),
    [anon_sym_assign] = ACTIONS(4916),
    [anon_sym_alias] = ACTIONS(4916),
    [anon_sym_always_comb] = ACTIONS(4916),
    [anon_sym_always_latch] = ACTIONS(4916),
    [anon_sym_always_ff] = ACTIONS(4916),
    [anon_sym_final] = ACTIONS(4916),
    [anon_sym_global] = ACTIONS(4916),
    [anon_sym_LPAREN_STAR] = ACTIONS(4914),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4914),
    [anon_sym_DOLLARunit] = ACTIONS(4914),
  },
  [4970] = {
    [sym_simple_identifier] = ACTIONS(4124),
    [anon_sym_wire] = ACTIONS(4124),
    [anon_sym_tri] = ACTIONS(4124),
    [anon_sym_tri0] = ACTIONS(4124),
    [anon_sym_tri1] = ACTIONS(4124),
    [anon_sym_wand] = ACTIONS(4124),
    [anon_sym_triand] = ACTIONS(4124),
    [anon_sym_wor] = ACTIONS(4124),
    [anon_sym_trior] = ACTIONS(4124),
    [anon_sym_trireg] = ACTIONS(4124),
    [anon_sym_uwire] = ACTIONS(4124),
    [anon_sym_SEMI] = ACTIONS(4122),
    [anon_sym_extern] = ACTIONS(4124),
    [anon_sym_interface] = ACTIONS(4124),
    [anon_sym_checker] = ACTIONS(4124),
    [anon_sym_virtual] = ACTIONS(4124),
    [anon_sym_class] = ACTIONS(4124),
    [anon_sym_type] = ACTIONS(4124),
    [anon_sym_DOLLARfatal] = ACTIONS(4122),
    [anon_sym_DOLLARerror] = ACTIONS(4122),
    [anon_sym_DOLLARwarning] = ACTIONS(4122),
    [anon_sym_DOLLARinfo] = ACTIONS(4122),
    [anon_sym_default] = ACTIONS(4124),
    [anon_sym_clocking] = ACTIONS(4124),
    [anon_sym_defparam] = ACTIONS(4124),
    [anon_sym_bind] = ACTIONS(4124),
    [anon_sym_rand] = ACTIONS(4124),
    [anon_sym_const] = ACTIONS(4124),
    [anon_sym_function] = ACTIONS(4124),
    [anon_sym_static] = ACTIONS(4124),
    [anon_sym_constraint] = ACTIONS(4124),
    [anon_sym_if] = ACTIONS(4124),
    [anon_sym_else] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4122),
    [anon_sym_localparam] = ACTIONS(4124),
    [anon_sym_parameter] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4124),
    [anon_sym_import] = ACTIONS(4124),
    [anon_sym_export] = ACTIONS(4124),
    [anon_sym_genvar] = ACTIONS(4124),
    [anon_sym_interconnect] = ACTIONS(4124),
    [anon_sym_typedef] = ACTIONS(4124),
    [anon_sym_enum] = ACTIONS(4124),
    [anon_sym_struct] = ACTIONS(4124),
    [anon_sym_union] = ACTIONS(4124),
    [anon_sym_nettype] = ACTIONS(4124),
    [anon_sym_automatic] = ACTIONS(4124),
    [anon_sym_string] = ACTIONS(4124),
    [anon_sym_chandle] = ACTIONS(4124),
    [anon_sym_event] = ACTIONS(4124),
    [anon_sym_byte] = ACTIONS(4124),
    [anon_sym_shortint] = ACTIONS(4124),
    [anon_sym_int] = ACTIONS(4124),
    [anon_sym_longint] = ACTIONS(4124),
    [anon_sym_integer] = ACTIONS(4124),
    [anon_sym_time] = ACTIONS(4124),
    [anon_sym_bit] = ACTIONS(4124),
    [anon_sym_logic] = ACTIONS(4124),
    [anon_sym_reg] = ACTIONS(4124),
    [anon_sym_shortreal] = ACTIONS(4124),
    [anon_sym_real] = ACTIONS(4124),
    [anon_sym_realtime] = ACTIONS(4124),
    [anon_sym_supply0] = ACTIONS(4124),
    [anon_sym_supply1] = ACTIONS(4124),
    [anon_sym_signed] = ACTIONS(4124),
    [anon_sym_unsigned] = ACTIONS(4124),
    [anon_sym_task] = ACTIONS(4124),
    [anon_sym_assert] = ACTIONS(4124),
    [anon_sym_property] = ACTIONS(4124),
    [anon_sym_assume] = ACTIONS(4124),
    [anon_sym_cover] = ACTIONS(4124),
    [anon_sym_sequence] = ACTIONS(4124),
    [anon_sym_restrict] = ACTIONS(4124),
    [anon_sym_not] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_case] = ACTIONS(4124),
    [anon_sym_always] = ACTIONS(4124),
    [anon_sym_covergroup] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_pulldown] = ACTIONS(4124),
    [anon_sym_pullup] = ACTIONS(4124),
    [anon_sym_cmos] = ACTIONS(4124),
    [anon_sym_rcmos] = ACTIONS(4124),
    [anon_sym_bufif0] = ACTIONS(4124),
    [anon_sym_bufif1] = ACTIONS(4124),
    [anon_sym_notif0] = ACTIONS(4124),
    [anon_sym_notif1] = ACTIONS(4124),
    [anon_sym_nmos] = ACTIONS(4124),
    [anon_sym_pmos] = ACTIONS(4124),
    [anon_sym_rnmos] = ACTIONS(4124),
    [anon_sym_rpmos] = ACTIONS(4124),
    [anon_sym_nand] = ACTIONS(4124),
    [anon_sym_nor] = ACTIONS(4124),
    [anon_sym_xor] = ACTIONS(4124),
    [anon_sym_xnor] = ACTIONS(4124),
    [anon_sym_buf] = ACTIONS(4124),
    [anon_sym_tranif0] = ACTIONS(4124),
    [anon_sym_tranif1] = ACTIONS(4124),
    [anon_sym_rtranif1] = ACTIONS(4124),
    [anon_sym_rtranif0] = ACTIONS(4124),
    [anon_sym_tran] = ACTIONS(4124),
    [anon_sym_rtran] = ACTIONS(4124),
    [anon_sym_generate] = ACTIONS(4124),
    [anon_sym_endgenerate] = ACTIONS(4124),
    [anon_sym_for] = ACTIONS(4124),
    [anon_sym_initial] = ACTIONS(4124),
    [anon_sym_assign] = ACTIONS(4124),
    [anon_sym_alias] = ACTIONS(4124),
    [anon_sym_always_comb] = ACTIONS(4124),
    [anon_sym_always_latch] = ACTIONS(4124),
    [anon_sym_always_ff] = ACTIONS(4124),
    [anon_sym_final] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4124),
    [anon_sym_LPAREN_STAR] = ACTIONS(4122),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4122),
    [anon_sym_DOLLARunit] = ACTIONS(4122),
  },
  [4971] = {
    [sym_simple_identifier] = ACTIONS(5210),
    [anon_sym_wire] = ACTIONS(5210),
    [anon_sym_tri] = ACTIONS(5210),
    [anon_sym_tri0] = ACTIONS(5210),
    [anon_sym_tri1] = ACTIONS(5210),
    [anon_sym_wand] = ACTIONS(5210),
    [anon_sym_triand] = ACTIONS(5210),
    [anon_sym_wor] = ACTIONS(5210),
    [anon_sym_trior] = ACTIONS(5210),
    [anon_sym_trireg] = ACTIONS(5210),
    [anon_sym_uwire] = ACTIONS(5210),
    [anon_sym_SEMI] = ACTIONS(5208),
    [anon_sym_extern] = ACTIONS(5210),
    [anon_sym_interface] = ACTIONS(5210),
    [anon_sym_checker] = ACTIONS(5210),
    [anon_sym_virtual] = ACTIONS(5210),
    [anon_sym_class] = ACTIONS(5210),
    [anon_sym_type] = ACTIONS(5210),
    [anon_sym_DOLLARfatal] = ACTIONS(5208),
    [anon_sym_DOLLARerror] = ACTIONS(5208),
    [anon_sym_DOLLARwarning] = ACTIONS(5208),
    [anon_sym_DOLLARinfo] = ACTIONS(5208),
    [anon_sym_default] = ACTIONS(5210),
    [anon_sym_clocking] = ACTIONS(5210),
    [anon_sym_defparam] = ACTIONS(5210),
    [anon_sym_bind] = ACTIONS(5210),
    [anon_sym_rand] = ACTIONS(5210),
    [anon_sym_const] = ACTIONS(5210),
    [anon_sym_function] = ACTIONS(5210),
    [anon_sym_static] = ACTIONS(5210),
    [anon_sym_constraint] = ACTIONS(5210),
    [anon_sym_if] = ACTIONS(5210),
    [anon_sym_else] = ACTIONS(5210),
    [anon_sym_LBRACK] = ACTIONS(5208),
    [anon_sym_localparam] = ACTIONS(5210),
    [anon_sym_parameter] = ACTIONS(5210),
    [anon_sym_var] = ACTIONS(5210),
    [anon_sym_import] = ACTIONS(5210),
    [anon_sym_export] = ACTIONS(5210),
    [anon_sym_genvar] = ACTIONS(5210),
    [anon_sym_interconnect] = ACTIONS(5210),
    [anon_sym_typedef] = ACTIONS(5210),
    [anon_sym_enum] = ACTIONS(5210),
    [anon_sym_struct] = ACTIONS(5210),
    [anon_sym_union] = ACTIONS(5210),
    [anon_sym_nettype] = ACTIONS(5210),
    [anon_sym_automatic] = ACTIONS(5210),
    [anon_sym_string] = ACTIONS(5210),
    [anon_sym_chandle] = ACTIONS(5210),
    [anon_sym_event] = ACTIONS(5210),
    [anon_sym_byte] = ACTIONS(5210),
    [anon_sym_shortint] = ACTIONS(5210),
    [anon_sym_int] = ACTIONS(5210),
    [anon_sym_longint] = ACTIONS(5210),
    [anon_sym_integer] = ACTIONS(5210),
    [anon_sym_time] = ACTIONS(5210),
    [anon_sym_bit] = ACTIONS(5210),
    [anon_sym_logic] = ACTIONS(5210),
    [anon_sym_reg] = ACTIONS(5210),
    [anon_sym_shortreal] = ACTIONS(5210),
    [anon_sym_real] = ACTIONS(5210),
    [anon_sym_realtime] = ACTIONS(5210),
    [anon_sym_supply0] = ACTIONS(5210),
    [anon_sym_supply1] = ACTIONS(5210),
    [anon_sym_signed] = ACTIONS(5210),
    [anon_sym_unsigned] = ACTIONS(5210),
    [anon_sym_task] = ACTIONS(5210),
    [anon_sym_assert] = ACTIONS(5210),
    [anon_sym_property] = ACTIONS(5210),
    [anon_sym_assume] = ACTIONS(5210),
    [anon_sym_cover] = ACTIONS(5210),
    [anon_sym_sequence] = ACTIONS(5210),
    [anon_sym_restrict] = ACTIONS(5210),
    [anon_sym_not] = ACTIONS(5210),
    [anon_sym_or] = ACTIONS(5210),
    [anon_sym_and] = ACTIONS(5210),
    [anon_sym_case] = ACTIONS(5210),
    [anon_sym_always] = ACTIONS(5210),
    [anon_sym_covergroup] = ACTIONS(5210),
    [anon_sym_end] = ACTIONS(5210),
    [anon_sym_let] = ACTIONS(5210),
    [anon_sym_pulldown] = ACTIONS(5210),
    [anon_sym_pullup] = ACTIONS(5210),
    [anon_sym_cmos] = ACTIONS(5210),
    [anon_sym_rcmos] = ACTIONS(5210),
    [anon_sym_bufif0] = ACTIONS(5210),
    [anon_sym_bufif1] = ACTIONS(5210),
    [anon_sym_notif0] = ACTIONS(5210),
    [anon_sym_notif1] = ACTIONS(5210),
    [anon_sym_nmos] = ACTIONS(5210),
    [anon_sym_pmos] = ACTIONS(5210),
    [anon_sym_rnmos] = ACTIONS(5210),
    [anon_sym_rpmos] = ACTIONS(5210),
    [anon_sym_nand] = ACTIONS(5210),
    [anon_sym_nor] = ACTIONS(5210),
    [anon_sym_xor] = ACTIONS(5210),
    [anon_sym_xnor] = ACTIONS(5210),
    [anon_sym_buf] = ACTIONS(5210),
    [anon_sym_tranif0] = ACTIONS(5210),
    [anon_sym_tranif1] = ACTIONS(5210),
    [anon_sym_rtranif1] = ACTIONS(5210),
    [anon_sym_rtranif0] = ACTIONS(5210),
    [anon_sym_tran] = ACTIONS(5210),
    [anon_sym_rtran] = ACTIONS(5210),
    [anon_sym_generate] = ACTIONS(5210),
    [anon_sym_for] = ACTIONS(5210),
    [anon_sym_initial] = ACTIONS(5210),
    [anon_sym_assign] = ACTIONS(5210),
    [anon_sym_alias] = ACTIONS(5210),
    [anon_sym_always_comb] = ACTIONS(5210),
    [anon_sym_always_latch] = ACTIONS(5210),
    [anon_sym_always_ff] = ACTIONS(5210),
    [anon_sym_final] = ACTIONS(5210),
    [anon_sym_global] = ACTIONS(5210),
    [anon_sym_LPAREN_STAR] = ACTIONS(5208),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5208),
    [anon_sym_DOLLARunit] = ACTIONS(5208),
  },
  [4972] = {
    [sym_simple_identifier] = ACTIONS(5202),
    [anon_sym_wire] = ACTIONS(5202),
    [anon_sym_tri] = ACTIONS(5202),
    [anon_sym_tri0] = ACTIONS(5202),
    [anon_sym_tri1] = ACTIONS(5202),
    [anon_sym_wand] = ACTIONS(5202),
    [anon_sym_triand] = ACTIONS(5202),
    [anon_sym_wor] = ACTIONS(5202),
    [anon_sym_trior] = ACTIONS(5202),
    [anon_sym_trireg] = ACTIONS(5202),
    [anon_sym_uwire] = ACTIONS(5202),
    [anon_sym_SEMI] = ACTIONS(5200),
    [anon_sym_extern] = ACTIONS(5202),
    [anon_sym_interface] = ACTIONS(5202),
    [anon_sym_checker] = ACTIONS(5202),
    [anon_sym_virtual] = ACTIONS(5202),
    [anon_sym_class] = ACTIONS(5202),
    [anon_sym_type] = ACTIONS(5202),
    [anon_sym_DOLLARfatal] = ACTIONS(5200),
    [anon_sym_DOLLARerror] = ACTIONS(5200),
    [anon_sym_DOLLARwarning] = ACTIONS(5200),
    [anon_sym_DOLLARinfo] = ACTIONS(5200),
    [anon_sym_default] = ACTIONS(5202),
    [anon_sym_clocking] = ACTIONS(5202),
    [anon_sym_defparam] = ACTIONS(5202),
    [anon_sym_bind] = ACTIONS(5202),
    [anon_sym_rand] = ACTIONS(5202),
    [anon_sym_const] = ACTIONS(5202),
    [anon_sym_function] = ACTIONS(5202),
    [anon_sym_static] = ACTIONS(5202),
    [anon_sym_constraint] = ACTIONS(5202),
    [anon_sym_if] = ACTIONS(5202),
    [anon_sym_else] = ACTIONS(5202),
    [anon_sym_LBRACK] = ACTIONS(5200),
    [anon_sym_localparam] = ACTIONS(5202),
    [anon_sym_parameter] = ACTIONS(5202),
    [anon_sym_var] = ACTIONS(5202),
    [anon_sym_import] = ACTIONS(5202),
    [anon_sym_export] = ACTIONS(5202),
    [anon_sym_genvar] = ACTIONS(5202),
    [anon_sym_interconnect] = ACTIONS(5202),
    [anon_sym_typedef] = ACTIONS(5202),
    [anon_sym_enum] = ACTIONS(5202),
    [anon_sym_struct] = ACTIONS(5202),
    [anon_sym_union] = ACTIONS(5202),
    [anon_sym_nettype] = ACTIONS(5202),
    [anon_sym_automatic] = ACTIONS(5202),
    [anon_sym_string] = ACTIONS(5202),
    [anon_sym_chandle] = ACTIONS(5202),
    [anon_sym_event] = ACTIONS(5202),
    [anon_sym_byte] = ACTIONS(5202),
    [anon_sym_shortint] = ACTIONS(5202),
    [anon_sym_int] = ACTIONS(5202),
    [anon_sym_longint] = ACTIONS(5202),
    [anon_sym_integer] = ACTIONS(5202),
    [anon_sym_time] = ACTIONS(5202),
    [anon_sym_bit] = ACTIONS(5202),
    [anon_sym_logic] = ACTIONS(5202),
    [anon_sym_reg] = ACTIONS(5202),
    [anon_sym_shortreal] = ACTIONS(5202),
    [anon_sym_real] = ACTIONS(5202),
    [anon_sym_realtime] = ACTIONS(5202),
    [anon_sym_supply0] = ACTIONS(5202),
    [anon_sym_supply1] = ACTIONS(5202),
    [anon_sym_signed] = ACTIONS(5202),
    [anon_sym_unsigned] = ACTIONS(5202),
    [anon_sym_task] = ACTIONS(5202),
    [anon_sym_assert] = ACTIONS(5202),
    [anon_sym_property] = ACTIONS(5202),
    [anon_sym_assume] = ACTIONS(5202),
    [anon_sym_cover] = ACTIONS(5202),
    [anon_sym_sequence] = ACTIONS(5202),
    [anon_sym_restrict] = ACTIONS(5202),
    [anon_sym_not] = ACTIONS(5202),
    [anon_sym_or] = ACTIONS(5202),
    [anon_sym_and] = ACTIONS(5202),
    [anon_sym_case] = ACTIONS(5202),
    [anon_sym_always] = ACTIONS(5202),
    [anon_sym_covergroup] = ACTIONS(5202),
    [anon_sym_end] = ACTIONS(5202),
    [anon_sym_let] = ACTIONS(5202),
    [anon_sym_pulldown] = ACTIONS(5202),
    [anon_sym_pullup] = ACTIONS(5202),
    [anon_sym_cmos] = ACTIONS(5202),
    [anon_sym_rcmos] = ACTIONS(5202),
    [anon_sym_bufif0] = ACTIONS(5202),
    [anon_sym_bufif1] = ACTIONS(5202),
    [anon_sym_notif0] = ACTIONS(5202),
    [anon_sym_notif1] = ACTIONS(5202),
    [anon_sym_nmos] = ACTIONS(5202),
    [anon_sym_pmos] = ACTIONS(5202),
    [anon_sym_rnmos] = ACTIONS(5202),
    [anon_sym_rpmos] = ACTIONS(5202),
    [anon_sym_nand] = ACTIONS(5202),
    [anon_sym_nor] = ACTIONS(5202),
    [anon_sym_xor] = ACTIONS(5202),
    [anon_sym_xnor] = ACTIONS(5202),
    [anon_sym_buf] = ACTIONS(5202),
    [anon_sym_tranif0] = ACTIONS(5202),
    [anon_sym_tranif1] = ACTIONS(5202),
    [anon_sym_rtranif1] = ACTIONS(5202),
    [anon_sym_rtranif0] = ACTIONS(5202),
    [anon_sym_tran] = ACTIONS(5202),
    [anon_sym_rtran] = ACTIONS(5202),
    [anon_sym_generate] = ACTIONS(5202),
    [anon_sym_for] = ACTIONS(5202),
    [anon_sym_initial] = ACTIONS(5202),
    [anon_sym_assign] = ACTIONS(5202),
    [anon_sym_alias] = ACTIONS(5202),
    [anon_sym_always_comb] = ACTIONS(5202),
    [anon_sym_always_latch] = ACTIONS(5202),
    [anon_sym_always_ff] = ACTIONS(5202),
    [anon_sym_final] = ACTIONS(5202),
    [anon_sym_global] = ACTIONS(5202),
    [anon_sym_LPAREN_STAR] = ACTIONS(5200),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5200),
    [anon_sym_DOLLARunit] = ACTIONS(5200),
  },
  [4973] = {
    [sym_simple_identifier] = ACTIONS(5238),
    [anon_sym_wire] = ACTIONS(5238),
    [anon_sym_tri] = ACTIONS(5238),
    [anon_sym_tri0] = ACTIONS(5238),
    [anon_sym_tri1] = ACTIONS(5238),
    [anon_sym_wand] = ACTIONS(5238),
    [anon_sym_triand] = ACTIONS(5238),
    [anon_sym_wor] = ACTIONS(5238),
    [anon_sym_trior] = ACTIONS(5238),
    [anon_sym_trireg] = ACTIONS(5238),
    [anon_sym_uwire] = ACTIONS(5238),
    [anon_sym_SEMI] = ACTIONS(5236),
    [anon_sym_extern] = ACTIONS(5238),
    [anon_sym_interface] = ACTIONS(5238),
    [anon_sym_checker] = ACTIONS(5238),
    [anon_sym_virtual] = ACTIONS(5238),
    [anon_sym_class] = ACTIONS(5238),
    [anon_sym_type] = ACTIONS(5238),
    [anon_sym_DOLLARfatal] = ACTIONS(5236),
    [anon_sym_DOLLARerror] = ACTIONS(5236),
    [anon_sym_DOLLARwarning] = ACTIONS(5236),
    [anon_sym_DOLLARinfo] = ACTIONS(5236),
    [anon_sym_default] = ACTIONS(5238),
    [anon_sym_clocking] = ACTIONS(5238),
    [anon_sym_defparam] = ACTIONS(5238),
    [anon_sym_bind] = ACTIONS(5238),
    [anon_sym_rand] = ACTIONS(5238),
    [anon_sym_const] = ACTIONS(5238),
    [anon_sym_function] = ACTIONS(5238),
    [anon_sym_static] = ACTIONS(5238),
    [anon_sym_constraint] = ACTIONS(5238),
    [anon_sym_if] = ACTIONS(5238),
    [anon_sym_else] = ACTIONS(5238),
    [anon_sym_LBRACK] = ACTIONS(5236),
    [anon_sym_localparam] = ACTIONS(5238),
    [anon_sym_parameter] = ACTIONS(5238),
    [anon_sym_var] = ACTIONS(5238),
    [anon_sym_import] = ACTIONS(5238),
    [anon_sym_export] = ACTIONS(5238),
    [anon_sym_genvar] = ACTIONS(5238),
    [anon_sym_interconnect] = ACTIONS(5238),
    [anon_sym_typedef] = ACTIONS(5238),
    [anon_sym_enum] = ACTIONS(5238),
    [anon_sym_struct] = ACTIONS(5238),
    [anon_sym_union] = ACTIONS(5238),
    [anon_sym_nettype] = ACTIONS(5238),
    [anon_sym_automatic] = ACTIONS(5238),
    [anon_sym_string] = ACTIONS(5238),
    [anon_sym_chandle] = ACTIONS(5238),
    [anon_sym_event] = ACTIONS(5238),
    [anon_sym_byte] = ACTIONS(5238),
    [anon_sym_shortint] = ACTIONS(5238),
    [anon_sym_int] = ACTIONS(5238),
    [anon_sym_longint] = ACTIONS(5238),
    [anon_sym_integer] = ACTIONS(5238),
    [anon_sym_time] = ACTIONS(5238),
    [anon_sym_bit] = ACTIONS(5238),
    [anon_sym_logic] = ACTIONS(5238),
    [anon_sym_reg] = ACTIONS(5238),
    [anon_sym_shortreal] = ACTIONS(5238),
    [anon_sym_real] = ACTIONS(5238),
    [anon_sym_realtime] = ACTIONS(5238),
    [anon_sym_supply0] = ACTIONS(5238),
    [anon_sym_supply1] = ACTIONS(5238),
    [anon_sym_signed] = ACTIONS(5238),
    [anon_sym_unsigned] = ACTIONS(5238),
    [anon_sym_task] = ACTIONS(5238),
    [anon_sym_assert] = ACTIONS(5238),
    [anon_sym_property] = ACTIONS(5238),
    [anon_sym_assume] = ACTIONS(5238),
    [anon_sym_cover] = ACTIONS(5238),
    [anon_sym_sequence] = ACTIONS(5238),
    [anon_sym_restrict] = ACTIONS(5238),
    [anon_sym_not] = ACTIONS(5238),
    [anon_sym_or] = ACTIONS(5238),
    [anon_sym_and] = ACTIONS(5238),
    [anon_sym_case] = ACTIONS(5238),
    [anon_sym_always] = ACTIONS(5238),
    [anon_sym_covergroup] = ACTIONS(5238),
    [anon_sym_let] = ACTIONS(5238),
    [anon_sym_pulldown] = ACTIONS(5238),
    [anon_sym_pullup] = ACTIONS(5238),
    [anon_sym_cmos] = ACTIONS(5238),
    [anon_sym_rcmos] = ACTIONS(5238),
    [anon_sym_bufif0] = ACTIONS(5238),
    [anon_sym_bufif1] = ACTIONS(5238),
    [anon_sym_notif0] = ACTIONS(5238),
    [anon_sym_notif1] = ACTIONS(5238),
    [anon_sym_nmos] = ACTIONS(5238),
    [anon_sym_pmos] = ACTIONS(5238),
    [anon_sym_rnmos] = ACTIONS(5238),
    [anon_sym_rpmos] = ACTIONS(5238),
    [anon_sym_nand] = ACTIONS(5238),
    [anon_sym_nor] = ACTIONS(5238),
    [anon_sym_xor] = ACTIONS(5238),
    [anon_sym_xnor] = ACTIONS(5238),
    [anon_sym_buf] = ACTIONS(5238),
    [anon_sym_tranif0] = ACTIONS(5238),
    [anon_sym_tranif1] = ACTIONS(5238),
    [anon_sym_rtranif1] = ACTIONS(5238),
    [anon_sym_rtranif0] = ACTIONS(5238),
    [anon_sym_tran] = ACTIONS(5238),
    [anon_sym_rtran] = ACTIONS(5238),
    [anon_sym_generate] = ACTIONS(5238),
    [anon_sym_endgenerate] = ACTIONS(5238),
    [anon_sym_for] = ACTIONS(5238),
    [anon_sym_initial] = ACTIONS(5238),
    [anon_sym_assign] = ACTIONS(5238),
    [anon_sym_alias] = ACTIONS(5238),
    [anon_sym_always_comb] = ACTIONS(5238),
    [anon_sym_always_latch] = ACTIONS(5238),
    [anon_sym_always_ff] = ACTIONS(5238),
    [anon_sym_final] = ACTIONS(5238),
    [anon_sym_global] = ACTIONS(5238),
    [anon_sym_LPAREN_STAR] = ACTIONS(5236),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5236),
    [anon_sym_DOLLARunit] = ACTIONS(5236),
  },
  [4974] = {
    [sym_simple_identifier] = ACTIONS(4920),
    [anon_sym_wire] = ACTIONS(4920),
    [anon_sym_tri] = ACTIONS(4920),
    [anon_sym_tri0] = ACTIONS(4920),
    [anon_sym_tri1] = ACTIONS(4920),
    [anon_sym_wand] = ACTIONS(4920),
    [anon_sym_triand] = ACTIONS(4920),
    [anon_sym_wor] = ACTIONS(4920),
    [anon_sym_trior] = ACTIONS(4920),
    [anon_sym_trireg] = ACTIONS(4920),
    [anon_sym_uwire] = ACTIONS(4920),
    [anon_sym_SEMI] = ACTIONS(4918),
    [anon_sym_extern] = ACTIONS(4920),
    [anon_sym_interface] = ACTIONS(4920),
    [anon_sym_checker] = ACTIONS(4920),
    [anon_sym_virtual] = ACTIONS(4920),
    [anon_sym_class] = ACTIONS(4920),
    [anon_sym_type] = ACTIONS(4920),
    [anon_sym_DOLLARfatal] = ACTIONS(4918),
    [anon_sym_DOLLARerror] = ACTIONS(4918),
    [anon_sym_DOLLARwarning] = ACTIONS(4918),
    [anon_sym_DOLLARinfo] = ACTIONS(4918),
    [anon_sym_default] = ACTIONS(4920),
    [anon_sym_clocking] = ACTIONS(4920),
    [anon_sym_defparam] = ACTIONS(4920),
    [anon_sym_bind] = ACTIONS(4920),
    [anon_sym_rand] = ACTIONS(4920),
    [anon_sym_const] = ACTIONS(4920),
    [anon_sym_function] = ACTIONS(4920),
    [anon_sym_static] = ACTIONS(4920),
    [anon_sym_constraint] = ACTIONS(4920),
    [anon_sym_if] = ACTIONS(4920),
    [anon_sym_else] = ACTIONS(4920),
    [anon_sym_LBRACK] = ACTIONS(4918),
    [anon_sym_localparam] = ACTIONS(4920),
    [anon_sym_parameter] = ACTIONS(4920),
    [anon_sym_var] = ACTIONS(4920),
    [anon_sym_import] = ACTIONS(4920),
    [anon_sym_export] = ACTIONS(4920),
    [anon_sym_genvar] = ACTIONS(4920),
    [anon_sym_interconnect] = ACTIONS(4920),
    [anon_sym_typedef] = ACTIONS(4920),
    [anon_sym_enum] = ACTIONS(4920),
    [anon_sym_struct] = ACTIONS(4920),
    [anon_sym_union] = ACTIONS(4920),
    [anon_sym_nettype] = ACTIONS(4920),
    [anon_sym_automatic] = ACTIONS(4920),
    [anon_sym_string] = ACTIONS(4920),
    [anon_sym_chandle] = ACTIONS(4920),
    [anon_sym_event] = ACTIONS(4920),
    [anon_sym_byte] = ACTIONS(4920),
    [anon_sym_shortint] = ACTIONS(4920),
    [anon_sym_int] = ACTIONS(4920),
    [anon_sym_longint] = ACTIONS(4920),
    [anon_sym_integer] = ACTIONS(4920),
    [anon_sym_time] = ACTIONS(4920),
    [anon_sym_bit] = ACTIONS(4920),
    [anon_sym_logic] = ACTIONS(4920),
    [anon_sym_reg] = ACTIONS(4920),
    [anon_sym_shortreal] = ACTIONS(4920),
    [anon_sym_real] = ACTIONS(4920),
    [anon_sym_realtime] = ACTIONS(4920),
    [anon_sym_supply0] = ACTIONS(4920),
    [anon_sym_supply1] = ACTIONS(4920),
    [anon_sym_signed] = ACTIONS(4920),
    [anon_sym_unsigned] = ACTIONS(4920),
    [anon_sym_task] = ACTIONS(4920),
    [anon_sym_assert] = ACTIONS(4920),
    [anon_sym_property] = ACTIONS(4920),
    [anon_sym_assume] = ACTIONS(4920),
    [anon_sym_cover] = ACTIONS(4920),
    [anon_sym_sequence] = ACTIONS(4920),
    [anon_sym_restrict] = ACTIONS(4920),
    [anon_sym_not] = ACTIONS(4920),
    [anon_sym_or] = ACTIONS(4920),
    [anon_sym_and] = ACTIONS(4920),
    [anon_sym_case] = ACTIONS(4920),
    [anon_sym_always] = ACTIONS(4920),
    [anon_sym_covergroup] = ACTIONS(4920),
    [anon_sym_let] = ACTIONS(4920),
    [anon_sym_pulldown] = ACTIONS(4920),
    [anon_sym_pullup] = ACTIONS(4920),
    [anon_sym_cmos] = ACTIONS(4920),
    [anon_sym_rcmos] = ACTIONS(4920),
    [anon_sym_bufif0] = ACTIONS(4920),
    [anon_sym_bufif1] = ACTIONS(4920),
    [anon_sym_notif0] = ACTIONS(4920),
    [anon_sym_notif1] = ACTIONS(4920),
    [anon_sym_nmos] = ACTIONS(4920),
    [anon_sym_pmos] = ACTIONS(4920),
    [anon_sym_rnmos] = ACTIONS(4920),
    [anon_sym_rpmos] = ACTIONS(4920),
    [anon_sym_nand] = ACTIONS(4920),
    [anon_sym_nor] = ACTIONS(4920),
    [anon_sym_xor] = ACTIONS(4920),
    [anon_sym_xnor] = ACTIONS(4920),
    [anon_sym_buf] = ACTIONS(4920),
    [anon_sym_tranif0] = ACTIONS(4920),
    [anon_sym_tranif1] = ACTIONS(4920),
    [anon_sym_rtranif1] = ACTIONS(4920),
    [anon_sym_rtranif0] = ACTIONS(4920),
    [anon_sym_tran] = ACTIONS(4920),
    [anon_sym_rtran] = ACTIONS(4920),
    [anon_sym_generate] = ACTIONS(4920),
    [anon_sym_endgenerate] = ACTIONS(4920),
    [anon_sym_for] = ACTIONS(4920),
    [anon_sym_initial] = ACTIONS(4920),
    [anon_sym_assign] = ACTIONS(4920),
    [anon_sym_alias] = ACTIONS(4920),
    [anon_sym_always_comb] = ACTIONS(4920),
    [anon_sym_always_latch] = ACTIONS(4920),
    [anon_sym_always_ff] = ACTIONS(4920),
    [anon_sym_final] = ACTIONS(4920),
    [anon_sym_global] = ACTIONS(4920),
    [anon_sym_LPAREN_STAR] = ACTIONS(4918),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4918),
    [anon_sym_DOLLARunit] = ACTIONS(4918),
  },
  [4975] = {
    [sym_simple_identifier] = ACTIONS(6299),
    [anon_sym_wire] = ACTIONS(6299),
    [anon_sym_tri] = ACTIONS(6299),
    [anon_sym_tri0] = ACTIONS(6299),
    [anon_sym_tri1] = ACTIONS(6299),
    [anon_sym_wand] = ACTIONS(6299),
    [anon_sym_triand] = ACTIONS(6299),
    [anon_sym_wor] = ACTIONS(6299),
    [anon_sym_trior] = ACTIONS(6299),
    [anon_sym_trireg] = ACTIONS(6299),
    [anon_sym_uwire] = ACTIONS(6299),
    [anon_sym_SEMI] = ACTIONS(6301),
    [anon_sym_extern] = ACTIONS(6299),
    [anon_sym_interface] = ACTIONS(6299),
    [anon_sym_checker] = ACTIONS(6299),
    [anon_sym_virtual] = ACTIONS(6299),
    [anon_sym_class] = ACTIONS(6299),
    [anon_sym_type] = ACTIONS(6299),
    [anon_sym_DOLLARfatal] = ACTIONS(6301),
    [anon_sym_DOLLARerror] = ACTIONS(6301),
    [anon_sym_DOLLARwarning] = ACTIONS(6301),
    [anon_sym_DOLLARinfo] = ACTIONS(6301),
    [anon_sym_default] = ACTIONS(6299),
    [anon_sym_clocking] = ACTIONS(6299),
    [anon_sym_defparam] = ACTIONS(6299),
    [anon_sym_bind] = ACTIONS(6299),
    [anon_sym_rand] = ACTIONS(6299),
    [anon_sym_const] = ACTIONS(6299),
    [anon_sym_function] = ACTIONS(6299),
    [anon_sym_static] = ACTIONS(6299),
    [anon_sym_constraint] = ACTIONS(6299),
    [anon_sym_if] = ACTIONS(6299),
    [anon_sym_else] = ACTIONS(6299),
    [anon_sym_LBRACK] = ACTIONS(6301),
    [anon_sym_localparam] = ACTIONS(6299),
    [anon_sym_parameter] = ACTIONS(6299),
    [anon_sym_var] = ACTIONS(6299),
    [anon_sym_import] = ACTIONS(6299),
    [anon_sym_export] = ACTIONS(6299),
    [anon_sym_genvar] = ACTIONS(6299),
    [anon_sym_interconnect] = ACTIONS(6299),
    [anon_sym_typedef] = ACTIONS(6299),
    [anon_sym_enum] = ACTIONS(6299),
    [anon_sym_struct] = ACTIONS(6299),
    [anon_sym_union] = ACTIONS(6299),
    [anon_sym_nettype] = ACTIONS(6299),
    [anon_sym_automatic] = ACTIONS(6299),
    [anon_sym_string] = ACTIONS(6299),
    [anon_sym_chandle] = ACTIONS(6299),
    [anon_sym_event] = ACTIONS(6299),
    [anon_sym_byte] = ACTIONS(6299),
    [anon_sym_shortint] = ACTIONS(6299),
    [anon_sym_int] = ACTIONS(6299),
    [anon_sym_longint] = ACTIONS(6299),
    [anon_sym_integer] = ACTIONS(6299),
    [anon_sym_time] = ACTIONS(6299),
    [anon_sym_bit] = ACTIONS(6299),
    [anon_sym_logic] = ACTIONS(6299),
    [anon_sym_reg] = ACTIONS(6299),
    [anon_sym_shortreal] = ACTIONS(6299),
    [anon_sym_real] = ACTIONS(6299),
    [anon_sym_realtime] = ACTIONS(6299),
    [anon_sym_supply0] = ACTIONS(6299),
    [anon_sym_supply1] = ACTIONS(6299),
    [anon_sym_signed] = ACTIONS(6299),
    [anon_sym_unsigned] = ACTIONS(6299),
    [anon_sym_task] = ACTIONS(6299),
    [anon_sym_assert] = ACTIONS(6299),
    [anon_sym_property] = ACTIONS(6299),
    [anon_sym_assume] = ACTIONS(6299),
    [anon_sym_cover] = ACTIONS(6299),
    [anon_sym_sequence] = ACTIONS(6299),
    [anon_sym_restrict] = ACTIONS(6299),
    [anon_sym_not] = ACTIONS(6299),
    [anon_sym_or] = ACTIONS(6299),
    [anon_sym_and] = ACTIONS(6299),
    [anon_sym_case] = ACTIONS(6299),
    [anon_sym_always] = ACTIONS(6299),
    [anon_sym_covergroup] = ACTIONS(6299),
    [anon_sym_end] = ACTIONS(6299),
    [anon_sym_let] = ACTIONS(6299),
    [anon_sym_pulldown] = ACTIONS(6299),
    [anon_sym_pullup] = ACTIONS(6299),
    [anon_sym_cmos] = ACTIONS(6299),
    [anon_sym_rcmos] = ACTIONS(6299),
    [anon_sym_bufif0] = ACTIONS(6299),
    [anon_sym_bufif1] = ACTIONS(6299),
    [anon_sym_notif0] = ACTIONS(6299),
    [anon_sym_notif1] = ACTIONS(6299),
    [anon_sym_nmos] = ACTIONS(6299),
    [anon_sym_pmos] = ACTIONS(6299),
    [anon_sym_rnmos] = ACTIONS(6299),
    [anon_sym_rpmos] = ACTIONS(6299),
    [anon_sym_nand] = ACTIONS(6299),
    [anon_sym_nor] = ACTIONS(6299),
    [anon_sym_xor] = ACTIONS(6299),
    [anon_sym_xnor] = ACTIONS(6299),
    [anon_sym_buf] = ACTIONS(6299),
    [anon_sym_tranif0] = ACTIONS(6299),
    [anon_sym_tranif1] = ACTIONS(6299),
    [anon_sym_rtranif1] = ACTIONS(6299),
    [anon_sym_rtranif0] = ACTIONS(6299),
    [anon_sym_tran] = ACTIONS(6299),
    [anon_sym_rtran] = ACTIONS(6299),
    [anon_sym_generate] = ACTIONS(6299),
    [anon_sym_for] = ACTIONS(6299),
    [anon_sym_initial] = ACTIONS(6299),
    [anon_sym_assign] = ACTIONS(6299),
    [anon_sym_alias] = ACTIONS(6299),
    [anon_sym_always_comb] = ACTIONS(6299),
    [anon_sym_always_latch] = ACTIONS(6299),
    [anon_sym_always_ff] = ACTIONS(6299),
    [anon_sym_final] = ACTIONS(6299),
    [anon_sym_global] = ACTIONS(6299),
    [anon_sym_LPAREN_STAR] = ACTIONS(6301),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6301),
    [anon_sym_DOLLARunit] = ACTIONS(6301),
  },
  [4976] = {
    [sym_simple_identifier] = ACTIONS(4364),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_rand] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_endgenerate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [4977] = {
    [sym_simple_identifier] = ACTIONS(5254),
    [anon_sym_wire] = ACTIONS(5254),
    [anon_sym_tri] = ACTIONS(5254),
    [anon_sym_tri0] = ACTIONS(5254),
    [anon_sym_tri1] = ACTIONS(5254),
    [anon_sym_wand] = ACTIONS(5254),
    [anon_sym_triand] = ACTIONS(5254),
    [anon_sym_wor] = ACTIONS(5254),
    [anon_sym_trior] = ACTIONS(5254),
    [anon_sym_trireg] = ACTIONS(5254),
    [anon_sym_uwire] = ACTIONS(5254),
    [anon_sym_SEMI] = ACTIONS(5252),
    [anon_sym_extern] = ACTIONS(5254),
    [anon_sym_interface] = ACTIONS(5254),
    [anon_sym_checker] = ACTIONS(5254),
    [anon_sym_virtual] = ACTIONS(5254),
    [anon_sym_class] = ACTIONS(5254),
    [anon_sym_type] = ACTIONS(5254),
    [anon_sym_DOLLARfatal] = ACTIONS(5252),
    [anon_sym_DOLLARerror] = ACTIONS(5252),
    [anon_sym_DOLLARwarning] = ACTIONS(5252),
    [anon_sym_DOLLARinfo] = ACTIONS(5252),
    [anon_sym_default] = ACTIONS(5254),
    [anon_sym_clocking] = ACTIONS(5254),
    [anon_sym_defparam] = ACTIONS(5254),
    [anon_sym_bind] = ACTIONS(5254),
    [anon_sym_rand] = ACTIONS(5254),
    [anon_sym_const] = ACTIONS(5254),
    [anon_sym_function] = ACTIONS(5254),
    [anon_sym_static] = ACTIONS(5254),
    [anon_sym_constraint] = ACTIONS(5254),
    [anon_sym_if] = ACTIONS(5254),
    [anon_sym_else] = ACTIONS(5254),
    [anon_sym_LBRACK] = ACTIONS(5252),
    [anon_sym_localparam] = ACTIONS(5254),
    [anon_sym_parameter] = ACTIONS(5254),
    [anon_sym_var] = ACTIONS(5254),
    [anon_sym_import] = ACTIONS(5254),
    [anon_sym_export] = ACTIONS(5254),
    [anon_sym_genvar] = ACTIONS(5254),
    [anon_sym_interconnect] = ACTIONS(5254),
    [anon_sym_typedef] = ACTIONS(5254),
    [anon_sym_enum] = ACTIONS(5254),
    [anon_sym_struct] = ACTIONS(5254),
    [anon_sym_union] = ACTIONS(5254),
    [anon_sym_nettype] = ACTIONS(5254),
    [anon_sym_automatic] = ACTIONS(5254),
    [anon_sym_string] = ACTIONS(5254),
    [anon_sym_chandle] = ACTIONS(5254),
    [anon_sym_event] = ACTIONS(5254),
    [anon_sym_byte] = ACTIONS(5254),
    [anon_sym_shortint] = ACTIONS(5254),
    [anon_sym_int] = ACTIONS(5254),
    [anon_sym_longint] = ACTIONS(5254),
    [anon_sym_integer] = ACTIONS(5254),
    [anon_sym_time] = ACTIONS(5254),
    [anon_sym_bit] = ACTIONS(5254),
    [anon_sym_logic] = ACTIONS(5254),
    [anon_sym_reg] = ACTIONS(5254),
    [anon_sym_shortreal] = ACTIONS(5254),
    [anon_sym_real] = ACTIONS(5254),
    [anon_sym_realtime] = ACTIONS(5254),
    [anon_sym_supply0] = ACTIONS(5254),
    [anon_sym_supply1] = ACTIONS(5254),
    [anon_sym_signed] = ACTIONS(5254),
    [anon_sym_unsigned] = ACTIONS(5254),
    [anon_sym_task] = ACTIONS(5254),
    [anon_sym_assert] = ACTIONS(5254),
    [anon_sym_property] = ACTIONS(5254),
    [anon_sym_assume] = ACTIONS(5254),
    [anon_sym_cover] = ACTIONS(5254),
    [anon_sym_sequence] = ACTIONS(5254),
    [anon_sym_restrict] = ACTIONS(5254),
    [anon_sym_not] = ACTIONS(5254),
    [anon_sym_or] = ACTIONS(5254),
    [anon_sym_and] = ACTIONS(5254),
    [anon_sym_case] = ACTIONS(5254),
    [anon_sym_always] = ACTIONS(5254),
    [anon_sym_covergroup] = ACTIONS(5254),
    [anon_sym_end] = ACTIONS(5254),
    [anon_sym_let] = ACTIONS(5254),
    [anon_sym_pulldown] = ACTIONS(5254),
    [anon_sym_pullup] = ACTIONS(5254),
    [anon_sym_cmos] = ACTIONS(5254),
    [anon_sym_rcmos] = ACTIONS(5254),
    [anon_sym_bufif0] = ACTIONS(5254),
    [anon_sym_bufif1] = ACTIONS(5254),
    [anon_sym_notif0] = ACTIONS(5254),
    [anon_sym_notif1] = ACTIONS(5254),
    [anon_sym_nmos] = ACTIONS(5254),
    [anon_sym_pmos] = ACTIONS(5254),
    [anon_sym_rnmos] = ACTIONS(5254),
    [anon_sym_rpmos] = ACTIONS(5254),
    [anon_sym_nand] = ACTIONS(5254),
    [anon_sym_nor] = ACTIONS(5254),
    [anon_sym_xor] = ACTIONS(5254),
    [anon_sym_xnor] = ACTIONS(5254),
    [anon_sym_buf] = ACTIONS(5254),
    [anon_sym_tranif0] = ACTIONS(5254),
    [anon_sym_tranif1] = ACTIONS(5254),
    [anon_sym_rtranif1] = ACTIONS(5254),
    [anon_sym_rtranif0] = ACTIONS(5254),
    [anon_sym_tran] = ACTIONS(5254),
    [anon_sym_rtran] = ACTIONS(5254),
    [anon_sym_generate] = ACTIONS(5254),
    [anon_sym_for] = ACTIONS(5254),
    [anon_sym_initial] = ACTIONS(5254),
    [anon_sym_assign] = ACTIONS(5254),
    [anon_sym_alias] = ACTIONS(5254),
    [anon_sym_always_comb] = ACTIONS(5254),
    [anon_sym_always_latch] = ACTIONS(5254),
    [anon_sym_always_ff] = ACTIONS(5254),
    [anon_sym_final] = ACTIONS(5254),
    [anon_sym_global] = ACTIONS(5254),
    [anon_sym_LPAREN_STAR] = ACTIONS(5252),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5252),
    [anon_sym_DOLLARunit] = ACTIONS(5252),
  },
  [4978] = {
    [sym_simple_identifier] = ACTIONS(6641),
    [anon_sym_wire] = ACTIONS(6641),
    [anon_sym_tri] = ACTIONS(6641),
    [anon_sym_tri0] = ACTIONS(6641),
    [anon_sym_tri1] = ACTIONS(6641),
    [anon_sym_wand] = ACTIONS(6641),
    [anon_sym_triand] = ACTIONS(6641),
    [anon_sym_wor] = ACTIONS(6641),
    [anon_sym_trior] = ACTIONS(6641),
    [anon_sym_trireg] = ACTIONS(6641),
    [anon_sym_uwire] = ACTIONS(6641),
    [anon_sym_SEMI] = ACTIONS(6643),
    [anon_sym_extern] = ACTIONS(6641),
    [anon_sym_interface] = ACTIONS(6641),
    [anon_sym_checker] = ACTIONS(6641),
    [anon_sym_virtual] = ACTIONS(6641),
    [anon_sym_class] = ACTIONS(6641),
    [anon_sym_type] = ACTIONS(6641),
    [anon_sym_DOLLARfatal] = ACTIONS(6643),
    [anon_sym_DOLLARerror] = ACTIONS(6643),
    [anon_sym_DOLLARwarning] = ACTIONS(6643),
    [anon_sym_DOLLARinfo] = ACTIONS(6643),
    [anon_sym_default] = ACTIONS(6641),
    [anon_sym_clocking] = ACTIONS(6641),
    [anon_sym_defparam] = ACTIONS(6641),
    [anon_sym_bind] = ACTIONS(6641),
    [anon_sym_rand] = ACTIONS(6641),
    [anon_sym_const] = ACTIONS(6641),
    [anon_sym_function] = ACTIONS(6641),
    [anon_sym_static] = ACTIONS(6641),
    [anon_sym_constraint] = ACTIONS(6641),
    [anon_sym_if] = ACTIONS(6641),
    [anon_sym_else] = ACTIONS(6641),
    [anon_sym_LBRACK] = ACTIONS(6643),
    [anon_sym_localparam] = ACTIONS(6641),
    [anon_sym_parameter] = ACTIONS(6641),
    [anon_sym_var] = ACTIONS(6641),
    [anon_sym_import] = ACTIONS(6641),
    [anon_sym_export] = ACTIONS(6641),
    [anon_sym_genvar] = ACTIONS(6641),
    [anon_sym_interconnect] = ACTIONS(6641),
    [anon_sym_typedef] = ACTIONS(6641),
    [anon_sym_enum] = ACTIONS(6641),
    [anon_sym_struct] = ACTIONS(6641),
    [anon_sym_union] = ACTIONS(6641),
    [anon_sym_nettype] = ACTIONS(6641),
    [anon_sym_automatic] = ACTIONS(6641),
    [anon_sym_string] = ACTIONS(6641),
    [anon_sym_chandle] = ACTIONS(6641),
    [anon_sym_event] = ACTIONS(6641),
    [anon_sym_byte] = ACTIONS(6641),
    [anon_sym_shortint] = ACTIONS(6641),
    [anon_sym_int] = ACTIONS(6641),
    [anon_sym_longint] = ACTIONS(6641),
    [anon_sym_integer] = ACTIONS(6641),
    [anon_sym_time] = ACTIONS(6641),
    [anon_sym_bit] = ACTIONS(6641),
    [anon_sym_logic] = ACTIONS(6641),
    [anon_sym_reg] = ACTIONS(6641),
    [anon_sym_shortreal] = ACTIONS(6641),
    [anon_sym_real] = ACTIONS(6641),
    [anon_sym_realtime] = ACTIONS(6641),
    [anon_sym_supply0] = ACTIONS(6641),
    [anon_sym_supply1] = ACTIONS(6641),
    [anon_sym_signed] = ACTIONS(6641),
    [anon_sym_unsigned] = ACTIONS(6641),
    [anon_sym_task] = ACTIONS(6641),
    [anon_sym_assert] = ACTIONS(6641),
    [anon_sym_property] = ACTIONS(6641),
    [anon_sym_assume] = ACTIONS(6641),
    [anon_sym_cover] = ACTIONS(6641),
    [anon_sym_sequence] = ACTIONS(6641),
    [anon_sym_restrict] = ACTIONS(6641),
    [anon_sym_not] = ACTIONS(6641),
    [anon_sym_or] = ACTIONS(6641),
    [anon_sym_and] = ACTIONS(6641),
    [anon_sym_case] = ACTIONS(6641),
    [anon_sym_always] = ACTIONS(6641),
    [anon_sym_covergroup] = ACTIONS(6641),
    [anon_sym_end] = ACTIONS(6641),
    [anon_sym_let] = ACTIONS(6641),
    [anon_sym_pulldown] = ACTIONS(6641),
    [anon_sym_pullup] = ACTIONS(6641),
    [anon_sym_cmos] = ACTIONS(6641),
    [anon_sym_rcmos] = ACTIONS(6641),
    [anon_sym_bufif0] = ACTIONS(6641),
    [anon_sym_bufif1] = ACTIONS(6641),
    [anon_sym_notif0] = ACTIONS(6641),
    [anon_sym_notif1] = ACTIONS(6641),
    [anon_sym_nmos] = ACTIONS(6641),
    [anon_sym_pmos] = ACTIONS(6641),
    [anon_sym_rnmos] = ACTIONS(6641),
    [anon_sym_rpmos] = ACTIONS(6641),
    [anon_sym_nand] = ACTIONS(6641),
    [anon_sym_nor] = ACTIONS(6641),
    [anon_sym_xor] = ACTIONS(6641),
    [anon_sym_xnor] = ACTIONS(6641),
    [anon_sym_buf] = ACTIONS(6641),
    [anon_sym_tranif0] = ACTIONS(6641),
    [anon_sym_tranif1] = ACTIONS(6641),
    [anon_sym_rtranif1] = ACTIONS(6641),
    [anon_sym_rtranif0] = ACTIONS(6641),
    [anon_sym_tran] = ACTIONS(6641),
    [anon_sym_rtran] = ACTIONS(6641),
    [anon_sym_generate] = ACTIONS(6641),
    [anon_sym_for] = ACTIONS(6641),
    [anon_sym_initial] = ACTIONS(6641),
    [anon_sym_assign] = ACTIONS(6641),
    [anon_sym_alias] = ACTIONS(6641),
    [anon_sym_always_comb] = ACTIONS(6641),
    [anon_sym_always_latch] = ACTIONS(6641),
    [anon_sym_always_ff] = ACTIONS(6641),
    [anon_sym_final] = ACTIONS(6641),
    [anon_sym_global] = ACTIONS(6641),
    [anon_sym_LPAREN_STAR] = ACTIONS(6643),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6643),
    [anon_sym_DOLLARunit] = ACTIONS(6643),
  },
  [4979] = {
    [sym_simple_identifier] = ACTIONS(4536),
    [anon_sym_wire] = ACTIONS(4536),
    [anon_sym_tri] = ACTIONS(4536),
    [anon_sym_tri0] = ACTIONS(4536),
    [anon_sym_tri1] = ACTIONS(4536),
    [anon_sym_wand] = ACTIONS(4536),
    [anon_sym_triand] = ACTIONS(4536),
    [anon_sym_wor] = ACTIONS(4536),
    [anon_sym_trior] = ACTIONS(4536),
    [anon_sym_trireg] = ACTIONS(4536),
    [anon_sym_uwire] = ACTIONS(4536),
    [anon_sym_SEMI] = ACTIONS(4534),
    [anon_sym_extern] = ACTIONS(4536),
    [anon_sym_interface] = ACTIONS(4536),
    [anon_sym_checker] = ACTIONS(4536),
    [anon_sym_virtual] = ACTIONS(4536),
    [anon_sym_class] = ACTIONS(4536),
    [anon_sym_type] = ACTIONS(4536),
    [anon_sym_DOLLARfatal] = ACTIONS(4534),
    [anon_sym_DOLLARerror] = ACTIONS(4534),
    [anon_sym_DOLLARwarning] = ACTIONS(4534),
    [anon_sym_DOLLARinfo] = ACTIONS(4534),
    [anon_sym_default] = ACTIONS(4536),
    [anon_sym_clocking] = ACTIONS(4536),
    [anon_sym_defparam] = ACTIONS(4536),
    [anon_sym_bind] = ACTIONS(4536),
    [anon_sym_rand] = ACTIONS(4536),
    [anon_sym_const] = ACTIONS(4536),
    [anon_sym_function] = ACTIONS(4536),
    [anon_sym_static] = ACTIONS(4536),
    [anon_sym_constraint] = ACTIONS(4536),
    [anon_sym_if] = ACTIONS(4536),
    [anon_sym_else] = ACTIONS(4536),
    [anon_sym_LBRACK] = ACTIONS(4534),
    [anon_sym_localparam] = ACTIONS(4536),
    [anon_sym_parameter] = ACTIONS(4536),
    [anon_sym_var] = ACTIONS(4536),
    [anon_sym_import] = ACTIONS(4536),
    [anon_sym_export] = ACTIONS(4536),
    [anon_sym_genvar] = ACTIONS(4536),
    [anon_sym_interconnect] = ACTIONS(4536),
    [anon_sym_typedef] = ACTIONS(4536),
    [anon_sym_enum] = ACTIONS(4536),
    [anon_sym_struct] = ACTIONS(4536),
    [anon_sym_union] = ACTIONS(4536),
    [anon_sym_nettype] = ACTIONS(4536),
    [anon_sym_automatic] = ACTIONS(4536),
    [anon_sym_string] = ACTIONS(4536),
    [anon_sym_chandle] = ACTIONS(4536),
    [anon_sym_event] = ACTIONS(4536),
    [anon_sym_byte] = ACTIONS(4536),
    [anon_sym_shortint] = ACTIONS(4536),
    [anon_sym_int] = ACTIONS(4536),
    [anon_sym_longint] = ACTIONS(4536),
    [anon_sym_integer] = ACTIONS(4536),
    [anon_sym_time] = ACTIONS(4536),
    [anon_sym_bit] = ACTIONS(4536),
    [anon_sym_logic] = ACTIONS(4536),
    [anon_sym_reg] = ACTIONS(4536),
    [anon_sym_shortreal] = ACTIONS(4536),
    [anon_sym_real] = ACTIONS(4536),
    [anon_sym_realtime] = ACTIONS(4536),
    [anon_sym_supply0] = ACTIONS(4536),
    [anon_sym_supply1] = ACTIONS(4536),
    [anon_sym_signed] = ACTIONS(4536),
    [anon_sym_unsigned] = ACTIONS(4536),
    [anon_sym_task] = ACTIONS(4536),
    [anon_sym_assert] = ACTIONS(4536),
    [anon_sym_property] = ACTIONS(4536),
    [anon_sym_assume] = ACTIONS(4536),
    [anon_sym_cover] = ACTIONS(4536),
    [anon_sym_sequence] = ACTIONS(4536),
    [anon_sym_restrict] = ACTIONS(4536),
    [anon_sym_not] = ACTIONS(4536),
    [anon_sym_or] = ACTIONS(4536),
    [anon_sym_and] = ACTIONS(4536),
    [anon_sym_case] = ACTIONS(4536),
    [anon_sym_always] = ACTIONS(4536),
    [anon_sym_covergroup] = ACTIONS(4536),
    [anon_sym_let] = ACTIONS(4536),
    [anon_sym_pulldown] = ACTIONS(4536),
    [anon_sym_pullup] = ACTIONS(4536),
    [anon_sym_cmos] = ACTIONS(4536),
    [anon_sym_rcmos] = ACTIONS(4536),
    [anon_sym_bufif0] = ACTIONS(4536),
    [anon_sym_bufif1] = ACTIONS(4536),
    [anon_sym_notif0] = ACTIONS(4536),
    [anon_sym_notif1] = ACTIONS(4536),
    [anon_sym_nmos] = ACTIONS(4536),
    [anon_sym_pmos] = ACTIONS(4536),
    [anon_sym_rnmos] = ACTIONS(4536),
    [anon_sym_rpmos] = ACTIONS(4536),
    [anon_sym_nand] = ACTIONS(4536),
    [anon_sym_nor] = ACTIONS(4536),
    [anon_sym_xor] = ACTIONS(4536),
    [anon_sym_xnor] = ACTIONS(4536),
    [anon_sym_buf] = ACTIONS(4536),
    [anon_sym_tranif0] = ACTIONS(4536),
    [anon_sym_tranif1] = ACTIONS(4536),
    [anon_sym_rtranif1] = ACTIONS(4536),
    [anon_sym_rtranif0] = ACTIONS(4536),
    [anon_sym_tran] = ACTIONS(4536),
    [anon_sym_rtran] = ACTIONS(4536),
    [anon_sym_generate] = ACTIONS(4536),
    [anon_sym_endgenerate] = ACTIONS(4536),
    [anon_sym_for] = ACTIONS(4536),
    [anon_sym_initial] = ACTIONS(4536),
    [anon_sym_assign] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4536),
    [anon_sym_always_comb] = ACTIONS(4536),
    [anon_sym_always_latch] = ACTIONS(4536),
    [anon_sym_always_ff] = ACTIONS(4536),
    [anon_sym_final] = ACTIONS(4536),
    [anon_sym_global] = ACTIONS(4536),
    [anon_sym_LPAREN_STAR] = ACTIONS(4534),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4534),
    [anon_sym_DOLLARunit] = ACTIONS(4534),
  },
  [4980] = {
    [sym_simple_identifier] = ACTIONS(4484),
    [anon_sym_wire] = ACTIONS(4484),
    [anon_sym_tri] = ACTIONS(4484),
    [anon_sym_tri0] = ACTIONS(4484),
    [anon_sym_tri1] = ACTIONS(4484),
    [anon_sym_wand] = ACTIONS(4484),
    [anon_sym_triand] = ACTIONS(4484),
    [anon_sym_wor] = ACTIONS(4484),
    [anon_sym_trior] = ACTIONS(4484),
    [anon_sym_trireg] = ACTIONS(4484),
    [anon_sym_uwire] = ACTIONS(4484),
    [anon_sym_SEMI] = ACTIONS(4482),
    [anon_sym_extern] = ACTIONS(4484),
    [anon_sym_interface] = ACTIONS(4484),
    [anon_sym_checker] = ACTIONS(4484),
    [anon_sym_virtual] = ACTIONS(4484),
    [anon_sym_class] = ACTIONS(4484),
    [anon_sym_type] = ACTIONS(4484),
    [anon_sym_DOLLARfatal] = ACTIONS(4482),
    [anon_sym_DOLLARerror] = ACTIONS(4482),
    [anon_sym_DOLLARwarning] = ACTIONS(4482),
    [anon_sym_DOLLARinfo] = ACTIONS(4482),
    [anon_sym_default] = ACTIONS(4484),
    [anon_sym_clocking] = ACTIONS(4484),
    [anon_sym_defparam] = ACTIONS(4484),
    [anon_sym_bind] = ACTIONS(4484),
    [anon_sym_rand] = ACTIONS(4484),
    [anon_sym_const] = ACTIONS(4484),
    [anon_sym_function] = ACTIONS(4484),
    [anon_sym_static] = ACTIONS(4484),
    [anon_sym_constraint] = ACTIONS(4484),
    [anon_sym_if] = ACTIONS(4484),
    [anon_sym_else] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4482),
    [anon_sym_localparam] = ACTIONS(4484),
    [anon_sym_parameter] = ACTIONS(4484),
    [anon_sym_var] = ACTIONS(4484),
    [anon_sym_import] = ACTIONS(4484),
    [anon_sym_export] = ACTIONS(4484),
    [anon_sym_genvar] = ACTIONS(4484),
    [anon_sym_interconnect] = ACTIONS(4484),
    [anon_sym_typedef] = ACTIONS(4484),
    [anon_sym_enum] = ACTIONS(4484),
    [anon_sym_struct] = ACTIONS(4484),
    [anon_sym_union] = ACTIONS(4484),
    [anon_sym_nettype] = ACTIONS(4484),
    [anon_sym_automatic] = ACTIONS(4484),
    [anon_sym_string] = ACTIONS(4484),
    [anon_sym_chandle] = ACTIONS(4484),
    [anon_sym_event] = ACTIONS(4484),
    [anon_sym_byte] = ACTIONS(4484),
    [anon_sym_shortint] = ACTIONS(4484),
    [anon_sym_int] = ACTIONS(4484),
    [anon_sym_longint] = ACTIONS(4484),
    [anon_sym_integer] = ACTIONS(4484),
    [anon_sym_time] = ACTIONS(4484),
    [anon_sym_bit] = ACTIONS(4484),
    [anon_sym_logic] = ACTIONS(4484),
    [anon_sym_reg] = ACTIONS(4484),
    [anon_sym_shortreal] = ACTIONS(4484),
    [anon_sym_real] = ACTIONS(4484),
    [anon_sym_realtime] = ACTIONS(4484),
    [anon_sym_supply0] = ACTIONS(4484),
    [anon_sym_supply1] = ACTIONS(4484),
    [anon_sym_signed] = ACTIONS(4484),
    [anon_sym_unsigned] = ACTIONS(4484),
    [anon_sym_task] = ACTIONS(4484),
    [anon_sym_assert] = ACTIONS(4484),
    [anon_sym_property] = ACTIONS(4484),
    [anon_sym_assume] = ACTIONS(4484),
    [anon_sym_cover] = ACTIONS(4484),
    [anon_sym_sequence] = ACTIONS(4484),
    [anon_sym_restrict] = ACTIONS(4484),
    [anon_sym_not] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_case] = ACTIONS(4484),
    [anon_sym_always] = ACTIONS(4484),
    [anon_sym_covergroup] = ACTIONS(4484),
    [anon_sym_let] = ACTIONS(4484),
    [anon_sym_pulldown] = ACTIONS(4484),
    [anon_sym_pullup] = ACTIONS(4484),
    [anon_sym_cmos] = ACTIONS(4484),
    [anon_sym_rcmos] = ACTIONS(4484),
    [anon_sym_bufif0] = ACTIONS(4484),
    [anon_sym_bufif1] = ACTIONS(4484),
    [anon_sym_notif0] = ACTIONS(4484),
    [anon_sym_notif1] = ACTIONS(4484),
    [anon_sym_nmos] = ACTIONS(4484),
    [anon_sym_pmos] = ACTIONS(4484),
    [anon_sym_rnmos] = ACTIONS(4484),
    [anon_sym_rpmos] = ACTIONS(4484),
    [anon_sym_nand] = ACTIONS(4484),
    [anon_sym_nor] = ACTIONS(4484),
    [anon_sym_xor] = ACTIONS(4484),
    [anon_sym_xnor] = ACTIONS(4484),
    [anon_sym_buf] = ACTIONS(4484),
    [anon_sym_tranif0] = ACTIONS(4484),
    [anon_sym_tranif1] = ACTIONS(4484),
    [anon_sym_rtranif1] = ACTIONS(4484),
    [anon_sym_rtranif0] = ACTIONS(4484),
    [anon_sym_tran] = ACTIONS(4484),
    [anon_sym_rtran] = ACTIONS(4484),
    [anon_sym_generate] = ACTIONS(4484),
    [anon_sym_endgenerate] = ACTIONS(4484),
    [anon_sym_for] = ACTIONS(4484),
    [anon_sym_initial] = ACTIONS(4484),
    [anon_sym_assign] = ACTIONS(4484),
    [anon_sym_alias] = ACTIONS(4484),
    [anon_sym_always_comb] = ACTIONS(4484),
    [anon_sym_always_latch] = ACTIONS(4484),
    [anon_sym_always_ff] = ACTIONS(4484),
    [anon_sym_final] = ACTIONS(4484),
    [anon_sym_global] = ACTIONS(4484),
    [anon_sym_LPAREN_STAR] = ACTIONS(4482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4482),
    [anon_sym_DOLLARunit] = ACTIONS(4482),
  },
  [4981] = {
    [sym_simple_identifier] = ACTIONS(5704),
    [anon_sym_wire] = ACTIONS(5704),
    [anon_sym_tri] = ACTIONS(5704),
    [anon_sym_tri0] = ACTIONS(5704),
    [anon_sym_tri1] = ACTIONS(5704),
    [anon_sym_wand] = ACTIONS(5704),
    [anon_sym_triand] = ACTIONS(5704),
    [anon_sym_wor] = ACTIONS(5704),
    [anon_sym_trior] = ACTIONS(5704),
    [anon_sym_trireg] = ACTIONS(5704),
    [anon_sym_uwire] = ACTIONS(5704),
    [anon_sym_SEMI] = ACTIONS(5706),
    [anon_sym_extern] = ACTIONS(5704),
    [anon_sym_interface] = ACTIONS(5704),
    [anon_sym_checker] = ACTIONS(5704),
    [anon_sym_virtual] = ACTIONS(5704),
    [anon_sym_class] = ACTIONS(5704),
    [anon_sym_type] = ACTIONS(5704),
    [anon_sym_DOLLARfatal] = ACTIONS(5706),
    [anon_sym_DOLLARerror] = ACTIONS(5706),
    [anon_sym_DOLLARwarning] = ACTIONS(5706),
    [anon_sym_DOLLARinfo] = ACTIONS(5706),
    [anon_sym_default] = ACTIONS(5704),
    [anon_sym_clocking] = ACTIONS(5704),
    [anon_sym_defparam] = ACTIONS(5704),
    [anon_sym_bind] = ACTIONS(5704),
    [anon_sym_rand] = ACTIONS(5704),
    [anon_sym_const] = ACTIONS(5704),
    [anon_sym_function] = ACTIONS(5704),
    [anon_sym_static] = ACTIONS(5704),
    [anon_sym_constraint] = ACTIONS(5704),
    [anon_sym_if] = ACTIONS(5704),
    [anon_sym_else] = ACTIONS(5704),
    [anon_sym_LBRACK] = ACTIONS(5706),
    [anon_sym_localparam] = ACTIONS(5704),
    [anon_sym_parameter] = ACTIONS(5704),
    [anon_sym_var] = ACTIONS(5704),
    [anon_sym_import] = ACTIONS(5704),
    [anon_sym_export] = ACTIONS(5704),
    [anon_sym_genvar] = ACTIONS(5704),
    [anon_sym_interconnect] = ACTIONS(5704),
    [anon_sym_typedef] = ACTIONS(5704),
    [anon_sym_enum] = ACTIONS(5704),
    [anon_sym_struct] = ACTIONS(5704),
    [anon_sym_union] = ACTIONS(5704),
    [anon_sym_nettype] = ACTIONS(5704),
    [anon_sym_automatic] = ACTIONS(5704),
    [anon_sym_string] = ACTIONS(5704),
    [anon_sym_chandle] = ACTIONS(5704),
    [anon_sym_event] = ACTIONS(5704),
    [anon_sym_byte] = ACTIONS(5704),
    [anon_sym_shortint] = ACTIONS(5704),
    [anon_sym_int] = ACTIONS(5704),
    [anon_sym_longint] = ACTIONS(5704),
    [anon_sym_integer] = ACTIONS(5704),
    [anon_sym_time] = ACTIONS(5704),
    [anon_sym_bit] = ACTIONS(5704),
    [anon_sym_logic] = ACTIONS(5704),
    [anon_sym_reg] = ACTIONS(5704),
    [anon_sym_shortreal] = ACTIONS(5704),
    [anon_sym_real] = ACTIONS(5704),
    [anon_sym_realtime] = ACTIONS(5704),
    [anon_sym_supply0] = ACTIONS(5704),
    [anon_sym_supply1] = ACTIONS(5704),
    [anon_sym_signed] = ACTIONS(5704),
    [anon_sym_unsigned] = ACTIONS(5704),
    [anon_sym_task] = ACTIONS(5704),
    [anon_sym_assert] = ACTIONS(5704),
    [anon_sym_property] = ACTIONS(5704),
    [anon_sym_assume] = ACTIONS(5704),
    [anon_sym_cover] = ACTIONS(5704),
    [anon_sym_sequence] = ACTIONS(5704),
    [anon_sym_restrict] = ACTIONS(5704),
    [anon_sym_not] = ACTIONS(5704),
    [anon_sym_or] = ACTIONS(5704),
    [anon_sym_and] = ACTIONS(5704),
    [anon_sym_case] = ACTIONS(5704),
    [anon_sym_always] = ACTIONS(5704),
    [anon_sym_covergroup] = ACTIONS(5704),
    [anon_sym_end] = ACTIONS(5704),
    [anon_sym_let] = ACTIONS(5704),
    [anon_sym_pulldown] = ACTIONS(5704),
    [anon_sym_pullup] = ACTIONS(5704),
    [anon_sym_cmos] = ACTIONS(5704),
    [anon_sym_rcmos] = ACTIONS(5704),
    [anon_sym_bufif0] = ACTIONS(5704),
    [anon_sym_bufif1] = ACTIONS(5704),
    [anon_sym_notif0] = ACTIONS(5704),
    [anon_sym_notif1] = ACTIONS(5704),
    [anon_sym_nmos] = ACTIONS(5704),
    [anon_sym_pmos] = ACTIONS(5704),
    [anon_sym_rnmos] = ACTIONS(5704),
    [anon_sym_rpmos] = ACTIONS(5704),
    [anon_sym_nand] = ACTIONS(5704),
    [anon_sym_nor] = ACTIONS(5704),
    [anon_sym_xor] = ACTIONS(5704),
    [anon_sym_xnor] = ACTIONS(5704),
    [anon_sym_buf] = ACTIONS(5704),
    [anon_sym_tranif0] = ACTIONS(5704),
    [anon_sym_tranif1] = ACTIONS(5704),
    [anon_sym_rtranif1] = ACTIONS(5704),
    [anon_sym_rtranif0] = ACTIONS(5704),
    [anon_sym_tran] = ACTIONS(5704),
    [anon_sym_rtran] = ACTIONS(5704),
    [anon_sym_generate] = ACTIONS(5704),
    [anon_sym_for] = ACTIONS(5704),
    [anon_sym_initial] = ACTIONS(5704),
    [anon_sym_assign] = ACTIONS(5704),
    [anon_sym_alias] = ACTIONS(5704),
    [anon_sym_always_comb] = ACTIONS(5704),
    [anon_sym_always_latch] = ACTIONS(5704),
    [anon_sym_always_ff] = ACTIONS(5704),
    [anon_sym_final] = ACTIONS(5704),
    [anon_sym_global] = ACTIONS(5704),
    [anon_sym_LPAREN_STAR] = ACTIONS(5706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5706),
    [anon_sym_DOLLARunit] = ACTIONS(5706),
  },
  [4982] = {
    [sym_simple_identifier] = ACTIONS(6307),
    [anon_sym_wire] = ACTIONS(6307),
    [anon_sym_tri] = ACTIONS(6307),
    [anon_sym_tri0] = ACTIONS(6307),
    [anon_sym_tri1] = ACTIONS(6307),
    [anon_sym_wand] = ACTIONS(6307),
    [anon_sym_triand] = ACTIONS(6307),
    [anon_sym_wor] = ACTIONS(6307),
    [anon_sym_trior] = ACTIONS(6307),
    [anon_sym_trireg] = ACTIONS(6307),
    [anon_sym_uwire] = ACTIONS(6307),
    [anon_sym_SEMI] = ACTIONS(6309),
    [anon_sym_extern] = ACTIONS(6307),
    [anon_sym_interface] = ACTIONS(6307),
    [anon_sym_checker] = ACTIONS(6307),
    [anon_sym_virtual] = ACTIONS(6307),
    [anon_sym_class] = ACTIONS(6307),
    [anon_sym_type] = ACTIONS(6307),
    [anon_sym_DOLLARfatal] = ACTIONS(6309),
    [anon_sym_DOLLARerror] = ACTIONS(6309),
    [anon_sym_DOLLARwarning] = ACTIONS(6309),
    [anon_sym_DOLLARinfo] = ACTIONS(6309),
    [anon_sym_default] = ACTIONS(6307),
    [anon_sym_clocking] = ACTIONS(6307),
    [anon_sym_defparam] = ACTIONS(6307),
    [anon_sym_bind] = ACTIONS(6307),
    [anon_sym_rand] = ACTIONS(6307),
    [anon_sym_const] = ACTIONS(6307),
    [anon_sym_function] = ACTIONS(6307),
    [anon_sym_static] = ACTIONS(6307),
    [anon_sym_constraint] = ACTIONS(6307),
    [anon_sym_if] = ACTIONS(6307),
    [anon_sym_else] = ACTIONS(6307),
    [anon_sym_LBRACK] = ACTIONS(6309),
    [anon_sym_localparam] = ACTIONS(6307),
    [anon_sym_parameter] = ACTIONS(6307),
    [anon_sym_var] = ACTIONS(6307),
    [anon_sym_import] = ACTIONS(6307),
    [anon_sym_export] = ACTIONS(6307),
    [anon_sym_genvar] = ACTIONS(6307),
    [anon_sym_interconnect] = ACTIONS(6307),
    [anon_sym_typedef] = ACTIONS(6307),
    [anon_sym_enum] = ACTIONS(6307),
    [anon_sym_struct] = ACTIONS(6307),
    [anon_sym_union] = ACTIONS(6307),
    [anon_sym_nettype] = ACTIONS(6307),
    [anon_sym_automatic] = ACTIONS(6307),
    [anon_sym_string] = ACTIONS(6307),
    [anon_sym_chandle] = ACTIONS(6307),
    [anon_sym_event] = ACTIONS(6307),
    [anon_sym_byte] = ACTIONS(6307),
    [anon_sym_shortint] = ACTIONS(6307),
    [anon_sym_int] = ACTIONS(6307),
    [anon_sym_longint] = ACTIONS(6307),
    [anon_sym_integer] = ACTIONS(6307),
    [anon_sym_time] = ACTIONS(6307),
    [anon_sym_bit] = ACTIONS(6307),
    [anon_sym_logic] = ACTIONS(6307),
    [anon_sym_reg] = ACTIONS(6307),
    [anon_sym_shortreal] = ACTIONS(6307),
    [anon_sym_real] = ACTIONS(6307),
    [anon_sym_realtime] = ACTIONS(6307),
    [anon_sym_supply0] = ACTIONS(6307),
    [anon_sym_supply1] = ACTIONS(6307),
    [anon_sym_signed] = ACTIONS(6307),
    [anon_sym_unsigned] = ACTIONS(6307),
    [anon_sym_task] = ACTIONS(6307),
    [anon_sym_assert] = ACTIONS(6307),
    [anon_sym_property] = ACTIONS(6307),
    [anon_sym_assume] = ACTIONS(6307),
    [anon_sym_cover] = ACTIONS(6307),
    [anon_sym_sequence] = ACTIONS(6307),
    [anon_sym_restrict] = ACTIONS(6307),
    [anon_sym_not] = ACTIONS(6307),
    [anon_sym_or] = ACTIONS(6307),
    [anon_sym_and] = ACTIONS(6307),
    [anon_sym_case] = ACTIONS(6307),
    [anon_sym_always] = ACTIONS(6307),
    [anon_sym_covergroup] = ACTIONS(6307),
    [anon_sym_end] = ACTIONS(6307),
    [anon_sym_let] = ACTIONS(6307),
    [anon_sym_pulldown] = ACTIONS(6307),
    [anon_sym_pullup] = ACTIONS(6307),
    [anon_sym_cmos] = ACTIONS(6307),
    [anon_sym_rcmos] = ACTIONS(6307),
    [anon_sym_bufif0] = ACTIONS(6307),
    [anon_sym_bufif1] = ACTIONS(6307),
    [anon_sym_notif0] = ACTIONS(6307),
    [anon_sym_notif1] = ACTIONS(6307),
    [anon_sym_nmos] = ACTIONS(6307),
    [anon_sym_pmos] = ACTIONS(6307),
    [anon_sym_rnmos] = ACTIONS(6307),
    [anon_sym_rpmos] = ACTIONS(6307),
    [anon_sym_nand] = ACTIONS(6307),
    [anon_sym_nor] = ACTIONS(6307),
    [anon_sym_xor] = ACTIONS(6307),
    [anon_sym_xnor] = ACTIONS(6307),
    [anon_sym_buf] = ACTIONS(6307),
    [anon_sym_tranif0] = ACTIONS(6307),
    [anon_sym_tranif1] = ACTIONS(6307),
    [anon_sym_rtranif1] = ACTIONS(6307),
    [anon_sym_rtranif0] = ACTIONS(6307),
    [anon_sym_tran] = ACTIONS(6307),
    [anon_sym_rtran] = ACTIONS(6307),
    [anon_sym_generate] = ACTIONS(6307),
    [anon_sym_for] = ACTIONS(6307),
    [anon_sym_initial] = ACTIONS(6307),
    [anon_sym_assign] = ACTIONS(6307),
    [anon_sym_alias] = ACTIONS(6307),
    [anon_sym_always_comb] = ACTIONS(6307),
    [anon_sym_always_latch] = ACTIONS(6307),
    [anon_sym_always_ff] = ACTIONS(6307),
    [anon_sym_final] = ACTIONS(6307),
    [anon_sym_global] = ACTIONS(6307),
    [anon_sym_LPAREN_STAR] = ACTIONS(6309),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6309),
    [anon_sym_DOLLARunit] = ACTIONS(6309),
  },
  [4983] = {
    [sym_simple_identifier] = ACTIONS(4560),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_rand] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_endgenerate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [4984] = {
    [sym_simple_identifier] = ACTIONS(4674),
    [anon_sym_wire] = ACTIONS(4674),
    [anon_sym_tri] = ACTIONS(4674),
    [anon_sym_tri0] = ACTIONS(4674),
    [anon_sym_tri1] = ACTIONS(4674),
    [anon_sym_wand] = ACTIONS(4674),
    [anon_sym_triand] = ACTIONS(4674),
    [anon_sym_wor] = ACTIONS(4674),
    [anon_sym_trior] = ACTIONS(4674),
    [anon_sym_trireg] = ACTIONS(4674),
    [anon_sym_uwire] = ACTIONS(4674),
    [anon_sym_SEMI] = ACTIONS(4672),
    [anon_sym_extern] = ACTIONS(4674),
    [anon_sym_interface] = ACTIONS(4674),
    [anon_sym_checker] = ACTIONS(4674),
    [anon_sym_virtual] = ACTIONS(4674),
    [anon_sym_class] = ACTIONS(4674),
    [anon_sym_type] = ACTIONS(4674),
    [anon_sym_DOLLARfatal] = ACTIONS(4672),
    [anon_sym_DOLLARerror] = ACTIONS(4672),
    [anon_sym_DOLLARwarning] = ACTIONS(4672),
    [anon_sym_DOLLARinfo] = ACTIONS(4672),
    [anon_sym_default] = ACTIONS(4674),
    [anon_sym_clocking] = ACTIONS(4674),
    [anon_sym_defparam] = ACTIONS(4674),
    [anon_sym_bind] = ACTIONS(4674),
    [anon_sym_rand] = ACTIONS(4674),
    [anon_sym_const] = ACTIONS(4674),
    [anon_sym_function] = ACTIONS(4674),
    [anon_sym_static] = ACTIONS(4674),
    [anon_sym_constraint] = ACTIONS(4674),
    [anon_sym_if] = ACTIONS(4674),
    [anon_sym_else] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4672),
    [anon_sym_localparam] = ACTIONS(4674),
    [anon_sym_parameter] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_import] = ACTIONS(4674),
    [anon_sym_export] = ACTIONS(4674),
    [anon_sym_genvar] = ACTIONS(4674),
    [anon_sym_interconnect] = ACTIONS(4674),
    [anon_sym_typedef] = ACTIONS(4674),
    [anon_sym_enum] = ACTIONS(4674),
    [anon_sym_struct] = ACTIONS(4674),
    [anon_sym_union] = ACTIONS(4674),
    [anon_sym_nettype] = ACTIONS(4674),
    [anon_sym_automatic] = ACTIONS(4674),
    [anon_sym_string] = ACTIONS(4674),
    [anon_sym_chandle] = ACTIONS(4674),
    [anon_sym_event] = ACTIONS(4674),
    [anon_sym_byte] = ACTIONS(4674),
    [anon_sym_shortint] = ACTIONS(4674),
    [anon_sym_int] = ACTIONS(4674),
    [anon_sym_longint] = ACTIONS(4674),
    [anon_sym_integer] = ACTIONS(4674),
    [anon_sym_time] = ACTIONS(4674),
    [anon_sym_bit] = ACTIONS(4674),
    [anon_sym_logic] = ACTIONS(4674),
    [anon_sym_reg] = ACTIONS(4674),
    [anon_sym_shortreal] = ACTIONS(4674),
    [anon_sym_real] = ACTIONS(4674),
    [anon_sym_realtime] = ACTIONS(4674),
    [anon_sym_supply0] = ACTIONS(4674),
    [anon_sym_supply1] = ACTIONS(4674),
    [anon_sym_signed] = ACTIONS(4674),
    [anon_sym_unsigned] = ACTIONS(4674),
    [anon_sym_task] = ACTIONS(4674),
    [anon_sym_assert] = ACTIONS(4674),
    [anon_sym_property] = ACTIONS(4674),
    [anon_sym_assume] = ACTIONS(4674),
    [anon_sym_cover] = ACTIONS(4674),
    [anon_sym_sequence] = ACTIONS(4674),
    [anon_sym_restrict] = ACTIONS(4674),
    [anon_sym_not] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_case] = ACTIONS(4674),
    [anon_sym_always] = ACTIONS(4674),
    [anon_sym_covergroup] = ACTIONS(4674),
    [anon_sym_end] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_pulldown] = ACTIONS(4674),
    [anon_sym_pullup] = ACTIONS(4674),
    [anon_sym_cmos] = ACTIONS(4674),
    [anon_sym_rcmos] = ACTIONS(4674),
    [anon_sym_bufif0] = ACTIONS(4674),
    [anon_sym_bufif1] = ACTIONS(4674),
    [anon_sym_notif0] = ACTIONS(4674),
    [anon_sym_notif1] = ACTIONS(4674),
    [anon_sym_nmos] = ACTIONS(4674),
    [anon_sym_pmos] = ACTIONS(4674),
    [anon_sym_rnmos] = ACTIONS(4674),
    [anon_sym_rpmos] = ACTIONS(4674),
    [anon_sym_nand] = ACTIONS(4674),
    [anon_sym_nor] = ACTIONS(4674),
    [anon_sym_xor] = ACTIONS(4674),
    [anon_sym_xnor] = ACTIONS(4674),
    [anon_sym_buf] = ACTIONS(4674),
    [anon_sym_tranif0] = ACTIONS(4674),
    [anon_sym_tranif1] = ACTIONS(4674),
    [anon_sym_rtranif1] = ACTIONS(4674),
    [anon_sym_rtranif0] = ACTIONS(4674),
    [anon_sym_tran] = ACTIONS(4674),
    [anon_sym_rtran] = ACTIONS(4674),
    [anon_sym_generate] = ACTIONS(4674),
    [anon_sym_for] = ACTIONS(4674),
    [anon_sym_initial] = ACTIONS(4674),
    [anon_sym_assign] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_always_comb] = ACTIONS(4674),
    [anon_sym_always_latch] = ACTIONS(4674),
    [anon_sym_always_ff] = ACTIONS(4674),
    [anon_sym_final] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LPAREN_STAR] = ACTIONS(4672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4672),
    [anon_sym_DOLLARunit] = ACTIONS(4672),
  },
  [4985] = {
    [sym_simple_identifier] = ACTIONS(5318),
    [anon_sym_wire] = ACTIONS(5318),
    [anon_sym_tri] = ACTIONS(5318),
    [anon_sym_tri0] = ACTIONS(5318),
    [anon_sym_tri1] = ACTIONS(5318),
    [anon_sym_wand] = ACTIONS(5318),
    [anon_sym_triand] = ACTIONS(5318),
    [anon_sym_wor] = ACTIONS(5318),
    [anon_sym_trior] = ACTIONS(5318),
    [anon_sym_trireg] = ACTIONS(5318),
    [anon_sym_uwire] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5316),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym_interface] = ACTIONS(5318),
    [anon_sym_checker] = ACTIONS(5318),
    [anon_sym_virtual] = ACTIONS(5318),
    [anon_sym_class] = ACTIONS(5318),
    [anon_sym_type] = ACTIONS(5318),
    [anon_sym_DOLLARfatal] = ACTIONS(5316),
    [anon_sym_DOLLARerror] = ACTIONS(5316),
    [anon_sym_DOLLARwarning] = ACTIONS(5316),
    [anon_sym_DOLLARinfo] = ACTIONS(5316),
    [anon_sym_default] = ACTIONS(5318),
    [anon_sym_clocking] = ACTIONS(5318),
    [anon_sym_defparam] = ACTIONS(5318),
    [anon_sym_bind] = ACTIONS(5318),
    [anon_sym_rand] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_function] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_constraint] = ACTIONS(5318),
    [anon_sym_if] = ACTIONS(5318),
    [anon_sym_else] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5316),
    [anon_sym_localparam] = ACTIONS(5318),
    [anon_sym_parameter] = ACTIONS(5318),
    [anon_sym_var] = ACTIONS(5318),
    [anon_sym_import] = ACTIONS(5318),
    [anon_sym_export] = ACTIONS(5318),
    [anon_sym_genvar] = ACTIONS(5318),
    [anon_sym_interconnect] = ACTIONS(5318),
    [anon_sym_typedef] = ACTIONS(5318),
    [anon_sym_enum] = ACTIONS(5318),
    [anon_sym_struct] = ACTIONS(5318),
    [anon_sym_union] = ACTIONS(5318),
    [anon_sym_nettype] = ACTIONS(5318),
    [anon_sym_automatic] = ACTIONS(5318),
    [anon_sym_string] = ACTIONS(5318),
    [anon_sym_chandle] = ACTIONS(5318),
    [anon_sym_event] = ACTIONS(5318),
    [anon_sym_byte] = ACTIONS(5318),
    [anon_sym_shortint] = ACTIONS(5318),
    [anon_sym_int] = ACTIONS(5318),
    [anon_sym_longint] = ACTIONS(5318),
    [anon_sym_integer] = ACTIONS(5318),
    [anon_sym_time] = ACTIONS(5318),
    [anon_sym_bit] = ACTIONS(5318),
    [anon_sym_logic] = ACTIONS(5318),
    [anon_sym_reg] = ACTIONS(5318),
    [anon_sym_shortreal] = ACTIONS(5318),
    [anon_sym_real] = ACTIONS(5318),
    [anon_sym_realtime] = ACTIONS(5318),
    [anon_sym_supply0] = ACTIONS(5318),
    [anon_sym_supply1] = ACTIONS(5318),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_task] = ACTIONS(5318),
    [anon_sym_assert] = ACTIONS(5318),
    [anon_sym_property] = ACTIONS(5318),
    [anon_sym_assume] = ACTIONS(5318),
    [anon_sym_cover] = ACTIONS(5318),
    [anon_sym_sequence] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym_not] = ACTIONS(5318),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_case] = ACTIONS(5318),
    [anon_sym_always] = ACTIONS(5318),
    [anon_sym_covergroup] = ACTIONS(5318),
    [anon_sym_let] = ACTIONS(5318),
    [anon_sym_pulldown] = ACTIONS(5318),
    [anon_sym_pullup] = ACTIONS(5318),
    [anon_sym_cmos] = ACTIONS(5318),
    [anon_sym_rcmos] = ACTIONS(5318),
    [anon_sym_bufif0] = ACTIONS(5318),
    [anon_sym_bufif1] = ACTIONS(5318),
    [anon_sym_notif0] = ACTIONS(5318),
    [anon_sym_notif1] = ACTIONS(5318),
    [anon_sym_nmos] = ACTIONS(5318),
    [anon_sym_pmos] = ACTIONS(5318),
    [anon_sym_rnmos] = ACTIONS(5318),
    [anon_sym_rpmos] = ACTIONS(5318),
    [anon_sym_nand] = ACTIONS(5318),
    [anon_sym_nor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_xnor] = ACTIONS(5318),
    [anon_sym_buf] = ACTIONS(5318),
    [anon_sym_tranif0] = ACTIONS(5318),
    [anon_sym_tranif1] = ACTIONS(5318),
    [anon_sym_rtranif1] = ACTIONS(5318),
    [anon_sym_rtranif0] = ACTIONS(5318),
    [anon_sym_tran] = ACTIONS(5318),
    [anon_sym_rtran] = ACTIONS(5318),
    [anon_sym_generate] = ACTIONS(5318),
    [anon_sym_endgenerate] = ACTIONS(5318),
    [anon_sym_for] = ACTIONS(5318),
    [anon_sym_initial] = ACTIONS(5318),
    [anon_sym_assign] = ACTIONS(5318),
    [anon_sym_alias] = ACTIONS(5318),
    [anon_sym_always_comb] = ACTIONS(5318),
    [anon_sym_always_latch] = ACTIONS(5318),
    [anon_sym_always_ff] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_global] = ACTIONS(5318),
    [anon_sym_LPAREN_STAR] = ACTIONS(5316),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5316),
    [anon_sym_DOLLARunit] = ACTIONS(5316),
  },
  [4986] = {
    [sym_simple_identifier] = ACTIONS(6275),
    [anon_sym_wire] = ACTIONS(6275),
    [anon_sym_tri] = ACTIONS(6275),
    [anon_sym_tri0] = ACTIONS(6275),
    [anon_sym_tri1] = ACTIONS(6275),
    [anon_sym_wand] = ACTIONS(6275),
    [anon_sym_triand] = ACTIONS(6275),
    [anon_sym_wor] = ACTIONS(6275),
    [anon_sym_trior] = ACTIONS(6275),
    [anon_sym_trireg] = ACTIONS(6275),
    [anon_sym_uwire] = ACTIONS(6275),
    [anon_sym_SEMI] = ACTIONS(6277),
    [anon_sym_extern] = ACTIONS(6275),
    [anon_sym_interface] = ACTIONS(6275),
    [anon_sym_checker] = ACTIONS(6275),
    [anon_sym_virtual] = ACTIONS(6275),
    [anon_sym_class] = ACTIONS(6275),
    [anon_sym_type] = ACTIONS(6275),
    [anon_sym_DOLLARfatal] = ACTIONS(6277),
    [anon_sym_DOLLARerror] = ACTIONS(6277),
    [anon_sym_DOLLARwarning] = ACTIONS(6277),
    [anon_sym_DOLLARinfo] = ACTIONS(6277),
    [anon_sym_default] = ACTIONS(6275),
    [anon_sym_clocking] = ACTIONS(6275),
    [anon_sym_defparam] = ACTIONS(6275),
    [anon_sym_bind] = ACTIONS(6275),
    [anon_sym_rand] = ACTIONS(6275),
    [anon_sym_const] = ACTIONS(6275),
    [anon_sym_function] = ACTIONS(6275),
    [anon_sym_static] = ACTIONS(6275),
    [anon_sym_constraint] = ACTIONS(6275),
    [anon_sym_if] = ACTIONS(6275),
    [anon_sym_else] = ACTIONS(6275),
    [anon_sym_LBRACK] = ACTIONS(6277),
    [anon_sym_localparam] = ACTIONS(6275),
    [anon_sym_parameter] = ACTIONS(6275),
    [anon_sym_var] = ACTIONS(6275),
    [anon_sym_import] = ACTIONS(6275),
    [anon_sym_export] = ACTIONS(6275),
    [anon_sym_genvar] = ACTIONS(6275),
    [anon_sym_interconnect] = ACTIONS(6275),
    [anon_sym_typedef] = ACTIONS(6275),
    [anon_sym_enum] = ACTIONS(6275),
    [anon_sym_struct] = ACTIONS(6275),
    [anon_sym_union] = ACTIONS(6275),
    [anon_sym_nettype] = ACTIONS(6275),
    [anon_sym_automatic] = ACTIONS(6275),
    [anon_sym_string] = ACTIONS(6275),
    [anon_sym_chandle] = ACTIONS(6275),
    [anon_sym_event] = ACTIONS(6275),
    [anon_sym_byte] = ACTIONS(6275),
    [anon_sym_shortint] = ACTIONS(6275),
    [anon_sym_int] = ACTIONS(6275),
    [anon_sym_longint] = ACTIONS(6275),
    [anon_sym_integer] = ACTIONS(6275),
    [anon_sym_time] = ACTIONS(6275),
    [anon_sym_bit] = ACTIONS(6275),
    [anon_sym_logic] = ACTIONS(6275),
    [anon_sym_reg] = ACTIONS(6275),
    [anon_sym_shortreal] = ACTIONS(6275),
    [anon_sym_real] = ACTIONS(6275),
    [anon_sym_realtime] = ACTIONS(6275),
    [anon_sym_supply0] = ACTIONS(6275),
    [anon_sym_supply1] = ACTIONS(6275),
    [anon_sym_signed] = ACTIONS(6275),
    [anon_sym_unsigned] = ACTIONS(6275),
    [anon_sym_task] = ACTIONS(6275),
    [anon_sym_assert] = ACTIONS(6275),
    [anon_sym_property] = ACTIONS(6275),
    [anon_sym_assume] = ACTIONS(6275),
    [anon_sym_cover] = ACTIONS(6275),
    [anon_sym_sequence] = ACTIONS(6275),
    [anon_sym_restrict] = ACTIONS(6275),
    [anon_sym_not] = ACTIONS(6275),
    [anon_sym_or] = ACTIONS(6275),
    [anon_sym_and] = ACTIONS(6275),
    [anon_sym_case] = ACTIONS(6275),
    [anon_sym_always] = ACTIONS(6275),
    [anon_sym_covergroup] = ACTIONS(6275),
    [anon_sym_let] = ACTIONS(6275),
    [anon_sym_pulldown] = ACTIONS(6275),
    [anon_sym_pullup] = ACTIONS(6275),
    [anon_sym_cmos] = ACTIONS(6275),
    [anon_sym_rcmos] = ACTIONS(6275),
    [anon_sym_bufif0] = ACTIONS(6275),
    [anon_sym_bufif1] = ACTIONS(6275),
    [anon_sym_notif0] = ACTIONS(6275),
    [anon_sym_notif1] = ACTIONS(6275),
    [anon_sym_nmos] = ACTIONS(6275),
    [anon_sym_pmos] = ACTIONS(6275),
    [anon_sym_rnmos] = ACTIONS(6275),
    [anon_sym_rpmos] = ACTIONS(6275),
    [anon_sym_nand] = ACTIONS(6275),
    [anon_sym_nor] = ACTIONS(6275),
    [anon_sym_xor] = ACTIONS(6275),
    [anon_sym_xnor] = ACTIONS(6275),
    [anon_sym_buf] = ACTIONS(6275),
    [anon_sym_tranif0] = ACTIONS(6275),
    [anon_sym_tranif1] = ACTIONS(6275),
    [anon_sym_rtranif1] = ACTIONS(6275),
    [anon_sym_rtranif0] = ACTIONS(6275),
    [anon_sym_tran] = ACTIONS(6275),
    [anon_sym_rtran] = ACTIONS(6275),
    [anon_sym_generate] = ACTIONS(6275),
    [anon_sym_endgenerate] = ACTIONS(6275),
    [anon_sym_for] = ACTIONS(6275),
    [anon_sym_initial] = ACTIONS(6275),
    [anon_sym_assign] = ACTIONS(6275),
    [anon_sym_alias] = ACTIONS(6275),
    [anon_sym_always_comb] = ACTIONS(6275),
    [anon_sym_always_latch] = ACTIONS(6275),
    [anon_sym_always_ff] = ACTIONS(6275),
    [anon_sym_final] = ACTIONS(6275),
    [anon_sym_global] = ACTIONS(6275),
    [anon_sym_LPAREN_STAR] = ACTIONS(6277),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6277),
    [anon_sym_DOLLARunit] = ACTIONS(6277),
  },
  [4987] = {
    [sym_simple_identifier] = ACTIONS(4180),
    [anon_sym_wire] = ACTIONS(4180),
    [anon_sym_tri] = ACTIONS(4180),
    [anon_sym_tri0] = ACTIONS(4180),
    [anon_sym_tri1] = ACTIONS(4180),
    [anon_sym_wand] = ACTIONS(4180),
    [anon_sym_triand] = ACTIONS(4180),
    [anon_sym_wor] = ACTIONS(4180),
    [anon_sym_trior] = ACTIONS(4180),
    [anon_sym_trireg] = ACTIONS(4180),
    [anon_sym_uwire] = ACTIONS(4180),
    [anon_sym_SEMI] = ACTIONS(4178),
    [anon_sym_extern] = ACTIONS(4180),
    [anon_sym_interface] = ACTIONS(4180),
    [anon_sym_checker] = ACTIONS(4180),
    [anon_sym_virtual] = ACTIONS(4180),
    [anon_sym_class] = ACTIONS(4180),
    [anon_sym_type] = ACTIONS(4180),
    [anon_sym_DOLLARfatal] = ACTIONS(4178),
    [anon_sym_DOLLARerror] = ACTIONS(4178),
    [anon_sym_DOLLARwarning] = ACTIONS(4178),
    [anon_sym_DOLLARinfo] = ACTIONS(4178),
    [anon_sym_default] = ACTIONS(4180),
    [anon_sym_clocking] = ACTIONS(4180),
    [anon_sym_defparam] = ACTIONS(4180),
    [anon_sym_bind] = ACTIONS(4180),
    [anon_sym_rand] = ACTIONS(4180),
    [anon_sym_const] = ACTIONS(4180),
    [anon_sym_function] = ACTIONS(4180),
    [anon_sym_static] = ACTIONS(4180),
    [anon_sym_constraint] = ACTIONS(4180),
    [anon_sym_if] = ACTIONS(4180),
    [anon_sym_else] = ACTIONS(4180),
    [anon_sym_LBRACK] = ACTIONS(4178),
    [anon_sym_localparam] = ACTIONS(4180),
    [anon_sym_parameter] = ACTIONS(4180),
    [anon_sym_var] = ACTIONS(4180),
    [anon_sym_import] = ACTIONS(4180),
    [anon_sym_export] = ACTIONS(4180),
    [anon_sym_genvar] = ACTIONS(4180),
    [anon_sym_interconnect] = ACTIONS(4180),
    [anon_sym_typedef] = ACTIONS(4180),
    [anon_sym_enum] = ACTIONS(4180),
    [anon_sym_struct] = ACTIONS(4180),
    [anon_sym_union] = ACTIONS(4180),
    [anon_sym_nettype] = ACTIONS(4180),
    [anon_sym_automatic] = ACTIONS(4180),
    [anon_sym_string] = ACTIONS(4180),
    [anon_sym_chandle] = ACTIONS(4180),
    [anon_sym_event] = ACTIONS(4180),
    [anon_sym_byte] = ACTIONS(4180),
    [anon_sym_shortint] = ACTIONS(4180),
    [anon_sym_int] = ACTIONS(4180),
    [anon_sym_longint] = ACTIONS(4180),
    [anon_sym_integer] = ACTIONS(4180),
    [anon_sym_time] = ACTIONS(4180),
    [anon_sym_bit] = ACTIONS(4180),
    [anon_sym_logic] = ACTIONS(4180),
    [anon_sym_reg] = ACTIONS(4180),
    [anon_sym_shortreal] = ACTIONS(4180),
    [anon_sym_real] = ACTIONS(4180),
    [anon_sym_realtime] = ACTIONS(4180),
    [anon_sym_supply0] = ACTIONS(4180),
    [anon_sym_supply1] = ACTIONS(4180),
    [anon_sym_signed] = ACTIONS(4180),
    [anon_sym_unsigned] = ACTIONS(4180),
    [anon_sym_task] = ACTIONS(4180),
    [anon_sym_assert] = ACTIONS(4180),
    [anon_sym_property] = ACTIONS(4180),
    [anon_sym_assume] = ACTIONS(4180),
    [anon_sym_cover] = ACTIONS(4180),
    [anon_sym_sequence] = ACTIONS(4180),
    [anon_sym_restrict] = ACTIONS(4180),
    [anon_sym_not] = ACTIONS(4180),
    [anon_sym_or] = ACTIONS(4180),
    [anon_sym_and] = ACTIONS(4180),
    [anon_sym_case] = ACTIONS(4180),
    [anon_sym_always] = ACTIONS(4180),
    [anon_sym_covergroup] = ACTIONS(4180),
    [anon_sym_end] = ACTIONS(4180),
    [anon_sym_let] = ACTIONS(4180),
    [anon_sym_pulldown] = ACTIONS(4180),
    [anon_sym_pullup] = ACTIONS(4180),
    [anon_sym_cmos] = ACTIONS(4180),
    [anon_sym_rcmos] = ACTIONS(4180),
    [anon_sym_bufif0] = ACTIONS(4180),
    [anon_sym_bufif1] = ACTIONS(4180),
    [anon_sym_notif0] = ACTIONS(4180),
    [anon_sym_notif1] = ACTIONS(4180),
    [anon_sym_nmos] = ACTIONS(4180),
    [anon_sym_pmos] = ACTIONS(4180),
    [anon_sym_rnmos] = ACTIONS(4180),
    [anon_sym_rpmos] = ACTIONS(4180),
    [anon_sym_nand] = ACTIONS(4180),
    [anon_sym_nor] = ACTIONS(4180),
    [anon_sym_xor] = ACTIONS(4180),
    [anon_sym_xnor] = ACTIONS(4180),
    [anon_sym_buf] = ACTIONS(4180),
    [anon_sym_tranif0] = ACTIONS(4180),
    [anon_sym_tranif1] = ACTIONS(4180),
    [anon_sym_rtranif1] = ACTIONS(4180),
    [anon_sym_rtranif0] = ACTIONS(4180),
    [anon_sym_tran] = ACTIONS(4180),
    [anon_sym_rtran] = ACTIONS(4180),
    [anon_sym_generate] = ACTIONS(4180),
    [anon_sym_for] = ACTIONS(4180),
    [anon_sym_initial] = ACTIONS(4180),
    [anon_sym_assign] = ACTIONS(4180),
    [anon_sym_alias] = ACTIONS(4180),
    [anon_sym_always_comb] = ACTIONS(4180),
    [anon_sym_always_latch] = ACTIONS(4180),
    [anon_sym_always_ff] = ACTIONS(4180),
    [anon_sym_final] = ACTIONS(4180),
    [anon_sym_global] = ACTIONS(4180),
    [anon_sym_LPAREN_STAR] = ACTIONS(4178),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4178),
    [anon_sym_DOLLARunit] = ACTIONS(4178),
  },
  [4988] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(5810),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_end] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [4989] = {
    [sym_simple_identifier] = ACTIONS(4872),
    [anon_sym_wire] = ACTIONS(4872),
    [anon_sym_tri] = ACTIONS(4872),
    [anon_sym_tri0] = ACTIONS(4872),
    [anon_sym_tri1] = ACTIONS(4872),
    [anon_sym_wand] = ACTIONS(4872),
    [anon_sym_triand] = ACTIONS(4872),
    [anon_sym_wor] = ACTIONS(4872),
    [anon_sym_trior] = ACTIONS(4872),
    [anon_sym_trireg] = ACTIONS(4872),
    [anon_sym_uwire] = ACTIONS(4872),
    [anon_sym_SEMI] = ACTIONS(4870),
    [anon_sym_extern] = ACTIONS(4872),
    [anon_sym_interface] = ACTIONS(4872),
    [anon_sym_checker] = ACTIONS(4872),
    [anon_sym_virtual] = ACTIONS(4872),
    [anon_sym_class] = ACTIONS(4872),
    [anon_sym_type] = ACTIONS(4872),
    [anon_sym_DOLLARfatal] = ACTIONS(4870),
    [anon_sym_DOLLARerror] = ACTIONS(4870),
    [anon_sym_DOLLARwarning] = ACTIONS(4870),
    [anon_sym_DOLLARinfo] = ACTIONS(4870),
    [anon_sym_default] = ACTIONS(4872),
    [anon_sym_clocking] = ACTIONS(4872),
    [anon_sym_defparam] = ACTIONS(4872),
    [anon_sym_bind] = ACTIONS(4872),
    [anon_sym_rand] = ACTIONS(4872),
    [anon_sym_const] = ACTIONS(4872),
    [anon_sym_function] = ACTIONS(4872),
    [anon_sym_static] = ACTIONS(4872),
    [anon_sym_constraint] = ACTIONS(4872),
    [anon_sym_if] = ACTIONS(4872),
    [anon_sym_else] = ACTIONS(4872),
    [anon_sym_LBRACK] = ACTIONS(4870),
    [anon_sym_localparam] = ACTIONS(4872),
    [anon_sym_parameter] = ACTIONS(4872),
    [anon_sym_var] = ACTIONS(4872),
    [anon_sym_import] = ACTIONS(4872),
    [anon_sym_export] = ACTIONS(4872),
    [anon_sym_genvar] = ACTIONS(4872),
    [anon_sym_interconnect] = ACTIONS(4872),
    [anon_sym_typedef] = ACTIONS(4872),
    [anon_sym_enum] = ACTIONS(4872),
    [anon_sym_struct] = ACTIONS(4872),
    [anon_sym_union] = ACTIONS(4872),
    [anon_sym_nettype] = ACTIONS(4872),
    [anon_sym_automatic] = ACTIONS(4872),
    [anon_sym_string] = ACTIONS(4872),
    [anon_sym_chandle] = ACTIONS(4872),
    [anon_sym_event] = ACTIONS(4872),
    [anon_sym_byte] = ACTIONS(4872),
    [anon_sym_shortint] = ACTIONS(4872),
    [anon_sym_int] = ACTIONS(4872),
    [anon_sym_longint] = ACTIONS(4872),
    [anon_sym_integer] = ACTIONS(4872),
    [anon_sym_time] = ACTIONS(4872),
    [anon_sym_bit] = ACTIONS(4872),
    [anon_sym_logic] = ACTIONS(4872),
    [anon_sym_reg] = ACTIONS(4872),
    [anon_sym_shortreal] = ACTIONS(4872),
    [anon_sym_real] = ACTIONS(4872),
    [anon_sym_realtime] = ACTIONS(4872),
    [anon_sym_supply0] = ACTIONS(4872),
    [anon_sym_supply1] = ACTIONS(4872),
    [anon_sym_signed] = ACTIONS(4872),
    [anon_sym_unsigned] = ACTIONS(4872),
    [anon_sym_task] = ACTIONS(4872),
    [anon_sym_assert] = ACTIONS(4872),
    [anon_sym_property] = ACTIONS(4872),
    [anon_sym_assume] = ACTIONS(4872),
    [anon_sym_cover] = ACTIONS(4872),
    [anon_sym_sequence] = ACTIONS(4872),
    [anon_sym_restrict] = ACTIONS(4872),
    [anon_sym_not] = ACTIONS(4872),
    [anon_sym_or] = ACTIONS(4872),
    [anon_sym_and] = ACTIONS(4872),
    [anon_sym_case] = ACTIONS(4872),
    [anon_sym_always] = ACTIONS(4872),
    [anon_sym_covergroup] = ACTIONS(4872),
    [anon_sym_end] = ACTIONS(4872),
    [anon_sym_let] = ACTIONS(4872),
    [anon_sym_pulldown] = ACTIONS(4872),
    [anon_sym_pullup] = ACTIONS(4872),
    [anon_sym_cmos] = ACTIONS(4872),
    [anon_sym_rcmos] = ACTIONS(4872),
    [anon_sym_bufif0] = ACTIONS(4872),
    [anon_sym_bufif1] = ACTIONS(4872),
    [anon_sym_notif0] = ACTIONS(4872),
    [anon_sym_notif1] = ACTIONS(4872),
    [anon_sym_nmos] = ACTIONS(4872),
    [anon_sym_pmos] = ACTIONS(4872),
    [anon_sym_rnmos] = ACTIONS(4872),
    [anon_sym_rpmos] = ACTIONS(4872),
    [anon_sym_nand] = ACTIONS(4872),
    [anon_sym_nor] = ACTIONS(4872),
    [anon_sym_xor] = ACTIONS(4872),
    [anon_sym_xnor] = ACTIONS(4872),
    [anon_sym_buf] = ACTIONS(4872),
    [anon_sym_tranif0] = ACTIONS(4872),
    [anon_sym_tranif1] = ACTIONS(4872),
    [anon_sym_rtranif1] = ACTIONS(4872),
    [anon_sym_rtranif0] = ACTIONS(4872),
    [anon_sym_tran] = ACTIONS(4872),
    [anon_sym_rtran] = ACTIONS(4872),
    [anon_sym_generate] = ACTIONS(4872),
    [anon_sym_for] = ACTIONS(4872),
    [anon_sym_initial] = ACTIONS(4872),
    [anon_sym_assign] = ACTIONS(4872),
    [anon_sym_alias] = ACTIONS(4872),
    [anon_sym_always_comb] = ACTIONS(4872),
    [anon_sym_always_latch] = ACTIONS(4872),
    [anon_sym_always_ff] = ACTIONS(4872),
    [anon_sym_final] = ACTIONS(4872),
    [anon_sym_global] = ACTIONS(4872),
    [anon_sym_LPAREN_STAR] = ACTIONS(4870),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4870),
    [anon_sym_DOLLARunit] = ACTIONS(4870),
  },
  [4990] = {
    [sym_simple_identifier] = ACTIONS(6279),
    [anon_sym_wire] = ACTIONS(6279),
    [anon_sym_tri] = ACTIONS(6279),
    [anon_sym_tri0] = ACTIONS(6279),
    [anon_sym_tri1] = ACTIONS(6279),
    [anon_sym_wand] = ACTIONS(6279),
    [anon_sym_triand] = ACTIONS(6279),
    [anon_sym_wor] = ACTIONS(6279),
    [anon_sym_trior] = ACTIONS(6279),
    [anon_sym_trireg] = ACTIONS(6279),
    [anon_sym_uwire] = ACTIONS(6279),
    [anon_sym_SEMI] = ACTIONS(6281),
    [anon_sym_extern] = ACTIONS(6279),
    [anon_sym_interface] = ACTIONS(6279),
    [anon_sym_checker] = ACTIONS(6279),
    [anon_sym_virtual] = ACTIONS(6279),
    [anon_sym_class] = ACTIONS(6279),
    [anon_sym_type] = ACTIONS(6279),
    [anon_sym_DOLLARfatal] = ACTIONS(6281),
    [anon_sym_DOLLARerror] = ACTIONS(6281),
    [anon_sym_DOLLARwarning] = ACTIONS(6281),
    [anon_sym_DOLLARinfo] = ACTIONS(6281),
    [anon_sym_default] = ACTIONS(6279),
    [anon_sym_clocking] = ACTIONS(6279),
    [anon_sym_defparam] = ACTIONS(6279),
    [anon_sym_bind] = ACTIONS(6279),
    [anon_sym_rand] = ACTIONS(6279),
    [anon_sym_const] = ACTIONS(6279),
    [anon_sym_function] = ACTIONS(6279),
    [anon_sym_static] = ACTIONS(6279),
    [anon_sym_constraint] = ACTIONS(6279),
    [anon_sym_if] = ACTIONS(6279),
    [anon_sym_else] = ACTIONS(6279),
    [anon_sym_LBRACK] = ACTIONS(6281),
    [anon_sym_localparam] = ACTIONS(6279),
    [anon_sym_parameter] = ACTIONS(6279),
    [anon_sym_var] = ACTIONS(6279),
    [anon_sym_import] = ACTIONS(6279),
    [anon_sym_export] = ACTIONS(6279),
    [anon_sym_genvar] = ACTIONS(6279),
    [anon_sym_interconnect] = ACTIONS(6279),
    [anon_sym_typedef] = ACTIONS(6279),
    [anon_sym_enum] = ACTIONS(6279),
    [anon_sym_struct] = ACTIONS(6279),
    [anon_sym_union] = ACTIONS(6279),
    [anon_sym_nettype] = ACTIONS(6279),
    [anon_sym_automatic] = ACTIONS(6279),
    [anon_sym_string] = ACTIONS(6279),
    [anon_sym_chandle] = ACTIONS(6279),
    [anon_sym_event] = ACTIONS(6279),
    [anon_sym_byte] = ACTIONS(6279),
    [anon_sym_shortint] = ACTIONS(6279),
    [anon_sym_int] = ACTIONS(6279),
    [anon_sym_longint] = ACTIONS(6279),
    [anon_sym_integer] = ACTIONS(6279),
    [anon_sym_time] = ACTIONS(6279),
    [anon_sym_bit] = ACTIONS(6279),
    [anon_sym_logic] = ACTIONS(6279),
    [anon_sym_reg] = ACTIONS(6279),
    [anon_sym_shortreal] = ACTIONS(6279),
    [anon_sym_real] = ACTIONS(6279),
    [anon_sym_realtime] = ACTIONS(6279),
    [anon_sym_supply0] = ACTIONS(6279),
    [anon_sym_supply1] = ACTIONS(6279),
    [anon_sym_signed] = ACTIONS(6279),
    [anon_sym_unsigned] = ACTIONS(6279),
    [anon_sym_task] = ACTIONS(6279),
    [anon_sym_assert] = ACTIONS(6279),
    [anon_sym_property] = ACTIONS(6279),
    [anon_sym_assume] = ACTIONS(6279),
    [anon_sym_cover] = ACTIONS(6279),
    [anon_sym_sequence] = ACTIONS(6279),
    [anon_sym_restrict] = ACTIONS(6279),
    [anon_sym_not] = ACTIONS(6279),
    [anon_sym_or] = ACTIONS(6279),
    [anon_sym_and] = ACTIONS(6279),
    [anon_sym_case] = ACTIONS(6279),
    [anon_sym_always] = ACTIONS(6279),
    [anon_sym_covergroup] = ACTIONS(6279),
    [anon_sym_let] = ACTIONS(6279),
    [anon_sym_pulldown] = ACTIONS(6279),
    [anon_sym_pullup] = ACTIONS(6279),
    [anon_sym_cmos] = ACTIONS(6279),
    [anon_sym_rcmos] = ACTIONS(6279),
    [anon_sym_bufif0] = ACTIONS(6279),
    [anon_sym_bufif1] = ACTIONS(6279),
    [anon_sym_notif0] = ACTIONS(6279),
    [anon_sym_notif1] = ACTIONS(6279),
    [anon_sym_nmos] = ACTIONS(6279),
    [anon_sym_pmos] = ACTIONS(6279),
    [anon_sym_rnmos] = ACTIONS(6279),
    [anon_sym_rpmos] = ACTIONS(6279),
    [anon_sym_nand] = ACTIONS(6279),
    [anon_sym_nor] = ACTIONS(6279),
    [anon_sym_xor] = ACTIONS(6279),
    [anon_sym_xnor] = ACTIONS(6279),
    [anon_sym_buf] = ACTIONS(6279),
    [anon_sym_tranif0] = ACTIONS(6279),
    [anon_sym_tranif1] = ACTIONS(6279),
    [anon_sym_rtranif1] = ACTIONS(6279),
    [anon_sym_rtranif0] = ACTIONS(6279),
    [anon_sym_tran] = ACTIONS(6279),
    [anon_sym_rtran] = ACTIONS(6279),
    [anon_sym_generate] = ACTIONS(6279),
    [anon_sym_endgenerate] = ACTIONS(6279),
    [anon_sym_for] = ACTIONS(6279),
    [anon_sym_initial] = ACTIONS(6279),
    [anon_sym_assign] = ACTIONS(6279),
    [anon_sym_alias] = ACTIONS(6279),
    [anon_sym_always_comb] = ACTIONS(6279),
    [anon_sym_always_latch] = ACTIONS(6279),
    [anon_sym_always_ff] = ACTIONS(6279),
    [anon_sym_final] = ACTIONS(6279),
    [anon_sym_global] = ACTIONS(6279),
    [anon_sym_LPAREN_STAR] = ACTIONS(6281),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6281),
    [anon_sym_DOLLARunit] = ACTIONS(6281),
  },
  [4991] = {
    [sym_simple_identifier] = ACTIONS(4924),
    [anon_sym_wire] = ACTIONS(4924),
    [anon_sym_tri] = ACTIONS(4924),
    [anon_sym_tri0] = ACTIONS(4924),
    [anon_sym_tri1] = ACTIONS(4924),
    [anon_sym_wand] = ACTIONS(4924),
    [anon_sym_triand] = ACTIONS(4924),
    [anon_sym_wor] = ACTIONS(4924),
    [anon_sym_trior] = ACTIONS(4924),
    [anon_sym_trireg] = ACTIONS(4924),
    [anon_sym_uwire] = ACTIONS(4924),
    [anon_sym_SEMI] = ACTIONS(4922),
    [anon_sym_extern] = ACTIONS(4924),
    [anon_sym_interface] = ACTIONS(4924),
    [anon_sym_checker] = ACTIONS(4924),
    [anon_sym_virtual] = ACTIONS(4924),
    [anon_sym_class] = ACTIONS(4924),
    [anon_sym_type] = ACTIONS(4924),
    [anon_sym_DOLLARfatal] = ACTIONS(4922),
    [anon_sym_DOLLARerror] = ACTIONS(4922),
    [anon_sym_DOLLARwarning] = ACTIONS(4922),
    [anon_sym_DOLLARinfo] = ACTIONS(4922),
    [anon_sym_default] = ACTIONS(4924),
    [anon_sym_clocking] = ACTIONS(4924),
    [anon_sym_defparam] = ACTIONS(4924),
    [anon_sym_bind] = ACTIONS(4924),
    [anon_sym_rand] = ACTIONS(4924),
    [anon_sym_const] = ACTIONS(4924),
    [anon_sym_function] = ACTIONS(4924),
    [anon_sym_static] = ACTIONS(4924),
    [anon_sym_constraint] = ACTIONS(4924),
    [anon_sym_if] = ACTIONS(4924),
    [anon_sym_else] = ACTIONS(4924),
    [anon_sym_LBRACK] = ACTIONS(4922),
    [anon_sym_localparam] = ACTIONS(4924),
    [anon_sym_parameter] = ACTIONS(4924),
    [anon_sym_var] = ACTIONS(4924),
    [anon_sym_import] = ACTIONS(4924),
    [anon_sym_export] = ACTIONS(4924),
    [anon_sym_genvar] = ACTIONS(4924),
    [anon_sym_interconnect] = ACTIONS(4924),
    [anon_sym_typedef] = ACTIONS(4924),
    [anon_sym_enum] = ACTIONS(4924),
    [anon_sym_struct] = ACTIONS(4924),
    [anon_sym_union] = ACTIONS(4924),
    [anon_sym_nettype] = ACTIONS(4924),
    [anon_sym_automatic] = ACTIONS(4924),
    [anon_sym_string] = ACTIONS(4924),
    [anon_sym_chandle] = ACTIONS(4924),
    [anon_sym_event] = ACTIONS(4924),
    [anon_sym_byte] = ACTIONS(4924),
    [anon_sym_shortint] = ACTIONS(4924),
    [anon_sym_int] = ACTIONS(4924),
    [anon_sym_longint] = ACTIONS(4924),
    [anon_sym_integer] = ACTIONS(4924),
    [anon_sym_time] = ACTIONS(4924),
    [anon_sym_bit] = ACTIONS(4924),
    [anon_sym_logic] = ACTIONS(4924),
    [anon_sym_reg] = ACTIONS(4924),
    [anon_sym_shortreal] = ACTIONS(4924),
    [anon_sym_real] = ACTIONS(4924),
    [anon_sym_realtime] = ACTIONS(4924),
    [anon_sym_supply0] = ACTIONS(4924),
    [anon_sym_supply1] = ACTIONS(4924),
    [anon_sym_signed] = ACTIONS(4924),
    [anon_sym_unsigned] = ACTIONS(4924),
    [anon_sym_task] = ACTIONS(4924),
    [anon_sym_assert] = ACTIONS(4924),
    [anon_sym_property] = ACTIONS(4924),
    [anon_sym_assume] = ACTIONS(4924),
    [anon_sym_cover] = ACTIONS(4924),
    [anon_sym_sequence] = ACTIONS(4924),
    [anon_sym_restrict] = ACTIONS(4924),
    [anon_sym_not] = ACTIONS(4924),
    [anon_sym_or] = ACTIONS(4924),
    [anon_sym_and] = ACTIONS(4924),
    [anon_sym_case] = ACTIONS(4924),
    [anon_sym_always] = ACTIONS(4924),
    [anon_sym_covergroup] = ACTIONS(4924),
    [anon_sym_let] = ACTIONS(4924),
    [anon_sym_pulldown] = ACTIONS(4924),
    [anon_sym_pullup] = ACTIONS(4924),
    [anon_sym_cmos] = ACTIONS(4924),
    [anon_sym_rcmos] = ACTIONS(4924),
    [anon_sym_bufif0] = ACTIONS(4924),
    [anon_sym_bufif1] = ACTIONS(4924),
    [anon_sym_notif0] = ACTIONS(4924),
    [anon_sym_notif1] = ACTIONS(4924),
    [anon_sym_nmos] = ACTIONS(4924),
    [anon_sym_pmos] = ACTIONS(4924),
    [anon_sym_rnmos] = ACTIONS(4924),
    [anon_sym_rpmos] = ACTIONS(4924),
    [anon_sym_nand] = ACTIONS(4924),
    [anon_sym_nor] = ACTIONS(4924),
    [anon_sym_xor] = ACTIONS(4924),
    [anon_sym_xnor] = ACTIONS(4924),
    [anon_sym_buf] = ACTIONS(4924),
    [anon_sym_tranif0] = ACTIONS(4924),
    [anon_sym_tranif1] = ACTIONS(4924),
    [anon_sym_rtranif1] = ACTIONS(4924),
    [anon_sym_rtranif0] = ACTIONS(4924),
    [anon_sym_tran] = ACTIONS(4924),
    [anon_sym_rtran] = ACTIONS(4924),
    [anon_sym_generate] = ACTIONS(4924),
    [anon_sym_endgenerate] = ACTIONS(4924),
    [anon_sym_for] = ACTIONS(4924),
    [anon_sym_initial] = ACTIONS(4924),
    [anon_sym_assign] = ACTIONS(4924),
    [anon_sym_alias] = ACTIONS(4924),
    [anon_sym_always_comb] = ACTIONS(4924),
    [anon_sym_always_latch] = ACTIONS(4924),
    [anon_sym_always_ff] = ACTIONS(4924),
    [anon_sym_final] = ACTIONS(4924),
    [anon_sym_global] = ACTIONS(4924),
    [anon_sym_LPAREN_STAR] = ACTIONS(4922),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4922),
    [anon_sym_DOLLARunit] = ACTIONS(4922),
  },
  [4992] = {
    [sym_simple_identifier] = ACTIONS(4658),
    [anon_sym_wire] = ACTIONS(4658),
    [anon_sym_tri] = ACTIONS(4658),
    [anon_sym_tri0] = ACTIONS(4658),
    [anon_sym_tri1] = ACTIONS(4658),
    [anon_sym_wand] = ACTIONS(4658),
    [anon_sym_triand] = ACTIONS(4658),
    [anon_sym_wor] = ACTIONS(4658),
    [anon_sym_trior] = ACTIONS(4658),
    [anon_sym_trireg] = ACTIONS(4658),
    [anon_sym_uwire] = ACTIONS(4658),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_extern] = ACTIONS(4658),
    [anon_sym_interface] = ACTIONS(4658),
    [anon_sym_checker] = ACTIONS(4658),
    [anon_sym_virtual] = ACTIONS(4658),
    [anon_sym_class] = ACTIONS(4658),
    [anon_sym_type] = ACTIONS(4658),
    [anon_sym_DOLLARfatal] = ACTIONS(4656),
    [anon_sym_DOLLARerror] = ACTIONS(4656),
    [anon_sym_DOLLARwarning] = ACTIONS(4656),
    [anon_sym_DOLLARinfo] = ACTIONS(4656),
    [anon_sym_default] = ACTIONS(4658),
    [anon_sym_clocking] = ACTIONS(4658),
    [anon_sym_defparam] = ACTIONS(4658),
    [anon_sym_bind] = ACTIONS(4658),
    [anon_sym_rand] = ACTIONS(4658),
    [anon_sym_const] = ACTIONS(4658),
    [anon_sym_function] = ACTIONS(4658),
    [anon_sym_static] = ACTIONS(4658),
    [anon_sym_constraint] = ACTIONS(4658),
    [anon_sym_if] = ACTIONS(4658),
    [anon_sym_else] = ACTIONS(4658),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [anon_sym_localparam] = ACTIONS(4658),
    [anon_sym_parameter] = ACTIONS(4658),
    [anon_sym_var] = ACTIONS(4658),
    [anon_sym_import] = ACTIONS(4658),
    [anon_sym_export] = ACTIONS(4658),
    [anon_sym_genvar] = ACTIONS(4658),
    [anon_sym_interconnect] = ACTIONS(4658),
    [anon_sym_typedef] = ACTIONS(4658),
    [anon_sym_enum] = ACTIONS(4658),
    [anon_sym_struct] = ACTIONS(4658),
    [anon_sym_union] = ACTIONS(4658),
    [anon_sym_nettype] = ACTIONS(4658),
    [anon_sym_automatic] = ACTIONS(4658),
    [anon_sym_string] = ACTIONS(4658),
    [anon_sym_chandle] = ACTIONS(4658),
    [anon_sym_event] = ACTIONS(4658),
    [anon_sym_byte] = ACTIONS(4658),
    [anon_sym_shortint] = ACTIONS(4658),
    [anon_sym_int] = ACTIONS(4658),
    [anon_sym_longint] = ACTIONS(4658),
    [anon_sym_integer] = ACTIONS(4658),
    [anon_sym_time] = ACTIONS(4658),
    [anon_sym_bit] = ACTIONS(4658),
    [anon_sym_logic] = ACTIONS(4658),
    [anon_sym_reg] = ACTIONS(4658),
    [anon_sym_shortreal] = ACTIONS(4658),
    [anon_sym_real] = ACTIONS(4658),
    [anon_sym_realtime] = ACTIONS(4658),
    [anon_sym_supply0] = ACTIONS(4658),
    [anon_sym_supply1] = ACTIONS(4658),
    [anon_sym_signed] = ACTIONS(4658),
    [anon_sym_unsigned] = ACTIONS(4658),
    [anon_sym_task] = ACTIONS(4658),
    [anon_sym_assert] = ACTIONS(4658),
    [anon_sym_property] = ACTIONS(4658),
    [anon_sym_assume] = ACTIONS(4658),
    [anon_sym_cover] = ACTIONS(4658),
    [anon_sym_sequence] = ACTIONS(4658),
    [anon_sym_restrict] = ACTIONS(4658),
    [anon_sym_not] = ACTIONS(4658),
    [anon_sym_or] = ACTIONS(4658),
    [anon_sym_and] = ACTIONS(4658),
    [anon_sym_case] = ACTIONS(4658),
    [anon_sym_always] = ACTIONS(4658),
    [anon_sym_covergroup] = ACTIONS(4658),
    [anon_sym_let] = ACTIONS(4658),
    [anon_sym_pulldown] = ACTIONS(4658),
    [anon_sym_pullup] = ACTIONS(4658),
    [anon_sym_cmos] = ACTIONS(4658),
    [anon_sym_rcmos] = ACTIONS(4658),
    [anon_sym_bufif0] = ACTIONS(4658),
    [anon_sym_bufif1] = ACTIONS(4658),
    [anon_sym_notif0] = ACTIONS(4658),
    [anon_sym_notif1] = ACTIONS(4658),
    [anon_sym_nmos] = ACTIONS(4658),
    [anon_sym_pmos] = ACTIONS(4658),
    [anon_sym_rnmos] = ACTIONS(4658),
    [anon_sym_rpmos] = ACTIONS(4658),
    [anon_sym_nand] = ACTIONS(4658),
    [anon_sym_nor] = ACTIONS(4658),
    [anon_sym_xor] = ACTIONS(4658),
    [anon_sym_xnor] = ACTIONS(4658),
    [anon_sym_buf] = ACTIONS(4658),
    [anon_sym_tranif0] = ACTIONS(4658),
    [anon_sym_tranif1] = ACTIONS(4658),
    [anon_sym_rtranif1] = ACTIONS(4658),
    [anon_sym_rtranif0] = ACTIONS(4658),
    [anon_sym_tran] = ACTIONS(4658),
    [anon_sym_rtran] = ACTIONS(4658),
    [anon_sym_generate] = ACTIONS(4658),
    [anon_sym_endgenerate] = ACTIONS(4658),
    [anon_sym_for] = ACTIONS(4658),
    [anon_sym_initial] = ACTIONS(4658),
    [anon_sym_assign] = ACTIONS(4658),
    [anon_sym_alias] = ACTIONS(4658),
    [anon_sym_always_comb] = ACTIONS(4658),
    [anon_sym_always_latch] = ACTIONS(4658),
    [anon_sym_always_ff] = ACTIONS(4658),
    [anon_sym_final] = ACTIONS(4658),
    [anon_sym_global] = ACTIONS(4658),
    [anon_sym_LPAREN_STAR] = ACTIONS(4656),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4656),
    [anon_sym_DOLLARunit] = ACTIONS(4656),
  },
  [4993] = {
    [sym_simple_identifier] = ACTIONS(6637),
    [anon_sym_wire] = ACTIONS(6637),
    [anon_sym_tri] = ACTIONS(6637),
    [anon_sym_tri0] = ACTIONS(6637),
    [anon_sym_tri1] = ACTIONS(6637),
    [anon_sym_wand] = ACTIONS(6637),
    [anon_sym_triand] = ACTIONS(6637),
    [anon_sym_wor] = ACTIONS(6637),
    [anon_sym_trior] = ACTIONS(6637),
    [anon_sym_trireg] = ACTIONS(6637),
    [anon_sym_uwire] = ACTIONS(6637),
    [anon_sym_SEMI] = ACTIONS(6639),
    [anon_sym_extern] = ACTIONS(6637),
    [anon_sym_interface] = ACTIONS(6637),
    [anon_sym_checker] = ACTIONS(6637),
    [anon_sym_virtual] = ACTIONS(6637),
    [anon_sym_class] = ACTIONS(6637),
    [anon_sym_type] = ACTIONS(6637),
    [anon_sym_DOLLARfatal] = ACTIONS(6639),
    [anon_sym_DOLLARerror] = ACTIONS(6639),
    [anon_sym_DOLLARwarning] = ACTIONS(6639),
    [anon_sym_DOLLARinfo] = ACTIONS(6639),
    [anon_sym_default] = ACTIONS(6637),
    [anon_sym_clocking] = ACTIONS(6637),
    [anon_sym_defparam] = ACTIONS(6637),
    [anon_sym_bind] = ACTIONS(6637),
    [anon_sym_rand] = ACTIONS(6637),
    [anon_sym_const] = ACTIONS(6637),
    [anon_sym_function] = ACTIONS(6637),
    [anon_sym_static] = ACTIONS(6637),
    [anon_sym_constraint] = ACTIONS(6637),
    [anon_sym_if] = ACTIONS(6637),
    [anon_sym_else] = ACTIONS(6637),
    [anon_sym_LBRACK] = ACTIONS(6639),
    [anon_sym_localparam] = ACTIONS(6637),
    [anon_sym_parameter] = ACTIONS(6637),
    [anon_sym_var] = ACTIONS(6637),
    [anon_sym_import] = ACTIONS(6637),
    [anon_sym_export] = ACTIONS(6637),
    [anon_sym_genvar] = ACTIONS(6637),
    [anon_sym_interconnect] = ACTIONS(6637),
    [anon_sym_typedef] = ACTIONS(6637),
    [anon_sym_enum] = ACTIONS(6637),
    [anon_sym_struct] = ACTIONS(6637),
    [anon_sym_union] = ACTIONS(6637),
    [anon_sym_nettype] = ACTIONS(6637),
    [anon_sym_automatic] = ACTIONS(6637),
    [anon_sym_string] = ACTIONS(6637),
    [anon_sym_chandle] = ACTIONS(6637),
    [anon_sym_event] = ACTIONS(6637),
    [anon_sym_byte] = ACTIONS(6637),
    [anon_sym_shortint] = ACTIONS(6637),
    [anon_sym_int] = ACTIONS(6637),
    [anon_sym_longint] = ACTIONS(6637),
    [anon_sym_integer] = ACTIONS(6637),
    [anon_sym_time] = ACTIONS(6637),
    [anon_sym_bit] = ACTIONS(6637),
    [anon_sym_logic] = ACTIONS(6637),
    [anon_sym_reg] = ACTIONS(6637),
    [anon_sym_shortreal] = ACTIONS(6637),
    [anon_sym_real] = ACTIONS(6637),
    [anon_sym_realtime] = ACTIONS(6637),
    [anon_sym_supply0] = ACTIONS(6637),
    [anon_sym_supply1] = ACTIONS(6637),
    [anon_sym_signed] = ACTIONS(6637),
    [anon_sym_unsigned] = ACTIONS(6637),
    [anon_sym_task] = ACTIONS(6637),
    [anon_sym_assert] = ACTIONS(6637),
    [anon_sym_property] = ACTIONS(6637),
    [anon_sym_assume] = ACTIONS(6637),
    [anon_sym_cover] = ACTIONS(6637),
    [anon_sym_sequence] = ACTIONS(6637),
    [anon_sym_restrict] = ACTIONS(6637),
    [anon_sym_not] = ACTIONS(6637),
    [anon_sym_or] = ACTIONS(6637),
    [anon_sym_and] = ACTIONS(6637),
    [anon_sym_case] = ACTIONS(6637),
    [anon_sym_always] = ACTIONS(6637),
    [anon_sym_covergroup] = ACTIONS(6637),
    [anon_sym_let] = ACTIONS(6637),
    [anon_sym_pulldown] = ACTIONS(6637),
    [anon_sym_pullup] = ACTIONS(6637),
    [anon_sym_cmos] = ACTIONS(6637),
    [anon_sym_rcmos] = ACTIONS(6637),
    [anon_sym_bufif0] = ACTIONS(6637),
    [anon_sym_bufif1] = ACTIONS(6637),
    [anon_sym_notif0] = ACTIONS(6637),
    [anon_sym_notif1] = ACTIONS(6637),
    [anon_sym_nmos] = ACTIONS(6637),
    [anon_sym_pmos] = ACTIONS(6637),
    [anon_sym_rnmos] = ACTIONS(6637),
    [anon_sym_rpmos] = ACTIONS(6637),
    [anon_sym_nand] = ACTIONS(6637),
    [anon_sym_nor] = ACTIONS(6637),
    [anon_sym_xor] = ACTIONS(6637),
    [anon_sym_xnor] = ACTIONS(6637),
    [anon_sym_buf] = ACTIONS(6637),
    [anon_sym_tranif0] = ACTIONS(6637),
    [anon_sym_tranif1] = ACTIONS(6637),
    [anon_sym_rtranif1] = ACTIONS(6637),
    [anon_sym_rtranif0] = ACTIONS(6637),
    [anon_sym_tran] = ACTIONS(6637),
    [anon_sym_rtran] = ACTIONS(6637),
    [anon_sym_generate] = ACTIONS(6637),
    [anon_sym_endgenerate] = ACTIONS(6637),
    [anon_sym_for] = ACTIONS(6637),
    [anon_sym_initial] = ACTIONS(6637),
    [anon_sym_assign] = ACTIONS(6637),
    [anon_sym_alias] = ACTIONS(6637),
    [anon_sym_always_comb] = ACTIONS(6637),
    [anon_sym_always_latch] = ACTIONS(6637),
    [anon_sym_always_ff] = ACTIONS(6637),
    [anon_sym_final] = ACTIONS(6637),
    [anon_sym_global] = ACTIONS(6637),
    [anon_sym_LPAREN_STAR] = ACTIONS(6639),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6639),
    [anon_sym_DOLLARunit] = ACTIONS(6639),
  },
  [4994] = {
    [sym_simple_identifier] = ACTIONS(6653),
    [anon_sym_wire] = ACTIONS(6653),
    [anon_sym_tri] = ACTIONS(6653),
    [anon_sym_tri0] = ACTIONS(6653),
    [anon_sym_tri1] = ACTIONS(6653),
    [anon_sym_wand] = ACTIONS(6653),
    [anon_sym_triand] = ACTIONS(6653),
    [anon_sym_wor] = ACTIONS(6653),
    [anon_sym_trior] = ACTIONS(6653),
    [anon_sym_trireg] = ACTIONS(6653),
    [anon_sym_uwire] = ACTIONS(6653),
    [anon_sym_SEMI] = ACTIONS(6655),
    [anon_sym_extern] = ACTIONS(6653),
    [anon_sym_interface] = ACTIONS(6653),
    [anon_sym_checker] = ACTIONS(6653),
    [anon_sym_virtual] = ACTIONS(6653),
    [anon_sym_class] = ACTIONS(6653),
    [anon_sym_type] = ACTIONS(6653),
    [anon_sym_DOLLARfatal] = ACTIONS(6655),
    [anon_sym_DOLLARerror] = ACTIONS(6655),
    [anon_sym_DOLLARwarning] = ACTIONS(6655),
    [anon_sym_DOLLARinfo] = ACTIONS(6655),
    [anon_sym_default] = ACTIONS(6653),
    [anon_sym_clocking] = ACTIONS(6653),
    [anon_sym_defparam] = ACTIONS(6653),
    [anon_sym_bind] = ACTIONS(6653),
    [anon_sym_rand] = ACTIONS(6653),
    [anon_sym_const] = ACTIONS(6653),
    [anon_sym_function] = ACTIONS(6653),
    [anon_sym_static] = ACTIONS(6653),
    [anon_sym_constraint] = ACTIONS(6653),
    [anon_sym_if] = ACTIONS(6653),
    [anon_sym_else] = ACTIONS(6653),
    [anon_sym_LBRACK] = ACTIONS(6655),
    [anon_sym_localparam] = ACTIONS(6653),
    [anon_sym_parameter] = ACTIONS(6653),
    [anon_sym_var] = ACTIONS(6653),
    [anon_sym_import] = ACTIONS(6653),
    [anon_sym_export] = ACTIONS(6653),
    [anon_sym_genvar] = ACTIONS(6653),
    [anon_sym_interconnect] = ACTIONS(6653),
    [anon_sym_typedef] = ACTIONS(6653),
    [anon_sym_enum] = ACTIONS(6653),
    [anon_sym_struct] = ACTIONS(6653),
    [anon_sym_union] = ACTIONS(6653),
    [anon_sym_nettype] = ACTIONS(6653),
    [anon_sym_automatic] = ACTIONS(6653),
    [anon_sym_string] = ACTIONS(6653),
    [anon_sym_chandle] = ACTIONS(6653),
    [anon_sym_event] = ACTIONS(6653),
    [anon_sym_byte] = ACTIONS(6653),
    [anon_sym_shortint] = ACTIONS(6653),
    [anon_sym_int] = ACTIONS(6653),
    [anon_sym_longint] = ACTIONS(6653),
    [anon_sym_integer] = ACTIONS(6653),
    [anon_sym_time] = ACTIONS(6653),
    [anon_sym_bit] = ACTIONS(6653),
    [anon_sym_logic] = ACTIONS(6653),
    [anon_sym_reg] = ACTIONS(6653),
    [anon_sym_shortreal] = ACTIONS(6653),
    [anon_sym_real] = ACTIONS(6653),
    [anon_sym_realtime] = ACTIONS(6653),
    [anon_sym_supply0] = ACTIONS(6653),
    [anon_sym_supply1] = ACTIONS(6653),
    [anon_sym_signed] = ACTIONS(6653),
    [anon_sym_unsigned] = ACTIONS(6653),
    [anon_sym_task] = ACTIONS(6653),
    [anon_sym_assert] = ACTIONS(6653),
    [anon_sym_property] = ACTIONS(6653),
    [anon_sym_assume] = ACTIONS(6653),
    [anon_sym_cover] = ACTIONS(6653),
    [anon_sym_sequence] = ACTIONS(6653),
    [anon_sym_restrict] = ACTIONS(6653),
    [anon_sym_not] = ACTIONS(6653),
    [anon_sym_or] = ACTIONS(6653),
    [anon_sym_and] = ACTIONS(6653),
    [anon_sym_case] = ACTIONS(6653),
    [anon_sym_always] = ACTIONS(6653),
    [anon_sym_covergroup] = ACTIONS(6653),
    [anon_sym_let] = ACTIONS(6653),
    [anon_sym_pulldown] = ACTIONS(6653),
    [anon_sym_pullup] = ACTIONS(6653),
    [anon_sym_cmos] = ACTIONS(6653),
    [anon_sym_rcmos] = ACTIONS(6653),
    [anon_sym_bufif0] = ACTIONS(6653),
    [anon_sym_bufif1] = ACTIONS(6653),
    [anon_sym_notif0] = ACTIONS(6653),
    [anon_sym_notif1] = ACTIONS(6653),
    [anon_sym_nmos] = ACTIONS(6653),
    [anon_sym_pmos] = ACTIONS(6653),
    [anon_sym_rnmos] = ACTIONS(6653),
    [anon_sym_rpmos] = ACTIONS(6653),
    [anon_sym_nand] = ACTIONS(6653),
    [anon_sym_nor] = ACTIONS(6653),
    [anon_sym_xor] = ACTIONS(6653),
    [anon_sym_xnor] = ACTIONS(6653),
    [anon_sym_buf] = ACTIONS(6653),
    [anon_sym_tranif0] = ACTIONS(6653),
    [anon_sym_tranif1] = ACTIONS(6653),
    [anon_sym_rtranif1] = ACTIONS(6653),
    [anon_sym_rtranif0] = ACTIONS(6653),
    [anon_sym_tran] = ACTIONS(6653),
    [anon_sym_rtran] = ACTIONS(6653),
    [anon_sym_generate] = ACTIONS(6653),
    [anon_sym_endgenerate] = ACTIONS(6653),
    [anon_sym_for] = ACTIONS(6653),
    [anon_sym_initial] = ACTIONS(6653),
    [anon_sym_assign] = ACTIONS(6653),
    [anon_sym_alias] = ACTIONS(6653),
    [anon_sym_always_comb] = ACTIONS(6653),
    [anon_sym_always_latch] = ACTIONS(6653),
    [anon_sym_always_ff] = ACTIONS(6653),
    [anon_sym_final] = ACTIONS(6653),
    [anon_sym_global] = ACTIONS(6653),
    [anon_sym_LPAREN_STAR] = ACTIONS(6655),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6655),
    [anon_sym_DOLLARunit] = ACTIONS(6655),
  },
  [4995] = {
    [sym_simple_identifier] = ACTIONS(6657),
    [anon_sym_wire] = ACTIONS(6657),
    [anon_sym_tri] = ACTIONS(6657),
    [anon_sym_tri0] = ACTIONS(6657),
    [anon_sym_tri1] = ACTIONS(6657),
    [anon_sym_wand] = ACTIONS(6657),
    [anon_sym_triand] = ACTIONS(6657),
    [anon_sym_wor] = ACTIONS(6657),
    [anon_sym_trior] = ACTIONS(6657),
    [anon_sym_trireg] = ACTIONS(6657),
    [anon_sym_uwire] = ACTIONS(6657),
    [anon_sym_SEMI] = ACTIONS(6659),
    [anon_sym_extern] = ACTIONS(6657),
    [anon_sym_interface] = ACTIONS(6657),
    [anon_sym_checker] = ACTIONS(6657),
    [anon_sym_virtual] = ACTIONS(6657),
    [anon_sym_class] = ACTIONS(6657),
    [anon_sym_type] = ACTIONS(6657),
    [anon_sym_DOLLARfatal] = ACTIONS(6659),
    [anon_sym_DOLLARerror] = ACTIONS(6659),
    [anon_sym_DOLLARwarning] = ACTIONS(6659),
    [anon_sym_DOLLARinfo] = ACTIONS(6659),
    [anon_sym_default] = ACTIONS(6657),
    [anon_sym_clocking] = ACTIONS(6657),
    [anon_sym_defparam] = ACTIONS(6657),
    [anon_sym_bind] = ACTIONS(6657),
    [anon_sym_rand] = ACTIONS(6657),
    [anon_sym_const] = ACTIONS(6657),
    [anon_sym_function] = ACTIONS(6657),
    [anon_sym_static] = ACTIONS(6657),
    [anon_sym_constraint] = ACTIONS(6657),
    [anon_sym_if] = ACTIONS(6657),
    [anon_sym_else] = ACTIONS(6657),
    [anon_sym_LBRACK] = ACTIONS(6659),
    [anon_sym_localparam] = ACTIONS(6657),
    [anon_sym_parameter] = ACTIONS(6657),
    [anon_sym_var] = ACTIONS(6657),
    [anon_sym_import] = ACTIONS(6657),
    [anon_sym_export] = ACTIONS(6657),
    [anon_sym_genvar] = ACTIONS(6657),
    [anon_sym_interconnect] = ACTIONS(6657),
    [anon_sym_typedef] = ACTIONS(6657),
    [anon_sym_enum] = ACTIONS(6657),
    [anon_sym_struct] = ACTIONS(6657),
    [anon_sym_union] = ACTIONS(6657),
    [anon_sym_nettype] = ACTIONS(6657),
    [anon_sym_automatic] = ACTIONS(6657),
    [anon_sym_string] = ACTIONS(6657),
    [anon_sym_chandle] = ACTIONS(6657),
    [anon_sym_event] = ACTIONS(6657),
    [anon_sym_byte] = ACTIONS(6657),
    [anon_sym_shortint] = ACTIONS(6657),
    [anon_sym_int] = ACTIONS(6657),
    [anon_sym_longint] = ACTIONS(6657),
    [anon_sym_integer] = ACTIONS(6657),
    [anon_sym_time] = ACTIONS(6657),
    [anon_sym_bit] = ACTIONS(6657),
    [anon_sym_logic] = ACTIONS(6657),
    [anon_sym_reg] = ACTIONS(6657),
    [anon_sym_shortreal] = ACTIONS(6657),
    [anon_sym_real] = ACTIONS(6657),
    [anon_sym_realtime] = ACTIONS(6657),
    [anon_sym_supply0] = ACTIONS(6657),
    [anon_sym_supply1] = ACTIONS(6657),
    [anon_sym_signed] = ACTIONS(6657),
    [anon_sym_unsigned] = ACTIONS(6657),
    [anon_sym_task] = ACTIONS(6657),
    [anon_sym_assert] = ACTIONS(6657),
    [anon_sym_property] = ACTIONS(6657),
    [anon_sym_assume] = ACTIONS(6657),
    [anon_sym_cover] = ACTIONS(6657),
    [anon_sym_sequence] = ACTIONS(6657),
    [anon_sym_restrict] = ACTIONS(6657),
    [anon_sym_not] = ACTIONS(6657),
    [anon_sym_or] = ACTIONS(6657),
    [anon_sym_and] = ACTIONS(6657),
    [anon_sym_case] = ACTIONS(6657),
    [anon_sym_always] = ACTIONS(6657),
    [anon_sym_covergroup] = ACTIONS(6657),
    [anon_sym_let] = ACTIONS(6657),
    [anon_sym_pulldown] = ACTIONS(6657),
    [anon_sym_pullup] = ACTIONS(6657),
    [anon_sym_cmos] = ACTIONS(6657),
    [anon_sym_rcmos] = ACTIONS(6657),
    [anon_sym_bufif0] = ACTIONS(6657),
    [anon_sym_bufif1] = ACTIONS(6657),
    [anon_sym_notif0] = ACTIONS(6657),
    [anon_sym_notif1] = ACTIONS(6657),
    [anon_sym_nmos] = ACTIONS(6657),
    [anon_sym_pmos] = ACTIONS(6657),
    [anon_sym_rnmos] = ACTIONS(6657),
    [anon_sym_rpmos] = ACTIONS(6657),
    [anon_sym_nand] = ACTIONS(6657),
    [anon_sym_nor] = ACTIONS(6657),
    [anon_sym_xor] = ACTIONS(6657),
    [anon_sym_xnor] = ACTIONS(6657),
    [anon_sym_buf] = ACTIONS(6657),
    [anon_sym_tranif0] = ACTIONS(6657),
    [anon_sym_tranif1] = ACTIONS(6657),
    [anon_sym_rtranif1] = ACTIONS(6657),
    [anon_sym_rtranif0] = ACTIONS(6657),
    [anon_sym_tran] = ACTIONS(6657),
    [anon_sym_rtran] = ACTIONS(6657),
    [anon_sym_generate] = ACTIONS(6657),
    [anon_sym_endgenerate] = ACTIONS(6657),
    [anon_sym_for] = ACTIONS(6657),
    [anon_sym_initial] = ACTIONS(6657),
    [anon_sym_assign] = ACTIONS(6657),
    [anon_sym_alias] = ACTIONS(6657),
    [anon_sym_always_comb] = ACTIONS(6657),
    [anon_sym_always_latch] = ACTIONS(6657),
    [anon_sym_always_ff] = ACTIONS(6657),
    [anon_sym_final] = ACTIONS(6657),
    [anon_sym_global] = ACTIONS(6657),
    [anon_sym_LPAREN_STAR] = ACTIONS(6659),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6659),
    [anon_sym_DOLLARunit] = ACTIONS(6659),
  },
  [4996] = {
    [sym_simple_identifier] = ACTIONS(5226),
    [anon_sym_wire] = ACTIONS(5226),
    [anon_sym_tri] = ACTIONS(5226),
    [anon_sym_tri0] = ACTIONS(5226),
    [anon_sym_tri1] = ACTIONS(5226),
    [anon_sym_wand] = ACTIONS(5226),
    [anon_sym_triand] = ACTIONS(5226),
    [anon_sym_wor] = ACTIONS(5226),
    [anon_sym_trior] = ACTIONS(5226),
    [anon_sym_trireg] = ACTIONS(5226),
    [anon_sym_uwire] = ACTIONS(5226),
    [anon_sym_SEMI] = ACTIONS(5224),
    [anon_sym_extern] = ACTIONS(5226),
    [anon_sym_interface] = ACTIONS(5226),
    [anon_sym_checker] = ACTIONS(5226),
    [anon_sym_virtual] = ACTIONS(5226),
    [anon_sym_class] = ACTIONS(5226),
    [anon_sym_type] = ACTIONS(5226),
    [anon_sym_DOLLARfatal] = ACTIONS(5224),
    [anon_sym_DOLLARerror] = ACTIONS(5224),
    [anon_sym_DOLLARwarning] = ACTIONS(5224),
    [anon_sym_DOLLARinfo] = ACTIONS(5224),
    [anon_sym_default] = ACTIONS(5226),
    [anon_sym_clocking] = ACTIONS(5226),
    [anon_sym_defparam] = ACTIONS(5226),
    [anon_sym_bind] = ACTIONS(5226),
    [anon_sym_rand] = ACTIONS(5226),
    [anon_sym_const] = ACTIONS(5226),
    [anon_sym_function] = ACTIONS(5226),
    [anon_sym_static] = ACTIONS(5226),
    [anon_sym_constraint] = ACTIONS(5226),
    [anon_sym_if] = ACTIONS(5226),
    [anon_sym_else] = ACTIONS(5226),
    [anon_sym_LBRACK] = ACTIONS(5224),
    [anon_sym_localparam] = ACTIONS(5226),
    [anon_sym_parameter] = ACTIONS(5226),
    [anon_sym_var] = ACTIONS(5226),
    [anon_sym_import] = ACTIONS(5226),
    [anon_sym_export] = ACTIONS(5226),
    [anon_sym_genvar] = ACTIONS(5226),
    [anon_sym_interconnect] = ACTIONS(5226),
    [anon_sym_typedef] = ACTIONS(5226),
    [anon_sym_enum] = ACTIONS(5226),
    [anon_sym_struct] = ACTIONS(5226),
    [anon_sym_union] = ACTIONS(5226),
    [anon_sym_nettype] = ACTIONS(5226),
    [anon_sym_automatic] = ACTIONS(5226),
    [anon_sym_string] = ACTIONS(5226),
    [anon_sym_chandle] = ACTIONS(5226),
    [anon_sym_event] = ACTIONS(5226),
    [anon_sym_byte] = ACTIONS(5226),
    [anon_sym_shortint] = ACTIONS(5226),
    [anon_sym_int] = ACTIONS(5226),
    [anon_sym_longint] = ACTIONS(5226),
    [anon_sym_integer] = ACTIONS(5226),
    [anon_sym_time] = ACTIONS(5226),
    [anon_sym_bit] = ACTIONS(5226),
    [anon_sym_logic] = ACTIONS(5226),
    [anon_sym_reg] = ACTIONS(5226),
    [anon_sym_shortreal] = ACTIONS(5226),
    [anon_sym_real] = ACTIONS(5226),
    [anon_sym_realtime] = ACTIONS(5226),
    [anon_sym_supply0] = ACTIONS(5226),
    [anon_sym_supply1] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5226),
    [anon_sym_unsigned] = ACTIONS(5226),
    [anon_sym_task] = ACTIONS(5226),
    [anon_sym_assert] = ACTIONS(5226),
    [anon_sym_property] = ACTIONS(5226),
    [anon_sym_assume] = ACTIONS(5226),
    [anon_sym_cover] = ACTIONS(5226),
    [anon_sym_sequence] = ACTIONS(5226),
    [anon_sym_restrict] = ACTIONS(5226),
    [anon_sym_not] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5226),
    [anon_sym_and] = ACTIONS(5226),
    [anon_sym_case] = ACTIONS(5226),
    [anon_sym_always] = ACTIONS(5226),
    [anon_sym_covergroup] = ACTIONS(5226),
    [anon_sym_end] = ACTIONS(5226),
    [anon_sym_let] = ACTIONS(5226),
    [anon_sym_pulldown] = ACTIONS(5226),
    [anon_sym_pullup] = ACTIONS(5226),
    [anon_sym_cmos] = ACTIONS(5226),
    [anon_sym_rcmos] = ACTIONS(5226),
    [anon_sym_bufif0] = ACTIONS(5226),
    [anon_sym_bufif1] = ACTIONS(5226),
    [anon_sym_notif0] = ACTIONS(5226),
    [anon_sym_notif1] = ACTIONS(5226),
    [anon_sym_nmos] = ACTIONS(5226),
    [anon_sym_pmos] = ACTIONS(5226),
    [anon_sym_rnmos] = ACTIONS(5226),
    [anon_sym_rpmos] = ACTIONS(5226),
    [anon_sym_nand] = ACTIONS(5226),
    [anon_sym_nor] = ACTIONS(5226),
    [anon_sym_xor] = ACTIONS(5226),
    [anon_sym_xnor] = ACTIONS(5226),
    [anon_sym_buf] = ACTIONS(5226),
    [anon_sym_tranif0] = ACTIONS(5226),
    [anon_sym_tranif1] = ACTIONS(5226),
    [anon_sym_rtranif1] = ACTIONS(5226),
    [anon_sym_rtranif0] = ACTIONS(5226),
    [anon_sym_tran] = ACTIONS(5226),
    [anon_sym_rtran] = ACTIONS(5226),
    [anon_sym_generate] = ACTIONS(5226),
    [anon_sym_for] = ACTIONS(5226),
    [anon_sym_initial] = ACTIONS(5226),
    [anon_sym_assign] = ACTIONS(5226),
    [anon_sym_alias] = ACTIONS(5226),
    [anon_sym_always_comb] = ACTIONS(5226),
    [anon_sym_always_latch] = ACTIONS(5226),
    [anon_sym_always_ff] = ACTIONS(5226),
    [anon_sym_final] = ACTIONS(5226),
    [anon_sym_global] = ACTIONS(5226),
    [anon_sym_LPAREN_STAR] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5224),
    [anon_sym_DOLLARunit] = ACTIONS(5224),
  },
  [4997] = {
    [sym_simple_identifier] = ACTIONS(4768),
    [anon_sym_wire] = ACTIONS(4768),
    [anon_sym_tri] = ACTIONS(4768),
    [anon_sym_tri0] = ACTIONS(4768),
    [anon_sym_tri1] = ACTIONS(4768),
    [anon_sym_wand] = ACTIONS(4768),
    [anon_sym_triand] = ACTIONS(4768),
    [anon_sym_wor] = ACTIONS(4768),
    [anon_sym_trior] = ACTIONS(4768),
    [anon_sym_trireg] = ACTIONS(4768),
    [anon_sym_uwire] = ACTIONS(4768),
    [anon_sym_SEMI] = ACTIONS(4766),
    [anon_sym_extern] = ACTIONS(4768),
    [anon_sym_interface] = ACTIONS(4768),
    [anon_sym_checker] = ACTIONS(4768),
    [anon_sym_virtual] = ACTIONS(4768),
    [anon_sym_class] = ACTIONS(4768),
    [anon_sym_type] = ACTIONS(4768),
    [anon_sym_DOLLARfatal] = ACTIONS(4766),
    [anon_sym_DOLLARerror] = ACTIONS(4766),
    [anon_sym_DOLLARwarning] = ACTIONS(4766),
    [anon_sym_DOLLARinfo] = ACTIONS(4766),
    [anon_sym_default] = ACTIONS(4768),
    [anon_sym_clocking] = ACTIONS(4768),
    [anon_sym_defparam] = ACTIONS(4768),
    [anon_sym_bind] = ACTIONS(4768),
    [anon_sym_rand] = ACTIONS(4768),
    [anon_sym_const] = ACTIONS(4768),
    [anon_sym_function] = ACTIONS(4768),
    [anon_sym_static] = ACTIONS(4768),
    [anon_sym_constraint] = ACTIONS(4768),
    [anon_sym_if] = ACTIONS(4768),
    [anon_sym_else] = ACTIONS(4768),
    [anon_sym_LBRACK] = ACTIONS(4766),
    [anon_sym_localparam] = ACTIONS(4768),
    [anon_sym_parameter] = ACTIONS(4768),
    [anon_sym_var] = ACTIONS(4768),
    [anon_sym_import] = ACTIONS(4768),
    [anon_sym_export] = ACTIONS(4768),
    [anon_sym_genvar] = ACTIONS(4768),
    [anon_sym_interconnect] = ACTIONS(4768),
    [anon_sym_typedef] = ACTIONS(4768),
    [anon_sym_enum] = ACTIONS(4768),
    [anon_sym_struct] = ACTIONS(4768),
    [anon_sym_union] = ACTIONS(4768),
    [anon_sym_nettype] = ACTIONS(4768),
    [anon_sym_automatic] = ACTIONS(4768),
    [anon_sym_string] = ACTIONS(4768),
    [anon_sym_chandle] = ACTIONS(4768),
    [anon_sym_event] = ACTIONS(4768),
    [anon_sym_byte] = ACTIONS(4768),
    [anon_sym_shortint] = ACTIONS(4768),
    [anon_sym_int] = ACTIONS(4768),
    [anon_sym_longint] = ACTIONS(4768),
    [anon_sym_integer] = ACTIONS(4768),
    [anon_sym_time] = ACTIONS(4768),
    [anon_sym_bit] = ACTIONS(4768),
    [anon_sym_logic] = ACTIONS(4768),
    [anon_sym_reg] = ACTIONS(4768),
    [anon_sym_shortreal] = ACTIONS(4768),
    [anon_sym_real] = ACTIONS(4768),
    [anon_sym_realtime] = ACTIONS(4768),
    [anon_sym_supply0] = ACTIONS(4768),
    [anon_sym_supply1] = ACTIONS(4768),
    [anon_sym_signed] = ACTIONS(4768),
    [anon_sym_unsigned] = ACTIONS(4768),
    [anon_sym_task] = ACTIONS(4768),
    [anon_sym_assert] = ACTIONS(4768),
    [anon_sym_property] = ACTIONS(4768),
    [anon_sym_assume] = ACTIONS(4768),
    [anon_sym_cover] = ACTIONS(4768),
    [anon_sym_sequence] = ACTIONS(4768),
    [anon_sym_restrict] = ACTIONS(4768),
    [anon_sym_not] = ACTIONS(4768),
    [anon_sym_or] = ACTIONS(4768),
    [anon_sym_and] = ACTIONS(4768),
    [anon_sym_case] = ACTIONS(4768),
    [anon_sym_always] = ACTIONS(4768),
    [anon_sym_covergroup] = ACTIONS(4768),
    [anon_sym_let] = ACTIONS(4768),
    [anon_sym_pulldown] = ACTIONS(4768),
    [anon_sym_pullup] = ACTIONS(4768),
    [anon_sym_cmos] = ACTIONS(4768),
    [anon_sym_rcmos] = ACTIONS(4768),
    [anon_sym_bufif0] = ACTIONS(4768),
    [anon_sym_bufif1] = ACTIONS(4768),
    [anon_sym_notif0] = ACTIONS(4768),
    [anon_sym_notif1] = ACTIONS(4768),
    [anon_sym_nmos] = ACTIONS(4768),
    [anon_sym_pmos] = ACTIONS(4768),
    [anon_sym_rnmos] = ACTIONS(4768),
    [anon_sym_rpmos] = ACTIONS(4768),
    [anon_sym_nand] = ACTIONS(4768),
    [anon_sym_nor] = ACTIONS(4768),
    [anon_sym_xor] = ACTIONS(4768),
    [anon_sym_xnor] = ACTIONS(4768),
    [anon_sym_buf] = ACTIONS(4768),
    [anon_sym_tranif0] = ACTIONS(4768),
    [anon_sym_tranif1] = ACTIONS(4768),
    [anon_sym_rtranif1] = ACTIONS(4768),
    [anon_sym_rtranif0] = ACTIONS(4768),
    [anon_sym_tran] = ACTIONS(4768),
    [anon_sym_rtran] = ACTIONS(4768),
    [anon_sym_generate] = ACTIONS(4768),
    [anon_sym_endgenerate] = ACTIONS(4768),
    [anon_sym_for] = ACTIONS(4768),
    [anon_sym_initial] = ACTIONS(4768),
    [anon_sym_assign] = ACTIONS(4768),
    [anon_sym_alias] = ACTIONS(4768),
    [anon_sym_always_comb] = ACTIONS(4768),
    [anon_sym_always_latch] = ACTIONS(4768),
    [anon_sym_always_ff] = ACTIONS(4768),
    [anon_sym_final] = ACTIONS(4768),
    [anon_sym_global] = ACTIONS(4768),
    [anon_sym_LPAREN_STAR] = ACTIONS(4766),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4766),
    [anon_sym_DOLLARunit] = ACTIONS(4766),
  },
  [4998] = {
    [sym_simple_identifier] = ACTIONS(6311),
    [anon_sym_wire] = ACTIONS(6311),
    [anon_sym_tri] = ACTIONS(6311),
    [anon_sym_tri0] = ACTIONS(6311),
    [anon_sym_tri1] = ACTIONS(6311),
    [anon_sym_wand] = ACTIONS(6311),
    [anon_sym_triand] = ACTIONS(6311),
    [anon_sym_wor] = ACTIONS(6311),
    [anon_sym_trior] = ACTIONS(6311),
    [anon_sym_trireg] = ACTIONS(6311),
    [anon_sym_uwire] = ACTIONS(6311),
    [anon_sym_SEMI] = ACTIONS(6313),
    [anon_sym_extern] = ACTIONS(6311),
    [anon_sym_interface] = ACTIONS(6311),
    [anon_sym_checker] = ACTIONS(6311),
    [anon_sym_virtual] = ACTIONS(6311),
    [anon_sym_class] = ACTIONS(6311),
    [anon_sym_type] = ACTIONS(6311),
    [anon_sym_DOLLARfatal] = ACTIONS(6313),
    [anon_sym_DOLLARerror] = ACTIONS(6313),
    [anon_sym_DOLLARwarning] = ACTIONS(6313),
    [anon_sym_DOLLARinfo] = ACTIONS(6313),
    [anon_sym_default] = ACTIONS(6311),
    [anon_sym_clocking] = ACTIONS(6311),
    [anon_sym_defparam] = ACTIONS(6311),
    [anon_sym_bind] = ACTIONS(6311),
    [anon_sym_rand] = ACTIONS(6311),
    [anon_sym_const] = ACTIONS(6311),
    [anon_sym_function] = ACTIONS(6311),
    [anon_sym_static] = ACTIONS(6311),
    [anon_sym_constraint] = ACTIONS(6311),
    [anon_sym_if] = ACTIONS(6311),
    [anon_sym_else] = ACTIONS(6311),
    [anon_sym_LBRACK] = ACTIONS(6313),
    [anon_sym_localparam] = ACTIONS(6311),
    [anon_sym_parameter] = ACTIONS(6311),
    [anon_sym_var] = ACTIONS(6311),
    [anon_sym_import] = ACTIONS(6311),
    [anon_sym_export] = ACTIONS(6311),
    [anon_sym_genvar] = ACTIONS(6311),
    [anon_sym_interconnect] = ACTIONS(6311),
    [anon_sym_typedef] = ACTIONS(6311),
    [anon_sym_enum] = ACTIONS(6311),
    [anon_sym_struct] = ACTIONS(6311),
    [anon_sym_union] = ACTIONS(6311),
    [anon_sym_nettype] = ACTIONS(6311),
    [anon_sym_automatic] = ACTIONS(6311),
    [anon_sym_string] = ACTIONS(6311),
    [anon_sym_chandle] = ACTIONS(6311),
    [anon_sym_event] = ACTIONS(6311),
    [anon_sym_byte] = ACTIONS(6311),
    [anon_sym_shortint] = ACTIONS(6311),
    [anon_sym_int] = ACTIONS(6311),
    [anon_sym_longint] = ACTIONS(6311),
    [anon_sym_integer] = ACTIONS(6311),
    [anon_sym_time] = ACTIONS(6311),
    [anon_sym_bit] = ACTIONS(6311),
    [anon_sym_logic] = ACTIONS(6311),
    [anon_sym_reg] = ACTIONS(6311),
    [anon_sym_shortreal] = ACTIONS(6311),
    [anon_sym_real] = ACTIONS(6311),
    [anon_sym_realtime] = ACTIONS(6311),
    [anon_sym_supply0] = ACTIONS(6311),
    [anon_sym_supply1] = ACTIONS(6311),
    [anon_sym_signed] = ACTIONS(6311),
    [anon_sym_unsigned] = ACTIONS(6311),
    [anon_sym_task] = ACTIONS(6311),
    [anon_sym_assert] = ACTIONS(6311),
    [anon_sym_property] = ACTIONS(6311),
    [anon_sym_assume] = ACTIONS(6311),
    [anon_sym_cover] = ACTIONS(6311),
    [anon_sym_sequence] = ACTIONS(6311),
    [anon_sym_restrict] = ACTIONS(6311),
    [anon_sym_not] = ACTIONS(6311),
    [anon_sym_or] = ACTIONS(6311),
    [anon_sym_and] = ACTIONS(6311),
    [anon_sym_case] = ACTIONS(6311),
    [anon_sym_always] = ACTIONS(6311),
    [anon_sym_covergroup] = ACTIONS(6311),
    [anon_sym_end] = ACTIONS(6311),
    [anon_sym_let] = ACTIONS(6311),
    [anon_sym_pulldown] = ACTIONS(6311),
    [anon_sym_pullup] = ACTIONS(6311),
    [anon_sym_cmos] = ACTIONS(6311),
    [anon_sym_rcmos] = ACTIONS(6311),
    [anon_sym_bufif0] = ACTIONS(6311),
    [anon_sym_bufif1] = ACTIONS(6311),
    [anon_sym_notif0] = ACTIONS(6311),
    [anon_sym_notif1] = ACTIONS(6311),
    [anon_sym_nmos] = ACTIONS(6311),
    [anon_sym_pmos] = ACTIONS(6311),
    [anon_sym_rnmos] = ACTIONS(6311),
    [anon_sym_rpmos] = ACTIONS(6311),
    [anon_sym_nand] = ACTIONS(6311),
    [anon_sym_nor] = ACTIONS(6311),
    [anon_sym_xor] = ACTIONS(6311),
    [anon_sym_xnor] = ACTIONS(6311),
    [anon_sym_buf] = ACTIONS(6311),
    [anon_sym_tranif0] = ACTIONS(6311),
    [anon_sym_tranif1] = ACTIONS(6311),
    [anon_sym_rtranif1] = ACTIONS(6311),
    [anon_sym_rtranif0] = ACTIONS(6311),
    [anon_sym_tran] = ACTIONS(6311),
    [anon_sym_rtran] = ACTIONS(6311),
    [anon_sym_generate] = ACTIONS(6311),
    [anon_sym_for] = ACTIONS(6311),
    [anon_sym_initial] = ACTIONS(6311),
    [anon_sym_assign] = ACTIONS(6311),
    [anon_sym_alias] = ACTIONS(6311),
    [anon_sym_always_comb] = ACTIONS(6311),
    [anon_sym_always_latch] = ACTIONS(6311),
    [anon_sym_always_ff] = ACTIONS(6311),
    [anon_sym_final] = ACTIONS(6311),
    [anon_sym_global] = ACTIONS(6311),
    [anon_sym_LPAREN_STAR] = ACTIONS(6313),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6313),
    [anon_sym_DOLLARunit] = ACTIONS(6313),
  },
  [4999] = {
    [sym_simple_identifier] = ACTIONS(6283),
    [anon_sym_wire] = ACTIONS(6283),
    [anon_sym_tri] = ACTIONS(6283),
    [anon_sym_tri0] = ACTIONS(6283),
    [anon_sym_tri1] = ACTIONS(6283),
    [anon_sym_wand] = ACTIONS(6283),
    [anon_sym_triand] = ACTIONS(6283),
    [anon_sym_wor] = ACTIONS(6283),
    [anon_sym_trior] = ACTIONS(6283),
    [anon_sym_trireg] = ACTIONS(6283),
    [anon_sym_uwire] = ACTIONS(6283),
    [anon_sym_SEMI] = ACTIONS(6285),
    [anon_sym_extern] = ACTIONS(6283),
    [anon_sym_interface] = ACTIONS(6283),
    [anon_sym_checker] = ACTIONS(6283),
    [anon_sym_virtual] = ACTIONS(6283),
    [anon_sym_class] = ACTIONS(6283),
    [anon_sym_type] = ACTIONS(6283),
    [anon_sym_DOLLARfatal] = ACTIONS(6285),
    [anon_sym_DOLLARerror] = ACTIONS(6285),
    [anon_sym_DOLLARwarning] = ACTIONS(6285),
    [anon_sym_DOLLARinfo] = ACTIONS(6285),
    [anon_sym_default] = ACTIONS(6283),
    [anon_sym_clocking] = ACTIONS(6283),
    [anon_sym_defparam] = ACTIONS(6283),
    [anon_sym_bind] = ACTIONS(6283),
    [anon_sym_rand] = ACTIONS(6283),
    [anon_sym_const] = ACTIONS(6283),
    [anon_sym_function] = ACTIONS(6283),
    [anon_sym_static] = ACTIONS(6283),
    [anon_sym_constraint] = ACTIONS(6283),
    [anon_sym_if] = ACTIONS(6283),
    [anon_sym_else] = ACTIONS(6283),
    [anon_sym_LBRACK] = ACTIONS(6285),
    [anon_sym_localparam] = ACTIONS(6283),
    [anon_sym_parameter] = ACTIONS(6283),
    [anon_sym_var] = ACTIONS(6283),
    [anon_sym_import] = ACTIONS(6283),
    [anon_sym_export] = ACTIONS(6283),
    [anon_sym_genvar] = ACTIONS(6283),
    [anon_sym_interconnect] = ACTIONS(6283),
    [anon_sym_typedef] = ACTIONS(6283),
    [anon_sym_enum] = ACTIONS(6283),
    [anon_sym_struct] = ACTIONS(6283),
    [anon_sym_union] = ACTIONS(6283),
    [anon_sym_nettype] = ACTIONS(6283),
    [anon_sym_automatic] = ACTIONS(6283),
    [anon_sym_string] = ACTIONS(6283),
    [anon_sym_chandle] = ACTIONS(6283),
    [anon_sym_event] = ACTIONS(6283),
    [anon_sym_byte] = ACTIONS(6283),
    [anon_sym_shortint] = ACTIONS(6283),
    [anon_sym_int] = ACTIONS(6283),
    [anon_sym_longint] = ACTIONS(6283),
    [anon_sym_integer] = ACTIONS(6283),
    [anon_sym_time] = ACTIONS(6283),
    [anon_sym_bit] = ACTIONS(6283),
    [anon_sym_logic] = ACTIONS(6283),
    [anon_sym_reg] = ACTIONS(6283),
    [anon_sym_shortreal] = ACTIONS(6283),
    [anon_sym_real] = ACTIONS(6283),
    [anon_sym_realtime] = ACTIONS(6283),
    [anon_sym_supply0] = ACTIONS(6283),
    [anon_sym_supply1] = ACTIONS(6283),
    [anon_sym_signed] = ACTIONS(6283),
    [anon_sym_unsigned] = ACTIONS(6283),
    [anon_sym_task] = ACTIONS(6283),
    [anon_sym_assert] = ACTIONS(6283),
    [anon_sym_property] = ACTIONS(6283),
    [anon_sym_assume] = ACTIONS(6283),
    [anon_sym_cover] = ACTIONS(6283),
    [anon_sym_sequence] = ACTIONS(6283),
    [anon_sym_restrict] = ACTIONS(6283),
    [anon_sym_not] = ACTIONS(6283),
    [anon_sym_or] = ACTIONS(6283),
    [anon_sym_and] = ACTIONS(6283),
    [anon_sym_case] = ACTIONS(6283),
    [anon_sym_always] = ACTIONS(6283),
    [anon_sym_covergroup] = ACTIONS(6283),
    [anon_sym_let] = ACTIONS(6283),
    [anon_sym_pulldown] = ACTIONS(6283),
    [anon_sym_pullup] = ACTIONS(6283),
    [anon_sym_cmos] = ACTIONS(6283),
    [anon_sym_rcmos] = ACTIONS(6283),
    [anon_sym_bufif0] = ACTIONS(6283),
    [anon_sym_bufif1] = ACTIONS(6283),
    [anon_sym_notif0] = ACTIONS(6283),
    [anon_sym_notif1] = ACTIONS(6283),
    [anon_sym_nmos] = ACTIONS(6283),
    [anon_sym_pmos] = ACTIONS(6283),
    [anon_sym_rnmos] = ACTIONS(6283),
    [anon_sym_rpmos] = ACTIONS(6283),
    [anon_sym_nand] = ACTIONS(6283),
    [anon_sym_nor] = ACTIONS(6283),
    [anon_sym_xor] = ACTIONS(6283),
    [anon_sym_xnor] = ACTIONS(6283),
    [anon_sym_buf] = ACTIONS(6283),
    [anon_sym_tranif0] = ACTIONS(6283),
    [anon_sym_tranif1] = ACTIONS(6283),
    [anon_sym_rtranif1] = ACTIONS(6283),
    [anon_sym_rtranif0] = ACTIONS(6283),
    [anon_sym_tran] = ACTIONS(6283),
    [anon_sym_rtran] = ACTIONS(6283),
    [anon_sym_generate] = ACTIONS(6283),
    [anon_sym_endgenerate] = ACTIONS(6283),
    [anon_sym_for] = ACTIONS(6283),
    [anon_sym_initial] = ACTIONS(6283),
    [anon_sym_assign] = ACTIONS(6283),
    [anon_sym_alias] = ACTIONS(6283),
    [anon_sym_always_comb] = ACTIONS(6283),
    [anon_sym_always_latch] = ACTIONS(6283),
    [anon_sym_always_ff] = ACTIONS(6283),
    [anon_sym_final] = ACTIONS(6283),
    [anon_sym_global] = ACTIONS(6283),
    [anon_sym_LPAREN_STAR] = ACTIONS(6285),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6285),
    [anon_sym_DOLLARunit] = ACTIONS(6285),
  },
  [5000] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_rand] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_endgenerate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [5001] = {
    [sym_simple_identifier] = ACTIONS(6233),
    [anon_sym_wire] = ACTIONS(6233),
    [anon_sym_tri] = ACTIONS(6233),
    [anon_sym_tri0] = ACTIONS(6233),
    [anon_sym_tri1] = ACTIONS(6233),
    [anon_sym_wand] = ACTIONS(6233),
    [anon_sym_triand] = ACTIONS(6233),
    [anon_sym_wor] = ACTIONS(6233),
    [anon_sym_trior] = ACTIONS(6233),
    [anon_sym_trireg] = ACTIONS(6233),
    [anon_sym_uwire] = ACTIONS(6233),
    [anon_sym_SEMI] = ACTIONS(6235),
    [anon_sym_extern] = ACTIONS(6233),
    [anon_sym_interface] = ACTIONS(6233),
    [anon_sym_checker] = ACTIONS(6233),
    [anon_sym_virtual] = ACTIONS(6233),
    [anon_sym_class] = ACTIONS(6233),
    [anon_sym_type] = ACTIONS(6233),
    [anon_sym_DOLLARfatal] = ACTIONS(6235),
    [anon_sym_DOLLARerror] = ACTIONS(6235),
    [anon_sym_DOLLARwarning] = ACTIONS(6235),
    [anon_sym_DOLLARinfo] = ACTIONS(6235),
    [anon_sym_default] = ACTIONS(6233),
    [anon_sym_clocking] = ACTIONS(6233),
    [anon_sym_defparam] = ACTIONS(6233),
    [anon_sym_bind] = ACTIONS(6233),
    [anon_sym_rand] = ACTIONS(6233),
    [anon_sym_const] = ACTIONS(6233),
    [anon_sym_function] = ACTIONS(6233),
    [anon_sym_static] = ACTIONS(6233),
    [anon_sym_constraint] = ACTIONS(6233),
    [anon_sym_if] = ACTIONS(6233),
    [anon_sym_else] = ACTIONS(6233),
    [anon_sym_LBRACK] = ACTIONS(6235),
    [anon_sym_localparam] = ACTIONS(6233),
    [anon_sym_parameter] = ACTIONS(6233),
    [anon_sym_var] = ACTIONS(6233),
    [anon_sym_import] = ACTIONS(6233),
    [anon_sym_export] = ACTIONS(6233),
    [anon_sym_genvar] = ACTIONS(6233),
    [anon_sym_interconnect] = ACTIONS(6233),
    [anon_sym_typedef] = ACTIONS(6233),
    [anon_sym_enum] = ACTIONS(6233),
    [anon_sym_struct] = ACTIONS(6233),
    [anon_sym_union] = ACTIONS(6233),
    [anon_sym_nettype] = ACTIONS(6233),
    [anon_sym_automatic] = ACTIONS(6233),
    [anon_sym_string] = ACTIONS(6233),
    [anon_sym_chandle] = ACTIONS(6233),
    [anon_sym_event] = ACTIONS(6233),
    [anon_sym_byte] = ACTIONS(6233),
    [anon_sym_shortint] = ACTIONS(6233),
    [anon_sym_int] = ACTIONS(6233),
    [anon_sym_longint] = ACTIONS(6233),
    [anon_sym_integer] = ACTIONS(6233),
    [anon_sym_time] = ACTIONS(6233),
    [anon_sym_bit] = ACTIONS(6233),
    [anon_sym_logic] = ACTIONS(6233),
    [anon_sym_reg] = ACTIONS(6233),
    [anon_sym_shortreal] = ACTIONS(6233),
    [anon_sym_real] = ACTIONS(6233),
    [anon_sym_realtime] = ACTIONS(6233),
    [anon_sym_supply0] = ACTIONS(6233),
    [anon_sym_supply1] = ACTIONS(6233),
    [anon_sym_signed] = ACTIONS(6233),
    [anon_sym_unsigned] = ACTIONS(6233),
    [anon_sym_task] = ACTIONS(6233),
    [anon_sym_assert] = ACTIONS(6233),
    [anon_sym_property] = ACTIONS(6233),
    [anon_sym_assume] = ACTIONS(6233),
    [anon_sym_cover] = ACTIONS(6233),
    [anon_sym_sequence] = ACTIONS(6233),
    [anon_sym_restrict] = ACTIONS(6233),
    [anon_sym_not] = ACTIONS(6233),
    [anon_sym_or] = ACTIONS(6233),
    [anon_sym_and] = ACTIONS(6233),
    [anon_sym_case] = ACTIONS(6233),
    [anon_sym_always] = ACTIONS(6233),
    [anon_sym_covergroup] = ACTIONS(6233),
    [anon_sym_end] = ACTIONS(6233),
    [anon_sym_let] = ACTIONS(6233),
    [anon_sym_pulldown] = ACTIONS(6233),
    [anon_sym_pullup] = ACTIONS(6233),
    [anon_sym_cmos] = ACTIONS(6233),
    [anon_sym_rcmos] = ACTIONS(6233),
    [anon_sym_bufif0] = ACTIONS(6233),
    [anon_sym_bufif1] = ACTIONS(6233),
    [anon_sym_notif0] = ACTIONS(6233),
    [anon_sym_notif1] = ACTIONS(6233),
    [anon_sym_nmos] = ACTIONS(6233),
    [anon_sym_pmos] = ACTIONS(6233),
    [anon_sym_rnmos] = ACTIONS(6233),
    [anon_sym_rpmos] = ACTIONS(6233),
    [anon_sym_nand] = ACTIONS(6233),
    [anon_sym_nor] = ACTIONS(6233),
    [anon_sym_xor] = ACTIONS(6233),
    [anon_sym_xnor] = ACTIONS(6233),
    [anon_sym_buf] = ACTIONS(6233),
    [anon_sym_tranif0] = ACTIONS(6233),
    [anon_sym_tranif1] = ACTIONS(6233),
    [anon_sym_rtranif1] = ACTIONS(6233),
    [anon_sym_rtranif0] = ACTIONS(6233),
    [anon_sym_tran] = ACTIONS(6233),
    [anon_sym_rtran] = ACTIONS(6233),
    [anon_sym_generate] = ACTIONS(6233),
    [anon_sym_for] = ACTIONS(6233),
    [anon_sym_initial] = ACTIONS(6233),
    [anon_sym_assign] = ACTIONS(6233),
    [anon_sym_alias] = ACTIONS(6233),
    [anon_sym_always_comb] = ACTIONS(6233),
    [anon_sym_always_latch] = ACTIONS(6233),
    [anon_sym_always_ff] = ACTIONS(6233),
    [anon_sym_final] = ACTIONS(6233),
    [anon_sym_global] = ACTIONS(6233),
    [anon_sym_LPAREN_STAR] = ACTIONS(6235),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6235),
    [anon_sym_DOLLARunit] = ACTIONS(6235),
  },
  [5002] = {
    [sym_simple_identifier] = ACTIONS(6271),
    [anon_sym_wire] = ACTIONS(6271),
    [anon_sym_tri] = ACTIONS(6271),
    [anon_sym_tri0] = ACTIONS(6271),
    [anon_sym_tri1] = ACTIONS(6271),
    [anon_sym_wand] = ACTIONS(6271),
    [anon_sym_triand] = ACTIONS(6271),
    [anon_sym_wor] = ACTIONS(6271),
    [anon_sym_trior] = ACTIONS(6271),
    [anon_sym_trireg] = ACTIONS(6271),
    [anon_sym_uwire] = ACTIONS(6271),
    [anon_sym_SEMI] = ACTIONS(6273),
    [anon_sym_extern] = ACTIONS(6271),
    [anon_sym_interface] = ACTIONS(6271),
    [anon_sym_checker] = ACTIONS(6271),
    [anon_sym_virtual] = ACTIONS(6271),
    [anon_sym_class] = ACTIONS(6271),
    [anon_sym_type] = ACTIONS(6271),
    [anon_sym_DOLLARfatal] = ACTIONS(6273),
    [anon_sym_DOLLARerror] = ACTIONS(6273),
    [anon_sym_DOLLARwarning] = ACTIONS(6273),
    [anon_sym_DOLLARinfo] = ACTIONS(6273),
    [anon_sym_default] = ACTIONS(6271),
    [anon_sym_clocking] = ACTIONS(6271),
    [anon_sym_defparam] = ACTIONS(6271),
    [anon_sym_bind] = ACTIONS(6271),
    [anon_sym_rand] = ACTIONS(6271),
    [anon_sym_const] = ACTIONS(6271),
    [anon_sym_function] = ACTIONS(6271),
    [anon_sym_static] = ACTIONS(6271),
    [anon_sym_constraint] = ACTIONS(6271),
    [anon_sym_if] = ACTIONS(6271),
    [anon_sym_else] = ACTIONS(6271),
    [anon_sym_LBRACK] = ACTIONS(6273),
    [anon_sym_localparam] = ACTIONS(6271),
    [anon_sym_parameter] = ACTIONS(6271),
    [anon_sym_var] = ACTIONS(6271),
    [anon_sym_import] = ACTIONS(6271),
    [anon_sym_export] = ACTIONS(6271),
    [anon_sym_genvar] = ACTIONS(6271),
    [anon_sym_interconnect] = ACTIONS(6271),
    [anon_sym_typedef] = ACTIONS(6271),
    [anon_sym_enum] = ACTIONS(6271),
    [anon_sym_struct] = ACTIONS(6271),
    [anon_sym_union] = ACTIONS(6271),
    [anon_sym_nettype] = ACTIONS(6271),
    [anon_sym_automatic] = ACTIONS(6271),
    [anon_sym_string] = ACTIONS(6271),
    [anon_sym_chandle] = ACTIONS(6271),
    [anon_sym_event] = ACTIONS(6271),
    [anon_sym_byte] = ACTIONS(6271),
    [anon_sym_shortint] = ACTIONS(6271),
    [anon_sym_int] = ACTIONS(6271),
    [anon_sym_longint] = ACTIONS(6271),
    [anon_sym_integer] = ACTIONS(6271),
    [anon_sym_time] = ACTIONS(6271),
    [anon_sym_bit] = ACTIONS(6271),
    [anon_sym_logic] = ACTIONS(6271),
    [anon_sym_reg] = ACTIONS(6271),
    [anon_sym_shortreal] = ACTIONS(6271),
    [anon_sym_real] = ACTIONS(6271),
    [anon_sym_realtime] = ACTIONS(6271),
    [anon_sym_supply0] = ACTIONS(6271),
    [anon_sym_supply1] = ACTIONS(6271),
    [anon_sym_signed] = ACTIONS(6271),
    [anon_sym_unsigned] = ACTIONS(6271),
    [anon_sym_task] = ACTIONS(6271),
    [anon_sym_assert] = ACTIONS(6271),
    [anon_sym_property] = ACTIONS(6271),
    [anon_sym_assume] = ACTIONS(6271),
    [anon_sym_cover] = ACTIONS(6271),
    [anon_sym_sequence] = ACTIONS(6271),
    [anon_sym_restrict] = ACTIONS(6271),
    [anon_sym_not] = ACTIONS(6271),
    [anon_sym_or] = ACTIONS(6271),
    [anon_sym_and] = ACTIONS(6271),
    [anon_sym_case] = ACTIONS(6271),
    [anon_sym_always] = ACTIONS(6271),
    [anon_sym_covergroup] = ACTIONS(6271),
    [anon_sym_end] = ACTIONS(6271),
    [anon_sym_let] = ACTIONS(6271),
    [anon_sym_pulldown] = ACTIONS(6271),
    [anon_sym_pullup] = ACTIONS(6271),
    [anon_sym_cmos] = ACTIONS(6271),
    [anon_sym_rcmos] = ACTIONS(6271),
    [anon_sym_bufif0] = ACTIONS(6271),
    [anon_sym_bufif1] = ACTIONS(6271),
    [anon_sym_notif0] = ACTIONS(6271),
    [anon_sym_notif1] = ACTIONS(6271),
    [anon_sym_nmos] = ACTIONS(6271),
    [anon_sym_pmos] = ACTIONS(6271),
    [anon_sym_rnmos] = ACTIONS(6271),
    [anon_sym_rpmos] = ACTIONS(6271),
    [anon_sym_nand] = ACTIONS(6271),
    [anon_sym_nor] = ACTIONS(6271),
    [anon_sym_xor] = ACTIONS(6271),
    [anon_sym_xnor] = ACTIONS(6271),
    [anon_sym_buf] = ACTIONS(6271),
    [anon_sym_tranif0] = ACTIONS(6271),
    [anon_sym_tranif1] = ACTIONS(6271),
    [anon_sym_rtranif1] = ACTIONS(6271),
    [anon_sym_rtranif0] = ACTIONS(6271),
    [anon_sym_tran] = ACTIONS(6271),
    [anon_sym_rtran] = ACTIONS(6271),
    [anon_sym_generate] = ACTIONS(6271),
    [anon_sym_for] = ACTIONS(6271),
    [anon_sym_initial] = ACTIONS(6271),
    [anon_sym_assign] = ACTIONS(6271),
    [anon_sym_alias] = ACTIONS(6271),
    [anon_sym_always_comb] = ACTIONS(6271),
    [anon_sym_always_latch] = ACTIONS(6271),
    [anon_sym_always_ff] = ACTIONS(6271),
    [anon_sym_final] = ACTIONS(6271),
    [anon_sym_global] = ACTIONS(6271),
    [anon_sym_LPAREN_STAR] = ACTIONS(6273),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6273),
    [anon_sym_DOLLARunit] = ACTIONS(6273),
  },
  [5003] = {
    [sym_simple_identifier] = ACTIONS(4876),
    [anon_sym_wire] = ACTIONS(4876),
    [anon_sym_tri] = ACTIONS(4876),
    [anon_sym_tri0] = ACTIONS(4876),
    [anon_sym_tri1] = ACTIONS(4876),
    [anon_sym_wand] = ACTIONS(4876),
    [anon_sym_triand] = ACTIONS(4876),
    [anon_sym_wor] = ACTIONS(4876),
    [anon_sym_trior] = ACTIONS(4876),
    [anon_sym_trireg] = ACTIONS(4876),
    [anon_sym_uwire] = ACTIONS(4876),
    [anon_sym_SEMI] = ACTIONS(4874),
    [anon_sym_extern] = ACTIONS(4876),
    [anon_sym_interface] = ACTIONS(4876),
    [anon_sym_checker] = ACTIONS(4876),
    [anon_sym_virtual] = ACTIONS(4876),
    [anon_sym_class] = ACTIONS(4876),
    [anon_sym_type] = ACTIONS(4876),
    [anon_sym_DOLLARfatal] = ACTIONS(4874),
    [anon_sym_DOLLARerror] = ACTIONS(4874),
    [anon_sym_DOLLARwarning] = ACTIONS(4874),
    [anon_sym_DOLLARinfo] = ACTIONS(4874),
    [anon_sym_default] = ACTIONS(4876),
    [anon_sym_clocking] = ACTIONS(4876),
    [anon_sym_defparam] = ACTIONS(4876),
    [anon_sym_bind] = ACTIONS(4876),
    [anon_sym_rand] = ACTIONS(4876),
    [anon_sym_const] = ACTIONS(4876),
    [anon_sym_function] = ACTIONS(4876),
    [anon_sym_static] = ACTIONS(4876),
    [anon_sym_constraint] = ACTIONS(4876),
    [anon_sym_if] = ACTIONS(4876),
    [anon_sym_else] = ACTIONS(4876),
    [anon_sym_LBRACK] = ACTIONS(4874),
    [anon_sym_localparam] = ACTIONS(4876),
    [anon_sym_parameter] = ACTIONS(4876),
    [anon_sym_var] = ACTIONS(4876),
    [anon_sym_import] = ACTIONS(4876),
    [anon_sym_export] = ACTIONS(4876),
    [anon_sym_genvar] = ACTIONS(4876),
    [anon_sym_interconnect] = ACTIONS(4876),
    [anon_sym_typedef] = ACTIONS(4876),
    [anon_sym_enum] = ACTIONS(4876),
    [anon_sym_struct] = ACTIONS(4876),
    [anon_sym_union] = ACTIONS(4876),
    [anon_sym_nettype] = ACTIONS(4876),
    [anon_sym_automatic] = ACTIONS(4876),
    [anon_sym_string] = ACTIONS(4876),
    [anon_sym_chandle] = ACTIONS(4876),
    [anon_sym_event] = ACTIONS(4876),
    [anon_sym_byte] = ACTIONS(4876),
    [anon_sym_shortint] = ACTIONS(4876),
    [anon_sym_int] = ACTIONS(4876),
    [anon_sym_longint] = ACTIONS(4876),
    [anon_sym_integer] = ACTIONS(4876),
    [anon_sym_time] = ACTIONS(4876),
    [anon_sym_bit] = ACTIONS(4876),
    [anon_sym_logic] = ACTIONS(4876),
    [anon_sym_reg] = ACTIONS(4876),
    [anon_sym_shortreal] = ACTIONS(4876),
    [anon_sym_real] = ACTIONS(4876),
    [anon_sym_realtime] = ACTIONS(4876),
    [anon_sym_supply0] = ACTIONS(4876),
    [anon_sym_supply1] = ACTIONS(4876),
    [anon_sym_signed] = ACTIONS(4876),
    [anon_sym_unsigned] = ACTIONS(4876),
    [anon_sym_task] = ACTIONS(4876),
    [anon_sym_assert] = ACTIONS(4876),
    [anon_sym_property] = ACTIONS(4876),
    [anon_sym_assume] = ACTIONS(4876),
    [anon_sym_cover] = ACTIONS(4876),
    [anon_sym_sequence] = ACTIONS(4876),
    [anon_sym_restrict] = ACTIONS(4876),
    [anon_sym_not] = ACTIONS(4876),
    [anon_sym_or] = ACTIONS(4876),
    [anon_sym_and] = ACTIONS(4876),
    [anon_sym_case] = ACTIONS(4876),
    [anon_sym_always] = ACTIONS(4876),
    [anon_sym_covergroup] = ACTIONS(4876),
    [anon_sym_end] = ACTIONS(4876),
    [anon_sym_let] = ACTIONS(4876),
    [anon_sym_pulldown] = ACTIONS(4876),
    [anon_sym_pullup] = ACTIONS(4876),
    [anon_sym_cmos] = ACTIONS(4876),
    [anon_sym_rcmos] = ACTIONS(4876),
    [anon_sym_bufif0] = ACTIONS(4876),
    [anon_sym_bufif1] = ACTIONS(4876),
    [anon_sym_notif0] = ACTIONS(4876),
    [anon_sym_notif1] = ACTIONS(4876),
    [anon_sym_nmos] = ACTIONS(4876),
    [anon_sym_pmos] = ACTIONS(4876),
    [anon_sym_rnmos] = ACTIONS(4876),
    [anon_sym_rpmos] = ACTIONS(4876),
    [anon_sym_nand] = ACTIONS(4876),
    [anon_sym_nor] = ACTIONS(4876),
    [anon_sym_xor] = ACTIONS(4876),
    [anon_sym_xnor] = ACTIONS(4876),
    [anon_sym_buf] = ACTIONS(4876),
    [anon_sym_tranif0] = ACTIONS(4876),
    [anon_sym_tranif1] = ACTIONS(4876),
    [anon_sym_rtranif1] = ACTIONS(4876),
    [anon_sym_rtranif0] = ACTIONS(4876),
    [anon_sym_tran] = ACTIONS(4876),
    [anon_sym_rtran] = ACTIONS(4876),
    [anon_sym_generate] = ACTIONS(4876),
    [anon_sym_for] = ACTIONS(4876),
    [anon_sym_initial] = ACTIONS(4876),
    [anon_sym_assign] = ACTIONS(4876),
    [anon_sym_alias] = ACTIONS(4876),
    [anon_sym_always_comb] = ACTIONS(4876),
    [anon_sym_always_latch] = ACTIONS(4876),
    [anon_sym_always_ff] = ACTIONS(4876),
    [anon_sym_final] = ACTIONS(4876),
    [anon_sym_global] = ACTIONS(4876),
    [anon_sym_LPAREN_STAR] = ACTIONS(4874),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4874),
    [anon_sym_DOLLARunit] = ACTIONS(4874),
  },
  [5004] = {
    [sym_simple_identifier] = ACTIONS(6315),
    [anon_sym_wire] = ACTIONS(6315),
    [anon_sym_tri] = ACTIONS(6315),
    [anon_sym_tri0] = ACTIONS(6315),
    [anon_sym_tri1] = ACTIONS(6315),
    [anon_sym_wand] = ACTIONS(6315),
    [anon_sym_triand] = ACTIONS(6315),
    [anon_sym_wor] = ACTIONS(6315),
    [anon_sym_trior] = ACTIONS(6315),
    [anon_sym_trireg] = ACTIONS(6315),
    [anon_sym_uwire] = ACTIONS(6315),
    [anon_sym_SEMI] = ACTIONS(6317),
    [anon_sym_extern] = ACTIONS(6315),
    [anon_sym_interface] = ACTIONS(6315),
    [anon_sym_checker] = ACTIONS(6315),
    [anon_sym_virtual] = ACTIONS(6315),
    [anon_sym_class] = ACTIONS(6315),
    [anon_sym_type] = ACTIONS(6315),
    [anon_sym_DOLLARfatal] = ACTIONS(6317),
    [anon_sym_DOLLARerror] = ACTIONS(6317),
    [anon_sym_DOLLARwarning] = ACTIONS(6317),
    [anon_sym_DOLLARinfo] = ACTIONS(6317),
    [anon_sym_default] = ACTIONS(6315),
    [anon_sym_clocking] = ACTIONS(6315),
    [anon_sym_defparam] = ACTIONS(6315),
    [anon_sym_bind] = ACTIONS(6315),
    [anon_sym_rand] = ACTIONS(6315),
    [anon_sym_const] = ACTIONS(6315),
    [anon_sym_function] = ACTIONS(6315),
    [anon_sym_static] = ACTIONS(6315),
    [anon_sym_constraint] = ACTIONS(6315),
    [anon_sym_if] = ACTIONS(6315),
    [anon_sym_else] = ACTIONS(6315),
    [anon_sym_LBRACK] = ACTIONS(6317),
    [anon_sym_localparam] = ACTIONS(6315),
    [anon_sym_parameter] = ACTIONS(6315),
    [anon_sym_var] = ACTIONS(6315),
    [anon_sym_import] = ACTIONS(6315),
    [anon_sym_export] = ACTIONS(6315),
    [anon_sym_genvar] = ACTIONS(6315),
    [anon_sym_interconnect] = ACTIONS(6315),
    [anon_sym_typedef] = ACTIONS(6315),
    [anon_sym_enum] = ACTIONS(6315),
    [anon_sym_struct] = ACTIONS(6315),
    [anon_sym_union] = ACTIONS(6315),
    [anon_sym_nettype] = ACTIONS(6315),
    [anon_sym_automatic] = ACTIONS(6315),
    [anon_sym_string] = ACTIONS(6315),
    [anon_sym_chandle] = ACTIONS(6315),
    [anon_sym_event] = ACTIONS(6315),
    [anon_sym_byte] = ACTIONS(6315),
    [anon_sym_shortint] = ACTIONS(6315),
    [anon_sym_int] = ACTIONS(6315),
    [anon_sym_longint] = ACTIONS(6315),
    [anon_sym_integer] = ACTIONS(6315),
    [anon_sym_time] = ACTIONS(6315),
    [anon_sym_bit] = ACTIONS(6315),
    [anon_sym_logic] = ACTIONS(6315),
    [anon_sym_reg] = ACTIONS(6315),
    [anon_sym_shortreal] = ACTIONS(6315),
    [anon_sym_real] = ACTIONS(6315),
    [anon_sym_realtime] = ACTIONS(6315),
    [anon_sym_supply0] = ACTIONS(6315),
    [anon_sym_supply1] = ACTIONS(6315),
    [anon_sym_signed] = ACTIONS(6315),
    [anon_sym_unsigned] = ACTIONS(6315),
    [anon_sym_task] = ACTIONS(6315),
    [anon_sym_assert] = ACTIONS(6315),
    [anon_sym_property] = ACTIONS(6315),
    [anon_sym_assume] = ACTIONS(6315),
    [anon_sym_cover] = ACTIONS(6315),
    [anon_sym_sequence] = ACTIONS(6315),
    [anon_sym_restrict] = ACTIONS(6315),
    [anon_sym_not] = ACTIONS(6315),
    [anon_sym_or] = ACTIONS(6315),
    [anon_sym_and] = ACTIONS(6315),
    [anon_sym_case] = ACTIONS(6315),
    [anon_sym_always] = ACTIONS(6315),
    [anon_sym_covergroup] = ACTIONS(6315),
    [anon_sym_end] = ACTIONS(6315),
    [anon_sym_let] = ACTIONS(6315),
    [anon_sym_pulldown] = ACTIONS(6315),
    [anon_sym_pullup] = ACTIONS(6315),
    [anon_sym_cmos] = ACTIONS(6315),
    [anon_sym_rcmos] = ACTIONS(6315),
    [anon_sym_bufif0] = ACTIONS(6315),
    [anon_sym_bufif1] = ACTIONS(6315),
    [anon_sym_notif0] = ACTIONS(6315),
    [anon_sym_notif1] = ACTIONS(6315),
    [anon_sym_nmos] = ACTIONS(6315),
    [anon_sym_pmos] = ACTIONS(6315),
    [anon_sym_rnmos] = ACTIONS(6315),
    [anon_sym_rpmos] = ACTIONS(6315),
    [anon_sym_nand] = ACTIONS(6315),
    [anon_sym_nor] = ACTIONS(6315),
    [anon_sym_xor] = ACTIONS(6315),
    [anon_sym_xnor] = ACTIONS(6315),
    [anon_sym_buf] = ACTIONS(6315),
    [anon_sym_tranif0] = ACTIONS(6315),
    [anon_sym_tranif1] = ACTIONS(6315),
    [anon_sym_rtranif1] = ACTIONS(6315),
    [anon_sym_rtranif0] = ACTIONS(6315),
    [anon_sym_tran] = ACTIONS(6315),
    [anon_sym_rtran] = ACTIONS(6315),
    [anon_sym_generate] = ACTIONS(6315),
    [anon_sym_for] = ACTIONS(6315),
    [anon_sym_initial] = ACTIONS(6315),
    [anon_sym_assign] = ACTIONS(6315),
    [anon_sym_alias] = ACTIONS(6315),
    [anon_sym_always_comb] = ACTIONS(6315),
    [anon_sym_always_latch] = ACTIONS(6315),
    [anon_sym_always_ff] = ACTIONS(6315),
    [anon_sym_final] = ACTIONS(6315),
    [anon_sym_global] = ACTIONS(6315),
    [anon_sym_LPAREN_STAR] = ACTIONS(6317),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6317),
    [anon_sym_DOLLARunit] = ACTIONS(6317),
  },
  [5005] = {
    [sym_simple_identifier] = ACTIONS(5782),
    [anon_sym_wire] = ACTIONS(5782),
    [anon_sym_tri] = ACTIONS(5782),
    [anon_sym_tri0] = ACTIONS(5782),
    [anon_sym_tri1] = ACTIONS(5782),
    [anon_sym_wand] = ACTIONS(5782),
    [anon_sym_triand] = ACTIONS(5782),
    [anon_sym_wor] = ACTIONS(5782),
    [anon_sym_trior] = ACTIONS(5782),
    [anon_sym_trireg] = ACTIONS(5782),
    [anon_sym_uwire] = ACTIONS(5782),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym_extern] = ACTIONS(5782),
    [anon_sym_interface] = ACTIONS(5782),
    [anon_sym_checker] = ACTIONS(5782),
    [anon_sym_virtual] = ACTIONS(5782),
    [anon_sym_class] = ACTIONS(5782),
    [anon_sym_type] = ACTIONS(5782),
    [anon_sym_DOLLARfatal] = ACTIONS(5784),
    [anon_sym_DOLLARerror] = ACTIONS(5784),
    [anon_sym_DOLLARwarning] = ACTIONS(5784),
    [anon_sym_DOLLARinfo] = ACTIONS(5784),
    [anon_sym_default] = ACTIONS(5782),
    [anon_sym_clocking] = ACTIONS(5782),
    [anon_sym_defparam] = ACTIONS(5782),
    [anon_sym_bind] = ACTIONS(5782),
    [anon_sym_rand] = ACTIONS(5782),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_function] = ACTIONS(5782),
    [anon_sym_static] = ACTIONS(5782),
    [anon_sym_constraint] = ACTIONS(5782),
    [anon_sym_if] = ACTIONS(5782),
    [anon_sym_else] = ACTIONS(5782),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_localparam] = ACTIONS(5782),
    [anon_sym_parameter] = ACTIONS(5782),
    [anon_sym_var] = ACTIONS(5782),
    [anon_sym_import] = ACTIONS(5782),
    [anon_sym_export] = ACTIONS(5782),
    [anon_sym_genvar] = ACTIONS(5782),
    [anon_sym_interconnect] = ACTIONS(5782),
    [anon_sym_typedef] = ACTIONS(5782),
    [anon_sym_enum] = ACTIONS(5782),
    [anon_sym_struct] = ACTIONS(5782),
    [anon_sym_union] = ACTIONS(5782),
    [anon_sym_nettype] = ACTIONS(5782),
    [anon_sym_automatic] = ACTIONS(5782),
    [anon_sym_string] = ACTIONS(5782),
    [anon_sym_chandle] = ACTIONS(5782),
    [anon_sym_event] = ACTIONS(5782),
    [anon_sym_byte] = ACTIONS(5782),
    [anon_sym_shortint] = ACTIONS(5782),
    [anon_sym_int] = ACTIONS(5782),
    [anon_sym_longint] = ACTIONS(5782),
    [anon_sym_integer] = ACTIONS(5782),
    [anon_sym_time] = ACTIONS(5782),
    [anon_sym_bit] = ACTIONS(5782),
    [anon_sym_logic] = ACTIONS(5782),
    [anon_sym_reg] = ACTIONS(5782),
    [anon_sym_shortreal] = ACTIONS(5782),
    [anon_sym_real] = ACTIONS(5782),
    [anon_sym_realtime] = ACTIONS(5782),
    [anon_sym_supply0] = ACTIONS(5782),
    [anon_sym_supply1] = ACTIONS(5782),
    [anon_sym_signed] = ACTIONS(5782),
    [anon_sym_unsigned] = ACTIONS(5782),
    [anon_sym_task] = ACTIONS(5782),
    [anon_sym_assert] = ACTIONS(5782),
    [anon_sym_property] = ACTIONS(5782),
    [anon_sym_assume] = ACTIONS(5782),
    [anon_sym_cover] = ACTIONS(5782),
    [anon_sym_sequence] = ACTIONS(5782),
    [anon_sym_restrict] = ACTIONS(5782),
    [anon_sym_not] = ACTIONS(5782),
    [anon_sym_or] = ACTIONS(5782),
    [anon_sym_and] = ACTIONS(5782),
    [anon_sym_case] = ACTIONS(5782),
    [anon_sym_always] = ACTIONS(5782),
    [anon_sym_covergroup] = ACTIONS(5782),
    [anon_sym_let] = ACTIONS(5782),
    [anon_sym_pulldown] = ACTIONS(5782),
    [anon_sym_pullup] = ACTIONS(5782),
    [anon_sym_cmos] = ACTIONS(5782),
    [anon_sym_rcmos] = ACTIONS(5782),
    [anon_sym_bufif0] = ACTIONS(5782),
    [anon_sym_bufif1] = ACTIONS(5782),
    [anon_sym_notif0] = ACTIONS(5782),
    [anon_sym_notif1] = ACTIONS(5782),
    [anon_sym_nmos] = ACTIONS(5782),
    [anon_sym_pmos] = ACTIONS(5782),
    [anon_sym_rnmos] = ACTIONS(5782),
    [anon_sym_rpmos] = ACTIONS(5782),
    [anon_sym_nand] = ACTIONS(5782),
    [anon_sym_nor] = ACTIONS(5782),
    [anon_sym_xor] = ACTIONS(5782),
    [anon_sym_xnor] = ACTIONS(5782),
    [anon_sym_buf] = ACTIONS(5782),
    [anon_sym_tranif0] = ACTIONS(5782),
    [anon_sym_tranif1] = ACTIONS(5782),
    [anon_sym_rtranif1] = ACTIONS(5782),
    [anon_sym_rtranif0] = ACTIONS(5782),
    [anon_sym_tran] = ACTIONS(5782),
    [anon_sym_rtran] = ACTIONS(5782),
    [anon_sym_generate] = ACTIONS(5782),
    [anon_sym_endgenerate] = ACTIONS(5782),
    [anon_sym_for] = ACTIONS(5782),
    [anon_sym_initial] = ACTIONS(5782),
    [anon_sym_assign] = ACTIONS(5782),
    [anon_sym_alias] = ACTIONS(5782),
    [anon_sym_always_comb] = ACTIONS(5782),
    [anon_sym_always_latch] = ACTIONS(5782),
    [anon_sym_always_ff] = ACTIONS(5782),
    [anon_sym_final] = ACTIONS(5782),
    [anon_sym_global] = ACTIONS(5782),
    [anon_sym_LPAREN_STAR] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5784),
    [anon_sym_DOLLARunit] = ACTIONS(5784),
  },
  [5006] = {
    [sym_simple_identifier] = ACTIONS(6319),
    [anon_sym_wire] = ACTIONS(6319),
    [anon_sym_tri] = ACTIONS(6319),
    [anon_sym_tri0] = ACTIONS(6319),
    [anon_sym_tri1] = ACTIONS(6319),
    [anon_sym_wand] = ACTIONS(6319),
    [anon_sym_triand] = ACTIONS(6319),
    [anon_sym_wor] = ACTIONS(6319),
    [anon_sym_trior] = ACTIONS(6319),
    [anon_sym_trireg] = ACTIONS(6319),
    [anon_sym_uwire] = ACTIONS(6319),
    [anon_sym_SEMI] = ACTIONS(6321),
    [anon_sym_extern] = ACTIONS(6319),
    [anon_sym_interface] = ACTIONS(6319),
    [anon_sym_checker] = ACTIONS(6319),
    [anon_sym_virtual] = ACTIONS(6319),
    [anon_sym_class] = ACTIONS(6319),
    [anon_sym_type] = ACTIONS(6319),
    [anon_sym_DOLLARfatal] = ACTIONS(6321),
    [anon_sym_DOLLARerror] = ACTIONS(6321),
    [anon_sym_DOLLARwarning] = ACTIONS(6321),
    [anon_sym_DOLLARinfo] = ACTIONS(6321),
    [anon_sym_default] = ACTIONS(6319),
    [anon_sym_clocking] = ACTIONS(6319),
    [anon_sym_defparam] = ACTIONS(6319),
    [anon_sym_bind] = ACTIONS(6319),
    [anon_sym_rand] = ACTIONS(6319),
    [anon_sym_const] = ACTIONS(6319),
    [anon_sym_function] = ACTIONS(6319),
    [anon_sym_static] = ACTIONS(6319),
    [anon_sym_constraint] = ACTIONS(6319),
    [anon_sym_if] = ACTIONS(6319),
    [anon_sym_else] = ACTIONS(6319),
    [anon_sym_LBRACK] = ACTIONS(6321),
    [anon_sym_localparam] = ACTIONS(6319),
    [anon_sym_parameter] = ACTIONS(6319),
    [anon_sym_var] = ACTIONS(6319),
    [anon_sym_import] = ACTIONS(6319),
    [anon_sym_export] = ACTIONS(6319),
    [anon_sym_genvar] = ACTIONS(6319),
    [anon_sym_interconnect] = ACTIONS(6319),
    [anon_sym_typedef] = ACTIONS(6319),
    [anon_sym_enum] = ACTIONS(6319),
    [anon_sym_struct] = ACTIONS(6319),
    [anon_sym_union] = ACTIONS(6319),
    [anon_sym_nettype] = ACTIONS(6319),
    [anon_sym_automatic] = ACTIONS(6319),
    [anon_sym_string] = ACTIONS(6319),
    [anon_sym_chandle] = ACTIONS(6319),
    [anon_sym_event] = ACTIONS(6319),
    [anon_sym_byte] = ACTIONS(6319),
    [anon_sym_shortint] = ACTIONS(6319),
    [anon_sym_int] = ACTIONS(6319),
    [anon_sym_longint] = ACTIONS(6319),
    [anon_sym_integer] = ACTIONS(6319),
    [anon_sym_time] = ACTIONS(6319),
    [anon_sym_bit] = ACTIONS(6319),
    [anon_sym_logic] = ACTIONS(6319),
    [anon_sym_reg] = ACTIONS(6319),
    [anon_sym_shortreal] = ACTIONS(6319),
    [anon_sym_real] = ACTIONS(6319),
    [anon_sym_realtime] = ACTIONS(6319),
    [anon_sym_supply0] = ACTIONS(6319),
    [anon_sym_supply1] = ACTIONS(6319),
    [anon_sym_signed] = ACTIONS(6319),
    [anon_sym_unsigned] = ACTIONS(6319),
    [anon_sym_task] = ACTIONS(6319),
    [anon_sym_assert] = ACTIONS(6319),
    [anon_sym_property] = ACTIONS(6319),
    [anon_sym_assume] = ACTIONS(6319),
    [anon_sym_cover] = ACTIONS(6319),
    [anon_sym_sequence] = ACTIONS(6319),
    [anon_sym_restrict] = ACTIONS(6319),
    [anon_sym_not] = ACTIONS(6319),
    [anon_sym_or] = ACTIONS(6319),
    [anon_sym_and] = ACTIONS(6319),
    [anon_sym_case] = ACTIONS(6319),
    [anon_sym_always] = ACTIONS(6319),
    [anon_sym_covergroup] = ACTIONS(6319),
    [anon_sym_end] = ACTIONS(6319),
    [anon_sym_let] = ACTIONS(6319),
    [anon_sym_pulldown] = ACTIONS(6319),
    [anon_sym_pullup] = ACTIONS(6319),
    [anon_sym_cmos] = ACTIONS(6319),
    [anon_sym_rcmos] = ACTIONS(6319),
    [anon_sym_bufif0] = ACTIONS(6319),
    [anon_sym_bufif1] = ACTIONS(6319),
    [anon_sym_notif0] = ACTIONS(6319),
    [anon_sym_notif1] = ACTIONS(6319),
    [anon_sym_nmos] = ACTIONS(6319),
    [anon_sym_pmos] = ACTIONS(6319),
    [anon_sym_rnmos] = ACTIONS(6319),
    [anon_sym_rpmos] = ACTIONS(6319),
    [anon_sym_nand] = ACTIONS(6319),
    [anon_sym_nor] = ACTIONS(6319),
    [anon_sym_xor] = ACTIONS(6319),
    [anon_sym_xnor] = ACTIONS(6319),
    [anon_sym_buf] = ACTIONS(6319),
    [anon_sym_tranif0] = ACTIONS(6319),
    [anon_sym_tranif1] = ACTIONS(6319),
    [anon_sym_rtranif1] = ACTIONS(6319),
    [anon_sym_rtranif0] = ACTIONS(6319),
    [anon_sym_tran] = ACTIONS(6319),
    [anon_sym_rtran] = ACTIONS(6319),
    [anon_sym_generate] = ACTIONS(6319),
    [anon_sym_for] = ACTIONS(6319),
    [anon_sym_initial] = ACTIONS(6319),
    [anon_sym_assign] = ACTIONS(6319),
    [anon_sym_alias] = ACTIONS(6319),
    [anon_sym_always_comb] = ACTIONS(6319),
    [anon_sym_always_latch] = ACTIONS(6319),
    [anon_sym_always_ff] = ACTIONS(6319),
    [anon_sym_final] = ACTIONS(6319),
    [anon_sym_global] = ACTIONS(6319),
    [anon_sym_LPAREN_STAR] = ACTIONS(6321),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6321),
    [anon_sym_DOLLARunit] = ACTIONS(6321),
  },
  [5007] = {
    [sym_simple_identifier] = ACTIONS(6323),
    [anon_sym_wire] = ACTIONS(6323),
    [anon_sym_tri] = ACTIONS(6323),
    [anon_sym_tri0] = ACTIONS(6323),
    [anon_sym_tri1] = ACTIONS(6323),
    [anon_sym_wand] = ACTIONS(6323),
    [anon_sym_triand] = ACTIONS(6323),
    [anon_sym_wor] = ACTIONS(6323),
    [anon_sym_trior] = ACTIONS(6323),
    [anon_sym_trireg] = ACTIONS(6323),
    [anon_sym_uwire] = ACTIONS(6323),
    [anon_sym_SEMI] = ACTIONS(6325),
    [anon_sym_extern] = ACTIONS(6323),
    [anon_sym_interface] = ACTIONS(6323),
    [anon_sym_checker] = ACTIONS(6323),
    [anon_sym_virtual] = ACTIONS(6323),
    [anon_sym_class] = ACTIONS(6323),
    [anon_sym_type] = ACTIONS(6323),
    [anon_sym_DOLLARfatal] = ACTIONS(6325),
    [anon_sym_DOLLARerror] = ACTIONS(6325),
    [anon_sym_DOLLARwarning] = ACTIONS(6325),
    [anon_sym_DOLLARinfo] = ACTIONS(6325),
    [anon_sym_default] = ACTIONS(6323),
    [anon_sym_clocking] = ACTIONS(6323),
    [anon_sym_defparam] = ACTIONS(6323),
    [anon_sym_bind] = ACTIONS(6323),
    [anon_sym_rand] = ACTIONS(6323),
    [anon_sym_const] = ACTIONS(6323),
    [anon_sym_function] = ACTIONS(6323),
    [anon_sym_static] = ACTIONS(6323),
    [anon_sym_constraint] = ACTIONS(6323),
    [anon_sym_if] = ACTIONS(6323),
    [anon_sym_else] = ACTIONS(6323),
    [anon_sym_LBRACK] = ACTIONS(6325),
    [anon_sym_localparam] = ACTIONS(6323),
    [anon_sym_parameter] = ACTIONS(6323),
    [anon_sym_var] = ACTIONS(6323),
    [anon_sym_import] = ACTIONS(6323),
    [anon_sym_export] = ACTIONS(6323),
    [anon_sym_genvar] = ACTIONS(6323),
    [anon_sym_interconnect] = ACTIONS(6323),
    [anon_sym_typedef] = ACTIONS(6323),
    [anon_sym_enum] = ACTIONS(6323),
    [anon_sym_struct] = ACTIONS(6323),
    [anon_sym_union] = ACTIONS(6323),
    [anon_sym_nettype] = ACTIONS(6323),
    [anon_sym_automatic] = ACTIONS(6323),
    [anon_sym_string] = ACTIONS(6323),
    [anon_sym_chandle] = ACTIONS(6323),
    [anon_sym_event] = ACTIONS(6323),
    [anon_sym_byte] = ACTIONS(6323),
    [anon_sym_shortint] = ACTIONS(6323),
    [anon_sym_int] = ACTIONS(6323),
    [anon_sym_longint] = ACTIONS(6323),
    [anon_sym_integer] = ACTIONS(6323),
    [anon_sym_time] = ACTIONS(6323),
    [anon_sym_bit] = ACTIONS(6323),
    [anon_sym_logic] = ACTIONS(6323),
    [anon_sym_reg] = ACTIONS(6323),
    [anon_sym_shortreal] = ACTIONS(6323),
    [anon_sym_real] = ACTIONS(6323),
    [anon_sym_realtime] = ACTIONS(6323),
    [anon_sym_supply0] = ACTIONS(6323),
    [anon_sym_supply1] = ACTIONS(6323),
    [anon_sym_signed] = ACTIONS(6323),
    [anon_sym_unsigned] = ACTIONS(6323),
    [anon_sym_task] = ACTIONS(6323),
    [anon_sym_assert] = ACTIONS(6323),
    [anon_sym_property] = ACTIONS(6323),
    [anon_sym_assume] = ACTIONS(6323),
    [anon_sym_cover] = ACTIONS(6323),
    [anon_sym_sequence] = ACTIONS(6323),
    [anon_sym_restrict] = ACTIONS(6323),
    [anon_sym_not] = ACTIONS(6323),
    [anon_sym_or] = ACTIONS(6323),
    [anon_sym_and] = ACTIONS(6323),
    [anon_sym_case] = ACTIONS(6323),
    [anon_sym_always] = ACTIONS(6323),
    [anon_sym_covergroup] = ACTIONS(6323),
    [anon_sym_end] = ACTIONS(6323),
    [anon_sym_let] = ACTIONS(6323),
    [anon_sym_pulldown] = ACTIONS(6323),
    [anon_sym_pullup] = ACTIONS(6323),
    [anon_sym_cmos] = ACTIONS(6323),
    [anon_sym_rcmos] = ACTIONS(6323),
    [anon_sym_bufif0] = ACTIONS(6323),
    [anon_sym_bufif1] = ACTIONS(6323),
    [anon_sym_notif0] = ACTIONS(6323),
    [anon_sym_notif1] = ACTIONS(6323),
    [anon_sym_nmos] = ACTIONS(6323),
    [anon_sym_pmos] = ACTIONS(6323),
    [anon_sym_rnmos] = ACTIONS(6323),
    [anon_sym_rpmos] = ACTIONS(6323),
    [anon_sym_nand] = ACTIONS(6323),
    [anon_sym_nor] = ACTIONS(6323),
    [anon_sym_xor] = ACTIONS(6323),
    [anon_sym_xnor] = ACTIONS(6323),
    [anon_sym_buf] = ACTIONS(6323),
    [anon_sym_tranif0] = ACTIONS(6323),
    [anon_sym_tranif1] = ACTIONS(6323),
    [anon_sym_rtranif1] = ACTIONS(6323),
    [anon_sym_rtranif0] = ACTIONS(6323),
    [anon_sym_tran] = ACTIONS(6323),
    [anon_sym_rtran] = ACTIONS(6323),
    [anon_sym_generate] = ACTIONS(6323),
    [anon_sym_for] = ACTIONS(6323),
    [anon_sym_initial] = ACTIONS(6323),
    [anon_sym_assign] = ACTIONS(6323),
    [anon_sym_alias] = ACTIONS(6323),
    [anon_sym_always_comb] = ACTIONS(6323),
    [anon_sym_always_latch] = ACTIONS(6323),
    [anon_sym_always_ff] = ACTIONS(6323),
    [anon_sym_final] = ACTIONS(6323),
    [anon_sym_global] = ACTIONS(6323),
    [anon_sym_LPAREN_STAR] = ACTIONS(6325),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6325),
    [anon_sym_DOLLARunit] = ACTIONS(6325),
  },
  [5008] = {
    [sym_simple_identifier] = ACTIONS(5360),
    [anon_sym_wire] = ACTIONS(5360),
    [anon_sym_tri] = ACTIONS(5360),
    [anon_sym_tri0] = ACTIONS(5360),
    [anon_sym_tri1] = ACTIONS(5360),
    [anon_sym_wand] = ACTIONS(5360),
    [anon_sym_triand] = ACTIONS(5360),
    [anon_sym_wor] = ACTIONS(5360),
    [anon_sym_trior] = ACTIONS(5360),
    [anon_sym_trireg] = ACTIONS(5360),
    [anon_sym_uwire] = ACTIONS(5360),
    [anon_sym_SEMI] = ACTIONS(5358),
    [anon_sym_extern] = ACTIONS(5360),
    [anon_sym_interface] = ACTIONS(5360),
    [anon_sym_checker] = ACTIONS(5360),
    [anon_sym_virtual] = ACTIONS(5360),
    [anon_sym_class] = ACTIONS(5360),
    [anon_sym_type] = ACTIONS(5360),
    [anon_sym_DOLLARfatal] = ACTIONS(5358),
    [anon_sym_DOLLARerror] = ACTIONS(5358),
    [anon_sym_DOLLARwarning] = ACTIONS(5358),
    [anon_sym_DOLLARinfo] = ACTIONS(5358),
    [anon_sym_default] = ACTIONS(5360),
    [anon_sym_clocking] = ACTIONS(5360),
    [anon_sym_defparam] = ACTIONS(5360),
    [anon_sym_bind] = ACTIONS(5360),
    [anon_sym_rand] = ACTIONS(5360),
    [anon_sym_const] = ACTIONS(5360),
    [anon_sym_function] = ACTIONS(5360),
    [anon_sym_static] = ACTIONS(5360),
    [anon_sym_constraint] = ACTIONS(5360),
    [anon_sym_if] = ACTIONS(5360),
    [anon_sym_else] = ACTIONS(5360),
    [anon_sym_LBRACK] = ACTIONS(5358),
    [anon_sym_localparam] = ACTIONS(5360),
    [anon_sym_parameter] = ACTIONS(5360),
    [anon_sym_var] = ACTIONS(5360),
    [anon_sym_import] = ACTIONS(5360),
    [anon_sym_export] = ACTIONS(5360),
    [anon_sym_genvar] = ACTIONS(5360),
    [anon_sym_interconnect] = ACTIONS(5360),
    [anon_sym_typedef] = ACTIONS(5360),
    [anon_sym_enum] = ACTIONS(5360),
    [anon_sym_struct] = ACTIONS(5360),
    [anon_sym_union] = ACTIONS(5360),
    [anon_sym_nettype] = ACTIONS(5360),
    [anon_sym_automatic] = ACTIONS(5360),
    [anon_sym_string] = ACTIONS(5360),
    [anon_sym_chandle] = ACTIONS(5360),
    [anon_sym_event] = ACTIONS(5360),
    [anon_sym_byte] = ACTIONS(5360),
    [anon_sym_shortint] = ACTIONS(5360),
    [anon_sym_int] = ACTIONS(5360),
    [anon_sym_longint] = ACTIONS(5360),
    [anon_sym_integer] = ACTIONS(5360),
    [anon_sym_time] = ACTIONS(5360),
    [anon_sym_bit] = ACTIONS(5360),
    [anon_sym_logic] = ACTIONS(5360),
    [anon_sym_reg] = ACTIONS(5360),
    [anon_sym_shortreal] = ACTIONS(5360),
    [anon_sym_real] = ACTIONS(5360),
    [anon_sym_realtime] = ACTIONS(5360),
    [anon_sym_supply0] = ACTIONS(5360),
    [anon_sym_supply1] = ACTIONS(5360),
    [anon_sym_signed] = ACTIONS(5360),
    [anon_sym_unsigned] = ACTIONS(5360),
    [anon_sym_task] = ACTIONS(5360),
    [anon_sym_assert] = ACTIONS(5360),
    [anon_sym_property] = ACTIONS(5360),
    [anon_sym_assume] = ACTIONS(5360),
    [anon_sym_cover] = ACTIONS(5360),
    [anon_sym_sequence] = ACTIONS(5360),
    [anon_sym_restrict] = ACTIONS(5360),
    [anon_sym_not] = ACTIONS(5360),
    [anon_sym_or] = ACTIONS(5360),
    [anon_sym_and] = ACTIONS(5360),
    [anon_sym_case] = ACTIONS(5360),
    [anon_sym_always] = ACTIONS(5360),
    [anon_sym_covergroup] = ACTIONS(5360),
    [anon_sym_end] = ACTIONS(5360),
    [anon_sym_let] = ACTIONS(5360),
    [anon_sym_pulldown] = ACTIONS(5360),
    [anon_sym_pullup] = ACTIONS(5360),
    [anon_sym_cmos] = ACTIONS(5360),
    [anon_sym_rcmos] = ACTIONS(5360),
    [anon_sym_bufif0] = ACTIONS(5360),
    [anon_sym_bufif1] = ACTIONS(5360),
    [anon_sym_notif0] = ACTIONS(5360),
    [anon_sym_notif1] = ACTIONS(5360),
    [anon_sym_nmos] = ACTIONS(5360),
    [anon_sym_pmos] = ACTIONS(5360),
    [anon_sym_rnmos] = ACTIONS(5360),
    [anon_sym_rpmos] = ACTIONS(5360),
    [anon_sym_nand] = ACTIONS(5360),
    [anon_sym_nor] = ACTIONS(5360),
    [anon_sym_xor] = ACTIONS(5360),
    [anon_sym_xnor] = ACTIONS(5360),
    [anon_sym_buf] = ACTIONS(5360),
    [anon_sym_tranif0] = ACTIONS(5360),
    [anon_sym_tranif1] = ACTIONS(5360),
    [anon_sym_rtranif1] = ACTIONS(5360),
    [anon_sym_rtranif0] = ACTIONS(5360),
    [anon_sym_tran] = ACTIONS(5360),
    [anon_sym_rtran] = ACTIONS(5360),
    [anon_sym_generate] = ACTIONS(5360),
    [anon_sym_for] = ACTIONS(5360),
    [anon_sym_initial] = ACTIONS(5360),
    [anon_sym_assign] = ACTIONS(5360),
    [anon_sym_alias] = ACTIONS(5360),
    [anon_sym_always_comb] = ACTIONS(5360),
    [anon_sym_always_latch] = ACTIONS(5360),
    [anon_sym_always_ff] = ACTIONS(5360),
    [anon_sym_final] = ACTIONS(5360),
    [anon_sym_global] = ACTIONS(5360),
    [anon_sym_LPAREN_STAR] = ACTIONS(5358),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5358),
    [anon_sym_DOLLARunit] = ACTIONS(5358),
  },
  [5009] = {
    [sym_simple_identifier] = ACTIONS(4884),
    [anon_sym_wire] = ACTIONS(4884),
    [anon_sym_tri] = ACTIONS(4884),
    [anon_sym_tri0] = ACTIONS(4884),
    [anon_sym_tri1] = ACTIONS(4884),
    [anon_sym_wand] = ACTIONS(4884),
    [anon_sym_triand] = ACTIONS(4884),
    [anon_sym_wor] = ACTIONS(4884),
    [anon_sym_trior] = ACTIONS(4884),
    [anon_sym_trireg] = ACTIONS(4884),
    [anon_sym_uwire] = ACTIONS(4884),
    [anon_sym_SEMI] = ACTIONS(4882),
    [anon_sym_extern] = ACTIONS(4884),
    [anon_sym_interface] = ACTIONS(4884),
    [anon_sym_checker] = ACTIONS(4884),
    [anon_sym_virtual] = ACTIONS(4884),
    [anon_sym_class] = ACTIONS(4884),
    [anon_sym_type] = ACTIONS(4884),
    [anon_sym_DOLLARfatal] = ACTIONS(4882),
    [anon_sym_DOLLARerror] = ACTIONS(4882),
    [anon_sym_DOLLARwarning] = ACTIONS(4882),
    [anon_sym_DOLLARinfo] = ACTIONS(4882),
    [anon_sym_default] = ACTIONS(4884),
    [anon_sym_clocking] = ACTIONS(4884),
    [anon_sym_defparam] = ACTIONS(4884),
    [anon_sym_bind] = ACTIONS(4884),
    [anon_sym_rand] = ACTIONS(4884),
    [anon_sym_const] = ACTIONS(4884),
    [anon_sym_function] = ACTIONS(4884),
    [anon_sym_static] = ACTIONS(4884),
    [anon_sym_constraint] = ACTIONS(4884),
    [anon_sym_if] = ACTIONS(4884),
    [anon_sym_else] = ACTIONS(4884),
    [anon_sym_LBRACK] = ACTIONS(4882),
    [anon_sym_localparam] = ACTIONS(4884),
    [anon_sym_parameter] = ACTIONS(4884),
    [anon_sym_var] = ACTIONS(4884),
    [anon_sym_import] = ACTIONS(4884),
    [anon_sym_export] = ACTIONS(4884),
    [anon_sym_genvar] = ACTIONS(4884),
    [anon_sym_interconnect] = ACTIONS(4884),
    [anon_sym_typedef] = ACTIONS(4884),
    [anon_sym_enum] = ACTIONS(4884),
    [anon_sym_struct] = ACTIONS(4884),
    [anon_sym_union] = ACTIONS(4884),
    [anon_sym_nettype] = ACTIONS(4884),
    [anon_sym_automatic] = ACTIONS(4884),
    [anon_sym_string] = ACTIONS(4884),
    [anon_sym_chandle] = ACTIONS(4884),
    [anon_sym_event] = ACTIONS(4884),
    [anon_sym_byte] = ACTIONS(4884),
    [anon_sym_shortint] = ACTIONS(4884),
    [anon_sym_int] = ACTIONS(4884),
    [anon_sym_longint] = ACTIONS(4884),
    [anon_sym_integer] = ACTIONS(4884),
    [anon_sym_time] = ACTIONS(4884),
    [anon_sym_bit] = ACTIONS(4884),
    [anon_sym_logic] = ACTIONS(4884),
    [anon_sym_reg] = ACTIONS(4884),
    [anon_sym_shortreal] = ACTIONS(4884),
    [anon_sym_real] = ACTIONS(4884),
    [anon_sym_realtime] = ACTIONS(4884),
    [anon_sym_supply0] = ACTIONS(4884),
    [anon_sym_supply1] = ACTIONS(4884),
    [anon_sym_signed] = ACTIONS(4884),
    [anon_sym_unsigned] = ACTIONS(4884),
    [anon_sym_task] = ACTIONS(4884),
    [anon_sym_assert] = ACTIONS(4884),
    [anon_sym_property] = ACTIONS(4884),
    [anon_sym_assume] = ACTIONS(4884),
    [anon_sym_cover] = ACTIONS(4884),
    [anon_sym_sequence] = ACTIONS(4884),
    [anon_sym_restrict] = ACTIONS(4884),
    [anon_sym_not] = ACTIONS(4884),
    [anon_sym_or] = ACTIONS(4884),
    [anon_sym_and] = ACTIONS(4884),
    [anon_sym_case] = ACTIONS(4884),
    [anon_sym_always] = ACTIONS(4884),
    [anon_sym_covergroup] = ACTIONS(4884),
    [anon_sym_let] = ACTIONS(4884),
    [anon_sym_pulldown] = ACTIONS(4884),
    [anon_sym_pullup] = ACTIONS(4884),
    [anon_sym_cmos] = ACTIONS(4884),
    [anon_sym_rcmos] = ACTIONS(4884),
    [anon_sym_bufif0] = ACTIONS(4884),
    [anon_sym_bufif1] = ACTIONS(4884),
    [anon_sym_notif0] = ACTIONS(4884),
    [anon_sym_notif1] = ACTIONS(4884),
    [anon_sym_nmos] = ACTIONS(4884),
    [anon_sym_pmos] = ACTIONS(4884),
    [anon_sym_rnmos] = ACTIONS(4884),
    [anon_sym_rpmos] = ACTIONS(4884),
    [anon_sym_nand] = ACTIONS(4884),
    [anon_sym_nor] = ACTIONS(4884),
    [anon_sym_xor] = ACTIONS(4884),
    [anon_sym_xnor] = ACTIONS(4884),
    [anon_sym_buf] = ACTIONS(4884),
    [anon_sym_tranif0] = ACTIONS(4884),
    [anon_sym_tranif1] = ACTIONS(4884),
    [anon_sym_rtranif1] = ACTIONS(4884),
    [anon_sym_rtranif0] = ACTIONS(4884),
    [anon_sym_tran] = ACTIONS(4884),
    [anon_sym_rtran] = ACTIONS(4884),
    [anon_sym_generate] = ACTIONS(4884),
    [anon_sym_endgenerate] = ACTIONS(4884),
    [anon_sym_for] = ACTIONS(4884),
    [anon_sym_initial] = ACTIONS(4884),
    [anon_sym_assign] = ACTIONS(4884),
    [anon_sym_alias] = ACTIONS(4884),
    [anon_sym_always_comb] = ACTIONS(4884),
    [anon_sym_always_latch] = ACTIONS(4884),
    [anon_sym_always_ff] = ACTIONS(4884),
    [anon_sym_final] = ACTIONS(4884),
    [anon_sym_global] = ACTIONS(4884),
    [anon_sym_LPAREN_STAR] = ACTIONS(4882),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4882),
    [anon_sym_DOLLARunit] = ACTIONS(4882),
  },
  [5010] = {
    [sym_simple_identifier] = ACTIONS(4774),
    [anon_sym_wire] = ACTIONS(4774),
    [anon_sym_tri] = ACTIONS(4774),
    [anon_sym_tri0] = ACTIONS(4774),
    [anon_sym_tri1] = ACTIONS(4774),
    [anon_sym_wand] = ACTIONS(4774),
    [anon_sym_triand] = ACTIONS(4774),
    [anon_sym_wor] = ACTIONS(4774),
    [anon_sym_trior] = ACTIONS(4774),
    [anon_sym_trireg] = ACTIONS(4774),
    [anon_sym_uwire] = ACTIONS(4774),
    [anon_sym_SEMI] = ACTIONS(4772),
    [anon_sym_extern] = ACTIONS(4774),
    [anon_sym_interface] = ACTIONS(4774),
    [anon_sym_checker] = ACTIONS(4774),
    [anon_sym_virtual] = ACTIONS(4774),
    [anon_sym_class] = ACTIONS(4774),
    [anon_sym_type] = ACTIONS(4774),
    [anon_sym_DOLLARfatal] = ACTIONS(4772),
    [anon_sym_DOLLARerror] = ACTIONS(4772),
    [anon_sym_DOLLARwarning] = ACTIONS(4772),
    [anon_sym_DOLLARinfo] = ACTIONS(4772),
    [anon_sym_default] = ACTIONS(4774),
    [anon_sym_clocking] = ACTIONS(4774),
    [anon_sym_defparam] = ACTIONS(4774),
    [anon_sym_bind] = ACTIONS(4774),
    [anon_sym_rand] = ACTIONS(4774),
    [anon_sym_const] = ACTIONS(4774),
    [anon_sym_function] = ACTIONS(4774),
    [anon_sym_static] = ACTIONS(4774),
    [anon_sym_constraint] = ACTIONS(4774),
    [anon_sym_if] = ACTIONS(4774),
    [anon_sym_else] = ACTIONS(4774),
    [anon_sym_LBRACK] = ACTIONS(4772),
    [anon_sym_localparam] = ACTIONS(4774),
    [anon_sym_parameter] = ACTIONS(4774),
    [anon_sym_var] = ACTIONS(4774),
    [anon_sym_import] = ACTIONS(4774),
    [anon_sym_export] = ACTIONS(4774),
    [anon_sym_genvar] = ACTIONS(4774),
    [anon_sym_interconnect] = ACTIONS(4774),
    [anon_sym_typedef] = ACTIONS(4774),
    [anon_sym_enum] = ACTIONS(4774),
    [anon_sym_struct] = ACTIONS(4774),
    [anon_sym_union] = ACTIONS(4774),
    [anon_sym_nettype] = ACTIONS(4774),
    [anon_sym_automatic] = ACTIONS(4774),
    [anon_sym_string] = ACTIONS(4774),
    [anon_sym_chandle] = ACTIONS(4774),
    [anon_sym_event] = ACTIONS(4774),
    [anon_sym_byte] = ACTIONS(4774),
    [anon_sym_shortint] = ACTIONS(4774),
    [anon_sym_int] = ACTIONS(4774),
    [anon_sym_longint] = ACTIONS(4774),
    [anon_sym_integer] = ACTIONS(4774),
    [anon_sym_time] = ACTIONS(4774),
    [anon_sym_bit] = ACTIONS(4774),
    [anon_sym_logic] = ACTIONS(4774),
    [anon_sym_reg] = ACTIONS(4774),
    [anon_sym_shortreal] = ACTIONS(4774),
    [anon_sym_real] = ACTIONS(4774),
    [anon_sym_realtime] = ACTIONS(4774),
    [anon_sym_supply0] = ACTIONS(4774),
    [anon_sym_supply1] = ACTIONS(4774),
    [anon_sym_signed] = ACTIONS(4774),
    [anon_sym_unsigned] = ACTIONS(4774),
    [anon_sym_task] = ACTIONS(4774),
    [anon_sym_assert] = ACTIONS(4774),
    [anon_sym_property] = ACTIONS(4774),
    [anon_sym_assume] = ACTIONS(4774),
    [anon_sym_cover] = ACTIONS(4774),
    [anon_sym_sequence] = ACTIONS(4774),
    [anon_sym_restrict] = ACTIONS(4774),
    [anon_sym_not] = ACTIONS(4774),
    [anon_sym_or] = ACTIONS(4774),
    [anon_sym_and] = ACTIONS(4774),
    [anon_sym_case] = ACTIONS(4774),
    [anon_sym_always] = ACTIONS(4774),
    [anon_sym_covergroup] = ACTIONS(4774),
    [anon_sym_let] = ACTIONS(4774),
    [anon_sym_pulldown] = ACTIONS(4774),
    [anon_sym_pullup] = ACTIONS(4774),
    [anon_sym_cmos] = ACTIONS(4774),
    [anon_sym_rcmos] = ACTIONS(4774),
    [anon_sym_bufif0] = ACTIONS(4774),
    [anon_sym_bufif1] = ACTIONS(4774),
    [anon_sym_notif0] = ACTIONS(4774),
    [anon_sym_notif1] = ACTIONS(4774),
    [anon_sym_nmos] = ACTIONS(4774),
    [anon_sym_pmos] = ACTIONS(4774),
    [anon_sym_rnmos] = ACTIONS(4774),
    [anon_sym_rpmos] = ACTIONS(4774),
    [anon_sym_nand] = ACTIONS(4774),
    [anon_sym_nor] = ACTIONS(4774),
    [anon_sym_xor] = ACTIONS(4774),
    [anon_sym_xnor] = ACTIONS(4774),
    [anon_sym_buf] = ACTIONS(4774),
    [anon_sym_tranif0] = ACTIONS(4774),
    [anon_sym_tranif1] = ACTIONS(4774),
    [anon_sym_rtranif1] = ACTIONS(4774),
    [anon_sym_rtranif0] = ACTIONS(4774),
    [anon_sym_tran] = ACTIONS(4774),
    [anon_sym_rtran] = ACTIONS(4774),
    [anon_sym_generate] = ACTIONS(4774),
    [anon_sym_endgenerate] = ACTIONS(4774),
    [anon_sym_for] = ACTIONS(4774),
    [anon_sym_initial] = ACTIONS(4774),
    [anon_sym_assign] = ACTIONS(4774),
    [anon_sym_alias] = ACTIONS(4774),
    [anon_sym_always_comb] = ACTIONS(4774),
    [anon_sym_always_latch] = ACTIONS(4774),
    [anon_sym_always_ff] = ACTIONS(4774),
    [anon_sym_final] = ACTIONS(4774),
    [anon_sym_global] = ACTIONS(4774),
    [anon_sym_LPAREN_STAR] = ACTIONS(4772),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4772),
    [anon_sym_DOLLARunit] = ACTIONS(4772),
  },
  [5011] = {
    [sym_simple_identifier] = ACTIONS(5310),
    [anon_sym_wire] = ACTIONS(5310),
    [anon_sym_tri] = ACTIONS(5310),
    [anon_sym_tri0] = ACTIONS(5310),
    [anon_sym_tri1] = ACTIONS(5310),
    [anon_sym_wand] = ACTIONS(5310),
    [anon_sym_triand] = ACTIONS(5310),
    [anon_sym_wor] = ACTIONS(5310),
    [anon_sym_trior] = ACTIONS(5310),
    [anon_sym_trireg] = ACTIONS(5310),
    [anon_sym_uwire] = ACTIONS(5310),
    [anon_sym_SEMI] = ACTIONS(5308),
    [anon_sym_extern] = ACTIONS(5310),
    [anon_sym_interface] = ACTIONS(5310),
    [anon_sym_checker] = ACTIONS(5310),
    [anon_sym_virtual] = ACTIONS(5310),
    [anon_sym_class] = ACTIONS(5310),
    [anon_sym_type] = ACTIONS(5310),
    [anon_sym_DOLLARfatal] = ACTIONS(5308),
    [anon_sym_DOLLARerror] = ACTIONS(5308),
    [anon_sym_DOLLARwarning] = ACTIONS(5308),
    [anon_sym_DOLLARinfo] = ACTIONS(5308),
    [anon_sym_default] = ACTIONS(5310),
    [anon_sym_clocking] = ACTIONS(5310),
    [anon_sym_defparam] = ACTIONS(5310),
    [anon_sym_bind] = ACTIONS(5310),
    [anon_sym_rand] = ACTIONS(5310),
    [anon_sym_const] = ACTIONS(5310),
    [anon_sym_function] = ACTIONS(5310),
    [anon_sym_static] = ACTIONS(5310),
    [anon_sym_constraint] = ACTIONS(5310),
    [anon_sym_if] = ACTIONS(5310),
    [anon_sym_else] = ACTIONS(5310),
    [anon_sym_LBRACK] = ACTIONS(5308),
    [anon_sym_localparam] = ACTIONS(5310),
    [anon_sym_parameter] = ACTIONS(5310),
    [anon_sym_var] = ACTIONS(5310),
    [anon_sym_import] = ACTIONS(5310),
    [anon_sym_export] = ACTIONS(5310),
    [anon_sym_genvar] = ACTIONS(5310),
    [anon_sym_interconnect] = ACTIONS(5310),
    [anon_sym_typedef] = ACTIONS(5310),
    [anon_sym_enum] = ACTIONS(5310),
    [anon_sym_struct] = ACTIONS(5310),
    [anon_sym_union] = ACTIONS(5310),
    [anon_sym_nettype] = ACTIONS(5310),
    [anon_sym_automatic] = ACTIONS(5310),
    [anon_sym_string] = ACTIONS(5310),
    [anon_sym_chandle] = ACTIONS(5310),
    [anon_sym_event] = ACTIONS(5310),
    [anon_sym_byte] = ACTIONS(5310),
    [anon_sym_shortint] = ACTIONS(5310),
    [anon_sym_int] = ACTIONS(5310),
    [anon_sym_longint] = ACTIONS(5310),
    [anon_sym_integer] = ACTIONS(5310),
    [anon_sym_time] = ACTIONS(5310),
    [anon_sym_bit] = ACTIONS(5310),
    [anon_sym_logic] = ACTIONS(5310),
    [anon_sym_reg] = ACTIONS(5310),
    [anon_sym_shortreal] = ACTIONS(5310),
    [anon_sym_real] = ACTIONS(5310),
    [anon_sym_realtime] = ACTIONS(5310),
    [anon_sym_supply0] = ACTIONS(5310),
    [anon_sym_supply1] = ACTIONS(5310),
    [anon_sym_signed] = ACTIONS(5310),
    [anon_sym_unsigned] = ACTIONS(5310),
    [anon_sym_task] = ACTIONS(5310),
    [anon_sym_assert] = ACTIONS(5310),
    [anon_sym_property] = ACTIONS(5310),
    [anon_sym_assume] = ACTIONS(5310),
    [anon_sym_cover] = ACTIONS(5310),
    [anon_sym_sequence] = ACTIONS(5310),
    [anon_sym_restrict] = ACTIONS(5310),
    [anon_sym_not] = ACTIONS(5310),
    [anon_sym_or] = ACTIONS(5310),
    [anon_sym_and] = ACTIONS(5310),
    [anon_sym_case] = ACTIONS(5310),
    [anon_sym_always] = ACTIONS(5310),
    [anon_sym_covergroup] = ACTIONS(5310),
    [anon_sym_let] = ACTIONS(5310),
    [anon_sym_pulldown] = ACTIONS(5310),
    [anon_sym_pullup] = ACTIONS(5310),
    [anon_sym_cmos] = ACTIONS(5310),
    [anon_sym_rcmos] = ACTIONS(5310),
    [anon_sym_bufif0] = ACTIONS(5310),
    [anon_sym_bufif1] = ACTIONS(5310),
    [anon_sym_notif0] = ACTIONS(5310),
    [anon_sym_notif1] = ACTIONS(5310),
    [anon_sym_nmos] = ACTIONS(5310),
    [anon_sym_pmos] = ACTIONS(5310),
    [anon_sym_rnmos] = ACTIONS(5310),
    [anon_sym_rpmos] = ACTIONS(5310),
    [anon_sym_nand] = ACTIONS(5310),
    [anon_sym_nor] = ACTIONS(5310),
    [anon_sym_xor] = ACTIONS(5310),
    [anon_sym_xnor] = ACTIONS(5310),
    [anon_sym_buf] = ACTIONS(5310),
    [anon_sym_tranif0] = ACTIONS(5310),
    [anon_sym_tranif1] = ACTIONS(5310),
    [anon_sym_rtranif1] = ACTIONS(5310),
    [anon_sym_rtranif0] = ACTIONS(5310),
    [anon_sym_tran] = ACTIONS(5310),
    [anon_sym_rtran] = ACTIONS(5310),
    [anon_sym_generate] = ACTIONS(5310),
    [anon_sym_endgenerate] = ACTIONS(5310),
    [anon_sym_for] = ACTIONS(5310),
    [anon_sym_initial] = ACTIONS(5310),
    [anon_sym_assign] = ACTIONS(5310),
    [anon_sym_alias] = ACTIONS(5310),
    [anon_sym_always_comb] = ACTIONS(5310),
    [anon_sym_always_latch] = ACTIONS(5310),
    [anon_sym_always_ff] = ACTIONS(5310),
    [anon_sym_final] = ACTIONS(5310),
    [anon_sym_global] = ACTIONS(5310),
    [anon_sym_LPAREN_STAR] = ACTIONS(5308),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5308),
    [anon_sym_DOLLARunit] = ACTIONS(5308),
  },
  [5012] = {
    [sym_simple_identifier] = ACTIONS(6253),
    [anon_sym_wire] = ACTIONS(6253),
    [anon_sym_tri] = ACTIONS(6253),
    [anon_sym_tri0] = ACTIONS(6253),
    [anon_sym_tri1] = ACTIONS(6253),
    [anon_sym_wand] = ACTIONS(6253),
    [anon_sym_triand] = ACTIONS(6253),
    [anon_sym_wor] = ACTIONS(6253),
    [anon_sym_trior] = ACTIONS(6253),
    [anon_sym_trireg] = ACTIONS(6253),
    [anon_sym_uwire] = ACTIONS(6253),
    [anon_sym_SEMI] = ACTIONS(6255),
    [anon_sym_extern] = ACTIONS(6253),
    [anon_sym_interface] = ACTIONS(6253),
    [anon_sym_checker] = ACTIONS(6253),
    [anon_sym_virtual] = ACTIONS(6253),
    [anon_sym_class] = ACTIONS(6253),
    [anon_sym_type] = ACTIONS(6253),
    [anon_sym_DOLLARfatal] = ACTIONS(6255),
    [anon_sym_DOLLARerror] = ACTIONS(6255),
    [anon_sym_DOLLARwarning] = ACTIONS(6255),
    [anon_sym_DOLLARinfo] = ACTIONS(6255),
    [anon_sym_default] = ACTIONS(6253),
    [anon_sym_clocking] = ACTIONS(6253),
    [anon_sym_defparam] = ACTIONS(6253),
    [anon_sym_bind] = ACTIONS(6253),
    [anon_sym_rand] = ACTIONS(6253),
    [anon_sym_const] = ACTIONS(6253),
    [anon_sym_function] = ACTIONS(6253),
    [anon_sym_static] = ACTIONS(6253),
    [anon_sym_constraint] = ACTIONS(6253),
    [anon_sym_if] = ACTIONS(6253),
    [anon_sym_else] = ACTIONS(6253),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [anon_sym_localparam] = ACTIONS(6253),
    [anon_sym_parameter] = ACTIONS(6253),
    [anon_sym_var] = ACTIONS(6253),
    [anon_sym_import] = ACTIONS(6253),
    [anon_sym_export] = ACTIONS(6253),
    [anon_sym_genvar] = ACTIONS(6253),
    [anon_sym_interconnect] = ACTIONS(6253),
    [anon_sym_typedef] = ACTIONS(6253),
    [anon_sym_enum] = ACTIONS(6253),
    [anon_sym_struct] = ACTIONS(6253),
    [anon_sym_union] = ACTIONS(6253),
    [anon_sym_nettype] = ACTIONS(6253),
    [anon_sym_automatic] = ACTIONS(6253),
    [anon_sym_string] = ACTIONS(6253),
    [anon_sym_chandle] = ACTIONS(6253),
    [anon_sym_event] = ACTIONS(6253),
    [anon_sym_byte] = ACTIONS(6253),
    [anon_sym_shortint] = ACTIONS(6253),
    [anon_sym_int] = ACTIONS(6253),
    [anon_sym_longint] = ACTIONS(6253),
    [anon_sym_integer] = ACTIONS(6253),
    [anon_sym_time] = ACTIONS(6253),
    [anon_sym_bit] = ACTIONS(6253),
    [anon_sym_logic] = ACTIONS(6253),
    [anon_sym_reg] = ACTIONS(6253),
    [anon_sym_shortreal] = ACTIONS(6253),
    [anon_sym_real] = ACTIONS(6253),
    [anon_sym_realtime] = ACTIONS(6253),
    [anon_sym_supply0] = ACTIONS(6253),
    [anon_sym_supply1] = ACTIONS(6253),
    [anon_sym_signed] = ACTIONS(6253),
    [anon_sym_unsigned] = ACTIONS(6253),
    [anon_sym_task] = ACTIONS(6253),
    [anon_sym_assert] = ACTIONS(6253),
    [anon_sym_property] = ACTIONS(6253),
    [anon_sym_assume] = ACTIONS(6253),
    [anon_sym_cover] = ACTIONS(6253),
    [anon_sym_sequence] = ACTIONS(6253),
    [anon_sym_restrict] = ACTIONS(6253),
    [anon_sym_not] = ACTIONS(6253),
    [anon_sym_or] = ACTIONS(6253),
    [anon_sym_and] = ACTIONS(6253),
    [anon_sym_case] = ACTIONS(6253),
    [anon_sym_always] = ACTIONS(6253),
    [anon_sym_covergroup] = ACTIONS(6253),
    [anon_sym_end] = ACTIONS(6253),
    [anon_sym_let] = ACTIONS(6253),
    [anon_sym_pulldown] = ACTIONS(6253),
    [anon_sym_pullup] = ACTIONS(6253),
    [anon_sym_cmos] = ACTIONS(6253),
    [anon_sym_rcmos] = ACTIONS(6253),
    [anon_sym_bufif0] = ACTIONS(6253),
    [anon_sym_bufif1] = ACTIONS(6253),
    [anon_sym_notif0] = ACTIONS(6253),
    [anon_sym_notif1] = ACTIONS(6253),
    [anon_sym_nmos] = ACTIONS(6253),
    [anon_sym_pmos] = ACTIONS(6253),
    [anon_sym_rnmos] = ACTIONS(6253),
    [anon_sym_rpmos] = ACTIONS(6253),
    [anon_sym_nand] = ACTIONS(6253),
    [anon_sym_nor] = ACTIONS(6253),
    [anon_sym_xor] = ACTIONS(6253),
    [anon_sym_xnor] = ACTIONS(6253),
    [anon_sym_buf] = ACTIONS(6253),
    [anon_sym_tranif0] = ACTIONS(6253),
    [anon_sym_tranif1] = ACTIONS(6253),
    [anon_sym_rtranif1] = ACTIONS(6253),
    [anon_sym_rtranif0] = ACTIONS(6253),
    [anon_sym_tran] = ACTIONS(6253),
    [anon_sym_rtran] = ACTIONS(6253),
    [anon_sym_generate] = ACTIONS(6253),
    [anon_sym_for] = ACTIONS(6253),
    [anon_sym_initial] = ACTIONS(6253),
    [anon_sym_assign] = ACTIONS(6253),
    [anon_sym_alias] = ACTIONS(6253),
    [anon_sym_always_comb] = ACTIONS(6253),
    [anon_sym_always_latch] = ACTIONS(6253),
    [anon_sym_always_ff] = ACTIONS(6253),
    [anon_sym_final] = ACTIONS(6253),
    [anon_sym_global] = ACTIONS(6253),
    [anon_sym_LPAREN_STAR] = ACTIONS(6255),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6255),
    [anon_sym_DOLLARunit] = ACTIONS(6255),
  },
  [5013] = {
    [sym_simple_identifier] = ACTIONS(6257),
    [anon_sym_wire] = ACTIONS(6257),
    [anon_sym_tri] = ACTIONS(6257),
    [anon_sym_tri0] = ACTIONS(6257),
    [anon_sym_tri1] = ACTIONS(6257),
    [anon_sym_wand] = ACTIONS(6257),
    [anon_sym_triand] = ACTIONS(6257),
    [anon_sym_wor] = ACTIONS(6257),
    [anon_sym_trior] = ACTIONS(6257),
    [anon_sym_trireg] = ACTIONS(6257),
    [anon_sym_uwire] = ACTIONS(6257),
    [anon_sym_SEMI] = ACTIONS(6259),
    [anon_sym_extern] = ACTIONS(6257),
    [anon_sym_interface] = ACTIONS(6257),
    [anon_sym_checker] = ACTIONS(6257),
    [anon_sym_virtual] = ACTIONS(6257),
    [anon_sym_class] = ACTIONS(6257),
    [anon_sym_type] = ACTIONS(6257),
    [anon_sym_DOLLARfatal] = ACTIONS(6259),
    [anon_sym_DOLLARerror] = ACTIONS(6259),
    [anon_sym_DOLLARwarning] = ACTIONS(6259),
    [anon_sym_DOLLARinfo] = ACTIONS(6259),
    [anon_sym_default] = ACTIONS(6257),
    [anon_sym_clocking] = ACTIONS(6257),
    [anon_sym_defparam] = ACTIONS(6257),
    [anon_sym_bind] = ACTIONS(6257),
    [anon_sym_rand] = ACTIONS(6257),
    [anon_sym_const] = ACTIONS(6257),
    [anon_sym_function] = ACTIONS(6257),
    [anon_sym_static] = ACTIONS(6257),
    [anon_sym_constraint] = ACTIONS(6257),
    [anon_sym_if] = ACTIONS(6257),
    [anon_sym_else] = ACTIONS(6257),
    [anon_sym_LBRACK] = ACTIONS(6259),
    [anon_sym_localparam] = ACTIONS(6257),
    [anon_sym_parameter] = ACTIONS(6257),
    [anon_sym_var] = ACTIONS(6257),
    [anon_sym_import] = ACTIONS(6257),
    [anon_sym_export] = ACTIONS(6257),
    [anon_sym_genvar] = ACTIONS(6257),
    [anon_sym_interconnect] = ACTIONS(6257),
    [anon_sym_typedef] = ACTIONS(6257),
    [anon_sym_enum] = ACTIONS(6257),
    [anon_sym_struct] = ACTIONS(6257),
    [anon_sym_union] = ACTIONS(6257),
    [anon_sym_nettype] = ACTIONS(6257),
    [anon_sym_automatic] = ACTIONS(6257),
    [anon_sym_string] = ACTIONS(6257),
    [anon_sym_chandle] = ACTIONS(6257),
    [anon_sym_event] = ACTIONS(6257),
    [anon_sym_byte] = ACTIONS(6257),
    [anon_sym_shortint] = ACTIONS(6257),
    [anon_sym_int] = ACTIONS(6257),
    [anon_sym_longint] = ACTIONS(6257),
    [anon_sym_integer] = ACTIONS(6257),
    [anon_sym_time] = ACTIONS(6257),
    [anon_sym_bit] = ACTIONS(6257),
    [anon_sym_logic] = ACTIONS(6257),
    [anon_sym_reg] = ACTIONS(6257),
    [anon_sym_shortreal] = ACTIONS(6257),
    [anon_sym_real] = ACTIONS(6257),
    [anon_sym_realtime] = ACTIONS(6257),
    [anon_sym_supply0] = ACTIONS(6257),
    [anon_sym_supply1] = ACTIONS(6257),
    [anon_sym_signed] = ACTIONS(6257),
    [anon_sym_unsigned] = ACTIONS(6257),
    [anon_sym_task] = ACTIONS(6257),
    [anon_sym_assert] = ACTIONS(6257),
    [anon_sym_property] = ACTIONS(6257),
    [anon_sym_assume] = ACTIONS(6257),
    [anon_sym_cover] = ACTIONS(6257),
    [anon_sym_sequence] = ACTIONS(6257),
    [anon_sym_restrict] = ACTIONS(6257),
    [anon_sym_not] = ACTIONS(6257),
    [anon_sym_or] = ACTIONS(6257),
    [anon_sym_and] = ACTIONS(6257),
    [anon_sym_case] = ACTIONS(6257),
    [anon_sym_always] = ACTIONS(6257),
    [anon_sym_covergroup] = ACTIONS(6257),
    [anon_sym_end] = ACTIONS(6257),
    [anon_sym_let] = ACTIONS(6257),
    [anon_sym_pulldown] = ACTIONS(6257),
    [anon_sym_pullup] = ACTIONS(6257),
    [anon_sym_cmos] = ACTIONS(6257),
    [anon_sym_rcmos] = ACTIONS(6257),
    [anon_sym_bufif0] = ACTIONS(6257),
    [anon_sym_bufif1] = ACTIONS(6257),
    [anon_sym_notif0] = ACTIONS(6257),
    [anon_sym_notif1] = ACTIONS(6257),
    [anon_sym_nmos] = ACTIONS(6257),
    [anon_sym_pmos] = ACTIONS(6257),
    [anon_sym_rnmos] = ACTIONS(6257),
    [anon_sym_rpmos] = ACTIONS(6257),
    [anon_sym_nand] = ACTIONS(6257),
    [anon_sym_nor] = ACTIONS(6257),
    [anon_sym_xor] = ACTIONS(6257),
    [anon_sym_xnor] = ACTIONS(6257),
    [anon_sym_buf] = ACTIONS(6257),
    [anon_sym_tranif0] = ACTIONS(6257),
    [anon_sym_tranif1] = ACTIONS(6257),
    [anon_sym_rtranif1] = ACTIONS(6257),
    [anon_sym_rtranif0] = ACTIONS(6257),
    [anon_sym_tran] = ACTIONS(6257),
    [anon_sym_rtran] = ACTIONS(6257),
    [anon_sym_generate] = ACTIONS(6257),
    [anon_sym_for] = ACTIONS(6257),
    [anon_sym_initial] = ACTIONS(6257),
    [anon_sym_assign] = ACTIONS(6257),
    [anon_sym_alias] = ACTIONS(6257),
    [anon_sym_always_comb] = ACTIONS(6257),
    [anon_sym_always_latch] = ACTIONS(6257),
    [anon_sym_always_ff] = ACTIONS(6257),
    [anon_sym_final] = ACTIONS(6257),
    [anon_sym_global] = ACTIONS(6257),
    [anon_sym_LPAREN_STAR] = ACTIONS(6259),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6259),
    [anon_sym_DOLLARunit] = ACTIONS(6259),
  },
  [5014] = {
    [sym_simple_identifier] = ACTIONS(4230),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_rand] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_endgenerate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [5015] = {
    [sym_simple_identifier] = ACTIONS(6261),
    [anon_sym_wire] = ACTIONS(6261),
    [anon_sym_tri] = ACTIONS(6261),
    [anon_sym_tri0] = ACTIONS(6261),
    [anon_sym_tri1] = ACTIONS(6261),
    [anon_sym_wand] = ACTIONS(6261),
    [anon_sym_triand] = ACTIONS(6261),
    [anon_sym_wor] = ACTIONS(6261),
    [anon_sym_trior] = ACTIONS(6261),
    [anon_sym_trireg] = ACTIONS(6261),
    [anon_sym_uwire] = ACTIONS(6261),
    [anon_sym_SEMI] = ACTIONS(6263),
    [anon_sym_extern] = ACTIONS(6261),
    [anon_sym_interface] = ACTIONS(6261),
    [anon_sym_checker] = ACTIONS(6261),
    [anon_sym_virtual] = ACTIONS(6261),
    [anon_sym_class] = ACTIONS(6261),
    [anon_sym_type] = ACTIONS(6261),
    [anon_sym_DOLLARfatal] = ACTIONS(6263),
    [anon_sym_DOLLARerror] = ACTIONS(6263),
    [anon_sym_DOLLARwarning] = ACTIONS(6263),
    [anon_sym_DOLLARinfo] = ACTIONS(6263),
    [anon_sym_default] = ACTIONS(6261),
    [anon_sym_clocking] = ACTIONS(6261),
    [anon_sym_defparam] = ACTIONS(6261),
    [anon_sym_bind] = ACTIONS(6261),
    [anon_sym_rand] = ACTIONS(6261),
    [anon_sym_const] = ACTIONS(6261),
    [anon_sym_function] = ACTIONS(6261),
    [anon_sym_static] = ACTIONS(6261),
    [anon_sym_constraint] = ACTIONS(6261),
    [anon_sym_if] = ACTIONS(6261),
    [anon_sym_else] = ACTIONS(6261),
    [anon_sym_LBRACK] = ACTIONS(6263),
    [anon_sym_localparam] = ACTIONS(6261),
    [anon_sym_parameter] = ACTIONS(6261),
    [anon_sym_var] = ACTIONS(6261),
    [anon_sym_import] = ACTIONS(6261),
    [anon_sym_export] = ACTIONS(6261),
    [anon_sym_genvar] = ACTIONS(6261),
    [anon_sym_interconnect] = ACTIONS(6261),
    [anon_sym_typedef] = ACTIONS(6261),
    [anon_sym_enum] = ACTIONS(6261),
    [anon_sym_struct] = ACTIONS(6261),
    [anon_sym_union] = ACTIONS(6261),
    [anon_sym_nettype] = ACTIONS(6261),
    [anon_sym_automatic] = ACTIONS(6261),
    [anon_sym_string] = ACTIONS(6261),
    [anon_sym_chandle] = ACTIONS(6261),
    [anon_sym_event] = ACTIONS(6261),
    [anon_sym_byte] = ACTIONS(6261),
    [anon_sym_shortint] = ACTIONS(6261),
    [anon_sym_int] = ACTIONS(6261),
    [anon_sym_longint] = ACTIONS(6261),
    [anon_sym_integer] = ACTIONS(6261),
    [anon_sym_time] = ACTIONS(6261),
    [anon_sym_bit] = ACTIONS(6261),
    [anon_sym_logic] = ACTIONS(6261),
    [anon_sym_reg] = ACTIONS(6261),
    [anon_sym_shortreal] = ACTIONS(6261),
    [anon_sym_real] = ACTIONS(6261),
    [anon_sym_realtime] = ACTIONS(6261),
    [anon_sym_supply0] = ACTIONS(6261),
    [anon_sym_supply1] = ACTIONS(6261),
    [anon_sym_signed] = ACTIONS(6261),
    [anon_sym_unsigned] = ACTIONS(6261),
    [anon_sym_task] = ACTIONS(6261),
    [anon_sym_assert] = ACTIONS(6261),
    [anon_sym_property] = ACTIONS(6261),
    [anon_sym_assume] = ACTIONS(6261),
    [anon_sym_cover] = ACTIONS(6261),
    [anon_sym_sequence] = ACTIONS(6261),
    [anon_sym_restrict] = ACTIONS(6261),
    [anon_sym_not] = ACTIONS(6261),
    [anon_sym_or] = ACTIONS(6261),
    [anon_sym_and] = ACTIONS(6261),
    [anon_sym_case] = ACTIONS(6261),
    [anon_sym_always] = ACTIONS(6261),
    [anon_sym_covergroup] = ACTIONS(6261),
    [anon_sym_end] = ACTIONS(6261),
    [anon_sym_let] = ACTIONS(6261),
    [anon_sym_pulldown] = ACTIONS(6261),
    [anon_sym_pullup] = ACTIONS(6261),
    [anon_sym_cmos] = ACTIONS(6261),
    [anon_sym_rcmos] = ACTIONS(6261),
    [anon_sym_bufif0] = ACTIONS(6261),
    [anon_sym_bufif1] = ACTIONS(6261),
    [anon_sym_notif0] = ACTIONS(6261),
    [anon_sym_notif1] = ACTIONS(6261),
    [anon_sym_nmos] = ACTIONS(6261),
    [anon_sym_pmos] = ACTIONS(6261),
    [anon_sym_rnmos] = ACTIONS(6261),
    [anon_sym_rpmos] = ACTIONS(6261),
    [anon_sym_nand] = ACTIONS(6261),
    [anon_sym_nor] = ACTIONS(6261),
    [anon_sym_xor] = ACTIONS(6261),
    [anon_sym_xnor] = ACTIONS(6261),
    [anon_sym_buf] = ACTIONS(6261),
    [anon_sym_tranif0] = ACTIONS(6261),
    [anon_sym_tranif1] = ACTIONS(6261),
    [anon_sym_rtranif1] = ACTIONS(6261),
    [anon_sym_rtranif0] = ACTIONS(6261),
    [anon_sym_tran] = ACTIONS(6261),
    [anon_sym_rtran] = ACTIONS(6261),
    [anon_sym_generate] = ACTIONS(6261),
    [anon_sym_for] = ACTIONS(6261),
    [anon_sym_initial] = ACTIONS(6261),
    [anon_sym_assign] = ACTIONS(6261),
    [anon_sym_alias] = ACTIONS(6261),
    [anon_sym_always_comb] = ACTIONS(6261),
    [anon_sym_always_latch] = ACTIONS(6261),
    [anon_sym_always_ff] = ACTIONS(6261),
    [anon_sym_final] = ACTIONS(6261),
    [anon_sym_global] = ACTIONS(6261),
    [anon_sym_LPAREN_STAR] = ACTIONS(6263),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6263),
    [anon_sym_DOLLARunit] = ACTIONS(6263),
  },
  [5016] = {
    [sym_simple_identifier] = ACTIONS(6303),
    [anon_sym_wire] = ACTIONS(6303),
    [anon_sym_tri] = ACTIONS(6303),
    [anon_sym_tri0] = ACTIONS(6303),
    [anon_sym_tri1] = ACTIONS(6303),
    [anon_sym_wand] = ACTIONS(6303),
    [anon_sym_triand] = ACTIONS(6303),
    [anon_sym_wor] = ACTIONS(6303),
    [anon_sym_trior] = ACTIONS(6303),
    [anon_sym_trireg] = ACTIONS(6303),
    [anon_sym_uwire] = ACTIONS(6303),
    [anon_sym_SEMI] = ACTIONS(6305),
    [anon_sym_extern] = ACTIONS(6303),
    [anon_sym_interface] = ACTIONS(6303),
    [anon_sym_checker] = ACTIONS(6303),
    [anon_sym_virtual] = ACTIONS(6303),
    [anon_sym_class] = ACTIONS(6303),
    [anon_sym_type] = ACTIONS(6303),
    [anon_sym_DOLLARfatal] = ACTIONS(6305),
    [anon_sym_DOLLARerror] = ACTIONS(6305),
    [anon_sym_DOLLARwarning] = ACTIONS(6305),
    [anon_sym_DOLLARinfo] = ACTIONS(6305),
    [anon_sym_default] = ACTIONS(6303),
    [anon_sym_clocking] = ACTIONS(6303),
    [anon_sym_defparam] = ACTIONS(6303),
    [anon_sym_bind] = ACTIONS(6303),
    [anon_sym_rand] = ACTIONS(6303),
    [anon_sym_const] = ACTIONS(6303),
    [anon_sym_function] = ACTIONS(6303),
    [anon_sym_static] = ACTIONS(6303),
    [anon_sym_constraint] = ACTIONS(6303),
    [anon_sym_if] = ACTIONS(6303),
    [anon_sym_else] = ACTIONS(6303),
    [anon_sym_LBRACK] = ACTIONS(6305),
    [anon_sym_localparam] = ACTIONS(6303),
    [anon_sym_parameter] = ACTIONS(6303),
    [anon_sym_var] = ACTIONS(6303),
    [anon_sym_import] = ACTIONS(6303),
    [anon_sym_export] = ACTIONS(6303),
    [anon_sym_genvar] = ACTIONS(6303),
    [anon_sym_interconnect] = ACTIONS(6303),
    [anon_sym_typedef] = ACTIONS(6303),
    [anon_sym_enum] = ACTIONS(6303),
    [anon_sym_struct] = ACTIONS(6303),
    [anon_sym_union] = ACTIONS(6303),
    [anon_sym_nettype] = ACTIONS(6303),
    [anon_sym_automatic] = ACTIONS(6303),
    [anon_sym_string] = ACTIONS(6303),
    [anon_sym_chandle] = ACTIONS(6303),
    [anon_sym_event] = ACTIONS(6303),
    [anon_sym_byte] = ACTIONS(6303),
    [anon_sym_shortint] = ACTIONS(6303),
    [anon_sym_int] = ACTIONS(6303),
    [anon_sym_longint] = ACTIONS(6303),
    [anon_sym_integer] = ACTIONS(6303),
    [anon_sym_time] = ACTIONS(6303),
    [anon_sym_bit] = ACTIONS(6303),
    [anon_sym_logic] = ACTIONS(6303),
    [anon_sym_reg] = ACTIONS(6303),
    [anon_sym_shortreal] = ACTIONS(6303),
    [anon_sym_real] = ACTIONS(6303),
    [anon_sym_realtime] = ACTIONS(6303),
    [anon_sym_supply0] = ACTIONS(6303),
    [anon_sym_supply1] = ACTIONS(6303),
    [anon_sym_signed] = ACTIONS(6303),
    [anon_sym_unsigned] = ACTIONS(6303),
    [anon_sym_task] = ACTIONS(6303),
    [anon_sym_assert] = ACTIONS(6303),
    [anon_sym_property] = ACTIONS(6303),
    [anon_sym_assume] = ACTIONS(6303),
    [anon_sym_cover] = ACTIONS(6303),
    [anon_sym_sequence] = ACTIONS(6303),
    [anon_sym_restrict] = ACTIONS(6303),
    [anon_sym_not] = ACTIONS(6303),
    [anon_sym_or] = ACTIONS(6303),
    [anon_sym_and] = ACTIONS(6303),
    [anon_sym_case] = ACTIONS(6303),
    [anon_sym_always] = ACTIONS(6303),
    [anon_sym_covergroup] = ACTIONS(6303),
    [anon_sym_end] = ACTIONS(6303),
    [anon_sym_let] = ACTIONS(6303),
    [anon_sym_pulldown] = ACTIONS(6303),
    [anon_sym_pullup] = ACTIONS(6303),
    [anon_sym_cmos] = ACTIONS(6303),
    [anon_sym_rcmos] = ACTIONS(6303),
    [anon_sym_bufif0] = ACTIONS(6303),
    [anon_sym_bufif1] = ACTIONS(6303),
    [anon_sym_notif0] = ACTIONS(6303),
    [anon_sym_notif1] = ACTIONS(6303),
    [anon_sym_nmos] = ACTIONS(6303),
    [anon_sym_pmos] = ACTIONS(6303),
    [anon_sym_rnmos] = ACTIONS(6303),
    [anon_sym_rpmos] = ACTIONS(6303),
    [anon_sym_nand] = ACTIONS(6303),
    [anon_sym_nor] = ACTIONS(6303),
    [anon_sym_xor] = ACTIONS(6303),
    [anon_sym_xnor] = ACTIONS(6303),
    [anon_sym_buf] = ACTIONS(6303),
    [anon_sym_tranif0] = ACTIONS(6303),
    [anon_sym_tranif1] = ACTIONS(6303),
    [anon_sym_rtranif1] = ACTIONS(6303),
    [anon_sym_rtranif0] = ACTIONS(6303),
    [anon_sym_tran] = ACTIONS(6303),
    [anon_sym_rtran] = ACTIONS(6303),
    [anon_sym_generate] = ACTIONS(6303),
    [anon_sym_for] = ACTIONS(6303),
    [anon_sym_initial] = ACTIONS(6303),
    [anon_sym_assign] = ACTIONS(6303),
    [anon_sym_alias] = ACTIONS(6303),
    [anon_sym_always_comb] = ACTIONS(6303),
    [anon_sym_always_latch] = ACTIONS(6303),
    [anon_sym_always_ff] = ACTIONS(6303),
    [anon_sym_final] = ACTIONS(6303),
    [anon_sym_global] = ACTIONS(6303),
    [anon_sym_LPAREN_STAR] = ACTIONS(6305),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6305),
    [anon_sym_DOLLARunit] = ACTIONS(6305),
  },
  [5017] = {
    [sym_simple_identifier] = ACTIONS(6287),
    [anon_sym_wire] = ACTIONS(6287),
    [anon_sym_tri] = ACTIONS(6287),
    [anon_sym_tri0] = ACTIONS(6287),
    [anon_sym_tri1] = ACTIONS(6287),
    [anon_sym_wand] = ACTIONS(6287),
    [anon_sym_triand] = ACTIONS(6287),
    [anon_sym_wor] = ACTIONS(6287),
    [anon_sym_trior] = ACTIONS(6287),
    [anon_sym_trireg] = ACTIONS(6287),
    [anon_sym_uwire] = ACTIONS(6287),
    [anon_sym_SEMI] = ACTIONS(6289),
    [anon_sym_extern] = ACTIONS(6287),
    [anon_sym_interface] = ACTIONS(6287),
    [anon_sym_checker] = ACTIONS(6287),
    [anon_sym_virtual] = ACTIONS(6287),
    [anon_sym_class] = ACTIONS(6287),
    [anon_sym_type] = ACTIONS(6287),
    [anon_sym_DOLLARfatal] = ACTIONS(6289),
    [anon_sym_DOLLARerror] = ACTIONS(6289),
    [anon_sym_DOLLARwarning] = ACTIONS(6289),
    [anon_sym_DOLLARinfo] = ACTIONS(6289),
    [anon_sym_default] = ACTIONS(6287),
    [anon_sym_clocking] = ACTIONS(6287),
    [anon_sym_defparam] = ACTIONS(6287),
    [anon_sym_bind] = ACTIONS(6287),
    [anon_sym_rand] = ACTIONS(6287),
    [anon_sym_const] = ACTIONS(6287),
    [anon_sym_function] = ACTIONS(6287),
    [anon_sym_static] = ACTIONS(6287),
    [anon_sym_constraint] = ACTIONS(6287),
    [anon_sym_if] = ACTIONS(6287),
    [anon_sym_else] = ACTIONS(6287),
    [anon_sym_LBRACK] = ACTIONS(6289),
    [anon_sym_localparam] = ACTIONS(6287),
    [anon_sym_parameter] = ACTIONS(6287),
    [anon_sym_var] = ACTIONS(6287),
    [anon_sym_import] = ACTIONS(6287),
    [anon_sym_export] = ACTIONS(6287),
    [anon_sym_genvar] = ACTIONS(6287),
    [anon_sym_interconnect] = ACTIONS(6287),
    [anon_sym_typedef] = ACTIONS(6287),
    [anon_sym_enum] = ACTIONS(6287),
    [anon_sym_struct] = ACTIONS(6287),
    [anon_sym_union] = ACTIONS(6287),
    [anon_sym_nettype] = ACTIONS(6287),
    [anon_sym_automatic] = ACTIONS(6287),
    [anon_sym_string] = ACTIONS(6287),
    [anon_sym_chandle] = ACTIONS(6287),
    [anon_sym_event] = ACTIONS(6287),
    [anon_sym_byte] = ACTIONS(6287),
    [anon_sym_shortint] = ACTIONS(6287),
    [anon_sym_int] = ACTIONS(6287),
    [anon_sym_longint] = ACTIONS(6287),
    [anon_sym_integer] = ACTIONS(6287),
    [anon_sym_time] = ACTIONS(6287),
    [anon_sym_bit] = ACTIONS(6287),
    [anon_sym_logic] = ACTIONS(6287),
    [anon_sym_reg] = ACTIONS(6287),
    [anon_sym_shortreal] = ACTIONS(6287),
    [anon_sym_real] = ACTIONS(6287),
    [anon_sym_realtime] = ACTIONS(6287),
    [anon_sym_supply0] = ACTIONS(6287),
    [anon_sym_supply1] = ACTIONS(6287),
    [anon_sym_signed] = ACTIONS(6287),
    [anon_sym_unsigned] = ACTIONS(6287),
    [anon_sym_task] = ACTIONS(6287),
    [anon_sym_assert] = ACTIONS(6287),
    [anon_sym_property] = ACTIONS(6287),
    [anon_sym_assume] = ACTIONS(6287),
    [anon_sym_cover] = ACTIONS(6287),
    [anon_sym_sequence] = ACTIONS(6287),
    [anon_sym_restrict] = ACTIONS(6287),
    [anon_sym_not] = ACTIONS(6287),
    [anon_sym_or] = ACTIONS(6287),
    [anon_sym_and] = ACTIONS(6287),
    [anon_sym_case] = ACTIONS(6287),
    [anon_sym_always] = ACTIONS(6287),
    [anon_sym_covergroup] = ACTIONS(6287),
    [anon_sym_let] = ACTIONS(6287),
    [anon_sym_pulldown] = ACTIONS(6287),
    [anon_sym_pullup] = ACTIONS(6287),
    [anon_sym_cmos] = ACTIONS(6287),
    [anon_sym_rcmos] = ACTIONS(6287),
    [anon_sym_bufif0] = ACTIONS(6287),
    [anon_sym_bufif1] = ACTIONS(6287),
    [anon_sym_notif0] = ACTIONS(6287),
    [anon_sym_notif1] = ACTIONS(6287),
    [anon_sym_nmos] = ACTIONS(6287),
    [anon_sym_pmos] = ACTIONS(6287),
    [anon_sym_rnmos] = ACTIONS(6287),
    [anon_sym_rpmos] = ACTIONS(6287),
    [anon_sym_nand] = ACTIONS(6287),
    [anon_sym_nor] = ACTIONS(6287),
    [anon_sym_xor] = ACTIONS(6287),
    [anon_sym_xnor] = ACTIONS(6287),
    [anon_sym_buf] = ACTIONS(6287),
    [anon_sym_tranif0] = ACTIONS(6287),
    [anon_sym_tranif1] = ACTIONS(6287),
    [anon_sym_rtranif1] = ACTIONS(6287),
    [anon_sym_rtranif0] = ACTIONS(6287),
    [anon_sym_tran] = ACTIONS(6287),
    [anon_sym_rtran] = ACTIONS(6287),
    [anon_sym_generate] = ACTIONS(6287),
    [anon_sym_endgenerate] = ACTIONS(6287),
    [anon_sym_for] = ACTIONS(6287),
    [anon_sym_initial] = ACTIONS(6287),
    [anon_sym_assign] = ACTIONS(6287),
    [anon_sym_alias] = ACTIONS(6287),
    [anon_sym_always_comb] = ACTIONS(6287),
    [anon_sym_always_latch] = ACTIONS(6287),
    [anon_sym_always_ff] = ACTIONS(6287),
    [anon_sym_final] = ACTIONS(6287),
    [anon_sym_global] = ACTIONS(6287),
    [anon_sym_LPAREN_STAR] = ACTIONS(6289),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6289),
    [anon_sym_DOLLARunit] = ACTIONS(6289),
  },
  [5018] = {
    [sym_simple_identifier] = ACTIONS(6645),
    [anon_sym_wire] = ACTIONS(6645),
    [anon_sym_tri] = ACTIONS(6645),
    [anon_sym_tri0] = ACTIONS(6645),
    [anon_sym_tri1] = ACTIONS(6645),
    [anon_sym_wand] = ACTIONS(6645),
    [anon_sym_triand] = ACTIONS(6645),
    [anon_sym_wor] = ACTIONS(6645),
    [anon_sym_trior] = ACTIONS(6645),
    [anon_sym_trireg] = ACTIONS(6645),
    [anon_sym_uwire] = ACTIONS(6645),
    [anon_sym_SEMI] = ACTIONS(6649),
    [anon_sym_extern] = ACTIONS(6645),
    [anon_sym_interface] = ACTIONS(6645),
    [anon_sym_checker] = ACTIONS(6645),
    [anon_sym_virtual] = ACTIONS(6645),
    [anon_sym_class] = ACTIONS(6645),
    [anon_sym_type] = ACTIONS(6645),
    [anon_sym_DOLLARfatal] = ACTIONS(6649),
    [anon_sym_DOLLARerror] = ACTIONS(6649),
    [anon_sym_DOLLARwarning] = ACTIONS(6649),
    [anon_sym_DOLLARinfo] = ACTIONS(6649),
    [anon_sym_default] = ACTIONS(6645),
    [anon_sym_clocking] = ACTIONS(6645),
    [anon_sym_defparam] = ACTIONS(6645),
    [anon_sym_bind] = ACTIONS(6645),
    [anon_sym_rand] = ACTIONS(6645),
    [anon_sym_const] = ACTIONS(6645),
    [anon_sym_function] = ACTIONS(6645),
    [anon_sym_static] = ACTIONS(6645),
    [anon_sym_constraint] = ACTIONS(6645),
    [anon_sym_if] = ACTIONS(6645),
    [anon_sym_else] = ACTIONS(6645),
    [anon_sym_LBRACK] = ACTIONS(6649),
    [anon_sym_localparam] = ACTIONS(6645),
    [anon_sym_parameter] = ACTIONS(6645),
    [anon_sym_var] = ACTIONS(6645),
    [anon_sym_import] = ACTIONS(6645),
    [anon_sym_export] = ACTIONS(6645),
    [anon_sym_genvar] = ACTIONS(6645),
    [anon_sym_interconnect] = ACTIONS(6645),
    [anon_sym_typedef] = ACTIONS(6645),
    [anon_sym_enum] = ACTIONS(6645),
    [anon_sym_struct] = ACTIONS(6645),
    [anon_sym_union] = ACTIONS(6645),
    [anon_sym_nettype] = ACTIONS(6645),
    [anon_sym_automatic] = ACTIONS(6645),
    [anon_sym_string] = ACTIONS(6645),
    [anon_sym_chandle] = ACTIONS(6645),
    [anon_sym_event] = ACTIONS(6645),
    [anon_sym_byte] = ACTIONS(6645),
    [anon_sym_shortint] = ACTIONS(6645),
    [anon_sym_int] = ACTIONS(6645),
    [anon_sym_longint] = ACTIONS(6645),
    [anon_sym_integer] = ACTIONS(6645),
    [anon_sym_time] = ACTIONS(6645),
    [anon_sym_bit] = ACTIONS(6645),
    [anon_sym_logic] = ACTIONS(6645),
    [anon_sym_reg] = ACTIONS(6645),
    [anon_sym_shortreal] = ACTIONS(6645),
    [anon_sym_real] = ACTIONS(6645),
    [anon_sym_realtime] = ACTIONS(6645),
    [anon_sym_supply0] = ACTIONS(6645),
    [anon_sym_supply1] = ACTIONS(6645),
    [anon_sym_signed] = ACTIONS(6645),
    [anon_sym_unsigned] = ACTIONS(6645),
    [anon_sym_task] = ACTIONS(6645),
    [anon_sym_assert] = ACTIONS(6645),
    [anon_sym_property] = ACTIONS(6645),
    [anon_sym_assume] = ACTIONS(6645),
    [anon_sym_cover] = ACTIONS(6645),
    [anon_sym_sequence] = ACTIONS(6645),
    [anon_sym_restrict] = ACTIONS(6645),
    [anon_sym_not] = ACTIONS(6645),
    [anon_sym_or] = ACTIONS(6645),
    [anon_sym_and] = ACTIONS(6645),
    [anon_sym_case] = ACTIONS(6645),
    [anon_sym_always] = ACTIONS(6645),
    [anon_sym_covergroup] = ACTIONS(6645),
    [anon_sym_end] = ACTIONS(6645),
    [anon_sym_let] = ACTIONS(6645),
    [anon_sym_pulldown] = ACTIONS(6645),
    [anon_sym_pullup] = ACTIONS(6645),
    [anon_sym_cmos] = ACTIONS(6645),
    [anon_sym_rcmos] = ACTIONS(6645),
    [anon_sym_bufif0] = ACTIONS(6645),
    [anon_sym_bufif1] = ACTIONS(6645),
    [anon_sym_notif0] = ACTIONS(6645),
    [anon_sym_notif1] = ACTIONS(6645),
    [anon_sym_nmos] = ACTIONS(6645),
    [anon_sym_pmos] = ACTIONS(6645),
    [anon_sym_rnmos] = ACTIONS(6645),
    [anon_sym_rpmos] = ACTIONS(6645),
    [anon_sym_nand] = ACTIONS(6645),
    [anon_sym_nor] = ACTIONS(6645),
    [anon_sym_xor] = ACTIONS(6645),
    [anon_sym_xnor] = ACTIONS(6645),
    [anon_sym_buf] = ACTIONS(6645),
    [anon_sym_tranif0] = ACTIONS(6645),
    [anon_sym_tranif1] = ACTIONS(6645),
    [anon_sym_rtranif1] = ACTIONS(6645),
    [anon_sym_rtranif0] = ACTIONS(6645),
    [anon_sym_tran] = ACTIONS(6645),
    [anon_sym_rtran] = ACTIONS(6645),
    [anon_sym_generate] = ACTIONS(6645),
    [anon_sym_for] = ACTIONS(6645),
    [anon_sym_initial] = ACTIONS(6645),
    [anon_sym_assign] = ACTIONS(6645),
    [anon_sym_alias] = ACTIONS(6645),
    [anon_sym_always_comb] = ACTIONS(6645),
    [anon_sym_always_latch] = ACTIONS(6645),
    [anon_sym_always_ff] = ACTIONS(6645),
    [anon_sym_final] = ACTIONS(6645),
    [anon_sym_global] = ACTIONS(6645),
    [anon_sym_LPAREN_STAR] = ACTIONS(6649),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6649),
    [anon_sym_DOLLARunit] = ACTIONS(6649),
  },
  [5019] = {
    [sym_simple_identifier] = ACTIONS(6237),
    [anon_sym_wire] = ACTIONS(6237),
    [anon_sym_tri] = ACTIONS(6237),
    [anon_sym_tri0] = ACTIONS(6237),
    [anon_sym_tri1] = ACTIONS(6237),
    [anon_sym_wand] = ACTIONS(6237),
    [anon_sym_triand] = ACTIONS(6237),
    [anon_sym_wor] = ACTIONS(6237),
    [anon_sym_trior] = ACTIONS(6237),
    [anon_sym_trireg] = ACTIONS(6237),
    [anon_sym_uwire] = ACTIONS(6237),
    [anon_sym_SEMI] = ACTIONS(6239),
    [anon_sym_extern] = ACTIONS(6237),
    [anon_sym_interface] = ACTIONS(6237),
    [anon_sym_checker] = ACTIONS(6237),
    [anon_sym_virtual] = ACTIONS(6237),
    [anon_sym_class] = ACTIONS(6237),
    [anon_sym_type] = ACTIONS(6237),
    [anon_sym_DOLLARfatal] = ACTIONS(6239),
    [anon_sym_DOLLARerror] = ACTIONS(6239),
    [anon_sym_DOLLARwarning] = ACTIONS(6239),
    [anon_sym_DOLLARinfo] = ACTIONS(6239),
    [anon_sym_default] = ACTIONS(6237),
    [anon_sym_clocking] = ACTIONS(6237),
    [anon_sym_defparam] = ACTIONS(6237),
    [anon_sym_bind] = ACTIONS(6237),
    [anon_sym_rand] = ACTIONS(6237),
    [anon_sym_const] = ACTIONS(6237),
    [anon_sym_function] = ACTIONS(6237),
    [anon_sym_static] = ACTIONS(6237),
    [anon_sym_constraint] = ACTIONS(6237),
    [anon_sym_if] = ACTIONS(6237),
    [anon_sym_else] = ACTIONS(6237),
    [anon_sym_LBRACK] = ACTIONS(6239),
    [anon_sym_localparam] = ACTIONS(6237),
    [anon_sym_parameter] = ACTIONS(6237),
    [anon_sym_var] = ACTIONS(6237),
    [anon_sym_import] = ACTIONS(6237),
    [anon_sym_export] = ACTIONS(6237),
    [anon_sym_genvar] = ACTIONS(6237),
    [anon_sym_interconnect] = ACTIONS(6237),
    [anon_sym_typedef] = ACTIONS(6237),
    [anon_sym_enum] = ACTIONS(6237),
    [anon_sym_struct] = ACTIONS(6237),
    [anon_sym_union] = ACTIONS(6237),
    [anon_sym_nettype] = ACTIONS(6237),
    [anon_sym_automatic] = ACTIONS(6237),
    [anon_sym_string] = ACTIONS(6237),
    [anon_sym_chandle] = ACTIONS(6237),
    [anon_sym_event] = ACTIONS(6237),
    [anon_sym_byte] = ACTIONS(6237),
    [anon_sym_shortint] = ACTIONS(6237),
    [anon_sym_int] = ACTIONS(6237),
    [anon_sym_longint] = ACTIONS(6237),
    [anon_sym_integer] = ACTIONS(6237),
    [anon_sym_time] = ACTIONS(6237),
    [anon_sym_bit] = ACTIONS(6237),
    [anon_sym_logic] = ACTIONS(6237),
    [anon_sym_reg] = ACTIONS(6237),
    [anon_sym_shortreal] = ACTIONS(6237),
    [anon_sym_real] = ACTIONS(6237),
    [anon_sym_realtime] = ACTIONS(6237),
    [anon_sym_supply0] = ACTIONS(6237),
    [anon_sym_supply1] = ACTIONS(6237),
    [anon_sym_signed] = ACTIONS(6237),
    [anon_sym_unsigned] = ACTIONS(6237),
    [anon_sym_task] = ACTIONS(6237),
    [anon_sym_assert] = ACTIONS(6237),
    [anon_sym_property] = ACTIONS(6237),
    [anon_sym_assume] = ACTIONS(6237),
    [anon_sym_cover] = ACTIONS(6237),
    [anon_sym_sequence] = ACTIONS(6237),
    [anon_sym_restrict] = ACTIONS(6237),
    [anon_sym_not] = ACTIONS(6237),
    [anon_sym_or] = ACTIONS(6237),
    [anon_sym_and] = ACTIONS(6237),
    [anon_sym_case] = ACTIONS(6237),
    [anon_sym_always] = ACTIONS(6237),
    [anon_sym_covergroup] = ACTIONS(6237),
    [anon_sym_let] = ACTIONS(6237),
    [anon_sym_pulldown] = ACTIONS(6237),
    [anon_sym_pullup] = ACTIONS(6237),
    [anon_sym_cmos] = ACTIONS(6237),
    [anon_sym_rcmos] = ACTIONS(6237),
    [anon_sym_bufif0] = ACTIONS(6237),
    [anon_sym_bufif1] = ACTIONS(6237),
    [anon_sym_notif0] = ACTIONS(6237),
    [anon_sym_notif1] = ACTIONS(6237),
    [anon_sym_nmos] = ACTIONS(6237),
    [anon_sym_pmos] = ACTIONS(6237),
    [anon_sym_rnmos] = ACTIONS(6237),
    [anon_sym_rpmos] = ACTIONS(6237),
    [anon_sym_nand] = ACTIONS(6237),
    [anon_sym_nor] = ACTIONS(6237),
    [anon_sym_xor] = ACTIONS(6237),
    [anon_sym_xnor] = ACTIONS(6237),
    [anon_sym_buf] = ACTIONS(6237),
    [anon_sym_tranif0] = ACTIONS(6237),
    [anon_sym_tranif1] = ACTIONS(6237),
    [anon_sym_rtranif1] = ACTIONS(6237),
    [anon_sym_rtranif0] = ACTIONS(6237),
    [anon_sym_tran] = ACTIONS(6237),
    [anon_sym_rtran] = ACTIONS(6237),
    [anon_sym_generate] = ACTIONS(6237),
    [anon_sym_endgenerate] = ACTIONS(6237),
    [anon_sym_for] = ACTIONS(6237),
    [anon_sym_initial] = ACTIONS(6237),
    [anon_sym_assign] = ACTIONS(6237),
    [anon_sym_alias] = ACTIONS(6237),
    [anon_sym_always_comb] = ACTIONS(6237),
    [anon_sym_always_latch] = ACTIONS(6237),
    [anon_sym_always_ff] = ACTIONS(6237),
    [anon_sym_final] = ACTIONS(6237),
    [anon_sym_global] = ACTIONS(6237),
    [anon_sym_LPAREN_STAR] = ACTIONS(6239),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6239),
    [anon_sym_DOLLARunit] = ACTIONS(6239),
  },
  [5020] = {
    [sym_simple_identifier] = ACTIONS(6537),
    [anon_sym_wire] = ACTIONS(6537),
    [anon_sym_tri] = ACTIONS(6537),
    [anon_sym_tri0] = ACTIONS(6537),
    [anon_sym_tri1] = ACTIONS(6537),
    [anon_sym_wand] = ACTIONS(6537),
    [anon_sym_triand] = ACTIONS(6537),
    [anon_sym_wor] = ACTIONS(6537),
    [anon_sym_trior] = ACTIONS(6537),
    [anon_sym_trireg] = ACTIONS(6537),
    [anon_sym_uwire] = ACTIONS(6537),
    [anon_sym_SEMI] = ACTIONS(6541),
    [anon_sym_extern] = ACTIONS(6537),
    [anon_sym_interface] = ACTIONS(6537),
    [anon_sym_checker] = ACTIONS(6537),
    [anon_sym_virtual] = ACTIONS(6537),
    [anon_sym_class] = ACTIONS(6537),
    [anon_sym_type] = ACTIONS(6537),
    [anon_sym_DOLLARfatal] = ACTIONS(6541),
    [anon_sym_DOLLARerror] = ACTIONS(6541),
    [anon_sym_DOLLARwarning] = ACTIONS(6541),
    [anon_sym_DOLLARinfo] = ACTIONS(6541),
    [anon_sym_default] = ACTIONS(6537),
    [anon_sym_clocking] = ACTIONS(6537),
    [anon_sym_defparam] = ACTIONS(6537),
    [anon_sym_bind] = ACTIONS(6537),
    [anon_sym_rand] = ACTIONS(6537),
    [anon_sym_const] = ACTIONS(6537),
    [anon_sym_function] = ACTIONS(6537),
    [anon_sym_static] = ACTIONS(6537),
    [anon_sym_constraint] = ACTIONS(6537),
    [anon_sym_if] = ACTIONS(6537),
    [anon_sym_else] = ACTIONS(6537),
    [anon_sym_LBRACK] = ACTIONS(6541),
    [anon_sym_localparam] = ACTIONS(6537),
    [anon_sym_parameter] = ACTIONS(6537),
    [anon_sym_var] = ACTIONS(6537),
    [anon_sym_import] = ACTIONS(6537),
    [anon_sym_export] = ACTIONS(6537),
    [anon_sym_genvar] = ACTIONS(6537),
    [anon_sym_interconnect] = ACTIONS(6537),
    [anon_sym_typedef] = ACTIONS(6537),
    [anon_sym_enum] = ACTIONS(6537),
    [anon_sym_struct] = ACTIONS(6537),
    [anon_sym_union] = ACTIONS(6537),
    [anon_sym_nettype] = ACTIONS(6537),
    [anon_sym_automatic] = ACTIONS(6537),
    [anon_sym_string] = ACTIONS(6537),
    [anon_sym_chandle] = ACTIONS(6537),
    [anon_sym_event] = ACTIONS(6537),
    [anon_sym_byte] = ACTIONS(6537),
    [anon_sym_shortint] = ACTIONS(6537),
    [anon_sym_int] = ACTIONS(6537),
    [anon_sym_longint] = ACTIONS(6537),
    [anon_sym_integer] = ACTIONS(6537),
    [anon_sym_time] = ACTIONS(6537),
    [anon_sym_bit] = ACTIONS(6537),
    [anon_sym_logic] = ACTIONS(6537),
    [anon_sym_reg] = ACTIONS(6537),
    [anon_sym_shortreal] = ACTIONS(6537),
    [anon_sym_real] = ACTIONS(6537),
    [anon_sym_realtime] = ACTIONS(6537),
    [anon_sym_supply0] = ACTIONS(6537),
    [anon_sym_supply1] = ACTIONS(6537),
    [anon_sym_signed] = ACTIONS(6537),
    [anon_sym_unsigned] = ACTIONS(6537),
    [anon_sym_task] = ACTIONS(6537),
    [anon_sym_assert] = ACTIONS(6537),
    [anon_sym_property] = ACTIONS(6537),
    [anon_sym_assume] = ACTIONS(6537),
    [anon_sym_cover] = ACTIONS(6537),
    [anon_sym_sequence] = ACTIONS(6537),
    [anon_sym_restrict] = ACTIONS(6537),
    [anon_sym_not] = ACTIONS(6537),
    [anon_sym_or] = ACTIONS(6537),
    [anon_sym_and] = ACTIONS(6537),
    [anon_sym_case] = ACTIONS(6537),
    [anon_sym_always] = ACTIONS(6537),
    [anon_sym_covergroup] = ACTIONS(6537),
    [anon_sym_end] = ACTIONS(6537),
    [anon_sym_let] = ACTIONS(6537),
    [anon_sym_pulldown] = ACTIONS(6537),
    [anon_sym_pullup] = ACTIONS(6537),
    [anon_sym_cmos] = ACTIONS(6537),
    [anon_sym_rcmos] = ACTIONS(6537),
    [anon_sym_bufif0] = ACTIONS(6537),
    [anon_sym_bufif1] = ACTIONS(6537),
    [anon_sym_notif0] = ACTIONS(6537),
    [anon_sym_notif1] = ACTIONS(6537),
    [anon_sym_nmos] = ACTIONS(6537),
    [anon_sym_pmos] = ACTIONS(6537),
    [anon_sym_rnmos] = ACTIONS(6537),
    [anon_sym_rpmos] = ACTIONS(6537),
    [anon_sym_nand] = ACTIONS(6537),
    [anon_sym_nor] = ACTIONS(6537),
    [anon_sym_xor] = ACTIONS(6537),
    [anon_sym_xnor] = ACTIONS(6537),
    [anon_sym_buf] = ACTIONS(6537),
    [anon_sym_tranif0] = ACTIONS(6537),
    [anon_sym_tranif1] = ACTIONS(6537),
    [anon_sym_rtranif1] = ACTIONS(6537),
    [anon_sym_rtranif0] = ACTIONS(6537),
    [anon_sym_tran] = ACTIONS(6537),
    [anon_sym_rtran] = ACTIONS(6537),
    [anon_sym_generate] = ACTIONS(6537),
    [anon_sym_for] = ACTIONS(6537),
    [anon_sym_initial] = ACTIONS(6537),
    [anon_sym_assign] = ACTIONS(6537),
    [anon_sym_alias] = ACTIONS(6537),
    [anon_sym_always_comb] = ACTIONS(6537),
    [anon_sym_always_latch] = ACTIONS(6537),
    [anon_sym_always_ff] = ACTIONS(6537),
    [anon_sym_final] = ACTIONS(6537),
    [anon_sym_global] = ACTIONS(6537),
    [anon_sym_LPAREN_STAR] = ACTIONS(6541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6541),
    [anon_sym_DOLLARunit] = ACTIONS(6541),
  },
  [5021] = {
    [sym_simple_identifier] = ACTIONS(1680),
    [anon_sym_wire] = ACTIONS(1680),
    [anon_sym_tri] = ACTIONS(1680),
    [anon_sym_tri0] = ACTIONS(1680),
    [anon_sym_tri1] = ACTIONS(1680),
    [anon_sym_wand] = ACTIONS(1680),
    [anon_sym_triand] = ACTIONS(1680),
    [anon_sym_wor] = ACTIONS(1680),
    [anon_sym_trior] = ACTIONS(1680),
    [anon_sym_trireg] = ACTIONS(1680),
    [anon_sym_uwire] = ACTIONS(1680),
    [anon_sym_SEMI] = ACTIONS(1678),
    [anon_sym_extern] = ACTIONS(1680),
    [anon_sym_interface] = ACTIONS(1680),
    [anon_sym_checker] = ACTIONS(1680),
    [anon_sym_virtual] = ACTIONS(1680),
    [anon_sym_class] = ACTIONS(1680),
    [anon_sym_type] = ACTIONS(1680),
    [anon_sym_DOLLARfatal] = ACTIONS(1678),
    [anon_sym_DOLLARerror] = ACTIONS(1678),
    [anon_sym_DOLLARwarning] = ACTIONS(1678),
    [anon_sym_DOLLARinfo] = ACTIONS(1678),
    [anon_sym_default] = ACTIONS(1680),
    [anon_sym_clocking] = ACTIONS(1680),
    [anon_sym_defparam] = ACTIONS(1680),
    [anon_sym_bind] = ACTIONS(1680),
    [anon_sym_rand] = ACTIONS(1680),
    [anon_sym_const] = ACTIONS(1680),
    [anon_sym_function] = ACTIONS(1680),
    [anon_sym_static] = ACTIONS(1680),
    [anon_sym_constraint] = ACTIONS(1680),
    [anon_sym_if] = ACTIONS(1680),
    [anon_sym_else] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1678),
    [anon_sym_localparam] = ACTIONS(1680),
    [anon_sym_parameter] = ACTIONS(1680),
    [anon_sym_var] = ACTIONS(1680),
    [anon_sym_import] = ACTIONS(1680),
    [anon_sym_export] = ACTIONS(1680),
    [anon_sym_genvar] = ACTIONS(1680),
    [anon_sym_interconnect] = ACTIONS(1680),
    [anon_sym_typedef] = ACTIONS(1680),
    [anon_sym_enum] = ACTIONS(1680),
    [anon_sym_struct] = ACTIONS(1680),
    [anon_sym_union] = ACTIONS(1680),
    [anon_sym_nettype] = ACTIONS(1680),
    [anon_sym_automatic] = ACTIONS(1680),
    [anon_sym_string] = ACTIONS(1680),
    [anon_sym_chandle] = ACTIONS(1680),
    [anon_sym_event] = ACTIONS(1680),
    [anon_sym_byte] = ACTIONS(1680),
    [anon_sym_shortint] = ACTIONS(1680),
    [anon_sym_int] = ACTIONS(1680),
    [anon_sym_longint] = ACTIONS(1680),
    [anon_sym_integer] = ACTIONS(1680),
    [anon_sym_time] = ACTIONS(1680),
    [anon_sym_bit] = ACTIONS(1680),
    [anon_sym_logic] = ACTIONS(1680),
    [anon_sym_reg] = ACTIONS(1680),
    [anon_sym_shortreal] = ACTIONS(1680),
    [anon_sym_real] = ACTIONS(1680),
    [anon_sym_realtime] = ACTIONS(1680),
    [anon_sym_supply0] = ACTIONS(1680),
    [anon_sym_supply1] = ACTIONS(1680),
    [anon_sym_signed] = ACTIONS(1680),
    [anon_sym_unsigned] = ACTIONS(1680),
    [anon_sym_task] = ACTIONS(1680),
    [anon_sym_assert] = ACTIONS(1680),
    [anon_sym_property] = ACTIONS(1680),
    [anon_sym_assume] = ACTIONS(1680),
    [anon_sym_cover] = ACTIONS(1680),
    [anon_sym_sequence] = ACTIONS(1680),
    [anon_sym_restrict] = ACTIONS(1680),
    [anon_sym_not] = ACTIONS(1680),
    [anon_sym_or] = ACTIONS(1680),
    [anon_sym_and] = ACTIONS(1680),
    [anon_sym_case] = ACTIONS(1680),
    [anon_sym_always] = ACTIONS(1680),
    [anon_sym_covergroup] = ACTIONS(1680),
    [anon_sym_end] = ACTIONS(1680),
    [anon_sym_let] = ACTIONS(1680),
    [anon_sym_pulldown] = ACTIONS(1680),
    [anon_sym_pullup] = ACTIONS(1680),
    [anon_sym_cmos] = ACTIONS(1680),
    [anon_sym_rcmos] = ACTIONS(1680),
    [anon_sym_bufif0] = ACTIONS(1680),
    [anon_sym_bufif1] = ACTIONS(1680),
    [anon_sym_notif0] = ACTIONS(1680),
    [anon_sym_notif1] = ACTIONS(1680),
    [anon_sym_nmos] = ACTIONS(1680),
    [anon_sym_pmos] = ACTIONS(1680),
    [anon_sym_rnmos] = ACTIONS(1680),
    [anon_sym_rpmos] = ACTIONS(1680),
    [anon_sym_nand] = ACTIONS(1680),
    [anon_sym_nor] = ACTIONS(1680),
    [anon_sym_xor] = ACTIONS(1680),
    [anon_sym_xnor] = ACTIONS(1680),
    [anon_sym_buf] = ACTIONS(1680),
    [anon_sym_tranif0] = ACTIONS(1680),
    [anon_sym_tranif1] = ACTIONS(1680),
    [anon_sym_rtranif1] = ACTIONS(1680),
    [anon_sym_rtranif0] = ACTIONS(1680),
    [anon_sym_tran] = ACTIONS(1680),
    [anon_sym_rtran] = ACTIONS(1680),
    [anon_sym_generate] = ACTIONS(1680),
    [anon_sym_for] = ACTIONS(1680),
    [anon_sym_initial] = ACTIONS(1680),
    [anon_sym_assign] = ACTIONS(1680),
    [anon_sym_alias] = ACTIONS(1680),
    [anon_sym_always_comb] = ACTIONS(1680),
    [anon_sym_always_latch] = ACTIONS(1680),
    [anon_sym_always_ff] = ACTIONS(1680),
    [anon_sym_final] = ACTIONS(1680),
    [anon_sym_global] = ACTIONS(1680),
    [anon_sym_LPAREN_STAR] = ACTIONS(1678),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1678),
    [anon_sym_DOLLARunit] = ACTIONS(1678),
  },
  [5022] = {
    [sym_simple_identifier] = ACTIONS(6727),
    [anon_sym_wire] = ACTIONS(6727),
    [anon_sym_tri] = ACTIONS(6727),
    [anon_sym_tri0] = ACTIONS(6727),
    [anon_sym_tri1] = ACTIONS(6727),
    [anon_sym_wand] = ACTIONS(6727),
    [anon_sym_triand] = ACTIONS(6727),
    [anon_sym_wor] = ACTIONS(6727),
    [anon_sym_trior] = ACTIONS(6727),
    [anon_sym_trireg] = ACTIONS(6727),
    [anon_sym_uwire] = ACTIONS(6727),
    [anon_sym_SEMI] = ACTIONS(6729),
    [anon_sym_extern] = ACTIONS(6727),
    [anon_sym_interface] = ACTIONS(6727),
    [anon_sym_checker] = ACTIONS(6727),
    [anon_sym_virtual] = ACTIONS(6727),
    [anon_sym_class] = ACTIONS(6727),
    [anon_sym_type] = ACTIONS(6727),
    [anon_sym_DOLLARfatal] = ACTIONS(6729),
    [anon_sym_DOLLARerror] = ACTIONS(6729),
    [anon_sym_DOLLARwarning] = ACTIONS(6729),
    [anon_sym_DOLLARinfo] = ACTIONS(6729),
    [anon_sym_default] = ACTIONS(6727),
    [anon_sym_clocking] = ACTIONS(6727),
    [anon_sym_defparam] = ACTIONS(6727),
    [anon_sym_bind] = ACTIONS(6727),
    [anon_sym_rand] = ACTIONS(6727),
    [anon_sym_const] = ACTIONS(6727),
    [anon_sym_function] = ACTIONS(6727),
    [anon_sym_static] = ACTIONS(6727),
    [anon_sym_constraint] = ACTIONS(6727),
    [anon_sym_if] = ACTIONS(6727),
    [anon_sym_else] = ACTIONS(6727),
    [anon_sym_LBRACK] = ACTIONS(6729),
    [anon_sym_localparam] = ACTIONS(6727),
    [anon_sym_parameter] = ACTIONS(6727),
    [anon_sym_var] = ACTIONS(6727),
    [anon_sym_import] = ACTIONS(6727),
    [anon_sym_export] = ACTIONS(6727),
    [anon_sym_genvar] = ACTIONS(6727),
    [anon_sym_interconnect] = ACTIONS(6727),
    [anon_sym_typedef] = ACTIONS(6727),
    [anon_sym_enum] = ACTIONS(6727),
    [anon_sym_struct] = ACTIONS(6727),
    [anon_sym_union] = ACTIONS(6727),
    [anon_sym_nettype] = ACTIONS(6727),
    [anon_sym_automatic] = ACTIONS(6727),
    [anon_sym_string] = ACTIONS(6727),
    [anon_sym_chandle] = ACTIONS(6727),
    [anon_sym_event] = ACTIONS(6727),
    [anon_sym_byte] = ACTIONS(6727),
    [anon_sym_shortint] = ACTIONS(6727),
    [anon_sym_int] = ACTIONS(6727),
    [anon_sym_longint] = ACTIONS(6727),
    [anon_sym_integer] = ACTIONS(6727),
    [anon_sym_time] = ACTIONS(6727),
    [anon_sym_bit] = ACTIONS(6727),
    [anon_sym_logic] = ACTIONS(6727),
    [anon_sym_reg] = ACTIONS(6727),
    [anon_sym_shortreal] = ACTIONS(6727),
    [anon_sym_real] = ACTIONS(6727),
    [anon_sym_realtime] = ACTIONS(6727),
    [anon_sym_supply0] = ACTIONS(6727),
    [anon_sym_supply1] = ACTIONS(6727),
    [anon_sym_signed] = ACTIONS(6727),
    [anon_sym_unsigned] = ACTIONS(6727),
    [anon_sym_task] = ACTIONS(6727),
    [anon_sym_assert] = ACTIONS(6727),
    [anon_sym_property] = ACTIONS(6727),
    [anon_sym_assume] = ACTIONS(6727),
    [anon_sym_cover] = ACTIONS(6727),
    [anon_sym_sequence] = ACTIONS(6727),
    [anon_sym_restrict] = ACTIONS(6727),
    [anon_sym_not] = ACTIONS(6727),
    [anon_sym_or] = ACTIONS(6727),
    [anon_sym_and] = ACTIONS(6727),
    [anon_sym_case] = ACTIONS(6727),
    [anon_sym_always] = ACTIONS(6727),
    [anon_sym_covergroup] = ACTIONS(6727),
    [anon_sym_let] = ACTIONS(6727),
    [anon_sym_pulldown] = ACTIONS(6727),
    [anon_sym_pullup] = ACTIONS(6727),
    [anon_sym_cmos] = ACTIONS(6727),
    [anon_sym_rcmos] = ACTIONS(6727),
    [anon_sym_bufif0] = ACTIONS(6727),
    [anon_sym_bufif1] = ACTIONS(6727),
    [anon_sym_notif0] = ACTIONS(6727),
    [anon_sym_notif1] = ACTIONS(6727),
    [anon_sym_nmos] = ACTIONS(6727),
    [anon_sym_pmos] = ACTIONS(6727),
    [anon_sym_rnmos] = ACTIONS(6727),
    [anon_sym_rpmos] = ACTIONS(6727),
    [anon_sym_nand] = ACTIONS(6727),
    [anon_sym_nor] = ACTIONS(6727),
    [anon_sym_xor] = ACTIONS(6727),
    [anon_sym_xnor] = ACTIONS(6727),
    [anon_sym_buf] = ACTIONS(6727),
    [anon_sym_tranif0] = ACTIONS(6727),
    [anon_sym_tranif1] = ACTIONS(6727),
    [anon_sym_rtranif1] = ACTIONS(6727),
    [anon_sym_rtranif0] = ACTIONS(6727),
    [anon_sym_tran] = ACTIONS(6727),
    [anon_sym_rtran] = ACTIONS(6727),
    [anon_sym_generate] = ACTIONS(6727),
    [anon_sym_endgenerate] = ACTIONS(6727),
    [anon_sym_for] = ACTIONS(6727),
    [anon_sym_initial] = ACTIONS(6727),
    [anon_sym_assign] = ACTIONS(6727),
    [anon_sym_alias] = ACTIONS(6727),
    [anon_sym_always_comb] = ACTIONS(6727),
    [anon_sym_always_latch] = ACTIONS(6727),
    [anon_sym_always_ff] = ACTIONS(6727),
    [anon_sym_final] = ACTIONS(6727),
    [anon_sym_global] = ACTIONS(6727),
    [anon_sym_LPAREN_STAR] = ACTIONS(6729),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6729),
    [anon_sym_DOLLARunit] = ACTIONS(6729),
  },
  [5023] = {
    [sym_simple_identifier] = ACTIONS(4888),
    [anon_sym_wire] = ACTIONS(4888),
    [anon_sym_tri] = ACTIONS(4888),
    [anon_sym_tri0] = ACTIONS(4888),
    [anon_sym_tri1] = ACTIONS(4888),
    [anon_sym_wand] = ACTIONS(4888),
    [anon_sym_triand] = ACTIONS(4888),
    [anon_sym_wor] = ACTIONS(4888),
    [anon_sym_trior] = ACTIONS(4888),
    [anon_sym_trireg] = ACTIONS(4888),
    [anon_sym_uwire] = ACTIONS(4888),
    [anon_sym_SEMI] = ACTIONS(4886),
    [anon_sym_extern] = ACTIONS(4888),
    [anon_sym_interface] = ACTIONS(4888),
    [anon_sym_checker] = ACTIONS(4888),
    [anon_sym_virtual] = ACTIONS(4888),
    [anon_sym_class] = ACTIONS(4888),
    [anon_sym_type] = ACTIONS(4888),
    [anon_sym_DOLLARfatal] = ACTIONS(4886),
    [anon_sym_DOLLARerror] = ACTIONS(4886),
    [anon_sym_DOLLARwarning] = ACTIONS(4886),
    [anon_sym_DOLLARinfo] = ACTIONS(4886),
    [anon_sym_default] = ACTIONS(4888),
    [anon_sym_clocking] = ACTIONS(4888),
    [anon_sym_defparam] = ACTIONS(4888),
    [anon_sym_bind] = ACTIONS(4888),
    [anon_sym_rand] = ACTIONS(4888),
    [anon_sym_const] = ACTIONS(4888),
    [anon_sym_function] = ACTIONS(4888),
    [anon_sym_static] = ACTIONS(4888),
    [anon_sym_constraint] = ACTIONS(4888),
    [anon_sym_if] = ACTIONS(4888),
    [anon_sym_else] = ACTIONS(4888),
    [anon_sym_LBRACK] = ACTIONS(4886),
    [anon_sym_localparam] = ACTIONS(4888),
    [anon_sym_parameter] = ACTIONS(4888),
    [anon_sym_var] = ACTIONS(4888),
    [anon_sym_import] = ACTIONS(4888),
    [anon_sym_export] = ACTIONS(4888),
    [anon_sym_genvar] = ACTIONS(4888),
    [anon_sym_interconnect] = ACTIONS(4888),
    [anon_sym_typedef] = ACTIONS(4888),
    [anon_sym_enum] = ACTIONS(4888),
    [anon_sym_struct] = ACTIONS(4888),
    [anon_sym_union] = ACTIONS(4888),
    [anon_sym_nettype] = ACTIONS(4888),
    [anon_sym_automatic] = ACTIONS(4888),
    [anon_sym_string] = ACTIONS(4888),
    [anon_sym_chandle] = ACTIONS(4888),
    [anon_sym_event] = ACTIONS(4888),
    [anon_sym_byte] = ACTIONS(4888),
    [anon_sym_shortint] = ACTIONS(4888),
    [anon_sym_int] = ACTIONS(4888),
    [anon_sym_longint] = ACTIONS(4888),
    [anon_sym_integer] = ACTIONS(4888),
    [anon_sym_time] = ACTIONS(4888),
    [anon_sym_bit] = ACTIONS(4888),
    [anon_sym_logic] = ACTIONS(4888),
    [anon_sym_reg] = ACTIONS(4888),
    [anon_sym_shortreal] = ACTIONS(4888),
    [anon_sym_real] = ACTIONS(4888),
    [anon_sym_realtime] = ACTIONS(4888),
    [anon_sym_supply0] = ACTIONS(4888),
    [anon_sym_supply1] = ACTIONS(4888),
    [anon_sym_signed] = ACTIONS(4888),
    [anon_sym_unsigned] = ACTIONS(4888),
    [anon_sym_task] = ACTIONS(4888),
    [anon_sym_assert] = ACTIONS(4888),
    [anon_sym_property] = ACTIONS(4888),
    [anon_sym_assume] = ACTIONS(4888),
    [anon_sym_cover] = ACTIONS(4888),
    [anon_sym_sequence] = ACTIONS(4888),
    [anon_sym_restrict] = ACTIONS(4888),
    [anon_sym_not] = ACTIONS(4888),
    [anon_sym_or] = ACTIONS(4888),
    [anon_sym_and] = ACTIONS(4888),
    [anon_sym_case] = ACTIONS(4888),
    [anon_sym_always] = ACTIONS(4888),
    [anon_sym_covergroup] = ACTIONS(4888),
    [anon_sym_let] = ACTIONS(4888),
    [anon_sym_pulldown] = ACTIONS(4888),
    [anon_sym_pullup] = ACTIONS(4888),
    [anon_sym_cmos] = ACTIONS(4888),
    [anon_sym_rcmos] = ACTIONS(4888),
    [anon_sym_bufif0] = ACTIONS(4888),
    [anon_sym_bufif1] = ACTIONS(4888),
    [anon_sym_notif0] = ACTIONS(4888),
    [anon_sym_notif1] = ACTIONS(4888),
    [anon_sym_nmos] = ACTIONS(4888),
    [anon_sym_pmos] = ACTIONS(4888),
    [anon_sym_rnmos] = ACTIONS(4888),
    [anon_sym_rpmos] = ACTIONS(4888),
    [anon_sym_nand] = ACTIONS(4888),
    [anon_sym_nor] = ACTIONS(4888),
    [anon_sym_xor] = ACTIONS(4888),
    [anon_sym_xnor] = ACTIONS(4888),
    [anon_sym_buf] = ACTIONS(4888),
    [anon_sym_tranif0] = ACTIONS(4888),
    [anon_sym_tranif1] = ACTIONS(4888),
    [anon_sym_rtranif1] = ACTIONS(4888),
    [anon_sym_rtranif0] = ACTIONS(4888),
    [anon_sym_tran] = ACTIONS(4888),
    [anon_sym_rtran] = ACTIONS(4888),
    [anon_sym_generate] = ACTIONS(4888),
    [anon_sym_endgenerate] = ACTIONS(4888),
    [anon_sym_for] = ACTIONS(4888),
    [anon_sym_initial] = ACTIONS(4888),
    [anon_sym_assign] = ACTIONS(4888),
    [anon_sym_alias] = ACTIONS(4888),
    [anon_sym_always_comb] = ACTIONS(4888),
    [anon_sym_always_latch] = ACTIONS(4888),
    [anon_sym_always_ff] = ACTIONS(4888),
    [anon_sym_final] = ACTIONS(4888),
    [anon_sym_global] = ACTIONS(4888),
    [anon_sym_LPAREN_STAR] = ACTIONS(4886),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4886),
    [anon_sym_DOLLARunit] = ACTIONS(4886),
  },
  [5024] = {
    [sym_simple_identifier] = ACTIONS(4820),
    [anon_sym_wire] = ACTIONS(4820),
    [anon_sym_tri] = ACTIONS(4820),
    [anon_sym_tri0] = ACTIONS(4820),
    [anon_sym_tri1] = ACTIONS(4820),
    [anon_sym_wand] = ACTIONS(4820),
    [anon_sym_triand] = ACTIONS(4820),
    [anon_sym_wor] = ACTIONS(4820),
    [anon_sym_trior] = ACTIONS(4820),
    [anon_sym_trireg] = ACTIONS(4820),
    [anon_sym_uwire] = ACTIONS(4820),
    [anon_sym_SEMI] = ACTIONS(4818),
    [anon_sym_extern] = ACTIONS(4820),
    [anon_sym_interface] = ACTIONS(4820),
    [anon_sym_checker] = ACTIONS(4820),
    [anon_sym_virtual] = ACTIONS(4820),
    [anon_sym_class] = ACTIONS(4820),
    [anon_sym_type] = ACTIONS(4820),
    [anon_sym_DOLLARfatal] = ACTIONS(4818),
    [anon_sym_DOLLARerror] = ACTIONS(4818),
    [anon_sym_DOLLARwarning] = ACTIONS(4818),
    [anon_sym_DOLLARinfo] = ACTIONS(4818),
    [anon_sym_default] = ACTIONS(4820),
    [anon_sym_clocking] = ACTIONS(4820),
    [anon_sym_defparam] = ACTIONS(4820),
    [anon_sym_bind] = ACTIONS(4820),
    [anon_sym_rand] = ACTIONS(4820),
    [anon_sym_const] = ACTIONS(4820),
    [anon_sym_function] = ACTIONS(4820),
    [anon_sym_static] = ACTIONS(4820),
    [anon_sym_constraint] = ACTIONS(4820),
    [anon_sym_if] = ACTIONS(4820),
    [anon_sym_else] = ACTIONS(4820),
    [anon_sym_LBRACK] = ACTIONS(4818),
    [anon_sym_localparam] = ACTIONS(4820),
    [anon_sym_parameter] = ACTIONS(4820),
    [anon_sym_var] = ACTIONS(4820),
    [anon_sym_import] = ACTIONS(4820),
    [anon_sym_export] = ACTIONS(4820),
    [anon_sym_genvar] = ACTIONS(4820),
    [anon_sym_interconnect] = ACTIONS(4820),
    [anon_sym_typedef] = ACTIONS(4820),
    [anon_sym_enum] = ACTIONS(4820),
    [anon_sym_struct] = ACTIONS(4820),
    [anon_sym_union] = ACTIONS(4820),
    [anon_sym_nettype] = ACTIONS(4820),
    [anon_sym_automatic] = ACTIONS(4820),
    [anon_sym_string] = ACTIONS(4820),
    [anon_sym_chandle] = ACTIONS(4820),
    [anon_sym_event] = ACTIONS(4820),
    [anon_sym_byte] = ACTIONS(4820),
    [anon_sym_shortint] = ACTIONS(4820),
    [anon_sym_int] = ACTIONS(4820),
    [anon_sym_longint] = ACTIONS(4820),
    [anon_sym_integer] = ACTIONS(4820),
    [anon_sym_time] = ACTIONS(4820),
    [anon_sym_bit] = ACTIONS(4820),
    [anon_sym_logic] = ACTIONS(4820),
    [anon_sym_reg] = ACTIONS(4820),
    [anon_sym_shortreal] = ACTIONS(4820),
    [anon_sym_real] = ACTIONS(4820),
    [anon_sym_realtime] = ACTIONS(4820),
    [anon_sym_supply0] = ACTIONS(4820),
    [anon_sym_supply1] = ACTIONS(4820),
    [anon_sym_signed] = ACTIONS(4820),
    [anon_sym_unsigned] = ACTIONS(4820),
    [anon_sym_task] = ACTIONS(4820),
    [anon_sym_assert] = ACTIONS(4820),
    [anon_sym_property] = ACTIONS(4820),
    [anon_sym_assume] = ACTIONS(4820),
    [anon_sym_cover] = ACTIONS(4820),
    [anon_sym_sequence] = ACTIONS(4820),
    [anon_sym_restrict] = ACTIONS(4820),
    [anon_sym_not] = ACTIONS(4820),
    [anon_sym_or] = ACTIONS(4820),
    [anon_sym_and] = ACTIONS(4820),
    [anon_sym_case] = ACTIONS(4820),
    [anon_sym_always] = ACTIONS(4820),
    [anon_sym_covergroup] = ACTIONS(4820),
    [anon_sym_end] = ACTIONS(4820),
    [anon_sym_let] = ACTIONS(4820),
    [anon_sym_pulldown] = ACTIONS(4820),
    [anon_sym_pullup] = ACTIONS(4820),
    [anon_sym_cmos] = ACTIONS(4820),
    [anon_sym_rcmos] = ACTIONS(4820),
    [anon_sym_bufif0] = ACTIONS(4820),
    [anon_sym_bufif1] = ACTIONS(4820),
    [anon_sym_notif0] = ACTIONS(4820),
    [anon_sym_notif1] = ACTIONS(4820),
    [anon_sym_nmos] = ACTIONS(4820),
    [anon_sym_pmos] = ACTIONS(4820),
    [anon_sym_rnmos] = ACTIONS(4820),
    [anon_sym_rpmos] = ACTIONS(4820),
    [anon_sym_nand] = ACTIONS(4820),
    [anon_sym_nor] = ACTIONS(4820),
    [anon_sym_xor] = ACTIONS(4820),
    [anon_sym_xnor] = ACTIONS(4820),
    [anon_sym_buf] = ACTIONS(4820),
    [anon_sym_tranif0] = ACTIONS(4820),
    [anon_sym_tranif1] = ACTIONS(4820),
    [anon_sym_rtranif1] = ACTIONS(4820),
    [anon_sym_rtranif0] = ACTIONS(4820),
    [anon_sym_tran] = ACTIONS(4820),
    [anon_sym_rtran] = ACTIONS(4820),
    [anon_sym_generate] = ACTIONS(4820),
    [anon_sym_for] = ACTIONS(4820),
    [anon_sym_initial] = ACTIONS(4820),
    [anon_sym_assign] = ACTIONS(4820),
    [anon_sym_alias] = ACTIONS(4820),
    [anon_sym_always_comb] = ACTIONS(4820),
    [anon_sym_always_latch] = ACTIONS(4820),
    [anon_sym_always_ff] = ACTIONS(4820),
    [anon_sym_final] = ACTIONS(4820),
    [anon_sym_global] = ACTIONS(4820),
    [anon_sym_LPAREN_STAR] = ACTIONS(4818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4818),
    [anon_sym_DOLLARunit] = ACTIONS(4818),
  },
  [5025] = {
    [sym_simple_identifier] = ACTIONS(4824),
    [anon_sym_wire] = ACTIONS(4824),
    [anon_sym_tri] = ACTIONS(4824),
    [anon_sym_tri0] = ACTIONS(4824),
    [anon_sym_tri1] = ACTIONS(4824),
    [anon_sym_wand] = ACTIONS(4824),
    [anon_sym_triand] = ACTIONS(4824),
    [anon_sym_wor] = ACTIONS(4824),
    [anon_sym_trior] = ACTIONS(4824),
    [anon_sym_trireg] = ACTIONS(4824),
    [anon_sym_uwire] = ACTIONS(4824),
    [anon_sym_SEMI] = ACTIONS(4822),
    [anon_sym_extern] = ACTIONS(4824),
    [anon_sym_interface] = ACTIONS(4824),
    [anon_sym_checker] = ACTIONS(4824),
    [anon_sym_virtual] = ACTIONS(4824),
    [anon_sym_class] = ACTIONS(4824),
    [anon_sym_type] = ACTIONS(4824),
    [anon_sym_DOLLARfatal] = ACTIONS(4822),
    [anon_sym_DOLLARerror] = ACTIONS(4822),
    [anon_sym_DOLLARwarning] = ACTIONS(4822),
    [anon_sym_DOLLARinfo] = ACTIONS(4822),
    [anon_sym_default] = ACTIONS(4824),
    [anon_sym_clocking] = ACTIONS(4824),
    [anon_sym_defparam] = ACTIONS(4824),
    [anon_sym_bind] = ACTIONS(4824),
    [anon_sym_rand] = ACTIONS(4824),
    [anon_sym_const] = ACTIONS(4824),
    [anon_sym_function] = ACTIONS(4824),
    [anon_sym_static] = ACTIONS(4824),
    [anon_sym_constraint] = ACTIONS(4824),
    [anon_sym_if] = ACTIONS(4824),
    [anon_sym_else] = ACTIONS(4824),
    [anon_sym_LBRACK] = ACTIONS(4822),
    [anon_sym_localparam] = ACTIONS(4824),
    [anon_sym_parameter] = ACTIONS(4824),
    [anon_sym_var] = ACTIONS(4824),
    [anon_sym_import] = ACTIONS(4824),
    [anon_sym_export] = ACTIONS(4824),
    [anon_sym_genvar] = ACTIONS(4824),
    [anon_sym_interconnect] = ACTIONS(4824),
    [anon_sym_typedef] = ACTIONS(4824),
    [anon_sym_enum] = ACTIONS(4824),
    [anon_sym_struct] = ACTIONS(4824),
    [anon_sym_union] = ACTIONS(4824),
    [anon_sym_nettype] = ACTIONS(4824),
    [anon_sym_automatic] = ACTIONS(4824),
    [anon_sym_string] = ACTIONS(4824),
    [anon_sym_chandle] = ACTIONS(4824),
    [anon_sym_event] = ACTIONS(4824),
    [anon_sym_byte] = ACTIONS(4824),
    [anon_sym_shortint] = ACTIONS(4824),
    [anon_sym_int] = ACTIONS(4824),
    [anon_sym_longint] = ACTIONS(4824),
    [anon_sym_integer] = ACTIONS(4824),
    [anon_sym_time] = ACTIONS(4824),
    [anon_sym_bit] = ACTIONS(4824),
    [anon_sym_logic] = ACTIONS(4824),
    [anon_sym_reg] = ACTIONS(4824),
    [anon_sym_shortreal] = ACTIONS(4824),
    [anon_sym_real] = ACTIONS(4824),
    [anon_sym_realtime] = ACTIONS(4824),
    [anon_sym_supply0] = ACTIONS(4824),
    [anon_sym_supply1] = ACTIONS(4824),
    [anon_sym_signed] = ACTIONS(4824),
    [anon_sym_unsigned] = ACTIONS(4824),
    [anon_sym_task] = ACTIONS(4824),
    [anon_sym_assert] = ACTIONS(4824),
    [anon_sym_property] = ACTIONS(4824),
    [anon_sym_assume] = ACTIONS(4824),
    [anon_sym_cover] = ACTIONS(4824),
    [anon_sym_sequence] = ACTIONS(4824),
    [anon_sym_restrict] = ACTIONS(4824),
    [anon_sym_not] = ACTIONS(4824),
    [anon_sym_or] = ACTIONS(4824),
    [anon_sym_and] = ACTIONS(4824),
    [anon_sym_case] = ACTIONS(4824),
    [anon_sym_always] = ACTIONS(4824),
    [anon_sym_covergroup] = ACTIONS(4824),
    [anon_sym_end] = ACTIONS(4824),
    [anon_sym_let] = ACTIONS(4824),
    [anon_sym_pulldown] = ACTIONS(4824),
    [anon_sym_pullup] = ACTIONS(4824),
    [anon_sym_cmos] = ACTIONS(4824),
    [anon_sym_rcmos] = ACTIONS(4824),
    [anon_sym_bufif0] = ACTIONS(4824),
    [anon_sym_bufif1] = ACTIONS(4824),
    [anon_sym_notif0] = ACTIONS(4824),
    [anon_sym_notif1] = ACTIONS(4824),
    [anon_sym_nmos] = ACTIONS(4824),
    [anon_sym_pmos] = ACTIONS(4824),
    [anon_sym_rnmos] = ACTIONS(4824),
    [anon_sym_rpmos] = ACTIONS(4824),
    [anon_sym_nand] = ACTIONS(4824),
    [anon_sym_nor] = ACTIONS(4824),
    [anon_sym_xor] = ACTIONS(4824),
    [anon_sym_xnor] = ACTIONS(4824),
    [anon_sym_buf] = ACTIONS(4824),
    [anon_sym_tranif0] = ACTIONS(4824),
    [anon_sym_tranif1] = ACTIONS(4824),
    [anon_sym_rtranif1] = ACTIONS(4824),
    [anon_sym_rtranif0] = ACTIONS(4824),
    [anon_sym_tran] = ACTIONS(4824),
    [anon_sym_rtran] = ACTIONS(4824),
    [anon_sym_generate] = ACTIONS(4824),
    [anon_sym_for] = ACTIONS(4824),
    [anon_sym_initial] = ACTIONS(4824),
    [anon_sym_assign] = ACTIONS(4824),
    [anon_sym_alias] = ACTIONS(4824),
    [anon_sym_always_comb] = ACTIONS(4824),
    [anon_sym_always_latch] = ACTIONS(4824),
    [anon_sym_always_ff] = ACTIONS(4824),
    [anon_sym_final] = ACTIONS(4824),
    [anon_sym_global] = ACTIONS(4824),
    [anon_sym_LPAREN_STAR] = ACTIONS(4822),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4822),
    [anon_sym_DOLLARunit] = ACTIONS(4822),
  },
  [5026] = {
    [sym_simple_identifier] = ACTIONS(5306),
    [anon_sym_wire] = ACTIONS(5306),
    [anon_sym_tri] = ACTIONS(5306),
    [anon_sym_tri0] = ACTIONS(5306),
    [anon_sym_tri1] = ACTIONS(5306),
    [anon_sym_wand] = ACTIONS(5306),
    [anon_sym_triand] = ACTIONS(5306),
    [anon_sym_wor] = ACTIONS(5306),
    [anon_sym_trior] = ACTIONS(5306),
    [anon_sym_trireg] = ACTIONS(5306),
    [anon_sym_uwire] = ACTIONS(5306),
    [anon_sym_SEMI] = ACTIONS(5304),
    [anon_sym_extern] = ACTIONS(5306),
    [anon_sym_interface] = ACTIONS(5306),
    [anon_sym_checker] = ACTIONS(5306),
    [anon_sym_virtual] = ACTIONS(5306),
    [anon_sym_class] = ACTIONS(5306),
    [anon_sym_type] = ACTIONS(5306),
    [anon_sym_DOLLARfatal] = ACTIONS(5304),
    [anon_sym_DOLLARerror] = ACTIONS(5304),
    [anon_sym_DOLLARwarning] = ACTIONS(5304),
    [anon_sym_DOLLARinfo] = ACTIONS(5304),
    [anon_sym_default] = ACTIONS(5306),
    [anon_sym_clocking] = ACTIONS(5306),
    [anon_sym_defparam] = ACTIONS(5306),
    [anon_sym_bind] = ACTIONS(5306),
    [anon_sym_rand] = ACTIONS(5306),
    [anon_sym_const] = ACTIONS(5306),
    [anon_sym_function] = ACTIONS(5306),
    [anon_sym_static] = ACTIONS(5306),
    [anon_sym_constraint] = ACTIONS(5306),
    [anon_sym_if] = ACTIONS(5306),
    [anon_sym_else] = ACTIONS(5306),
    [anon_sym_LBRACK] = ACTIONS(5304),
    [anon_sym_localparam] = ACTIONS(5306),
    [anon_sym_parameter] = ACTIONS(5306),
    [anon_sym_var] = ACTIONS(5306),
    [anon_sym_import] = ACTIONS(5306),
    [anon_sym_export] = ACTIONS(5306),
    [anon_sym_genvar] = ACTIONS(5306),
    [anon_sym_interconnect] = ACTIONS(5306),
    [anon_sym_typedef] = ACTIONS(5306),
    [anon_sym_enum] = ACTIONS(5306),
    [anon_sym_struct] = ACTIONS(5306),
    [anon_sym_union] = ACTIONS(5306),
    [anon_sym_nettype] = ACTIONS(5306),
    [anon_sym_automatic] = ACTIONS(5306),
    [anon_sym_string] = ACTIONS(5306),
    [anon_sym_chandle] = ACTIONS(5306),
    [anon_sym_event] = ACTIONS(5306),
    [anon_sym_byte] = ACTIONS(5306),
    [anon_sym_shortint] = ACTIONS(5306),
    [anon_sym_int] = ACTIONS(5306),
    [anon_sym_longint] = ACTIONS(5306),
    [anon_sym_integer] = ACTIONS(5306),
    [anon_sym_time] = ACTIONS(5306),
    [anon_sym_bit] = ACTIONS(5306),
    [anon_sym_logic] = ACTIONS(5306),
    [anon_sym_reg] = ACTIONS(5306),
    [anon_sym_shortreal] = ACTIONS(5306),
    [anon_sym_real] = ACTIONS(5306),
    [anon_sym_realtime] = ACTIONS(5306),
    [anon_sym_supply0] = ACTIONS(5306),
    [anon_sym_supply1] = ACTIONS(5306),
    [anon_sym_signed] = ACTIONS(5306),
    [anon_sym_unsigned] = ACTIONS(5306),
    [anon_sym_task] = ACTIONS(5306),
    [anon_sym_assert] = ACTIONS(5306),
    [anon_sym_property] = ACTIONS(5306),
    [anon_sym_assume] = ACTIONS(5306),
    [anon_sym_cover] = ACTIONS(5306),
    [anon_sym_sequence] = ACTIONS(5306),
    [anon_sym_restrict] = ACTIONS(5306),
    [anon_sym_not] = ACTIONS(5306),
    [anon_sym_or] = ACTIONS(5306),
    [anon_sym_and] = ACTIONS(5306),
    [anon_sym_case] = ACTIONS(5306),
    [anon_sym_always] = ACTIONS(5306),
    [anon_sym_covergroup] = ACTIONS(5306),
    [anon_sym_end] = ACTIONS(5306),
    [anon_sym_let] = ACTIONS(5306),
    [anon_sym_pulldown] = ACTIONS(5306),
    [anon_sym_pullup] = ACTIONS(5306),
    [anon_sym_cmos] = ACTIONS(5306),
    [anon_sym_rcmos] = ACTIONS(5306),
    [anon_sym_bufif0] = ACTIONS(5306),
    [anon_sym_bufif1] = ACTIONS(5306),
    [anon_sym_notif0] = ACTIONS(5306),
    [anon_sym_notif1] = ACTIONS(5306),
    [anon_sym_nmos] = ACTIONS(5306),
    [anon_sym_pmos] = ACTIONS(5306),
    [anon_sym_rnmos] = ACTIONS(5306),
    [anon_sym_rpmos] = ACTIONS(5306),
    [anon_sym_nand] = ACTIONS(5306),
    [anon_sym_nor] = ACTIONS(5306),
    [anon_sym_xor] = ACTIONS(5306),
    [anon_sym_xnor] = ACTIONS(5306),
    [anon_sym_buf] = ACTIONS(5306),
    [anon_sym_tranif0] = ACTIONS(5306),
    [anon_sym_tranif1] = ACTIONS(5306),
    [anon_sym_rtranif1] = ACTIONS(5306),
    [anon_sym_rtranif0] = ACTIONS(5306),
    [anon_sym_tran] = ACTIONS(5306),
    [anon_sym_rtran] = ACTIONS(5306),
    [anon_sym_generate] = ACTIONS(5306),
    [anon_sym_for] = ACTIONS(5306),
    [anon_sym_initial] = ACTIONS(5306),
    [anon_sym_assign] = ACTIONS(5306),
    [anon_sym_alias] = ACTIONS(5306),
    [anon_sym_always_comb] = ACTIONS(5306),
    [anon_sym_always_latch] = ACTIONS(5306),
    [anon_sym_always_ff] = ACTIONS(5306),
    [anon_sym_final] = ACTIONS(5306),
    [anon_sym_global] = ACTIONS(5306),
    [anon_sym_LPAREN_STAR] = ACTIONS(5304),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5304),
    [anon_sym_DOLLARunit] = ACTIONS(5304),
  },
  [5027] = {
    [sym_simple_identifier] = ACTIONS(4828),
    [anon_sym_wire] = ACTIONS(4828),
    [anon_sym_tri] = ACTIONS(4828),
    [anon_sym_tri0] = ACTIONS(4828),
    [anon_sym_tri1] = ACTIONS(4828),
    [anon_sym_wand] = ACTIONS(4828),
    [anon_sym_triand] = ACTIONS(4828),
    [anon_sym_wor] = ACTIONS(4828),
    [anon_sym_trior] = ACTIONS(4828),
    [anon_sym_trireg] = ACTIONS(4828),
    [anon_sym_uwire] = ACTIONS(4828),
    [anon_sym_SEMI] = ACTIONS(4826),
    [anon_sym_extern] = ACTIONS(4828),
    [anon_sym_interface] = ACTIONS(4828),
    [anon_sym_checker] = ACTIONS(4828),
    [anon_sym_virtual] = ACTIONS(4828),
    [anon_sym_class] = ACTIONS(4828),
    [anon_sym_type] = ACTIONS(4828),
    [anon_sym_DOLLARfatal] = ACTIONS(4826),
    [anon_sym_DOLLARerror] = ACTIONS(4826),
    [anon_sym_DOLLARwarning] = ACTIONS(4826),
    [anon_sym_DOLLARinfo] = ACTIONS(4826),
    [anon_sym_default] = ACTIONS(4828),
    [anon_sym_clocking] = ACTIONS(4828),
    [anon_sym_defparam] = ACTIONS(4828),
    [anon_sym_bind] = ACTIONS(4828),
    [anon_sym_rand] = ACTIONS(4828),
    [anon_sym_const] = ACTIONS(4828),
    [anon_sym_function] = ACTIONS(4828),
    [anon_sym_static] = ACTIONS(4828),
    [anon_sym_constraint] = ACTIONS(4828),
    [anon_sym_if] = ACTIONS(4828),
    [anon_sym_else] = ACTIONS(4828),
    [anon_sym_LBRACK] = ACTIONS(4826),
    [anon_sym_localparam] = ACTIONS(4828),
    [anon_sym_parameter] = ACTIONS(4828),
    [anon_sym_var] = ACTIONS(4828),
    [anon_sym_import] = ACTIONS(4828),
    [anon_sym_export] = ACTIONS(4828),
    [anon_sym_genvar] = ACTIONS(4828),
    [anon_sym_interconnect] = ACTIONS(4828),
    [anon_sym_typedef] = ACTIONS(4828),
    [anon_sym_enum] = ACTIONS(4828),
    [anon_sym_struct] = ACTIONS(4828),
    [anon_sym_union] = ACTIONS(4828),
    [anon_sym_nettype] = ACTIONS(4828),
    [anon_sym_automatic] = ACTIONS(4828),
    [anon_sym_string] = ACTIONS(4828),
    [anon_sym_chandle] = ACTIONS(4828),
    [anon_sym_event] = ACTIONS(4828),
    [anon_sym_byte] = ACTIONS(4828),
    [anon_sym_shortint] = ACTIONS(4828),
    [anon_sym_int] = ACTIONS(4828),
    [anon_sym_longint] = ACTIONS(4828),
    [anon_sym_integer] = ACTIONS(4828),
    [anon_sym_time] = ACTIONS(4828),
    [anon_sym_bit] = ACTIONS(4828),
    [anon_sym_logic] = ACTIONS(4828),
    [anon_sym_reg] = ACTIONS(4828),
    [anon_sym_shortreal] = ACTIONS(4828),
    [anon_sym_real] = ACTIONS(4828),
    [anon_sym_realtime] = ACTIONS(4828),
    [anon_sym_supply0] = ACTIONS(4828),
    [anon_sym_supply1] = ACTIONS(4828),
    [anon_sym_signed] = ACTIONS(4828),
    [anon_sym_unsigned] = ACTIONS(4828),
    [anon_sym_task] = ACTIONS(4828),
    [anon_sym_assert] = ACTIONS(4828),
    [anon_sym_property] = ACTIONS(4828),
    [anon_sym_assume] = ACTIONS(4828),
    [anon_sym_cover] = ACTIONS(4828),
    [anon_sym_sequence] = ACTIONS(4828),
    [anon_sym_restrict] = ACTIONS(4828),
    [anon_sym_not] = ACTIONS(4828),
    [anon_sym_or] = ACTIONS(4828),
    [anon_sym_and] = ACTIONS(4828),
    [anon_sym_case] = ACTIONS(4828),
    [anon_sym_always] = ACTIONS(4828),
    [anon_sym_covergroup] = ACTIONS(4828),
    [anon_sym_end] = ACTIONS(4828),
    [anon_sym_let] = ACTIONS(4828),
    [anon_sym_pulldown] = ACTIONS(4828),
    [anon_sym_pullup] = ACTIONS(4828),
    [anon_sym_cmos] = ACTIONS(4828),
    [anon_sym_rcmos] = ACTIONS(4828),
    [anon_sym_bufif0] = ACTIONS(4828),
    [anon_sym_bufif1] = ACTIONS(4828),
    [anon_sym_notif0] = ACTIONS(4828),
    [anon_sym_notif1] = ACTIONS(4828),
    [anon_sym_nmos] = ACTIONS(4828),
    [anon_sym_pmos] = ACTIONS(4828),
    [anon_sym_rnmos] = ACTIONS(4828),
    [anon_sym_rpmos] = ACTIONS(4828),
    [anon_sym_nand] = ACTIONS(4828),
    [anon_sym_nor] = ACTIONS(4828),
    [anon_sym_xor] = ACTIONS(4828),
    [anon_sym_xnor] = ACTIONS(4828),
    [anon_sym_buf] = ACTIONS(4828),
    [anon_sym_tranif0] = ACTIONS(4828),
    [anon_sym_tranif1] = ACTIONS(4828),
    [anon_sym_rtranif1] = ACTIONS(4828),
    [anon_sym_rtranif0] = ACTIONS(4828),
    [anon_sym_tran] = ACTIONS(4828),
    [anon_sym_rtran] = ACTIONS(4828),
    [anon_sym_generate] = ACTIONS(4828),
    [anon_sym_for] = ACTIONS(4828),
    [anon_sym_initial] = ACTIONS(4828),
    [anon_sym_assign] = ACTIONS(4828),
    [anon_sym_alias] = ACTIONS(4828),
    [anon_sym_always_comb] = ACTIONS(4828),
    [anon_sym_always_latch] = ACTIONS(4828),
    [anon_sym_always_ff] = ACTIONS(4828),
    [anon_sym_final] = ACTIONS(4828),
    [anon_sym_global] = ACTIONS(4828),
    [anon_sym_LPAREN_STAR] = ACTIONS(4826),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4826),
    [anon_sym_DOLLARunit] = ACTIONS(4826),
  },
  [5028] = {
    [sym_simple_identifier] = ACTIONS(6291),
    [anon_sym_wire] = ACTIONS(6291),
    [anon_sym_tri] = ACTIONS(6291),
    [anon_sym_tri0] = ACTIONS(6291),
    [anon_sym_tri1] = ACTIONS(6291),
    [anon_sym_wand] = ACTIONS(6291),
    [anon_sym_triand] = ACTIONS(6291),
    [anon_sym_wor] = ACTIONS(6291),
    [anon_sym_trior] = ACTIONS(6291),
    [anon_sym_trireg] = ACTIONS(6291),
    [anon_sym_uwire] = ACTIONS(6291),
    [anon_sym_SEMI] = ACTIONS(6293),
    [anon_sym_extern] = ACTIONS(6291),
    [anon_sym_interface] = ACTIONS(6291),
    [anon_sym_checker] = ACTIONS(6291),
    [anon_sym_virtual] = ACTIONS(6291),
    [anon_sym_class] = ACTIONS(6291),
    [anon_sym_type] = ACTIONS(6291),
    [anon_sym_DOLLARfatal] = ACTIONS(6293),
    [anon_sym_DOLLARerror] = ACTIONS(6293),
    [anon_sym_DOLLARwarning] = ACTIONS(6293),
    [anon_sym_DOLLARinfo] = ACTIONS(6293),
    [anon_sym_default] = ACTIONS(6291),
    [anon_sym_clocking] = ACTIONS(6291),
    [anon_sym_defparam] = ACTIONS(6291),
    [anon_sym_bind] = ACTIONS(6291),
    [anon_sym_rand] = ACTIONS(6291),
    [anon_sym_const] = ACTIONS(6291),
    [anon_sym_function] = ACTIONS(6291),
    [anon_sym_static] = ACTIONS(6291),
    [anon_sym_constraint] = ACTIONS(6291),
    [anon_sym_if] = ACTIONS(6291),
    [anon_sym_else] = ACTIONS(6291),
    [anon_sym_LBRACK] = ACTIONS(6293),
    [anon_sym_localparam] = ACTIONS(6291),
    [anon_sym_parameter] = ACTIONS(6291),
    [anon_sym_var] = ACTIONS(6291),
    [anon_sym_import] = ACTIONS(6291),
    [anon_sym_export] = ACTIONS(6291),
    [anon_sym_genvar] = ACTIONS(6291),
    [anon_sym_interconnect] = ACTIONS(6291),
    [anon_sym_typedef] = ACTIONS(6291),
    [anon_sym_enum] = ACTIONS(6291),
    [anon_sym_struct] = ACTIONS(6291),
    [anon_sym_union] = ACTIONS(6291),
    [anon_sym_nettype] = ACTIONS(6291),
    [anon_sym_automatic] = ACTIONS(6291),
    [anon_sym_string] = ACTIONS(6291),
    [anon_sym_chandle] = ACTIONS(6291),
    [anon_sym_event] = ACTIONS(6291),
    [anon_sym_byte] = ACTIONS(6291),
    [anon_sym_shortint] = ACTIONS(6291),
    [anon_sym_int] = ACTIONS(6291),
    [anon_sym_longint] = ACTIONS(6291),
    [anon_sym_integer] = ACTIONS(6291),
    [anon_sym_time] = ACTIONS(6291),
    [anon_sym_bit] = ACTIONS(6291),
    [anon_sym_logic] = ACTIONS(6291),
    [anon_sym_reg] = ACTIONS(6291),
    [anon_sym_shortreal] = ACTIONS(6291),
    [anon_sym_real] = ACTIONS(6291),
    [anon_sym_realtime] = ACTIONS(6291),
    [anon_sym_supply0] = ACTIONS(6291),
    [anon_sym_supply1] = ACTIONS(6291),
    [anon_sym_signed] = ACTIONS(6291),
    [anon_sym_unsigned] = ACTIONS(6291),
    [anon_sym_task] = ACTIONS(6291),
    [anon_sym_assert] = ACTIONS(6291),
    [anon_sym_property] = ACTIONS(6291),
    [anon_sym_assume] = ACTIONS(6291),
    [anon_sym_cover] = ACTIONS(6291),
    [anon_sym_sequence] = ACTIONS(6291),
    [anon_sym_restrict] = ACTIONS(6291),
    [anon_sym_not] = ACTIONS(6291),
    [anon_sym_or] = ACTIONS(6291),
    [anon_sym_and] = ACTIONS(6291),
    [anon_sym_case] = ACTIONS(6291),
    [anon_sym_always] = ACTIONS(6291),
    [anon_sym_covergroup] = ACTIONS(6291),
    [anon_sym_let] = ACTIONS(6291),
    [anon_sym_pulldown] = ACTIONS(6291),
    [anon_sym_pullup] = ACTIONS(6291),
    [anon_sym_cmos] = ACTIONS(6291),
    [anon_sym_rcmos] = ACTIONS(6291),
    [anon_sym_bufif0] = ACTIONS(6291),
    [anon_sym_bufif1] = ACTIONS(6291),
    [anon_sym_notif0] = ACTIONS(6291),
    [anon_sym_notif1] = ACTIONS(6291),
    [anon_sym_nmos] = ACTIONS(6291),
    [anon_sym_pmos] = ACTIONS(6291),
    [anon_sym_rnmos] = ACTIONS(6291),
    [anon_sym_rpmos] = ACTIONS(6291),
    [anon_sym_nand] = ACTIONS(6291),
    [anon_sym_nor] = ACTIONS(6291),
    [anon_sym_xor] = ACTIONS(6291),
    [anon_sym_xnor] = ACTIONS(6291),
    [anon_sym_buf] = ACTIONS(6291),
    [anon_sym_tranif0] = ACTIONS(6291),
    [anon_sym_tranif1] = ACTIONS(6291),
    [anon_sym_rtranif1] = ACTIONS(6291),
    [anon_sym_rtranif0] = ACTIONS(6291),
    [anon_sym_tran] = ACTIONS(6291),
    [anon_sym_rtran] = ACTIONS(6291),
    [anon_sym_generate] = ACTIONS(6291),
    [anon_sym_endgenerate] = ACTIONS(6291),
    [anon_sym_for] = ACTIONS(6291),
    [anon_sym_initial] = ACTIONS(6291),
    [anon_sym_assign] = ACTIONS(6291),
    [anon_sym_alias] = ACTIONS(6291),
    [anon_sym_always_comb] = ACTIONS(6291),
    [anon_sym_always_latch] = ACTIONS(6291),
    [anon_sym_always_ff] = ACTIONS(6291),
    [anon_sym_final] = ACTIONS(6291),
    [anon_sym_global] = ACTIONS(6291),
    [anon_sym_LPAREN_STAR] = ACTIONS(6293),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6293),
    [anon_sym_DOLLARunit] = ACTIONS(6293),
  },
  [5029] = {
    [sym_simple_identifier] = ACTIONS(6295),
    [anon_sym_wire] = ACTIONS(6295),
    [anon_sym_tri] = ACTIONS(6295),
    [anon_sym_tri0] = ACTIONS(6295),
    [anon_sym_tri1] = ACTIONS(6295),
    [anon_sym_wand] = ACTIONS(6295),
    [anon_sym_triand] = ACTIONS(6295),
    [anon_sym_wor] = ACTIONS(6295),
    [anon_sym_trior] = ACTIONS(6295),
    [anon_sym_trireg] = ACTIONS(6295),
    [anon_sym_uwire] = ACTIONS(6295),
    [anon_sym_SEMI] = ACTIONS(6297),
    [anon_sym_extern] = ACTIONS(6295),
    [anon_sym_interface] = ACTIONS(6295),
    [anon_sym_checker] = ACTIONS(6295),
    [anon_sym_virtual] = ACTIONS(6295),
    [anon_sym_class] = ACTIONS(6295),
    [anon_sym_type] = ACTIONS(6295),
    [anon_sym_DOLLARfatal] = ACTIONS(6297),
    [anon_sym_DOLLARerror] = ACTIONS(6297),
    [anon_sym_DOLLARwarning] = ACTIONS(6297),
    [anon_sym_DOLLARinfo] = ACTIONS(6297),
    [anon_sym_default] = ACTIONS(6295),
    [anon_sym_clocking] = ACTIONS(6295),
    [anon_sym_defparam] = ACTIONS(6295),
    [anon_sym_bind] = ACTIONS(6295),
    [anon_sym_rand] = ACTIONS(6295),
    [anon_sym_const] = ACTIONS(6295),
    [anon_sym_function] = ACTIONS(6295),
    [anon_sym_static] = ACTIONS(6295),
    [anon_sym_constraint] = ACTIONS(6295),
    [anon_sym_if] = ACTIONS(6295),
    [anon_sym_else] = ACTIONS(6295),
    [anon_sym_LBRACK] = ACTIONS(6297),
    [anon_sym_localparam] = ACTIONS(6295),
    [anon_sym_parameter] = ACTIONS(6295),
    [anon_sym_var] = ACTIONS(6295),
    [anon_sym_import] = ACTIONS(6295),
    [anon_sym_export] = ACTIONS(6295),
    [anon_sym_genvar] = ACTIONS(6295),
    [anon_sym_interconnect] = ACTIONS(6295),
    [anon_sym_typedef] = ACTIONS(6295),
    [anon_sym_enum] = ACTIONS(6295),
    [anon_sym_struct] = ACTIONS(6295),
    [anon_sym_union] = ACTIONS(6295),
    [anon_sym_nettype] = ACTIONS(6295),
    [anon_sym_automatic] = ACTIONS(6295),
    [anon_sym_string] = ACTIONS(6295),
    [anon_sym_chandle] = ACTIONS(6295),
    [anon_sym_event] = ACTIONS(6295),
    [anon_sym_byte] = ACTIONS(6295),
    [anon_sym_shortint] = ACTIONS(6295),
    [anon_sym_int] = ACTIONS(6295),
    [anon_sym_longint] = ACTIONS(6295),
    [anon_sym_integer] = ACTIONS(6295),
    [anon_sym_time] = ACTIONS(6295),
    [anon_sym_bit] = ACTIONS(6295),
    [anon_sym_logic] = ACTIONS(6295),
    [anon_sym_reg] = ACTIONS(6295),
    [anon_sym_shortreal] = ACTIONS(6295),
    [anon_sym_real] = ACTIONS(6295),
    [anon_sym_realtime] = ACTIONS(6295),
    [anon_sym_supply0] = ACTIONS(6295),
    [anon_sym_supply1] = ACTIONS(6295),
    [anon_sym_signed] = ACTIONS(6295),
    [anon_sym_unsigned] = ACTIONS(6295),
    [anon_sym_task] = ACTIONS(6295),
    [anon_sym_assert] = ACTIONS(6295),
    [anon_sym_property] = ACTIONS(6295),
    [anon_sym_assume] = ACTIONS(6295),
    [anon_sym_cover] = ACTIONS(6295),
    [anon_sym_sequence] = ACTIONS(6295),
    [anon_sym_restrict] = ACTIONS(6295),
    [anon_sym_not] = ACTIONS(6295),
    [anon_sym_or] = ACTIONS(6295),
    [anon_sym_and] = ACTIONS(6295),
    [anon_sym_case] = ACTIONS(6295),
    [anon_sym_always] = ACTIONS(6295),
    [anon_sym_covergroup] = ACTIONS(6295),
    [anon_sym_let] = ACTIONS(6295),
    [anon_sym_pulldown] = ACTIONS(6295),
    [anon_sym_pullup] = ACTIONS(6295),
    [anon_sym_cmos] = ACTIONS(6295),
    [anon_sym_rcmos] = ACTIONS(6295),
    [anon_sym_bufif0] = ACTIONS(6295),
    [anon_sym_bufif1] = ACTIONS(6295),
    [anon_sym_notif0] = ACTIONS(6295),
    [anon_sym_notif1] = ACTIONS(6295),
    [anon_sym_nmos] = ACTIONS(6295),
    [anon_sym_pmos] = ACTIONS(6295),
    [anon_sym_rnmos] = ACTIONS(6295),
    [anon_sym_rpmos] = ACTIONS(6295),
    [anon_sym_nand] = ACTIONS(6295),
    [anon_sym_nor] = ACTIONS(6295),
    [anon_sym_xor] = ACTIONS(6295),
    [anon_sym_xnor] = ACTIONS(6295),
    [anon_sym_buf] = ACTIONS(6295),
    [anon_sym_tranif0] = ACTIONS(6295),
    [anon_sym_tranif1] = ACTIONS(6295),
    [anon_sym_rtranif1] = ACTIONS(6295),
    [anon_sym_rtranif0] = ACTIONS(6295),
    [anon_sym_tran] = ACTIONS(6295),
    [anon_sym_rtran] = ACTIONS(6295),
    [anon_sym_generate] = ACTIONS(6295),
    [anon_sym_endgenerate] = ACTIONS(6295),
    [anon_sym_for] = ACTIONS(6295),
    [anon_sym_initial] = ACTIONS(6295),
    [anon_sym_assign] = ACTIONS(6295),
    [anon_sym_alias] = ACTIONS(6295),
    [anon_sym_always_comb] = ACTIONS(6295),
    [anon_sym_always_latch] = ACTIONS(6295),
    [anon_sym_always_ff] = ACTIONS(6295),
    [anon_sym_final] = ACTIONS(6295),
    [anon_sym_global] = ACTIONS(6295),
    [anon_sym_LPAREN_STAR] = ACTIONS(6297),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6297),
    [anon_sym_DOLLARunit] = ACTIONS(6297),
  },
  [5030] = {
    [sym_simple_identifier] = ACTIONS(6673),
    [anon_sym_wire] = ACTIONS(6673),
    [anon_sym_tri] = ACTIONS(6673),
    [anon_sym_tri0] = ACTIONS(6673),
    [anon_sym_tri1] = ACTIONS(6673),
    [anon_sym_wand] = ACTIONS(6673),
    [anon_sym_triand] = ACTIONS(6673),
    [anon_sym_wor] = ACTIONS(6673),
    [anon_sym_trior] = ACTIONS(6673),
    [anon_sym_trireg] = ACTIONS(6673),
    [anon_sym_uwire] = ACTIONS(6673),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_extern] = ACTIONS(6673),
    [anon_sym_interface] = ACTIONS(6673),
    [anon_sym_checker] = ACTIONS(6673),
    [anon_sym_virtual] = ACTIONS(6673),
    [anon_sym_class] = ACTIONS(6673),
    [anon_sym_type] = ACTIONS(6673),
    [anon_sym_DOLLARfatal] = ACTIONS(6675),
    [anon_sym_DOLLARerror] = ACTIONS(6675),
    [anon_sym_DOLLARwarning] = ACTIONS(6675),
    [anon_sym_DOLLARinfo] = ACTIONS(6675),
    [anon_sym_default] = ACTIONS(6673),
    [anon_sym_clocking] = ACTIONS(6673),
    [anon_sym_defparam] = ACTIONS(6673),
    [anon_sym_bind] = ACTIONS(6673),
    [anon_sym_rand] = ACTIONS(6673),
    [anon_sym_const] = ACTIONS(6673),
    [anon_sym_function] = ACTIONS(6673),
    [anon_sym_static] = ACTIONS(6673),
    [anon_sym_constraint] = ACTIONS(6673),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_else] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [anon_sym_localparam] = ACTIONS(6673),
    [anon_sym_parameter] = ACTIONS(6673),
    [anon_sym_var] = ACTIONS(6673),
    [anon_sym_import] = ACTIONS(6673),
    [anon_sym_export] = ACTIONS(6673),
    [anon_sym_genvar] = ACTIONS(6673),
    [anon_sym_interconnect] = ACTIONS(6673),
    [anon_sym_typedef] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_struct] = ACTIONS(6673),
    [anon_sym_union] = ACTIONS(6673),
    [anon_sym_nettype] = ACTIONS(6673),
    [anon_sym_automatic] = ACTIONS(6673),
    [anon_sym_string] = ACTIONS(6673),
    [anon_sym_chandle] = ACTIONS(6673),
    [anon_sym_event] = ACTIONS(6673),
    [anon_sym_byte] = ACTIONS(6673),
    [anon_sym_shortint] = ACTIONS(6673),
    [anon_sym_int] = ACTIONS(6673),
    [anon_sym_longint] = ACTIONS(6673),
    [anon_sym_integer] = ACTIONS(6673),
    [anon_sym_time] = ACTIONS(6673),
    [anon_sym_bit] = ACTIONS(6673),
    [anon_sym_logic] = ACTIONS(6673),
    [anon_sym_reg] = ACTIONS(6673),
    [anon_sym_shortreal] = ACTIONS(6673),
    [anon_sym_real] = ACTIONS(6673),
    [anon_sym_realtime] = ACTIONS(6673),
    [anon_sym_supply0] = ACTIONS(6673),
    [anon_sym_supply1] = ACTIONS(6673),
    [anon_sym_signed] = ACTIONS(6673),
    [anon_sym_unsigned] = ACTIONS(6673),
    [anon_sym_task] = ACTIONS(6673),
    [anon_sym_assert] = ACTIONS(6673),
    [anon_sym_property] = ACTIONS(6673),
    [anon_sym_assume] = ACTIONS(6673),
    [anon_sym_cover] = ACTIONS(6673),
    [anon_sym_sequence] = ACTIONS(6673),
    [anon_sym_restrict] = ACTIONS(6673),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_or] = ACTIONS(6673),
    [anon_sym_and] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_always] = ACTIONS(6673),
    [anon_sym_covergroup] = ACTIONS(6673),
    [anon_sym_let] = ACTIONS(6673),
    [anon_sym_pulldown] = ACTIONS(6673),
    [anon_sym_pullup] = ACTIONS(6673),
    [anon_sym_cmos] = ACTIONS(6673),
    [anon_sym_rcmos] = ACTIONS(6673),
    [anon_sym_bufif0] = ACTIONS(6673),
    [anon_sym_bufif1] = ACTIONS(6673),
    [anon_sym_notif0] = ACTIONS(6673),
    [anon_sym_notif1] = ACTIONS(6673),
    [anon_sym_nmos] = ACTIONS(6673),
    [anon_sym_pmos] = ACTIONS(6673),
    [anon_sym_rnmos] = ACTIONS(6673),
    [anon_sym_rpmos] = ACTIONS(6673),
    [anon_sym_nand] = ACTIONS(6673),
    [anon_sym_nor] = ACTIONS(6673),
    [anon_sym_xor] = ACTIONS(6673),
    [anon_sym_xnor] = ACTIONS(6673),
    [anon_sym_buf] = ACTIONS(6673),
    [anon_sym_tranif0] = ACTIONS(6673),
    [anon_sym_tranif1] = ACTIONS(6673),
    [anon_sym_rtranif1] = ACTIONS(6673),
    [anon_sym_rtranif0] = ACTIONS(6673),
    [anon_sym_tran] = ACTIONS(6673),
    [anon_sym_rtran] = ACTIONS(6673),
    [anon_sym_generate] = ACTIONS(6673),
    [anon_sym_endgenerate] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_initial] = ACTIONS(6673),
    [anon_sym_assign] = ACTIONS(6673),
    [anon_sym_alias] = ACTIONS(6673),
    [anon_sym_always_comb] = ACTIONS(6673),
    [anon_sym_always_latch] = ACTIONS(6673),
    [anon_sym_always_ff] = ACTIONS(6673),
    [anon_sym_final] = ACTIONS(6673),
    [anon_sym_global] = ACTIONS(6673),
    [anon_sym_LPAREN_STAR] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6675),
    [anon_sym_DOLLARunit] = ACTIONS(6675),
  },
  [5031] = {
    [sym_simple_identifier] = ACTIONS(6581),
    [anon_sym_wire] = ACTIONS(6581),
    [anon_sym_tri] = ACTIONS(6581),
    [anon_sym_tri0] = ACTIONS(6581),
    [anon_sym_tri1] = ACTIONS(6581),
    [anon_sym_wand] = ACTIONS(6581),
    [anon_sym_triand] = ACTIONS(6581),
    [anon_sym_wor] = ACTIONS(6581),
    [anon_sym_trior] = ACTIONS(6581),
    [anon_sym_trireg] = ACTIONS(6581),
    [anon_sym_uwire] = ACTIONS(6581),
    [anon_sym_SEMI] = ACTIONS(6583),
    [anon_sym_extern] = ACTIONS(6581),
    [anon_sym_interface] = ACTIONS(6581),
    [anon_sym_checker] = ACTIONS(6581),
    [anon_sym_virtual] = ACTIONS(6581),
    [anon_sym_class] = ACTIONS(6581),
    [anon_sym_type] = ACTIONS(6581),
    [anon_sym_DOLLARfatal] = ACTIONS(6583),
    [anon_sym_DOLLARerror] = ACTIONS(6583),
    [anon_sym_DOLLARwarning] = ACTIONS(6583),
    [anon_sym_DOLLARinfo] = ACTIONS(6583),
    [anon_sym_default] = ACTIONS(6581),
    [anon_sym_clocking] = ACTIONS(6581),
    [anon_sym_defparam] = ACTIONS(6581),
    [anon_sym_bind] = ACTIONS(6581),
    [anon_sym_rand] = ACTIONS(6581),
    [anon_sym_const] = ACTIONS(6581),
    [anon_sym_function] = ACTIONS(6581),
    [anon_sym_static] = ACTIONS(6581),
    [anon_sym_constraint] = ACTIONS(6581),
    [anon_sym_if] = ACTIONS(6581),
    [anon_sym_else] = ACTIONS(6581),
    [anon_sym_LBRACK] = ACTIONS(6583),
    [anon_sym_localparam] = ACTIONS(6581),
    [anon_sym_parameter] = ACTIONS(6581),
    [anon_sym_var] = ACTIONS(6581),
    [anon_sym_import] = ACTIONS(6581),
    [anon_sym_export] = ACTIONS(6581),
    [anon_sym_genvar] = ACTIONS(6581),
    [anon_sym_interconnect] = ACTIONS(6581),
    [anon_sym_typedef] = ACTIONS(6581),
    [anon_sym_enum] = ACTIONS(6581),
    [anon_sym_struct] = ACTIONS(6581),
    [anon_sym_union] = ACTIONS(6581),
    [anon_sym_nettype] = ACTIONS(6581),
    [anon_sym_automatic] = ACTIONS(6581),
    [anon_sym_string] = ACTIONS(6581),
    [anon_sym_chandle] = ACTIONS(6581),
    [anon_sym_event] = ACTIONS(6581),
    [anon_sym_byte] = ACTIONS(6581),
    [anon_sym_shortint] = ACTIONS(6581),
    [anon_sym_int] = ACTIONS(6581),
    [anon_sym_longint] = ACTIONS(6581),
    [anon_sym_integer] = ACTIONS(6581),
    [anon_sym_time] = ACTIONS(6581),
    [anon_sym_bit] = ACTIONS(6581),
    [anon_sym_logic] = ACTIONS(6581),
    [anon_sym_reg] = ACTIONS(6581),
    [anon_sym_shortreal] = ACTIONS(6581),
    [anon_sym_real] = ACTIONS(6581),
    [anon_sym_realtime] = ACTIONS(6581),
    [anon_sym_supply0] = ACTIONS(6581),
    [anon_sym_supply1] = ACTIONS(6581),
    [anon_sym_signed] = ACTIONS(6581),
    [anon_sym_unsigned] = ACTIONS(6581),
    [anon_sym_task] = ACTIONS(6581),
    [anon_sym_assert] = ACTIONS(6581),
    [anon_sym_property] = ACTIONS(6581),
    [anon_sym_assume] = ACTIONS(6581),
    [anon_sym_cover] = ACTIONS(6581),
    [anon_sym_sequence] = ACTIONS(6581),
    [anon_sym_restrict] = ACTIONS(6581),
    [anon_sym_not] = ACTIONS(6581),
    [anon_sym_or] = ACTIONS(6581),
    [anon_sym_and] = ACTIONS(6581),
    [anon_sym_case] = ACTIONS(6581),
    [anon_sym_always] = ACTIONS(6581),
    [anon_sym_covergroup] = ACTIONS(6581),
    [anon_sym_end] = ACTIONS(6581),
    [anon_sym_let] = ACTIONS(6581),
    [anon_sym_pulldown] = ACTIONS(6581),
    [anon_sym_pullup] = ACTIONS(6581),
    [anon_sym_cmos] = ACTIONS(6581),
    [anon_sym_rcmos] = ACTIONS(6581),
    [anon_sym_bufif0] = ACTIONS(6581),
    [anon_sym_bufif1] = ACTIONS(6581),
    [anon_sym_notif0] = ACTIONS(6581),
    [anon_sym_notif1] = ACTIONS(6581),
    [anon_sym_nmos] = ACTIONS(6581),
    [anon_sym_pmos] = ACTIONS(6581),
    [anon_sym_rnmos] = ACTIONS(6581),
    [anon_sym_rpmos] = ACTIONS(6581),
    [anon_sym_nand] = ACTIONS(6581),
    [anon_sym_nor] = ACTIONS(6581),
    [anon_sym_xor] = ACTIONS(6581),
    [anon_sym_xnor] = ACTIONS(6581),
    [anon_sym_buf] = ACTIONS(6581),
    [anon_sym_tranif0] = ACTIONS(6581),
    [anon_sym_tranif1] = ACTIONS(6581),
    [anon_sym_rtranif1] = ACTIONS(6581),
    [anon_sym_rtranif0] = ACTIONS(6581),
    [anon_sym_tran] = ACTIONS(6581),
    [anon_sym_rtran] = ACTIONS(6581),
    [anon_sym_generate] = ACTIONS(6581),
    [anon_sym_for] = ACTIONS(6581),
    [anon_sym_initial] = ACTIONS(6581),
    [anon_sym_assign] = ACTIONS(6581),
    [anon_sym_alias] = ACTIONS(6581),
    [anon_sym_always_comb] = ACTIONS(6581),
    [anon_sym_always_latch] = ACTIONS(6581),
    [anon_sym_always_ff] = ACTIONS(6581),
    [anon_sym_final] = ACTIONS(6581),
    [anon_sym_global] = ACTIONS(6581),
    [anon_sym_LPAREN_STAR] = ACTIONS(6583),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6583),
    [anon_sym_DOLLARunit] = ACTIONS(6583),
  },
  [5032] = {
    [sym_simple_identifier] = ACTIONS(6111),
    [anon_sym_wire] = ACTIONS(6111),
    [anon_sym_tri] = ACTIONS(6111),
    [anon_sym_tri0] = ACTIONS(6111),
    [anon_sym_tri1] = ACTIONS(6111),
    [anon_sym_wand] = ACTIONS(6111),
    [anon_sym_triand] = ACTIONS(6111),
    [anon_sym_wor] = ACTIONS(6111),
    [anon_sym_trior] = ACTIONS(6111),
    [anon_sym_trireg] = ACTIONS(6111),
    [anon_sym_uwire] = ACTIONS(6111),
    [anon_sym_SEMI] = ACTIONS(6113),
    [anon_sym_extern] = ACTIONS(6111),
    [anon_sym_interface] = ACTIONS(6111),
    [anon_sym_checker] = ACTIONS(6111),
    [anon_sym_virtual] = ACTIONS(6111),
    [anon_sym_class] = ACTIONS(6111),
    [anon_sym_type] = ACTIONS(6111),
    [anon_sym_DOLLARfatal] = ACTIONS(6113),
    [anon_sym_DOLLARerror] = ACTIONS(6113),
    [anon_sym_DOLLARwarning] = ACTIONS(6113),
    [anon_sym_DOLLARinfo] = ACTIONS(6113),
    [anon_sym_default] = ACTIONS(6111),
    [anon_sym_clocking] = ACTIONS(6111),
    [anon_sym_defparam] = ACTIONS(6111),
    [anon_sym_bind] = ACTIONS(6111),
    [anon_sym_rand] = ACTIONS(6111),
    [anon_sym_const] = ACTIONS(6111),
    [anon_sym_function] = ACTIONS(6111),
    [anon_sym_static] = ACTIONS(6111),
    [anon_sym_constraint] = ACTIONS(6111),
    [anon_sym_if] = ACTIONS(6111),
    [anon_sym_else] = ACTIONS(6111),
    [anon_sym_LBRACK] = ACTIONS(6113),
    [anon_sym_localparam] = ACTIONS(6111),
    [anon_sym_parameter] = ACTIONS(6111),
    [anon_sym_var] = ACTIONS(6111),
    [anon_sym_import] = ACTIONS(6111),
    [anon_sym_export] = ACTIONS(6111),
    [anon_sym_genvar] = ACTIONS(6111),
    [anon_sym_interconnect] = ACTIONS(6111),
    [anon_sym_typedef] = ACTIONS(6111),
    [anon_sym_enum] = ACTIONS(6111),
    [anon_sym_struct] = ACTIONS(6111),
    [anon_sym_union] = ACTIONS(6111),
    [anon_sym_nettype] = ACTIONS(6111),
    [anon_sym_automatic] = ACTIONS(6111),
    [anon_sym_string] = ACTIONS(6111),
    [anon_sym_chandle] = ACTIONS(6111),
    [anon_sym_event] = ACTIONS(6111),
    [anon_sym_byte] = ACTIONS(6111),
    [anon_sym_shortint] = ACTIONS(6111),
    [anon_sym_int] = ACTIONS(6111),
    [anon_sym_longint] = ACTIONS(6111),
    [anon_sym_integer] = ACTIONS(6111),
    [anon_sym_time] = ACTIONS(6111),
    [anon_sym_bit] = ACTIONS(6111),
    [anon_sym_logic] = ACTIONS(6111),
    [anon_sym_reg] = ACTIONS(6111),
    [anon_sym_shortreal] = ACTIONS(6111),
    [anon_sym_real] = ACTIONS(6111),
    [anon_sym_realtime] = ACTIONS(6111),
    [anon_sym_supply0] = ACTIONS(6111),
    [anon_sym_supply1] = ACTIONS(6111),
    [anon_sym_signed] = ACTIONS(6111),
    [anon_sym_unsigned] = ACTIONS(6111),
    [anon_sym_task] = ACTIONS(6111),
    [anon_sym_assert] = ACTIONS(6111),
    [anon_sym_property] = ACTIONS(6111),
    [anon_sym_assume] = ACTIONS(6111),
    [anon_sym_cover] = ACTIONS(6111),
    [anon_sym_sequence] = ACTIONS(6111),
    [anon_sym_restrict] = ACTIONS(6111),
    [anon_sym_not] = ACTIONS(6111),
    [anon_sym_or] = ACTIONS(6111),
    [anon_sym_and] = ACTIONS(6111),
    [anon_sym_case] = ACTIONS(6111),
    [anon_sym_always] = ACTIONS(6111),
    [anon_sym_covergroup] = ACTIONS(6111),
    [anon_sym_let] = ACTIONS(6111),
    [anon_sym_pulldown] = ACTIONS(6111),
    [anon_sym_pullup] = ACTIONS(6111),
    [anon_sym_cmos] = ACTIONS(6111),
    [anon_sym_rcmos] = ACTIONS(6111),
    [anon_sym_bufif0] = ACTIONS(6111),
    [anon_sym_bufif1] = ACTIONS(6111),
    [anon_sym_notif0] = ACTIONS(6111),
    [anon_sym_notif1] = ACTIONS(6111),
    [anon_sym_nmos] = ACTIONS(6111),
    [anon_sym_pmos] = ACTIONS(6111),
    [anon_sym_rnmos] = ACTIONS(6111),
    [anon_sym_rpmos] = ACTIONS(6111),
    [anon_sym_nand] = ACTIONS(6111),
    [anon_sym_nor] = ACTIONS(6111),
    [anon_sym_xor] = ACTIONS(6111),
    [anon_sym_xnor] = ACTIONS(6111),
    [anon_sym_buf] = ACTIONS(6111),
    [anon_sym_tranif0] = ACTIONS(6111),
    [anon_sym_tranif1] = ACTIONS(6111),
    [anon_sym_rtranif1] = ACTIONS(6111),
    [anon_sym_rtranif0] = ACTIONS(6111),
    [anon_sym_tran] = ACTIONS(6111),
    [anon_sym_rtran] = ACTIONS(6111),
    [anon_sym_generate] = ACTIONS(6111),
    [anon_sym_endgenerate] = ACTIONS(6111),
    [anon_sym_for] = ACTIONS(6111),
    [anon_sym_initial] = ACTIONS(6111),
    [anon_sym_assign] = ACTIONS(6111),
    [anon_sym_alias] = ACTIONS(6111),
    [anon_sym_always_comb] = ACTIONS(6111),
    [anon_sym_always_latch] = ACTIONS(6111),
    [anon_sym_always_ff] = ACTIONS(6111),
    [anon_sym_final] = ACTIONS(6111),
    [anon_sym_global] = ACTIONS(6111),
    [anon_sym_LPAREN_STAR] = ACTIONS(6113),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6113),
    [anon_sym_DOLLARunit] = ACTIONS(6113),
  },
  [5033] = {
    [sym_simple_identifier] = ACTIONS(6715),
    [anon_sym_wire] = ACTIONS(6715),
    [anon_sym_tri] = ACTIONS(6715),
    [anon_sym_tri0] = ACTIONS(6715),
    [anon_sym_tri1] = ACTIONS(6715),
    [anon_sym_wand] = ACTIONS(6715),
    [anon_sym_triand] = ACTIONS(6715),
    [anon_sym_wor] = ACTIONS(6715),
    [anon_sym_trior] = ACTIONS(6715),
    [anon_sym_trireg] = ACTIONS(6715),
    [anon_sym_uwire] = ACTIONS(6715),
    [anon_sym_SEMI] = ACTIONS(6717),
    [anon_sym_extern] = ACTIONS(6715),
    [anon_sym_interface] = ACTIONS(6715),
    [anon_sym_checker] = ACTIONS(6715),
    [anon_sym_virtual] = ACTIONS(6715),
    [anon_sym_class] = ACTIONS(6715),
    [anon_sym_type] = ACTIONS(6715),
    [anon_sym_DOLLARfatal] = ACTIONS(6717),
    [anon_sym_DOLLARerror] = ACTIONS(6717),
    [anon_sym_DOLLARwarning] = ACTIONS(6717),
    [anon_sym_DOLLARinfo] = ACTIONS(6717),
    [anon_sym_default] = ACTIONS(6715),
    [anon_sym_clocking] = ACTIONS(6715),
    [anon_sym_defparam] = ACTIONS(6715),
    [anon_sym_bind] = ACTIONS(6715),
    [anon_sym_rand] = ACTIONS(6715),
    [anon_sym_const] = ACTIONS(6715),
    [anon_sym_function] = ACTIONS(6715),
    [anon_sym_static] = ACTIONS(6715),
    [anon_sym_constraint] = ACTIONS(6715),
    [anon_sym_if] = ACTIONS(6715),
    [anon_sym_else] = ACTIONS(6715),
    [anon_sym_LBRACK] = ACTIONS(6717),
    [anon_sym_localparam] = ACTIONS(6715),
    [anon_sym_parameter] = ACTIONS(6715),
    [anon_sym_var] = ACTIONS(6715),
    [anon_sym_import] = ACTIONS(6715),
    [anon_sym_export] = ACTIONS(6715),
    [anon_sym_genvar] = ACTIONS(6715),
    [anon_sym_interconnect] = ACTIONS(6715),
    [anon_sym_typedef] = ACTIONS(6715),
    [anon_sym_enum] = ACTIONS(6715),
    [anon_sym_struct] = ACTIONS(6715),
    [anon_sym_union] = ACTIONS(6715),
    [anon_sym_nettype] = ACTIONS(6715),
    [anon_sym_automatic] = ACTIONS(6715),
    [anon_sym_string] = ACTIONS(6715),
    [anon_sym_chandle] = ACTIONS(6715),
    [anon_sym_event] = ACTIONS(6715),
    [anon_sym_byte] = ACTIONS(6715),
    [anon_sym_shortint] = ACTIONS(6715),
    [anon_sym_int] = ACTIONS(6715),
    [anon_sym_longint] = ACTIONS(6715),
    [anon_sym_integer] = ACTIONS(6715),
    [anon_sym_time] = ACTIONS(6715),
    [anon_sym_bit] = ACTIONS(6715),
    [anon_sym_logic] = ACTIONS(6715),
    [anon_sym_reg] = ACTIONS(6715),
    [anon_sym_shortreal] = ACTIONS(6715),
    [anon_sym_real] = ACTIONS(6715),
    [anon_sym_realtime] = ACTIONS(6715),
    [anon_sym_supply0] = ACTIONS(6715),
    [anon_sym_supply1] = ACTIONS(6715),
    [anon_sym_signed] = ACTIONS(6715),
    [anon_sym_unsigned] = ACTIONS(6715),
    [anon_sym_task] = ACTIONS(6715),
    [anon_sym_assert] = ACTIONS(6715),
    [anon_sym_property] = ACTIONS(6715),
    [anon_sym_assume] = ACTIONS(6715),
    [anon_sym_cover] = ACTIONS(6715),
    [anon_sym_sequence] = ACTIONS(6715),
    [anon_sym_restrict] = ACTIONS(6715),
    [anon_sym_not] = ACTIONS(6715),
    [anon_sym_or] = ACTIONS(6715),
    [anon_sym_and] = ACTIONS(6715),
    [anon_sym_case] = ACTIONS(6715),
    [anon_sym_always] = ACTIONS(6715),
    [anon_sym_covergroup] = ACTIONS(6715),
    [anon_sym_let] = ACTIONS(6715),
    [anon_sym_pulldown] = ACTIONS(6715),
    [anon_sym_pullup] = ACTIONS(6715),
    [anon_sym_cmos] = ACTIONS(6715),
    [anon_sym_rcmos] = ACTIONS(6715),
    [anon_sym_bufif0] = ACTIONS(6715),
    [anon_sym_bufif1] = ACTIONS(6715),
    [anon_sym_notif0] = ACTIONS(6715),
    [anon_sym_notif1] = ACTIONS(6715),
    [anon_sym_nmos] = ACTIONS(6715),
    [anon_sym_pmos] = ACTIONS(6715),
    [anon_sym_rnmos] = ACTIONS(6715),
    [anon_sym_rpmos] = ACTIONS(6715),
    [anon_sym_nand] = ACTIONS(6715),
    [anon_sym_nor] = ACTIONS(6715),
    [anon_sym_xor] = ACTIONS(6715),
    [anon_sym_xnor] = ACTIONS(6715),
    [anon_sym_buf] = ACTIONS(6715),
    [anon_sym_tranif0] = ACTIONS(6715),
    [anon_sym_tranif1] = ACTIONS(6715),
    [anon_sym_rtranif1] = ACTIONS(6715),
    [anon_sym_rtranif0] = ACTIONS(6715),
    [anon_sym_tran] = ACTIONS(6715),
    [anon_sym_rtran] = ACTIONS(6715),
    [anon_sym_generate] = ACTIONS(6715),
    [anon_sym_endgenerate] = ACTIONS(6715),
    [anon_sym_for] = ACTIONS(6715),
    [anon_sym_initial] = ACTIONS(6715),
    [anon_sym_assign] = ACTIONS(6715),
    [anon_sym_alias] = ACTIONS(6715),
    [anon_sym_always_comb] = ACTIONS(6715),
    [anon_sym_always_latch] = ACTIONS(6715),
    [anon_sym_always_ff] = ACTIONS(6715),
    [anon_sym_final] = ACTIONS(6715),
    [anon_sym_global] = ACTIONS(6715),
    [anon_sym_LPAREN_STAR] = ACTIONS(6717),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6717),
    [anon_sym_DOLLARunit] = ACTIONS(6717),
  },
  [5034] = {
    [sym_simple_identifier] = ACTIONS(6605),
    [anon_sym_wire] = ACTIONS(6605),
    [anon_sym_tri] = ACTIONS(6605),
    [anon_sym_tri0] = ACTIONS(6605),
    [anon_sym_tri1] = ACTIONS(6605),
    [anon_sym_wand] = ACTIONS(6605),
    [anon_sym_triand] = ACTIONS(6605),
    [anon_sym_wor] = ACTIONS(6605),
    [anon_sym_trior] = ACTIONS(6605),
    [anon_sym_trireg] = ACTIONS(6605),
    [anon_sym_uwire] = ACTIONS(6605),
    [anon_sym_SEMI] = ACTIONS(6607),
    [anon_sym_extern] = ACTIONS(6605),
    [anon_sym_interface] = ACTIONS(6605),
    [anon_sym_checker] = ACTIONS(6605),
    [anon_sym_virtual] = ACTIONS(6605),
    [anon_sym_class] = ACTIONS(6605),
    [anon_sym_type] = ACTIONS(6605),
    [anon_sym_DOLLARfatal] = ACTIONS(6607),
    [anon_sym_DOLLARerror] = ACTIONS(6607),
    [anon_sym_DOLLARwarning] = ACTIONS(6607),
    [anon_sym_DOLLARinfo] = ACTIONS(6607),
    [anon_sym_default] = ACTIONS(6605),
    [anon_sym_clocking] = ACTIONS(6605),
    [anon_sym_defparam] = ACTIONS(6605),
    [anon_sym_bind] = ACTIONS(6605),
    [anon_sym_rand] = ACTIONS(6605),
    [anon_sym_const] = ACTIONS(6605),
    [anon_sym_function] = ACTIONS(6605),
    [anon_sym_static] = ACTIONS(6605),
    [anon_sym_constraint] = ACTIONS(6605),
    [anon_sym_if] = ACTIONS(6605),
    [anon_sym_else] = ACTIONS(6605),
    [anon_sym_LBRACK] = ACTIONS(6607),
    [anon_sym_localparam] = ACTIONS(6605),
    [anon_sym_parameter] = ACTIONS(6605),
    [anon_sym_var] = ACTIONS(6605),
    [anon_sym_import] = ACTIONS(6605),
    [anon_sym_export] = ACTIONS(6605),
    [anon_sym_genvar] = ACTIONS(6605),
    [anon_sym_interconnect] = ACTIONS(6605),
    [anon_sym_typedef] = ACTIONS(6605),
    [anon_sym_enum] = ACTIONS(6605),
    [anon_sym_struct] = ACTIONS(6605),
    [anon_sym_union] = ACTIONS(6605),
    [anon_sym_nettype] = ACTIONS(6605),
    [anon_sym_automatic] = ACTIONS(6605),
    [anon_sym_string] = ACTIONS(6605),
    [anon_sym_chandle] = ACTIONS(6605),
    [anon_sym_event] = ACTIONS(6605),
    [anon_sym_byte] = ACTIONS(6605),
    [anon_sym_shortint] = ACTIONS(6605),
    [anon_sym_int] = ACTIONS(6605),
    [anon_sym_longint] = ACTIONS(6605),
    [anon_sym_integer] = ACTIONS(6605),
    [anon_sym_time] = ACTIONS(6605),
    [anon_sym_bit] = ACTIONS(6605),
    [anon_sym_logic] = ACTIONS(6605),
    [anon_sym_reg] = ACTIONS(6605),
    [anon_sym_shortreal] = ACTIONS(6605),
    [anon_sym_real] = ACTIONS(6605),
    [anon_sym_realtime] = ACTIONS(6605),
    [anon_sym_supply0] = ACTIONS(6605),
    [anon_sym_supply1] = ACTIONS(6605),
    [anon_sym_signed] = ACTIONS(6605),
    [anon_sym_unsigned] = ACTIONS(6605),
    [anon_sym_task] = ACTIONS(6605),
    [anon_sym_assert] = ACTIONS(6605),
    [anon_sym_property] = ACTIONS(6605),
    [anon_sym_assume] = ACTIONS(6605),
    [anon_sym_cover] = ACTIONS(6605),
    [anon_sym_sequence] = ACTIONS(6605),
    [anon_sym_restrict] = ACTIONS(6605),
    [anon_sym_not] = ACTIONS(6605),
    [anon_sym_or] = ACTIONS(6605),
    [anon_sym_and] = ACTIONS(6605),
    [anon_sym_case] = ACTIONS(6605),
    [anon_sym_always] = ACTIONS(6605),
    [anon_sym_covergroup] = ACTIONS(6605),
    [anon_sym_end] = ACTIONS(6605),
    [anon_sym_let] = ACTIONS(6605),
    [anon_sym_pulldown] = ACTIONS(6605),
    [anon_sym_pullup] = ACTIONS(6605),
    [anon_sym_cmos] = ACTIONS(6605),
    [anon_sym_rcmos] = ACTIONS(6605),
    [anon_sym_bufif0] = ACTIONS(6605),
    [anon_sym_bufif1] = ACTIONS(6605),
    [anon_sym_notif0] = ACTIONS(6605),
    [anon_sym_notif1] = ACTIONS(6605),
    [anon_sym_nmos] = ACTIONS(6605),
    [anon_sym_pmos] = ACTIONS(6605),
    [anon_sym_rnmos] = ACTIONS(6605),
    [anon_sym_rpmos] = ACTIONS(6605),
    [anon_sym_nand] = ACTIONS(6605),
    [anon_sym_nor] = ACTIONS(6605),
    [anon_sym_xor] = ACTIONS(6605),
    [anon_sym_xnor] = ACTIONS(6605),
    [anon_sym_buf] = ACTIONS(6605),
    [anon_sym_tranif0] = ACTIONS(6605),
    [anon_sym_tranif1] = ACTIONS(6605),
    [anon_sym_rtranif1] = ACTIONS(6605),
    [anon_sym_rtranif0] = ACTIONS(6605),
    [anon_sym_tran] = ACTIONS(6605),
    [anon_sym_rtran] = ACTIONS(6605),
    [anon_sym_generate] = ACTIONS(6605),
    [anon_sym_for] = ACTIONS(6605),
    [anon_sym_initial] = ACTIONS(6605),
    [anon_sym_assign] = ACTIONS(6605),
    [anon_sym_alias] = ACTIONS(6605),
    [anon_sym_always_comb] = ACTIONS(6605),
    [anon_sym_always_latch] = ACTIONS(6605),
    [anon_sym_always_ff] = ACTIONS(6605),
    [anon_sym_final] = ACTIONS(6605),
    [anon_sym_global] = ACTIONS(6605),
    [anon_sym_LPAREN_STAR] = ACTIONS(6607),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6607),
    [anon_sym_DOLLARunit] = ACTIONS(6607),
  },
  [5035] = {
    [sym_simple_identifier] = ACTIONS(6665),
    [anon_sym_wire] = ACTIONS(6665),
    [anon_sym_tri] = ACTIONS(6665),
    [anon_sym_tri0] = ACTIONS(6665),
    [anon_sym_tri1] = ACTIONS(6665),
    [anon_sym_wand] = ACTIONS(6665),
    [anon_sym_triand] = ACTIONS(6665),
    [anon_sym_wor] = ACTIONS(6665),
    [anon_sym_trior] = ACTIONS(6665),
    [anon_sym_trireg] = ACTIONS(6665),
    [anon_sym_uwire] = ACTIONS(6665),
    [anon_sym_SEMI] = ACTIONS(6667),
    [anon_sym_extern] = ACTIONS(6665),
    [anon_sym_interface] = ACTIONS(6665),
    [anon_sym_checker] = ACTIONS(6665),
    [anon_sym_virtual] = ACTIONS(6665),
    [anon_sym_class] = ACTIONS(6665),
    [anon_sym_type] = ACTIONS(6665),
    [anon_sym_DOLLARfatal] = ACTIONS(6667),
    [anon_sym_DOLLARerror] = ACTIONS(6667),
    [anon_sym_DOLLARwarning] = ACTIONS(6667),
    [anon_sym_DOLLARinfo] = ACTIONS(6667),
    [anon_sym_default] = ACTIONS(6665),
    [anon_sym_clocking] = ACTIONS(6665),
    [anon_sym_defparam] = ACTIONS(6665),
    [anon_sym_bind] = ACTIONS(6665),
    [anon_sym_rand] = ACTIONS(6665),
    [anon_sym_const] = ACTIONS(6665),
    [anon_sym_function] = ACTIONS(6665),
    [anon_sym_static] = ACTIONS(6665),
    [anon_sym_constraint] = ACTIONS(6665),
    [anon_sym_if] = ACTIONS(6665),
    [anon_sym_else] = ACTIONS(6665),
    [anon_sym_LBRACK] = ACTIONS(6667),
    [anon_sym_localparam] = ACTIONS(6665),
    [anon_sym_parameter] = ACTIONS(6665),
    [anon_sym_var] = ACTIONS(6665),
    [anon_sym_import] = ACTIONS(6665),
    [anon_sym_export] = ACTIONS(6665),
    [anon_sym_genvar] = ACTIONS(6665),
    [anon_sym_interconnect] = ACTIONS(6665),
    [anon_sym_typedef] = ACTIONS(6665),
    [anon_sym_enum] = ACTIONS(6665),
    [anon_sym_struct] = ACTIONS(6665),
    [anon_sym_union] = ACTIONS(6665),
    [anon_sym_nettype] = ACTIONS(6665),
    [anon_sym_automatic] = ACTIONS(6665),
    [anon_sym_string] = ACTIONS(6665),
    [anon_sym_chandle] = ACTIONS(6665),
    [anon_sym_event] = ACTIONS(6665),
    [anon_sym_byte] = ACTIONS(6665),
    [anon_sym_shortint] = ACTIONS(6665),
    [anon_sym_int] = ACTIONS(6665),
    [anon_sym_longint] = ACTIONS(6665),
    [anon_sym_integer] = ACTIONS(6665),
    [anon_sym_time] = ACTIONS(6665),
    [anon_sym_bit] = ACTIONS(6665),
    [anon_sym_logic] = ACTIONS(6665),
    [anon_sym_reg] = ACTIONS(6665),
    [anon_sym_shortreal] = ACTIONS(6665),
    [anon_sym_real] = ACTIONS(6665),
    [anon_sym_realtime] = ACTIONS(6665),
    [anon_sym_supply0] = ACTIONS(6665),
    [anon_sym_supply1] = ACTIONS(6665),
    [anon_sym_signed] = ACTIONS(6665),
    [anon_sym_unsigned] = ACTIONS(6665),
    [anon_sym_task] = ACTIONS(6665),
    [anon_sym_assert] = ACTIONS(6665),
    [anon_sym_property] = ACTIONS(6665),
    [anon_sym_assume] = ACTIONS(6665),
    [anon_sym_cover] = ACTIONS(6665),
    [anon_sym_sequence] = ACTIONS(6665),
    [anon_sym_restrict] = ACTIONS(6665),
    [anon_sym_not] = ACTIONS(6665),
    [anon_sym_or] = ACTIONS(6665),
    [anon_sym_and] = ACTIONS(6665),
    [anon_sym_case] = ACTIONS(6665),
    [anon_sym_always] = ACTIONS(6665),
    [anon_sym_covergroup] = ACTIONS(6665),
    [anon_sym_end] = ACTIONS(6665),
    [anon_sym_let] = ACTIONS(6665),
    [anon_sym_pulldown] = ACTIONS(6665),
    [anon_sym_pullup] = ACTIONS(6665),
    [anon_sym_cmos] = ACTIONS(6665),
    [anon_sym_rcmos] = ACTIONS(6665),
    [anon_sym_bufif0] = ACTIONS(6665),
    [anon_sym_bufif1] = ACTIONS(6665),
    [anon_sym_notif0] = ACTIONS(6665),
    [anon_sym_notif1] = ACTIONS(6665),
    [anon_sym_nmos] = ACTIONS(6665),
    [anon_sym_pmos] = ACTIONS(6665),
    [anon_sym_rnmos] = ACTIONS(6665),
    [anon_sym_rpmos] = ACTIONS(6665),
    [anon_sym_nand] = ACTIONS(6665),
    [anon_sym_nor] = ACTIONS(6665),
    [anon_sym_xor] = ACTIONS(6665),
    [anon_sym_xnor] = ACTIONS(6665),
    [anon_sym_buf] = ACTIONS(6665),
    [anon_sym_tranif0] = ACTIONS(6665),
    [anon_sym_tranif1] = ACTIONS(6665),
    [anon_sym_rtranif1] = ACTIONS(6665),
    [anon_sym_rtranif0] = ACTIONS(6665),
    [anon_sym_tran] = ACTIONS(6665),
    [anon_sym_rtran] = ACTIONS(6665),
    [anon_sym_generate] = ACTIONS(6665),
    [anon_sym_for] = ACTIONS(6665),
    [anon_sym_initial] = ACTIONS(6665),
    [anon_sym_assign] = ACTIONS(6665),
    [anon_sym_alias] = ACTIONS(6665),
    [anon_sym_always_comb] = ACTIONS(6665),
    [anon_sym_always_latch] = ACTIONS(6665),
    [anon_sym_always_ff] = ACTIONS(6665),
    [anon_sym_final] = ACTIONS(6665),
    [anon_sym_global] = ACTIONS(6665),
    [anon_sym_LPAREN_STAR] = ACTIONS(6667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6667),
    [anon_sym_DOLLARunit] = ACTIONS(6667),
  },
  [5036] = {
    [sym_simple_identifier] = ACTIONS(6735),
    [anon_sym_wire] = ACTIONS(6735),
    [anon_sym_tri] = ACTIONS(6735),
    [anon_sym_tri0] = ACTIONS(6735),
    [anon_sym_tri1] = ACTIONS(6735),
    [anon_sym_wand] = ACTIONS(6735),
    [anon_sym_triand] = ACTIONS(6735),
    [anon_sym_wor] = ACTIONS(6735),
    [anon_sym_trior] = ACTIONS(6735),
    [anon_sym_trireg] = ACTIONS(6735),
    [anon_sym_uwire] = ACTIONS(6735),
    [anon_sym_SEMI] = ACTIONS(6737),
    [anon_sym_extern] = ACTIONS(6735),
    [anon_sym_interface] = ACTIONS(6735),
    [anon_sym_checker] = ACTIONS(6735),
    [anon_sym_virtual] = ACTIONS(6735),
    [anon_sym_class] = ACTIONS(6735),
    [anon_sym_type] = ACTIONS(6735),
    [anon_sym_DOLLARfatal] = ACTIONS(6737),
    [anon_sym_DOLLARerror] = ACTIONS(6737),
    [anon_sym_DOLLARwarning] = ACTIONS(6737),
    [anon_sym_DOLLARinfo] = ACTIONS(6737),
    [anon_sym_default] = ACTIONS(6735),
    [anon_sym_clocking] = ACTIONS(6735),
    [anon_sym_defparam] = ACTIONS(6735),
    [anon_sym_bind] = ACTIONS(6735),
    [anon_sym_rand] = ACTIONS(6735),
    [anon_sym_const] = ACTIONS(6735),
    [anon_sym_function] = ACTIONS(6735),
    [anon_sym_static] = ACTIONS(6735),
    [anon_sym_constraint] = ACTIONS(6735),
    [anon_sym_if] = ACTIONS(6735),
    [anon_sym_else] = ACTIONS(6735),
    [anon_sym_LBRACK] = ACTIONS(6737),
    [anon_sym_localparam] = ACTIONS(6735),
    [anon_sym_parameter] = ACTIONS(6735),
    [anon_sym_var] = ACTIONS(6735),
    [anon_sym_import] = ACTIONS(6735),
    [anon_sym_export] = ACTIONS(6735),
    [anon_sym_genvar] = ACTIONS(6735),
    [anon_sym_interconnect] = ACTIONS(6735),
    [anon_sym_typedef] = ACTIONS(6735),
    [anon_sym_enum] = ACTIONS(6735),
    [anon_sym_struct] = ACTIONS(6735),
    [anon_sym_union] = ACTIONS(6735),
    [anon_sym_nettype] = ACTIONS(6735),
    [anon_sym_automatic] = ACTIONS(6735),
    [anon_sym_string] = ACTIONS(6735),
    [anon_sym_chandle] = ACTIONS(6735),
    [anon_sym_event] = ACTIONS(6735),
    [anon_sym_byte] = ACTIONS(6735),
    [anon_sym_shortint] = ACTIONS(6735),
    [anon_sym_int] = ACTIONS(6735),
    [anon_sym_longint] = ACTIONS(6735),
    [anon_sym_integer] = ACTIONS(6735),
    [anon_sym_time] = ACTIONS(6735),
    [anon_sym_bit] = ACTIONS(6735),
    [anon_sym_logic] = ACTIONS(6735),
    [anon_sym_reg] = ACTIONS(6735),
    [anon_sym_shortreal] = ACTIONS(6735),
    [anon_sym_real] = ACTIONS(6735),
    [anon_sym_realtime] = ACTIONS(6735),
    [anon_sym_supply0] = ACTIONS(6735),
    [anon_sym_supply1] = ACTIONS(6735),
    [anon_sym_signed] = ACTIONS(6735),
    [anon_sym_unsigned] = ACTIONS(6735),
    [anon_sym_task] = ACTIONS(6735),
    [anon_sym_assert] = ACTIONS(6735),
    [anon_sym_property] = ACTIONS(6735),
    [anon_sym_assume] = ACTIONS(6735),
    [anon_sym_cover] = ACTIONS(6735),
    [anon_sym_sequence] = ACTIONS(6735),
    [anon_sym_restrict] = ACTIONS(6735),
    [anon_sym_not] = ACTIONS(6735),
    [anon_sym_or] = ACTIONS(6735),
    [anon_sym_and] = ACTIONS(6735),
    [anon_sym_case] = ACTIONS(6735),
    [anon_sym_always] = ACTIONS(6735),
    [anon_sym_covergroup] = ACTIONS(6735),
    [anon_sym_end] = ACTIONS(6735),
    [anon_sym_let] = ACTIONS(6735),
    [anon_sym_pulldown] = ACTIONS(6735),
    [anon_sym_pullup] = ACTIONS(6735),
    [anon_sym_cmos] = ACTIONS(6735),
    [anon_sym_rcmos] = ACTIONS(6735),
    [anon_sym_bufif0] = ACTIONS(6735),
    [anon_sym_bufif1] = ACTIONS(6735),
    [anon_sym_notif0] = ACTIONS(6735),
    [anon_sym_notif1] = ACTIONS(6735),
    [anon_sym_nmos] = ACTIONS(6735),
    [anon_sym_pmos] = ACTIONS(6735),
    [anon_sym_rnmos] = ACTIONS(6735),
    [anon_sym_rpmos] = ACTIONS(6735),
    [anon_sym_nand] = ACTIONS(6735),
    [anon_sym_nor] = ACTIONS(6735),
    [anon_sym_xor] = ACTIONS(6735),
    [anon_sym_xnor] = ACTIONS(6735),
    [anon_sym_buf] = ACTIONS(6735),
    [anon_sym_tranif0] = ACTIONS(6735),
    [anon_sym_tranif1] = ACTIONS(6735),
    [anon_sym_rtranif1] = ACTIONS(6735),
    [anon_sym_rtranif0] = ACTIONS(6735),
    [anon_sym_tran] = ACTIONS(6735),
    [anon_sym_rtran] = ACTIONS(6735),
    [anon_sym_generate] = ACTIONS(6735),
    [anon_sym_for] = ACTIONS(6735),
    [anon_sym_initial] = ACTIONS(6735),
    [anon_sym_assign] = ACTIONS(6735),
    [anon_sym_alias] = ACTIONS(6735),
    [anon_sym_always_comb] = ACTIONS(6735),
    [anon_sym_always_latch] = ACTIONS(6735),
    [anon_sym_always_ff] = ACTIONS(6735),
    [anon_sym_final] = ACTIONS(6735),
    [anon_sym_global] = ACTIONS(6735),
    [anon_sym_LPAREN_STAR] = ACTIONS(6737),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6737),
    [anon_sym_DOLLARunit] = ACTIONS(6737),
  },
  [5037] = {
    [sym_simple_identifier] = ACTIONS(4892),
    [anon_sym_wire] = ACTIONS(4892),
    [anon_sym_tri] = ACTIONS(4892),
    [anon_sym_tri0] = ACTIONS(4892),
    [anon_sym_tri1] = ACTIONS(4892),
    [anon_sym_wand] = ACTIONS(4892),
    [anon_sym_triand] = ACTIONS(4892),
    [anon_sym_wor] = ACTIONS(4892),
    [anon_sym_trior] = ACTIONS(4892),
    [anon_sym_trireg] = ACTIONS(4892),
    [anon_sym_uwire] = ACTIONS(4892),
    [anon_sym_SEMI] = ACTIONS(4890),
    [anon_sym_extern] = ACTIONS(4892),
    [anon_sym_interface] = ACTIONS(4892),
    [anon_sym_checker] = ACTIONS(4892),
    [anon_sym_virtual] = ACTIONS(4892),
    [anon_sym_class] = ACTIONS(4892),
    [anon_sym_type] = ACTIONS(4892),
    [anon_sym_DOLLARfatal] = ACTIONS(4890),
    [anon_sym_DOLLARerror] = ACTIONS(4890),
    [anon_sym_DOLLARwarning] = ACTIONS(4890),
    [anon_sym_DOLLARinfo] = ACTIONS(4890),
    [anon_sym_default] = ACTIONS(4892),
    [anon_sym_clocking] = ACTIONS(4892),
    [anon_sym_defparam] = ACTIONS(4892),
    [anon_sym_bind] = ACTIONS(4892),
    [anon_sym_rand] = ACTIONS(4892),
    [anon_sym_const] = ACTIONS(4892),
    [anon_sym_function] = ACTIONS(4892),
    [anon_sym_static] = ACTIONS(4892),
    [anon_sym_constraint] = ACTIONS(4892),
    [anon_sym_if] = ACTIONS(4892),
    [anon_sym_else] = ACTIONS(4892),
    [anon_sym_LBRACK] = ACTIONS(4890),
    [anon_sym_localparam] = ACTIONS(4892),
    [anon_sym_parameter] = ACTIONS(4892),
    [anon_sym_var] = ACTIONS(4892),
    [anon_sym_import] = ACTIONS(4892),
    [anon_sym_export] = ACTIONS(4892),
    [anon_sym_genvar] = ACTIONS(4892),
    [anon_sym_interconnect] = ACTIONS(4892),
    [anon_sym_typedef] = ACTIONS(4892),
    [anon_sym_enum] = ACTIONS(4892),
    [anon_sym_struct] = ACTIONS(4892),
    [anon_sym_union] = ACTIONS(4892),
    [anon_sym_nettype] = ACTIONS(4892),
    [anon_sym_automatic] = ACTIONS(4892),
    [anon_sym_string] = ACTIONS(4892),
    [anon_sym_chandle] = ACTIONS(4892),
    [anon_sym_event] = ACTIONS(4892),
    [anon_sym_byte] = ACTIONS(4892),
    [anon_sym_shortint] = ACTIONS(4892),
    [anon_sym_int] = ACTIONS(4892),
    [anon_sym_longint] = ACTIONS(4892),
    [anon_sym_integer] = ACTIONS(4892),
    [anon_sym_time] = ACTIONS(4892),
    [anon_sym_bit] = ACTIONS(4892),
    [anon_sym_logic] = ACTIONS(4892),
    [anon_sym_reg] = ACTIONS(4892),
    [anon_sym_shortreal] = ACTIONS(4892),
    [anon_sym_real] = ACTIONS(4892),
    [anon_sym_realtime] = ACTIONS(4892),
    [anon_sym_supply0] = ACTIONS(4892),
    [anon_sym_supply1] = ACTIONS(4892),
    [anon_sym_signed] = ACTIONS(4892),
    [anon_sym_unsigned] = ACTIONS(4892),
    [anon_sym_task] = ACTIONS(4892),
    [anon_sym_assert] = ACTIONS(4892),
    [anon_sym_property] = ACTIONS(4892),
    [anon_sym_assume] = ACTIONS(4892),
    [anon_sym_cover] = ACTIONS(4892),
    [anon_sym_sequence] = ACTIONS(4892),
    [anon_sym_restrict] = ACTIONS(4892),
    [anon_sym_not] = ACTIONS(4892),
    [anon_sym_or] = ACTIONS(4892),
    [anon_sym_and] = ACTIONS(4892),
    [anon_sym_case] = ACTIONS(4892),
    [anon_sym_always] = ACTIONS(4892),
    [anon_sym_covergroup] = ACTIONS(4892),
    [anon_sym_let] = ACTIONS(4892),
    [anon_sym_pulldown] = ACTIONS(4892),
    [anon_sym_pullup] = ACTIONS(4892),
    [anon_sym_cmos] = ACTIONS(4892),
    [anon_sym_rcmos] = ACTIONS(4892),
    [anon_sym_bufif0] = ACTIONS(4892),
    [anon_sym_bufif1] = ACTIONS(4892),
    [anon_sym_notif0] = ACTIONS(4892),
    [anon_sym_notif1] = ACTIONS(4892),
    [anon_sym_nmos] = ACTIONS(4892),
    [anon_sym_pmos] = ACTIONS(4892),
    [anon_sym_rnmos] = ACTIONS(4892),
    [anon_sym_rpmos] = ACTIONS(4892),
    [anon_sym_nand] = ACTIONS(4892),
    [anon_sym_nor] = ACTIONS(4892),
    [anon_sym_xor] = ACTIONS(4892),
    [anon_sym_xnor] = ACTIONS(4892),
    [anon_sym_buf] = ACTIONS(4892),
    [anon_sym_tranif0] = ACTIONS(4892),
    [anon_sym_tranif1] = ACTIONS(4892),
    [anon_sym_rtranif1] = ACTIONS(4892),
    [anon_sym_rtranif0] = ACTIONS(4892),
    [anon_sym_tran] = ACTIONS(4892),
    [anon_sym_rtran] = ACTIONS(4892),
    [anon_sym_generate] = ACTIONS(4892),
    [anon_sym_endgenerate] = ACTIONS(4892),
    [anon_sym_for] = ACTIONS(4892),
    [anon_sym_initial] = ACTIONS(4892),
    [anon_sym_assign] = ACTIONS(4892),
    [anon_sym_alias] = ACTIONS(4892),
    [anon_sym_always_comb] = ACTIONS(4892),
    [anon_sym_always_latch] = ACTIONS(4892),
    [anon_sym_always_ff] = ACTIONS(4892),
    [anon_sym_final] = ACTIONS(4892),
    [anon_sym_global] = ACTIONS(4892),
    [anon_sym_LPAREN_STAR] = ACTIONS(4890),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4890),
    [anon_sym_DOLLARunit] = ACTIONS(4890),
  },
  [5038] = {
    [sym_simple_identifier] = ACTIONS(4896),
    [anon_sym_wire] = ACTIONS(4896),
    [anon_sym_tri] = ACTIONS(4896),
    [anon_sym_tri0] = ACTIONS(4896),
    [anon_sym_tri1] = ACTIONS(4896),
    [anon_sym_wand] = ACTIONS(4896),
    [anon_sym_triand] = ACTIONS(4896),
    [anon_sym_wor] = ACTIONS(4896),
    [anon_sym_trior] = ACTIONS(4896),
    [anon_sym_trireg] = ACTIONS(4896),
    [anon_sym_uwire] = ACTIONS(4896),
    [anon_sym_SEMI] = ACTIONS(4894),
    [anon_sym_extern] = ACTIONS(4896),
    [anon_sym_interface] = ACTIONS(4896),
    [anon_sym_checker] = ACTIONS(4896),
    [anon_sym_virtual] = ACTIONS(4896),
    [anon_sym_class] = ACTIONS(4896),
    [anon_sym_type] = ACTIONS(4896),
    [anon_sym_DOLLARfatal] = ACTIONS(4894),
    [anon_sym_DOLLARerror] = ACTIONS(4894),
    [anon_sym_DOLLARwarning] = ACTIONS(4894),
    [anon_sym_DOLLARinfo] = ACTIONS(4894),
    [anon_sym_default] = ACTIONS(4896),
    [anon_sym_clocking] = ACTIONS(4896),
    [anon_sym_defparam] = ACTIONS(4896),
    [anon_sym_bind] = ACTIONS(4896),
    [anon_sym_rand] = ACTIONS(4896),
    [anon_sym_const] = ACTIONS(4896),
    [anon_sym_function] = ACTIONS(4896),
    [anon_sym_static] = ACTIONS(4896),
    [anon_sym_constraint] = ACTIONS(4896),
    [anon_sym_if] = ACTIONS(4896),
    [anon_sym_else] = ACTIONS(4896),
    [anon_sym_LBRACK] = ACTIONS(4894),
    [anon_sym_localparam] = ACTIONS(4896),
    [anon_sym_parameter] = ACTIONS(4896),
    [anon_sym_var] = ACTIONS(4896),
    [anon_sym_import] = ACTIONS(4896),
    [anon_sym_export] = ACTIONS(4896),
    [anon_sym_genvar] = ACTIONS(4896),
    [anon_sym_interconnect] = ACTIONS(4896),
    [anon_sym_typedef] = ACTIONS(4896),
    [anon_sym_enum] = ACTIONS(4896),
    [anon_sym_struct] = ACTIONS(4896),
    [anon_sym_union] = ACTIONS(4896),
    [anon_sym_nettype] = ACTIONS(4896),
    [anon_sym_automatic] = ACTIONS(4896),
    [anon_sym_string] = ACTIONS(4896),
    [anon_sym_chandle] = ACTIONS(4896),
    [anon_sym_event] = ACTIONS(4896),
    [anon_sym_byte] = ACTIONS(4896),
    [anon_sym_shortint] = ACTIONS(4896),
    [anon_sym_int] = ACTIONS(4896),
    [anon_sym_longint] = ACTIONS(4896),
    [anon_sym_integer] = ACTIONS(4896),
    [anon_sym_time] = ACTIONS(4896),
    [anon_sym_bit] = ACTIONS(4896),
    [anon_sym_logic] = ACTIONS(4896),
    [anon_sym_reg] = ACTIONS(4896),
    [anon_sym_shortreal] = ACTIONS(4896),
    [anon_sym_real] = ACTIONS(4896),
    [anon_sym_realtime] = ACTIONS(4896),
    [anon_sym_supply0] = ACTIONS(4896),
    [anon_sym_supply1] = ACTIONS(4896),
    [anon_sym_signed] = ACTIONS(4896),
    [anon_sym_unsigned] = ACTIONS(4896),
    [anon_sym_task] = ACTIONS(4896),
    [anon_sym_assert] = ACTIONS(4896),
    [anon_sym_property] = ACTIONS(4896),
    [anon_sym_assume] = ACTIONS(4896),
    [anon_sym_cover] = ACTIONS(4896),
    [anon_sym_sequence] = ACTIONS(4896),
    [anon_sym_restrict] = ACTIONS(4896),
    [anon_sym_not] = ACTIONS(4896),
    [anon_sym_or] = ACTIONS(4896),
    [anon_sym_and] = ACTIONS(4896),
    [anon_sym_case] = ACTIONS(4896),
    [anon_sym_always] = ACTIONS(4896),
    [anon_sym_covergroup] = ACTIONS(4896),
    [anon_sym_let] = ACTIONS(4896),
    [anon_sym_pulldown] = ACTIONS(4896),
    [anon_sym_pullup] = ACTIONS(4896),
    [anon_sym_cmos] = ACTIONS(4896),
    [anon_sym_rcmos] = ACTIONS(4896),
    [anon_sym_bufif0] = ACTIONS(4896),
    [anon_sym_bufif1] = ACTIONS(4896),
    [anon_sym_notif0] = ACTIONS(4896),
    [anon_sym_notif1] = ACTIONS(4896),
    [anon_sym_nmos] = ACTIONS(4896),
    [anon_sym_pmos] = ACTIONS(4896),
    [anon_sym_rnmos] = ACTIONS(4896),
    [anon_sym_rpmos] = ACTIONS(4896),
    [anon_sym_nand] = ACTIONS(4896),
    [anon_sym_nor] = ACTIONS(4896),
    [anon_sym_xor] = ACTIONS(4896),
    [anon_sym_xnor] = ACTIONS(4896),
    [anon_sym_buf] = ACTIONS(4896),
    [anon_sym_tranif0] = ACTIONS(4896),
    [anon_sym_tranif1] = ACTIONS(4896),
    [anon_sym_rtranif1] = ACTIONS(4896),
    [anon_sym_rtranif0] = ACTIONS(4896),
    [anon_sym_tran] = ACTIONS(4896),
    [anon_sym_rtran] = ACTIONS(4896),
    [anon_sym_generate] = ACTIONS(4896),
    [anon_sym_endgenerate] = ACTIONS(4896),
    [anon_sym_for] = ACTIONS(4896),
    [anon_sym_initial] = ACTIONS(4896),
    [anon_sym_assign] = ACTIONS(4896),
    [anon_sym_alias] = ACTIONS(4896),
    [anon_sym_always_comb] = ACTIONS(4896),
    [anon_sym_always_latch] = ACTIONS(4896),
    [anon_sym_always_ff] = ACTIONS(4896),
    [anon_sym_final] = ACTIONS(4896),
    [anon_sym_global] = ACTIONS(4896),
    [anon_sym_LPAREN_STAR] = ACTIONS(4894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4894),
    [anon_sym_DOLLARunit] = ACTIONS(4894),
  },
  [5039] = {
    [sym_simple_identifier] = ACTIONS(6449),
    [anon_sym_wire] = ACTIONS(6449),
    [anon_sym_tri] = ACTIONS(6449),
    [anon_sym_tri0] = ACTIONS(6449),
    [anon_sym_tri1] = ACTIONS(6449),
    [anon_sym_wand] = ACTIONS(6449),
    [anon_sym_triand] = ACTIONS(6449),
    [anon_sym_wor] = ACTIONS(6449),
    [anon_sym_trior] = ACTIONS(6449),
    [anon_sym_trireg] = ACTIONS(6449),
    [anon_sym_uwire] = ACTIONS(6449),
    [anon_sym_SEMI] = ACTIONS(6451),
    [anon_sym_extern] = ACTIONS(6449),
    [anon_sym_interface] = ACTIONS(6449),
    [anon_sym_checker] = ACTIONS(6449),
    [anon_sym_virtual] = ACTIONS(6449),
    [anon_sym_class] = ACTIONS(6449),
    [anon_sym_type] = ACTIONS(6449),
    [anon_sym_DOLLARfatal] = ACTIONS(6451),
    [anon_sym_DOLLARerror] = ACTIONS(6451),
    [anon_sym_DOLLARwarning] = ACTIONS(6451),
    [anon_sym_DOLLARinfo] = ACTIONS(6451),
    [anon_sym_default] = ACTIONS(6449),
    [anon_sym_clocking] = ACTIONS(6449),
    [anon_sym_defparam] = ACTIONS(6449),
    [anon_sym_bind] = ACTIONS(6449),
    [anon_sym_rand] = ACTIONS(6449),
    [anon_sym_const] = ACTIONS(6449),
    [anon_sym_function] = ACTIONS(6449),
    [anon_sym_static] = ACTIONS(6449),
    [anon_sym_constraint] = ACTIONS(6449),
    [anon_sym_if] = ACTIONS(6449),
    [anon_sym_else] = ACTIONS(6449),
    [anon_sym_LBRACK] = ACTIONS(6451),
    [anon_sym_localparam] = ACTIONS(6449),
    [anon_sym_parameter] = ACTIONS(6449),
    [anon_sym_var] = ACTIONS(6449),
    [anon_sym_import] = ACTIONS(6449),
    [anon_sym_export] = ACTIONS(6449),
    [anon_sym_genvar] = ACTIONS(6449),
    [anon_sym_interconnect] = ACTIONS(6449),
    [anon_sym_typedef] = ACTIONS(6449),
    [anon_sym_enum] = ACTIONS(6449),
    [anon_sym_struct] = ACTIONS(6449),
    [anon_sym_union] = ACTIONS(6449),
    [anon_sym_nettype] = ACTIONS(6449),
    [anon_sym_automatic] = ACTIONS(6449),
    [anon_sym_string] = ACTIONS(6449),
    [anon_sym_chandle] = ACTIONS(6449),
    [anon_sym_event] = ACTIONS(6449),
    [anon_sym_byte] = ACTIONS(6449),
    [anon_sym_shortint] = ACTIONS(6449),
    [anon_sym_int] = ACTIONS(6449),
    [anon_sym_longint] = ACTIONS(6449),
    [anon_sym_integer] = ACTIONS(6449),
    [anon_sym_time] = ACTIONS(6449),
    [anon_sym_bit] = ACTIONS(6449),
    [anon_sym_logic] = ACTIONS(6449),
    [anon_sym_reg] = ACTIONS(6449),
    [anon_sym_shortreal] = ACTIONS(6449),
    [anon_sym_real] = ACTIONS(6449),
    [anon_sym_realtime] = ACTIONS(6449),
    [anon_sym_supply0] = ACTIONS(6449),
    [anon_sym_supply1] = ACTIONS(6449),
    [anon_sym_signed] = ACTIONS(6449),
    [anon_sym_unsigned] = ACTIONS(6449),
    [anon_sym_task] = ACTIONS(6449),
    [anon_sym_assert] = ACTIONS(6449),
    [anon_sym_property] = ACTIONS(6449),
    [anon_sym_assume] = ACTIONS(6449),
    [anon_sym_cover] = ACTIONS(6449),
    [anon_sym_sequence] = ACTIONS(6449),
    [anon_sym_restrict] = ACTIONS(6449),
    [anon_sym_not] = ACTIONS(6449),
    [anon_sym_or] = ACTIONS(6449),
    [anon_sym_and] = ACTIONS(6449),
    [anon_sym_case] = ACTIONS(6449),
    [anon_sym_always] = ACTIONS(6449),
    [anon_sym_covergroup] = ACTIONS(6449),
    [anon_sym_let] = ACTIONS(6449),
    [anon_sym_pulldown] = ACTIONS(6449),
    [anon_sym_pullup] = ACTIONS(6449),
    [anon_sym_cmos] = ACTIONS(6449),
    [anon_sym_rcmos] = ACTIONS(6449),
    [anon_sym_bufif0] = ACTIONS(6449),
    [anon_sym_bufif1] = ACTIONS(6449),
    [anon_sym_notif0] = ACTIONS(6449),
    [anon_sym_notif1] = ACTIONS(6449),
    [anon_sym_nmos] = ACTIONS(6449),
    [anon_sym_pmos] = ACTIONS(6449),
    [anon_sym_rnmos] = ACTIONS(6449),
    [anon_sym_rpmos] = ACTIONS(6449),
    [anon_sym_nand] = ACTIONS(6449),
    [anon_sym_nor] = ACTIONS(6449),
    [anon_sym_xor] = ACTIONS(6449),
    [anon_sym_xnor] = ACTIONS(6449),
    [anon_sym_buf] = ACTIONS(6449),
    [anon_sym_tranif0] = ACTIONS(6449),
    [anon_sym_tranif1] = ACTIONS(6449),
    [anon_sym_rtranif1] = ACTIONS(6449),
    [anon_sym_rtranif0] = ACTIONS(6449),
    [anon_sym_tran] = ACTIONS(6449),
    [anon_sym_rtran] = ACTIONS(6449),
    [anon_sym_generate] = ACTIONS(6449),
    [anon_sym_endgenerate] = ACTIONS(6449),
    [anon_sym_for] = ACTIONS(6449),
    [anon_sym_initial] = ACTIONS(6449),
    [anon_sym_assign] = ACTIONS(6449),
    [anon_sym_alias] = ACTIONS(6449),
    [anon_sym_always_comb] = ACTIONS(6449),
    [anon_sym_always_latch] = ACTIONS(6449),
    [anon_sym_always_ff] = ACTIONS(6449),
    [anon_sym_final] = ACTIONS(6449),
    [anon_sym_global] = ACTIONS(6449),
    [anon_sym_LPAREN_STAR] = ACTIONS(6451),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6451),
    [anon_sym_DOLLARunit] = ACTIONS(6451),
  },
  [5040] = {
    [sym_simple_identifier] = ACTIONS(6747),
    [anon_sym_wire] = ACTIONS(6747),
    [anon_sym_tri] = ACTIONS(6747),
    [anon_sym_tri0] = ACTIONS(6747),
    [anon_sym_tri1] = ACTIONS(6747),
    [anon_sym_wand] = ACTIONS(6747),
    [anon_sym_triand] = ACTIONS(6747),
    [anon_sym_wor] = ACTIONS(6747),
    [anon_sym_trior] = ACTIONS(6747),
    [anon_sym_trireg] = ACTIONS(6747),
    [anon_sym_uwire] = ACTIONS(6747),
    [anon_sym_SEMI] = ACTIONS(6749),
    [anon_sym_extern] = ACTIONS(6747),
    [anon_sym_interface] = ACTIONS(6747),
    [anon_sym_checker] = ACTIONS(6747),
    [anon_sym_virtual] = ACTIONS(6747),
    [anon_sym_class] = ACTIONS(6747),
    [anon_sym_type] = ACTIONS(6747),
    [anon_sym_DOLLARfatal] = ACTIONS(6749),
    [anon_sym_DOLLARerror] = ACTIONS(6749),
    [anon_sym_DOLLARwarning] = ACTIONS(6749),
    [anon_sym_DOLLARinfo] = ACTIONS(6749),
    [anon_sym_default] = ACTIONS(6747),
    [anon_sym_clocking] = ACTIONS(6747),
    [anon_sym_defparam] = ACTIONS(6747),
    [anon_sym_bind] = ACTIONS(6747),
    [anon_sym_rand] = ACTIONS(6747),
    [anon_sym_const] = ACTIONS(6747),
    [anon_sym_function] = ACTIONS(6747),
    [anon_sym_static] = ACTIONS(6747),
    [anon_sym_constraint] = ACTIONS(6747),
    [anon_sym_if] = ACTIONS(6747),
    [anon_sym_else] = ACTIONS(6747),
    [anon_sym_LBRACK] = ACTIONS(6749),
    [anon_sym_localparam] = ACTIONS(6747),
    [anon_sym_parameter] = ACTIONS(6747),
    [anon_sym_var] = ACTIONS(6747),
    [anon_sym_import] = ACTIONS(6747),
    [anon_sym_export] = ACTIONS(6747),
    [anon_sym_genvar] = ACTIONS(6747),
    [anon_sym_interconnect] = ACTIONS(6747),
    [anon_sym_typedef] = ACTIONS(6747),
    [anon_sym_enum] = ACTIONS(6747),
    [anon_sym_struct] = ACTIONS(6747),
    [anon_sym_union] = ACTIONS(6747),
    [anon_sym_nettype] = ACTIONS(6747),
    [anon_sym_automatic] = ACTIONS(6747),
    [anon_sym_string] = ACTIONS(6747),
    [anon_sym_chandle] = ACTIONS(6747),
    [anon_sym_event] = ACTIONS(6747),
    [anon_sym_byte] = ACTIONS(6747),
    [anon_sym_shortint] = ACTIONS(6747),
    [anon_sym_int] = ACTIONS(6747),
    [anon_sym_longint] = ACTIONS(6747),
    [anon_sym_integer] = ACTIONS(6747),
    [anon_sym_time] = ACTIONS(6747),
    [anon_sym_bit] = ACTIONS(6747),
    [anon_sym_logic] = ACTIONS(6747),
    [anon_sym_reg] = ACTIONS(6747),
    [anon_sym_shortreal] = ACTIONS(6747),
    [anon_sym_real] = ACTIONS(6747),
    [anon_sym_realtime] = ACTIONS(6747),
    [anon_sym_supply0] = ACTIONS(6747),
    [anon_sym_supply1] = ACTIONS(6747),
    [anon_sym_signed] = ACTIONS(6747),
    [anon_sym_unsigned] = ACTIONS(6747),
    [anon_sym_task] = ACTIONS(6747),
    [anon_sym_assert] = ACTIONS(6747),
    [anon_sym_property] = ACTIONS(6747),
    [anon_sym_assume] = ACTIONS(6747),
    [anon_sym_cover] = ACTIONS(6747),
    [anon_sym_sequence] = ACTIONS(6747),
    [anon_sym_restrict] = ACTIONS(6747),
    [anon_sym_not] = ACTIONS(6747),
    [anon_sym_or] = ACTIONS(6747),
    [anon_sym_and] = ACTIONS(6747),
    [anon_sym_case] = ACTIONS(6747),
    [anon_sym_always] = ACTIONS(6747),
    [anon_sym_covergroup] = ACTIONS(6747),
    [anon_sym_end] = ACTIONS(6747),
    [anon_sym_let] = ACTIONS(6747),
    [anon_sym_pulldown] = ACTIONS(6747),
    [anon_sym_pullup] = ACTIONS(6747),
    [anon_sym_cmos] = ACTIONS(6747),
    [anon_sym_rcmos] = ACTIONS(6747),
    [anon_sym_bufif0] = ACTIONS(6747),
    [anon_sym_bufif1] = ACTIONS(6747),
    [anon_sym_notif0] = ACTIONS(6747),
    [anon_sym_notif1] = ACTIONS(6747),
    [anon_sym_nmos] = ACTIONS(6747),
    [anon_sym_pmos] = ACTIONS(6747),
    [anon_sym_rnmos] = ACTIONS(6747),
    [anon_sym_rpmos] = ACTIONS(6747),
    [anon_sym_nand] = ACTIONS(6747),
    [anon_sym_nor] = ACTIONS(6747),
    [anon_sym_xor] = ACTIONS(6747),
    [anon_sym_xnor] = ACTIONS(6747),
    [anon_sym_buf] = ACTIONS(6747),
    [anon_sym_tranif0] = ACTIONS(6747),
    [anon_sym_tranif1] = ACTIONS(6747),
    [anon_sym_rtranif1] = ACTIONS(6747),
    [anon_sym_rtranif0] = ACTIONS(6747),
    [anon_sym_tran] = ACTIONS(6747),
    [anon_sym_rtran] = ACTIONS(6747),
    [anon_sym_generate] = ACTIONS(6747),
    [anon_sym_for] = ACTIONS(6747),
    [anon_sym_initial] = ACTIONS(6747),
    [anon_sym_assign] = ACTIONS(6747),
    [anon_sym_alias] = ACTIONS(6747),
    [anon_sym_always_comb] = ACTIONS(6747),
    [anon_sym_always_latch] = ACTIONS(6747),
    [anon_sym_always_ff] = ACTIONS(6747),
    [anon_sym_final] = ACTIONS(6747),
    [anon_sym_global] = ACTIONS(6747),
    [anon_sym_LPAREN_STAR] = ACTIONS(6749),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6749),
    [anon_sym_DOLLARunit] = ACTIONS(6749),
  },
  [5041] = {
    [sym_simple_identifier] = ACTIONS(6479),
    [anon_sym_wire] = ACTIONS(6479),
    [anon_sym_tri] = ACTIONS(6479),
    [anon_sym_tri0] = ACTIONS(6479),
    [anon_sym_tri1] = ACTIONS(6479),
    [anon_sym_wand] = ACTIONS(6479),
    [anon_sym_triand] = ACTIONS(6479),
    [anon_sym_wor] = ACTIONS(6479),
    [anon_sym_trior] = ACTIONS(6479),
    [anon_sym_trireg] = ACTIONS(6479),
    [anon_sym_uwire] = ACTIONS(6479),
    [anon_sym_SEMI] = ACTIONS(6481),
    [anon_sym_extern] = ACTIONS(6479),
    [anon_sym_interface] = ACTIONS(6479),
    [anon_sym_checker] = ACTIONS(6479),
    [anon_sym_virtual] = ACTIONS(6479),
    [anon_sym_class] = ACTIONS(6479),
    [anon_sym_type] = ACTIONS(6479),
    [anon_sym_DOLLARfatal] = ACTIONS(6481),
    [anon_sym_DOLLARerror] = ACTIONS(6481),
    [anon_sym_DOLLARwarning] = ACTIONS(6481),
    [anon_sym_DOLLARinfo] = ACTIONS(6481),
    [anon_sym_default] = ACTIONS(6479),
    [anon_sym_clocking] = ACTIONS(6479),
    [anon_sym_defparam] = ACTIONS(6479),
    [anon_sym_bind] = ACTIONS(6479),
    [anon_sym_rand] = ACTIONS(6479),
    [anon_sym_const] = ACTIONS(6479),
    [anon_sym_function] = ACTIONS(6479),
    [anon_sym_static] = ACTIONS(6479),
    [anon_sym_constraint] = ACTIONS(6479),
    [anon_sym_if] = ACTIONS(6479),
    [anon_sym_else] = ACTIONS(6479),
    [anon_sym_LBRACK] = ACTIONS(6481),
    [anon_sym_localparam] = ACTIONS(6479),
    [anon_sym_parameter] = ACTIONS(6479),
    [anon_sym_var] = ACTIONS(6479),
    [anon_sym_import] = ACTIONS(6479),
    [anon_sym_export] = ACTIONS(6479),
    [anon_sym_genvar] = ACTIONS(6479),
    [anon_sym_interconnect] = ACTIONS(6479),
    [anon_sym_typedef] = ACTIONS(6479),
    [anon_sym_enum] = ACTIONS(6479),
    [anon_sym_struct] = ACTIONS(6479),
    [anon_sym_union] = ACTIONS(6479),
    [anon_sym_nettype] = ACTIONS(6479),
    [anon_sym_automatic] = ACTIONS(6479),
    [anon_sym_string] = ACTIONS(6479),
    [anon_sym_chandle] = ACTIONS(6479),
    [anon_sym_event] = ACTIONS(6479),
    [anon_sym_byte] = ACTIONS(6479),
    [anon_sym_shortint] = ACTIONS(6479),
    [anon_sym_int] = ACTIONS(6479),
    [anon_sym_longint] = ACTIONS(6479),
    [anon_sym_integer] = ACTIONS(6479),
    [anon_sym_time] = ACTIONS(6479),
    [anon_sym_bit] = ACTIONS(6479),
    [anon_sym_logic] = ACTIONS(6479),
    [anon_sym_reg] = ACTIONS(6479),
    [anon_sym_shortreal] = ACTIONS(6479),
    [anon_sym_real] = ACTIONS(6479),
    [anon_sym_realtime] = ACTIONS(6479),
    [anon_sym_supply0] = ACTIONS(6479),
    [anon_sym_supply1] = ACTIONS(6479),
    [anon_sym_signed] = ACTIONS(6479),
    [anon_sym_unsigned] = ACTIONS(6479),
    [anon_sym_task] = ACTIONS(6479),
    [anon_sym_assert] = ACTIONS(6479),
    [anon_sym_property] = ACTIONS(6479),
    [anon_sym_assume] = ACTIONS(6479),
    [anon_sym_cover] = ACTIONS(6479),
    [anon_sym_sequence] = ACTIONS(6479),
    [anon_sym_restrict] = ACTIONS(6479),
    [anon_sym_not] = ACTIONS(6479),
    [anon_sym_or] = ACTIONS(6479),
    [anon_sym_and] = ACTIONS(6479),
    [anon_sym_case] = ACTIONS(6479),
    [anon_sym_always] = ACTIONS(6479),
    [anon_sym_covergroup] = ACTIONS(6479),
    [anon_sym_let] = ACTIONS(6479),
    [anon_sym_pulldown] = ACTIONS(6479),
    [anon_sym_pullup] = ACTIONS(6479),
    [anon_sym_cmos] = ACTIONS(6479),
    [anon_sym_rcmos] = ACTIONS(6479),
    [anon_sym_bufif0] = ACTIONS(6479),
    [anon_sym_bufif1] = ACTIONS(6479),
    [anon_sym_notif0] = ACTIONS(6479),
    [anon_sym_notif1] = ACTIONS(6479),
    [anon_sym_nmos] = ACTIONS(6479),
    [anon_sym_pmos] = ACTIONS(6479),
    [anon_sym_rnmos] = ACTIONS(6479),
    [anon_sym_rpmos] = ACTIONS(6479),
    [anon_sym_nand] = ACTIONS(6479),
    [anon_sym_nor] = ACTIONS(6479),
    [anon_sym_xor] = ACTIONS(6479),
    [anon_sym_xnor] = ACTIONS(6479),
    [anon_sym_buf] = ACTIONS(6479),
    [anon_sym_tranif0] = ACTIONS(6479),
    [anon_sym_tranif1] = ACTIONS(6479),
    [anon_sym_rtranif1] = ACTIONS(6479),
    [anon_sym_rtranif0] = ACTIONS(6479),
    [anon_sym_tran] = ACTIONS(6479),
    [anon_sym_rtran] = ACTIONS(6479),
    [anon_sym_generate] = ACTIONS(6479),
    [anon_sym_endgenerate] = ACTIONS(6479),
    [anon_sym_for] = ACTIONS(6479),
    [anon_sym_initial] = ACTIONS(6479),
    [anon_sym_assign] = ACTIONS(6479),
    [anon_sym_alias] = ACTIONS(6479),
    [anon_sym_always_comb] = ACTIONS(6479),
    [anon_sym_always_latch] = ACTIONS(6479),
    [anon_sym_always_ff] = ACTIONS(6479),
    [anon_sym_final] = ACTIONS(6479),
    [anon_sym_global] = ACTIONS(6479),
    [anon_sym_LPAREN_STAR] = ACTIONS(6481),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6481),
    [anon_sym_DOLLARunit] = ACTIONS(6481),
  },
  [5042] = {
    [sym_simple_identifier] = ACTIONS(6593),
    [anon_sym_wire] = ACTIONS(6593),
    [anon_sym_tri] = ACTIONS(6593),
    [anon_sym_tri0] = ACTIONS(6593),
    [anon_sym_tri1] = ACTIONS(6593),
    [anon_sym_wand] = ACTIONS(6593),
    [anon_sym_triand] = ACTIONS(6593),
    [anon_sym_wor] = ACTIONS(6593),
    [anon_sym_trior] = ACTIONS(6593),
    [anon_sym_trireg] = ACTIONS(6593),
    [anon_sym_uwire] = ACTIONS(6593),
    [anon_sym_SEMI] = ACTIONS(6595),
    [anon_sym_extern] = ACTIONS(6593),
    [anon_sym_interface] = ACTIONS(6593),
    [anon_sym_checker] = ACTIONS(6593),
    [anon_sym_virtual] = ACTIONS(6593),
    [anon_sym_class] = ACTIONS(6593),
    [anon_sym_type] = ACTIONS(6593),
    [anon_sym_DOLLARfatal] = ACTIONS(6595),
    [anon_sym_DOLLARerror] = ACTIONS(6595),
    [anon_sym_DOLLARwarning] = ACTIONS(6595),
    [anon_sym_DOLLARinfo] = ACTIONS(6595),
    [anon_sym_default] = ACTIONS(6593),
    [anon_sym_clocking] = ACTIONS(6593),
    [anon_sym_defparam] = ACTIONS(6593),
    [anon_sym_bind] = ACTIONS(6593),
    [anon_sym_rand] = ACTIONS(6593),
    [anon_sym_const] = ACTIONS(6593),
    [anon_sym_function] = ACTIONS(6593),
    [anon_sym_static] = ACTIONS(6593),
    [anon_sym_constraint] = ACTIONS(6593),
    [anon_sym_if] = ACTIONS(6593),
    [anon_sym_else] = ACTIONS(6593),
    [anon_sym_LBRACK] = ACTIONS(6595),
    [anon_sym_localparam] = ACTIONS(6593),
    [anon_sym_parameter] = ACTIONS(6593),
    [anon_sym_var] = ACTIONS(6593),
    [anon_sym_import] = ACTIONS(6593),
    [anon_sym_export] = ACTIONS(6593),
    [anon_sym_genvar] = ACTIONS(6593),
    [anon_sym_interconnect] = ACTIONS(6593),
    [anon_sym_typedef] = ACTIONS(6593),
    [anon_sym_enum] = ACTIONS(6593),
    [anon_sym_struct] = ACTIONS(6593),
    [anon_sym_union] = ACTIONS(6593),
    [anon_sym_nettype] = ACTIONS(6593),
    [anon_sym_automatic] = ACTIONS(6593),
    [anon_sym_string] = ACTIONS(6593),
    [anon_sym_chandle] = ACTIONS(6593),
    [anon_sym_event] = ACTIONS(6593),
    [anon_sym_byte] = ACTIONS(6593),
    [anon_sym_shortint] = ACTIONS(6593),
    [anon_sym_int] = ACTIONS(6593),
    [anon_sym_longint] = ACTIONS(6593),
    [anon_sym_integer] = ACTIONS(6593),
    [anon_sym_time] = ACTIONS(6593),
    [anon_sym_bit] = ACTIONS(6593),
    [anon_sym_logic] = ACTIONS(6593),
    [anon_sym_reg] = ACTIONS(6593),
    [anon_sym_shortreal] = ACTIONS(6593),
    [anon_sym_real] = ACTIONS(6593),
    [anon_sym_realtime] = ACTIONS(6593),
    [anon_sym_supply0] = ACTIONS(6593),
    [anon_sym_supply1] = ACTIONS(6593),
    [anon_sym_signed] = ACTIONS(6593),
    [anon_sym_unsigned] = ACTIONS(6593),
    [anon_sym_task] = ACTIONS(6593),
    [anon_sym_assert] = ACTIONS(6593),
    [anon_sym_property] = ACTIONS(6593),
    [anon_sym_assume] = ACTIONS(6593),
    [anon_sym_cover] = ACTIONS(6593),
    [anon_sym_sequence] = ACTIONS(6593),
    [anon_sym_restrict] = ACTIONS(6593),
    [anon_sym_not] = ACTIONS(6593),
    [anon_sym_or] = ACTIONS(6593),
    [anon_sym_and] = ACTIONS(6593),
    [anon_sym_case] = ACTIONS(6593),
    [anon_sym_always] = ACTIONS(6593),
    [anon_sym_covergroup] = ACTIONS(6593),
    [anon_sym_let] = ACTIONS(6593),
    [anon_sym_pulldown] = ACTIONS(6593),
    [anon_sym_pullup] = ACTIONS(6593),
    [anon_sym_cmos] = ACTIONS(6593),
    [anon_sym_rcmos] = ACTIONS(6593),
    [anon_sym_bufif0] = ACTIONS(6593),
    [anon_sym_bufif1] = ACTIONS(6593),
    [anon_sym_notif0] = ACTIONS(6593),
    [anon_sym_notif1] = ACTIONS(6593),
    [anon_sym_nmos] = ACTIONS(6593),
    [anon_sym_pmos] = ACTIONS(6593),
    [anon_sym_rnmos] = ACTIONS(6593),
    [anon_sym_rpmos] = ACTIONS(6593),
    [anon_sym_nand] = ACTIONS(6593),
    [anon_sym_nor] = ACTIONS(6593),
    [anon_sym_xor] = ACTIONS(6593),
    [anon_sym_xnor] = ACTIONS(6593),
    [anon_sym_buf] = ACTIONS(6593),
    [anon_sym_tranif0] = ACTIONS(6593),
    [anon_sym_tranif1] = ACTIONS(6593),
    [anon_sym_rtranif1] = ACTIONS(6593),
    [anon_sym_rtranif0] = ACTIONS(6593),
    [anon_sym_tran] = ACTIONS(6593),
    [anon_sym_rtran] = ACTIONS(6593),
    [anon_sym_generate] = ACTIONS(6593),
    [anon_sym_endgenerate] = ACTIONS(6593),
    [anon_sym_for] = ACTIONS(6593),
    [anon_sym_initial] = ACTIONS(6593),
    [anon_sym_assign] = ACTIONS(6593),
    [anon_sym_alias] = ACTIONS(6593),
    [anon_sym_always_comb] = ACTIONS(6593),
    [anon_sym_always_latch] = ACTIONS(6593),
    [anon_sym_always_ff] = ACTIONS(6593),
    [anon_sym_final] = ACTIONS(6593),
    [anon_sym_global] = ACTIONS(6593),
    [anon_sym_LPAREN_STAR] = ACTIONS(6595),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6595),
    [anon_sym_DOLLARunit] = ACTIONS(6595),
  },
  [5043] = {
    [sym_simple_identifier] = ACTIONS(5892),
    [anon_sym_wire] = ACTIONS(5892),
    [anon_sym_tri] = ACTIONS(5892),
    [anon_sym_tri0] = ACTIONS(5892),
    [anon_sym_tri1] = ACTIONS(5892),
    [anon_sym_wand] = ACTIONS(5892),
    [anon_sym_triand] = ACTIONS(5892),
    [anon_sym_wor] = ACTIONS(5892),
    [anon_sym_trior] = ACTIONS(5892),
    [anon_sym_trireg] = ACTIONS(5892),
    [anon_sym_uwire] = ACTIONS(5892),
    [anon_sym_SEMI] = ACTIONS(5894),
    [anon_sym_extern] = ACTIONS(5892),
    [anon_sym_interface] = ACTIONS(5892),
    [anon_sym_checker] = ACTIONS(5892),
    [anon_sym_virtual] = ACTIONS(5892),
    [anon_sym_class] = ACTIONS(5892),
    [anon_sym_type] = ACTIONS(5892),
    [anon_sym_DOLLARfatal] = ACTIONS(5894),
    [anon_sym_DOLLARerror] = ACTIONS(5894),
    [anon_sym_DOLLARwarning] = ACTIONS(5894),
    [anon_sym_DOLLARinfo] = ACTIONS(5894),
    [anon_sym_default] = ACTIONS(5892),
    [anon_sym_clocking] = ACTIONS(5892),
    [anon_sym_defparam] = ACTIONS(5892),
    [anon_sym_bind] = ACTIONS(5892),
    [anon_sym_rand] = ACTIONS(5892),
    [anon_sym_const] = ACTIONS(5892),
    [anon_sym_function] = ACTIONS(5892),
    [anon_sym_static] = ACTIONS(5892),
    [anon_sym_constraint] = ACTIONS(5892),
    [anon_sym_if] = ACTIONS(5892),
    [anon_sym_else] = ACTIONS(5892),
    [anon_sym_LBRACK] = ACTIONS(5894),
    [anon_sym_localparam] = ACTIONS(5892),
    [anon_sym_parameter] = ACTIONS(5892),
    [anon_sym_var] = ACTIONS(5892),
    [anon_sym_import] = ACTIONS(5892),
    [anon_sym_export] = ACTIONS(5892),
    [anon_sym_genvar] = ACTIONS(5892),
    [anon_sym_interconnect] = ACTIONS(5892),
    [anon_sym_typedef] = ACTIONS(5892),
    [anon_sym_enum] = ACTIONS(5892),
    [anon_sym_struct] = ACTIONS(5892),
    [anon_sym_union] = ACTIONS(5892),
    [anon_sym_nettype] = ACTIONS(5892),
    [anon_sym_automatic] = ACTIONS(5892),
    [anon_sym_string] = ACTIONS(5892),
    [anon_sym_chandle] = ACTIONS(5892),
    [anon_sym_event] = ACTIONS(5892),
    [anon_sym_byte] = ACTIONS(5892),
    [anon_sym_shortint] = ACTIONS(5892),
    [anon_sym_int] = ACTIONS(5892),
    [anon_sym_longint] = ACTIONS(5892),
    [anon_sym_integer] = ACTIONS(5892),
    [anon_sym_time] = ACTIONS(5892),
    [anon_sym_bit] = ACTIONS(5892),
    [anon_sym_logic] = ACTIONS(5892),
    [anon_sym_reg] = ACTIONS(5892),
    [anon_sym_shortreal] = ACTIONS(5892),
    [anon_sym_real] = ACTIONS(5892),
    [anon_sym_realtime] = ACTIONS(5892),
    [anon_sym_supply0] = ACTIONS(5892),
    [anon_sym_supply1] = ACTIONS(5892),
    [anon_sym_signed] = ACTIONS(5892),
    [anon_sym_unsigned] = ACTIONS(5892),
    [anon_sym_task] = ACTIONS(5892),
    [anon_sym_assert] = ACTIONS(5892),
    [anon_sym_property] = ACTIONS(5892),
    [anon_sym_assume] = ACTIONS(5892),
    [anon_sym_cover] = ACTIONS(5892),
    [anon_sym_sequence] = ACTIONS(5892),
    [anon_sym_restrict] = ACTIONS(5892),
    [anon_sym_not] = ACTIONS(5892),
    [anon_sym_or] = ACTIONS(5892),
    [anon_sym_and] = ACTIONS(5892),
    [anon_sym_case] = ACTIONS(5892),
    [anon_sym_always] = ACTIONS(5892),
    [anon_sym_covergroup] = ACTIONS(5892),
    [anon_sym_let] = ACTIONS(5892),
    [anon_sym_pulldown] = ACTIONS(5892),
    [anon_sym_pullup] = ACTIONS(5892),
    [anon_sym_cmos] = ACTIONS(5892),
    [anon_sym_rcmos] = ACTIONS(5892),
    [anon_sym_bufif0] = ACTIONS(5892),
    [anon_sym_bufif1] = ACTIONS(5892),
    [anon_sym_notif0] = ACTIONS(5892),
    [anon_sym_notif1] = ACTIONS(5892),
    [anon_sym_nmos] = ACTIONS(5892),
    [anon_sym_pmos] = ACTIONS(5892),
    [anon_sym_rnmos] = ACTIONS(5892),
    [anon_sym_rpmos] = ACTIONS(5892),
    [anon_sym_nand] = ACTIONS(5892),
    [anon_sym_nor] = ACTIONS(5892),
    [anon_sym_xor] = ACTIONS(5892),
    [anon_sym_xnor] = ACTIONS(5892),
    [anon_sym_buf] = ACTIONS(5892),
    [anon_sym_tranif0] = ACTIONS(5892),
    [anon_sym_tranif1] = ACTIONS(5892),
    [anon_sym_rtranif1] = ACTIONS(5892),
    [anon_sym_rtranif0] = ACTIONS(5892),
    [anon_sym_tran] = ACTIONS(5892),
    [anon_sym_rtran] = ACTIONS(5892),
    [anon_sym_generate] = ACTIONS(5892),
    [anon_sym_endgenerate] = ACTIONS(5892),
    [anon_sym_for] = ACTIONS(5892),
    [anon_sym_initial] = ACTIONS(5892),
    [anon_sym_assign] = ACTIONS(5892),
    [anon_sym_alias] = ACTIONS(5892),
    [anon_sym_always_comb] = ACTIONS(5892),
    [anon_sym_always_latch] = ACTIONS(5892),
    [anon_sym_always_ff] = ACTIONS(5892),
    [anon_sym_final] = ACTIONS(5892),
    [anon_sym_global] = ACTIONS(5892),
    [anon_sym_LPAREN_STAR] = ACTIONS(5894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5894),
    [anon_sym_DOLLARunit] = ACTIONS(5894),
  },
  [5044] = {
    [sym_simple_identifier] = ACTIONS(4780),
    [anon_sym_wire] = ACTIONS(4780),
    [anon_sym_tri] = ACTIONS(4780),
    [anon_sym_tri0] = ACTIONS(4780),
    [anon_sym_tri1] = ACTIONS(4780),
    [anon_sym_wand] = ACTIONS(4780),
    [anon_sym_triand] = ACTIONS(4780),
    [anon_sym_wor] = ACTIONS(4780),
    [anon_sym_trior] = ACTIONS(4780),
    [anon_sym_trireg] = ACTIONS(4780),
    [anon_sym_uwire] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_extern] = ACTIONS(4780),
    [anon_sym_interface] = ACTIONS(4780),
    [anon_sym_checker] = ACTIONS(4780),
    [anon_sym_virtual] = ACTIONS(4780),
    [anon_sym_class] = ACTIONS(4780),
    [anon_sym_type] = ACTIONS(4780),
    [anon_sym_DOLLARfatal] = ACTIONS(4778),
    [anon_sym_DOLLARerror] = ACTIONS(4778),
    [anon_sym_DOLLARwarning] = ACTIONS(4778),
    [anon_sym_DOLLARinfo] = ACTIONS(4778),
    [anon_sym_default] = ACTIONS(4780),
    [anon_sym_clocking] = ACTIONS(4780),
    [anon_sym_defparam] = ACTIONS(4780),
    [anon_sym_bind] = ACTIONS(4780),
    [anon_sym_rand] = ACTIONS(4780),
    [anon_sym_const] = ACTIONS(4780),
    [anon_sym_function] = ACTIONS(4780),
    [anon_sym_static] = ACTIONS(4780),
    [anon_sym_constraint] = ACTIONS(4780),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [anon_sym_localparam] = ACTIONS(4780),
    [anon_sym_parameter] = ACTIONS(4780),
    [anon_sym_var] = ACTIONS(4780),
    [anon_sym_import] = ACTIONS(4780),
    [anon_sym_export] = ACTIONS(4780),
    [anon_sym_genvar] = ACTIONS(4780),
    [anon_sym_interconnect] = ACTIONS(4780),
    [anon_sym_typedef] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_struct] = ACTIONS(4780),
    [anon_sym_union] = ACTIONS(4780),
    [anon_sym_nettype] = ACTIONS(4780),
    [anon_sym_automatic] = ACTIONS(4780),
    [anon_sym_string] = ACTIONS(4780),
    [anon_sym_chandle] = ACTIONS(4780),
    [anon_sym_event] = ACTIONS(4780),
    [anon_sym_byte] = ACTIONS(4780),
    [anon_sym_shortint] = ACTIONS(4780),
    [anon_sym_int] = ACTIONS(4780),
    [anon_sym_longint] = ACTIONS(4780),
    [anon_sym_integer] = ACTIONS(4780),
    [anon_sym_time] = ACTIONS(4780),
    [anon_sym_bit] = ACTIONS(4780),
    [anon_sym_logic] = ACTIONS(4780),
    [anon_sym_reg] = ACTIONS(4780),
    [anon_sym_shortreal] = ACTIONS(4780),
    [anon_sym_real] = ACTIONS(4780),
    [anon_sym_realtime] = ACTIONS(4780),
    [anon_sym_supply0] = ACTIONS(4780),
    [anon_sym_supply1] = ACTIONS(4780),
    [anon_sym_signed] = ACTIONS(4780),
    [anon_sym_unsigned] = ACTIONS(4780),
    [anon_sym_task] = ACTIONS(4780),
    [anon_sym_assert] = ACTIONS(4780),
    [anon_sym_property] = ACTIONS(4780),
    [anon_sym_assume] = ACTIONS(4780),
    [anon_sym_cover] = ACTIONS(4780),
    [anon_sym_sequence] = ACTIONS(4780),
    [anon_sym_restrict] = ACTIONS(4780),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_or] = ACTIONS(4780),
    [anon_sym_and] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_always] = ACTIONS(4780),
    [anon_sym_covergroup] = ACTIONS(4780),
    [anon_sym_let] = ACTIONS(4780),
    [anon_sym_pulldown] = ACTIONS(4780),
    [anon_sym_pullup] = ACTIONS(4780),
    [anon_sym_cmos] = ACTIONS(4780),
    [anon_sym_rcmos] = ACTIONS(4780),
    [anon_sym_bufif0] = ACTIONS(4780),
    [anon_sym_bufif1] = ACTIONS(4780),
    [anon_sym_notif0] = ACTIONS(4780),
    [anon_sym_notif1] = ACTIONS(4780),
    [anon_sym_nmos] = ACTIONS(4780),
    [anon_sym_pmos] = ACTIONS(4780),
    [anon_sym_rnmos] = ACTIONS(4780),
    [anon_sym_rpmos] = ACTIONS(4780),
    [anon_sym_nand] = ACTIONS(4780),
    [anon_sym_nor] = ACTIONS(4780),
    [anon_sym_xor] = ACTIONS(4780),
    [anon_sym_xnor] = ACTIONS(4780),
    [anon_sym_buf] = ACTIONS(4780),
    [anon_sym_tranif0] = ACTIONS(4780),
    [anon_sym_tranif1] = ACTIONS(4780),
    [anon_sym_rtranif1] = ACTIONS(4780),
    [anon_sym_rtranif0] = ACTIONS(4780),
    [anon_sym_tran] = ACTIONS(4780),
    [anon_sym_rtran] = ACTIONS(4780),
    [anon_sym_generate] = ACTIONS(4780),
    [anon_sym_endgenerate] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_initial] = ACTIONS(4780),
    [anon_sym_assign] = ACTIONS(4780),
    [anon_sym_alias] = ACTIONS(4780),
    [anon_sym_always_comb] = ACTIONS(4780),
    [anon_sym_always_latch] = ACTIONS(4780),
    [anon_sym_always_ff] = ACTIONS(4780),
    [anon_sym_final] = ACTIONS(4780),
    [anon_sym_global] = ACTIONS(4780),
    [anon_sym_LPAREN_STAR] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4778),
    [anon_sym_DOLLARunit] = ACTIONS(4778),
  },
  [5045] = {
    [sym_simple_identifier] = ACTIONS(4972),
    [anon_sym_wire] = ACTIONS(4972),
    [anon_sym_tri] = ACTIONS(4972),
    [anon_sym_tri0] = ACTIONS(4972),
    [anon_sym_tri1] = ACTIONS(4972),
    [anon_sym_wand] = ACTIONS(4972),
    [anon_sym_triand] = ACTIONS(4972),
    [anon_sym_wor] = ACTIONS(4972),
    [anon_sym_trior] = ACTIONS(4972),
    [anon_sym_trireg] = ACTIONS(4972),
    [anon_sym_uwire] = ACTIONS(4972),
    [anon_sym_SEMI] = ACTIONS(4970),
    [anon_sym_extern] = ACTIONS(4972),
    [anon_sym_interface] = ACTIONS(4972),
    [anon_sym_checker] = ACTIONS(4972),
    [anon_sym_virtual] = ACTIONS(4972),
    [anon_sym_class] = ACTIONS(4972),
    [anon_sym_type] = ACTIONS(4972),
    [anon_sym_DOLLARfatal] = ACTIONS(4970),
    [anon_sym_DOLLARerror] = ACTIONS(4970),
    [anon_sym_DOLLARwarning] = ACTIONS(4970),
    [anon_sym_DOLLARinfo] = ACTIONS(4970),
    [anon_sym_default] = ACTIONS(4972),
    [anon_sym_clocking] = ACTIONS(4972),
    [anon_sym_defparam] = ACTIONS(4972),
    [anon_sym_bind] = ACTIONS(4972),
    [anon_sym_rand] = ACTIONS(4972),
    [anon_sym_const] = ACTIONS(4972),
    [anon_sym_function] = ACTIONS(4972),
    [anon_sym_static] = ACTIONS(4972),
    [anon_sym_constraint] = ACTIONS(4972),
    [anon_sym_if] = ACTIONS(4972),
    [anon_sym_else] = ACTIONS(4972),
    [anon_sym_LBRACK] = ACTIONS(4970),
    [anon_sym_localparam] = ACTIONS(4972),
    [anon_sym_parameter] = ACTIONS(4972),
    [anon_sym_var] = ACTIONS(4972),
    [anon_sym_import] = ACTIONS(4972),
    [anon_sym_export] = ACTIONS(4972),
    [anon_sym_genvar] = ACTIONS(4972),
    [anon_sym_interconnect] = ACTIONS(4972),
    [anon_sym_typedef] = ACTIONS(4972),
    [anon_sym_enum] = ACTIONS(4972),
    [anon_sym_struct] = ACTIONS(4972),
    [anon_sym_union] = ACTIONS(4972),
    [anon_sym_nettype] = ACTIONS(4972),
    [anon_sym_automatic] = ACTIONS(4972),
    [anon_sym_string] = ACTIONS(4972),
    [anon_sym_chandle] = ACTIONS(4972),
    [anon_sym_event] = ACTIONS(4972),
    [anon_sym_byte] = ACTIONS(4972),
    [anon_sym_shortint] = ACTIONS(4972),
    [anon_sym_int] = ACTIONS(4972),
    [anon_sym_longint] = ACTIONS(4972),
    [anon_sym_integer] = ACTIONS(4972),
    [anon_sym_time] = ACTIONS(4972),
    [anon_sym_bit] = ACTIONS(4972),
    [anon_sym_logic] = ACTIONS(4972),
    [anon_sym_reg] = ACTIONS(4972),
    [anon_sym_shortreal] = ACTIONS(4972),
    [anon_sym_real] = ACTIONS(4972),
    [anon_sym_realtime] = ACTIONS(4972),
    [anon_sym_supply0] = ACTIONS(4972),
    [anon_sym_supply1] = ACTIONS(4972),
    [anon_sym_signed] = ACTIONS(4972),
    [anon_sym_unsigned] = ACTIONS(4972),
    [anon_sym_task] = ACTIONS(4972),
    [anon_sym_assert] = ACTIONS(4972),
    [anon_sym_property] = ACTIONS(4972),
    [anon_sym_assume] = ACTIONS(4972),
    [anon_sym_cover] = ACTIONS(4972),
    [anon_sym_sequence] = ACTIONS(4972),
    [anon_sym_restrict] = ACTIONS(4972),
    [anon_sym_not] = ACTIONS(4972),
    [anon_sym_or] = ACTIONS(4972),
    [anon_sym_and] = ACTIONS(4972),
    [anon_sym_case] = ACTIONS(4972),
    [anon_sym_always] = ACTIONS(4972),
    [anon_sym_covergroup] = ACTIONS(4972),
    [anon_sym_end] = ACTIONS(4972),
    [anon_sym_let] = ACTIONS(4972),
    [anon_sym_pulldown] = ACTIONS(4972),
    [anon_sym_pullup] = ACTIONS(4972),
    [anon_sym_cmos] = ACTIONS(4972),
    [anon_sym_rcmos] = ACTIONS(4972),
    [anon_sym_bufif0] = ACTIONS(4972),
    [anon_sym_bufif1] = ACTIONS(4972),
    [anon_sym_notif0] = ACTIONS(4972),
    [anon_sym_notif1] = ACTIONS(4972),
    [anon_sym_nmos] = ACTIONS(4972),
    [anon_sym_pmos] = ACTIONS(4972),
    [anon_sym_rnmos] = ACTIONS(4972),
    [anon_sym_rpmos] = ACTIONS(4972),
    [anon_sym_nand] = ACTIONS(4972),
    [anon_sym_nor] = ACTIONS(4972),
    [anon_sym_xor] = ACTIONS(4972),
    [anon_sym_xnor] = ACTIONS(4972),
    [anon_sym_buf] = ACTIONS(4972),
    [anon_sym_tranif0] = ACTIONS(4972),
    [anon_sym_tranif1] = ACTIONS(4972),
    [anon_sym_rtranif1] = ACTIONS(4972),
    [anon_sym_rtranif0] = ACTIONS(4972),
    [anon_sym_tran] = ACTIONS(4972),
    [anon_sym_rtran] = ACTIONS(4972),
    [anon_sym_generate] = ACTIONS(4972),
    [anon_sym_for] = ACTIONS(4972),
    [anon_sym_initial] = ACTIONS(4972),
    [anon_sym_assign] = ACTIONS(4972),
    [anon_sym_alias] = ACTIONS(4972),
    [anon_sym_always_comb] = ACTIONS(4972),
    [anon_sym_always_latch] = ACTIONS(4972),
    [anon_sym_always_ff] = ACTIONS(4972),
    [anon_sym_final] = ACTIONS(4972),
    [anon_sym_global] = ACTIONS(4972),
    [anon_sym_LPAREN_STAR] = ACTIONS(4970),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4970),
    [anon_sym_DOLLARunit] = ACTIONS(4970),
  },
  [5046] = {
    [sym_simple_identifier] = ACTIONS(6755),
    [anon_sym_wire] = ACTIONS(6755),
    [anon_sym_tri] = ACTIONS(6755),
    [anon_sym_tri0] = ACTIONS(6755),
    [anon_sym_tri1] = ACTIONS(6755),
    [anon_sym_wand] = ACTIONS(6755),
    [anon_sym_triand] = ACTIONS(6755),
    [anon_sym_wor] = ACTIONS(6755),
    [anon_sym_trior] = ACTIONS(6755),
    [anon_sym_trireg] = ACTIONS(6755),
    [anon_sym_uwire] = ACTIONS(6755),
    [anon_sym_SEMI] = ACTIONS(6757),
    [anon_sym_extern] = ACTIONS(6755),
    [anon_sym_interface] = ACTIONS(6755),
    [anon_sym_checker] = ACTIONS(6755),
    [anon_sym_virtual] = ACTIONS(6755),
    [anon_sym_class] = ACTIONS(6755),
    [anon_sym_type] = ACTIONS(6755),
    [anon_sym_DOLLARfatal] = ACTIONS(6757),
    [anon_sym_DOLLARerror] = ACTIONS(6757),
    [anon_sym_DOLLARwarning] = ACTIONS(6757),
    [anon_sym_DOLLARinfo] = ACTIONS(6757),
    [anon_sym_default] = ACTIONS(6755),
    [anon_sym_clocking] = ACTIONS(6755),
    [anon_sym_defparam] = ACTIONS(6755),
    [anon_sym_bind] = ACTIONS(6755),
    [anon_sym_rand] = ACTIONS(6755),
    [anon_sym_const] = ACTIONS(6755),
    [anon_sym_function] = ACTIONS(6755),
    [anon_sym_static] = ACTIONS(6755),
    [anon_sym_constraint] = ACTIONS(6755),
    [anon_sym_if] = ACTIONS(6755),
    [anon_sym_else] = ACTIONS(6755),
    [anon_sym_LBRACK] = ACTIONS(6757),
    [anon_sym_localparam] = ACTIONS(6755),
    [anon_sym_parameter] = ACTIONS(6755),
    [anon_sym_var] = ACTIONS(6755),
    [anon_sym_import] = ACTIONS(6755),
    [anon_sym_export] = ACTIONS(6755),
    [anon_sym_genvar] = ACTIONS(6755),
    [anon_sym_interconnect] = ACTIONS(6755),
    [anon_sym_typedef] = ACTIONS(6755),
    [anon_sym_enum] = ACTIONS(6755),
    [anon_sym_struct] = ACTIONS(6755),
    [anon_sym_union] = ACTIONS(6755),
    [anon_sym_nettype] = ACTIONS(6755),
    [anon_sym_automatic] = ACTIONS(6755),
    [anon_sym_string] = ACTIONS(6755),
    [anon_sym_chandle] = ACTIONS(6755),
    [anon_sym_event] = ACTIONS(6755),
    [anon_sym_byte] = ACTIONS(6755),
    [anon_sym_shortint] = ACTIONS(6755),
    [anon_sym_int] = ACTIONS(6755),
    [anon_sym_longint] = ACTIONS(6755),
    [anon_sym_integer] = ACTIONS(6755),
    [anon_sym_time] = ACTIONS(6755),
    [anon_sym_bit] = ACTIONS(6755),
    [anon_sym_logic] = ACTIONS(6755),
    [anon_sym_reg] = ACTIONS(6755),
    [anon_sym_shortreal] = ACTIONS(6755),
    [anon_sym_real] = ACTIONS(6755),
    [anon_sym_realtime] = ACTIONS(6755),
    [anon_sym_supply0] = ACTIONS(6755),
    [anon_sym_supply1] = ACTIONS(6755),
    [anon_sym_signed] = ACTIONS(6755),
    [anon_sym_unsigned] = ACTIONS(6755),
    [anon_sym_task] = ACTIONS(6755),
    [anon_sym_assert] = ACTIONS(6755),
    [anon_sym_property] = ACTIONS(6755),
    [anon_sym_assume] = ACTIONS(6755),
    [anon_sym_cover] = ACTIONS(6755),
    [anon_sym_sequence] = ACTIONS(6755),
    [anon_sym_restrict] = ACTIONS(6755),
    [anon_sym_not] = ACTIONS(6755),
    [anon_sym_or] = ACTIONS(6755),
    [anon_sym_and] = ACTIONS(6755),
    [anon_sym_case] = ACTIONS(6755),
    [anon_sym_always] = ACTIONS(6755),
    [anon_sym_covergroup] = ACTIONS(6755),
    [anon_sym_let] = ACTIONS(6755),
    [anon_sym_pulldown] = ACTIONS(6755),
    [anon_sym_pullup] = ACTIONS(6755),
    [anon_sym_cmos] = ACTIONS(6755),
    [anon_sym_rcmos] = ACTIONS(6755),
    [anon_sym_bufif0] = ACTIONS(6755),
    [anon_sym_bufif1] = ACTIONS(6755),
    [anon_sym_notif0] = ACTIONS(6755),
    [anon_sym_notif1] = ACTIONS(6755),
    [anon_sym_nmos] = ACTIONS(6755),
    [anon_sym_pmos] = ACTIONS(6755),
    [anon_sym_rnmos] = ACTIONS(6755),
    [anon_sym_rpmos] = ACTIONS(6755),
    [anon_sym_nand] = ACTIONS(6755),
    [anon_sym_nor] = ACTIONS(6755),
    [anon_sym_xor] = ACTIONS(6755),
    [anon_sym_xnor] = ACTIONS(6755),
    [anon_sym_buf] = ACTIONS(6755),
    [anon_sym_tranif0] = ACTIONS(6755),
    [anon_sym_tranif1] = ACTIONS(6755),
    [anon_sym_rtranif1] = ACTIONS(6755),
    [anon_sym_rtranif0] = ACTIONS(6755),
    [anon_sym_tran] = ACTIONS(6755),
    [anon_sym_rtran] = ACTIONS(6755),
    [anon_sym_generate] = ACTIONS(6755),
    [anon_sym_endgenerate] = ACTIONS(6755),
    [anon_sym_for] = ACTIONS(6755),
    [anon_sym_initial] = ACTIONS(6755),
    [anon_sym_assign] = ACTIONS(6755),
    [anon_sym_alias] = ACTIONS(6755),
    [anon_sym_always_comb] = ACTIONS(6755),
    [anon_sym_always_latch] = ACTIONS(6755),
    [anon_sym_always_ff] = ACTIONS(6755),
    [anon_sym_final] = ACTIONS(6755),
    [anon_sym_global] = ACTIONS(6755),
    [anon_sym_LPAREN_STAR] = ACTIONS(6757),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6757),
    [anon_sym_DOLLARunit] = ACTIONS(6757),
  },
  [5047] = {
    [sym_simple_identifier] = ACTIONS(6141),
    [anon_sym_wire] = ACTIONS(6141),
    [anon_sym_tri] = ACTIONS(6141),
    [anon_sym_tri0] = ACTIONS(6141),
    [anon_sym_tri1] = ACTIONS(6141),
    [anon_sym_wand] = ACTIONS(6141),
    [anon_sym_triand] = ACTIONS(6141),
    [anon_sym_wor] = ACTIONS(6141),
    [anon_sym_trior] = ACTIONS(6141),
    [anon_sym_trireg] = ACTIONS(6141),
    [anon_sym_uwire] = ACTIONS(6141),
    [anon_sym_SEMI] = ACTIONS(6143),
    [anon_sym_extern] = ACTIONS(6141),
    [anon_sym_interface] = ACTIONS(6141),
    [anon_sym_checker] = ACTIONS(6141),
    [anon_sym_virtual] = ACTIONS(6141),
    [anon_sym_class] = ACTIONS(6141),
    [anon_sym_type] = ACTIONS(6141),
    [anon_sym_DOLLARfatal] = ACTIONS(6143),
    [anon_sym_DOLLARerror] = ACTIONS(6143),
    [anon_sym_DOLLARwarning] = ACTIONS(6143),
    [anon_sym_DOLLARinfo] = ACTIONS(6143),
    [anon_sym_default] = ACTIONS(6141),
    [anon_sym_clocking] = ACTIONS(6141),
    [anon_sym_defparam] = ACTIONS(6141),
    [anon_sym_bind] = ACTIONS(6141),
    [anon_sym_rand] = ACTIONS(6141),
    [anon_sym_const] = ACTIONS(6141),
    [anon_sym_function] = ACTIONS(6141),
    [anon_sym_static] = ACTIONS(6141),
    [anon_sym_constraint] = ACTIONS(6141),
    [anon_sym_if] = ACTIONS(6141),
    [anon_sym_else] = ACTIONS(6141),
    [anon_sym_LBRACK] = ACTIONS(6143),
    [anon_sym_localparam] = ACTIONS(6141),
    [anon_sym_parameter] = ACTIONS(6141),
    [anon_sym_var] = ACTIONS(6141),
    [anon_sym_import] = ACTIONS(6141),
    [anon_sym_export] = ACTIONS(6141),
    [anon_sym_genvar] = ACTIONS(6141),
    [anon_sym_interconnect] = ACTIONS(6141),
    [anon_sym_typedef] = ACTIONS(6141),
    [anon_sym_enum] = ACTIONS(6141),
    [anon_sym_struct] = ACTIONS(6141),
    [anon_sym_union] = ACTIONS(6141),
    [anon_sym_nettype] = ACTIONS(6141),
    [anon_sym_automatic] = ACTIONS(6141),
    [anon_sym_string] = ACTIONS(6141),
    [anon_sym_chandle] = ACTIONS(6141),
    [anon_sym_event] = ACTIONS(6141),
    [anon_sym_byte] = ACTIONS(6141),
    [anon_sym_shortint] = ACTIONS(6141),
    [anon_sym_int] = ACTIONS(6141),
    [anon_sym_longint] = ACTIONS(6141),
    [anon_sym_integer] = ACTIONS(6141),
    [anon_sym_time] = ACTIONS(6141),
    [anon_sym_bit] = ACTIONS(6141),
    [anon_sym_logic] = ACTIONS(6141),
    [anon_sym_reg] = ACTIONS(6141),
    [anon_sym_shortreal] = ACTIONS(6141),
    [anon_sym_real] = ACTIONS(6141),
    [anon_sym_realtime] = ACTIONS(6141),
    [anon_sym_supply0] = ACTIONS(6141),
    [anon_sym_supply1] = ACTIONS(6141),
    [anon_sym_signed] = ACTIONS(6141),
    [anon_sym_unsigned] = ACTIONS(6141),
    [anon_sym_task] = ACTIONS(6141),
    [anon_sym_assert] = ACTIONS(6141),
    [anon_sym_property] = ACTIONS(6141),
    [anon_sym_assume] = ACTIONS(6141),
    [anon_sym_cover] = ACTIONS(6141),
    [anon_sym_sequence] = ACTIONS(6141),
    [anon_sym_restrict] = ACTIONS(6141),
    [anon_sym_not] = ACTIONS(6141),
    [anon_sym_or] = ACTIONS(6141),
    [anon_sym_and] = ACTIONS(6141),
    [anon_sym_case] = ACTIONS(6141),
    [anon_sym_always] = ACTIONS(6141),
    [anon_sym_covergroup] = ACTIONS(6141),
    [anon_sym_let] = ACTIONS(6141),
    [anon_sym_pulldown] = ACTIONS(6141),
    [anon_sym_pullup] = ACTIONS(6141),
    [anon_sym_cmos] = ACTIONS(6141),
    [anon_sym_rcmos] = ACTIONS(6141),
    [anon_sym_bufif0] = ACTIONS(6141),
    [anon_sym_bufif1] = ACTIONS(6141),
    [anon_sym_notif0] = ACTIONS(6141),
    [anon_sym_notif1] = ACTIONS(6141),
    [anon_sym_nmos] = ACTIONS(6141),
    [anon_sym_pmos] = ACTIONS(6141),
    [anon_sym_rnmos] = ACTIONS(6141),
    [anon_sym_rpmos] = ACTIONS(6141),
    [anon_sym_nand] = ACTIONS(6141),
    [anon_sym_nor] = ACTIONS(6141),
    [anon_sym_xor] = ACTIONS(6141),
    [anon_sym_xnor] = ACTIONS(6141),
    [anon_sym_buf] = ACTIONS(6141),
    [anon_sym_tranif0] = ACTIONS(6141),
    [anon_sym_tranif1] = ACTIONS(6141),
    [anon_sym_rtranif1] = ACTIONS(6141),
    [anon_sym_rtranif0] = ACTIONS(6141),
    [anon_sym_tran] = ACTIONS(6141),
    [anon_sym_rtran] = ACTIONS(6141),
    [anon_sym_generate] = ACTIONS(6141),
    [anon_sym_endgenerate] = ACTIONS(6141),
    [anon_sym_for] = ACTIONS(6141),
    [anon_sym_initial] = ACTIONS(6141),
    [anon_sym_assign] = ACTIONS(6141),
    [anon_sym_alias] = ACTIONS(6141),
    [anon_sym_always_comb] = ACTIONS(6141),
    [anon_sym_always_latch] = ACTIONS(6141),
    [anon_sym_always_ff] = ACTIONS(6141),
    [anon_sym_final] = ACTIONS(6141),
    [anon_sym_global] = ACTIONS(6141),
    [anon_sym_LPAREN_STAR] = ACTIONS(6143),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6143),
    [anon_sym_DOLLARunit] = ACTIONS(6143),
  },
  [5048] = {
    [sym_simple_identifier] = ACTIONS(4708),
    [anon_sym_wire] = ACTIONS(4708),
    [anon_sym_tri] = ACTIONS(4708),
    [anon_sym_tri0] = ACTIONS(4708),
    [anon_sym_tri1] = ACTIONS(4708),
    [anon_sym_wand] = ACTIONS(4708),
    [anon_sym_triand] = ACTIONS(4708),
    [anon_sym_wor] = ACTIONS(4708),
    [anon_sym_trior] = ACTIONS(4708),
    [anon_sym_trireg] = ACTIONS(4708),
    [anon_sym_uwire] = ACTIONS(4708),
    [anon_sym_SEMI] = ACTIONS(4706),
    [anon_sym_extern] = ACTIONS(4708),
    [anon_sym_interface] = ACTIONS(4708),
    [anon_sym_checker] = ACTIONS(4708),
    [anon_sym_virtual] = ACTIONS(4708),
    [anon_sym_class] = ACTIONS(4708),
    [anon_sym_type] = ACTIONS(4708),
    [anon_sym_DOLLARfatal] = ACTIONS(4706),
    [anon_sym_DOLLARerror] = ACTIONS(4706),
    [anon_sym_DOLLARwarning] = ACTIONS(4706),
    [anon_sym_DOLLARinfo] = ACTIONS(4706),
    [anon_sym_default] = ACTIONS(4708),
    [anon_sym_clocking] = ACTIONS(4708),
    [anon_sym_defparam] = ACTIONS(4708),
    [anon_sym_bind] = ACTIONS(4708),
    [anon_sym_rand] = ACTIONS(4708),
    [anon_sym_const] = ACTIONS(4708),
    [anon_sym_function] = ACTIONS(4708),
    [anon_sym_static] = ACTIONS(4708),
    [anon_sym_constraint] = ACTIONS(4708),
    [anon_sym_if] = ACTIONS(4708),
    [anon_sym_else] = ACTIONS(4708),
    [anon_sym_LBRACK] = ACTIONS(4706),
    [anon_sym_localparam] = ACTIONS(4708),
    [anon_sym_parameter] = ACTIONS(4708),
    [anon_sym_var] = ACTIONS(4708),
    [anon_sym_import] = ACTIONS(4708),
    [anon_sym_export] = ACTIONS(4708),
    [anon_sym_genvar] = ACTIONS(4708),
    [anon_sym_interconnect] = ACTIONS(4708),
    [anon_sym_typedef] = ACTIONS(4708),
    [anon_sym_enum] = ACTIONS(4708),
    [anon_sym_struct] = ACTIONS(4708),
    [anon_sym_union] = ACTIONS(4708),
    [anon_sym_nettype] = ACTIONS(4708),
    [anon_sym_automatic] = ACTIONS(4708),
    [anon_sym_string] = ACTIONS(4708),
    [anon_sym_chandle] = ACTIONS(4708),
    [anon_sym_event] = ACTIONS(4708),
    [anon_sym_byte] = ACTIONS(4708),
    [anon_sym_shortint] = ACTIONS(4708),
    [anon_sym_int] = ACTIONS(4708),
    [anon_sym_longint] = ACTIONS(4708),
    [anon_sym_integer] = ACTIONS(4708),
    [anon_sym_time] = ACTIONS(4708),
    [anon_sym_bit] = ACTIONS(4708),
    [anon_sym_logic] = ACTIONS(4708),
    [anon_sym_reg] = ACTIONS(4708),
    [anon_sym_shortreal] = ACTIONS(4708),
    [anon_sym_real] = ACTIONS(4708),
    [anon_sym_realtime] = ACTIONS(4708),
    [anon_sym_supply0] = ACTIONS(4708),
    [anon_sym_supply1] = ACTIONS(4708),
    [anon_sym_signed] = ACTIONS(4708),
    [anon_sym_unsigned] = ACTIONS(4708),
    [anon_sym_task] = ACTIONS(4708),
    [anon_sym_assert] = ACTIONS(4708),
    [anon_sym_property] = ACTIONS(4708),
    [anon_sym_assume] = ACTIONS(4708),
    [anon_sym_cover] = ACTIONS(4708),
    [anon_sym_sequence] = ACTIONS(4708),
    [anon_sym_restrict] = ACTIONS(4708),
    [anon_sym_not] = ACTIONS(4708),
    [anon_sym_or] = ACTIONS(4708),
    [anon_sym_and] = ACTIONS(4708),
    [anon_sym_case] = ACTIONS(4708),
    [anon_sym_always] = ACTIONS(4708),
    [anon_sym_covergroup] = ACTIONS(4708),
    [anon_sym_end] = ACTIONS(4708),
    [anon_sym_let] = ACTIONS(4708),
    [anon_sym_pulldown] = ACTIONS(4708),
    [anon_sym_pullup] = ACTIONS(4708),
    [anon_sym_cmos] = ACTIONS(4708),
    [anon_sym_rcmos] = ACTIONS(4708),
    [anon_sym_bufif0] = ACTIONS(4708),
    [anon_sym_bufif1] = ACTIONS(4708),
    [anon_sym_notif0] = ACTIONS(4708),
    [anon_sym_notif1] = ACTIONS(4708),
    [anon_sym_nmos] = ACTIONS(4708),
    [anon_sym_pmos] = ACTIONS(4708),
    [anon_sym_rnmos] = ACTIONS(4708),
    [anon_sym_rpmos] = ACTIONS(4708),
    [anon_sym_nand] = ACTIONS(4708),
    [anon_sym_nor] = ACTIONS(4708),
    [anon_sym_xor] = ACTIONS(4708),
    [anon_sym_xnor] = ACTIONS(4708),
    [anon_sym_buf] = ACTIONS(4708),
    [anon_sym_tranif0] = ACTIONS(4708),
    [anon_sym_tranif1] = ACTIONS(4708),
    [anon_sym_rtranif1] = ACTIONS(4708),
    [anon_sym_rtranif0] = ACTIONS(4708),
    [anon_sym_tran] = ACTIONS(4708),
    [anon_sym_rtran] = ACTIONS(4708),
    [anon_sym_generate] = ACTIONS(4708),
    [anon_sym_for] = ACTIONS(4708),
    [anon_sym_initial] = ACTIONS(4708),
    [anon_sym_assign] = ACTIONS(4708),
    [anon_sym_alias] = ACTIONS(4708),
    [anon_sym_always_comb] = ACTIONS(4708),
    [anon_sym_always_latch] = ACTIONS(4708),
    [anon_sym_always_ff] = ACTIONS(4708),
    [anon_sym_final] = ACTIONS(4708),
    [anon_sym_global] = ACTIONS(4708),
    [anon_sym_LPAREN_STAR] = ACTIONS(4706),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4706),
    [anon_sym_DOLLARunit] = ACTIONS(4706),
  },
  [5049] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4780),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4780),
    [sym_package_or_generate_item_declaration] = STATE(4780),
    [sym_anonymous_program] = STATE(4780),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4780),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4780),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11182),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [5050] = {
    [sym_simple_identifier] = ACTIONS(6145),
    [anon_sym_wire] = ACTIONS(6145),
    [anon_sym_tri] = ACTIONS(6145),
    [anon_sym_tri0] = ACTIONS(6145),
    [anon_sym_tri1] = ACTIONS(6145),
    [anon_sym_wand] = ACTIONS(6145),
    [anon_sym_triand] = ACTIONS(6145),
    [anon_sym_wor] = ACTIONS(6145),
    [anon_sym_trior] = ACTIONS(6145),
    [anon_sym_trireg] = ACTIONS(6145),
    [anon_sym_uwire] = ACTIONS(6145),
    [anon_sym_SEMI] = ACTIONS(6147),
    [anon_sym_extern] = ACTIONS(6145),
    [anon_sym_interface] = ACTIONS(6145),
    [anon_sym_checker] = ACTIONS(6145),
    [anon_sym_virtual] = ACTIONS(6145),
    [anon_sym_class] = ACTIONS(6145),
    [anon_sym_type] = ACTIONS(6145),
    [anon_sym_DOLLARfatal] = ACTIONS(6147),
    [anon_sym_DOLLARerror] = ACTIONS(6147),
    [anon_sym_DOLLARwarning] = ACTIONS(6147),
    [anon_sym_DOLLARinfo] = ACTIONS(6147),
    [anon_sym_default] = ACTIONS(6145),
    [anon_sym_clocking] = ACTIONS(6145),
    [anon_sym_defparam] = ACTIONS(6145),
    [anon_sym_bind] = ACTIONS(6145),
    [anon_sym_rand] = ACTIONS(6145),
    [anon_sym_const] = ACTIONS(6145),
    [anon_sym_function] = ACTIONS(6145),
    [anon_sym_static] = ACTIONS(6145),
    [anon_sym_constraint] = ACTIONS(6145),
    [anon_sym_if] = ACTIONS(6145),
    [anon_sym_else] = ACTIONS(6145),
    [anon_sym_LBRACK] = ACTIONS(6147),
    [anon_sym_localparam] = ACTIONS(6145),
    [anon_sym_parameter] = ACTIONS(6145),
    [anon_sym_var] = ACTIONS(6145),
    [anon_sym_import] = ACTIONS(6145),
    [anon_sym_export] = ACTIONS(6145),
    [anon_sym_genvar] = ACTIONS(6145),
    [anon_sym_interconnect] = ACTIONS(6145),
    [anon_sym_typedef] = ACTIONS(6145),
    [anon_sym_enum] = ACTIONS(6145),
    [anon_sym_struct] = ACTIONS(6145),
    [anon_sym_union] = ACTIONS(6145),
    [anon_sym_nettype] = ACTIONS(6145),
    [anon_sym_automatic] = ACTIONS(6145),
    [anon_sym_string] = ACTIONS(6145),
    [anon_sym_chandle] = ACTIONS(6145),
    [anon_sym_event] = ACTIONS(6145),
    [anon_sym_byte] = ACTIONS(6145),
    [anon_sym_shortint] = ACTIONS(6145),
    [anon_sym_int] = ACTIONS(6145),
    [anon_sym_longint] = ACTIONS(6145),
    [anon_sym_integer] = ACTIONS(6145),
    [anon_sym_time] = ACTIONS(6145),
    [anon_sym_bit] = ACTIONS(6145),
    [anon_sym_logic] = ACTIONS(6145),
    [anon_sym_reg] = ACTIONS(6145),
    [anon_sym_shortreal] = ACTIONS(6145),
    [anon_sym_real] = ACTIONS(6145),
    [anon_sym_realtime] = ACTIONS(6145),
    [anon_sym_supply0] = ACTIONS(6145),
    [anon_sym_supply1] = ACTIONS(6145),
    [anon_sym_signed] = ACTIONS(6145),
    [anon_sym_unsigned] = ACTIONS(6145),
    [anon_sym_task] = ACTIONS(6145),
    [anon_sym_assert] = ACTIONS(6145),
    [anon_sym_property] = ACTIONS(6145),
    [anon_sym_assume] = ACTIONS(6145),
    [anon_sym_cover] = ACTIONS(6145),
    [anon_sym_sequence] = ACTIONS(6145),
    [anon_sym_restrict] = ACTIONS(6145),
    [anon_sym_not] = ACTIONS(6145),
    [anon_sym_or] = ACTIONS(6145),
    [anon_sym_and] = ACTIONS(6145),
    [anon_sym_case] = ACTIONS(6145),
    [anon_sym_always] = ACTIONS(6145),
    [anon_sym_covergroup] = ACTIONS(6145),
    [anon_sym_let] = ACTIONS(6145),
    [anon_sym_pulldown] = ACTIONS(6145),
    [anon_sym_pullup] = ACTIONS(6145),
    [anon_sym_cmos] = ACTIONS(6145),
    [anon_sym_rcmos] = ACTIONS(6145),
    [anon_sym_bufif0] = ACTIONS(6145),
    [anon_sym_bufif1] = ACTIONS(6145),
    [anon_sym_notif0] = ACTIONS(6145),
    [anon_sym_notif1] = ACTIONS(6145),
    [anon_sym_nmos] = ACTIONS(6145),
    [anon_sym_pmos] = ACTIONS(6145),
    [anon_sym_rnmos] = ACTIONS(6145),
    [anon_sym_rpmos] = ACTIONS(6145),
    [anon_sym_nand] = ACTIONS(6145),
    [anon_sym_nor] = ACTIONS(6145),
    [anon_sym_xor] = ACTIONS(6145),
    [anon_sym_xnor] = ACTIONS(6145),
    [anon_sym_buf] = ACTIONS(6145),
    [anon_sym_tranif0] = ACTIONS(6145),
    [anon_sym_tranif1] = ACTIONS(6145),
    [anon_sym_rtranif1] = ACTIONS(6145),
    [anon_sym_rtranif0] = ACTIONS(6145),
    [anon_sym_tran] = ACTIONS(6145),
    [anon_sym_rtran] = ACTIONS(6145),
    [anon_sym_generate] = ACTIONS(6145),
    [anon_sym_endgenerate] = ACTIONS(6145),
    [anon_sym_for] = ACTIONS(6145),
    [anon_sym_initial] = ACTIONS(6145),
    [anon_sym_assign] = ACTIONS(6145),
    [anon_sym_alias] = ACTIONS(6145),
    [anon_sym_always_comb] = ACTIONS(6145),
    [anon_sym_always_latch] = ACTIONS(6145),
    [anon_sym_always_ff] = ACTIONS(6145),
    [anon_sym_final] = ACTIONS(6145),
    [anon_sym_global] = ACTIONS(6145),
    [anon_sym_LPAREN_STAR] = ACTIONS(6147),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6147),
    [anon_sym_DOLLARunit] = ACTIONS(6147),
  },
  [5051] = {
    [sym_simple_identifier] = ACTIONS(4512),
    [anon_sym_wire] = ACTIONS(4512),
    [anon_sym_tri] = ACTIONS(4512),
    [anon_sym_tri0] = ACTIONS(4512),
    [anon_sym_tri1] = ACTIONS(4512),
    [anon_sym_wand] = ACTIONS(4512),
    [anon_sym_triand] = ACTIONS(4512),
    [anon_sym_wor] = ACTIONS(4512),
    [anon_sym_trior] = ACTIONS(4512),
    [anon_sym_trireg] = ACTIONS(4512),
    [anon_sym_uwire] = ACTIONS(4512),
    [anon_sym_SEMI] = ACTIONS(4510),
    [anon_sym_extern] = ACTIONS(4512),
    [anon_sym_interface] = ACTIONS(4512),
    [anon_sym_checker] = ACTIONS(4512),
    [anon_sym_virtual] = ACTIONS(4512),
    [anon_sym_class] = ACTIONS(4512),
    [anon_sym_type] = ACTIONS(4512),
    [anon_sym_DOLLARfatal] = ACTIONS(4510),
    [anon_sym_DOLLARerror] = ACTIONS(4510),
    [anon_sym_DOLLARwarning] = ACTIONS(4510),
    [anon_sym_DOLLARinfo] = ACTIONS(4510),
    [anon_sym_default] = ACTIONS(4512),
    [anon_sym_clocking] = ACTIONS(4512),
    [anon_sym_defparam] = ACTIONS(4512),
    [anon_sym_bind] = ACTIONS(4512),
    [anon_sym_rand] = ACTIONS(4512),
    [anon_sym_const] = ACTIONS(4512),
    [anon_sym_function] = ACTIONS(4512),
    [anon_sym_static] = ACTIONS(4512),
    [anon_sym_constraint] = ACTIONS(4512),
    [anon_sym_if] = ACTIONS(4512),
    [anon_sym_else] = ACTIONS(4512),
    [anon_sym_LBRACK] = ACTIONS(4510),
    [anon_sym_localparam] = ACTIONS(4512),
    [anon_sym_parameter] = ACTIONS(4512),
    [anon_sym_var] = ACTIONS(4512),
    [anon_sym_import] = ACTIONS(4512),
    [anon_sym_export] = ACTIONS(4512),
    [anon_sym_genvar] = ACTIONS(4512),
    [anon_sym_interconnect] = ACTIONS(4512),
    [anon_sym_typedef] = ACTIONS(4512),
    [anon_sym_enum] = ACTIONS(4512),
    [anon_sym_struct] = ACTIONS(4512),
    [anon_sym_union] = ACTIONS(4512),
    [anon_sym_nettype] = ACTIONS(4512),
    [anon_sym_automatic] = ACTIONS(4512),
    [anon_sym_string] = ACTIONS(4512),
    [anon_sym_chandle] = ACTIONS(4512),
    [anon_sym_event] = ACTIONS(4512),
    [anon_sym_byte] = ACTIONS(4512),
    [anon_sym_shortint] = ACTIONS(4512),
    [anon_sym_int] = ACTIONS(4512),
    [anon_sym_longint] = ACTIONS(4512),
    [anon_sym_integer] = ACTIONS(4512),
    [anon_sym_time] = ACTIONS(4512),
    [anon_sym_bit] = ACTIONS(4512),
    [anon_sym_logic] = ACTIONS(4512),
    [anon_sym_reg] = ACTIONS(4512),
    [anon_sym_shortreal] = ACTIONS(4512),
    [anon_sym_real] = ACTIONS(4512),
    [anon_sym_realtime] = ACTIONS(4512),
    [anon_sym_supply0] = ACTIONS(4512),
    [anon_sym_supply1] = ACTIONS(4512),
    [anon_sym_signed] = ACTIONS(4512),
    [anon_sym_unsigned] = ACTIONS(4512),
    [anon_sym_task] = ACTIONS(4512),
    [anon_sym_assert] = ACTIONS(4512),
    [anon_sym_property] = ACTIONS(4512),
    [anon_sym_assume] = ACTIONS(4512),
    [anon_sym_cover] = ACTIONS(4512),
    [anon_sym_sequence] = ACTIONS(4512),
    [anon_sym_restrict] = ACTIONS(4512),
    [anon_sym_not] = ACTIONS(4512),
    [anon_sym_or] = ACTIONS(4512),
    [anon_sym_and] = ACTIONS(4512),
    [anon_sym_case] = ACTIONS(4512),
    [anon_sym_always] = ACTIONS(4512),
    [anon_sym_covergroup] = ACTIONS(4512),
    [anon_sym_end] = ACTIONS(4512),
    [anon_sym_let] = ACTIONS(4512),
    [anon_sym_pulldown] = ACTIONS(4512),
    [anon_sym_pullup] = ACTIONS(4512),
    [anon_sym_cmos] = ACTIONS(4512),
    [anon_sym_rcmos] = ACTIONS(4512),
    [anon_sym_bufif0] = ACTIONS(4512),
    [anon_sym_bufif1] = ACTIONS(4512),
    [anon_sym_notif0] = ACTIONS(4512),
    [anon_sym_notif1] = ACTIONS(4512),
    [anon_sym_nmos] = ACTIONS(4512),
    [anon_sym_pmos] = ACTIONS(4512),
    [anon_sym_rnmos] = ACTIONS(4512),
    [anon_sym_rpmos] = ACTIONS(4512),
    [anon_sym_nand] = ACTIONS(4512),
    [anon_sym_nor] = ACTIONS(4512),
    [anon_sym_xor] = ACTIONS(4512),
    [anon_sym_xnor] = ACTIONS(4512),
    [anon_sym_buf] = ACTIONS(4512),
    [anon_sym_tranif0] = ACTIONS(4512),
    [anon_sym_tranif1] = ACTIONS(4512),
    [anon_sym_rtranif1] = ACTIONS(4512),
    [anon_sym_rtranif0] = ACTIONS(4512),
    [anon_sym_tran] = ACTIONS(4512),
    [anon_sym_rtran] = ACTIONS(4512),
    [anon_sym_generate] = ACTIONS(4512),
    [anon_sym_for] = ACTIONS(4512),
    [anon_sym_initial] = ACTIONS(4512),
    [anon_sym_assign] = ACTIONS(4512),
    [anon_sym_alias] = ACTIONS(4512),
    [anon_sym_always_comb] = ACTIONS(4512),
    [anon_sym_always_latch] = ACTIONS(4512),
    [anon_sym_always_ff] = ACTIONS(4512),
    [anon_sym_final] = ACTIONS(4512),
    [anon_sym_global] = ACTIONS(4512),
    [anon_sym_LPAREN_STAR] = ACTIONS(4510),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4510),
    [anon_sym_DOLLARunit] = ACTIONS(4510),
  },
  [5052] = {
    [sym_simple_identifier] = ACTIONS(6759),
    [anon_sym_wire] = ACTIONS(6759),
    [anon_sym_tri] = ACTIONS(6759),
    [anon_sym_tri0] = ACTIONS(6759),
    [anon_sym_tri1] = ACTIONS(6759),
    [anon_sym_wand] = ACTIONS(6759),
    [anon_sym_triand] = ACTIONS(6759),
    [anon_sym_wor] = ACTIONS(6759),
    [anon_sym_trior] = ACTIONS(6759),
    [anon_sym_trireg] = ACTIONS(6759),
    [anon_sym_uwire] = ACTIONS(6759),
    [anon_sym_SEMI] = ACTIONS(6762),
    [anon_sym_extern] = ACTIONS(6759),
    [anon_sym_interface] = ACTIONS(6759),
    [anon_sym_checker] = ACTIONS(6759),
    [anon_sym_virtual] = ACTIONS(6759),
    [anon_sym_class] = ACTIONS(6759),
    [anon_sym_type] = ACTIONS(6759),
    [anon_sym_DOLLARfatal] = ACTIONS(6762),
    [anon_sym_DOLLARerror] = ACTIONS(6762),
    [anon_sym_DOLLARwarning] = ACTIONS(6762),
    [anon_sym_DOLLARinfo] = ACTIONS(6762),
    [anon_sym_default] = ACTIONS(6759),
    [anon_sym_clocking] = ACTIONS(6759),
    [anon_sym_defparam] = ACTIONS(6759),
    [anon_sym_bind] = ACTIONS(6759),
    [anon_sym_rand] = ACTIONS(6759),
    [anon_sym_const] = ACTIONS(6759),
    [anon_sym_function] = ACTIONS(6759),
    [anon_sym_static] = ACTIONS(6759),
    [anon_sym_constraint] = ACTIONS(6759),
    [anon_sym_if] = ACTIONS(6759),
    [anon_sym_else] = ACTIONS(6759),
    [anon_sym_LBRACK] = ACTIONS(6762),
    [anon_sym_localparam] = ACTIONS(6759),
    [anon_sym_parameter] = ACTIONS(6759),
    [anon_sym_var] = ACTIONS(6759),
    [anon_sym_import] = ACTIONS(6759),
    [anon_sym_export] = ACTIONS(6759),
    [anon_sym_genvar] = ACTIONS(6759),
    [anon_sym_interconnect] = ACTIONS(6759),
    [anon_sym_typedef] = ACTIONS(6759),
    [anon_sym_enum] = ACTIONS(6759),
    [anon_sym_struct] = ACTIONS(6759),
    [anon_sym_union] = ACTIONS(6759),
    [anon_sym_nettype] = ACTIONS(6759),
    [anon_sym_automatic] = ACTIONS(6759),
    [anon_sym_string] = ACTIONS(6759),
    [anon_sym_chandle] = ACTIONS(6759),
    [anon_sym_event] = ACTIONS(6759),
    [anon_sym_byte] = ACTIONS(6759),
    [anon_sym_shortint] = ACTIONS(6759),
    [anon_sym_int] = ACTIONS(6759),
    [anon_sym_longint] = ACTIONS(6759),
    [anon_sym_integer] = ACTIONS(6759),
    [anon_sym_time] = ACTIONS(6759),
    [anon_sym_bit] = ACTIONS(6759),
    [anon_sym_logic] = ACTIONS(6759),
    [anon_sym_reg] = ACTIONS(6759),
    [anon_sym_shortreal] = ACTIONS(6759),
    [anon_sym_real] = ACTIONS(6759),
    [anon_sym_realtime] = ACTIONS(6759),
    [anon_sym_supply0] = ACTIONS(6759),
    [anon_sym_supply1] = ACTIONS(6759),
    [anon_sym_signed] = ACTIONS(6759),
    [anon_sym_unsigned] = ACTIONS(6759),
    [anon_sym_task] = ACTIONS(6759),
    [anon_sym_assert] = ACTIONS(6759),
    [anon_sym_property] = ACTIONS(6759),
    [anon_sym_assume] = ACTIONS(6759),
    [anon_sym_cover] = ACTIONS(6759),
    [anon_sym_sequence] = ACTIONS(6759),
    [anon_sym_restrict] = ACTIONS(6759),
    [anon_sym_not] = ACTIONS(6759),
    [anon_sym_or] = ACTIONS(6759),
    [anon_sym_and] = ACTIONS(6759),
    [anon_sym_case] = ACTIONS(6759),
    [anon_sym_always] = ACTIONS(6759),
    [anon_sym_covergroup] = ACTIONS(6759),
    [anon_sym_end] = ACTIONS(6759),
    [anon_sym_let] = ACTIONS(6759),
    [anon_sym_pulldown] = ACTIONS(6759),
    [anon_sym_pullup] = ACTIONS(6759),
    [anon_sym_cmos] = ACTIONS(6759),
    [anon_sym_rcmos] = ACTIONS(6759),
    [anon_sym_bufif0] = ACTIONS(6759),
    [anon_sym_bufif1] = ACTIONS(6759),
    [anon_sym_notif0] = ACTIONS(6759),
    [anon_sym_notif1] = ACTIONS(6759),
    [anon_sym_nmos] = ACTIONS(6759),
    [anon_sym_pmos] = ACTIONS(6759),
    [anon_sym_rnmos] = ACTIONS(6759),
    [anon_sym_rpmos] = ACTIONS(6759),
    [anon_sym_nand] = ACTIONS(6759),
    [anon_sym_nor] = ACTIONS(6759),
    [anon_sym_xor] = ACTIONS(6759),
    [anon_sym_xnor] = ACTIONS(6759),
    [anon_sym_buf] = ACTIONS(6759),
    [anon_sym_tranif0] = ACTIONS(6759),
    [anon_sym_tranif1] = ACTIONS(6759),
    [anon_sym_rtranif1] = ACTIONS(6759),
    [anon_sym_rtranif0] = ACTIONS(6759),
    [anon_sym_tran] = ACTIONS(6759),
    [anon_sym_rtran] = ACTIONS(6759),
    [anon_sym_generate] = ACTIONS(6759),
    [anon_sym_for] = ACTIONS(6759),
    [anon_sym_initial] = ACTIONS(6759),
    [anon_sym_assign] = ACTIONS(6759),
    [anon_sym_alias] = ACTIONS(6759),
    [anon_sym_always_comb] = ACTIONS(6759),
    [anon_sym_always_latch] = ACTIONS(6759),
    [anon_sym_always_ff] = ACTIONS(6759),
    [anon_sym_final] = ACTIONS(6759),
    [anon_sym_global] = ACTIONS(6759),
    [anon_sym_LPAREN_STAR] = ACTIONS(6762),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6762),
    [anon_sym_DOLLARunit] = ACTIONS(6762),
  },
  [5053] = {
    [sym_simple_identifier] = ACTIONS(4784),
    [anon_sym_wire] = ACTIONS(4784),
    [anon_sym_tri] = ACTIONS(4784),
    [anon_sym_tri0] = ACTIONS(4784),
    [anon_sym_tri1] = ACTIONS(4784),
    [anon_sym_wand] = ACTIONS(4784),
    [anon_sym_triand] = ACTIONS(4784),
    [anon_sym_wor] = ACTIONS(4784),
    [anon_sym_trior] = ACTIONS(4784),
    [anon_sym_trireg] = ACTIONS(4784),
    [anon_sym_uwire] = ACTIONS(4784),
    [anon_sym_SEMI] = ACTIONS(4782),
    [anon_sym_extern] = ACTIONS(4784),
    [anon_sym_interface] = ACTIONS(4784),
    [anon_sym_checker] = ACTIONS(4784),
    [anon_sym_virtual] = ACTIONS(4784),
    [anon_sym_class] = ACTIONS(4784),
    [anon_sym_type] = ACTIONS(4784),
    [anon_sym_DOLLARfatal] = ACTIONS(4782),
    [anon_sym_DOLLARerror] = ACTIONS(4782),
    [anon_sym_DOLLARwarning] = ACTIONS(4782),
    [anon_sym_DOLLARinfo] = ACTIONS(4782),
    [anon_sym_default] = ACTIONS(4784),
    [anon_sym_clocking] = ACTIONS(4784),
    [anon_sym_defparam] = ACTIONS(4784),
    [anon_sym_bind] = ACTIONS(4784),
    [anon_sym_rand] = ACTIONS(4784),
    [anon_sym_const] = ACTIONS(4784),
    [anon_sym_function] = ACTIONS(4784),
    [anon_sym_static] = ACTIONS(4784),
    [anon_sym_constraint] = ACTIONS(4784),
    [anon_sym_if] = ACTIONS(4784),
    [anon_sym_else] = ACTIONS(4784),
    [anon_sym_LBRACK] = ACTIONS(4782),
    [anon_sym_localparam] = ACTIONS(4784),
    [anon_sym_parameter] = ACTIONS(4784),
    [anon_sym_var] = ACTIONS(4784),
    [anon_sym_import] = ACTIONS(4784),
    [anon_sym_export] = ACTIONS(4784),
    [anon_sym_genvar] = ACTIONS(4784),
    [anon_sym_interconnect] = ACTIONS(4784),
    [anon_sym_typedef] = ACTIONS(4784),
    [anon_sym_enum] = ACTIONS(4784),
    [anon_sym_struct] = ACTIONS(4784),
    [anon_sym_union] = ACTIONS(4784),
    [anon_sym_nettype] = ACTIONS(4784),
    [anon_sym_automatic] = ACTIONS(4784),
    [anon_sym_string] = ACTIONS(4784),
    [anon_sym_chandle] = ACTIONS(4784),
    [anon_sym_event] = ACTIONS(4784),
    [anon_sym_byte] = ACTIONS(4784),
    [anon_sym_shortint] = ACTIONS(4784),
    [anon_sym_int] = ACTIONS(4784),
    [anon_sym_longint] = ACTIONS(4784),
    [anon_sym_integer] = ACTIONS(4784),
    [anon_sym_time] = ACTIONS(4784),
    [anon_sym_bit] = ACTIONS(4784),
    [anon_sym_logic] = ACTIONS(4784),
    [anon_sym_reg] = ACTIONS(4784),
    [anon_sym_shortreal] = ACTIONS(4784),
    [anon_sym_real] = ACTIONS(4784),
    [anon_sym_realtime] = ACTIONS(4784),
    [anon_sym_supply0] = ACTIONS(4784),
    [anon_sym_supply1] = ACTIONS(4784),
    [anon_sym_signed] = ACTIONS(4784),
    [anon_sym_unsigned] = ACTIONS(4784),
    [anon_sym_task] = ACTIONS(4784),
    [anon_sym_assert] = ACTIONS(4784),
    [anon_sym_property] = ACTIONS(4784),
    [anon_sym_assume] = ACTIONS(4784),
    [anon_sym_cover] = ACTIONS(4784),
    [anon_sym_sequence] = ACTIONS(4784),
    [anon_sym_restrict] = ACTIONS(4784),
    [anon_sym_not] = ACTIONS(4784),
    [anon_sym_or] = ACTIONS(4784),
    [anon_sym_and] = ACTIONS(4784),
    [anon_sym_case] = ACTIONS(4784),
    [anon_sym_always] = ACTIONS(4784),
    [anon_sym_covergroup] = ACTIONS(4784),
    [anon_sym_let] = ACTIONS(4784),
    [anon_sym_pulldown] = ACTIONS(4784),
    [anon_sym_pullup] = ACTIONS(4784),
    [anon_sym_cmos] = ACTIONS(4784),
    [anon_sym_rcmos] = ACTIONS(4784),
    [anon_sym_bufif0] = ACTIONS(4784),
    [anon_sym_bufif1] = ACTIONS(4784),
    [anon_sym_notif0] = ACTIONS(4784),
    [anon_sym_notif1] = ACTIONS(4784),
    [anon_sym_nmos] = ACTIONS(4784),
    [anon_sym_pmos] = ACTIONS(4784),
    [anon_sym_rnmos] = ACTIONS(4784),
    [anon_sym_rpmos] = ACTIONS(4784),
    [anon_sym_nand] = ACTIONS(4784),
    [anon_sym_nor] = ACTIONS(4784),
    [anon_sym_xor] = ACTIONS(4784),
    [anon_sym_xnor] = ACTIONS(4784),
    [anon_sym_buf] = ACTIONS(4784),
    [anon_sym_tranif0] = ACTIONS(4784),
    [anon_sym_tranif1] = ACTIONS(4784),
    [anon_sym_rtranif1] = ACTIONS(4784),
    [anon_sym_rtranif0] = ACTIONS(4784),
    [anon_sym_tran] = ACTIONS(4784),
    [anon_sym_rtran] = ACTIONS(4784),
    [anon_sym_generate] = ACTIONS(4784),
    [anon_sym_endgenerate] = ACTIONS(4784),
    [anon_sym_for] = ACTIONS(4784),
    [anon_sym_initial] = ACTIONS(4784),
    [anon_sym_assign] = ACTIONS(4784),
    [anon_sym_alias] = ACTIONS(4784),
    [anon_sym_always_comb] = ACTIONS(4784),
    [anon_sym_always_latch] = ACTIONS(4784),
    [anon_sym_always_ff] = ACTIONS(4784),
    [anon_sym_final] = ACTIONS(4784),
    [anon_sym_global] = ACTIONS(4784),
    [anon_sym_LPAREN_STAR] = ACTIONS(4782),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4782),
    [anon_sym_DOLLARunit] = ACTIONS(4782),
  },
  [5054] = {
    [sym_simple_identifier] = ACTIONS(6765),
    [anon_sym_wire] = ACTIONS(6765),
    [anon_sym_tri] = ACTIONS(6765),
    [anon_sym_tri0] = ACTIONS(6765),
    [anon_sym_tri1] = ACTIONS(6765),
    [anon_sym_wand] = ACTIONS(6765),
    [anon_sym_triand] = ACTIONS(6765),
    [anon_sym_wor] = ACTIONS(6765),
    [anon_sym_trior] = ACTIONS(6765),
    [anon_sym_trireg] = ACTIONS(6765),
    [anon_sym_uwire] = ACTIONS(6765),
    [anon_sym_SEMI] = ACTIONS(6768),
    [anon_sym_extern] = ACTIONS(6765),
    [anon_sym_interface] = ACTIONS(6765),
    [anon_sym_checker] = ACTIONS(6765),
    [anon_sym_virtual] = ACTIONS(6765),
    [anon_sym_class] = ACTIONS(6765),
    [anon_sym_type] = ACTIONS(6765),
    [anon_sym_DOLLARfatal] = ACTIONS(6768),
    [anon_sym_DOLLARerror] = ACTIONS(6768),
    [anon_sym_DOLLARwarning] = ACTIONS(6768),
    [anon_sym_DOLLARinfo] = ACTIONS(6768),
    [anon_sym_default] = ACTIONS(6765),
    [anon_sym_clocking] = ACTIONS(6765),
    [anon_sym_defparam] = ACTIONS(6765),
    [anon_sym_bind] = ACTIONS(6765),
    [anon_sym_rand] = ACTIONS(6765),
    [anon_sym_const] = ACTIONS(6765),
    [anon_sym_function] = ACTIONS(6765),
    [anon_sym_static] = ACTIONS(6765),
    [anon_sym_constraint] = ACTIONS(6765),
    [anon_sym_if] = ACTIONS(6765),
    [anon_sym_else] = ACTIONS(6765),
    [anon_sym_LBRACK] = ACTIONS(6768),
    [anon_sym_localparam] = ACTIONS(6765),
    [anon_sym_parameter] = ACTIONS(6765),
    [anon_sym_var] = ACTIONS(6765),
    [anon_sym_import] = ACTIONS(6765),
    [anon_sym_export] = ACTIONS(6765),
    [anon_sym_genvar] = ACTIONS(6765),
    [anon_sym_interconnect] = ACTIONS(6765),
    [anon_sym_typedef] = ACTIONS(6765),
    [anon_sym_enum] = ACTIONS(6765),
    [anon_sym_struct] = ACTIONS(6765),
    [anon_sym_union] = ACTIONS(6765),
    [anon_sym_nettype] = ACTIONS(6765),
    [anon_sym_automatic] = ACTIONS(6765),
    [anon_sym_string] = ACTIONS(6765),
    [anon_sym_chandle] = ACTIONS(6765),
    [anon_sym_event] = ACTIONS(6765),
    [anon_sym_byte] = ACTIONS(6765),
    [anon_sym_shortint] = ACTIONS(6765),
    [anon_sym_int] = ACTIONS(6765),
    [anon_sym_longint] = ACTIONS(6765),
    [anon_sym_integer] = ACTIONS(6765),
    [anon_sym_time] = ACTIONS(6765),
    [anon_sym_bit] = ACTIONS(6765),
    [anon_sym_logic] = ACTIONS(6765),
    [anon_sym_reg] = ACTIONS(6765),
    [anon_sym_shortreal] = ACTIONS(6765),
    [anon_sym_real] = ACTIONS(6765),
    [anon_sym_realtime] = ACTIONS(6765),
    [anon_sym_supply0] = ACTIONS(6765),
    [anon_sym_supply1] = ACTIONS(6765),
    [anon_sym_signed] = ACTIONS(6765),
    [anon_sym_unsigned] = ACTIONS(6765),
    [anon_sym_task] = ACTIONS(6765),
    [anon_sym_assert] = ACTIONS(6765),
    [anon_sym_property] = ACTIONS(6765),
    [anon_sym_assume] = ACTIONS(6765),
    [anon_sym_cover] = ACTIONS(6765),
    [anon_sym_sequence] = ACTIONS(6765),
    [anon_sym_restrict] = ACTIONS(6765),
    [anon_sym_not] = ACTIONS(6765),
    [anon_sym_or] = ACTIONS(6765),
    [anon_sym_and] = ACTIONS(6765),
    [anon_sym_case] = ACTIONS(6765),
    [anon_sym_always] = ACTIONS(6765),
    [anon_sym_covergroup] = ACTIONS(6765),
    [anon_sym_end] = ACTIONS(6765),
    [anon_sym_let] = ACTIONS(6765),
    [anon_sym_pulldown] = ACTIONS(6765),
    [anon_sym_pullup] = ACTIONS(6765),
    [anon_sym_cmos] = ACTIONS(6765),
    [anon_sym_rcmos] = ACTIONS(6765),
    [anon_sym_bufif0] = ACTIONS(6765),
    [anon_sym_bufif1] = ACTIONS(6765),
    [anon_sym_notif0] = ACTIONS(6765),
    [anon_sym_notif1] = ACTIONS(6765),
    [anon_sym_nmos] = ACTIONS(6765),
    [anon_sym_pmos] = ACTIONS(6765),
    [anon_sym_rnmos] = ACTIONS(6765),
    [anon_sym_rpmos] = ACTIONS(6765),
    [anon_sym_nand] = ACTIONS(6765),
    [anon_sym_nor] = ACTIONS(6765),
    [anon_sym_xor] = ACTIONS(6765),
    [anon_sym_xnor] = ACTIONS(6765),
    [anon_sym_buf] = ACTIONS(6765),
    [anon_sym_tranif0] = ACTIONS(6765),
    [anon_sym_tranif1] = ACTIONS(6765),
    [anon_sym_rtranif1] = ACTIONS(6765),
    [anon_sym_rtranif0] = ACTIONS(6765),
    [anon_sym_tran] = ACTIONS(6765),
    [anon_sym_rtran] = ACTIONS(6765),
    [anon_sym_generate] = ACTIONS(6765),
    [anon_sym_for] = ACTIONS(6765),
    [anon_sym_initial] = ACTIONS(6765),
    [anon_sym_assign] = ACTIONS(6765),
    [anon_sym_alias] = ACTIONS(6765),
    [anon_sym_always_comb] = ACTIONS(6765),
    [anon_sym_always_latch] = ACTIONS(6765),
    [anon_sym_always_ff] = ACTIONS(6765),
    [anon_sym_final] = ACTIONS(6765),
    [anon_sym_global] = ACTIONS(6765),
    [anon_sym_LPAREN_STAR] = ACTIONS(6768),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6768),
    [anon_sym_DOLLARunit] = ACTIONS(6768),
  },
  [5055] = {
    [sym_simple_identifier] = ACTIONS(6345),
    [anon_sym_wire] = ACTIONS(6345),
    [anon_sym_tri] = ACTIONS(6345),
    [anon_sym_tri0] = ACTIONS(6345),
    [anon_sym_tri1] = ACTIONS(6345),
    [anon_sym_wand] = ACTIONS(6345),
    [anon_sym_triand] = ACTIONS(6345),
    [anon_sym_wor] = ACTIONS(6345),
    [anon_sym_trior] = ACTIONS(6345),
    [anon_sym_trireg] = ACTIONS(6345),
    [anon_sym_uwire] = ACTIONS(6345),
    [anon_sym_SEMI] = ACTIONS(6347),
    [anon_sym_extern] = ACTIONS(6345),
    [anon_sym_interface] = ACTIONS(6345),
    [anon_sym_checker] = ACTIONS(6345),
    [anon_sym_virtual] = ACTIONS(6345),
    [anon_sym_class] = ACTIONS(6345),
    [anon_sym_type] = ACTIONS(6345),
    [anon_sym_DOLLARfatal] = ACTIONS(6347),
    [anon_sym_DOLLARerror] = ACTIONS(6347),
    [anon_sym_DOLLARwarning] = ACTIONS(6347),
    [anon_sym_DOLLARinfo] = ACTIONS(6347),
    [anon_sym_default] = ACTIONS(6345),
    [anon_sym_clocking] = ACTIONS(6345),
    [anon_sym_defparam] = ACTIONS(6345),
    [anon_sym_bind] = ACTIONS(6345),
    [anon_sym_rand] = ACTIONS(6345),
    [anon_sym_const] = ACTIONS(6345),
    [anon_sym_function] = ACTIONS(6345),
    [anon_sym_static] = ACTIONS(6345),
    [anon_sym_constraint] = ACTIONS(6345),
    [anon_sym_if] = ACTIONS(6345),
    [anon_sym_else] = ACTIONS(6345),
    [anon_sym_LBRACK] = ACTIONS(6347),
    [anon_sym_localparam] = ACTIONS(6345),
    [anon_sym_parameter] = ACTIONS(6345),
    [anon_sym_var] = ACTIONS(6345),
    [anon_sym_import] = ACTIONS(6345),
    [anon_sym_export] = ACTIONS(6345),
    [anon_sym_genvar] = ACTIONS(6345),
    [anon_sym_interconnect] = ACTIONS(6345),
    [anon_sym_typedef] = ACTIONS(6345),
    [anon_sym_enum] = ACTIONS(6345),
    [anon_sym_struct] = ACTIONS(6345),
    [anon_sym_union] = ACTIONS(6345),
    [anon_sym_nettype] = ACTIONS(6345),
    [anon_sym_automatic] = ACTIONS(6345),
    [anon_sym_string] = ACTIONS(6345),
    [anon_sym_chandle] = ACTIONS(6345),
    [anon_sym_event] = ACTIONS(6345),
    [anon_sym_byte] = ACTIONS(6345),
    [anon_sym_shortint] = ACTIONS(6345),
    [anon_sym_int] = ACTIONS(6345),
    [anon_sym_longint] = ACTIONS(6345),
    [anon_sym_integer] = ACTIONS(6345),
    [anon_sym_time] = ACTIONS(6345),
    [anon_sym_bit] = ACTIONS(6345),
    [anon_sym_logic] = ACTIONS(6345),
    [anon_sym_reg] = ACTIONS(6345),
    [anon_sym_shortreal] = ACTIONS(6345),
    [anon_sym_real] = ACTIONS(6345),
    [anon_sym_realtime] = ACTIONS(6345),
    [anon_sym_supply0] = ACTIONS(6345),
    [anon_sym_supply1] = ACTIONS(6345),
    [anon_sym_signed] = ACTIONS(6345),
    [anon_sym_unsigned] = ACTIONS(6345),
    [anon_sym_task] = ACTIONS(6345),
    [anon_sym_assert] = ACTIONS(6345),
    [anon_sym_property] = ACTIONS(6345),
    [anon_sym_assume] = ACTIONS(6345),
    [anon_sym_cover] = ACTIONS(6345),
    [anon_sym_sequence] = ACTIONS(6345),
    [anon_sym_restrict] = ACTIONS(6345),
    [anon_sym_not] = ACTIONS(6345),
    [anon_sym_or] = ACTIONS(6345),
    [anon_sym_and] = ACTIONS(6345),
    [anon_sym_case] = ACTIONS(6345),
    [anon_sym_always] = ACTIONS(6345),
    [anon_sym_covergroup] = ACTIONS(6345),
    [anon_sym_end] = ACTIONS(6345),
    [anon_sym_let] = ACTIONS(6345),
    [anon_sym_pulldown] = ACTIONS(6345),
    [anon_sym_pullup] = ACTIONS(6345),
    [anon_sym_cmos] = ACTIONS(6345),
    [anon_sym_rcmos] = ACTIONS(6345),
    [anon_sym_bufif0] = ACTIONS(6345),
    [anon_sym_bufif1] = ACTIONS(6345),
    [anon_sym_notif0] = ACTIONS(6345),
    [anon_sym_notif1] = ACTIONS(6345),
    [anon_sym_nmos] = ACTIONS(6345),
    [anon_sym_pmos] = ACTIONS(6345),
    [anon_sym_rnmos] = ACTIONS(6345),
    [anon_sym_rpmos] = ACTIONS(6345),
    [anon_sym_nand] = ACTIONS(6345),
    [anon_sym_nor] = ACTIONS(6345),
    [anon_sym_xor] = ACTIONS(6345),
    [anon_sym_xnor] = ACTIONS(6345),
    [anon_sym_buf] = ACTIONS(6345),
    [anon_sym_tranif0] = ACTIONS(6345),
    [anon_sym_tranif1] = ACTIONS(6345),
    [anon_sym_rtranif1] = ACTIONS(6345),
    [anon_sym_rtranif0] = ACTIONS(6345),
    [anon_sym_tran] = ACTIONS(6345),
    [anon_sym_rtran] = ACTIONS(6345),
    [anon_sym_generate] = ACTIONS(6345),
    [anon_sym_for] = ACTIONS(6345),
    [anon_sym_initial] = ACTIONS(6345),
    [anon_sym_assign] = ACTIONS(6345),
    [anon_sym_alias] = ACTIONS(6345),
    [anon_sym_always_comb] = ACTIONS(6345),
    [anon_sym_always_latch] = ACTIONS(6345),
    [anon_sym_always_ff] = ACTIONS(6345),
    [anon_sym_final] = ACTIONS(6345),
    [anon_sym_global] = ACTIONS(6345),
    [anon_sym_LPAREN_STAR] = ACTIONS(6347),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6347),
    [anon_sym_DOLLARunit] = ACTIONS(6347),
  },
  [5056] = {
    [sym_simple_identifier] = ACTIONS(6149),
    [anon_sym_wire] = ACTIONS(6149),
    [anon_sym_tri] = ACTIONS(6149),
    [anon_sym_tri0] = ACTIONS(6149),
    [anon_sym_tri1] = ACTIONS(6149),
    [anon_sym_wand] = ACTIONS(6149),
    [anon_sym_triand] = ACTIONS(6149),
    [anon_sym_wor] = ACTIONS(6149),
    [anon_sym_trior] = ACTIONS(6149),
    [anon_sym_trireg] = ACTIONS(6149),
    [anon_sym_uwire] = ACTIONS(6149),
    [anon_sym_SEMI] = ACTIONS(6151),
    [anon_sym_extern] = ACTIONS(6149),
    [anon_sym_interface] = ACTIONS(6149),
    [anon_sym_checker] = ACTIONS(6149),
    [anon_sym_virtual] = ACTIONS(6149),
    [anon_sym_class] = ACTIONS(6149),
    [anon_sym_type] = ACTIONS(6149),
    [anon_sym_DOLLARfatal] = ACTIONS(6151),
    [anon_sym_DOLLARerror] = ACTIONS(6151),
    [anon_sym_DOLLARwarning] = ACTIONS(6151),
    [anon_sym_DOLLARinfo] = ACTIONS(6151),
    [anon_sym_default] = ACTIONS(6149),
    [anon_sym_clocking] = ACTIONS(6149),
    [anon_sym_defparam] = ACTIONS(6149),
    [anon_sym_bind] = ACTIONS(6149),
    [anon_sym_rand] = ACTIONS(6149),
    [anon_sym_const] = ACTIONS(6149),
    [anon_sym_function] = ACTIONS(6149),
    [anon_sym_static] = ACTIONS(6149),
    [anon_sym_constraint] = ACTIONS(6149),
    [anon_sym_if] = ACTIONS(6149),
    [anon_sym_else] = ACTIONS(6149),
    [anon_sym_LBRACK] = ACTIONS(6151),
    [anon_sym_localparam] = ACTIONS(6149),
    [anon_sym_parameter] = ACTIONS(6149),
    [anon_sym_var] = ACTIONS(6149),
    [anon_sym_import] = ACTIONS(6149),
    [anon_sym_export] = ACTIONS(6149),
    [anon_sym_genvar] = ACTIONS(6149),
    [anon_sym_interconnect] = ACTIONS(6149),
    [anon_sym_typedef] = ACTIONS(6149),
    [anon_sym_enum] = ACTIONS(6149),
    [anon_sym_struct] = ACTIONS(6149),
    [anon_sym_union] = ACTIONS(6149),
    [anon_sym_nettype] = ACTIONS(6149),
    [anon_sym_automatic] = ACTIONS(6149),
    [anon_sym_string] = ACTIONS(6149),
    [anon_sym_chandle] = ACTIONS(6149),
    [anon_sym_event] = ACTIONS(6149),
    [anon_sym_byte] = ACTIONS(6149),
    [anon_sym_shortint] = ACTIONS(6149),
    [anon_sym_int] = ACTIONS(6149),
    [anon_sym_longint] = ACTIONS(6149),
    [anon_sym_integer] = ACTIONS(6149),
    [anon_sym_time] = ACTIONS(6149),
    [anon_sym_bit] = ACTIONS(6149),
    [anon_sym_logic] = ACTIONS(6149),
    [anon_sym_reg] = ACTIONS(6149),
    [anon_sym_shortreal] = ACTIONS(6149),
    [anon_sym_real] = ACTIONS(6149),
    [anon_sym_realtime] = ACTIONS(6149),
    [anon_sym_supply0] = ACTIONS(6149),
    [anon_sym_supply1] = ACTIONS(6149),
    [anon_sym_signed] = ACTIONS(6149),
    [anon_sym_unsigned] = ACTIONS(6149),
    [anon_sym_task] = ACTIONS(6149),
    [anon_sym_assert] = ACTIONS(6149),
    [anon_sym_property] = ACTIONS(6149),
    [anon_sym_assume] = ACTIONS(6149),
    [anon_sym_cover] = ACTIONS(6149),
    [anon_sym_sequence] = ACTIONS(6149),
    [anon_sym_restrict] = ACTIONS(6149),
    [anon_sym_not] = ACTIONS(6149),
    [anon_sym_or] = ACTIONS(6149),
    [anon_sym_and] = ACTIONS(6149),
    [anon_sym_case] = ACTIONS(6149),
    [anon_sym_always] = ACTIONS(6149),
    [anon_sym_covergroup] = ACTIONS(6149),
    [anon_sym_let] = ACTIONS(6149),
    [anon_sym_pulldown] = ACTIONS(6149),
    [anon_sym_pullup] = ACTIONS(6149),
    [anon_sym_cmos] = ACTIONS(6149),
    [anon_sym_rcmos] = ACTIONS(6149),
    [anon_sym_bufif0] = ACTIONS(6149),
    [anon_sym_bufif1] = ACTIONS(6149),
    [anon_sym_notif0] = ACTIONS(6149),
    [anon_sym_notif1] = ACTIONS(6149),
    [anon_sym_nmos] = ACTIONS(6149),
    [anon_sym_pmos] = ACTIONS(6149),
    [anon_sym_rnmos] = ACTIONS(6149),
    [anon_sym_rpmos] = ACTIONS(6149),
    [anon_sym_nand] = ACTIONS(6149),
    [anon_sym_nor] = ACTIONS(6149),
    [anon_sym_xor] = ACTIONS(6149),
    [anon_sym_xnor] = ACTIONS(6149),
    [anon_sym_buf] = ACTIONS(6149),
    [anon_sym_tranif0] = ACTIONS(6149),
    [anon_sym_tranif1] = ACTIONS(6149),
    [anon_sym_rtranif1] = ACTIONS(6149),
    [anon_sym_rtranif0] = ACTIONS(6149),
    [anon_sym_tran] = ACTIONS(6149),
    [anon_sym_rtran] = ACTIONS(6149),
    [anon_sym_generate] = ACTIONS(6149),
    [anon_sym_endgenerate] = ACTIONS(6149),
    [anon_sym_for] = ACTIONS(6149),
    [anon_sym_initial] = ACTIONS(6149),
    [anon_sym_assign] = ACTIONS(6149),
    [anon_sym_alias] = ACTIONS(6149),
    [anon_sym_always_comb] = ACTIONS(6149),
    [anon_sym_always_latch] = ACTIONS(6149),
    [anon_sym_always_ff] = ACTIONS(6149),
    [anon_sym_final] = ACTIONS(6149),
    [anon_sym_global] = ACTIONS(6149),
    [anon_sym_LPAREN_STAR] = ACTIONS(6151),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6151),
    [anon_sym_DOLLARunit] = ACTIONS(6151),
  },
  [5057] = {
    [sym_simple_identifier] = ACTIONS(4142),
    [anon_sym_wire] = ACTIONS(4142),
    [anon_sym_tri] = ACTIONS(4142),
    [anon_sym_tri0] = ACTIONS(4142),
    [anon_sym_tri1] = ACTIONS(4142),
    [anon_sym_wand] = ACTIONS(4142),
    [anon_sym_triand] = ACTIONS(4142),
    [anon_sym_wor] = ACTIONS(4142),
    [anon_sym_trior] = ACTIONS(4142),
    [anon_sym_trireg] = ACTIONS(4142),
    [anon_sym_uwire] = ACTIONS(4142),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_extern] = ACTIONS(4142),
    [anon_sym_interface] = ACTIONS(4142),
    [anon_sym_checker] = ACTIONS(4142),
    [anon_sym_virtual] = ACTIONS(4142),
    [anon_sym_class] = ACTIONS(4142),
    [anon_sym_type] = ACTIONS(4142),
    [anon_sym_DOLLARfatal] = ACTIONS(4140),
    [anon_sym_DOLLARerror] = ACTIONS(4140),
    [anon_sym_DOLLARwarning] = ACTIONS(4140),
    [anon_sym_DOLLARinfo] = ACTIONS(4140),
    [anon_sym_default] = ACTIONS(4142),
    [anon_sym_clocking] = ACTIONS(4142),
    [anon_sym_defparam] = ACTIONS(4142),
    [anon_sym_bind] = ACTIONS(4142),
    [anon_sym_rand] = ACTIONS(4142),
    [anon_sym_const] = ACTIONS(4142),
    [anon_sym_function] = ACTIONS(4142),
    [anon_sym_static] = ACTIONS(4142),
    [anon_sym_constraint] = ACTIONS(4142),
    [anon_sym_if] = ACTIONS(4142),
    [anon_sym_else] = ACTIONS(4142),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_localparam] = ACTIONS(4142),
    [anon_sym_parameter] = ACTIONS(4142),
    [anon_sym_var] = ACTIONS(4142),
    [anon_sym_import] = ACTIONS(4142),
    [anon_sym_export] = ACTIONS(4142),
    [anon_sym_genvar] = ACTIONS(4142),
    [anon_sym_interconnect] = ACTIONS(4142),
    [anon_sym_typedef] = ACTIONS(4142),
    [anon_sym_enum] = ACTIONS(4142),
    [anon_sym_struct] = ACTIONS(4142),
    [anon_sym_union] = ACTIONS(4142),
    [anon_sym_nettype] = ACTIONS(4142),
    [anon_sym_automatic] = ACTIONS(4142),
    [anon_sym_string] = ACTIONS(4142),
    [anon_sym_chandle] = ACTIONS(4142),
    [anon_sym_event] = ACTIONS(4142),
    [anon_sym_byte] = ACTIONS(4142),
    [anon_sym_shortint] = ACTIONS(4142),
    [anon_sym_int] = ACTIONS(4142),
    [anon_sym_longint] = ACTIONS(4142),
    [anon_sym_integer] = ACTIONS(4142),
    [anon_sym_time] = ACTIONS(4142),
    [anon_sym_bit] = ACTIONS(4142),
    [anon_sym_logic] = ACTIONS(4142),
    [anon_sym_reg] = ACTIONS(4142),
    [anon_sym_shortreal] = ACTIONS(4142),
    [anon_sym_real] = ACTIONS(4142),
    [anon_sym_realtime] = ACTIONS(4142),
    [anon_sym_supply0] = ACTIONS(4142),
    [anon_sym_supply1] = ACTIONS(4142),
    [anon_sym_signed] = ACTIONS(4142),
    [anon_sym_unsigned] = ACTIONS(4142),
    [anon_sym_task] = ACTIONS(4142),
    [anon_sym_assert] = ACTIONS(4142),
    [anon_sym_property] = ACTIONS(4142),
    [anon_sym_assume] = ACTIONS(4142),
    [anon_sym_cover] = ACTIONS(4142),
    [anon_sym_sequence] = ACTIONS(4142),
    [anon_sym_restrict] = ACTIONS(4142),
    [anon_sym_not] = ACTIONS(4142),
    [anon_sym_or] = ACTIONS(4142),
    [anon_sym_and] = ACTIONS(4142),
    [anon_sym_case] = ACTIONS(4142),
    [anon_sym_always] = ACTIONS(4142),
    [anon_sym_covergroup] = ACTIONS(4142),
    [anon_sym_end] = ACTIONS(4142),
    [anon_sym_let] = ACTIONS(4142),
    [anon_sym_pulldown] = ACTIONS(4142),
    [anon_sym_pullup] = ACTIONS(4142),
    [anon_sym_cmos] = ACTIONS(4142),
    [anon_sym_rcmos] = ACTIONS(4142),
    [anon_sym_bufif0] = ACTIONS(4142),
    [anon_sym_bufif1] = ACTIONS(4142),
    [anon_sym_notif0] = ACTIONS(4142),
    [anon_sym_notif1] = ACTIONS(4142),
    [anon_sym_nmos] = ACTIONS(4142),
    [anon_sym_pmos] = ACTIONS(4142),
    [anon_sym_rnmos] = ACTIONS(4142),
    [anon_sym_rpmos] = ACTIONS(4142),
    [anon_sym_nand] = ACTIONS(4142),
    [anon_sym_nor] = ACTIONS(4142),
    [anon_sym_xor] = ACTIONS(4142),
    [anon_sym_xnor] = ACTIONS(4142),
    [anon_sym_buf] = ACTIONS(4142),
    [anon_sym_tranif0] = ACTIONS(4142),
    [anon_sym_tranif1] = ACTIONS(4142),
    [anon_sym_rtranif1] = ACTIONS(4142),
    [anon_sym_rtranif0] = ACTIONS(4142),
    [anon_sym_tran] = ACTIONS(4142),
    [anon_sym_rtran] = ACTIONS(4142),
    [anon_sym_generate] = ACTIONS(4142),
    [anon_sym_for] = ACTIONS(4142),
    [anon_sym_initial] = ACTIONS(4142),
    [anon_sym_assign] = ACTIONS(4142),
    [anon_sym_alias] = ACTIONS(4142),
    [anon_sym_always_comb] = ACTIONS(4142),
    [anon_sym_always_latch] = ACTIONS(4142),
    [anon_sym_always_ff] = ACTIONS(4142),
    [anon_sym_final] = ACTIONS(4142),
    [anon_sym_global] = ACTIONS(4142),
    [anon_sym_LPAREN_STAR] = ACTIONS(4140),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4140),
    [anon_sym_DOLLARunit] = ACTIONS(4140),
  },
  [5058] = {
    [sym_simple_identifier] = ACTIONS(6299),
    [anon_sym_wire] = ACTIONS(6299),
    [anon_sym_tri] = ACTIONS(6299),
    [anon_sym_tri0] = ACTIONS(6299),
    [anon_sym_tri1] = ACTIONS(6299),
    [anon_sym_wand] = ACTIONS(6299),
    [anon_sym_triand] = ACTIONS(6299),
    [anon_sym_wor] = ACTIONS(6299),
    [anon_sym_trior] = ACTIONS(6299),
    [anon_sym_trireg] = ACTIONS(6299),
    [anon_sym_uwire] = ACTIONS(6299),
    [anon_sym_SEMI] = ACTIONS(6301),
    [anon_sym_extern] = ACTIONS(6299),
    [anon_sym_interface] = ACTIONS(6299),
    [anon_sym_checker] = ACTIONS(6299),
    [anon_sym_virtual] = ACTIONS(6299),
    [anon_sym_class] = ACTIONS(6299),
    [anon_sym_type] = ACTIONS(6299),
    [anon_sym_DOLLARfatal] = ACTIONS(6301),
    [anon_sym_DOLLARerror] = ACTIONS(6301),
    [anon_sym_DOLLARwarning] = ACTIONS(6301),
    [anon_sym_DOLLARinfo] = ACTIONS(6301),
    [anon_sym_default] = ACTIONS(6299),
    [anon_sym_clocking] = ACTIONS(6299),
    [anon_sym_defparam] = ACTIONS(6299),
    [anon_sym_bind] = ACTIONS(6299),
    [anon_sym_rand] = ACTIONS(6299),
    [anon_sym_const] = ACTIONS(6299),
    [anon_sym_function] = ACTIONS(6299),
    [anon_sym_static] = ACTIONS(6299),
    [anon_sym_constraint] = ACTIONS(6299),
    [anon_sym_if] = ACTIONS(6299),
    [anon_sym_else] = ACTIONS(6299),
    [anon_sym_LBRACK] = ACTIONS(6301),
    [anon_sym_localparam] = ACTIONS(6299),
    [anon_sym_parameter] = ACTIONS(6299),
    [anon_sym_var] = ACTIONS(6299),
    [anon_sym_import] = ACTIONS(6299),
    [anon_sym_export] = ACTIONS(6299),
    [anon_sym_genvar] = ACTIONS(6299),
    [anon_sym_interconnect] = ACTIONS(6299),
    [anon_sym_typedef] = ACTIONS(6299),
    [anon_sym_enum] = ACTIONS(6299),
    [anon_sym_struct] = ACTIONS(6299),
    [anon_sym_union] = ACTIONS(6299),
    [anon_sym_nettype] = ACTIONS(6299),
    [anon_sym_automatic] = ACTIONS(6299),
    [anon_sym_string] = ACTIONS(6299),
    [anon_sym_chandle] = ACTIONS(6299),
    [anon_sym_event] = ACTIONS(6299),
    [anon_sym_byte] = ACTIONS(6299),
    [anon_sym_shortint] = ACTIONS(6299),
    [anon_sym_int] = ACTIONS(6299),
    [anon_sym_longint] = ACTIONS(6299),
    [anon_sym_integer] = ACTIONS(6299),
    [anon_sym_time] = ACTIONS(6299),
    [anon_sym_bit] = ACTIONS(6299),
    [anon_sym_logic] = ACTIONS(6299),
    [anon_sym_reg] = ACTIONS(6299),
    [anon_sym_shortreal] = ACTIONS(6299),
    [anon_sym_real] = ACTIONS(6299),
    [anon_sym_realtime] = ACTIONS(6299),
    [anon_sym_supply0] = ACTIONS(6299),
    [anon_sym_supply1] = ACTIONS(6299),
    [anon_sym_signed] = ACTIONS(6299),
    [anon_sym_unsigned] = ACTIONS(6299),
    [anon_sym_task] = ACTIONS(6299),
    [anon_sym_assert] = ACTIONS(6299),
    [anon_sym_property] = ACTIONS(6299),
    [anon_sym_assume] = ACTIONS(6299),
    [anon_sym_cover] = ACTIONS(6299),
    [anon_sym_sequence] = ACTIONS(6299),
    [anon_sym_restrict] = ACTIONS(6299),
    [anon_sym_not] = ACTIONS(6299),
    [anon_sym_or] = ACTIONS(6299),
    [anon_sym_and] = ACTIONS(6299),
    [anon_sym_case] = ACTIONS(6299),
    [anon_sym_always] = ACTIONS(6299),
    [anon_sym_covergroup] = ACTIONS(6299),
    [anon_sym_let] = ACTIONS(6299),
    [anon_sym_pulldown] = ACTIONS(6299),
    [anon_sym_pullup] = ACTIONS(6299),
    [anon_sym_cmos] = ACTIONS(6299),
    [anon_sym_rcmos] = ACTIONS(6299),
    [anon_sym_bufif0] = ACTIONS(6299),
    [anon_sym_bufif1] = ACTIONS(6299),
    [anon_sym_notif0] = ACTIONS(6299),
    [anon_sym_notif1] = ACTIONS(6299),
    [anon_sym_nmos] = ACTIONS(6299),
    [anon_sym_pmos] = ACTIONS(6299),
    [anon_sym_rnmos] = ACTIONS(6299),
    [anon_sym_rpmos] = ACTIONS(6299),
    [anon_sym_nand] = ACTIONS(6299),
    [anon_sym_nor] = ACTIONS(6299),
    [anon_sym_xor] = ACTIONS(6299),
    [anon_sym_xnor] = ACTIONS(6299),
    [anon_sym_buf] = ACTIONS(6299),
    [anon_sym_tranif0] = ACTIONS(6299),
    [anon_sym_tranif1] = ACTIONS(6299),
    [anon_sym_rtranif1] = ACTIONS(6299),
    [anon_sym_rtranif0] = ACTIONS(6299),
    [anon_sym_tran] = ACTIONS(6299),
    [anon_sym_rtran] = ACTIONS(6299),
    [anon_sym_generate] = ACTIONS(6299),
    [anon_sym_endgenerate] = ACTIONS(6299),
    [anon_sym_for] = ACTIONS(6299),
    [anon_sym_initial] = ACTIONS(6299),
    [anon_sym_assign] = ACTIONS(6299),
    [anon_sym_alias] = ACTIONS(6299),
    [anon_sym_always_comb] = ACTIONS(6299),
    [anon_sym_always_latch] = ACTIONS(6299),
    [anon_sym_always_ff] = ACTIONS(6299),
    [anon_sym_final] = ACTIONS(6299),
    [anon_sym_global] = ACTIONS(6299),
    [anon_sym_LPAREN_STAR] = ACTIONS(6301),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6301),
    [anon_sym_DOLLARunit] = ACTIONS(6301),
  },
  [5059] = {
    [sym_simple_identifier] = ACTIONS(6705),
    [anon_sym_wire] = ACTIONS(6705),
    [anon_sym_tri] = ACTIONS(6705),
    [anon_sym_tri0] = ACTIONS(6705),
    [anon_sym_tri1] = ACTIONS(6705),
    [anon_sym_wand] = ACTIONS(6705),
    [anon_sym_triand] = ACTIONS(6705),
    [anon_sym_wor] = ACTIONS(6705),
    [anon_sym_trior] = ACTIONS(6705),
    [anon_sym_trireg] = ACTIONS(6705),
    [anon_sym_uwire] = ACTIONS(6705),
    [anon_sym_SEMI] = ACTIONS(6707),
    [anon_sym_extern] = ACTIONS(6705),
    [anon_sym_interface] = ACTIONS(6705),
    [anon_sym_checker] = ACTIONS(6705),
    [anon_sym_virtual] = ACTIONS(6705),
    [anon_sym_class] = ACTIONS(6705),
    [anon_sym_type] = ACTIONS(6705),
    [anon_sym_DOLLARfatal] = ACTIONS(6707),
    [anon_sym_DOLLARerror] = ACTIONS(6707),
    [anon_sym_DOLLARwarning] = ACTIONS(6707),
    [anon_sym_DOLLARinfo] = ACTIONS(6707),
    [anon_sym_default] = ACTIONS(6705),
    [anon_sym_clocking] = ACTIONS(6705),
    [anon_sym_defparam] = ACTIONS(6705),
    [anon_sym_bind] = ACTIONS(6705),
    [anon_sym_rand] = ACTIONS(6705),
    [anon_sym_const] = ACTIONS(6705),
    [anon_sym_function] = ACTIONS(6705),
    [anon_sym_static] = ACTIONS(6705),
    [anon_sym_constraint] = ACTIONS(6705),
    [anon_sym_if] = ACTIONS(6705),
    [anon_sym_else] = ACTIONS(6705),
    [anon_sym_LBRACK] = ACTIONS(6707),
    [anon_sym_localparam] = ACTIONS(6705),
    [anon_sym_parameter] = ACTIONS(6705),
    [anon_sym_var] = ACTIONS(6705),
    [anon_sym_import] = ACTIONS(6705),
    [anon_sym_export] = ACTIONS(6705),
    [anon_sym_genvar] = ACTIONS(6705),
    [anon_sym_interconnect] = ACTIONS(6705),
    [anon_sym_typedef] = ACTIONS(6705),
    [anon_sym_enum] = ACTIONS(6705),
    [anon_sym_struct] = ACTIONS(6705),
    [anon_sym_union] = ACTIONS(6705),
    [anon_sym_nettype] = ACTIONS(6705),
    [anon_sym_automatic] = ACTIONS(6705),
    [anon_sym_string] = ACTIONS(6705),
    [anon_sym_chandle] = ACTIONS(6705),
    [anon_sym_event] = ACTIONS(6705),
    [anon_sym_byte] = ACTIONS(6705),
    [anon_sym_shortint] = ACTIONS(6705),
    [anon_sym_int] = ACTIONS(6705),
    [anon_sym_longint] = ACTIONS(6705),
    [anon_sym_integer] = ACTIONS(6705),
    [anon_sym_time] = ACTIONS(6705),
    [anon_sym_bit] = ACTIONS(6705),
    [anon_sym_logic] = ACTIONS(6705),
    [anon_sym_reg] = ACTIONS(6705),
    [anon_sym_shortreal] = ACTIONS(6705),
    [anon_sym_real] = ACTIONS(6705),
    [anon_sym_realtime] = ACTIONS(6705),
    [anon_sym_supply0] = ACTIONS(6705),
    [anon_sym_supply1] = ACTIONS(6705),
    [anon_sym_signed] = ACTIONS(6705),
    [anon_sym_unsigned] = ACTIONS(6705),
    [anon_sym_task] = ACTIONS(6705),
    [anon_sym_assert] = ACTIONS(6705),
    [anon_sym_property] = ACTIONS(6705),
    [anon_sym_assume] = ACTIONS(6705),
    [anon_sym_cover] = ACTIONS(6705),
    [anon_sym_sequence] = ACTIONS(6705),
    [anon_sym_restrict] = ACTIONS(6705),
    [anon_sym_not] = ACTIONS(6705),
    [anon_sym_or] = ACTIONS(6705),
    [anon_sym_and] = ACTIONS(6705),
    [anon_sym_case] = ACTIONS(6705),
    [anon_sym_always] = ACTIONS(6705),
    [anon_sym_covergroup] = ACTIONS(6705),
    [anon_sym_end] = ACTIONS(6705),
    [anon_sym_let] = ACTIONS(6705),
    [anon_sym_pulldown] = ACTIONS(6705),
    [anon_sym_pullup] = ACTIONS(6705),
    [anon_sym_cmos] = ACTIONS(6705),
    [anon_sym_rcmos] = ACTIONS(6705),
    [anon_sym_bufif0] = ACTIONS(6705),
    [anon_sym_bufif1] = ACTIONS(6705),
    [anon_sym_notif0] = ACTIONS(6705),
    [anon_sym_notif1] = ACTIONS(6705),
    [anon_sym_nmos] = ACTIONS(6705),
    [anon_sym_pmos] = ACTIONS(6705),
    [anon_sym_rnmos] = ACTIONS(6705),
    [anon_sym_rpmos] = ACTIONS(6705),
    [anon_sym_nand] = ACTIONS(6705),
    [anon_sym_nor] = ACTIONS(6705),
    [anon_sym_xor] = ACTIONS(6705),
    [anon_sym_xnor] = ACTIONS(6705),
    [anon_sym_buf] = ACTIONS(6705),
    [anon_sym_tranif0] = ACTIONS(6705),
    [anon_sym_tranif1] = ACTIONS(6705),
    [anon_sym_rtranif1] = ACTIONS(6705),
    [anon_sym_rtranif0] = ACTIONS(6705),
    [anon_sym_tran] = ACTIONS(6705),
    [anon_sym_rtran] = ACTIONS(6705),
    [anon_sym_generate] = ACTIONS(6705),
    [anon_sym_for] = ACTIONS(6705),
    [anon_sym_initial] = ACTIONS(6705),
    [anon_sym_assign] = ACTIONS(6705),
    [anon_sym_alias] = ACTIONS(6705),
    [anon_sym_always_comb] = ACTIONS(6705),
    [anon_sym_always_latch] = ACTIONS(6705),
    [anon_sym_always_ff] = ACTIONS(6705),
    [anon_sym_final] = ACTIONS(6705),
    [anon_sym_global] = ACTIONS(6705),
    [anon_sym_LPAREN_STAR] = ACTIONS(6707),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6707),
    [anon_sym_DOLLARunit] = ACTIONS(6707),
  },
  [5060] = {
    [sym_simple_identifier] = ACTIONS(4322),
    [anon_sym_wire] = ACTIONS(4322),
    [anon_sym_tri] = ACTIONS(4322),
    [anon_sym_tri0] = ACTIONS(4322),
    [anon_sym_tri1] = ACTIONS(4322),
    [anon_sym_wand] = ACTIONS(4322),
    [anon_sym_triand] = ACTIONS(4322),
    [anon_sym_wor] = ACTIONS(4322),
    [anon_sym_trior] = ACTIONS(4322),
    [anon_sym_trireg] = ACTIONS(4322),
    [anon_sym_uwire] = ACTIONS(4322),
    [anon_sym_SEMI] = ACTIONS(4320),
    [anon_sym_extern] = ACTIONS(4322),
    [anon_sym_interface] = ACTIONS(4322),
    [anon_sym_checker] = ACTIONS(4322),
    [anon_sym_virtual] = ACTIONS(4322),
    [anon_sym_class] = ACTIONS(4322),
    [anon_sym_type] = ACTIONS(4322),
    [anon_sym_DOLLARfatal] = ACTIONS(4320),
    [anon_sym_DOLLARerror] = ACTIONS(4320),
    [anon_sym_DOLLARwarning] = ACTIONS(4320),
    [anon_sym_DOLLARinfo] = ACTIONS(4320),
    [anon_sym_default] = ACTIONS(4322),
    [anon_sym_clocking] = ACTIONS(4322),
    [anon_sym_defparam] = ACTIONS(4322),
    [anon_sym_bind] = ACTIONS(4322),
    [anon_sym_rand] = ACTIONS(4322),
    [anon_sym_const] = ACTIONS(4322),
    [anon_sym_function] = ACTIONS(4322),
    [anon_sym_static] = ACTIONS(4322),
    [anon_sym_constraint] = ACTIONS(4322),
    [anon_sym_if] = ACTIONS(4322),
    [anon_sym_else] = ACTIONS(4322),
    [anon_sym_LBRACK] = ACTIONS(4320),
    [anon_sym_localparam] = ACTIONS(4322),
    [anon_sym_parameter] = ACTIONS(4322),
    [anon_sym_var] = ACTIONS(4322),
    [anon_sym_import] = ACTIONS(4322),
    [anon_sym_export] = ACTIONS(4322),
    [anon_sym_genvar] = ACTIONS(4322),
    [anon_sym_interconnect] = ACTIONS(4322),
    [anon_sym_typedef] = ACTIONS(4322),
    [anon_sym_enum] = ACTIONS(4322),
    [anon_sym_struct] = ACTIONS(4322),
    [anon_sym_union] = ACTIONS(4322),
    [anon_sym_nettype] = ACTIONS(4322),
    [anon_sym_automatic] = ACTIONS(4322),
    [anon_sym_string] = ACTIONS(4322),
    [anon_sym_chandle] = ACTIONS(4322),
    [anon_sym_event] = ACTIONS(4322),
    [anon_sym_byte] = ACTIONS(4322),
    [anon_sym_shortint] = ACTIONS(4322),
    [anon_sym_int] = ACTIONS(4322),
    [anon_sym_longint] = ACTIONS(4322),
    [anon_sym_integer] = ACTIONS(4322),
    [anon_sym_time] = ACTIONS(4322),
    [anon_sym_bit] = ACTIONS(4322),
    [anon_sym_logic] = ACTIONS(4322),
    [anon_sym_reg] = ACTIONS(4322),
    [anon_sym_shortreal] = ACTIONS(4322),
    [anon_sym_real] = ACTIONS(4322),
    [anon_sym_realtime] = ACTIONS(4322),
    [anon_sym_supply0] = ACTIONS(4322),
    [anon_sym_supply1] = ACTIONS(4322),
    [anon_sym_signed] = ACTIONS(4322),
    [anon_sym_unsigned] = ACTIONS(4322),
    [anon_sym_task] = ACTIONS(4322),
    [anon_sym_assert] = ACTIONS(4322),
    [anon_sym_property] = ACTIONS(4322),
    [anon_sym_assume] = ACTIONS(4322),
    [anon_sym_cover] = ACTIONS(4322),
    [anon_sym_sequence] = ACTIONS(4322),
    [anon_sym_restrict] = ACTIONS(4322),
    [anon_sym_not] = ACTIONS(4322),
    [anon_sym_or] = ACTIONS(4322),
    [anon_sym_and] = ACTIONS(4322),
    [anon_sym_case] = ACTIONS(4322),
    [anon_sym_always] = ACTIONS(4322),
    [anon_sym_covergroup] = ACTIONS(4322),
    [anon_sym_end] = ACTIONS(4322),
    [anon_sym_let] = ACTIONS(4322),
    [anon_sym_pulldown] = ACTIONS(4322),
    [anon_sym_pullup] = ACTIONS(4322),
    [anon_sym_cmos] = ACTIONS(4322),
    [anon_sym_rcmos] = ACTIONS(4322),
    [anon_sym_bufif0] = ACTIONS(4322),
    [anon_sym_bufif1] = ACTIONS(4322),
    [anon_sym_notif0] = ACTIONS(4322),
    [anon_sym_notif1] = ACTIONS(4322),
    [anon_sym_nmos] = ACTIONS(4322),
    [anon_sym_pmos] = ACTIONS(4322),
    [anon_sym_rnmos] = ACTIONS(4322),
    [anon_sym_rpmos] = ACTIONS(4322),
    [anon_sym_nand] = ACTIONS(4322),
    [anon_sym_nor] = ACTIONS(4322),
    [anon_sym_xor] = ACTIONS(4322),
    [anon_sym_xnor] = ACTIONS(4322),
    [anon_sym_buf] = ACTIONS(4322),
    [anon_sym_tranif0] = ACTIONS(4322),
    [anon_sym_tranif1] = ACTIONS(4322),
    [anon_sym_rtranif1] = ACTIONS(4322),
    [anon_sym_rtranif0] = ACTIONS(4322),
    [anon_sym_tran] = ACTIONS(4322),
    [anon_sym_rtran] = ACTIONS(4322),
    [anon_sym_generate] = ACTIONS(4322),
    [anon_sym_for] = ACTIONS(4322),
    [anon_sym_initial] = ACTIONS(4322),
    [anon_sym_assign] = ACTIONS(4322),
    [anon_sym_alias] = ACTIONS(4322),
    [anon_sym_always_comb] = ACTIONS(4322),
    [anon_sym_always_latch] = ACTIONS(4322),
    [anon_sym_always_ff] = ACTIONS(4322),
    [anon_sym_final] = ACTIONS(4322),
    [anon_sym_global] = ACTIONS(4322),
    [anon_sym_LPAREN_STAR] = ACTIONS(4320),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4320),
    [anon_sym_DOLLARunit] = ACTIONS(4320),
  },
  [5061] = {
    [sym_simple_identifier] = ACTIONS(5366),
    [anon_sym_wire] = ACTIONS(5366),
    [anon_sym_tri] = ACTIONS(5366),
    [anon_sym_tri0] = ACTIONS(5366),
    [anon_sym_tri1] = ACTIONS(5366),
    [anon_sym_wand] = ACTIONS(5366),
    [anon_sym_triand] = ACTIONS(5366),
    [anon_sym_wor] = ACTIONS(5366),
    [anon_sym_trior] = ACTIONS(5366),
    [anon_sym_trireg] = ACTIONS(5366),
    [anon_sym_uwire] = ACTIONS(5366),
    [anon_sym_SEMI] = ACTIONS(5364),
    [anon_sym_extern] = ACTIONS(5366),
    [anon_sym_interface] = ACTIONS(5366),
    [anon_sym_checker] = ACTIONS(5366),
    [anon_sym_virtual] = ACTIONS(5366),
    [anon_sym_class] = ACTIONS(5366),
    [anon_sym_type] = ACTIONS(5366),
    [anon_sym_DOLLARfatal] = ACTIONS(5364),
    [anon_sym_DOLLARerror] = ACTIONS(5364),
    [anon_sym_DOLLARwarning] = ACTIONS(5364),
    [anon_sym_DOLLARinfo] = ACTIONS(5364),
    [anon_sym_default] = ACTIONS(5366),
    [anon_sym_clocking] = ACTIONS(5366),
    [anon_sym_defparam] = ACTIONS(5366),
    [anon_sym_bind] = ACTIONS(5366),
    [anon_sym_rand] = ACTIONS(5366),
    [anon_sym_const] = ACTIONS(5366),
    [anon_sym_function] = ACTIONS(5366),
    [anon_sym_static] = ACTIONS(5366),
    [anon_sym_constraint] = ACTIONS(5366),
    [anon_sym_if] = ACTIONS(5366),
    [anon_sym_else] = ACTIONS(5366),
    [anon_sym_LBRACK] = ACTIONS(5364),
    [anon_sym_localparam] = ACTIONS(5366),
    [anon_sym_parameter] = ACTIONS(5366),
    [anon_sym_var] = ACTIONS(5366),
    [anon_sym_import] = ACTIONS(5366),
    [anon_sym_export] = ACTIONS(5366),
    [anon_sym_genvar] = ACTIONS(5366),
    [anon_sym_interconnect] = ACTIONS(5366),
    [anon_sym_typedef] = ACTIONS(5366),
    [anon_sym_enum] = ACTIONS(5366),
    [anon_sym_struct] = ACTIONS(5366),
    [anon_sym_union] = ACTIONS(5366),
    [anon_sym_nettype] = ACTIONS(5366),
    [anon_sym_automatic] = ACTIONS(5366),
    [anon_sym_string] = ACTIONS(5366),
    [anon_sym_chandle] = ACTIONS(5366),
    [anon_sym_event] = ACTIONS(5366),
    [anon_sym_byte] = ACTIONS(5366),
    [anon_sym_shortint] = ACTIONS(5366),
    [anon_sym_int] = ACTIONS(5366),
    [anon_sym_longint] = ACTIONS(5366),
    [anon_sym_integer] = ACTIONS(5366),
    [anon_sym_time] = ACTIONS(5366),
    [anon_sym_bit] = ACTIONS(5366),
    [anon_sym_logic] = ACTIONS(5366),
    [anon_sym_reg] = ACTIONS(5366),
    [anon_sym_shortreal] = ACTIONS(5366),
    [anon_sym_real] = ACTIONS(5366),
    [anon_sym_realtime] = ACTIONS(5366),
    [anon_sym_supply0] = ACTIONS(5366),
    [anon_sym_supply1] = ACTIONS(5366),
    [anon_sym_signed] = ACTIONS(5366),
    [anon_sym_unsigned] = ACTIONS(5366),
    [anon_sym_task] = ACTIONS(5366),
    [anon_sym_assert] = ACTIONS(5366),
    [anon_sym_property] = ACTIONS(5366),
    [anon_sym_assume] = ACTIONS(5366),
    [anon_sym_cover] = ACTIONS(5366),
    [anon_sym_sequence] = ACTIONS(5366),
    [anon_sym_restrict] = ACTIONS(5366),
    [anon_sym_not] = ACTIONS(5366),
    [anon_sym_or] = ACTIONS(5366),
    [anon_sym_and] = ACTIONS(5366),
    [anon_sym_case] = ACTIONS(5366),
    [anon_sym_always] = ACTIONS(5366),
    [anon_sym_covergroup] = ACTIONS(5366),
    [anon_sym_end] = ACTIONS(5366),
    [anon_sym_let] = ACTIONS(5366),
    [anon_sym_pulldown] = ACTIONS(5366),
    [anon_sym_pullup] = ACTIONS(5366),
    [anon_sym_cmos] = ACTIONS(5366),
    [anon_sym_rcmos] = ACTIONS(5366),
    [anon_sym_bufif0] = ACTIONS(5366),
    [anon_sym_bufif1] = ACTIONS(5366),
    [anon_sym_notif0] = ACTIONS(5366),
    [anon_sym_notif1] = ACTIONS(5366),
    [anon_sym_nmos] = ACTIONS(5366),
    [anon_sym_pmos] = ACTIONS(5366),
    [anon_sym_rnmos] = ACTIONS(5366),
    [anon_sym_rpmos] = ACTIONS(5366),
    [anon_sym_nand] = ACTIONS(5366),
    [anon_sym_nor] = ACTIONS(5366),
    [anon_sym_xor] = ACTIONS(5366),
    [anon_sym_xnor] = ACTIONS(5366),
    [anon_sym_buf] = ACTIONS(5366),
    [anon_sym_tranif0] = ACTIONS(5366),
    [anon_sym_tranif1] = ACTIONS(5366),
    [anon_sym_rtranif1] = ACTIONS(5366),
    [anon_sym_rtranif0] = ACTIONS(5366),
    [anon_sym_tran] = ACTIONS(5366),
    [anon_sym_rtran] = ACTIONS(5366),
    [anon_sym_generate] = ACTIONS(5366),
    [anon_sym_for] = ACTIONS(5366),
    [anon_sym_initial] = ACTIONS(5366),
    [anon_sym_assign] = ACTIONS(5366),
    [anon_sym_alias] = ACTIONS(5366),
    [anon_sym_always_comb] = ACTIONS(5366),
    [anon_sym_always_latch] = ACTIONS(5366),
    [anon_sym_always_ff] = ACTIONS(5366),
    [anon_sym_final] = ACTIONS(5366),
    [anon_sym_global] = ACTIONS(5366),
    [anon_sym_LPAREN_STAR] = ACTIONS(5364),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5364),
    [anon_sym_DOLLARunit] = ACTIONS(5364),
  },
  [5062] = {
    [sym_simple_identifier] = ACTIONS(6357),
    [anon_sym_wire] = ACTIONS(6357),
    [anon_sym_tri] = ACTIONS(6357),
    [anon_sym_tri0] = ACTIONS(6357),
    [anon_sym_tri1] = ACTIONS(6357),
    [anon_sym_wand] = ACTIONS(6357),
    [anon_sym_triand] = ACTIONS(6357),
    [anon_sym_wor] = ACTIONS(6357),
    [anon_sym_trior] = ACTIONS(6357),
    [anon_sym_trireg] = ACTIONS(6357),
    [anon_sym_uwire] = ACTIONS(6357),
    [anon_sym_SEMI] = ACTIONS(6359),
    [anon_sym_extern] = ACTIONS(6357),
    [anon_sym_interface] = ACTIONS(6357),
    [anon_sym_checker] = ACTIONS(6357),
    [anon_sym_virtual] = ACTIONS(6357),
    [anon_sym_class] = ACTIONS(6357),
    [anon_sym_type] = ACTIONS(6357),
    [anon_sym_DOLLARfatal] = ACTIONS(6359),
    [anon_sym_DOLLARerror] = ACTIONS(6359),
    [anon_sym_DOLLARwarning] = ACTIONS(6359),
    [anon_sym_DOLLARinfo] = ACTIONS(6359),
    [anon_sym_default] = ACTIONS(6357),
    [anon_sym_clocking] = ACTIONS(6357),
    [anon_sym_defparam] = ACTIONS(6357),
    [anon_sym_bind] = ACTIONS(6357),
    [anon_sym_rand] = ACTIONS(6357),
    [anon_sym_const] = ACTIONS(6357),
    [anon_sym_function] = ACTIONS(6357),
    [anon_sym_static] = ACTIONS(6357),
    [anon_sym_constraint] = ACTIONS(6357),
    [anon_sym_if] = ACTIONS(6357),
    [anon_sym_else] = ACTIONS(6357),
    [anon_sym_LBRACK] = ACTIONS(6359),
    [anon_sym_localparam] = ACTIONS(6357),
    [anon_sym_parameter] = ACTIONS(6357),
    [anon_sym_var] = ACTIONS(6357),
    [anon_sym_import] = ACTIONS(6357),
    [anon_sym_export] = ACTIONS(6357),
    [anon_sym_genvar] = ACTIONS(6357),
    [anon_sym_interconnect] = ACTIONS(6357),
    [anon_sym_typedef] = ACTIONS(6357),
    [anon_sym_enum] = ACTIONS(6357),
    [anon_sym_struct] = ACTIONS(6357),
    [anon_sym_union] = ACTIONS(6357),
    [anon_sym_nettype] = ACTIONS(6357),
    [anon_sym_automatic] = ACTIONS(6357),
    [anon_sym_string] = ACTIONS(6357),
    [anon_sym_chandle] = ACTIONS(6357),
    [anon_sym_event] = ACTIONS(6357),
    [anon_sym_byte] = ACTIONS(6357),
    [anon_sym_shortint] = ACTIONS(6357),
    [anon_sym_int] = ACTIONS(6357),
    [anon_sym_longint] = ACTIONS(6357),
    [anon_sym_integer] = ACTIONS(6357),
    [anon_sym_time] = ACTIONS(6357),
    [anon_sym_bit] = ACTIONS(6357),
    [anon_sym_logic] = ACTIONS(6357),
    [anon_sym_reg] = ACTIONS(6357),
    [anon_sym_shortreal] = ACTIONS(6357),
    [anon_sym_real] = ACTIONS(6357),
    [anon_sym_realtime] = ACTIONS(6357),
    [anon_sym_supply0] = ACTIONS(6357),
    [anon_sym_supply1] = ACTIONS(6357),
    [anon_sym_signed] = ACTIONS(6357),
    [anon_sym_unsigned] = ACTIONS(6357),
    [anon_sym_task] = ACTIONS(6357),
    [anon_sym_assert] = ACTIONS(6357),
    [anon_sym_property] = ACTIONS(6357),
    [anon_sym_assume] = ACTIONS(6357),
    [anon_sym_cover] = ACTIONS(6357),
    [anon_sym_sequence] = ACTIONS(6357),
    [anon_sym_restrict] = ACTIONS(6357),
    [anon_sym_not] = ACTIONS(6357),
    [anon_sym_or] = ACTIONS(6357),
    [anon_sym_and] = ACTIONS(6357),
    [anon_sym_case] = ACTIONS(6357),
    [anon_sym_always] = ACTIONS(6357),
    [anon_sym_covergroup] = ACTIONS(6357),
    [anon_sym_end] = ACTIONS(6357),
    [anon_sym_let] = ACTIONS(6357),
    [anon_sym_pulldown] = ACTIONS(6357),
    [anon_sym_pullup] = ACTIONS(6357),
    [anon_sym_cmos] = ACTIONS(6357),
    [anon_sym_rcmos] = ACTIONS(6357),
    [anon_sym_bufif0] = ACTIONS(6357),
    [anon_sym_bufif1] = ACTIONS(6357),
    [anon_sym_notif0] = ACTIONS(6357),
    [anon_sym_notif1] = ACTIONS(6357),
    [anon_sym_nmos] = ACTIONS(6357),
    [anon_sym_pmos] = ACTIONS(6357),
    [anon_sym_rnmos] = ACTIONS(6357),
    [anon_sym_rpmos] = ACTIONS(6357),
    [anon_sym_nand] = ACTIONS(6357),
    [anon_sym_nor] = ACTIONS(6357),
    [anon_sym_xor] = ACTIONS(6357),
    [anon_sym_xnor] = ACTIONS(6357),
    [anon_sym_buf] = ACTIONS(6357),
    [anon_sym_tranif0] = ACTIONS(6357),
    [anon_sym_tranif1] = ACTIONS(6357),
    [anon_sym_rtranif1] = ACTIONS(6357),
    [anon_sym_rtranif0] = ACTIONS(6357),
    [anon_sym_tran] = ACTIONS(6357),
    [anon_sym_rtran] = ACTIONS(6357),
    [anon_sym_generate] = ACTIONS(6357),
    [anon_sym_for] = ACTIONS(6357),
    [anon_sym_initial] = ACTIONS(6357),
    [anon_sym_assign] = ACTIONS(6357),
    [anon_sym_alias] = ACTIONS(6357),
    [anon_sym_always_comb] = ACTIONS(6357),
    [anon_sym_always_latch] = ACTIONS(6357),
    [anon_sym_always_ff] = ACTIONS(6357),
    [anon_sym_final] = ACTIONS(6357),
    [anon_sym_global] = ACTIONS(6357),
    [anon_sym_LPAREN_STAR] = ACTIONS(6359),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6359),
    [anon_sym_DOLLARunit] = ACTIONS(6359),
  },
  [5063] = {
    [sym_simple_identifier] = ACTIONS(5958),
    [anon_sym_wire] = ACTIONS(5958),
    [anon_sym_tri] = ACTIONS(5958),
    [anon_sym_tri0] = ACTIONS(5958),
    [anon_sym_tri1] = ACTIONS(5958),
    [anon_sym_wand] = ACTIONS(5958),
    [anon_sym_triand] = ACTIONS(5958),
    [anon_sym_wor] = ACTIONS(5958),
    [anon_sym_trior] = ACTIONS(5958),
    [anon_sym_trireg] = ACTIONS(5958),
    [anon_sym_uwire] = ACTIONS(5958),
    [anon_sym_SEMI] = ACTIONS(5960),
    [anon_sym_extern] = ACTIONS(5958),
    [anon_sym_interface] = ACTIONS(5958),
    [anon_sym_checker] = ACTIONS(5958),
    [anon_sym_virtual] = ACTIONS(5958),
    [anon_sym_class] = ACTIONS(5958),
    [anon_sym_type] = ACTIONS(5958),
    [anon_sym_DOLLARfatal] = ACTIONS(5960),
    [anon_sym_DOLLARerror] = ACTIONS(5960),
    [anon_sym_DOLLARwarning] = ACTIONS(5960),
    [anon_sym_DOLLARinfo] = ACTIONS(5960),
    [anon_sym_default] = ACTIONS(5958),
    [anon_sym_clocking] = ACTIONS(5958),
    [anon_sym_defparam] = ACTIONS(5958),
    [anon_sym_bind] = ACTIONS(5958),
    [anon_sym_rand] = ACTIONS(5958),
    [anon_sym_const] = ACTIONS(5958),
    [anon_sym_function] = ACTIONS(5958),
    [anon_sym_static] = ACTIONS(5958),
    [anon_sym_constraint] = ACTIONS(5958),
    [anon_sym_if] = ACTIONS(5958),
    [anon_sym_else] = ACTIONS(5958),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_localparam] = ACTIONS(5958),
    [anon_sym_parameter] = ACTIONS(5958),
    [anon_sym_var] = ACTIONS(5958),
    [anon_sym_import] = ACTIONS(5958),
    [anon_sym_export] = ACTIONS(5958),
    [anon_sym_genvar] = ACTIONS(5958),
    [anon_sym_interconnect] = ACTIONS(5958),
    [anon_sym_typedef] = ACTIONS(5958),
    [anon_sym_enum] = ACTIONS(5958),
    [anon_sym_struct] = ACTIONS(5958),
    [anon_sym_union] = ACTIONS(5958),
    [anon_sym_nettype] = ACTIONS(5958),
    [anon_sym_automatic] = ACTIONS(5958),
    [anon_sym_string] = ACTIONS(5958),
    [anon_sym_chandle] = ACTIONS(5958),
    [anon_sym_event] = ACTIONS(5958),
    [anon_sym_byte] = ACTIONS(5958),
    [anon_sym_shortint] = ACTIONS(5958),
    [anon_sym_int] = ACTIONS(5958),
    [anon_sym_longint] = ACTIONS(5958),
    [anon_sym_integer] = ACTIONS(5958),
    [anon_sym_time] = ACTIONS(5958),
    [anon_sym_bit] = ACTIONS(5958),
    [anon_sym_logic] = ACTIONS(5958),
    [anon_sym_reg] = ACTIONS(5958),
    [anon_sym_shortreal] = ACTIONS(5958),
    [anon_sym_real] = ACTIONS(5958),
    [anon_sym_realtime] = ACTIONS(5958),
    [anon_sym_supply0] = ACTIONS(5958),
    [anon_sym_supply1] = ACTIONS(5958),
    [anon_sym_signed] = ACTIONS(5958),
    [anon_sym_unsigned] = ACTIONS(5958),
    [anon_sym_task] = ACTIONS(5958),
    [anon_sym_assert] = ACTIONS(5958),
    [anon_sym_property] = ACTIONS(5958),
    [anon_sym_assume] = ACTIONS(5958),
    [anon_sym_cover] = ACTIONS(5958),
    [anon_sym_sequence] = ACTIONS(5958),
    [anon_sym_restrict] = ACTIONS(5958),
    [anon_sym_not] = ACTIONS(5958),
    [anon_sym_or] = ACTIONS(5958),
    [anon_sym_and] = ACTIONS(5958),
    [anon_sym_case] = ACTIONS(5958),
    [anon_sym_always] = ACTIONS(5958),
    [anon_sym_covergroup] = ACTIONS(5958),
    [anon_sym_let] = ACTIONS(5958),
    [anon_sym_pulldown] = ACTIONS(5958),
    [anon_sym_pullup] = ACTIONS(5958),
    [anon_sym_cmos] = ACTIONS(5958),
    [anon_sym_rcmos] = ACTIONS(5958),
    [anon_sym_bufif0] = ACTIONS(5958),
    [anon_sym_bufif1] = ACTIONS(5958),
    [anon_sym_notif0] = ACTIONS(5958),
    [anon_sym_notif1] = ACTIONS(5958),
    [anon_sym_nmos] = ACTIONS(5958),
    [anon_sym_pmos] = ACTIONS(5958),
    [anon_sym_rnmos] = ACTIONS(5958),
    [anon_sym_rpmos] = ACTIONS(5958),
    [anon_sym_nand] = ACTIONS(5958),
    [anon_sym_nor] = ACTIONS(5958),
    [anon_sym_xor] = ACTIONS(5958),
    [anon_sym_xnor] = ACTIONS(5958),
    [anon_sym_buf] = ACTIONS(5958),
    [anon_sym_tranif0] = ACTIONS(5958),
    [anon_sym_tranif1] = ACTIONS(5958),
    [anon_sym_rtranif1] = ACTIONS(5958),
    [anon_sym_rtranif0] = ACTIONS(5958),
    [anon_sym_tran] = ACTIONS(5958),
    [anon_sym_rtran] = ACTIONS(5958),
    [anon_sym_generate] = ACTIONS(5958),
    [anon_sym_endgenerate] = ACTIONS(5958),
    [anon_sym_for] = ACTIONS(5958),
    [anon_sym_initial] = ACTIONS(5958),
    [anon_sym_assign] = ACTIONS(5958),
    [anon_sym_alias] = ACTIONS(5958),
    [anon_sym_always_comb] = ACTIONS(5958),
    [anon_sym_always_latch] = ACTIONS(5958),
    [anon_sym_always_ff] = ACTIONS(5958),
    [anon_sym_final] = ACTIONS(5958),
    [anon_sym_global] = ACTIONS(5958),
    [anon_sym_LPAREN_STAR] = ACTIONS(5960),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5960),
    [anon_sym_DOLLARunit] = ACTIONS(5960),
  },
  [5064] = {
    [sym_simple_identifier] = ACTIONS(4836),
    [anon_sym_wire] = ACTIONS(4836),
    [anon_sym_tri] = ACTIONS(4836),
    [anon_sym_tri0] = ACTIONS(4836),
    [anon_sym_tri1] = ACTIONS(4836),
    [anon_sym_wand] = ACTIONS(4836),
    [anon_sym_triand] = ACTIONS(4836),
    [anon_sym_wor] = ACTIONS(4836),
    [anon_sym_trior] = ACTIONS(4836),
    [anon_sym_trireg] = ACTIONS(4836),
    [anon_sym_uwire] = ACTIONS(4836),
    [anon_sym_SEMI] = ACTIONS(4834),
    [anon_sym_extern] = ACTIONS(4836),
    [anon_sym_interface] = ACTIONS(4836),
    [anon_sym_checker] = ACTIONS(4836),
    [anon_sym_virtual] = ACTIONS(4836),
    [anon_sym_class] = ACTIONS(4836),
    [anon_sym_type] = ACTIONS(4836),
    [anon_sym_DOLLARfatal] = ACTIONS(4834),
    [anon_sym_DOLLARerror] = ACTIONS(4834),
    [anon_sym_DOLLARwarning] = ACTIONS(4834),
    [anon_sym_DOLLARinfo] = ACTIONS(4834),
    [anon_sym_default] = ACTIONS(4836),
    [anon_sym_clocking] = ACTIONS(4836),
    [anon_sym_defparam] = ACTIONS(4836),
    [anon_sym_bind] = ACTIONS(4836),
    [anon_sym_rand] = ACTIONS(4836),
    [anon_sym_const] = ACTIONS(4836),
    [anon_sym_function] = ACTIONS(4836),
    [anon_sym_static] = ACTIONS(4836),
    [anon_sym_constraint] = ACTIONS(4836),
    [anon_sym_if] = ACTIONS(4836),
    [anon_sym_else] = ACTIONS(4836),
    [anon_sym_LBRACK] = ACTIONS(4834),
    [anon_sym_localparam] = ACTIONS(4836),
    [anon_sym_parameter] = ACTIONS(4836),
    [anon_sym_var] = ACTIONS(4836),
    [anon_sym_import] = ACTIONS(4836),
    [anon_sym_export] = ACTIONS(4836),
    [anon_sym_genvar] = ACTIONS(4836),
    [anon_sym_interconnect] = ACTIONS(4836),
    [anon_sym_typedef] = ACTIONS(4836),
    [anon_sym_enum] = ACTIONS(4836),
    [anon_sym_struct] = ACTIONS(4836),
    [anon_sym_union] = ACTIONS(4836),
    [anon_sym_nettype] = ACTIONS(4836),
    [anon_sym_automatic] = ACTIONS(4836),
    [anon_sym_string] = ACTIONS(4836),
    [anon_sym_chandle] = ACTIONS(4836),
    [anon_sym_event] = ACTIONS(4836),
    [anon_sym_byte] = ACTIONS(4836),
    [anon_sym_shortint] = ACTIONS(4836),
    [anon_sym_int] = ACTIONS(4836),
    [anon_sym_longint] = ACTIONS(4836),
    [anon_sym_integer] = ACTIONS(4836),
    [anon_sym_time] = ACTIONS(4836),
    [anon_sym_bit] = ACTIONS(4836),
    [anon_sym_logic] = ACTIONS(4836),
    [anon_sym_reg] = ACTIONS(4836),
    [anon_sym_shortreal] = ACTIONS(4836),
    [anon_sym_real] = ACTIONS(4836),
    [anon_sym_realtime] = ACTIONS(4836),
    [anon_sym_supply0] = ACTIONS(4836),
    [anon_sym_supply1] = ACTIONS(4836),
    [anon_sym_signed] = ACTIONS(4836),
    [anon_sym_unsigned] = ACTIONS(4836),
    [anon_sym_task] = ACTIONS(4836),
    [anon_sym_assert] = ACTIONS(4836),
    [anon_sym_property] = ACTIONS(4836),
    [anon_sym_assume] = ACTIONS(4836),
    [anon_sym_cover] = ACTIONS(4836),
    [anon_sym_sequence] = ACTIONS(4836),
    [anon_sym_restrict] = ACTIONS(4836),
    [anon_sym_not] = ACTIONS(4836),
    [anon_sym_or] = ACTIONS(4836),
    [anon_sym_and] = ACTIONS(4836),
    [anon_sym_case] = ACTIONS(4836),
    [anon_sym_always] = ACTIONS(4836),
    [anon_sym_covergroup] = ACTIONS(4836),
    [anon_sym_end] = ACTIONS(4836),
    [anon_sym_let] = ACTIONS(4836),
    [anon_sym_pulldown] = ACTIONS(4836),
    [anon_sym_pullup] = ACTIONS(4836),
    [anon_sym_cmos] = ACTIONS(4836),
    [anon_sym_rcmos] = ACTIONS(4836),
    [anon_sym_bufif0] = ACTIONS(4836),
    [anon_sym_bufif1] = ACTIONS(4836),
    [anon_sym_notif0] = ACTIONS(4836),
    [anon_sym_notif1] = ACTIONS(4836),
    [anon_sym_nmos] = ACTIONS(4836),
    [anon_sym_pmos] = ACTIONS(4836),
    [anon_sym_rnmos] = ACTIONS(4836),
    [anon_sym_rpmos] = ACTIONS(4836),
    [anon_sym_nand] = ACTIONS(4836),
    [anon_sym_nor] = ACTIONS(4836),
    [anon_sym_xor] = ACTIONS(4836),
    [anon_sym_xnor] = ACTIONS(4836),
    [anon_sym_buf] = ACTIONS(4836),
    [anon_sym_tranif0] = ACTIONS(4836),
    [anon_sym_tranif1] = ACTIONS(4836),
    [anon_sym_rtranif1] = ACTIONS(4836),
    [anon_sym_rtranif0] = ACTIONS(4836),
    [anon_sym_tran] = ACTIONS(4836),
    [anon_sym_rtran] = ACTIONS(4836),
    [anon_sym_generate] = ACTIONS(4836),
    [anon_sym_for] = ACTIONS(4836),
    [anon_sym_initial] = ACTIONS(4836),
    [anon_sym_assign] = ACTIONS(4836),
    [anon_sym_alias] = ACTIONS(4836),
    [anon_sym_always_comb] = ACTIONS(4836),
    [anon_sym_always_latch] = ACTIONS(4836),
    [anon_sym_always_ff] = ACTIONS(4836),
    [anon_sym_final] = ACTIONS(4836),
    [anon_sym_global] = ACTIONS(4836),
    [anon_sym_LPAREN_STAR] = ACTIONS(4834),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4834),
    [anon_sym_DOLLARunit] = ACTIONS(4834),
  },
  [5065] = {
    [sym_simple_identifier] = ACTIONS(6011),
    [anon_sym_wire] = ACTIONS(6011),
    [anon_sym_tri] = ACTIONS(6011),
    [anon_sym_tri0] = ACTIONS(6011),
    [anon_sym_tri1] = ACTIONS(6011),
    [anon_sym_wand] = ACTIONS(6011),
    [anon_sym_triand] = ACTIONS(6011),
    [anon_sym_wor] = ACTIONS(6011),
    [anon_sym_trior] = ACTIONS(6011),
    [anon_sym_trireg] = ACTIONS(6011),
    [anon_sym_uwire] = ACTIONS(6011),
    [anon_sym_SEMI] = ACTIONS(6013),
    [anon_sym_extern] = ACTIONS(6011),
    [anon_sym_interface] = ACTIONS(6011),
    [anon_sym_checker] = ACTIONS(6011),
    [anon_sym_virtual] = ACTIONS(6011),
    [anon_sym_class] = ACTIONS(6011),
    [anon_sym_type] = ACTIONS(6011),
    [anon_sym_DOLLARfatal] = ACTIONS(6013),
    [anon_sym_DOLLARerror] = ACTIONS(6013),
    [anon_sym_DOLLARwarning] = ACTIONS(6013),
    [anon_sym_DOLLARinfo] = ACTIONS(6013),
    [anon_sym_default] = ACTIONS(6011),
    [anon_sym_clocking] = ACTIONS(6011),
    [anon_sym_defparam] = ACTIONS(6011),
    [anon_sym_bind] = ACTIONS(6011),
    [anon_sym_rand] = ACTIONS(6011),
    [anon_sym_const] = ACTIONS(6011),
    [anon_sym_function] = ACTIONS(6011),
    [anon_sym_static] = ACTIONS(6011),
    [anon_sym_constraint] = ACTIONS(6011),
    [anon_sym_if] = ACTIONS(6011),
    [anon_sym_else] = ACTIONS(6011),
    [anon_sym_LBRACK] = ACTIONS(6013),
    [anon_sym_localparam] = ACTIONS(6011),
    [anon_sym_parameter] = ACTIONS(6011),
    [anon_sym_var] = ACTIONS(6011),
    [anon_sym_import] = ACTIONS(6011),
    [anon_sym_export] = ACTIONS(6011),
    [anon_sym_genvar] = ACTIONS(6011),
    [anon_sym_interconnect] = ACTIONS(6011),
    [anon_sym_typedef] = ACTIONS(6011),
    [anon_sym_enum] = ACTIONS(6011),
    [anon_sym_struct] = ACTIONS(6011),
    [anon_sym_union] = ACTIONS(6011),
    [anon_sym_nettype] = ACTIONS(6011),
    [anon_sym_automatic] = ACTIONS(6011),
    [anon_sym_string] = ACTIONS(6011),
    [anon_sym_chandle] = ACTIONS(6011),
    [anon_sym_event] = ACTIONS(6011),
    [anon_sym_byte] = ACTIONS(6011),
    [anon_sym_shortint] = ACTIONS(6011),
    [anon_sym_int] = ACTIONS(6011),
    [anon_sym_longint] = ACTIONS(6011),
    [anon_sym_integer] = ACTIONS(6011),
    [anon_sym_time] = ACTIONS(6011),
    [anon_sym_bit] = ACTIONS(6011),
    [anon_sym_logic] = ACTIONS(6011),
    [anon_sym_reg] = ACTIONS(6011),
    [anon_sym_shortreal] = ACTIONS(6011),
    [anon_sym_real] = ACTIONS(6011),
    [anon_sym_realtime] = ACTIONS(6011),
    [anon_sym_supply0] = ACTIONS(6011),
    [anon_sym_supply1] = ACTIONS(6011),
    [anon_sym_signed] = ACTIONS(6011),
    [anon_sym_unsigned] = ACTIONS(6011),
    [anon_sym_task] = ACTIONS(6011),
    [anon_sym_assert] = ACTIONS(6011),
    [anon_sym_property] = ACTIONS(6011),
    [anon_sym_assume] = ACTIONS(6011),
    [anon_sym_cover] = ACTIONS(6011),
    [anon_sym_sequence] = ACTIONS(6011),
    [anon_sym_restrict] = ACTIONS(6011),
    [anon_sym_not] = ACTIONS(6011),
    [anon_sym_or] = ACTIONS(6011),
    [anon_sym_and] = ACTIONS(6011),
    [anon_sym_case] = ACTIONS(6011),
    [anon_sym_always] = ACTIONS(6011),
    [anon_sym_covergroup] = ACTIONS(6011),
    [anon_sym_let] = ACTIONS(6011),
    [anon_sym_pulldown] = ACTIONS(6011),
    [anon_sym_pullup] = ACTIONS(6011),
    [anon_sym_cmos] = ACTIONS(6011),
    [anon_sym_rcmos] = ACTIONS(6011),
    [anon_sym_bufif0] = ACTIONS(6011),
    [anon_sym_bufif1] = ACTIONS(6011),
    [anon_sym_notif0] = ACTIONS(6011),
    [anon_sym_notif1] = ACTIONS(6011),
    [anon_sym_nmos] = ACTIONS(6011),
    [anon_sym_pmos] = ACTIONS(6011),
    [anon_sym_rnmos] = ACTIONS(6011),
    [anon_sym_rpmos] = ACTIONS(6011),
    [anon_sym_nand] = ACTIONS(6011),
    [anon_sym_nor] = ACTIONS(6011),
    [anon_sym_xor] = ACTIONS(6011),
    [anon_sym_xnor] = ACTIONS(6011),
    [anon_sym_buf] = ACTIONS(6011),
    [anon_sym_tranif0] = ACTIONS(6011),
    [anon_sym_tranif1] = ACTIONS(6011),
    [anon_sym_rtranif1] = ACTIONS(6011),
    [anon_sym_rtranif0] = ACTIONS(6011),
    [anon_sym_tran] = ACTIONS(6011),
    [anon_sym_rtran] = ACTIONS(6011),
    [anon_sym_generate] = ACTIONS(6011),
    [anon_sym_endgenerate] = ACTIONS(6011),
    [anon_sym_for] = ACTIONS(6011),
    [anon_sym_initial] = ACTIONS(6011),
    [anon_sym_assign] = ACTIONS(6011),
    [anon_sym_alias] = ACTIONS(6011),
    [anon_sym_always_comb] = ACTIONS(6011),
    [anon_sym_always_latch] = ACTIONS(6011),
    [anon_sym_always_ff] = ACTIONS(6011),
    [anon_sym_final] = ACTIONS(6011),
    [anon_sym_global] = ACTIONS(6011),
    [anon_sym_LPAREN_STAR] = ACTIONS(6013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6013),
    [anon_sym_DOLLARunit] = ACTIONS(6013),
  },
  [5066] = {
    [sym_simple_identifier] = ACTIONS(5328),
    [anon_sym_wire] = ACTIONS(5328),
    [anon_sym_tri] = ACTIONS(5328),
    [anon_sym_tri0] = ACTIONS(5328),
    [anon_sym_tri1] = ACTIONS(5328),
    [anon_sym_wand] = ACTIONS(5328),
    [anon_sym_triand] = ACTIONS(5328),
    [anon_sym_wor] = ACTIONS(5328),
    [anon_sym_trior] = ACTIONS(5328),
    [anon_sym_trireg] = ACTIONS(5328),
    [anon_sym_uwire] = ACTIONS(5328),
    [anon_sym_SEMI] = ACTIONS(5326),
    [anon_sym_extern] = ACTIONS(5328),
    [anon_sym_interface] = ACTIONS(5328),
    [anon_sym_checker] = ACTIONS(5328),
    [anon_sym_virtual] = ACTIONS(5328),
    [anon_sym_class] = ACTIONS(5328),
    [anon_sym_type] = ACTIONS(5328),
    [anon_sym_DOLLARfatal] = ACTIONS(5326),
    [anon_sym_DOLLARerror] = ACTIONS(5326),
    [anon_sym_DOLLARwarning] = ACTIONS(5326),
    [anon_sym_DOLLARinfo] = ACTIONS(5326),
    [anon_sym_default] = ACTIONS(5328),
    [anon_sym_clocking] = ACTIONS(5328),
    [anon_sym_defparam] = ACTIONS(5328),
    [anon_sym_bind] = ACTIONS(5328),
    [anon_sym_rand] = ACTIONS(5328),
    [anon_sym_const] = ACTIONS(5328),
    [anon_sym_function] = ACTIONS(5328),
    [anon_sym_static] = ACTIONS(5328),
    [anon_sym_constraint] = ACTIONS(5328),
    [anon_sym_if] = ACTIONS(5328),
    [anon_sym_else] = ACTIONS(5328),
    [anon_sym_LBRACK] = ACTIONS(5326),
    [anon_sym_localparam] = ACTIONS(5328),
    [anon_sym_parameter] = ACTIONS(5328),
    [anon_sym_var] = ACTIONS(5328),
    [anon_sym_import] = ACTIONS(5328),
    [anon_sym_export] = ACTIONS(5328),
    [anon_sym_genvar] = ACTIONS(5328),
    [anon_sym_interconnect] = ACTIONS(5328),
    [anon_sym_typedef] = ACTIONS(5328),
    [anon_sym_enum] = ACTIONS(5328),
    [anon_sym_struct] = ACTIONS(5328),
    [anon_sym_union] = ACTIONS(5328),
    [anon_sym_nettype] = ACTIONS(5328),
    [anon_sym_automatic] = ACTIONS(5328),
    [anon_sym_string] = ACTIONS(5328),
    [anon_sym_chandle] = ACTIONS(5328),
    [anon_sym_event] = ACTIONS(5328),
    [anon_sym_byte] = ACTIONS(5328),
    [anon_sym_shortint] = ACTIONS(5328),
    [anon_sym_int] = ACTIONS(5328),
    [anon_sym_longint] = ACTIONS(5328),
    [anon_sym_integer] = ACTIONS(5328),
    [anon_sym_time] = ACTIONS(5328),
    [anon_sym_bit] = ACTIONS(5328),
    [anon_sym_logic] = ACTIONS(5328),
    [anon_sym_reg] = ACTIONS(5328),
    [anon_sym_shortreal] = ACTIONS(5328),
    [anon_sym_real] = ACTIONS(5328),
    [anon_sym_realtime] = ACTIONS(5328),
    [anon_sym_supply0] = ACTIONS(5328),
    [anon_sym_supply1] = ACTIONS(5328),
    [anon_sym_signed] = ACTIONS(5328),
    [anon_sym_unsigned] = ACTIONS(5328),
    [anon_sym_task] = ACTIONS(5328),
    [anon_sym_assert] = ACTIONS(5328),
    [anon_sym_property] = ACTIONS(5328),
    [anon_sym_assume] = ACTIONS(5328),
    [anon_sym_cover] = ACTIONS(5328),
    [anon_sym_sequence] = ACTIONS(5328),
    [anon_sym_restrict] = ACTIONS(5328),
    [anon_sym_not] = ACTIONS(5328),
    [anon_sym_or] = ACTIONS(5328),
    [anon_sym_and] = ACTIONS(5328),
    [anon_sym_case] = ACTIONS(5328),
    [anon_sym_always] = ACTIONS(5328),
    [anon_sym_covergroup] = ACTIONS(5328),
    [anon_sym_let] = ACTIONS(5328),
    [anon_sym_pulldown] = ACTIONS(5328),
    [anon_sym_pullup] = ACTIONS(5328),
    [anon_sym_cmos] = ACTIONS(5328),
    [anon_sym_rcmos] = ACTIONS(5328),
    [anon_sym_bufif0] = ACTIONS(5328),
    [anon_sym_bufif1] = ACTIONS(5328),
    [anon_sym_notif0] = ACTIONS(5328),
    [anon_sym_notif1] = ACTIONS(5328),
    [anon_sym_nmos] = ACTIONS(5328),
    [anon_sym_pmos] = ACTIONS(5328),
    [anon_sym_rnmos] = ACTIONS(5328),
    [anon_sym_rpmos] = ACTIONS(5328),
    [anon_sym_nand] = ACTIONS(5328),
    [anon_sym_nor] = ACTIONS(5328),
    [anon_sym_xor] = ACTIONS(5328),
    [anon_sym_xnor] = ACTIONS(5328),
    [anon_sym_buf] = ACTIONS(5328),
    [anon_sym_tranif0] = ACTIONS(5328),
    [anon_sym_tranif1] = ACTIONS(5328),
    [anon_sym_rtranif1] = ACTIONS(5328),
    [anon_sym_rtranif0] = ACTIONS(5328),
    [anon_sym_tran] = ACTIONS(5328),
    [anon_sym_rtran] = ACTIONS(5328),
    [anon_sym_generate] = ACTIONS(5328),
    [anon_sym_endgenerate] = ACTIONS(5328),
    [anon_sym_for] = ACTIONS(5328),
    [anon_sym_initial] = ACTIONS(5328),
    [anon_sym_assign] = ACTIONS(5328),
    [anon_sym_alias] = ACTIONS(5328),
    [anon_sym_always_comb] = ACTIONS(5328),
    [anon_sym_always_latch] = ACTIONS(5328),
    [anon_sym_always_ff] = ACTIONS(5328),
    [anon_sym_final] = ACTIONS(5328),
    [anon_sym_global] = ACTIONS(5328),
    [anon_sym_LPAREN_STAR] = ACTIONS(5326),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5326),
    [anon_sym_DOLLARunit] = ACTIONS(5326),
  },
  [5067] = {
    [sym_simple_identifier] = ACTIONS(4820),
    [anon_sym_wire] = ACTIONS(4820),
    [anon_sym_tri] = ACTIONS(4820),
    [anon_sym_tri0] = ACTIONS(4820),
    [anon_sym_tri1] = ACTIONS(4820),
    [anon_sym_wand] = ACTIONS(4820),
    [anon_sym_triand] = ACTIONS(4820),
    [anon_sym_wor] = ACTIONS(4820),
    [anon_sym_trior] = ACTIONS(4820),
    [anon_sym_trireg] = ACTIONS(4820),
    [anon_sym_uwire] = ACTIONS(4820),
    [anon_sym_SEMI] = ACTIONS(4818),
    [anon_sym_extern] = ACTIONS(4820),
    [anon_sym_interface] = ACTIONS(4820),
    [anon_sym_checker] = ACTIONS(4820),
    [anon_sym_virtual] = ACTIONS(4820),
    [anon_sym_class] = ACTIONS(4820),
    [anon_sym_type] = ACTIONS(4820),
    [anon_sym_DOLLARfatal] = ACTIONS(4818),
    [anon_sym_DOLLARerror] = ACTIONS(4818),
    [anon_sym_DOLLARwarning] = ACTIONS(4818),
    [anon_sym_DOLLARinfo] = ACTIONS(4818),
    [anon_sym_default] = ACTIONS(4820),
    [anon_sym_clocking] = ACTIONS(4820),
    [anon_sym_defparam] = ACTIONS(4820),
    [anon_sym_bind] = ACTIONS(4820),
    [anon_sym_rand] = ACTIONS(4820),
    [anon_sym_const] = ACTIONS(4820),
    [anon_sym_function] = ACTIONS(4820),
    [anon_sym_static] = ACTIONS(4820),
    [anon_sym_constraint] = ACTIONS(4820),
    [anon_sym_if] = ACTIONS(4820),
    [anon_sym_else] = ACTIONS(4820),
    [anon_sym_LBRACK] = ACTIONS(4818),
    [anon_sym_localparam] = ACTIONS(4820),
    [anon_sym_parameter] = ACTIONS(4820),
    [anon_sym_var] = ACTIONS(4820),
    [anon_sym_import] = ACTIONS(4820),
    [anon_sym_export] = ACTIONS(4820),
    [anon_sym_genvar] = ACTIONS(4820),
    [anon_sym_interconnect] = ACTIONS(4820),
    [anon_sym_typedef] = ACTIONS(4820),
    [anon_sym_enum] = ACTIONS(4820),
    [anon_sym_struct] = ACTIONS(4820),
    [anon_sym_union] = ACTIONS(4820),
    [anon_sym_nettype] = ACTIONS(4820),
    [anon_sym_automatic] = ACTIONS(4820),
    [anon_sym_string] = ACTIONS(4820),
    [anon_sym_chandle] = ACTIONS(4820),
    [anon_sym_event] = ACTIONS(4820),
    [anon_sym_byte] = ACTIONS(4820),
    [anon_sym_shortint] = ACTIONS(4820),
    [anon_sym_int] = ACTIONS(4820),
    [anon_sym_longint] = ACTIONS(4820),
    [anon_sym_integer] = ACTIONS(4820),
    [anon_sym_time] = ACTIONS(4820),
    [anon_sym_bit] = ACTIONS(4820),
    [anon_sym_logic] = ACTIONS(4820),
    [anon_sym_reg] = ACTIONS(4820),
    [anon_sym_shortreal] = ACTIONS(4820),
    [anon_sym_real] = ACTIONS(4820),
    [anon_sym_realtime] = ACTIONS(4820),
    [anon_sym_supply0] = ACTIONS(4820),
    [anon_sym_supply1] = ACTIONS(4820),
    [anon_sym_signed] = ACTIONS(4820),
    [anon_sym_unsigned] = ACTIONS(4820),
    [anon_sym_task] = ACTIONS(4820),
    [anon_sym_assert] = ACTIONS(4820),
    [anon_sym_property] = ACTIONS(4820),
    [anon_sym_assume] = ACTIONS(4820),
    [anon_sym_cover] = ACTIONS(4820),
    [anon_sym_sequence] = ACTIONS(4820),
    [anon_sym_restrict] = ACTIONS(4820),
    [anon_sym_not] = ACTIONS(4820),
    [anon_sym_or] = ACTIONS(4820),
    [anon_sym_and] = ACTIONS(4820),
    [anon_sym_case] = ACTIONS(4820),
    [anon_sym_always] = ACTIONS(4820),
    [anon_sym_covergroup] = ACTIONS(4820),
    [anon_sym_let] = ACTIONS(4820),
    [anon_sym_pulldown] = ACTIONS(4820),
    [anon_sym_pullup] = ACTIONS(4820),
    [anon_sym_cmos] = ACTIONS(4820),
    [anon_sym_rcmos] = ACTIONS(4820),
    [anon_sym_bufif0] = ACTIONS(4820),
    [anon_sym_bufif1] = ACTIONS(4820),
    [anon_sym_notif0] = ACTIONS(4820),
    [anon_sym_notif1] = ACTIONS(4820),
    [anon_sym_nmos] = ACTIONS(4820),
    [anon_sym_pmos] = ACTIONS(4820),
    [anon_sym_rnmos] = ACTIONS(4820),
    [anon_sym_rpmos] = ACTIONS(4820),
    [anon_sym_nand] = ACTIONS(4820),
    [anon_sym_nor] = ACTIONS(4820),
    [anon_sym_xor] = ACTIONS(4820),
    [anon_sym_xnor] = ACTIONS(4820),
    [anon_sym_buf] = ACTIONS(4820),
    [anon_sym_tranif0] = ACTIONS(4820),
    [anon_sym_tranif1] = ACTIONS(4820),
    [anon_sym_rtranif1] = ACTIONS(4820),
    [anon_sym_rtranif0] = ACTIONS(4820),
    [anon_sym_tran] = ACTIONS(4820),
    [anon_sym_rtran] = ACTIONS(4820),
    [anon_sym_generate] = ACTIONS(4820),
    [anon_sym_endgenerate] = ACTIONS(4820),
    [anon_sym_for] = ACTIONS(4820),
    [anon_sym_initial] = ACTIONS(4820),
    [anon_sym_assign] = ACTIONS(4820),
    [anon_sym_alias] = ACTIONS(4820),
    [anon_sym_always_comb] = ACTIONS(4820),
    [anon_sym_always_latch] = ACTIONS(4820),
    [anon_sym_always_ff] = ACTIONS(4820),
    [anon_sym_final] = ACTIONS(4820),
    [anon_sym_global] = ACTIONS(4820),
    [anon_sym_LPAREN_STAR] = ACTIONS(4818),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4818),
    [anon_sym_DOLLARunit] = ACTIONS(4818),
  },
  [5068] = {
    [sym_simple_identifier] = ACTIONS(4364),
    [anon_sym_wire] = ACTIONS(4364),
    [anon_sym_tri] = ACTIONS(4364),
    [anon_sym_tri0] = ACTIONS(4364),
    [anon_sym_tri1] = ACTIONS(4364),
    [anon_sym_wand] = ACTIONS(4364),
    [anon_sym_triand] = ACTIONS(4364),
    [anon_sym_wor] = ACTIONS(4364),
    [anon_sym_trior] = ACTIONS(4364),
    [anon_sym_trireg] = ACTIONS(4364),
    [anon_sym_uwire] = ACTIONS(4364),
    [anon_sym_SEMI] = ACTIONS(4362),
    [anon_sym_extern] = ACTIONS(4364),
    [anon_sym_interface] = ACTIONS(4364),
    [anon_sym_checker] = ACTIONS(4364),
    [anon_sym_virtual] = ACTIONS(4364),
    [anon_sym_class] = ACTIONS(4364),
    [anon_sym_type] = ACTIONS(4364),
    [anon_sym_DOLLARfatal] = ACTIONS(4362),
    [anon_sym_DOLLARerror] = ACTIONS(4362),
    [anon_sym_DOLLARwarning] = ACTIONS(4362),
    [anon_sym_DOLLARinfo] = ACTIONS(4362),
    [anon_sym_default] = ACTIONS(4364),
    [anon_sym_clocking] = ACTIONS(4364),
    [anon_sym_defparam] = ACTIONS(4364),
    [anon_sym_bind] = ACTIONS(4364),
    [anon_sym_rand] = ACTIONS(4364),
    [anon_sym_const] = ACTIONS(4364),
    [anon_sym_function] = ACTIONS(4364),
    [anon_sym_static] = ACTIONS(4364),
    [anon_sym_constraint] = ACTIONS(4364),
    [anon_sym_if] = ACTIONS(4364),
    [anon_sym_else] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4362),
    [anon_sym_localparam] = ACTIONS(4364),
    [anon_sym_parameter] = ACTIONS(4364),
    [anon_sym_var] = ACTIONS(4364),
    [anon_sym_import] = ACTIONS(4364),
    [anon_sym_export] = ACTIONS(4364),
    [anon_sym_genvar] = ACTIONS(4364),
    [anon_sym_interconnect] = ACTIONS(4364),
    [anon_sym_typedef] = ACTIONS(4364),
    [anon_sym_enum] = ACTIONS(4364),
    [anon_sym_struct] = ACTIONS(4364),
    [anon_sym_union] = ACTIONS(4364),
    [anon_sym_nettype] = ACTIONS(4364),
    [anon_sym_automatic] = ACTIONS(4364),
    [anon_sym_string] = ACTIONS(4364),
    [anon_sym_chandle] = ACTIONS(4364),
    [anon_sym_event] = ACTIONS(4364),
    [anon_sym_byte] = ACTIONS(4364),
    [anon_sym_shortint] = ACTIONS(4364),
    [anon_sym_int] = ACTIONS(4364),
    [anon_sym_longint] = ACTIONS(4364),
    [anon_sym_integer] = ACTIONS(4364),
    [anon_sym_time] = ACTIONS(4364),
    [anon_sym_bit] = ACTIONS(4364),
    [anon_sym_logic] = ACTIONS(4364),
    [anon_sym_reg] = ACTIONS(4364),
    [anon_sym_shortreal] = ACTIONS(4364),
    [anon_sym_real] = ACTIONS(4364),
    [anon_sym_realtime] = ACTIONS(4364),
    [anon_sym_supply0] = ACTIONS(4364),
    [anon_sym_supply1] = ACTIONS(4364),
    [anon_sym_signed] = ACTIONS(4364),
    [anon_sym_unsigned] = ACTIONS(4364),
    [anon_sym_task] = ACTIONS(4364),
    [anon_sym_assert] = ACTIONS(4364),
    [anon_sym_property] = ACTIONS(4364),
    [anon_sym_assume] = ACTIONS(4364),
    [anon_sym_cover] = ACTIONS(4364),
    [anon_sym_sequence] = ACTIONS(4364),
    [anon_sym_restrict] = ACTIONS(4364),
    [anon_sym_not] = ACTIONS(4364),
    [anon_sym_or] = ACTIONS(4364),
    [anon_sym_and] = ACTIONS(4364),
    [anon_sym_case] = ACTIONS(4364),
    [anon_sym_always] = ACTIONS(4364),
    [anon_sym_covergroup] = ACTIONS(4364),
    [anon_sym_end] = ACTIONS(4364),
    [anon_sym_let] = ACTIONS(4364),
    [anon_sym_pulldown] = ACTIONS(4364),
    [anon_sym_pullup] = ACTIONS(4364),
    [anon_sym_cmos] = ACTIONS(4364),
    [anon_sym_rcmos] = ACTIONS(4364),
    [anon_sym_bufif0] = ACTIONS(4364),
    [anon_sym_bufif1] = ACTIONS(4364),
    [anon_sym_notif0] = ACTIONS(4364),
    [anon_sym_notif1] = ACTIONS(4364),
    [anon_sym_nmos] = ACTIONS(4364),
    [anon_sym_pmos] = ACTIONS(4364),
    [anon_sym_rnmos] = ACTIONS(4364),
    [anon_sym_rpmos] = ACTIONS(4364),
    [anon_sym_nand] = ACTIONS(4364),
    [anon_sym_nor] = ACTIONS(4364),
    [anon_sym_xor] = ACTIONS(4364),
    [anon_sym_xnor] = ACTIONS(4364),
    [anon_sym_buf] = ACTIONS(4364),
    [anon_sym_tranif0] = ACTIONS(4364),
    [anon_sym_tranif1] = ACTIONS(4364),
    [anon_sym_rtranif1] = ACTIONS(4364),
    [anon_sym_rtranif0] = ACTIONS(4364),
    [anon_sym_tran] = ACTIONS(4364),
    [anon_sym_rtran] = ACTIONS(4364),
    [anon_sym_generate] = ACTIONS(4364),
    [anon_sym_for] = ACTIONS(4364),
    [anon_sym_initial] = ACTIONS(4364),
    [anon_sym_assign] = ACTIONS(4364),
    [anon_sym_alias] = ACTIONS(4364),
    [anon_sym_always_comb] = ACTIONS(4364),
    [anon_sym_always_latch] = ACTIONS(4364),
    [anon_sym_always_ff] = ACTIONS(4364),
    [anon_sym_final] = ACTIONS(4364),
    [anon_sym_global] = ACTIONS(4364),
    [anon_sym_LPAREN_STAR] = ACTIONS(4362),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4362),
    [anon_sym_DOLLARunit] = ACTIONS(4362),
  },
  [5069] = {
    [sym_simple_identifier] = ACTIONS(5262),
    [anon_sym_wire] = ACTIONS(5262),
    [anon_sym_tri] = ACTIONS(5262),
    [anon_sym_tri0] = ACTIONS(5262),
    [anon_sym_tri1] = ACTIONS(5262),
    [anon_sym_wand] = ACTIONS(5262),
    [anon_sym_triand] = ACTIONS(5262),
    [anon_sym_wor] = ACTIONS(5262),
    [anon_sym_trior] = ACTIONS(5262),
    [anon_sym_trireg] = ACTIONS(5262),
    [anon_sym_uwire] = ACTIONS(5262),
    [anon_sym_SEMI] = ACTIONS(5260),
    [anon_sym_extern] = ACTIONS(5262),
    [anon_sym_interface] = ACTIONS(5262),
    [anon_sym_checker] = ACTIONS(5262),
    [anon_sym_virtual] = ACTIONS(5262),
    [anon_sym_class] = ACTIONS(5262),
    [anon_sym_type] = ACTIONS(5262),
    [anon_sym_DOLLARfatal] = ACTIONS(5260),
    [anon_sym_DOLLARerror] = ACTIONS(5260),
    [anon_sym_DOLLARwarning] = ACTIONS(5260),
    [anon_sym_DOLLARinfo] = ACTIONS(5260),
    [anon_sym_default] = ACTIONS(5262),
    [anon_sym_clocking] = ACTIONS(5262),
    [anon_sym_defparam] = ACTIONS(5262),
    [anon_sym_bind] = ACTIONS(5262),
    [anon_sym_rand] = ACTIONS(5262),
    [anon_sym_const] = ACTIONS(5262),
    [anon_sym_function] = ACTIONS(5262),
    [anon_sym_static] = ACTIONS(5262),
    [anon_sym_constraint] = ACTIONS(5262),
    [anon_sym_if] = ACTIONS(5262),
    [anon_sym_else] = ACTIONS(5262),
    [anon_sym_LBRACK] = ACTIONS(5260),
    [anon_sym_localparam] = ACTIONS(5262),
    [anon_sym_parameter] = ACTIONS(5262),
    [anon_sym_var] = ACTIONS(5262),
    [anon_sym_import] = ACTIONS(5262),
    [anon_sym_export] = ACTIONS(5262),
    [anon_sym_genvar] = ACTIONS(5262),
    [anon_sym_interconnect] = ACTIONS(5262),
    [anon_sym_typedef] = ACTIONS(5262),
    [anon_sym_enum] = ACTIONS(5262),
    [anon_sym_struct] = ACTIONS(5262),
    [anon_sym_union] = ACTIONS(5262),
    [anon_sym_nettype] = ACTIONS(5262),
    [anon_sym_automatic] = ACTIONS(5262),
    [anon_sym_string] = ACTIONS(5262),
    [anon_sym_chandle] = ACTIONS(5262),
    [anon_sym_event] = ACTIONS(5262),
    [anon_sym_byte] = ACTIONS(5262),
    [anon_sym_shortint] = ACTIONS(5262),
    [anon_sym_int] = ACTIONS(5262),
    [anon_sym_longint] = ACTIONS(5262),
    [anon_sym_integer] = ACTIONS(5262),
    [anon_sym_time] = ACTIONS(5262),
    [anon_sym_bit] = ACTIONS(5262),
    [anon_sym_logic] = ACTIONS(5262),
    [anon_sym_reg] = ACTIONS(5262),
    [anon_sym_shortreal] = ACTIONS(5262),
    [anon_sym_real] = ACTIONS(5262),
    [anon_sym_realtime] = ACTIONS(5262),
    [anon_sym_supply0] = ACTIONS(5262),
    [anon_sym_supply1] = ACTIONS(5262),
    [anon_sym_signed] = ACTIONS(5262),
    [anon_sym_unsigned] = ACTIONS(5262),
    [anon_sym_task] = ACTIONS(5262),
    [anon_sym_assert] = ACTIONS(5262),
    [anon_sym_property] = ACTIONS(5262),
    [anon_sym_assume] = ACTIONS(5262),
    [anon_sym_cover] = ACTIONS(5262),
    [anon_sym_sequence] = ACTIONS(5262),
    [anon_sym_restrict] = ACTIONS(5262),
    [anon_sym_not] = ACTIONS(5262),
    [anon_sym_or] = ACTIONS(5262),
    [anon_sym_and] = ACTIONS(5262),
    [anon_sym_case] = ACTIONS(5262),
    [anon_sym_always] = ACTIONS(5262),
    [anon_sym_covergroup] = ACTIONS(5262),
    [anon_sym_end] = ACTIONS(5262),
    [anon_sym_let] = ACTIONS(5262),
    [anon_sym_pulldown] = ACTIONS(5262),
    [anon_sym_pullup] = ACTIONS(5262),
    [anon_sym_cmos] = ACTIONS(5262),
    [anon_sym_rcmos] = ACTIONS(5262),
    [anon_sym_bufif0] = ACTIONS(5262),
    [anon_sym_bufif1] = ACTIONS(5262),
    [anon_sym_notif0] = ACTIONS(5262),
    [anon_sym_notif1] = ACTIONS(5262),
    [anon_sym_nmos] = ACTIONS(5262),
    [anon_sym_pmos] = ACTIONS(5262),
    [anon_sym_rnmos] = ACTIONS(5262),
    [anon_sym_rpmos] = ACTIONS(5262),
    [anon_sym_nand] = ACTIONS(5262),
    [anon_sym_nor] = ACTIONS(5262),
    [anon_sym_xor] = ACTIONS(5262),
    [anon_sym_xnor] = ACTIONS(5262),
    [anon_sym_buf] = ACTIONS(5262),
    [anon_sym_tranif0] = ACTIONS(5262),
    [anon_sym_tranif1] = ACTIONS(5262),
    [anon_sym_rtranif1] = ACTIONS(5262),
    [anon_sym_rtranif0] = ACTIONS(5262),
    [anon_sym_tran] = ACTIONS(5262),
    [anon_sym_rtran] = ACTIONS(5262),
    [anon_sym_generate] = ACTIONS(5262),
    [anon_sym_for] = ACTIONS(5262),
    [anon_sym_initial] = ACTIONS(5262),
    [anon_sym_assign] = ACTIONS(5262),
    [anon_sym_alias] = ACTIONS(5262),
    [anon_sym_always_comb] = ACTIONS(5262),
    [anon_sym_always_latch] = ACTIONS(5262),
    [anon_sym_always_ff] = ACTIONS(5262),
    [anon_sym_final] = ACTIONS(5262),
    [anon_sym_global] = ACTIONS(5262),
    [anon_sym_LPAREN_STAR] = ACTIONS(5260),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5260),
    [anon_sym_DOLLARunit] = ACTIONS(5260),
  },
  [5070] = {
    [sym_simple_identifier] = ACTIONS(4484),
    [anon_sym_wire] = ACTIONS(4484),
    [anon_sym_tri] = ACTIONS(4484),
    [anon_sym_tri0] = ACTIONS(4484),
    [anon_sym_tri1] = ACTIONS(4484),
    [anon_sym_wand] = ACTIONS(4484),
    [anon_sym_triand] = ACTIONS(4484),
    [anon_sym_wor] = ACTIONS(4484),
    [anon_sym_trior] = ACTIONS(4484),
    [anon_sym_trireg] = ACTIONS(4484),
    [anon_sym_uwire] = ACTIONS(4484),
    [anon_sym_SEMI] = ACTIONS(4482),
    [anon_sym_extern] = ACTIONS(4484),
    [anon_sym_interface] = ACTIONS(4484),
    [anon_sym_checker] = ACTIONS(4484),
    [anon_sym_virtual] = ACTIONS(4484),
    [anon_sym_class] = ACTIONS(4484),
    [anon_sym_type] = ACTIONS(4484),
    [anon_sym_DOLLARfatal] = ACTIONS(4482),
    [anon_sym_DOLLARerror] = ACTIONS(4482),
    [anon_sym_DOLLARwarning] = ACTIONS(4482),
    [anon_sym_DOLLARinfo] = ACTIONS(4482),
    [anon_sym_default] = ACTIONS(4484),
    [anon_sym_clocking] = ACTIONS(4484),
    [anon_sym_defparam] = ACTIONS(4484),
    [anon_sym_bind] = ACTIONS(4484),
    [anon_sym_rand] = ACTIONS(4484),
    [anon_sym_const] = ACTIONS(4484),
    [anon_sym_function] = ACTIONS(4484),
    [anon_sym_static] = ACTIONS(4484),
    [anon_sym_constraint] = ACTIONS(4484),
    [anon_sym_if] = ACTIONS(4484),
    [anon_sym_else] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4482),
    [anon_sym_localparam] = ACTIONS(4484),
    [anon_sym_parameter] = ACTIONS(4484),
    [anon_sym_var] = ACTIONS(4484),
    [anon_sym_import] = ACTIONS(4484),
    [anon_sym_export] = ACTIONS(4484),
    [anon_sym_genvar] = ACTIONS(4484),
    [anon_sym_interconnect] = ACTIONS(4484),
    [anon_sym_typedef] = ACTIONS(4484),
    [anon_sym_enum] = ACTIONS(4484),
    [anon_sym_struct] = ACTIONS(4484),
    [anon_sym_union] = ACTIONS(4484),
    [anon_sym_nettype] = ACTIONS(4484),
    [anon_sym_automatic] = ACTIONS(4484),
    [anon_sym_string] = ACTIONS(4484),
    [anon_sym_chandle] = ACTIONS(4484),
    [anon_sym_event] = ACTIONS(4484),
    [anon_sym_byte] = ACTIONS(4484),
    [anon_sym_shortint] = ACTIONS(4484),
    [anon_sym_int] = ACTIONS(4484),
    [anon_sym_longint] = ACTIONS(4484),
    [anon_sym_integer] = ACTIONS(4484),
    [anon_sym_time] = ACTIONS(4484),
    [anon_sym_bit] = ACTIONS(4484),
    [anon_sym_logic] = ACTIONS(4484),
    [anon_sym_reg] = ACTIONS(4484),
    [anon_sym_shortreal] = ACTIONS(4484),
    [anon_sym_real] = ACTIONS(4484),
    [anon_sym_realtime] = ACTIONS(4484),
    [anon_sym_supply0] = ACTIONS(4484),
    [anon_sym_supply1] = ACTIONS(4484),
    [anon_sym_signed] = ACTIONS(4484),
    [anon_sym_unsigned] = ACTIONS(4484),
    [anon_sym_task] = ACTIONS(4484),
    [anon_sym_assert] = ACTIONS(4484),
    [anon_sym_property] = ACTIONS(4484),
    [anon_sym_assume] = ACTIONS(4484),
    [anon_sym_cover] = ACTIONS(4484),
    [anon_sym_sequence] = ACTIONS(4484),
    [anon_sym_restrict] = ACTIONS(4484),
    [anon_sym_not] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_case] = ACTIONS(4484),
    [anon_sym_always] = ACTIONS(4484),
    [anon_sym_covergroup] = ACTIONS(4484),
    [anon_sym_end] = ACTIONS(4484),
    [anon_sym_let] = ACTIONS(4484),
    [anon_sym_pulldown] = ACTIONS(4484),
    [anon_sym_pullup] = ACTIONS(4484),
    [anon_sym_cmos] = ACTIONS(4484),
    [anon_sym_rcmos] = ACTIONS(4484),
    [anon_sym_bufif0] = ACTIONS(4484),
    [anon_sym_bufif1] = ACTIONS(4484),
    [anon_sym_notif0] = ACTIONS(4484),
    [anon_sym_notif1] = ACTIONS(4484),
    [anon_sym_nmos] = ACTIONS(4484),
    [anon_sym_pmos] = ACTIONS(4484),
    [anon_sym_rnmos] = ACTIONS(4484),
    [anon_sym_rpmos] = ACTIONS(4484),
    [anon_sym_nand] = ACTIONS(4484),
    [anon_sym_nor] = ACTIONS(4484),
    [anon_sym_xor] = ACTIONS(4484),
    [anon_sym_xnor] = ACTIONS(4484),
    [anon_sym_buf] = ACTIONS(4484),
    [anon_sym_tranif0] = ACTIONS(4484),
    [anon_sym_tranif1] = ACTIONS(4484),
    [anon_sym_rtranif1] = ACTIONS(4484),
    [anon_sym_rtranif0] = ACTIONS(4484),
    [anon_sym_tran] = ACTIONS(4484),
    [anon_sym_rtran] = ACTIONS(4484),
    [anon_sym_generate] = ACTIONS(4484),
    [anon_sym_for] = ACTIONS(4484),
    [anon_sym_initial] = ACTIONS(4484),
    [anon_sym_assign] = ACTIONS(4484),
    [anon_sym_alias] = ACTIONS(4484),
    [anon_sym_always_comb] = ACTIONS(4484),
    [anon_sym_always_latch] = ACTIONS(4484),
    [anon_sym_always_ff] = ACTIONS(4484),
    [anon_sym_final] = ACTIONS(4484),
    [anon_sym_global] = ACTIONS(4484),
    [anon_sym_LPAREN_STAR] = ACTIONS(4482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4482),
    [anon_sym_DOLLARunit] = ACTIONS(4482),
  },
  [5071] = {
    [sym_simple_identifier] = ACTIONS(6015),
    [anon_sym_wire] = ACTIONS(6015),
    [anon_sym_tri] = ACTIONS(6015),
    [anon_sym_tri0] = ACTIONS(6015),
    [anon_sym_tri1] = ACTIONS(6015),
    [anon_sym_wand] = ACTIONS(6015),
    [anon_sym_triand] = ACTIONS(6015),
    [anon_sym_wor] = ACTIONS(6015),
    [anon_sym_trior] = ACTIONS(6015),
    [anon_sym_trireg] = ACTIONS(6015),
    [anon_sym_uwire] = ACTIONS(6015),
    [anon_sym_SEMI] = ACTIONS(6017),
    [anon_sym_extern] = ACTIONS(6015),
    [anon_sym_interface] = ACTIONS(6015),
    [anon_sym_checker] = ACTIONS(6015),
    [anon_sym_virtual] = ACTIONS(6015),
    [anon_sym_class] = ACTIONS(6015),
    [anon_sym_type] = ACTIONS(6015),
    [anon_sym_DOLLARfatal] = ACTIONS(6017),
    [anon_sym_DOLLARerror] = ACTIONS(6017),
    [anon_sym_DOLLARwarning] = ACTIONS(6017),
    [anon_sym_DOLLARinfo] = ACTIONS(6017),
    [anon_sym_default] = ACTIONS(6015),
    [anon_sym_clocking] = ACTIONS(6015),
    [anon_sym_defparam] = ACTIONS(6015),
    [anon_sym_bind] = ACTIONS(6015),
    [anon_sym_rand] = ACTIONS(6015),
    [anon_sym_const] = ACTIONS(6015),
    [anon_sym_function] = ACTIONS(6015),
    [anon_sym_static] = ACTIONS(6015),
    [anon_sym_constraint] = ACTIONS(6015),
    [anon_sym_if] = ACTIONS(6015),
    [anon_sym_else] = ACTIONS(6015),
    [anon_sym_LBRACK] = ACTIONS(6017),
    [anon_sym_localparam] = ACTIONS(6015),
    [anon_sym_parameter] = ACTIONS(6015),
    [anon_sym_var] = ACTIONS(6015),
    [anon_sym_import] = ACTIONS(6015),
    [anon_sym_export] = ACTIONS(6015),
    [anon_sym_genvar] = ACTIONS(6015),
    [anon_sym_interconnect] = ACTIONS(6015),
    [anon_sym_typedef] = ACTIONS(6015),
    [anon_sym_enum] = ACTIONS(6015),
    [anon_sym_struct] = ACTIONS(6015),
    [anon_sym_union] = ACTIONS(6015),
    [anon_sym_nettype] = ACTIONS(6015),
    [anon_sym_automatic] = ACTIONS(6015),
    [anon_sym_string] = ACTIONS(6015),
    [anon_sym_chandle] = ACTIONS(6015),
    [anon_sym_event] = ACTIONS(6015),
    [anon_sym_byte] = ACTIONS(6015),
    [anon_sym_shortint] = ACTIONS(6015),
    [anon_sym_int] = ACTIONS(6015),
    [anon_sym_longint] = ACTIONS(6015),
    [anon_sym_integer] = ACTIONS(6015),
    [anon_sym_time] = ACTIONS(6015),
    [anon_sym_bit] = ACTIONS(6015),
    [anon_sym_logic] = ACTIONS(6015),
    [anon_sym_reg] = ACTIONS(6015),
    [anon_sym_shortreal] = ACTIONS(6015),
    [anon_sym_real] = ACTIONS(6015),
    [anon_sym_realtime] = ACTIONS(6015),
    [anon_sym_supply0] = ACTIONS(6015),
    [anon_sym_supply1] = ACTIONS(6015),
    [anon_sym_signed] = ACTIONS(6015),
    [anon_sym_unsigned] = ACTIONS(6015),
    [anon_sym_task] = ACTIONS(6015),
    [anon_sym_assert] = ACTIONS(6015),
    [anon_sym_property] = ACTIONS(6015),
    [anon_sym_assume] = ACTIONS(6015),
    [anon_sym_cover] = ACTIONS(6015),
    [anon_sym_sequence] = ACTIONS(6015),
    [anon_sym_restrict] = ACTIONS(6015),
    [anon_sym_not] = ACTIONS(6015),
    [anon_sym_or] = ACTIONS(6015),
    [anon_sym_and] = ACTIONS(6015),
    [anon_sym_case] = ACTIONS(6015),
    [anon_sym_always] = ACTIONS(6015),
    [anon_sym_covergroup] = ACTIONS(6015),
    [anon_sym_let] = ACTIONS(6015),
    [anon_sym_pulldown] = ACTIONS(6015),
    [anon_sym_pullup] = ACTIONS(6015),
    [anon_sym_cmos] = ACTIONS(6015),
    [anon_sym_rcmos] = ACTIONS(6015),
    [anon_sym_bufif0] = ACTIONS(6015),
    [anon_sym_bufif1] = ACTIONS(6015),
    [anon_sym_notif0] = ACTIONS(6015),
    [anon_sym_notif1] = ACTIONS(6015),
    [anon_sym_nmos] = ACTIONS(6015),
    [anon_sym_pmos] = ACTIONS(6015),
    [anon_sym_rnmos] = ACTIONS(6015),
    [anon_sym_rpmos] = ACTIONS(6015),
    [anon_sym_nand] = ACTIONS(6015),
    [anon_sym_nor] = ACTIONS(6015),
    [anon_sym_xor] = ACTIONS(6015),
    [anon_sym_xnor] = ACTIONS(6015),
    [anon_sym_buf] = ACTIONS(6015),
    [anon_sym_tranif0] = ACTIONS(6015),
    [anon_sym_tranif1] = ACTIONS(6015),
    [anon_sym_rtranif1] = ACTIONS(6015),
    [anon_sym_rtranif0] = ACTIONS(6015),
    [anon_sym_tran] = ACTIONS(6015),
    [anon_sym_rtran] = ACTIONS(6015),
    [anon_sym_generate] = ACTIONS(6015),
    [anon_sym_endgenerate] = ACTIONS(6015),
    [anon_sym_for] = ACTIONS(6015),
    [anon_sym_initial] = ACTIONS(6015),
    [anon_sym_assign] = ACTIONS(6015),
    [anon_sym_alias] = ACTIONS(6015),
    [anon_sym_always_comb] = ACTIONS(6015),
    [anon_sym_always_latch] = ACTIONS(6015),
    [anon_sym_always_ff] = ACTIONS(6015),
    [anon_sym_final] = ACTIONS(6015),
    [anon_sym_global] = ACTIONS(6015),
    [anon_sym_LPAREN_STAR] = ACTIONS(6017),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6017),
    [anon_sym_DOLLARunit] = ACTIONS(6017),
  },
  [5072] = {
    [sym_simple_identifier] = ACTIONS(6019),
    [anon_sym_wire] = ACTIONS(6019),
    [anon_sym_tri] = ACTIONS(6019),
    [anon_sym_tri0] = ACTIONS(6019),
    [anon_sym_tri1] = ACTIONS(6019),
    [anon_sym_wand] = ACTIONS(6019),
    [anon_sym_triand] = ACTIONS(6019),
    [anon_sym_wor] = ACTIONS(6019),
    [anon_sym_trior] = ACTIONS(6019),
    [anon_sym_trireg] = ACTIONS(6019),
    [anon_sym_uwire] = ACTIONS(6019),
    [anon_sym_SEMI] = ACTIONS(6021),
    [anon_sym_extern] = ACTIONS(6019),
    [anon_sym_interface] = ACTIONS(6019),
    [anon_sym_checker] = ACTIONS(6019),
    [anon_sym_virtual] = ACTIONS(6019),
    [anon_sym_class] = ACTIONS(6019),
    [anon_sym_type] = ACTIONS(6019),
    [anon_sym_DOLLARfatal] = ACTIONS(6021),
    [anon_sym_DOLLARerror] = ACTIONS(6021),
    [anon_sym_DOLLARwarning] = ACTIONS(6021),
    [anon_sym_DOLLARinfo] = ACTIONS(6021),
    [anon_sym_default] = ACTIONS(6019),
    [anon_sym_clocking] = ACTIONS(6019),
    [anon_sym_defparam] = ACTIONS(6019),
    [anon_sym_bind] = ACTIONS(6019),
    [anon_sym_rand] = ACTIONS(6019),
    [anon_sym_const] = ACTIONS(6019),
    [anon_sym_function] = ACTIONS(6019),
    [anon_sym_static] = ACTIONS(6019),
    [anon_sym_constraint] = ACTIONS(6019),
    [anon_sym_if] = ACTIONS(6019),
    [anon_sym_else] = ACTIONS(6019),
    [anon_sym_LBRACK] = ACTIONS(6021),
    [anon_sym_localparam] = ACTIONS(6019),
    [anon_sym_parameter] = ACTIONS(6019),
    [anon_sym_var] = ACTIONS(6019),
    [anon_sym_import] = ACTIONS(6019),
    [anon_sym_export] = ACTIONS(6019),
    [anon_sym_genvar] = ACTIONS(6019),
    [anon_sym_interconnect] = ACTIONS(6019),
    [anon_sym_typedef] = ACTIONS(6019),
    [anon_sym_enum] = ACTIONS(6019),
    [anon_sym_struct] = ACTIONS(6019),
    [anon_sym_union] = ACTIONS(6019),
    [anon_sym_nettype] = ACTIONS(6019),
    [anon_sym_automatic] = ACTIONS(6019),
    [anon_sym_string] = ACTIONS(6019),
    [anon_sym_chandle] = ACTIONS(6019),
    [anon_sym_event] = ACTIONS(6019),
    [anon_sym_byte] = ACTIONS(6019),
    [anon_sym_shortint] = ACTIONS(6019),
    [anon_sym_int] = ACTIONS(6019),
    [anon_sym_longint] = ACTIONS(6019),
    [anon_sym_integer] = ACTIONS(6019),
    [anon_sym_time] = ACTIONS(6019),
    [anon_sym_bit] = ACTIONS(6019),
    [anon_sym_logic] = ACTIONS(6019),
    [anon_sym_reg] = ACTIONS(6019),
    [anon_sym_shortreal] = ACTIONS(6019),
    [anon_sym_real] = ACTIONS(6019),
    [anon_sym_realtime] = ACTIONS(6019),
    [anon_sym_supply0] = ACTIONS(6019),
    [anon_sym_supply1] = ACTIONS(6019),
    [anon_sym_signed] = ACTIONS(6019),
    [anon_sym_unsigned] = ACTIONS(6019),
    [anon_sym_task] = ACTIONS(6019),
    [anon_sym_assert] = ACTIONS(6019),
    [anon_sym_property] = ACTIONS(6019),
    [anon_sym_assume] = ACTIONS(6019),
    [anon_sym_cover] = ACTIONS(6019),
    [anon_sym_sequence] = ACTIONS(6019),
    [anon_sym_restrict] = ACTIONS(6019),
    [anon_sym_not] = ACTIONS(6019),
    [anon_sym_or] = ACTIONS(6019),
    [anon_sym_and] = ACTIONS(6019),
    [anon_sym_case] = ACTIONS(6019),
    [anon_sym_always] = ACTIONS(6019),
    [anon_sym_covergroup] = ACTIONS(6019),
    [anon_sym_let] = ACTIONS(6019),
    [anon_sym_pulldown] = ACTIONS(6019),
    [anon_sym_pullup] = ACTIONS(6019),
    [anon_sym_cmos] = ACTIONS(6019),
    [anon_sym_rcmos] = ACTIONS(6019),
    [anon_sym_bufif0] = ACTIONS(6019),
    [anon_sym_bufif1] = ACTIONS(6019),
    [anon_sym_notif0] = ACTIONS(6019),
    [anon_sym_notif1] = ACTIONS(6019),
    [anon_sym_nmos] = ACTIONS(6019),
    [anon_sym_pmos] = ACTIONS(6019),
    [anon_sym_rnmos] = ACTIONS(6019),
    [anon_sym_rpmos] = ACTIONS(6019),
    [anon_sym_nand] = ACTIONS(6019),
    [anon_sym_nor] = ACTIONS(6019),
    [anon_sym_xor] = ACTIONS(6019),
    [anon_sym_xnor] = ACTIONS(6019),
    [anon_sym_buf] = ACTIONS(6019),
    [anon_sym_tranif0] = ACTIONS(6019),
    [anon_sym_tranif1] = ACTIONS(6019),
    [anon_sym_rtranif1] = ACTIONS(6019),
    [anon_sym_rtranif0] = ACTIONS(6019),
    [anon_sym_tran] = ACTIONS(6019),
    [anon_sym_rtran] = ACTIONS(6019),
    [anon_sym_generate] = ACTIONS(6019),
    [anon_sym_endgenerate] = ACTIONS(6019),
    [anon_sym_for] = ACTIONS(6019),
    [anon_sym_initial] = ACTIONS(6019),
    [anon_sym_assign] = ACTIONS(6019),
    [anon_sym_alias] = ACTIONS(6019),
    [anon_sym_always_comb] = ACTIONS(6019),
    [anon_sym_always_latch] = ACTIONS(6019),
    [anon_sym_always_ff] = ACTIONS(6019),
    [anon_sym_final] = ACTIONS(6019),
    [anon_sym_global] = ACTIONS(6019),
    [anon_sym_LPAREN_STAR] = ACTIONS(6021),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6021),
    [anon_sym_DOLLARunit] = ACTIONS(6021),
  },
  [5073] = {
    [sym_simple_identifier] = ACTIONS(6361),
    [anon_sym_wire] = ACTIONS(6361),
    [anon_sym_tri] = ACTIONS(6361),
    [anon_sym_tri0] = ACTIONS(6361),
    [anon_sym_tri1] = ACTIONS(6361),
    [anon_sym_wand] = ACTIONS(6361),
    [anon_sym_triand] = ACTIONS(6361),
    [anon_sym_wor] = ACTIONS(6361),
    [anon_sym_trior] = ACTIONS(6361),
    [anon_sym_trireg] = ACTIONS(6361),
    [anon_sym_uwire] = ACTIONS(6361),
    [anon_sym_SEMI] = ACTIONS(6363),
    [anon_sym_extern] = ACTIONS(6361),
    [anon_sym_interface] = ACTIONS(6361),
    [anon_sym_checker] = ACTIONS(6361),
    [anon_sym_virtual] = ACTIONS(6361),
    [anon_sym_class] = ACTIONS(6361),
    [anon_sym_type] = ACTIONS(6361),
    [anon_sym_DOLLARfatal] = ACTIONS(6363),
    [anon_sym_DOLLARerror] = ACTIONS(6363),
    [anon_sym_DOLLARwarning] = ACTIONS(6363),
    [anon_sym_DOLLARinfo] = ACTIONS(6363),
    [anon_sym_default] = ACTIONS(6361),
    [anon_sym_clocking] = ACTIONS(6361),
    [anon_sym_defparam] = ACTIONS(6361),
    [anon_sym_bind] = ACTIONS(6361),
    [anon_sym_rand] = ACTIONS(6361),
    [anon_sym_const] = ACTIONS(6361),
    [anon_sym_function] = ACTIONS(6361),
    [anon_sym_static] = ACTIONS(6361),
    [anon_sym_constraint] = ACTIONS(6361),
    [anon_sym_if] = ACTIONS(6361),
    [anon_sym_else] = ACTIONS(6361),
    [anon_sym_LBRACK] = ACTIONS(6363),
    [anon_sym_localparam] = ACTIONS(6361),
    [anon_sym_parameter] = ACTIONS(6361),
    [anon_sym_var] = ACTIONS(6361),
    [anon_sym_import] = ACTIONS(6361),
    [anon_sym_export] = ACTIONS(6361),
    [anon_sym_genvar] = ACTIONS(6361),
    [anon_sym_interconnect] = ACTIONS(6361),
    [anon_sym_typedef] = ACTIONS(6361),
    [anon_sym_enum] = ACTIONS(6361),
    [anon_sym_struct] = ACTIONS(6361),
    [anon_sym_union] = ACTIONS(6361),
    [anon_sym_nettype] = ACTIONS(6361),
    [anon_sym_automatic] = ACTIONS(6361),
    [anon_sym_string] = ACTIONS(6361),
    [anon_sym_chandle] = ACTIONS(6361),
    [anon_sym_event] = ACTIONS(6361),
    [anon_sym_byte] = ACTIONS(6361),
    [anon_sym_shortint] = ACTIONS(6361),
    [anon_sym_int] = ACTIONS(6361),
    [anon_sym_longint] = ACTIONS(6361),
    [anon_sym_integer] = ACTIONS(6361),
    [anon_sym_time] = ACTIONS(6361),
    [anon_sym_bit] = ACTIONS(6361),
    [anon_sym_logic] = ACTIONS(6361),
    [anon_sym_reg] = ACTIONS(6361),
    [anon_sym_shortreal] = ACTIONS(6361),
    [anon_sym_real] = ACTIONS(6361),
    [anon_sym_realtime] = ACTIONS(6361),
    [anon_sym_supply0] = ACTIONS(6361),
    [anon_sym_supply1] = ACTIONS(6361),
    [anon_sym_signed] = ACTIONS(6361),
    [anon_sym_unsigned] = ACTIONS(6361),
    [anon_sym_task] = ACTIONS(6361),
    [anon_sym_assert] = ACTIONS(6361),
    [anon_sym_property] = ACTIONS(6361),
    [anon_sym_assume] = ACTIONS(6361),
    [anon_sym_cover] = ACTIONS(6361),
    [anon_sym_sequence] = ACTIONS(6361),
    [anon_sym_restrict] = ACTIONS(6361),
    [anon_sym_not] = ACTIONS(6361),
    [anon_sym_or] = ACTIONS(6361),
    [anon_sym_and] = ACTIONS(6361),
    [anon_sym_case] = ACTIONS(6361),
    [anon_sym_always] = ACTIONS(6361),
    [anon_sym_covergroup] = ACTIONS(6361),
    [anon_sym_end] = ACTIONS(6361),
    [anon_sym_let] = ACTIONS(6361),
    [anon_sym_pulldown] = ACTIONS(6361),
    [anon_sym_pullup] = ACTIONS(6361),
    [anon_sym_cmos] = ACTIONS(6361),
    [anon_sym_rcmos] = ACTIONS(6361),
    [anon_sym_bufif0] = ACTIONS(6361),
    [anon_sym_bufif1] = ACTIONS(6361),
    [anon_sym_notif0] = ACTIONS(6361),
    [anon_sym_notif1] = ACTIONS(6361),
    [anon_sym_nmos] = ACTIONS(6361),
    [anon_sym_pmos] = ACTIONS(6361),
    [anon_sym_rnmos] = ACTIONS(6361),
    [anon_sym_rpmos] = ACTIONS(6361),
    [anon_sym_nand] = ACTIONS(6361),
    [anon_sym_nor] = ACTIONS(6361),
    [anon_sym_xor] = ACTIONS(6361),
    [anon_sym_xnor] = ACTIONS(6361),
    [anon_sym_buf] = ACTIONS(6361),
    [anon_sym_tranif0] = ACTIONS(6361),
    [anon_sym_tranif1] = ACTIONS(6361),
    [anon_sym_rtranif1] = ACTIONS(6361),
    [anon_sym_rtranif0] = ACTIONS(6361),
    [anon_sym_tran] = ACTIONS(6361),
    [anon_sym_rtran] = ACTIONS(6361),
    [anon_sym_generate] = ACTIONS(6361),
    [anon_sym_for] = ACTIONS(6361),
    [anon_sym_initial] = ACTIONS(6361),
    [anon_sym_assign] = ACTIONS(6361),
    [anon_sym_alias] = ACTIONS(6361),
    [anon_sym_always_comb] = ACTIONS(6361),
    [anon_sym_always_latch] = ACTIONS(6361),
    [anon_sym_always_ff] = ACTIONS(6361),
    [anon_sym_final] = ACTIONS(6361),
    [anon_sym_global] = ACTIONS(6361),
    [anon_sym_LPAREN_STAR] = ACTIONS(6363),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6363),
    [anon_sym_DOLLARunit] = ACTIONS(6363),
  },
  [5074] = {
    [sym_simple_identifier] = ACTIONS(5782),
    [anon_sym_wire] = ACTIONS(5782),
    [anon_sym_tri] = ACTIONS(5782),
    [anon_sym_tri0] = ACTIONS(5782),
    [anon_sym_tri1] = ACTIONS(5782),
    [anon_sym_wand] = ACTIONS(5782),
    [anon_sym_triand] = ACTIONS(5782),
    [anon_sym_wor] = ACTIONS(5782),
    [anon_sym_trior] = ACTIONS(5782),
    [anon_sym_trireg] = ACTIONS(5782),
    [anon_sym_uwire] = ACTIONS(5782),
    [anon_sym_SEMI] = ACTIONS(5784),
    [anon_sym_extern] = ACTIONS(5782),
    [anon_sym_interface] = ACTIONS(5782),
    [anon_sym_checker] = ACTIONS(5782),
    [anon_sym_virtual] = ACTIONS(5782),
    [anon_sym_class] = ACTIONS(5782),
    [anon_sym_type] = ACTIONS(5782),
    [anon_sym_DOLLARfatal] = ACTIONS(5784),
    [anon_sym_DOLLARerror] = ACTIONS(5784),
    [anon_sym_DOLLARwarning] = ACTIONS(5784),
    [anon_sym_DOLLARinfo] = ACTIONS(5784),
    [anon_sym_default] = ACTIONS(5782),
    [anon_sym_clocking] = ACTIONS(5782),
    [anon_sym_defparam] = ACTIONS(5782),
    [anon_sym_bind] = ACTIONS(5782),
    [anon_sym_rand] = ACTIONS(5782),
    [anon_sym_const] = ACTIONS(5782),
    [anon_sym_function] = ACTIONS(5782),
    [anon_sym_static] = ACTIONS(5782),
    [anon_sym_constraint] = ACTIONS(5782),
    [anon_sym_if] = ACTIONS(5782),
    [anon_sym_else] = ACTIONS(5782),
    [anon_sym_LBRACK] = ACTIONS(5784),
    [anon_sym_localparam] = ACTIONS(5782),
    [anon_sym_parameter] = ACTIONS(5782),
    [anon_sym_var] = ACTIONS(5782),
    [anon_sym_import] = ACTIONS(5782),
    [anon_sym_export] = ACTIONS(5782),
    [anon_sym_genvar] = ACTIONS(5782),
    [anon_sym_interconnect] = ACTIONS(5782),
    [anon_sym_typedef] = ACTIONS(5782),
    [anon_sym_enum] = ACTIONS(5782),
    [anon_sym_struct] = ACTIONS(5782),
    [anon_sym_union] = ACTIONS(5782),
    [anon_sym_nettype] = ACTIONS(5782),
    [anon_sym_automatic] = ACTIONS(5782),
    [anon_sym_string] = ACTIONS(5782),
    [anon_sym_chandle] = ACTIONS(5782),
    [anon_sym_event] = ACTIONS(5782),
    [anon_sym_byte] = ACTIONS(5782),
    [anon_sym_shortint] = ACTIONS(5782),
    [anon_sym_int] = ACTIONS(5782),
    [anon_sym_longint] = ACTIONS(5782),
    [anon_sym_integer] = ACTIONS(5782),
    [anon_sym_time] = ACTIONS(5782),
    [anon_sym_bit] = ACTIONS(5782),
    [anon_sym_logic] = ACTIONS(5782),
    [anon_sym_reg] = ACTIONS(5782),
    [anon_sym_shortreal] = ACTIONS(5782),
    [anon_sym_real] = ACTIONS(5782),
    [anon_sym_realtime] = ACTIONS(5782),
    [anon_sym_supply0] = ACTIONS(5782),
    [anon_sym_supply1] = ACTIONS(5782),
    [anon_sym_signed] = ACTIONS(5782),
    [anon_sym_unsigned] = ACTIONS(5782),
    [anon_sym_task] = ACTIONS(5782),
    [anon_sym_assert] = ACTIONS(5782),
    [anon_sym_property] = ACTIONS(5782),
    [anon_sym_assume] = ACTIONS(5782),
    [anon_sym_cover] = ACTIONS(5782),
    [anon_sym_sequence] = ACTIONS(5782),
    [anon_sym_restrict] = ACTIONS(5782),
    [anon_sym_not] = ACTIONS(5782),
    [anon_sym_or] = ACTIONS(5782),
    [anon_sym_and] = ACTIONS(5782),
    [anon_sym_case] = ACTIONS(5782),
    [anon_sym_always] = ACTIONS(5782),
    [anon_sym_covergroup] = ACTIONS(5782),
    [anon_sym_end] = ACTIONS(5782),
    [anon_sym_let] = ACTIONS(5782),
    [anon_sym_pulldown] = ACTIONS(5782),
    [anon_sym_pullup] = ACTIONS(5782),
    [anon_sym_cmos] = ACTIONS(5782),
    [anon_sym_rcmos] = ACTIONS(5782),
    [anon_sym_bufif0] = ACTIONS(5782),
    [anon_sym_bufif1] = ACTIONS(5782),
    [anon_sym_notif0] = ACTIONS(5782),
    [anon_sym_notif1] = ACTIONS(5782),
    [anon_sym_nmos] = ACTIONS(5782),
    [anon_sym_pmos] = ACTIONS(5782),
    [anon_sym_rnmos] = ACTIONS(5782),
    [anon_sym_rpmos] = ACTIONS(5782),
    [anon_sym_nand] = ACTIONS(5782),
    [anon_sym_nor] = ACTIONS(5782),
    [anon_sym_xor] = ACTIONS(5782),
    [anon_sym_xnor] = ACTIONS(5782),
    [anon_sym_buf] = ACTIONS(5782),
    [anon_sym_tranif0] = ACTIONS(5782),
    [anon_sym_tranif1] = ACTIONS(5782),
    [anon_sym_rtranif1] = ACTIONS(5782),
    [anon_sym_rtranif0] = ACTIONS(5782),
    [anon_sym_tran] = ACTIONS(5782),
    [anon_sym_rtran] = ACTIONS(5782),
    [anon_sym_generate] = ACTIONS(5782),
    [anon_sym_for] = ACTIONS(5782),
    [anon_sym_initial] = ACTIONS(5782),
    [anon_sym_assign] = ACTIONS(5782),
    [anon_sym_alias] = ACTIONS(5782),
    [anon_sym_always_comb] = ACTIONS(5782),
    [anon_sym_always_latch] = ACTIONS(5782),
    [anon_sym_always_ff] = ACTIONS(5782),
    [anon_sym_final] = ACTIONS(5782),
    [anon_sym_global] = ACTIONS(5782),
    [anon_sym_LPAREN_STAR] = ACTIONS(5784),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5784),
    [anon_sym_DOLLARunit] = ACTIONS(5784),
  },
  [5075] = {
    [sym_simple_identifier] = ACTIONS(5876),
    [anon_sym_wire] = ACTIONS(5876),
    [anon_sym_tri] = ACTIONS(5876),
    [anon_sym_tri0] = ACTIONS(5876),
    [anon_sym_tri1] = ACTIONS(5876),
    [anon_sym_wand] = ACTIONS(5876),
    [anon_sym_triand] = ACTIONS(5876),
    [anon_sym_wor] = ACTIONS(5876),
    [anon_sym_trior] = ACTIONS(5876),
    [anon_sym_trireg] = ACTIONS(5876),
    [anon_sym_uwire] = ACTIONS(5876),
    [anon_sym_SEMI] = ACTIONS(5878),
    [anon_sym_extern] = ACTIONS(5876),
    [anon_sym_interface] = ACTIONS(5876),
    [anon_sym_checker] = ACTIONS(5876),
    [anon_sym_virtual] = ACTIONS(5876),
    [anon_sym_class] = ACTIONS(5876),
    [anon_sym_type] = ACTIONS(5876),
    [anon_sym_DOLLARfatal] = ACTIONS(5878),
    [anon_sym_DOLLARerror] = ACTIONS(5878),
    [anon_sym_DOLLARwarning] = ACTIONS(5878),
    [anon_sym_DOLLARinfo] = ACTIONS(5878),
    [anon_sym_default] = ACTIONS(5876),
    [anon_sym_clocking] = ACTIONS(5876),
    [anon_sym_defparam] = ACTIONS(5876),
    [anon_sym_bind] = ACTIONS(5876),
    [anon_sym_rand] = ACTIONS(5876),
    [anon_sym_const] = ACTIONS(5876),
    [anon_sym_function] = ACTIONS(5876),
    [anon_sym_static] = ACTIONS(5876),
    [anon_sym_constraint] = ACTIONS(5876),
    [anon_sym_if] = ACTIONS(5876),
    [anon_sym_else] = ACTIONS(5876),
    [anon_sym_LBRACK] = ACTIONS(5878),
    [anon_sym_localparam] = ACTIONS(5876),
    [anon_sym_parameter] = ACTIONS(5876),
    [anon_sym_var] = ACTIONS(5876),
    [anon_sym_import] = ACTIONS(5876),
    [anon_sym_export] = ACTIONS(5876),
    [anon_sym_genvar] = ACTIONS(5876),
    [anon_sym_interconnect] = ACTIONS(5876),
    [anon_sym_typedef] = ACTIONS(5876),
    [anon_sym_enum] = ACTIONS(5876),
    [anon_sym_struct] = ACTIONS(5876),
    [anon_sym_union] = ACTIONS(5876),
    [anon_sym_nettype] = ACTIONS(5876),
    [anon_sym_automatic] = ACTIONS(5876),
    [anon_sym_string] = ACTIONS(5876),
    [anon_sym_chandle] = ACTIONS(5876),
    [anon_sym_event] = ACTIONS(5876),
    [anon_sym_byte] = ACTIONS(5876),
    [anon_sym_shortint] = ACTIONS(5876),
    [anon_sym_int] = ACTIONS(5876),
    [anon_sym_longint] = ACTIONS(5876),
    [anon_sym_integer] = ACTIONS(5876),
    [anon_sym_time] = ACTIONS(5876),
    [anon_sym_bit] = ACTIONS(5876),
    [anon_sym_logic] = ACTIONS(5876),
    [anon_sym_reg] = ACTIONS(5876),
    [anon_sym_shortreal] = ACTIONS(5876),
    [anon_sym_real] = ACTIONS(5876),
    [anon_sym_realtime] = ACTIONS(5876),
    [anon_sym_supply0] = ACTIONS(5876),
    [anon_sym_supply1] = ACTIONS(5876),
    [anon_sym_signed] = ACTIONS(5876),
    [anon_sym_unsigned] = ACTIONS(5876),
    [anon_sym_task] = ACTIONS(5876),
    [anon_sym_assert] = ACTIONS(5876),
    [anon_sym_property] = ACTIONS(5876),
    [anon_sym_assume] = ACTIONS(5876),
    [anon_sym_cover] = ACTIONS(5876),
    [anon_sym_sequence] = ACTIONS(5876),
    [anon_sym_restrict] = ACTIONS(5876),
    [anon_sym_not] = ACTIONS(5876),
    [anon_sym_or] = ACTIONS(5876),
    [anon_sym_and] = ACTIONS(5876),
    [anon_sym_case] = ACTIONS(5876),
    [anon_sym_always] = ACTIONS(5876),
    [anon_sym_covergroup] = ACTIONS(5876),
    [anon_sym_let] = ACTIONS(5876),
    [anon_sym_pulldown] = ACTIONS(5876),
    [anon_sym_pullup] = ACTIONS(5876),
    [anon_sym_cmos] = ACTIONS(5876),
    [anon_sym_rcmos] = ACTIONS(5876),
    [anon_sym_bufif0] = ACTIONS(5876),
    [anon_sym_bufif1] = ACTIONS(5876),
    [anon_sym_notif0] = ACTIONS(5876),
    [anon_sym_notif1] = ACTIONS(5876),
    [anon_sym_nmos] = ACTIONS(5876),
    [anon_sym_pmos] = ACTIONS(5876),
    [anon_sym_rnmos] = ACTIONS(5876),
    [anon_sym_rpmos] = ACTIONS(5876),
    [anon_sym_nand] = ACTIONS(5876),
    [anon_sym_nor] = ACTIONS(5876),
    [anon_sym_xor] = ACTIONS(5876),
    [anon_sym_xnor] = ACTIONS(5876),
    [anon_sym_buf] = ACTIONS(5876),
    [anon_sym_tranif0] = ACTIONS(5876),
    [anon_sym_tranif1] = ACTIONS(5876),
    [anon_sym_rtranif1] = ACTIONS(5876),
    [anon_sym_rtranif0] = ACTIONS(5876),
    [anon_sym_tran] = ACTIONS(5876),
    [anon_sym_rtran] = ACTIONS(5876),
    [anon_sym_generate] = ACTIONS(5876),
    [anon_sym_endgenerate] = ACTIONS(5876),
    [anon_sym_for] = ACTIONS(5876),
    [anon_sym_initial] = ACTIONS(5876),
    [anon_sym_assign] = ACTIONS(5876),
    [anon_sym_alias] = ACTIONS(5876),
    [anon_sym_always_comb] = ACTIONS(5876),
    [anon_sym_always_latch] = ACTIONS(5876),
    [anon_sym_always_ff] = ACTIONS(5876),
    [anon_sym_final] = ACTIONS(5876),
    [anon_sym_global] = ACTIONS(5876),
    [anon_sym_LPAREN_STAR] = ACTIONS(5878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5878),
    [anon_sym_DOLLARunit] = ACTIONS(5878),
  },
  [5076] = {
    [sym_simple_identifier] = ACTIONS(5332),
    [anon_sym_wire] = ACTIONS(5332),
    [anon_sym_tri] = ACTIONS(5332),
    [anon_sym_tri0] = ACTIONS(5332),
    [anon_sym_tri1] = ACTIONS(5332),
    [anon_sym_wand] = ACTIONS(5332),
    [anon_sym_triand] = ACTIONS(5332),
    [anon_sym_wor] = ACTIONS(5332),
    [anon_sym_trior] = ACTIONS(5332),
    [anon_sym_trireg] = ACTIONS(5332),
    [anon_sym_uwire] = ACTIONS(5332),
    [anon_sym_SEMI] = ACTIONS(5330),
    [anon_sym_extern] = ACTIONS(5332),
    [anon_sym_interface] = ACTIONS(5332),
    [anon_sym_checker] = ACTIONS(5332),
    [anon_sym_virtual] = ACTIONS(5332),
    [anon_sym_class] = ACTIONS(5332),
    [anon_sym_type] = ACTIONS(5332),
    [anon_sym_DOLLARfatal] = ACTIONS(5330),
    [anon_sym_DOLLARerror] = ACTIONS(5330),
    [anon_sym_DOLLARwarning] = ACTIONS(5330),
    [anon_sym_DOLLARinfo] = ACTIONS(5330),
    [anon_sym_default] = ACTIONS(5332),
    [anon_sym_clocking] = ACTIONS(5332),
    [anon_sym_defparam] = ACTIONS(5332),
    [anon_sym_bind] = ACTIONS(5332),
    [anon_sym_rand] = ACTIONS(5332),
    [anon_sym_const] = ACTIONS(5332),
    [anon_sym_function] = ACTIONS(5332),
    [anon_sym_static] = ACTIONS(5332),
    [anon_sym_constraint] = ACTIONS(5332),
    [anon_sym_if] = ACTIONS(5332),
    [anon_sym_else] = ACTIONS(5332),
    [anon_sym_LBRACK] = ACTIONS(5330),
    [anon_sym_localparam] = ACTIONS(5332),
    [anon_sym_parameter] = ACTIONS(5332),
    [anon_sym_var] = ACTIONS(5332),
    [anon_sym_import] = ACTIONS(5332),
    [anon_sym_export] = ACTIONS(5332),
    [anon_sym_genvar] = ACTIONS(5332),
    [anon_sym_interconnect] = ACTIONS(5332),
    [anon_sym_typedef] = ACTIONS(5332),
    [anon_sym_enum] = ACTIONS(5332),
    [anon_sym_struct] = ACTIONS(5332),
    [anon_sym_union] = ACTIONS(5332),
    [anon_sym_nettype] = ACTIONS(5332),
    [anon_sym_automatic] = ACTIONS(5332),
    [anon_sym_string] = ACTIONS(5332),
    [anon_sym_chandle] = ACTIONS(5332),
    [anon_sym_event] = ACTIONS(5332),
    [anon_sym_byte] = ACTIONS(5332),
    [anon_sym_shortint] = ACTIONS(5332),
    [anon_sym_int] = ACTIONS(5332),
    [anon_sym_longint] = ACTIONS(5332),
    [anon_sym_integer] = ACTIONS(5332),
    [anon_sym_time] = ACTIONS(5332),
    [anon_sym_bit] = ACTIONS(5332),
    [anon_sym_logic] = ACTIONS(5332),
    [anon_sym_reg] = ACTIONS(5332),
    [anon_sym_shortreal] = ACTIONS(5332),
    [anon_sym_real] = ACTIONS(5332),
    [anon_sym_realtime] = ACTIONS(5332),
    [anon_sym_supply0] = ACTIONS(5332),
    [anon_sym_supply1] = ACTIONS(5332),
    [anon_sym_signed] = ACTIONS(5332),
    [anon_sym_unsigned] = ACTIONS(5332),
    [anon_sym_task] = ACTIONS(5332),
    [anon_sym_assert] = ACTIONS(5332),
    [anon_sym_property] = ACTIONS(5332),
    [anon_sym_assume] = ACTIONS(5332),
    [anon_sym_cover] = ACTIONS(5332),
    [anon_sym_sequence] = ACTIONS(5332),
    [anon_sym_restrict] = ACTIONS(5332),
    [anon_sym_not] = ACTIONS(5332),
    [anon_sym_or] = ACTIONS(5332),
    [anon_sym_and] = ACTIONS(5332),
    [anon_sym_case] = ACTIONS(5332),
    [anon_sym_always] = ACTIONS(5332),
    [anon_sym_covergroup] = ACTIONS(5332),
    [anon_sym_let] = ACTIONS(5332),
    [anon_sym_pulldown] = ACTIONS(5332),
    [anon_sym_pullup] = ACTIONS(5332),
    [anon_sym_cmos] = ACTIONS(5332),
    [anon_sym_rcmos] = ACTIONS(5332),
    [anon_sym_bufif0] = ACTIONS(5332),
    [anon_sym_bufif1] = ACTIONS(5332),
    [anon_sym_notif0] = ACTIONS(5332),
    [anon_sym_notif1] = ACTIONS(5332),
    [anon_sym_nmos] = ACTIONS(5332),
    [anon_sym_pmos] = ACTIONS(5332),
    [anon_sym_rnmos] = ACTIONS(5332),
    [anon_sym_rpmos] = ACTIONS(5332),
    [anon_sym_nand] = ACTIONS(5332),
    [anon_sym_nor] = ACTIONS(5332),
    [anon_sym_xor] = ACTIONS(5332),
    [anon_sym_xnor] = ACTIONS(5332),
    [anon_sym_buf] = ACTIONS(5332),
    [anon_sym_tranif0] = ACTIONS(5332),
    [anon_sym_tranif1] = ACTIONS(5332),
    [anon_sym_rtranif1] = ACTIONS(5332),
    [anon_sym_rtranif0] = ACTIONS(5332),
    [anon_sym_tran] = ACTIONS(5332),
    [anon_sym_rtran] = ACTIONS(5332),
    [anon_sym_generate] = ACTIONS(5332),
    [anon_sym_endgenerate] = ACTIONS(5332),
    [anon_sym_for] = ACTIONS(5332),
    [anon_sym_initial] = ACTIONS(5332),
    [anon_sym_assign] = ACTIONS(5332),
    [anon_sym_alias] = ACTIONS(5332),
    [anon_sym_always_comb] = ACTIONS(5332),
    [anon_sym_always_latch] = ACTIONS(5332),
    [anon_sym_always_ff] = ACTIONS(5332),
    [anon_sym_final] = ACTIONS(5332),
    [anon_sym_global] = ACTIONS(5332),
    [anon_sym_LPAREN_STAR] = ACTIONS(5330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5330),
    [anon_sym_DOLLARunit] = ACTIONS(5330),
  },
  [5077] = {
    [sym_simple_identifier] = ACTIONS(4560),
    [anon_sym_wire] = ACTIONS(4560),
    [anon_sym_tri] = ACTIONS(4560),
    [anon_sym_tri0] = ACTIONS(4560),
    [anon_sym_tri1] = ACTIONS(4560),
    [anon_sym_wand] = ACTIONS(4560),
    [anon_sym_triand] = ACTIONS(4560),
    [anon_sym_wor] = ACTIONS(4560),
    [anon_sym_trior] = ACTIONS(4560),
    [anon_sym_trireg] = ACTIONS(4560),
    [anon_sym_uwire] = ACTIONS(4560),
    [anon_sym_SEMI] = ACTIONS(4558),
    [anon_sym_extern] = ACTIONS(4560),
    [anon_sym_interface] = ACTIONS(4560),
    [anon_sym_checker] = ACTIONS(4560),
    [anon_sym_virtual] = ACTIONS(4560),
    [anon_sym_class] = ACTIONS(4560),
    [anon_sym_type] = ACTIONS(4560),
    [anon_sym_DOLLARfatal] = ACTIONS(4558),
    [anon_sym_DOLLARerror] = ACTIONS(4558),
    [anon_sym_DOLLARwarning] = ACTIONS(4558),
    [anon_sym_DOLLARinfo] = ACTIONS(4558),
    [anon_sym_default] = ACTIONS(4560),
    [anon_sym_clocking] = ACTIONS(4560),
    [anon_sym_defparam] = ACTIONS(4560),
    [anon_sym_bind] = ACTIONS(4560),
    [anon_sym_rand] = ACTIONS(4560),
    [anon_sym_const] = ACTIONS(4560),
    [anon_sym_function] = ACTIONS(4560),
    [anon_sym_static] = ACTIONS(4560),
    [anon_sym_constraint] = ACTIONS(4560),
    [anon_sym_if] = ACTIONS(4560),
    [anon_sym_else] = ACTIONS(4560),
    [anon_sym_LBRACK] = ACTIONS(4558),
    [anon_sym_localparam] = ACTIONS(4560),
    [anon_sym_parameter] = ACTIONS(4560),
    [anon_sym_var] = ACTIONS(4560),
    [anon_sym_import] = ACTIONS(4560),
    [anon_sym_export] = ACTIONS(4560),
    [anon_sym_genvar] = ACTIONS(4560),
    [anon_sym_interconnect] = ACTIONS(4560),
    [anon_sym_typedef] = ACTIONS(4560),
    [anon_sym_enum] = ACTIONS(4560),
    [anon_sym_struct] = ACTIONS(4560),
    [anon_sym_union] = ACTIONS(4560),
    [anon_sym_nettype] = ACTIONS(4560),
    [anon_sym_automatic] = ACTIONS(4560),
    [anon_sym_string] = ACTIONS(4560),
    [anon_sym_chandle] = ACTIONS(4560),
    [anon_sym_event] = ACTIONS(4560),
    [anon_sym_byte] = ACTIONS(4560),
    [anon_sym_shortint] = ACTIONS(4560),
    [anon_sym_int] = ACTIONS(4560),
    [anon_sym_longint] = ACTIONS(4560),
    [anon_sym_integer] = ACTIONS(4560),
    [anon_sym_time] = ACTIONS(4560),
    [anon_sym_bit] = ACTIONS(4560),
    [anon_sym_logic] = ACTIONS(4560),
    [anon_sym_reg] = ACTIONS(4560),
    [anon_sym_shortreal] = ACTIONS(4560),
    [anon_sym_real] = ACTIONS(4560),
    [anon_sym_realtime] = ACTIONS(4560),
    [anon_sym_supply0] = ACTIONS(4560),
    [anon_sym_supply1] = ACTIONS(4560),
    [anon_sym_signed] = ACTIONS(4560),
    [anon_sym_unsigned] = ACTIONS(4560),
    [anon_sym_task] = ACTIONS(4560),
    [anon_sym_assert] = ACTIONS(4560),
    [anon_sym_property] = ACTIONS(4560),
    [anon_sym_assume] = ACTIONS(4560),
    [anon_sym_cover] = ACTIONS(4560),
    [anon_sym_sequence] = ACTIONS(4560),
    [anon_sym_restrict] = ACTIONS(4560),
    [anon_sym_not] = ACTIONS(4560),
    [anon_sym_or] = ACTIONS(4560),
    [anon_sym_and] = ACTIONS(4560),
    [anon_sym_case] = ACTIONS(4560),
    [anon_sym_always] = ACTIONS(4560),
    [anon_sym_covergroup] = ACTIONS(4560),
    [anon_sym_end] = ACTIONS(4560),
    [anon_sym_let] = ACTIONS(4560),
    [anon_sym_pulldown] = ACTIONS(4560),
    [anon_sym_pullup] = ACTIONS(4560),
    [anon_sym_cmos] = ACTIONS(4560),
    [anon_sym_rcmos] = ACTIONS(4560),
    [anon_sym_bufif0] = ACTIONS(4560),
    [anon_sym_bufif1] = ACTIONS(4560),
    [anon_sym_notif0] = ACTIONS(4560),
    [anon_sym_notif1] = ACTIONS(4560),
    [anon_sym_nmos] = ACTIONS(4560),
    [anon_sym_pmos] = ACTIONS(4560),
    [anon_sym_rnmos] = ACTIONS(4560),
    [anon_sym_rpmos] = ACTIONS(4560),
    [anon_sym_nand] = ACTIONS(4560),
    [anon_sym_nor] = ACTIONS(4560),
    [anon_sym_xor] = ACTIONS(4560),
    [anon_sym_xnor] = ACTIONS(4560),
    [anon_sym_buf] = ACTIONS(4560),
    [anon_sym_tranif0] = ACTIONS(4560),
    [anon_sym_tranif1] = ACTIONS(4560),
    [anon_sym_rtranif1] = ACTIONS(4560),
    [anon_sym_rtranif0] = ACTIONS(4560),
    [anon_sym_tran] = ACTIONS(4560),
    [anon_sym_rtran] = ACTIONS(4560),
    [anon_sym_generate] = ACTIONS(4560),
    [anon_sym_for] = ACTIONS(4560),
    [anon_sym_initial] = ACTIONS(4560),
    [anon_sym_assign] = ACTIONS(4560),
    [anon_sym_alias] = ACTIONS(4560),
    [anon_sym_always_comb] = ACTIONS(4560),
    [anon_sym_always_latch] = ACTIONS(4560),
    [anon_sym_always_ff] = ACTIONS(4560),
    [anon_sym_final] = ACTIONS(4560),
    [anon_sym_global] = ACTIONS(4560),
    [anon_sym_LPAREN_STAR] = ACTIONS(4558),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4558),
    [anon_sym_DOLLARunit] = ACTIONS(4558),
  },
  [5078] = {
    [sym_simple_identifier] = ACTIONS(6657),
    [anon_sym_wire] = ACTIONS(6657),
    [anon_sym_tri] = ACTIONS(6657),
    [anon_sym_tri0] = ACTIONS(6657),
    [anon_sym_tri1] = ACTIONS(6657),
    [anon_sym_wand] = ACTIONS(6657),
    [anon_sym_triand] = ACTIONS(6657),
    [anon_sym_wor] = ACTIONS(6657),
    [anon_sym_trior] = ACTIONS(6657),
    [anon_sym_trireg] = ACTIONS(6657),
    [anon_sym_uwire] = ACTIONS(6657),
    [anon_sym_SEMI] = ACTIONS(6659),
    [anon_sym_extern] = ACTIONS(6657),
    [anon_sym_interface] = ACTIONS(6657),
    [anon_sym_checker] = ACTIONS(6657),
    [anon_sym_virtual] = ACTIONS(6657),
    [anon_sym_class] = ACTIONS(6657),
    [anon_sym_type] = ACTIONS(6657),
    [anon_sym_DOLLARfatal] = ACTIONS(6659),
    [anon_sym_DOLLARerror] = ACTIONS(6659),
    [anon_sym_DOLLARwarning] = ACTIONS(6659),
    [anon_sym_DOLLARinfo] = ACTIONS(6659),
    [anon_sym_default] = ACTIONS(6657),
    [anon_sym_clocking] = ACTIONS(6657),
    [anon_sym_defparam] = ACTIONS(6657),
    [anon_sym_bind] = ACTIONS(6657),
    [anon_sym_rand] = ACTIONS(6657),
    [anon_sym_const] = ACTIONS(6657),
    [anon_sym_function] = ACTIONS(6657),
    [anon_sym_static] = ACTIONS(6657),
    [anon_sym_constraint] = ACTIONS(6657),
    [anon_sym_if] = ACTIONS(6657),
    [anon_sym_else] = ACTIONS(6657),
    [anon_sym_LBRACK] = ACTIONS(6659),
    [anon_sym_localparam] = ACTIONS(6657),
    [anon_sym_parameter] = ACTIONS(6657),
    [anon_sym_var] = ACTIONS(6657),
    [anon_sym_import] = ACTIONS(6657),
    [anon_sym_export] = ACTIONS(6657),
    [anon_sym_genvar] = ACTIONS(6657),
    [anon_sym_interconnect] = ACTIONS(6657),
    [anon_sym_typedef] = ACTIONS(6657),
    [anon_sym_enum] = ACTIONS(6657),
    [anon_sym_struct] = ACTIONS(6657),
    [anon_sym_union] = ACTIONS(6657),
    [anon_sym_nettype] = ACTIONS(6657),
    [anon_sym_automatic] = ACTIONS(6657),
    [anon_sym_string] = ACTIONS(6657),
    [anon_sym_chandle] = ACTIONS(6657),
    [anon_sym_event] = ACTIONS(6657),
    [anon_sym_byte] = ACTIONS(6657),
    [anon_sym_shortint] = ACTIONS(6657),
    [anon_sym_int] = ACTIONS(6657),
    [anon_sym_longint] = ACTIONS(6657),
    [anon_sym_integer] = ACTIONS(6657),
    [anon_sym_time] = ACTIONS(6657),
    [anon_sym_bit] = ACTIONS(6657),
    [anon_sym_logic] = ACTIONS(6657),
    [anon_sym_reg] = ACTIONS(6657),
    [anon_sym_shortreal] = ACTIONS(6657),
    [anon_sym_real] = ACTIONS(6657),
    [anon_sym_realtime] = ACTIONS(6657),
    [anon_sym_supply0] = ACTIONS(6657),
    [anon_sym_supply1] = ACTIONS(6657),
    [anon_sym_signed] = ACTIONS(6657),
    [anon_sym_unsigned] = ACTIONS(6657),
    [anon_sym_task] = ACTIONS(6657),
    [anon_sym_assert] = ACTIONS(6657),
    [anon_sym_property] = ACTIONS(6657),
    [anon_sym_assume] = ACTIONS(6657),
    [anon_sym_cover] = ACTIONS(6657),
    [anon_sym_sequence] = ACTIONS(6657),
    [anon_sym_restrict] = ACTIONS(6657),
    [anon_sym_not] = ACTIONS(6657),
    [anon_sym_or] = ACTIONS(6657),
    [anon_sym_and] = ACTIONS(6657),
    [anon_sym_case] = ACTIONS(6657),
    [anon_sym_always] = ACTIONS(6657),
    [anon_sym_covergroup] = ACTIONS(6657),
    [anon_sym_end] = ACTIONS(6657),
    [anon_sym_let] = ACTIONS(6657),
    [anon_sym_pulldown] = ACTIONS(6657),
    [anon_sym_pullup] = ACTIONS(6657),
    [anon_sym_cmos] = ACTIONS(6657),
    [anon_sym_rcmos] = ACTIONS(6657),
    [anon_sym_bufif0] = ACTIONS(6657),
    [anon_sym_bufif1] = ACTIONS(6657),
    [anon_sym_notif0] = ACTIONS(6657),
    [anon_sym_notif1] = ACTIONS(6657),
    [anon_sym_nmos] = ACTIONS(6657),
    [anon_sym_pmos] = ACTIONS(6657),
    [anon_sym_rnmos] = ACTIONS(6657),
    [anon_sym_rpmos] = ACTIONS(6657),
    [anon_sym_nand] = ACTIONS(6657),
    [anon_sym_nor] = ACTIONS(6657),
    [anon_sym_xor] = ACTIONS(6657),
    [anon_sym_xnor] = ACTIONS(6657),
    [anon_sym_buf] = ACTIONS(6657),
    [anon_sym_tranif0] = ACTIONS(6657),
    [anon_sym_tranif1] = ACTIONS(6657),
    [anon_sym_rtranif1] = ACTIONS(6657),
    [anon_sym_rtranif0] = ACTIONS(6657),
    [anon_sym_tran] = ACTIONS(6657),
    [anon_sym_rtran] = ACTIONS(6657),
    [anon_sym_generate] = ACTIONS(6657),
    [anon_sym_for] = ACTIONS(6657),
    [anon_sym_initial] = ACTIONS(6657),
    [anon_sym_assign] = ACTIONS(6657),
    [anon_sym_alias] = ACTIONS(6657),
    [anon_sym_always_comb] = ACTIONS(6657),
    [anon_sym_always_latch] = ACTIONS(6657),
    [anon_sym_always_ff] = ACTIONS(6657),
    [anon_sym_final] = ACTIONS(6657),
    [anon_sym_global] = ACTIONS(6657),
    [anon_sym_LPAREN_STAR] = ACTIONS(6659),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6659),
    [anon_sym_DOLLARunit] = ACTIONS(6659),
  },
  [5079] = {
    [sym_simple_identifier] = ACTIONS(6091),
    [anon_sym_wire] = ACTIONS(6091),
    [anon_sym_tri] = ACTIONS(6091),
    [anon_sym_tri0] = ACTIONS(6091),
    [anon_sym_tri1] = ACTIONS(6091),
    [anon_sym_wand] = ACTIONS(6091),
    [anon_sym_triand] = ACTIONS(6091),
    [anon_sym_wor] = ACTIONS(6091),
    [anon_sym_trior] = ACTIONS(6091),
    [anon_sym_trireg] = ACTIONS(6091),
    [anon_sym_uwire] = ACTIONS(6091),
    [anon_sym_SEMI] = ACTIONS(6093),
    [anon_sym_extern] = ACTIONS(6091),
    [anon_sym_interface] = ACTIONS(6091),
    [anon_sym_checker] = ACTIONS(6091),
    [anon_sym_virtual] = ACTIONS(6091),
    [anon_sym_class] = ACTIONS(6091),
    [anon_sym_type] = ACTIONS(6091),
    [anon_sym_DOLLARfatal] = ACTIONS(6093),
    [anon_sym_DOLLARerror] = ACTIONS(6093),
    [anon_sym_DOLLARwarning] = ACTIONS(6093),
    [anon_sym_DOLLARinfo] = ACTIONS(6093),
    [anon_sym_default] = ACTIONS(6091),
    [anon_sym_clocking] = ACTIONS(6091),
    [anon_sym_defparam] = ACTIONS(6091),
    [anon_sym_bind] = ACTIONS(6091),
    [anon_sym_rand] = ACTIONS(6091),
    [anon_sym_const] = ACTIONS(6091),
    [anon_sym_function] = ACTIONS(6091),
    [anon_sym_static] = ACTIONS(6091),
    [anon_sym_constraint] = ACTIONS(6091),
    [anon_sym_if] = ACTIONS(6091),
    [anon_sym_else] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_localparam] = ACTIONS(6091),
    [anon_sym_parameter] = ACTIONS(6091),
    [anon_sym_var] = ACTIONS(6091),
    [anon_sym_import] = ACTIONS(6091),
    [anon_sym_export] = ACTIONS(6091),
    [anon_sym_genvar] = ACTIONS(6091),
    [anon_sym_interconnect] = ACTIONS(6091),
    [anon_sym_typedef] = ACTIONS(6091),
    [anon_sym_enum] = ACTIONS(6091),
    [anon_sym_struct] = ACTIONS(6091),
    [anon_sym_union] = ACTIONS(6091),
    [anon_sym_nettype] = ACTIONS(6091),
    [anon_sym_automatic] = ACTIONS(6091),
    [anon_sym_string] = ACTIONS(6091),
    [anon_sym_chandle] = ACTIONS(6091),
    [anon_sym_event] = ACTIONS(6091),
    [anon_sym_byte] = ACTIONS(6091),
    [anon_sym_shortint] = ACTIONS(6091),
    [anon_sym_int] = ACTIONS(6091),
    [anon_sym_longint] = ACTIONS(6091),
    [anon_sym_integer] = ACTIONS(6091),
    [anon_sym_time] = ACTIONS(6091),
    [anon_sym_bit] = ACTIONS(6091),
    [anon_sym_logic] = ACTIONS(6091),
    [anon_sym_reg] = ACTIONS(6091),
    [anon_sym_shortreal] = ACTIONS(6091),
    [anon_sym_real] = ACTIONS(6091),
    [anon_sym_realtime] = ACTIONS(6091),
    [anon_sym_supply0] = ACTIONS(6091),
    [anon_sym_supply1] = ACTIONS(6091),
    [anon_sym_signed] = ACTIONS(6091),
    [anon_sym_unsigned] = ACTIONS(6091),
    [anon_sym_task] = ACTIONS(6091),
    [anon_sym_assert] = ACTIONS(6091),
    [anon_sym_property] = ACTIONS(6091),
    [anon_sym_assume] = ACTIONS(6091),
    [anon_sym_cover] = ACTIONS(6091),
    [anon_sym_sequence] = ACTIONS(6091),
    [anon_sym_restrict] = ACTIONS(6091),
    [anon_sym_not] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6091),
    [anon_sym_and] = ACTIONS(6091),
    [anon_sym_case] = ACTIONS(6091),
    [anon_sym_always] = ACTIONS(6091),
    [anon_sym_covergroup] = ACTIONS(6091),
    [anon_sym_end] = ACTIONS(6091),
    [anon_sym_let] = ACTIONS(6091),
    [anon_sym_pulldown] = ACTIONS(6091),
    [anon_sym_pullup] = ACTIONS(6091),
    [anon_sym_cmos] = ACTIONS(6091),
    [anon_sym_rcmos] = ACTIONS(6091),
    [anon_sym_bufif0] = ACTIONS(6091),
    [anon_sym_bufif1] = ACTIONS(6091),
    [anon_sym_notif0] = ACTIONS(6091),
    [anon_sym_notif1] = ACTIONS(6091),
    [anon_sym_nmos] = ACTIONS(6091),
    [anon_sym_pmos] = ACTIONS(6091),
    [anon_sym_rnmos] = ACTIONS(6091),
    [anon_sym_rpmos] = ACTIONS(6091),
    [anon_sym_nand] = ACTIONS(6091),
    [anon_sym_nor] = ACTIONS(6091),
    [anon_sym_xor] = ACTIONS(6091),
    [anon_sym_xnor] = ACTIONS(6091),
    [anon_sym_buf] = ACTIONS(6091),
    [anon_sym_tranif0] = ACTIONS(6091),
    [anon_sym_tranif1] = ACTIONS(6091),
    [anon_sym_rtranif1] = ACTIONS(6091),
    [anon_sym_rtranif0] = ACTIONS(6091),
    [anon_sym_tran] = ACTIONS(6091),
    [anon_sym_rtran] = ACTIONS(6091),
    [anon_sym_generate] = ACTIONS(6091),
    [anon_sym_for] = ACTIONS(6091),
    [anon_sym_initial] = ACTIONS(6091),
    [anon_sym_assign] = ACTIONS(6091),
    [anon_sym_alias] = ACTIONS(6091),
    [anon_sym_always_comb] = ACTIONS(6091),
    [anon_sym_always_latch] = ACTIONS(6091),
    [anon_sym_always_ff] = ACTIONS(6091),
    [anon_sym_final] = ACTIONS(6091),
    [anon_sym_global] = ACTIONS(6091),
    [anon_sym_LPAREN_STAR] = ACTIONS(6093),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6093),
    [anon_sym_DOLLARunit] = ACTIONS(6093),
  },
  [5080] = {
    [sym_simple_identifier] = ACTIONS(6777),
    [anon_sym_wire] = ACTIONS(6777),
    [anon_sym_tri] = ACTIONS(6777),
    [anon_sym_tri0] = ACTIONS(6777),
    [anon_sym_tri1] = ACTIONS(6777),
    [anon_sym_wand] = ACTIONS(6777),
    [anon_sym_triand] = ACTIONS(6777),
    [anon_sym_wor] = ACTIONS(6777),
    [anon_sym_trior] = ACTIONS(6777),
    [anon_sym_trireg] = ACTIONS(6777),
    [anon_sym_uwire] = ACTIONS(6777),
    [anon_sym_SEMI] = ACTIONS(6780),
    [anon_sym_extern] = ACTIONS(6777),
    [anon_sym_interface] = ACTIONS(6777),
    [anon_sym_checker] = ACTIONS(6777),
    [anon_sym_virtual] = ACTIONS(6777),
    [anon_sym_class] = ACTIONS(6777),
    [anon_sym_type] = ACTIONS(6777),
    [anon_sym_DOLLARfatal] = ACTIONS(6780),
    [anon_sym_DOLLARerror] = ACTIONS(6780),
    [anon_sym_DOLLARwarning] = ACTIONS(6780),
    [anon_sym_DOLLARinfo] = ACTIONS(6780),
    [anon_sym_default] = ACTIONS(6777),
    [anon_sym_clocking] = ACTIONS(6777),
    [anon_sym_defparam] = ACTIONS(6777),
    [anon_sym_bind] = ACTIONS(6777),
    [anon_sym_rand] = ACTIONS(6777),
    [anon_sym_const] = ACTIONS(6777),
    [anon_sym_function] = ACTIONS(6777),
    [anon_sym_static] = ACTIONS(6777),
    [anon_sym_constraint] = ACTIONS(6777),
    [anon_sym_if] = ACTIONS(6777),
    [anon_sym_else] = ACTIONS(6777),
    [anon_sym_LBRACK] = ACTIONS(6780),
    [anon_sym_localparam] = ACTIONS(6777),
    [anon_sym_parameter] = ACTIONS(6777),
    [anon_sym_var] = ACTIONS(6777),
    [anon_sym_import] = ACTIONS(6777),
    [anon_sym_export] = ACTIONS(6777),
    [anon_sym_genvar] = ACTIONS(6777),
    [anon_sym_interconnect] = ACTIONS(6777),
    [anon_sym_typedef] = ACTIONS(6777),
    [anon_sym_enum] = ACTIONS(6777),
    [anon_sym_struct] = ACTIONS(6777),
    [anon_sym_union] = ACTIONS(6777),
    [anon_sym_nettype] = ACTIONS(6777),
    [anon_sym_automatic] = ACTIONS(6777),
    [anon_sym_string] = ACTIONS(6777),
    [anon_sym_chandle] = ACTIONS(6777),
    [anon_sym_event] = ACTIONS(6777),
    [anon_sym_byte] = ACTIONS(6777),
    [anon_sym_shortint] = ACTIONS(6777),
    [anon_sym_int] = ACTIONS(6777),
    [anon_sym_longint] = ACTIONS(6777),
    [anon_sym_integer] = ACTIONS(6777),
    [anon_sym_time] = ACTIONS(6777),
    [anon_sym_bit] = ACTIONS(6777),
    [anon_sym_logic] = ACTIONS(6777),
    [anon_sym_reg] = ACTIONS(6777),
    [anon_sym_shortreal] = ACTIONS(6777),
    [anon_sym_real] = ACTIONS(6777),
    [anon_sym_realtime] = ACTIONS(6777),
    [anon_sym_supply0] = ACTIONS(6777),
    [anon_sym_supply1] = ACTIONS(6777),
    [anon_sym_signed] = ACTIONS(6777),
    [anon_sym_unsigned] = ACTIONS(6777),
    [anon_sym_task] = ACTIONS(6777),
    [anon_sym_assert] = ACTIONS(6777),
    [anon_sym_property] = ACTIONS(6777),
    [anon_sym_assume] = ACTIONS(6777),
    [anon_sym_cover] = ACTIONS(6777),
    [anon_sym_sequence] = ACTIONS(6777),
    [anon_sym_restrict] = ACTIONS(6777),
    [anon_sym_not] = ACTIONS(6777),
    [anon_sym_or] = ACTIONS(6777),
    [anon_sym_and] = ACTIONS(6777),
    [anon_sym_case] = ACTIONS(6777),
    [anon_sym_always] = ACTIONS(6777),
    [anon_sym_covergroup] = ACTIONS(6777),
    [anon_sym_end] = ACTIONS(6777),
    [anon_sym_let] = ACTIONS(6777),
    [anon_sym_pulldown] = ACTIONS(6777),
    [anon_sym_pullup] = ACTIONS(6777),
    [anon_sym_cmos] = ACTIONS(6777),
    [anon_sym_rcmos] = ACTIONS(6777),
    [anon_sym_bufif0] = ACTIONS(6777),
    [anon_sym_bufif1] = ACTIONS(6777),
    [anon_sym_notif0] = ACTIONS(6777),
    [anon_sym_notif1] = ACTIONS(6777),
    [anon_sym_nmos] = ACTIONS(6777),
    [anon_sym_pmos] = ACTIONS(6777),
    [anon_sym_rnmos] = ACTIONS(6777),
    [anon_sym_rpmos] = ACTIONS(6777),
    [anon_sym_nand] = ACTIONS(6777),
    [anon_sym_nor] = ACTIONS(6777),
    [anon_sym_xor] = ACTIONS(6777),
    [anon_sym_xnor] = ACTIONS(6777),
    [anon_sym_buf] = ACTIONS(6777),
    [anon_sym_tranif0] = ACTIONS(6777),
    [anon_sym_tranif1] = ACTIONS(6777),
    [anon_sym_rtranif1] = ACTIONS(6777),
    [anon_sym_rtranif0] = ACTIONS(6777),
    [anon_sym_tran] = ACTIONS(6777),
    [anon_sym_rtran] = ACTIONS(6777),
    [anon_sym_generate] = ACTIONS(6777),
    [anon_sym_for] = ACTIONS(6777),
    [anon_sym_initial] = ACTIONS(6777),
    [anon_sym_assign] = ACTIONS(6777),
    [anon_sym_alias] = ACTIONS(6777),
    [anon_sym_always_comb] = ACTIONS(6777),
    [anon_sym_always_latch] = ACTIONS(6777),
    [anon_sym_always_ff] = ACTIONS(6777),
    [anon_sym_final] = ACTIONS(6777),
    [anon_sym_global] = ACTIONS(6777),
    [anon_sym_LPAREN_STAR] = ACTIONS(6780),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6780),
    [anon_sym_DOLLARunit] = ACTIONS(6780),
  },
  [5081] = {
    [sym_simple_identifier] = ACTIONS(6027),
    [anon_sym_wire] = ACTIONS(6027),
    [anon_sym_tri] = ACTIONS(6027),
    [anon_sym_tri0] = ACTIONS(6027),
    [anon_sym_tri1] = ACTIONS(6027),
    [anon_sym_wand] = ACTIONS(6027),
    [anon_sym_triand] = ACTIONS(6027),
    [anon_sym_wor] = ACTIONS(6027),
    [anon_sym_trior] = ACTIONS(6027),
    [anon_sym_trireg] = ACTIONS(6027),
    [anon_sym_uwire] = ACTIONS(6027),
    [anon_sym_SEMI] = ACTIONS(6029),
    [anon_sym_extern] = ACTIONS(6027),
    [anon_sym_interface] = ACTIONS(6027),
    [anon_sym_checker] = ACTIONS(6027),
    [anon_sym_virtual] = ACTIONS(6027),
    [anon_sym_class] = ACTIONS(6027),
    [anon_sym_type] = ACTIONS(6027),
    [anon_sym_DOLLARfatal] = ACTIONS(6029),
    [anon_sym_DOLLARerror] = ACTIONS(6029),
    [anon_sym_DOLLARwarning] = ACTIONS(6029),
    [anon_sym_DOLLARinfo] = ACTIONS(6029),
    [anon_sym_default] = ACTIONS(6027),
    [anon_sym_clocking] = ACTIONS(6027),
    [anon_sym_defparam] = ACTIONS(6027),
    [anon_sym_bind] = ACTIONS(6027),
    [anon_sym_rand] = ACTIONS(6027),
    [anon_sym_const] = ACTIONS(6027),
    [anon_sym_function] = ACTIONS(6027),
    [anon_sym_static] = ACTIONS(6027),
    [anon_sym_constraint] = ACTIONS(6027),
    [anon_sym_if] = ACTIONS(6027),
    [anon_sym_else] = ACTIONS(6027),
    [anon_sym_LBRACK] = ACTIONS(6029),
    [anon_sym_localparam] = ACTIONS(6027),
    [anon_sym_parameter] = ACTIONS(6027),
    [anon_sym_var] = ACTIONS(6027),
    [anon_sym_import] = ACTIONS(6027),
    [anon_sym_export] = ACTIONS(6027),
    [anon_sym_genvar] = ACTIONS(6027),
    [anon_sym_interconnect] = ACTIONS(6027),
    [anon_sym_typedef] = ACTIONS(6027),
    [anon_sym_enum] = ACTIONS(6027),
    [anon_sym_struct] = ACTIONS(6027),
    [anon_sym_union] = ACTIONS(6027),
    [anon_sym_nettype] = ACTIONS(6027),
    [anon_sym_automatic] = ACTIONS(6027),
    [anon_sym_string] = ACTIONS(6027),
    [anon_sym_chandle] = ACTIONS(6027),
    [anon_sym_event] = ACTIONS(6027),
    [anon_sym_byte] = ACTIONS(6027),
    [anon_sym_shortint] = ACTIONS(6027),
    [anon_sym_int] = ACTIONS(6027),
    [anon_sym_longint] = ACTIONS(6027),
    [anon_sym_integer] = ACTIONS(6027),
    [anon_sym_time] = ACTIONS(6027),
    [anon_sym_bit] = ACTIONS(6027),
    [anon_sym_logic] = ACTIONS(6027),
    [anon_sym_reg] = ACTIONS(6027),
    [anon_sym_shortreal] = ACTIONS(6027),
    [anon_sym_real] = ACTIONS(6027),
    [anon_sym_realtime] = ACTIONS(6027),
    [anon_sym_supply0] = ACTIONS(6027),
    [anon_sym_supply1] = ACTIONS(6027),
    [anon_sym_signed] = ACTIONS(6027),
    [anon_sym_unsigned] = ACTIONS(6027),
    [anon_sym_task] = ACTIONS(6027),
    [anon_sym_assert] = ACTIONS(6027),
    [anon_sym_property] = ACTIONS(6027),
    [anon_sym_assume] = ACTIONS(6027),
    [anon_sym_cover] = ACTIONS(6027),
    [anon_sym_sequence] = ACTIONS(6027),
    [anon_sym_restrict] = ACTIONS(6027),
    [anon_sym_not] = ACTIONS(6027),
    [anon_sym_or] = ACTIONS(6027),
    [anon_sym_and] = ACTIONS(6027),
    [anon_sym_case] = ACTIONS(6027),
    [anon_sym_always] = ACTIONS(6027),
    [anon_sym_covergroup] = ACTIONS(6027),
    [anon_sym_let] = ACTIONS(6027),
    [anon_sym_pulldown] = ACTIONS(6027),
    [anon_sym_pullup] = ACTIONS(6027),
    [anon_sym_cmos] = ACTIONS(6027),
    [anon_sym_rcmos] = ACTIONS(6027),
    [anon_sym_bufif0] = ACTIONS(6027),
    [anon_sym_bufif1] = ACTIONS(6027),
    [anon_sym_notif0] = ACTIONS(6027),
    [anon_sym_notif1] = ACTIONS(6027),
    [anon_sym_nmos] = ACTIONS(6027),
    [anon_sym_pmos] = ACTIONS(6027),
    [anon_sym_rnmos] = ACTIONS(6027),
    [anon_sym_rpmos] = ACTIONS(6027),
    [anon_sym_nand] = ACTIONS(6027),
    [anon_sym_nor] = ACTIONS(6027),
    [anon_sym_xor] = ACTIONS(6027),
    [anon_sym_xnor] = ACTIONS(6027),
    [anon_sym_buf] = ACTIONS(6027),
    [anon_sym_tranif0] = ACTIONS(6027),
    [anon_sym_tranif1] = ACTIONS(6027),
    [anon_sym_rtranif1] = ACTIONS(6027),
    [anon_sym_rtranif0] = ACTIONS(6027),
    [anon_sym_tran] = ACTIONS(6027),
    [anon_sym_rtran] = ACTIONS(6027),
    [anon_sym_generate] = ACTIONS(6027),
    [anon_sym_endgenerate] = ACTIONS(6027),
    [anon_sym_for] = ACTIONS(6027),
    [anon_sym_initial] = ACTIONS(6027),
    [anon_sym_assign] = ACTIONS(6027),
    [anon_sym_alias] = ACTIONS(6027),
    [anon_sym_always_comb] = ACTIONS(6027),
    [anon_sym_always_latch] = ACTIONS(6027),
    [anon_sym_always_ff] = ACTIONS(6027),
    [anon_sym_final] = ACTIONS(6027),
    [anon_sym_global] = ACTIONS(6027),
    [anon_sym_LPAREN_STAR] = ACTIONS(6029),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6029),
    [anon_sym_DOLLARunit] = ACTIONS(6029),
  },
  [5082] = {
    [sym_simple_identifier] = ACTIONS(6083),
    [anon_sym_wire] = ACTIONS(6083),
    [anon_sym_tri] = ACTIONS(6083),
    [anon_sym_tri0] = ACTIONS(6083),
    [anon_sym_tri1] = ACTIONS(6083),
    [anon_sym_wand] = ACTIONS(6083),
    [anon_sym_triand] = ACTIONS(6083),
    [anon_sym_wor] = ACTIONS(6083),
    [anon_sym_trior] = ACTIONS(6083),
    [anon_sym_trireg] = ACTIONS(6083),
    [anon_sym_uwire] = ACTIONS(6083),
    [anon_sym_SEMI] = ACTIONS(6085),
    [anon_sym_extern] = ACTIONS(6083),
    [anon_sym_interface] = ACTIONS(6083),
    [anon_sym_checker] = ACTIONS(6083),
    [anon_sym_virtual] = ACTIONS(6083),
    [anon_sym_class] = ACTIONS(6083),
    [anon_sym_type] = ACTIONS(6083),
    [anon_sym_DOLLARfatal] = ACTIONS(6085),
    [anon_sym_DOLLARerror] = ACTIONS(6085),
    [anon_sym_DOLLARwarning] = ACTIONS(6085),
    [anon_sym_DOLLARinfo] = ACTIONS(6085),
    [anon_sym_default] = ACTIONS(6083),
    [anon_sym_clocking] = ACTIONS(6083),
    [anon_sym_defparam] = ACTIONS(6083),
    [anon_sym_bind] = ACTIONS(6083),
    [anon_sym_rand] = ACTIONS(6083),
    [anon_sym_const] = ACTIONS(6083),
    [anon_sym_function] = ACTIONS(6083),
    [anon_sym_static] = ACTIONS(6083),
    [anon_sym_constraint] = ACTIONS(6083),
    [anon_sym_if] = ACTIONS(6083),
    [anon_sym_else] = ACTIONS(6083),
    [anon_sym_LBRACK] = ACTIONS(6085),
    [anon_sym_localparam] = ACTIONS(6083),
    [anon_sym_parameter] = ACTIONS(6083),
    [anon_sym_var] = ACTIONS(6083),
    [anon_sym_import] = ACTIONS(6083),
    [anon_sym_export] = ACTIONS(6083),
    [anon_sym_genvar] = ACTIONS(6083),
    [anon_sym_interconnect] = ACTIONS(6083),
    [anon_sym_typedef] = ACTIONS(6083),
    [anon_sym_enum] = ACTIONS(6083),
    [anon_sym_struct] = ACTIONS(6083),
    [anon_sym_union] = ACTIONS(6083),
    [anon_sym_nettype] = ACTIONS(6083),
    [anon_sym_automatic] = ACTIONS(6083),
    [anon_sym_string] = ACTIONS(6083),
    [anon_sym_chandle] = ACTIONS(6083),
    [anon_sym_event] = ACTIONS(6083),
    [anon_sym_byte] = ACTIONS(6083),
    [anon_sym_shortint] = ACTIONS(6083),
    [anon_sym_int] = ACTIONS(6083),
    [anon_sym_longint] = ACTIONS(6083),
    [anon_sym_integer] = ACTIONS(6083),
    [anon_sym_time] = ACTIONS(6083),
    [anon_sym_bit] = ACTIONS(6083),
    [anon_sym_logic] = ACTIONS(6083),
    [anon_sym_reg] = ACTIONS(6083),
    [anon_sym_shortreal] = ACTIONS(6083),
    [anon_sym_real] = ACTIONS(6083),
    [anon_sym_realtime] = ACTIONS(6083),
    [anon_sym_supply0] = ACTIONS(6083),
    [anon_sym_supply1] = ACTIONS(6083),
    [anon_sym_signed] = ACTIONS(6083),
    [anon_sym_unsigned] = ACTIONS(6083),
    [anon_sym_task] = ACTIONS(6083),
    [anon_sym_assert] = ACTIONS(6083),
    [anon_sym_property] = ACTIONS(6083),
    [anon_sym_assume] = ACTIONS(6083),
    [anon_sym_cover] = ACTIONS(6083),
    [anon_sym_sequence] = ACTIONS(6083),
    [anon_sym_restrict] = ACTIONS(6083),
    [anon_sym_not] = ACTIONS(6083),
    [anon_sym_or] = ACTIONS(6083),
    [anon_sym_and] = ACTIONS(6083),
    [anon_sym_case] = ACTIONS(6083),
    [anon_sym_always] = ACTIONS(6083),
    [anon_sym_covergroup] = ACTIONS(6083),
    [anon_sym_let] = ACTIONS(6083),
    [anon_sym_pulldown] = ACTIONS(6083),
    [anon_sym_pullup] = ACTIONS(6083),
    [anon_sym_cmos] = ACTIONS(6083),
    [anon_sym_rcmos] = ACTIONS(6083),
    [anon_sym_bufif0] = ACTIONS(6083),
    [anon_sym_bufif1] = ACTIONS(6083),
    [anon_sym_notif0] = ACTIONS(6083),
    [anon_sym_notif1] = ACTIONS(6083),
    [anon_sym_nmos] = ACTIONS(6083),
    [anon_sym_pmos] = ACTIONS(6083),
    [anon_sym_rnmos] = ACTIONS(6083),
    [anon_sym_rpmos] = ACTIONS(6083),
    [anon_sym_nand] = ACTIONS(6083),
    [anon_sym_nor] = ACTIONS(6083),
    [anon_sym_xor] = ACTIONS(6083),
    [anon_sym_xnor] = ACTIONS(6083),
    [anon_sym_buf] = ACTIONS(6083),
    [anon_sym_tranif0] = ACTIONS(6083),
    [anon_sym_tranif1] = ACTIONS(6083),
    [anon_sym_rtranif1] = ACTIONS(6083),
    [anon_sym_rtranif0] = ACTIONS(6083),
    [anon_sym_tran] = ACTIONS(6083),
    [anon_sym_rtran] = ACTIONS(6083),
    [anon_sym_generate] = ACTIONS(6083),
    [anon_sym_endgenerate] = ACTIONS(6083),
    [anon_sym_for] = ACTIONS(6083),
    [anon_sym_initial] = ACTIONS(6083),
    [anon_sym_assign] = ACTIONS(6083),
    [anon_sym_alias] = ACTIONS(6083),
    [anon_sym_always_comb] = ACTIONS(6083),
    [anon_sym_always_latch] = ACTIONS(6083),
    [anon_sym_always_ff] = ACTIONS(6083),
    [anon_sym_final] = ACTIONS(6083),
    [anon_sym_global] = ACTIONS(6083),
    [anon_sym_LPAREN_STAR] = ACTIONS(6085),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6085),
    [anon_sym_DOLLARunit] = ACTIONS(6085),
  },
  [5083] = {
    [sym_simple_identifier] = ACTIONS(5876),
    [anon_sym_wire] = ACTIONS(5876),
    [anon_sym_tri] = ACTIONS(5876),
    [anon_sym_tri0] = ACTIONS(5876),
    [anon_sym_tri1] = ACTIONS(5876),
    [anon_sym_wand] = ACTIONS(5876),
    [anon_sym_triand] = ACTIONS(5876),
    [anon_sym_wor] = ACTIONS(5876),
    [anon_sym_trior] = ACTIONS(5876),
    [anon_sym_trireg] = ACTIONS(5876),
    [anon_sym_uwire] = ACTIONS(5876),
    [anon_sym_SEMI] = ACTIONS(5878),
    [anon_sym_extern] = ACTIONS(5876),
    [anon_sym_interface] = ACTIONS(5876),
    [anon_sym_checker] = ACTIONS(5876),
    [anon_sym_virtual] = ACTIONS(5876),
    [anon_sym_class] = ACTIONS(5876),
    [anon_sym_type] = ACTIONS(5876),
    [anon_sym_DOLLARfatal] = ACTIONS(5878),
    [anon_sym_DOLLARerror] = ACTIONS(5878),
    [anon_sym_DOLLARwarning] = ACTIONS(5878),
    [anon_sym_DOLLARinfo] = ACTIONS(5878),
    [anon_sym_default] = ACTIONS(5876),
    [anon_sym_clocking] = ACTIONS(5876),
    [anon_sym_defparam] = ACTIONS(5876),
    [anon_sym_bind] = ACTIONS(5876),
    [anon_sym_rand] = ACTIONS(5876),
    [anon_sym_const] = ACTIONS(5876),
    [anon_sym_function] = ACTIONS(5876),
    [anon_sym_static] = ACTIONS(5876),
    [anon_sym_constraint] = ACTIONS(5876),
    [anon_sym_if] = ACTIONS(5876),
    [anon_sym_else] = ACTIONS(5876),
    [anon_sym_LBRACK] = ACTIONS(5878),
    [anon_sym_localparam] = ACTIONS(5876),
    [anon_sym_parameter] = ACTIONS(5876),
    [anon_sym_var] = ACTIONS(5876),
    [anon_sym_import] = ACTIONS(5876),
    [anon_sym_export] = ACTIONS(5876),
    [anon_sym_genvar] = ACTIONS(5876),
    [anon_sym_interconnect] = ACTIONS(5876),
    [anon_sym_typedef] = ACTIONS(5876),
    [anon_sym_enum] = ACTIONS(5876),
    [anon_sym_struct] = ACTIONS(5876),
    [anon_sym_union] = ACTIONS(5876),
    [anon_sym_nettype] = ACTIONS(5876),
    [anon_sym_automatic] = ACTIONS(5876),
    [anon_sym_string] = ACTIONS(5876),
    [anon_sym_chandle] = ACTIONS(5876),
    [anon_sym_event] = ACTIONS(5876),
    [anon_sym_byte] = ACTIONS(5876),
    [anon_sym_shortint] = ACTIONS(5876),
    [anon_sym_int] = ACTIONS(5876),
    [anon_sym_longint] = ACTIONS(5876),
    [anon_sym_integer] = ACTIONS(5876),
    [anon_sym_time] = ACTIONS(5876),
    [anon_sym_bit] = ACTIONS(5876),
    [anon_sym_logic] = ACTIONS(5876),
    [anon_sym_reg] = ACTIONS(5876),
    [anon_sym_shortreal] = ACTIONS(5876),
    [anon_sym_real] = ACTIONS(5876),
    [anon_sym_realtime] = ACTIONS(5876),
    [anon_sym_supply0] = ACTIONS(5876),
    [anon_sym_supply1] = ACTIONS(5876),
    [anon_sym_signed] = ACTIONS(5876),
    [anon_sym_unsigned] = ACTIONS(5876),
    [anon_sym_task] = ACTIONS(5876),
    [anon_sym_assert] = ACTIONS(5876),
    [anon_sym_property] = ACTIONS(5876),
    [anon_sym_assume] = ACTIONS(5876),
    [anon_sym_cover] = ACTIONS(5876),
    [anon_sym_sequence] = ACTIONS(5876),
    [anon_sym_restrict] = ACTIONS(5876),
    [anon_sym_not] = ACTIONS(5876),
    [anon_sym_or] = ACTIONS(5876),
    [anon_sym_and] = ACTIONS(5876),
    [anon_sym_case] = ACTIONS(5876),
    [anon_sym_always] = ACTIONS(5876),
    [anon_sym_covergroup] = ACTIONS(5876),
    [anon_sym_end] = ACTIONS(5876),
    [anon_sym_let] = ACTIONS(5876),
    [anon_sym_pulldown] = ACTIONS(5876),
    [anon_sym_pullup] = ACTIONS(5876),
    [anon_sym_cmos] = ACTIONS(5876),
    [anon_sym_rcmos] = ACTIONS(5876),
    [anon_sym_bufif0] = ACTIONS(5876),
    [anon_sym_bufif1] = ACTIONS(5876),
    [anon_sym_notif0] = ACTIONS(5876),
    [anon_sym_notif1] = ACTIONS(5876),
    [anon_sym_nmos] = ACTIONS(5876),
    [anon_sym_pmos] = ACTIONS(5876),
    [anon_sym_rnmos] = ACTIONS(5876),
    [anon_sym_rpmos] = ACTIONS(5876),
    [anon_sym_nand] = ACTIONS(5876),
    [anon_sym_nor] = ACTIONS(5876),
    [anon_sym_xor] = ACTIONS(5876),
    [anon_sym_xnor] = ACTIONS(5876),
    [anon_sym_buf] = ACTIONS(5876),
    [anon_sym_tranif0] = ACTIONS(5876),
    [anon_sym_tranif1] = ACTIONS(5876),
    [anon_sym_rtranif1] = ACTIONS(5876),
    [anon_sym_rtranif0] = ACTIONS(5876),
    [anon_sym_tran] = ACTIONS(5876),
    [anon_sym_rtran] = ACTIONS(5876),
    [anon_sym_generate] = ACTIONS(5876),
    [anon_sym_for] = ACTIONS(5876),
    [anon_sym_initial] = ACTIONS(5876),
    [anon_sym_assign] = ACTIONS(5876),
    [anon_sym_alias] = ACTIONS(5876),
    [anon_sym_always_comb] = ACTIONS(5876),
    [anon_sym_always_latch] = ACTIONS(5876),
    [anon_sym_always_ff] = ACTIONS(5876),
    [anon_sym_final] = ACTIONS(5876),
    [anon_sym_global] = ACTIONS(5876),
    [anon_sym_LPAREN_STAR] = ACTIONS(5878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5878),
    [anon_sym_DOLLARunit] = ACTIONS(5878),
  },
  [5084] = {
    [sym_simple_identifier] = ACTIONS(4696),
    [anon_sym_wire] = ACTIONS(4696),
    [anon_sym_tri] = ACTIONS(4696),
    [anon_sym_tri0] = ACTIONS(4696),
    [anon_sym_tri1] = ACTIONS(4696),
    [anon_sym_wand] = ACTIONS(4696),
    [anon_sym_triand] = ACTIONS(4696),
    [anon_sym_wor] = ACTIONS(4696),
    [anon_sym_trior] = ACTIONS(4696),
    [anon_sym_trireg] = ACTIONS(4696),
    [anon_sym_uwire] = ACTIONS(4696),
    [anon_sym_SEMI] = ACTIONS(4694),
    [anon_sym_extern] = ACTIONS(4696),
    [anon_sym_interface] = ACTIONS(4696),
    [anon_sym_checker] = ACTIONS(4696),
    [anon_sym_virtual] = ACTIONS(4696),
    [anon_sym_class] = ACTIONS(4696),
    [anon_sym_type] = ACTIONS(4696),
    [anon_sym_DOLLARfatal] = ACTIONS(4694),
    [anon_sym_DOLLARerror] = ACTIONS(4694),
    [anon_sym_DOLLARwarning] = ACTIONS(4694),
    [anon_sym_DOLLARinfo] = ACTIONS(4694),
    [anon_sym_default] = ACTIONS(4696),
    [anon_sym_clocking] = ACTIONS(4696),
    [anon_sym_defparam] = ACTIONS(4696),
    [anon_sym_bind] = ACTIONS(4696),
    [anon_sym_rand] = ACTIONS(4696),
    [anon_sym_const] = ACTIONS(4696),
    [anon_sym_function] = ACTIONS(4696),
    [anon_sym_static] = ACTIONS(4696),
    [anon_sym_constraint] = ACTIONS(4696),
    [anon_sym_if] = ACTIONS(4696),
    [anon_sym_else] = ACTIONS(4696),
    [anon_sym_LBRACK] = ACTIONS(4694),
    [anon_sym_localparam] = ACTIONS(4696),
    [anon_sym_parameter] = ACTIONS(4696),
    [anon_sym_var] = ACTIONS(4696),
    [anon_sym_import] = ACTIONS(4696),
    [anon_sym_export] = ACTIONS(4696),
    [anon_sym_genvar] = ACTIONS(4696),
    [anon_sym_interconnect] = ACTIONS(4696),
    [anon_sym_typedef] = ACTIONS(4696),
    [anon_sym_enum] = ACTIONS(4696),
    [anon_sym_struct] = ACTIONS(4696),
    [anon_sym_union] = ACTIONS(4696),
    [anon_sym_nettype] = ACTIONS(4696),
    [anon_sym_automatic] = ACTIONS(4696),
    [anon_sym_string] = ACTIONS(4696),
    [anon_sym_chandle] = ACTIONS(4696),
    [anon_sym_event] = ACTIONS(4696),
    [anon_sym_byte] = ACTIONS(4696),
    [anon_sym_shortint] = ACTIONS(4696),
    [anon_sym_int] = ACTIONS(4696),
    [anon_sym_longint] = ACTIONS(4696),
    [anon_sym_integer] = ACTIONS(4696),
    [anon_sym_time] = ACTIONS(4696),
    [anon_sym_bit] = ACTIONS(4696),
    [anon_sym_logic] = ACTIONS(4696),
    [anon_sym_reg] = ACTIONS(4696),
    [anon_sym_shortreal] = ACTIONS(4696),
    [anon_sym_real] = ACTIONS(4696),
    [anon_sym_realtime] = ACTIONS(4696),
    [anon_sym_supply0] = ACTIONS(4696),
    [anon_sym_supply1] = ACTIONS(4696),
    [anon_sym_signed] = ACTIONS(4696),
    [anon_sym_unsigned] = ACTIONS(4696),
    [anon_sym_task] = ACTIONS(4696),
    [anon_sym_assert] = ACTIONS(4696),
    [anon_sym_property] = ACTIONS(4696),
    [anon_sym_assume] = ACTIONS(4696),
    [anon_sym_cover] = ACTIONS(4696),
    [anon_sym_sequence] = ACTIONS(4696),
    [anon_sym_restrict] = ACTIONS(4696),
    [anon_sym_not] = ACTIONS(4696),
    [anon_sym_or] = ACTIONS(4696),
    [anon_sym_and] = ACTIONS(4696),
    [anon_sym_case] = ACTIONS(4696),
    [anon_sym_always] = ACTIONS(4696),
    [anon_sym_covergroup] = ACTIONS(4696),
    [anon_sym_let] = ACTIONS(4696),
    [anon_sym_pulldown] = ACTIONS(4696),
    [anon_sym_pullup] = ACTIONS(4696),
    [anon_sym_cmos] = ACTIONS(4696),
    [anon_sym_rcmos] = ACTIONS(4696),
    [anon_sym_bufif0] = ACTIONS(4696),
    [anon_sym_bufif1] = ACTIONS(4696),
    [anon_sym_notif0] = ACTIONS(4696),
    [anon_sym_notif1] = ACTIONS(4696),
    [anon_sym_nmos] = ACTIONS(4696),
    [anon_sym_pmos] = ACTIONS(4696),
    [anon_sym_rnmos] = ACTIONS(4696),
    [anon_sym_rpmos] = ACTIONS(4696),
    [anon_sym_nand] = ACTIONS(4696),
    [anon_sym_nor] = ACTIONS(4696),
    [anon_sym_xor] = ACTIONS(4696),
    [anon_sym_xnor] = ACTIONS(4696),
    [anon_sym_buf] = ACTIONS(4696),
    [anon_sym_tranif0] = ACTIONS(4696),
    [anon_sym_tranif1] = ACTIONS(4696),
    [anon_sym_rtranif1] = ACTIONS(4696),
    [anon_sym_rtranif0] = ACTIONS(4696),
    [anon_sym_tran] = ACTIONS(4696),
    [anon_sym_rtran] = ACTIONS(4696),
    [anon_sym_generate] = ACTIONS(4696),
    [anon_sym_endgenerate] = ACTIONS(4696),
    [anon_sym_for] = ACTIONS(4696),
    [anon_sym_initial] = ACTIONS(4696),
    [anon_sym_assign] = ACTIONS(4696),
    [anon_sym_alias] = ACTIONS(4696),
    [anon_sym_always_comb] = ACTIONS(4696),
    [anon_sym_always_latch] = ACTIONS(4696),
    [anon_sym_always_ff] = ACTIONS(4696),
    [anon_sym_final] = ACTIONS(4696),
    [anon_sym_global] = ACTIONS(4696),
    [anon_sym_LPAREN_STAR] = ACTIONS(4694),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4694),
    [anon_sym_DOLLARunit] = ACTIONS(4694),
  },
  [5085] = {
    [sym_simple_identifier] = ACTIONS(5336),
    [anon_sym_wire] = ACTIONS(5336),
    [anon_sym_tri] = ACTIONS(5336),
    [anon_sym_tri0] = ACTIONS(5336),
    [anon_sym_tri1] = ACTIONS(5336),
    [anon_sym_wand] = ACTIONS(5336),
    [anon_sym_triand] = ACTIONS(5336),
    [anon_sym_wor] = ACTIONS(5336),
    [anon_sym_trior] = ACTIONS(5336),
    [anon_sym_trireg] = ACTIONS(5336),
    [anon_sym_uwire] = ACTIONS(5336),
    [anon_sym_SEMI] = ACTIONS(5334),
    [anon_sym_extern] = ACTIONS(5336),
    [anon_sym_interface] = ACTIONS(5336),
    [anon_sym_checker] = ACTIONS(5336),
    [anon_sym_virtual] = ACTIONS(5336),
    [anon_sym_class] = ACTIONS(5336),
    [anon_sym_type] = ACTIONS(5336),
    [anon_sym_DOLLARfatal] = ACTIONS(5334),
    [anon_sym_DOLLARerror] = ACTIONS(5334),
    [anon_sym_DOLLARwarning] = ACTIONS(5334),
    [anon_sym_DOLLARinfo] = ACTIONS(5334),
    [anon_sym_default] = ACTIONS(5336),
    [anon_sym_clocking] = ACTIONS(5336),
    [anon_sym_defparam] = ACTIONS(5336),
    [anon_sym_bind] = ACTIONS(5336),
    [anon_sym_rand] = ACTIONS(5336),
    [anon_sym_const] = ACTIONS(5336),
    [anon_sym_function] = ACTIONS(5336),
    [anon_sym_static] = ACTIONS(5336),
    [anon_sym_constraint] = ACTIONS(5336),
    [anon_sym_if] = ACTIONS(5336),
    [anon_sym_else] = ACTIONS(5336),
    [anon_sym_LBRACK] = ACTIONS(5334),
    [anon_sym_localparam] = ACTIONS(5336),
    [anon_sym_parameter] = ACTIONS(5336),
    [anon_sym_var] = ACTIONS(5336),
    [anon_sym_import] = ACTIONS(5336),
    [anon_sym_export] = ACTIONS(5336),
    [anon_sym_genvar] = ACTIONS(5336),
    [anon_sym_interconnect] = ACTIONS(5336),
    [anon_sym_typedef] = ACTIONS(5336),
    [anon_sym_enum] = ACTIONS(5336),
    [anon_sym_struct] = ACTIONS(5336),
    [anon_sym_union] = ACTIONS(5336),
    [anon_sym_nettype] = ACTIONS(5336),
    [anon_sym_automatic] = ACTIONS(5336),
    [anon_sym_string] = ACTIONS(5336),
    [anon_sym_chandle] = ACTIONS(5336),
    [anon_sym_event] = ACTIONS(5336),
    [anon_sym_byte] = ACTIONS(5336),
    [anon_sym_shortint] = ACTIONS(5336),
    [anon_sym_int] = ACTIONS(5336),
    [anon_sym_longint] = ACTIONS(5336),
    [anon_sym_integer] = ACTIONS(5336),
    [anon_sym_time] = ACTIONS(5336),
    [anon_sym_bit] = ACTIONS(5336),
    [anon_sym_logic] = ACTIONS(5336),
    [anon_sym_reg] = ACTIONS(5336),
    [anon_sym_shortreal] = ACTIONS(5336),
    [anon_sym_real] = ACTIONS(5336),
    [anon_sym_realtime] = ACTIONS(5336),
    [anon_sym_supply0] = ACTIONS(5336),
    [anon_sym_supply1] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(5336),
    [anon_sym_unsigned] = ACTIONS(5336),
    [anon_sym_task] = ACTIONS(5336),
    [anon_sym_assert] = ACTIONS(5336),
    [anon_sym_property] = ACTIONS(5336),
    [anon_sym_assume] = ACTIONS(5336),
    [anon_sym_cover] = ACTIONS(5336),
    [anon_sym_sequence] = ACTIONS(5336),
    [anon_sym_restrict] = ACTIONS(5336),
    [anon_sym_not] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5336),
    [anon_sym_and] = ACTIONS(5336),
    [anon_sym_case] = ACTIONS(5336),
    [anon_sym_always] = ACTIONS(5336),
    [anon_sym_covergroup] = ACTIONS(5336),
    [anon_sym_let] = ACTIONS(5336),
    [anon_sym_pulldown] = ACTIONS(5336),
    [anon_sym_pullup] = ACTIONS(5336),
    [anon_sym_cmos] = ACTIONS(5336),
    [anon_sym_rcmos] = ACTIONS(5336),
    [anon_sym_bufif0] = ACTIONS(5336),
    [anon_sym_bufif1] = ACTIONS(5336),
    [anon_sym_notif0] = ACTIONS(5336),
    [anon_sym_notif1] = ACTIONS(5336),
    [anon_sym_nmos] = ACTIONS(5336),
    [anon_sym_pmos] = ACTIONS(5336),
    [anon_sym_rnmos] = ACTIONS(5336),
    [anon_sym_rpmos] = ACTIONS(5336),
    [anon_sym_nand] = ACTIONS(5336),
    [anon_sym_nor] = ACTIONS(5336),
    [anon_sym_xor] = ACTIONS(5336),
    [anon_sym_xnor] = ACTIONS(5336),
    [anon_sym_buf] = ACTIONS(5336),
    [anon_sym_tranif0] = ACTIONS(5336),
    [anon_sym_tranif1] = ACTIONS(5336),
    [anon_sym_rtranif1] = ACTIONS(5336),
    [anon_sym_rtranif0] = ACTIONS(5336),
    [anon_sym_tran] = ACTIONS(5336),
    [anon_sym_rtran] = ACTIONS(5336),
    [anon_sym_generate] = ACTIONS(5336),
    [anon_sym_endgenerate] = ACTIONS(5336),
    [anon_sym_for] = ACTIONS(5336),
    [anon_sym_initial] = ACTIONS(5336),
    [anon_sym_assign] = ACTIONS(5336),
    [anon_sym_alias] = ACTIONS(5336),
    [anon_sym_always_comb] = ACTIONS(5336),
    [anon_sym_always_latch] = ACTIONS(5336),
    [anon_sym_always_ff] = ACTIONS(5336),
    [anon_sym_final] = ACTIONS(5336),
    [anon_sym_global] = ACTIONS(5336),
    [anon_sym_LPAREN_STAR] = ACTIONS(5334),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5334),
    [anon_sym_DOLLARunit] = ACTIONS(5334),
  },
  [5086] = {
    [sym_simple_identifier] = ACTIONS(5714),
    [anon_sym_wire] = ACTIONS(5714),
    [anon_sym_tri] = ACTIONS(5714),
    [anon_sym_tri0] = ACTIONS(5714),
    [anon_sym_tri1] = ACTIONS(5714),
    [anon_sym_wand] = ACTIONS(5714),
    [anon_sym_triand] = ACTIONS(5714),
    [anon_sym_wor] = ACTIONS(5714),
    [anon_sym_trior] = ACTIONS(5714),
    [anon_sym_trireg] = ACTIONS(5714),
    [anon_sym_uwire] = ACTIONS(5714),
    [anon_sym_SEMI] = ACTIONS(5716),
    [anon_sym_extern] = ACTIONS(5714),
    [anon_sym_interface] = ACTIONS(5714),
    [anon_sym_checker] = ACTIONS(5714),
    [anon_sym_virtual] = ACTIONS(5714),
    [anon_sym_class] = ACTIONS(5714),
    [anon_sym_type] = ACTIONS(5714),
    [anon_sym_DOLLARfatal] = ACTIONS(5716),
    [anon_sym_DOLLARerror] = ACTIONS(5716),
    [anon_sym_DOLLARwarning] = ACTIONS(5716),
    [anon_sym_DOLLARinfo] = ACTIONS(5716),
    [anon_sym_default] = ACTIONS(5714),
    [anon_sym_clocking] = ACTIONS(5714),
    [anon_sym_defparam] = ACTIONS(5714),
    [anon_sym_bind] = ACTIONS(5714),
    [anon_sym_rand] = ACTIONS(5714),
    [anon_sym_const] = ACTIONS(5714),
    [anon_sym_function] = ACTIONS(5714),
    [anon_sym_static] = ACTIONS(5714),
    [anon_sym_constraint] = ACTIONS(5714),
    [anon_sym_if] = ACTIONS(5714),
    [anon_sym_else] = ACTIONS(5714),
    [anon_sym_LBRACK] = ACTIONS(5716),
    [anon_sym_localparam] = ACTIONS(5714),
    [anon_sym_parameter] = ACTIONS(5714),
    [anon_sym_var] = ACTIONS(5714),
    [anon_sym_import] = ACTIONS(5714),
    [anon_sym_export] = ACTIONS(5714),
    [anon_sym_genvar] = ACTIONS(5714),
    [anon_sym_interconnect] = ACTIONS(5714),
    [anon_sym_typedef] = ACTIONS(5714),
    [anon_sym_enum] = ACTIONS(5714),
    [anon_sym_struct] = ACTIONS(5714),
    [anon_sym_union] = ACTIONS(5714),
    [anon_sym_nettype] = ACTIONS(5714),
    [anon_sym_automatic] = ACTIONS(5714),
    [anon_sym_string] = ACTIONS(5714),
    [anon_sym_chandle] = ACTIONS(5714),
    [anon_sym_event] = ACTIONS(5714),
    [anon_sym_byte] = ACTIONS(5714),
    [anon_sym_shortint] = ACTIONS(5714),
    [anon_sym_int] = ACTIONS(5714),
    [anon_sym_longint] = ACTIONS(5714),
    [anon_sym_integer] = ACTIONS(5714),
    [anon_sym_time] = ACTIONS(5714),
    [anon_sym_bit] = ACTIONS(5714),
    [anon_sym_logic] = ACTIONS(5714),
    [anon_sym_reg] = ACTIONS(5714),
    [anon_sym_shortreal] = ACTIONS(5714),
    [anon_sym_real] = ACTIONS(5714),
    [anon_sym_realtime] = ACTIONS(5714),
    [anon_sym_supply0] = ACTIONS(5714),
    [anon_sym_supply1] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5714),
    [anon_sym_unsigned] = ACTIONS(5714),
    [anon_sym_task] = ACTIONS(5714),
    [anon_sym_assert] = ACTIONS(5714),
    [anon_sym_property] = ACTIONS(5714),
    [anon_sym_assume] = ACTIONS(5714),
    [anon_sym_cover] = ACTIONS(5714),
    [anon_sym_sequence] = ACTIONS(5714),
    [anon_sym_restrict] = ACTIONS(5714),
    [anon_sym_not] = ACTIONS(5714),
    [anon_sym_or] = ACTIONS(5714),
    [anon_sym_and] = ACTIONS(5714),
    [anon_sym_case] = ACTIONS(5714),
    [anon_sym_always] = ACTIONS(5714),
    [anon_sym_covergroup] = ACTIONS(5714),
    [anon_sym_end] = ACTIONS(5714),
    [anon_sym_let] = ACTIONS(5714),
    [anon_sym_pulldown] = ACTIONS(5714),
    [anon_sym_pullup] = ACTIONS(5714),
    [anon_sym_cmos] = ACTIONS(5714),
    [anon_sym_rcmos] = ACTIONS(5714),
    [anon_sym_bufif0] = ACTIONS(5714),
    [anon_sym_bufif1] = ACTIONS(5714),
    [anon_sym_notif0] = ACTIONS(5714),
    [anon_sym_notif1] = ACTIONS(5714),
    [anon_sym_nmos] = ACTIONS(5714),
    [anon_sym_pmos] = ACTIONS(5714),
    [anon_sym_rnmos] = ACTIONS(5714),
    [anon_sym_rpmos] = ACTIONS(5714),
    [anon_sym_nand] = ACTIONS(5714),
    [anon_sym_nor] = ACTIONS(5714),
    [anon_sym_xor] = ACTIONS(5714),
    [anon_sym_xnor] = ACTIONS(5714),
    [anon_sym_buf] = ACTIONS(5714),
    [anon_sym_tranif0] = ACTIONS(5714),
    [anon_sym_tranif1] = ACTIONS(5714),
    [anon_sym_rtranif1] = ACTIONS(5714),
    [anon_sym_rtranif0] = ACTIONS(5714),
    [anon_sym_tran] = ACTIONS(5714),
    [anon_sym_rtran] = ACTIONS(5714),
    [anon_sym_generate] = ACTIONS(5714),
    [anon_sym_for] = ACTIONS(5714),
    [anon_sym_initial] = ACTIONS(5714),
    [anon_sym_assign] = ACTIONS(5714),
    [anon_sym_alias] = ACTIONS(5714),
    [anon_sym_always_comb] = ACTIONS(5714),
    [anon_sym_always_latch] = ACTIONS(5714),
    [anon_sym_always_ff] = ACTIONS(5714),
    [anon_sym_final] = ACTIONS(5714),
    [anon_sym_global] = ACTIONS(5714),
    [anon_sym_LPAREN_STAR] = ACTIONS(5716),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5716),
    [anon_sym_DOLLARunit] = ACTIONS(5716),
  },
  [5087] = {
    [sym_simple_identifier] = ACTIONS(6673),
    [anon_sym_wire] = ACTIONS(6673),
    [anon_sym_tri] = ACTIONS(6673),
    [anon_sym_tri0] = ACTIONS(6673),
    [anon_sym_tri1] = ACTIONS(6673),
    [anon_sym_wand] = ACTIONS(6673),
    [anon_sym_triand] = ACTIONS(6673),
    [anon_sym_wor] = ACTIONS(6673),
    [anon_sym_trior] = ACTIONS(6673),
    [anon_sym_trireg] = ACTIONS(6673),
    [anon_sym_uwire] = ACTIONS(6673),
    [anon_sym_SEMI] = ACTIONS(6675),
    [anon_sym_extern] = ACTIONS(6673),
    [anon_sym_interface] = ACTIONS(6673),
    [anon_sym_checker] = ACTIONS(6673),
    [anon_sym_virtual] = ACTIONS(6673),
    [anon_sym_class] = ACTIONS(6673),
    [anon_sym_type] = ACTIONS(6673),
    [anon_sym_DOLLARfatal] = ACTIONS(6675),
    [anon_sym_DOLLARerror] = ACTIONS(6675),
    [anon_sym_DOLLARwarning] = ACTIONS(6675),
    [anon_sym_DOLLARinfo] = ACTIONS(6675),
    [anon_sym_default] = ACTIONS(6673),
    [anon_sym_clocking] = ACTIONS(6673),
    [anon_sym_defparam] = ACTIONS(6673),
    [anon_sym_bind] = ACTIONS(6673),
    [anon_sym_rand] = ACTIONS(6673),
    [anon_sym_const] = ACTIONS(6673),
    [anon_sym_function] = ACTIONS(6673),
    [anon_sym_static] = ACTIONS(6673),
    [anon_sym_constraint] = ACTIONS(6673),
    [anon_sym_if] = ACTIONS(6673),
    [anon_sym_else] = ACTIONS(6673),
    [anon_sym_LBRACK] = ACTIONS(6675),
    [anon_sym_localparam] = ACTIONS(6673),
    [anon_sym_parameter] = ACTIONS(6673),
    [anon_sym_var] = ACTIONS(6673),
    [anon_sym_import] = ACTIONS(6673),
    [anon_sym_export] = ACTIONS(6673),
    [anon_sym_genvar] = ACTIONS(6673),
    [anon_sym_interconnect] = ACTIONS(6673),
    [anon_sym_typedef] = ACTIONS(6673),
    [anon_sym_enum] = ACTIONS(6673),
    [anon_sym_struct] = ACTIONS(6673),
    [anon_sym_union] = ACTIONS(6673),
    [anon_sym_nettype] = ACTIONS(6673),
    [anon_sym_automatic] = ACTIONS(6673),
    [anon_sym_string] = ACTIONS(6673),
    [anon_sym_chandle] = ACTIONS(6673),
    [anon_sym_event] = ACTIONS(6673),
    [anon_sym_byte] = ACTIONS(6673),
    [anon_sym_shortint] = ACTIONS(6673),
    [anon_sym_int] = ACTIONS(6673),
    [anon_sym_longint] = ACTIONS(6673),
    [anon_sym_integer] = ACTIONS(6673),
    [anon_sym_time] = ACTIONS(6673),
    [anon_sym_bit] = ACTIONS(6673),
    [anon_sym_logic] = ACTIONS(6673),
    [anon_sym_reg] = ACTIONS(6673),
    [anon_sym_shortreal] = ACTIONS(6673),
    [anon_sym_real] = ACTIONS(6673),
    [anon_sym_realtime] = ACTIONS(6673),
    [anon_sym_supply0] = ACTIONS(6673),
    [anon_sym_supply1] = ACTIONS(6673),
    [anon_sym_signed] = ACTIONS(6673),
    [anon_sym_unsigned] = ACTIONS(6673),
    [anon_sym_task] = ACTIONS(6673),
    [anon_sym_assert] = ACTIONS(6673),
    [anon_sym_property] = ACTIONS(6673),
    [anon_sym_assume] = ACTIONS(6673),
    [anon_sym_cover] = ACTIONS(6673),
    [anon_sym_sequence] = ACTIONS(6673),
    [anon_sym_restrict] = ACTIONS(6673),
    [anon_sym_not] = ACTIONS(6673),
    [anon_sym_or] = ACTIONS(6673),
    [anon_sym_and] = ACTIONS(6673),
    [anon_sym_case] = ACTIONS(6673),
    [anon_sym_always] = ACTIONS(6673),
    [anon_sym_covergroup] = ACTIONS(6673),
    [anon_sym_end] = ACTIONS(6673),
    [anon_sym_let] = ACTIONS(6673),
    [anon_sym_pulldown] = ACTIONS(6673),
    [anon_sym_pullup] = ACTIONS(6673),
    [anon_sym_cmos] = ACTIONS(6673),
    [anon_sym_rcmos] = ACTIONS(6673),
    [anon_sym_bufif0] = ACTIONS(6673),
    [anon_sym_bufif1] = ACTIONS(6673),
    [anon_sym_notif0] = ACTIONS(6673),
    [anon_sym_notif1] = ACTIONS(6673),
    [anon_sym_nmos] = ACTIONS(6673),
    [anon_sym_pmos] = ACTIONS(6673),
    [anon_sym_rnmos] = ACTIONS(6673),
    [anon_sym_rpmos] = ACTIONS(6673),
    [anon_sym_nand] = ACTIONS(6673),
    [anon_sym_nor] = ACTIONS(6673),
    [anon_sym_xor] = ACTIONS(6673),
    [anon_sym_xnor] = ACTIONS(6673),
    [anon_sym_buf] = ACTIONS(6673),
    [anon_sym_tranif0] = ACTIONS(6673),
    [anon_sym_tranif1] = ACTIONS(6673),
    [anon_sym_rtranif1] = ACTIONS(6673),
    [anon_sym_rtranif0] = ACTIONS(6673),
    [anon_sym_tran] = ACTIONS(6673),
    [anon_sym_rtran] = ACTIONS(6673),
    [anon_sym_generate] = ACTIONS(6673),
    [anon_sym_for] = ACTIONS(6673),
    [anon_sym_initial] = ACTIONS(6673),
    [anon_sym_assign] = ACTIONS(6673),
    [anon_sym_alias] = ACTIONS(6673),
    [anon_sym_always_comb] = ACTIONS(6673),
    [anon_sym_always_latch] = ACTIONS(6673),
    [anon_sym_always_ff] = ACTIONS(6673),
    [anon_sym_final] = ACTIONS(6673),
    [anon_sym_global] = ACTIONS(6673),
    [anon_sym_LPAREN_STAR] = ACTIONS(6675),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6675),
    [anon_sym_DOLLARunit] = ACTIONS(6675),
  },
  [5088] = {
    [sym_simple_identifier] = ACTIONS(5340),
    [anon_sym_wire] = ACTIONS(5340),
    [anon_sym_tri] = ACTIONS(5340),
    [anon_sym_tri0] = ACTIONS(5340),
    [anon_sym_tri1] = ACTIONS(5340),
    [anon_sym_wand] = ACTIONS(5340),
    [anon_sym_triand] = ACTIONS(5340),
    [anon_sym_wor] = ACTIONS(5340),
    [anon_sym_trior] = ACTIONS(5340),
    [anon_sym_trireg] = ACTIONS(5340),
    [anon_sym_uwire] = ACTIONS(5340),
    [anon_sym_SEMI] = ACTIONS(5338),
    [anon_sym_extern] = ACTIONS(5340),
    [anon_sym_interface] = ACTIONS(5340),
    [anon_sym_checker] = ACTIONS(5340),
    [anon_sym_virtual] = ACTIONS(5340),
    [anon_sym_class] = ACTIONS(5340),
    [anon_sym_type] = ACTIONS(5340),
    [anon_sym_DOLLARfatal] = ACTIONS(5338),
    [anon_sym_DOLLARerror] = ACTIONS(5338),
    [anon_sym_DOLLARwarning] = ACTIONS(5338),
    [anon_sym_DOLLARinfo] = ACTIONS(5338),
    [anon_sym_default] = ACTIONS(5340),
    [anon_sym_clocking] = ACTIONS(5340),
    [anon_sym_defparam] = ACTIONS(5340),
    [anon_sym_bind] = ACTIONS(5340),
    [anon_sym_rand] = ACTIONS(5340),
    [anon_sym_const] = ACTIONS(5340),
    [anon_sym_function] = ACTIONS(5340),
    [anon_sym_static] = ACTIONS(5340),
    [anon_sym_constraint] = ACTIONS(5340),
    [anon_sym_if] = ACTIONS(5340),
    [anon_sym_else] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5338),
    [anon_sym_localparam] = ACTIONS(5340),
    [anon_sym_parameter] = ACTIONS(5340),
    [anon_sym_var] = ACTIONS(5340),
    [anon_sym_import] = ACTIONS(5340),
    [anon_sym_export] = ACTIONS(5340),
    [anon_sym_genvar] = ACTIONS(5340),
    [anon_sym_interconnect] = ACTIONS(5340),
    [anon_sym_typedef] = ACTIONS(5340),
    [anon_sym_enum] = ACTIONS(5340),
    [anon_sym_struct] = ACTIONS(5340),
    [anon_sym_union] = ACTIONS(5340),
    [anon_sym_nettype] = ACTIONS(5340),
    [anon_sym_automatic] = ACTIONS(5340),
    [anon_sym_string] = ACTIONS(5340),
    [anon_sym_chandle] = ACTIONS(5340),
    [anon_sym_event] = ACTIONS(5340),
    [anon_sym_byte] = ACTIONS(5340),
    [anon_sym_shortint] = ACTIONS(5340),
    [anon_sym_int] = ACTIONS(5340),
    [anon_sym_longint] = ACTIONS(5340),
    [anon_sym_integer] = ACTIONS(5340),
    [anon_sym_time] = ACTIONS(5340),
    [anon_sym_bit] = ACTIONS(5340),
    [anon_sym_logic] = ACTIONS(5340),
    [anon_sym_reg] = ACTIONS(5340),
    [anon_sym_shortreal] = ACTIONS(5340),
    [anon_sym_real] = ACTIONS(5340),
    [anon_sym_realtime] = ACTIONS(5340),
    [anon_sym_supply0] = ACTIONS(5340),
    [anon_sym_supply1] = ACTIONS(5340),
    [anon_sym_signed] = ACTIONS(5340),
    [anon_sym_unsigned] = ACTIONS(5340),
    [anon_sym_task] = ACTIONS(5340),
    [anon_sym_assert] = ACTIONS(5340),
    [anon_sym_property] = ACTIONS(5340),
    [anon_sym_assume] = ACTIONS(5340),
    [anon_sym_cover] = ACTIONS(5340),
    [anon_sym_sequence] = ACTIONS(5340),
    [anon_sym_restrict] = ACTIONS(5340),
    [anon_sym_not] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_case] = ACTIONS(5340),
    [anon_sym_always] = ACTIONS(5340),
    [anon_sym_covergroup] = ACTIONS(5340),
    [anon_sym_let] = ACTIONS(5340),
    [anon_sym_pulldown] = ACTIONS(5340),
    [anon_sym_pullup] = ACTIONS(5340),
    [anon_sym_cmos] = ACTIONS(5340),
    [anon_sym_rcmos] = ACTIONS(5340),
    [anon_sym_bufif0] = ACTIONS(5340),
    [anon_sym_bufif1] = ACTIONS(5340),
    [anon_sym_notif0] = ACTIONS(5340),
    [anon_sym_notif1] = ACTIONS(5340),
    [anon_sym_nmos] = ACTIONS(5340),
    [anon_sym_pmos] = ACTIONS(5340),
    [anon_sym_rnmos] = ACTIONS(5340),
    [anon_sym_rpmos] = ACTIONS(5340),
    [anon_sym_nand] = ACTIONS(5340),
    [anon_sym_nor] = ACTIONS(5340),
    [anon_sym_xor] = ACTIONS(5340),
    [anon_sym_xnor] = ACTIONS(5340),
    [anon_sym_buf] = ACTIONS(5340),
    [anon_sym_tranif0] = ACTIONS(5340),
    [anon_sym_tranif1] = ACTIONS(5340),
    [anon_sym_rtranif1] = ACTIONS(5340),
    [anon_sym_rtranif0] = ACTIONS(5340),
    [anon_sym_tran] = ACTIONS(5340),
    [anon_sym_rtran] = ACTIONS(5340),
    [anon_sym_generate] = ACTIONS(5340),
    [anon_sym_endgenerate] = ACTIONS(5340),
    [anon_sym_for] = ACTIONS(5340),
    [anon_sym_initial] = ACTIONS(5340),
    [anon_sym_assign] = ACTIONS(5340),
    [anon_sym_alias] = ACTIONS(5340),
    [anon_sym_always_comb] = ACTIONS(5340),
    [anon_sym_always_latch] = ACTIONS(5340),
    [anon_sym_always_ff] = ACTIONS(5340),
    [anon_sym_final] = ACTIONS(5340),
    [anon_sym_global] = ACTIONS(5340),
    [anon_sym_LPAREN_STAR] = ACTIONS(5338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5338),
    [anon_sym_DOLLARunit] = ACTIONS(5338),
  },
  [5089] = {
    [sym_simple_identifier] = ACTIONS(6715),
    [anon_sym_wire] = ACTIONS(6715),
    [anon_sym_tri] = ACTIONS(6715),
    [anon_sym_tri0] = ACTIONS(6715),
    [anon_sym_tri1] = ACTIONS(6715),
    [anon_sym_wand] = ACTIONS(6715),
    [anon_sym_triand] = ACTIONS(6715),
    [anon_sym_wor] = ACTIONS(6715),
    [anon_sym_trior] = ACTIONS(6715),
    [anon_sym_trireg] = ACTIONS(6715),
    [anon_sym_uwire] = ACTIONS(6715),
    [anon_sym_SEMI] = ACTIONS(6717),
    [anon_sym_extern] = ACTIONS(6715),
    [anon_sym_interface] = ACTIONS(6715),
    [anon_sym_checker] = ACTIONS(6715),
    [anon_sym_virtual] = ACTIONS(6715),
    [anon_sym_class] = ACTIONS(6715),
    [anon_sym_type] = ACTIONS(6715),
    [anon_sym_DOLLARfatal] = ACTIONS(6717),
    [anon_sym_DOLLARerror] = ACTIONS(6717),
    [anon_sym_DOLLARwarning] = ACTIONS(6717),
    [anon_sym_DOLLARinfo] = ACTIONS(6717),
    [anon_sym_default] = ACTIONS(6715),
    [anon_sym_clocking] = ACTIONS(6715),
    [anon_sym_defparam] = ACTIONS(6715),
    [anon_sym_bind] = ACTIONS(6715),
    [anon_sym_rand] = ACTIONS(6715),
    [anon_sym_const] = ACTIONS(6715),
    [anon_sym_function] = ACTIONS(6715),
    [anon_sym_static] = ACTIONS(6715),
    [anon_sym_constraint] = ACTIONS(6715),
    [anon_sym_if] = ACTIONS(6715),
    [anon_sym_else] = ACTIONS(6715),
    [anon_sym_LBRACK] = ACTIONS(6717),
    [anon_sym_localparam] = ACTIONS(6715),
    [anon_sym_parameter] = ACTIONS(6715),
    [anon_sym_var] = ACTIONS(6715),
    [anon_sym_import] = ACTIONS(6715),
    [anon_sym_export] = ACTIONS(6715),
    [anon_sym_genvar] = ACTIONS(6715),
    [anon_sym_interconnect] = ACTIONS(6715),
    [anon_sym_typedef] = ACTIONS(6715),
    [anon_sym_enum] = ACTIONS(6715),
    [anon_sym_struct] = ACTIONS(6715),
    [anon_sym_union] = ACTIONS(6715),
    [anon_sym_nettype] = ACTIONS(6715),
    [anon_sym_automatic] = ACTIONS(6715),
    [anon_sym_string] = ACTIONS(6715),
    [anon_sym_chandle] = ACTIONS(6715),
    [anon_sym_event] = ACTIONS(6715),
    [anon_sym_byte] = ACTIONS(6715),
    [anon_sym_shortint] = ACTIONS(6715),
    [anon_sym_int] = ACTIONS(6715),
    [anon_sym_longint] = ACTIONS(6715),
    [anon_sym_integer] = ACTIONS(6715),
    [anon_sym_time] = ACTIONS(6715),
    [anon_sym_bit] = ACTIONS(6715),
    [anon_sym_logic] = ACTIONS(6715),
    [anon_sym_reg] = ACTIONS(6715),
    [anon_sym_shortreal] = ACTIONS(6715),
    [anon_sym_real] = ACTIONS(6715),
    [anon_sym_realtime] = ACTIONS(6715),
    [anon_sym_supply0] = ACTIONS(6715),
    [anon_sym_supply1] = ACTIONS(6715),
    [anon_sym_signed] = ACTIONS(6715),
    [anon_sym_unsigned] = ACTIONS(6715),
    [anon_sym_task] = ACTIONS(6715),
    [anon_sym_assert] = ACTIONS(6715),
    [anon_sym_property] = ACTIONS(6715),
    [anon_sym_assume] = ACTIONS(6715),
    [anon_sym_cover] = ACTIONS(6715),
    [anon_sym_sequence] = ACTIONS(6715),
    [anon_sym_restrict] = ACTIONS(6715),
    [anon_sym_not] = ACTIONS(6715),
    [anon_sym_or] = ACTIONS(6715),
    [anon_sym_and] = ACTIONS(6715),
    [anon_sym_case] = ACTIONS(6715),
    [anon_sym_always] = ACTIONS(6715),
    [anon_sym_covergroup] = ACTIONS(6715),
    [anon_sym_end] = ACTIONS(6715),
    [anon_sym_let] = ACTIONS(6715),
    [anon_sym_pulldown] = ACTIONS(6715),
    [anon_sym_pullup] = ACTIONS(6715),
    [anon_sym_cmos] = ACTIONS(6715),
    [anon_sym_rcmos] = ACTIONS(6715),
    [anon_sym_bufif0] = ACTIONS(6715),
    [anon_sym_bufif1] = ACTIONS(6715),
    [anon_sym_notif0] = ACTIONS(6715),
    [anon_sym_notif1] = ACTIONS(6715),
    [anon_sym_nmos] = ACTIONS(6715),
    [anon_sym_pmos] = ACTIONS(6715),
    [anon_sym_rnmos] = ACTIONS(6715),
    [anon_sym_rpmos] = ACTIONS(6715),
    [anon_sym_nand] = ACTIONS(6715),
    [anon_sym_nor] = ACTIONS(6715),
    [anon_sym_xor] = ACTIONS(6715),
    [anon_sym_xnor] = ACTIONS(6715),
    [anon_sym_buf] = ACTIONS(6715),
    [anon_sym_tranif0] = ACTIONS(6715),
    [anon_sym_tranif1] = ACTIONS(6715),
    [anon_sym_rtranif1] = ACTIONS(6715),
    [anon_sym_rtranif0] = ACTIONS(6715),
    [anon_sym_tran] = ACTIONS(6715),
    [anon_sym_rtran] = ACTIONS(6715),
    [anon_sym_generate] = ACTIONS(6715),
    [anon_sym_for] = ACTIONS(6715),
    [anon_sym_initial] = ACTIONS(6715),
    [anon_sym_assign] = ACTIONS(6715),
    [anon_sym_alias] = ACTIONS(6715),
    [anon_sym_always_comb] = ACTIONS(6715),
    [anon_sym_always_latch] = ACTIONS(6715),
    [anon_sym_always_ff] = ACTIONS(6715),
    [anon_sym_final] = ACTIONS(6715),
    [anon_sym_global] = ACTIONS(6715),
    [anon_sym_LPAREN_STAR] = ACTIONS(6717),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6717),
    [anon_sym_DOLLARunit] = ACTIONS(6717),
  },
  [5090] = {
    [sym_simple_identifier] = ACTIONS(6529),
    [anon_sym_wire] = ACTIONS(6529),
    [anon_sym_tri] = ACTIONS(6529),
    [anon_sym_tri0] = ACTIONS(6529),
    [anon_sym_tri1] = ACTIONS(6529),
    [anon_sym_wand] = ACTIONS(6529),
    [anon_sym_triand] = ACTIONS(6529),
    [anon_sym_wor] = ACTIONS(6529),
    [anon_sym_trior] = ACTIONS(6529),
    [anon_sym_trireg] = ACTIONS(6529),
    [anon_sym_uwire] = ACTIONS(6529),
    [anon_sym_SEMI] = ACTIONS(6531),
    [anon_sym_extern] = ACTIONS(6529),
    [anon_sym_interface] = ACTIONS(6529),
    [anon_sym_checker] = ACTIONS(6529),
    [anon_sym_virtual] = ACTIONS(6529),
    [anon_sym_class] = ACTIONS(6529),
    [anon_sym_type] = ACTIONS(6529),
    [anon_sym_DOLLARfatal] = ACTIONS(6531),
    [anon_sym_DOLLARerror] = ACTIONS(6531),
    [anon_sym_DOLLARwarning] = ACTIONS(6531),
    [anon_sym_DOLLARinfo] = ACTIONS(6531),
    [anon_sym_default] = ACTIONS(6529),
    [anon_sym_clocking] = ACTIONS(6529),
    [anon_sym_defparam] = ACTIONS(6529),
    [anon_sym_bind] = ACTIONS(6529),
    [anon_sym_rand] = ACTIONS(6529),
    [anon_sym_const] = ACTIONS(6529),
    [anon_sym_function] = ACTIONS(6529),
    [anon_sym_static] = ACTIONS(6529),
    [anon_sym_constraint] = ACTIONS(6529),
    [anon_sym_if] = ACTIONS(6529),
    [anon_sym_else] = ACTIONS(6529),
    [anon_sym_LBRACK] = ACTIONS(6531),
    [anon_sym_localparam] = ACTIONS(6529),
    [anon_sym_parameter] = ACTIONS(6529),
    [anon_sym_var] = ACTIONS(6529),
    [anon_sym_import] = ACTIONS(6529),
    [anon_sym_export] = ACTIONS(6529),
    [anon_sym_genvar] = ACTIONS(6529),
    [anon_sym_interconnect] = ACTIONS(6529),
    [anon_sym_typedef] = ACTIONS(6529),
    [anon_sym_enum] = ACTIONS(6529),
    [anon_sym_struct] = ACTIONS(6529),
    [anon_sym_union] = ACTIONS(6529),
    [anon_sym_nettype] = ACTIONS(6529),
    [anon_sym_automatic] = ACTIONS(6529),
    [anon_sym_string] = ACTIONS(6529),
    [anon_sym_chandle] = ACTIONS(6529),
    [anon_sym_event] = ACTIONS(6529),
    [anon_sym_byte] = ACTIONS(6529),
    [anon_sym_shortint] = ACTIONS(6529),
    [anon_sym_int] = ACTIONS(6529),
    [anon_sym_longint] = ACTIONS(6529),
    [anon_sym_integer] = ACTIONS(6529),
    [anon_sym_time] = ACTIONS(6529),
    [anon_sym_bit] = ACTIONS(6529),
    [anon_sym_logic] = ACTIONS(6529),
    [anon_sym_reg] = ACTIONS(6529),
    [anon_sym_shortreal] = ACTIONS(6529),
    [anon_sym_real] = ACTIONS(6529),
    [anon_sym_realtime] = ACTIONS(6529),
    [anon_sym_supply0] = ACTIONS(6529),
    [anon_sym_supply1] = ACTIONS(6529),
    [anon_sym_signed] = ACTIONS(6529),
    [anon_sym_unsigned] = ACTIONS(6529),
    [anon_sym_task] = ACTIONS(6529),
    [anon_sym_assert] = ACTIONS(6529),
    [anon_sym_property] = ACTIONS(6529),
    [anon_sym_assume] = ACTIONS(6529),
    [anon_sym_cover] = ACTIONS(6529),
    [anon_sym_sequence] = ACTIONS(6529),
    [anon_sym_restrict] = ACTIONS(6529),
    [anon_sym_not] = ACTIONS(6529),
    [anon_sym_or] = ACTIONS(6529),
    [anon_sym_and] = ACTIONS(6529),
    [anon_sym_case] = ACTIONS(6529),
    [anon_sym_always] = ACTIONS(6529),
    [anon_sym_covergroup] = ACTIONS(6529),
    [anon_sym_let] = ACTIONS(6529),
    [anon_sym_pulldown] = ACTIONS(6529),
    [anon_sym_pullup] = ACTIONS(6529),
    [anon_sym_cmos] = ACTIONS(6529),
    [anon_sym_rcmos] = ACTIONS(6529),
    [anon_sym_bufif0] = ACTIONS(6529),
    [anon_sym_bufif1] = ACTIONS(6529),
    [anon_sym_notif0] = ACTIONS(6529),
    [anon_sym_notif1] = ACTIONS(6529),
    [anon_sym_nmos] = ACTIONS(6529),
    [anon_sym_pmos] = ACTIONS(6529),
    [anon_sym_rnmos] = ACTIONS(6529),
    [anon_sym_rpmos] = ACTIONS(6529),
    [anon_sym_nand] = ACTIONS(6529),
    [anon_sym_nor] = ACTIONS(6529),
    [anon_sym_xor] = ACTIONS(6529),
    [anon_sym_xnor] = ACTIONS(6529),
    [anon_sym_buf] = ACTIONS(6529),
    [anon_sym_tranif0] = ACTIONS(6529),
    [anon_sym_tranif1] = ACTIONS(6529),
    [anon_sym_rtranif1] = ACTIONS(6529),
    [anon_sym_rtranif0] = ACTIONS(6529),
    [anon_sym_tran] = ACTIONS(6529),
    [anon_sym_rtran] = ACTIONS(6529),
    [anon_sym_generate] = ACTIONS(6529),
    [anon_sym_endgenerate] = ACTIONS(6529),
    [anon_sym_for] = ACTIONS(6529),
    [anon_sym_initial] = ACTIONS(6529),
    [anon_sym_assign] = ACTIONS(6529),
    [anon_sym_alias] = ACTIONS(6529),
    [anon_sym_always_comb] = ACTIONS(6529),
    [anon_sym_always_latch] = ACTIONS(6529),
    [anon_sym_always_ff] = ACTIONS(6529),
    [anon_sym_final] = ACTIONS(6529),
    [anon_sym_global] = ACTIONS(6529),
    [anon_sym_LPAREN_STAR] = ACTIONS(6531),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6531),
    [anon_sym_DOLLARunit] = ACTIONS(6531),
  },
  [5091] = {
    [sym_simple_identifier] = ACTIONS(5170),
    [anon_sym_wire] = ACTIONS(5170),
    [anon_sym_tri] = ACTIONS(5170),
    [anon_sym_tri0] = ACTIONS(5170),
    [anon_sym_tri1] = ACTIONS(5170),
    [anon_sym_wand] = ACTIONS(5170),
    [anon_sym_triand] = ACTIONS(5170),
    [anon_sym_wor] = ACTIONS(5170),
    [anon_sym_trior] = ACTIONS(5170),
    [anon_sym_trireg] = ACTIONS(5170),
    [anon_sym_uwire] = ACTIONS(5170),
    [anon_sym_SEMI] = ACTIONS(5168),
    [anon_sym_extern] = ACTIONS(5170),
    [anon_sym_interface] = ACTIONS(5170),
    [anon_sym_checker] = ACTIONS(5170),
    [anon_sym_virtual] = ACTIONS(5170),
    [anon_sym_class] = ACTIONS(5170),
    [anon_sym_type] = ACTIONS(5170),
    [anon_sym_DOLLARfatal] = ACTIONS(5168),
    [anon_sym_DOLLARerror] = ACTIONS(5168),
    [anon_sym_DOLLARwarning] = ACTIONS(5168),
    [anon_sym_DOLLARinfo] = ACTIONS(5168),
    [anon_sym_default] = ACTIONS(5170),
    [anon_sym_clocking] = ACTIONS(5170),
    [anon_sym_defparam] = ACTIONS(5170),
    [anon_sym_bind] = ACTIONS(5170),
    [anon_sym_rand] = ACTIONS(5170),
    [anon_sym_const] = ACTIONS(5170),
    [anon_sym_function] = ACTIONS(5170),
    [anon_sym_static] = ACTIONS(5170),
    [anon_sym_constraint] = ACTIONS(5170),
    [anon_sym_if] = ACTIONS(5170),
    [anon_sym_else] = ACTIONS(5170),
    [anon_sym_LBRACK] = ACTIONS(5168),
    [anon_sym_localparam] = ACTIONS(5170),
    [anon_sym_parameter] = ACTIONS(5170),
    [anon_sym_var] = ACTIONS(5170),
    [anon_sym_import] = ACTIONS(5170),
    [anon_sym_export] = ACTIONS(5170),
    [anon_sym_genvar] = ACTIONS(5170),
    [anon_sym_interconnect] = ACTIONS(5170),
    [anon_sym_typedef] = ACTIONS(5170),
    [anon_sym_enum] = ACTIONS(5170),
    [anon_sym_struct] = ACTIONS(5170),
    [anon_sym_union] = ACTIONS(5170),
    [anon_sym_nettype] = ACTIONS(5170),
    [anon_sym_automatic] = ACTIONS(5170),
    [anon_sym_string] = ACTIONS(5170),
    [anon_sym_chandle] = ACTIONS(5170),
    [anon_sym_event] = ACTIONS(5170),
    [anon_sym_byte] = ACTIONS(5170),
    [anon_sym_shortint] = ACTIONS(5170),
    [anon_sym_int] = ACTIONS(5170),
    [anon_sym_longint] = ACTIONS(5170),
    [anon_sym_integer] = ACTIONS(5170),
    [anon_sym_time] = ACTIONS(5170),
    [anon_sym_bit] = ACTIONS(5170),
    [anon_sym_logic] = ACTIONS(5170),
    [anon_sym_reg] = ACTIONS(5170),
    [anon_sym_shortreal] = ACTIONS(5170),
    [anon_sym_real] = ACTIONS(5170),
    [anon_sym_realtime] = ACTIONS(5170),
    [anon_sym_supply0] = ACTIONS(5170),
    [anon_sym_supply1] = ACTIONS(5170),
    [anon_sym_signed] = ACTIONS(5170),
    [anon_sym_unsigned] = ACTIONS(5170),
    [anon_sym_task] = ACTIONS(5170),
    [anon_sym_assert] = ACTIONS(5170),
    [anon_sym_property] = ACTIONS(5170),
    [anon_sym_assume] = ACTIONS(5170),
    [anon_sym_cover] = ACTIONS(5170),
    [anon_sym_sequence] = ACTIONS(5170),
    [anon_sym_restrict] = ACTIONS(5170),
    [anon_sym_not] = ACTIONS(5170),
    [anon_sym_or] = ACTIONS(5170),
    [anon_sym_and] = ACTIONS(5170),
    [anon_sym_case] = ACTIONS(5170),
    [anon_sym_always] = ACTIONS(5170),
    [anon_sym_covergroup] = ACTIONS(5170),
    [anon_sym_end] = ACTIONS(5170),
    [anon_sym_let] = ACTIONS(5170),
    [anon_sym_pulldown] = ACTIONS(5170),
    [anon_sym_pullup] = ACTIONS(5170),
    [anon_sym_cmos] = ACTIONS(5170),
    [anon_sym_rcmos] = ACTIONS(5170),
    [anon_sym_bufif0] = ACTIONS(5170),
    [anon_sym_bufif1] = ACTIONS(5170),
    [anon_sym_notif0] = ACTIONS(5170),
    [anon_sym_notif1] = ACTIONS(5170),
    [anon_sym_nmos] = ACTIONS(5170),
    [anon_sym_pmos] = ACTIONS(5170),
    [anon_sym_rnmos] = ACTIONS(5170),
    [anon_sym_rpmos] = ACTIONS(5170),
    [anon_sym_nand] = ACTIONS(5170),
    [anon_sym_nor] = ACTIONS(5170),
    [anon_sym_xor] = ACTIONS(5170),
    [anon_sym_xnor] = ACTIONS(5170),
    [anon_sym_buf] = ACTIONS(5170),
    [anon_sym_tranif0] = ACTIONS(5170),
    [anon_sym_tranif1] = ACTIONS(5170),
    [anon_sym_rtranif1] = ACTIONS(5170),
    [anon_sym_rtranif0] = ACTIONS(5170),
    [anon_sym_tran] = ACTIONS(5170),
    [anon_sym_rtran] = ACTIONS(5170),
    [anon_sym_generate] = ACTIONS(5170),
    [anon_sym_for] = ACTIONS(5170),
    [anon_sym_initial] = ACTIONS(5170),
    [anon_sym_assign] = ACTIONS(5170),
    [anon_sym_alias] = ACTIONS(5170),
    [anon_sym_always_comb] = ACTIONS(5170),
    [anon_sym_always_latch] = ACTIONS(5170),
    [anon_sym_always_ff] = ACTIONS(5170),
    [anon_sym_final] = ACTIONS(5170),
    [anon_sym_global] = ACTIONS(5170),
    [anon_sym_LPAREN_STAR] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5168),
    [anon_sym_DOLLARunit] = ACTIONS(5168),
  },
  [5092] = {
    [sym_simple_identifier] = ACTIONS(4646),
    [anon_sym_wire] = ACTIONS(4646),
    [anon_sym_tri] = ACTIONS(4646),
    [anon_sym_tri0] = ACTIONS(4646),
    [anon_sym_tri1] = ACTIONS(4646),
    [anon_sym_wand] = ACTIONS(4646),
    [anon_sym_triand] = ACTIONS(4646),
    [anon_sym_wor] = ACTIONS(4646),
    [anon_sym_trior] = ACTIONS(4646),
    [anon_sym_trireg] = ACTIONS(4646),
    [anon_sym_uwire] = ACTIONS(4646),
    [anon_sym_SEMI] = ACTIONS(4644),
    [anon_sym_extern] = ACTIONS(4646),
    [anon_sym_interface] = ACTIONS(4646),
    [anon_sym_checker] = ACTIONS(4646),
    [anon_sym_virtual] = ACTIONS(4646),
    [anon_sym_class] = ACTIONS(4646),
    [anon_sym_type] = ACTIONS(4646),
    [anon_sym_DOLLARfatal] = ACTIONS(4644),
    [anon_sym_DOLLARerror] = ACTIONS(4644),
    [anon_sym_DOLLARwarning] = ACTIONS(4644),
    [anon_sym_DOLLARinfo] = ACTIONS(4644),
    [anon_sym_default] = ACTIONS(4646),
    [anon_sym_clocking] = ACTIONS(4646),
    [anon_sym_defparam] = ACTIONS(4646),
    [anon_sym_bind] = ACTIONS(4646),
    [anon_sym_rand] = ACTIONS(4646),
    [anon_sym_const] = ACTIONS(4646),
    [anon_sym_function] = ACTIONS(4646),
    [anon_sym_static] = ACTIONS(4646),
    [anon_sym_constraint] = ACTIONS(4646),
    [anon_sym_if] = ACTIONS(4646),
    [anon_sym_else] = ACTIONS(4646),
    [anon_sym_LBRACK] = ACTIONS(4644),
    [anon_sym_localparam] = ACTIONS(4646),
    [anon_sym_parameter] = ACTIONS(4646),
    [anon_sym_var] = ACTIONS(4646),
    [anon_sym_import] = ACTIONS(4646),
    [anon_sym_export] = ACTIONS(4646),
    [anon_sym_genvar] = ACTIONS(4646),
    [anon_sym_interconnect] = ACTIONS(4646),
    [anon_sym_typedef] = ACTIONS(4646),
    [anon_sym_enum] = ACTIONS(4646),
    [anon_sym_struct] = ACTIONS(4646),
    [anon_sym_union] = ACTIONS(4646),
    [anon_sym_nettype] = ACTIONS(4646),
    [anon_sym_automatic] = ACTIONS(4646),
    [anon_sym_string] = ACTIONS(4646),
    [anon_sym_chandle] = ACTIONS(4646),
    [anon_sym_event] = ACTIONS(4646),
    [anon_sym_byte] = ACTIONS(4646),
    [anon_sym_shortint] = ACTIONS(4646),
    [anon_sym_int] = ACTIONS(4646),
    [anon_sym_longint] = ACTIONS(4646),
    [anon_sym_integer] = ACTIONS(4646),
    [anon_sym_time] = ACTIONS(4646),
    [anon_sym_bit] = ACTIONS(4646),
    [anon_sym_logic] = ACTIONS(4646),
    [anon_sym_reg] = ACTIONS(4646),
    [anon_sym_shortreal] = ACTIONS(4646),
    [anon_sym_real] = ACTIONS(4646),
    [anon_sym_realtime] = ACTIONS(4646),
    [anon_sym_supply0] = ACTIONS(4646),
    [anon_sym_supply1] = ACTIONS(4646),
    [anon_sym_signed] = ACTIONS(4646),
    [anon_sym_unsigned] = ACTIONS(4646),
    [anon_sym_task] = ACTIONS(4646),
    [anon_sym_assert] = ACTIONS(4646),
    [anon_sym_property] = ACTIONS(4646),
    [anon_sym_assume] = ACTIONS(4646),
    [anon_sym_cover] = ACTIONS(4646),
    [anon_sym_sequence] = ACTIONS(4646),
    [anon_sym_restrict] = ACTIONS(4646),
    [anon_sym_not] = ACTIONS(4646),
    [anon_sym_or] = ACTIONS(4646),
    [anon_sym_and] = ACTIONS(4646),
    [anon_sym_case] = ACTIONS(4646),
    [anon_sym_always] = ACTIONS(4646),
    [anon_sym_covergroup] = ACTIONS(4646),
    [anon_sym_let] = ACTIONS(4646),
    [anon_sym_pulldown] = ACTIONS(4646),
    [anon_sym_pullup] = ACTIONS(4646),
    [anon_sym_cmos] = ACTIONS(4646),
    [anon_sym_rcmos] = ACTIONS(4646),
    [anon_sym_bufif0] = ACTIONS(4646),
    [anon_sym_bufif1] = ACTIONS(4646),
    [anon_sym_notif0] = ACTIONS(4646),
    [anon_sym_notif1] = ACTIONS(4646),
    [anon_sym_nmos] = ACTIONS(4646),
    [anon_sym_pmos] = ACTIONS(4646),
    [anon_sym_rnmos] = ACTIONS(4646),
    [anon_sym_rpmos] = ACTIONS(4646),
    [anon_sym_nand] = ACTIONS(4646),
    [anon_sym_nor] = ACTIONS(4646),
    [anon_sym_xor] = ACTIONS(4646),
    [anon_sym_xnor] = ACTIONS(4646),
    [anon_sym_buf] = ACTIONS(4646),
    [anon_sym_tranif0] = ACTIONS(4646),
    [anon_sym_tranif1] = ACTIONS(4646),
    [anon_sym_rtranif1] = ACTIONS(4646),
    [anon_sym_rtranif0] = ACTIONS(4646),
    [anon_sym_tran] = ACTIONS(4646),
    [anon_sym_rtran] = ACTIONS(4646),
    [anon_sym_generate] = ACTIONS(4646),
    [anon_sym_endgenerate] = ACTIONS(4646),
    [anon_sym_for] = ACTIONS(4646),
    [anon_sym_initial] = ACTIONS(4646),
    [anon_sym_assign] = ACTIONS(4646),
    [anon_sym_alias] = ACTIONS(4646),
    [anon_sym_always_comb] = ACTIONS(4646),
    [anon_sym_always_latch] = ACTIONS(4646),
    [anon_sym_always_ff] = ACTIONS(4646),
    [anon_sym_final] = ACTIONS(4646),
    [anon_sym_global] = ACTIONS(4646),
    [anon_sym_LPAREN_STAR] = ACTIONS(4644),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4644),
    [anon_sym_DOLLARunit] = ACTIONS(4644),
  },
  [5093] = {
    [sym_simple_identifier] = ACTIONS(4880),
    [anon_sym_wire] = ACTIONS(4880),
    [anon_sym_tri] = ACTIONS(4880),
    [anon_sym_tri0] = ACTIONS(4880),
    [anon_sym_tri1] = ACTIONS(4880),
    [anon_sym_wand] = ACTIONS(4880),
    [anon_sym_triand] = ACTIONS(4880),
    [anon_sym_wor] = ACTIONS(4880),
    [anon_sym_trior] = ACTIONS(4880),
    [anon_sym_trireg] = ACTIONS(4880),
    [anon_sym_uwire] = ACTIONS(4880),
    [anon_sym_SEMI] = ACTIONS(4878),
    [anon_sym_extern] = ACTIONS(4880),
    [anon_sym_interface] = ACTIONS(4880),
    [anon_sym_checker] = ACTIONS(4880),
    [anon_sym_virtual] = ACTIONS(4880),
    [anon_sym_class] = ACTIONS(4880),
    [anon_sym_type] = ACTIONS(4880),
    [anon_sym_DOLLARfatal] = ACTIONS(4878),
    [anon_sym_DOLLARerror] = ACTIONS(4878),
    [anon_sym_DOLLARwarning] = ACTIONS(4878),
    [anon_sym_DOLLARinfo] = ACTIONS(4878),
    [anon_sym_default] = ACTIONS(4880),
    [anon_sym_clocking] = ACTIONS(4880),
    [anon_sym_defparam] = ACTIONS(4880),
    [anon_sym_bind] = ACTIONS(4880),
    [anon_sym_rand] = ACTIONS(4880),
    [anon_sym_const] = ACTIONS(4880),
    [anon_sym_function] = ACTIONS(4880),
    [anon_sym_static] = ACTIONS(4880),
    [anon_sym_constraint] = ACTIONS(4880),
    [anon_sym_if] = ACTIONS(4880),
    [anon_sym_else] = ACTIONS(4880),
    [anon_sym_LBRACK] = ACTIONS(4878),
    [anon_sym_localparam] = ACTIONS(4880),
    [anon_sym_parameter] = ACTIONS(4880),
    [anon_sym_var] = ACTIONS(4880),
    [anon_sym_import] = ACTIONS(4880),
    [anon_sym_export] = ACTIONS(4880),
    [anon_sym_genvar] = ACTIONS(4880),
    [anon_sym_interconnect] = ACTIONS(4880),
    [anon_sym_typedef] = ACTIONS(4880),
    [anon_sym_enum] = ACTIONS(4880),
    [anon_sym_struct] = ACTIONS(4880),
    [anon_sym_union] = ACTIONS(4880),
    [anon_sym_nettype] = ACTIONS(4880),
    [anon_sym_automatic] = ACTIONS(4880),
    [anon_sym_string] = ACTIONS(4880),
    [anon_sym_chandle] = ACTIONS(4880),
    [anon_sym_event] = ACTIONS(4880),
    [anon_sym_byte] = ACTIONS(4880),
    [anon_sym_shortint] = ACTIONS(4880),
    [anon_sym_int] = ACTIONS(4880),
    [anon_sym_longint] = ACTIONS(4880),
    [anon_sym_integer] = ACTIONS(4880),
    [anon_sym_time] = ACTIONS(4880),
    [anon_sym_bit] = ACTIONS(4880),
    [anon_sym_logic] = ACTIONS(4880),
    [anon_sym_reg] = ACTIONS(4880),
    [anon_sym_shortreal] = ACTIONS(4880),
    [anon_sym_real] = ACTIONS(4880),
    [anon_sym_realtime] = ACTIONS(4880),
    [anon_sym_supply0] = ACTIONS(4880),
    [anon_sym_supply1] = ACTIONS(4880),
    [anon_sym_signed] = ACTIONS(4880),
    [anon_sym_unsigned] = ACTIONS(4880),
    [anon_sym_task] = ACTIONS(4880),
    [anon_sym_assert] = ACTIONS(4880),
    [anon_sym_property] = ACTIONS(4880),
    [anon_sym_assume] = ACTIONS(4880),
    [anon_sym_cover] = ACTIONS(4880),
    [anon_sym_sequence] = ACTIONS(4880),
    [anon_sym_restrict] = ACTIONS(4880),
    [anon_sym_not] = ACTIONS(4880),
    [anon_sym_or] = ACTIONS(4880),
    [anon_sym_and] = ACTIONS(4880),
    [anon_sym_case] = ACTIONS(4880),
    [anon_sym_always] = ACTIONS(4880),
    [anon_sym_covergroup] = ACTIONS(4880),
    [anon_sym_end] = ACTIONS(4880),
    [anon_sym_let] = ACTIONS(4880),
    [anon_sym_pulldown] = ACTIONS(4880),
    [anon_sym_pullup] = ACTIONS(4880),
    [anon_sym_cmos] = ACTIONS(4880),
    [anon_sym_rcmos] = ACTIONS(4880),
    [anon_sym_bufif0] = ACTIONS(4880),
    [anon_sym_bufif1] = ACTIONS(4880),
    [anon_sym_notif0] = ACTIONS(4880),
    [anon_sym_notif1] = ACTIONS(4880),
    [anon_sym_nmos] = ACTIONS(4880),
    [anon_sym_pmos] = ACTIONS(4880),
    [anon_sym_rnmos] = ACTIONS(4880),
    [anon_sym_rpmos] = ACTIONS(4880),
    [anon_sym_nand] = ACTIONS(4880),
    [anon_sym_nor] = ACTIONS(4880),
    [anon_sym_xor] = ACTIONS(4880),
    [anon_sym_xnor] = ACTIONS(4880),
    [anon_sym_buf] = ACTIONS(4880),
    [anon_sym_tranif0] = ACTIONS(4880),
    [anon_sym_tranif1] = ACTIONS(4880),
    [anon_sym_rtranif1] = ACTIONS(4880),
    [anon_sym_rtranif0] = ACTIONS(4880),
    [anon_sym_tran] = ACTIONS(4880),
    [anon_sym_rtran] = ACTIONS(4880),
    [anon_sym_generate] = ACTIONS(4880),
    [anon_sym_for] = ACTIONS(4880),
    [anon_sym_initial] = ACTIONS(4880),
    [anon_sym_assign] = ACTIONS(4880),
    [anon_sym_alias] = ACTIONS(4880),
    [anon_sym_always_comb] = ACTIONS(4880),
    [anon_sym_always_latch] = ACTIONS(4880),
    [anon_sym_always_ff] = ACTIONS(4880),
    [anon_sym_final] = ACTIONS(4880),
    [anon_sym_global] = ACTIONS(4880),
    [anon_sym_LPAREN_STAR] = ACTIONS(4878),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4878),
    [anon_sym_DOLLARunit] = ACTIONS(4878),
  },
  [5094] = {
    [sym_simple_identifier] = ACTIONS(4896),
    [anon_sym_wire] = ACTIONS(4896),
    [anon_sym_tri] = ACTIONS(4896),
    [anon_sym_tri0] = ACTIONS(4896),
    [anon_sym_tri1] = ACTIONS(4896),
    [anon_sym_wand] = ACTIONS(4896),
    [anon_sym_triand] = ACTIONS(4896),
    [anon_sym_wor] = ACTIONS(4896),
    [anon_sym_trior] = ACTIONS(4896),
    [anon_sym_trireg] = ACTIONS(4896),
    [anon_sym_uwire] = ACTIONS(4896),
    [anon_sym_SEMI] = ACTIONS(4894),
    [anon_sym_extern] = ACTIONS(4896),
    [anon_sym_interface] = ACTIONS(4896),
    [anon_sym_checker] = ACTIONS(4896),
    [anon_sym_virtual] = ACTIONS(4896),
    [anon_sym_class] = ACTIONS(4896),
    [anon_sym_type] = ACTIONS(4896),
    [anon_sym_DOLLARfatal] = ACTIONS(4894),
    [anon_sym_DOLLARerror] = ACTIONS(4894),
    [anon_sym_DOLLARwarning] = ACTIONS(4894),
    [anon_sym_DOLLARinfo] = ACTIONS(4894),
    [anon_sym_default] = ACTIONS(4896),
    [anon_sym_clocking] = ACTIONS(4896),
    [anon_sym_defparam] = ACTIONS(4896),
    [anon_sym_bind] = ACTIONS(4896),
    [anon_sym_rand] = ACTIONS(4896),
    [anon_sym_const] = ACTIONS(4896),
    [anon_sym_function] = ACTIONS(4896),
    [anon_sym_static] = ACTIONS(4896),
    [anon_sym_constraint] = ACTIONS(4896),
    [anon_sym_if] = ACTIONS(4896),
    [anon_sym_else] = ACTIONS(4896),
    [anon_sym_LBRACK] = ACTIONS(4894),
    [anon_sym_localparam] = ACTIONS(4896),
    [anon_sym_parameter] = ACTIONS(4896),
    [anon_sym_var] = ACTIONS(4896),
    [anon_sym_import] = ACTIONS(4896),
    [anon_sym_export] = ACTIONS(4896),
    [anon_sym_genvar] = ACTIONS(4896),
    [anon_sym_interconnect] = ACTIONS(4896),
    [anon_sym_typedef] = ACTIONS(4896),
    [anon_sym_enum] = ACTIONS(4896),
    [anon_sym_struct] = ACTIONS(4896),
    [anon_sym_union] = ACTIONS(4896),
    [anon_sym_nettype] = ACTIONS(4896),
    [anon_sym_automatic] = ACTIONS(4896),
    [anon_sym_string] = ACTIONS(4896),
    [anon_sym_chandle] = ACTIONS(4896),
    [anon_sym_event] = ACTIONS(4896),
    [anon_sym_byte] = ACTIONS(4896),
    [anon_sym_shortint] = ACTIONS(4896),
    [anon_sym_int] = ACTIONS(4896),
    [anon_sym_longint] = ACTIONS(4896),
    [anon_sym_integer] = ACTIONS(4896),
    [anon_sym_time] = ACTIONS(4896),
    [anon_sym_bit] = ACTIONS(4896),
    [anon_sym_logic] = ACTIONS(4896),
    [anon_sym_reg] = ACTIONS(4896),
    [anon_sym_shortreal] = ACTIONS(4896),
    [anon_sym_real] = ACTIONS(4896),
    [anon_sym_realtime] = ACTIONS(4896),
    [anon_sym_supply0] = ACTIONS(4896),
    [anon_sym_supply1] = ACTIONS(4896),
    [anon_sym_signed] = ACTIONS(4896),
    [anon_sym_unsigned] = ACTIONS(4896),
    [anon_sym_task] = ACTIONS(4896),
    [anon_sym_assert] = ACTIONS(4896),
    [anon_sym_property] = ACTIONS(4896),
    [anon_sym_assume] = ACTIONS(4896),
    [anon_sym_cover] = ACTIONS(4896),
    [anon_sym_sequence] = ACTIONS(4896),
    [anon_sym_restrict] = ACTIONS(4896),
    [anon_sym_not] = ACTIONS(4896),
    [anon_sym_or] = ACTIONS(4896),
    [anon_sym_and] = ACTIONS(4896),
    [anon_sym_case] = ACTIONS(4896),
    [anon_sym_always] = ACTIONS(4896),
    [anon_sym_covergroup] = ACTIONS(4896),
    [anon_sym_end] = ACTIONS(4896),
    [anon_sym_let] = ACTIONS(4896),
    [anon_sym_pulldown] = ACTIONS(4896),
    [anon_sym_pullup] = ACTIONS(4896),
    [anon_sym_cmos] = ACTIONS(4896),
    [anon_sym_rcmos] = ACTIONS(4896),
    [anon_sym_bufif0] = ACTIONS(4896),
    [anon_sym_bufif1] = ACTIONS(4896),
    [anon_sym_notif0] = ACTIONS(4896),
    [anon_sym_notif1] = ACTIONS(4896),
    [anon_sym_nmos] = ACTIONS(4896),
    [anon_sym_pmos] = ACTIONS(4896),
    [anon_sym_rnmos] = ACTIONS(4896),
    [anon_sym_rpmos] = ACTIONS(4896),
    [anon_sym_nand] = ACTIONS(4896),
    [anon_sym_nor] = ACTIONS(4896),
    [anon_sym_xor] = ACTIONS(4896),
    [anon_sym_xnor] = ACTIONS(4896),
    [anon_sym_buf] = ACTIONS(4896),
    [anon_sym_tranif0] = ACTIONS(4896),
    [anon_sym_tranif1] = ACTIONS(4896),
    [anon_sym_rtranif1] = ACTIONS(4896),
    [anon_sym_rtranif0] = ACTIONS(4896),
    [anon_sym_tran] = ACTIONS(4896),
    [anon_sym_rtran] = ACTIONS(4896),
    [anon_sym_generate] = ACTIONS(4896),
    [anon_sym_for] = ACTIONS(4896),
    [anon_sym_initial] = ACTIONS(4896),
    [anon_sym_assign] = ACTIONS(4896),
    [anon_sym_alias] = ACTIONS(4896),
    [anon_sym_always_comb] = ACTIONS(4896),
    [anon_sym_always_latch] = ACTIONS(4896),
    [anon_sym_always_ff] = ACTIONS(4896),
    [anon_sym_final] = ACTIONS(4896),
    [anon_sym_global] = ACTIONS(4896),
    [anon_sym_LPAREN_STAR] = ACTIONS(4894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4894),
    [anon_sym_DOLLARunit] = ACTIONS(4894),
  },
  [5095] = {
    [sym_simple_identifier] = ACTIONS(4578),
    [anon_sym_wire] = ACTIONS(4578),
    [anon_sym_tri] = ACTIONS(4578),
    [anon_sym_tri0] = ACTIONS(4578),
    [anon_sym_tri1] = ACTIONS(4578),
    [anon_sym_wand] = ACTIONS(4578),
    [anon_sym_triand] = ACTIONS(4578),
    [anon_sym_wor] = ACTIONS(4578),
    [anon_sym_trior] = ACTIONS(4578),
    [anon_sym_trireg] = ACTIONS(4578),
    [anon_sym_uwire] = ACTIONS(4578),
    [anon_sym_SEMI] = ACTIONS(4576),
    [anon_sym_extern] = ACTIONS(4578),
    [anon_sym_interface] = ACTIONS(4578),
    [anon_sym_checker] = ACTIONS(4578),
    [anon_sym_virtual] = ACTIONS(4578),
    [anon_sym_class] = ACTIONS(4578),
    [anon_sym_type] = ACTIONS(4578),
    [anon_sym_DOLLARfatal] = ACTIONS(4576),
    [anon_sym_DOLLARerror] = ACTIONS(4576),
    [anon_sym_DOLLARwarning] = ACTIONS(4576),
    [anon_sym_DOLLARinfo] = ACTIONS(4576),
    [anon_sym_default] = ACTIONS(4578),
    [anon_sym_clocking] = ACTIONS(4578),
    [anon_sym_defparam] = ACTIONS(4578),
    [anon_sym_bind] = ACTIONS(4578),
    [anon_sym_rand] = ACTIONS(4578),
    [anon_sym_const] = ACTIONS(4578),
    [anon_sym_function] = ACTIONS(4578),
    [anon_sym_static] = ACTIONS(4578),
    [anon_sym_constraint] = ACTIONS(4578),
    [anon_sym_if] = ACTIONS(4578),
    [anon_sym_else] = ACTIONS(4578),
    [anon_sym_LBRACK] = ACTIONS(4576),
    [anon_sym_localparam] = ACTIONS(4578),
    [anon_sym_parameter] = ACTIONS(4578),
    [anon_sym_var] = ACTIONS(4578),
    [anon_sym_import] = ACTIONS(4578),
    [anon_sym_export] = ACTIONS(4578),
    [anon_sym_genvar] = ACTIONS(4578),
    [anon_sym_interconnect] = ACTIONS(4578),
    [anon_sym_typedef] = ACTIONS(4578),
    [anon_sym_enum] = ACTIONS(4578),
    [anon_sym_struct] = ACTIONS(4578),
    [anon_sym_union] = ACTIONS(4578),
    [anon_sym_nettype] = ACTIONS(4578),
    [anon_sym_automatic] = ACTIONS(4578),
    [anon_sym_string] = ACTIONS(4578),
    [anon_sym_chandle] = ACTIONS(4578),
    [anon_sym_event] = ACTIONS(4578),
    [anon_sym_byte] = ACTIONS(4578),
    [anon_sym_shortint] = ACTIONS(4578),
    [anon_sym_int] = ACTIONS(4578),
    [anon_sym_longint] = ACTIONS(4578),
    [anon_sym_integer] = ACTIONS(4578),
    [anon_sym_time] = ACTIONS(4578),
    [anon_sym_bit] = ACTIONS(4578),
    [anon_sym_logic] = ACTIONS(4578),
    [anon_sym_reg] = ACTIONS(4578),
    [anon_sym_shortreal] = ACTIONS(4578),
    [anon_sym_real] = ACTIONS(4578),
    [anon_sym_realtime] = ACTIONS(4578),
    [anon_sym_supply0] = ACTIONS(4578),
    [anon_sym_supply1] = ACTIONS(4578),
    [anon_sym_signed] = ACTIONS(4578),
    [anon_sym_unsigned] = ACTIONS(4578),
    [anon_sym_task] = ACTIONS(4578),
    [anon_sym_assert] = ACTIONS(4578),
    [anon_sym_property] = ACTIONS(4578),
    [anon_sym_assume] = ACTIONS(4578),
    [anon_sym_cover] = ACTIONS(4578),
    [anon_sym_sequence] = ACTIONS(4578),
    [anon_sym_restrict] = ACTIONS(4578),
    [anon_sym_not] = ACTIONS(4578),
    [anon_sym_or] = ACTIONS(4578),
    [anon_sym_and] = ACTIONS(4578),
    [anon_sym_case] = ACTIONS(4578),
    [anon_sym_always] = ACTIONS(4578),
    [anon_sym_covergroup] = ACTIONS(4578),
    [anon_sym_end] = ACTIONS(4578),
    [anon_sym_let] = ACTIONS(4578),
    [anon_sym_pulldown] = ACTIONS(4578),
    [anon_sym_pullup] = ACTIONS(4578),
    [anon_sym_cmos] = ACTIONS(4578),
    [anon_sym_rcmos] = ACTIONS(4578),
    [anon_sym_bufif0] = ACTIONS(4578),
    [anon_sym_bufif1] = ACTIONS(4578),
    [anon_sym_notif0] = ACTIONS(4578),
    [anon_sym_notif1] = ACTIONS(4578),
    [anon_sym_nmos] = ACTIONS(4578),
    [anon_sym_pmos] = ACTIONS(4578),
    [anon_sym_rnmos] = ACTIONS(4578),
    [anon_sym_rpmos] = ACTIONS(4578),
    [anon_sym_nand] = ACTIONS(4578),
    [anon_sym_nor] = ACTIONS(4578),
    [anon_sym_xor] = ACTIONS(4578),
    [anon_sym_xnor] = ACTIONS(4578),
    [anon_sym_buf] = ACTIONS(4578),
    [anon_sym_tranif0] = ACTIONS(4578),
    [anon_sym_tranif1] = ACTIONS(4578),
    [anon_sym_rtranif1] = ACTIONS(4578),
    [anon_sym_rtranif0] = ACTIONS(4578),
    [anon_sym_tran] = ACTIONS(4578),
    [anon_sym_rtran] = ACTIONS(4578),
    [anon_sym_generate] = ACTIONS(4578),
    [anon_sym_for] = ACTIONS(4578),
    [anon_sym_initial] = ACTIONS(4578),
    [anon_sym_assign] = ACTIONS(4578),
    [anon_sym_alias] = ACTIONS(4578),
    [anon_sym_always_comb] = ACTIONS(4578),
    [anon_sym_always_latch] = ACTIONS(4578),
    [anon_sym_always_ff] = ACTIONS(4578),
    [anon_sym_final] = ACTIONS(4578),
    [anon_sym_global] = ACTIONS(4578),
    [anon_sym_LPAREN_STAR] = ACTIONS(4576),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4576),
    [anon_sym_DOLLARunit] = ACTIONS(4576),
  },
  [5096] = {
    [sym_simple_identifier] = ACTIONS(5946),
    [anon_sym_wire] = ACTIONS(5946),
    [anon_sym_tri] = ACTIONS(5946),
    [anon_sym_tri0] = ACTIONS(5946),
    [anon_sym_tri1] = ACTIONS(5946),
    [anon_sym_wand] = ACTIONS(5946),
    [anon_sym_triand] = ACTIONS(5946),
    [anon_sym_wor] = ACTIONS(5946),
    [anon_sym_trior] = ACTIONS(5946),
    [anon_sym_trireg] = ACTIONS(5946),
    [anon_sym_uwire] = ACTIONS(5946),
    [anon_sym_SEMI] = ACTIONS(5948),
    [anon_sym_extern] = ACTIONS(5946),
    [anon_sym_interface] = ACTIONS(5946),
    [anon_sym_checker] = ACTIONS(5946),
    [anon_sym_virtual] = ACTIONS(5946),
    [anon_sym_class] = ACTIONS(5946),
    [anon_sym_type] = ACTIONS(5946),
    [anon_sym_DOLLARfatal] = ACTIONS(5948),
    [anon_sym_DOLLARerror] = ACTIONS(5948),
    [anon_sym_DOLLARwarning] = ACTIONS(5948),
    [anon_sym_DOLLARinfo] = ACTIONS(5948),
    [anon_sym_default] = ACTIONS(5946),
    [anon_sym_clocking] = ACTIONS(5946),
    [anon_sym_defparam] = ACTIONS(5946),
    [anon_sym_bind] = ACTIONS(5946),
    [anon_sym_rand] = ACTIONS(5946),
    [anon_sym_const] = ACTIONS(5946),
    [anon_sym_function] = ACTIONS(5946),
    [anon_sym_static] = ACTIONS(5946),
    [anon_sym_constraint] = ACTIONS(5946),
    [anon_sym_if] = ACTIONS(5946),
    [anon_sym_else] = ACTIONS(5946),
    [anon_sym_LBRACK] = ACTIONS(5948),
    [anon_sym_localparam] = ACTIONS(5946),
    [anon_sym_parameter] = ACTIONS(5946),
    [anon_sym_var] = ACTIONS(5946),
    [anon_sym_import] = ACTIONS(5946),
    [anon_sym_export] = ACTIONS(5946),
    [anon_sym_genvar] = ACTIONS(5946),
    [anon_sym_interconnect] = ACTIONS(5946),
    [anon_sym_typedef] = ACTIONS(5946),
    [anon_sym_enum] = ACTIONS(5946),
    [anon_sym_struct] = ACTIONS(5946),
    [anon_sym_union] = ACTIONS(5946),
    [anon_sym_nettype] = ACTIONS(5946),
    [anon_sym_automatic] = ACTIONS(5946),
    [anon_sym_string] = ACTIONS(5946),
    [anon_sym_chandle] = ACTIONS(5946),
    [anon_sym_event] = ACTIONS(5946),
    [anon_sym_byte] = ACTIONS(5946),
    [anon_sym_shortint] = ACTIONS(5946),
    [anon_sym_int] = ACTIONS(5946),
    [anon_sym_longint] = ACTIONS(5946),
    [anon_sym_integer] = ACTIONS(5946),
    [anon_sym_time] = ACTIONS(5946),
    [anon_sym_bit] = ACTIONS(5946),
    [anon_sym_logic] = ACTIONS(5946),
    [anon_sym_reg] = ACTIONS(5946),
    [anon_sym_shortreal] = ACTIONS(5946),
    [anon_sym_real] = ACTIONS(5946),
    [anon_sym_realtime] = ACTIONS(5946),
    [anon_sym_supply0] = ACTIONS(5946),
    [anon_sym_supply1] = ACTIONS(5946),
    [anon_sym_signed] = ACTIONS(5946),
    [anon_sym_unsigned] = ACTIONS(5946),
    [anon_sym_task] = ACTIONS(5946),
    [anon_sym_assert] = ACTIONS(5946),
    [anon_sym_property] = ACTIONS(5946),
    [anon_sym_assume] = ACTIONS(5946),
    [anon_sym_cover] = ACTIONS(5946),
    [anon_sym_sequence] = ACTIONS(5946),
    [anon_sym_restrict] = ACTIONS(5946),
    [anon_sym_not] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_case] = ACTIONS(5946),
    [anon_sym_always] = ACTIONS(5946),
    [anon_sym_covergroup] = ACTIONS(5946),
    [anon_sym_end] = ACTIONS(5946),
    [anon_sym_let] = ACTIONS(5946),
    [anon_sym_pulldown] = ACTIONS(5946),
    [anon_sym_pullup] = ACTIONS(5946),
    [anon_sym_cmos] = ACTIONS(5946),
    [anon_sym_rcmos] = ACTIONS(5946),
    [anon_sym_bufif0] = ACTIONS(5946),
    [anon_sym_bufif1] = ACTIONS(5946),
    [anon_sym_notif0] = ACTIONS(5946),
    [anon_sym_notif1] = ACTIONS(5946),
    [anon_sym_nmos] = ACTIONS(5946),
    [anon_sym_pmos] = ACTIONS(5946),
    [anon_sym_rnmos] = ACTIONS(5946),
    [anon_sym_rpmos] = ACTIONS(5946),
    [anon_sym_nand] = ACTIONS(5946),
    [anon_sym_nor] = ACTIONS(5946),
    [anon_sym_xor] = ACTIONS(5946),
    [anon_sym_xnor] = ACTIONS(5946),
    [anon_sym_buf] = ACTIONS(5946),
    [anon_sym_tranif0] = ACTIONS(5946),
    [anon_sym_tranif1] = ACTIONS(5946),
    [anon_sym_rtranif1] = ACTIONS(5946),
    [anon_sym_rtranif0] = ACTIONS(5946),
    [anon_sym_tran] = ACTIONS(5946),
    [anon_sym_rtran] = ACTIONS(5946),
    [anon_sym_generate] = ACTIONS(5946),
    [anon_sym_for] = ACTIONS(5946),
    [anon_sym_initial] = ACTIONS(5946),
    [anon_sym_assign] = ACTIONS(5946),
    [anon_sym_alias] = ACTIONS(5946),
    [anon_sym_always_comb] = ACTIONS(5946),
    [anon_sym_always_latch] = ACTIONS(5946),
    [anon_sym_always_ff] = ACTIONS(5946),
    [anon_sym_final] = ACTIONS(5946),
    [anon_sym_global] = ACTIONS(5946),
    [anon_sym_LPAREN_STAR] = ACTIONS(5948),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5948),
    [anon_sym_DOLLARunit] = ACTIONS(5948),
  },
  [5097] = {
    [sym_simple_identifier] = ACTIONS(5484),
    [anon_sym_wire] = ACTIONS(5484),
    [anon_sym_tri] = ACTIONS(5484),
    [anon_sym_tri0] = ACTIONS(5484),
    [anon_sym_tri1] = ACTIONS(5484),
    [anon_sym_wand] = ACTIONS(5484),
    [anon_sym_triand] = ACTIONS(5484),
    [anon_sym_wor] = ACTIONS(5484),
    [anon_sym_trior] = ACTIONS(5484),
    [anon_sym_trireg] = ACTIONS(5484),
    [anon_sym_uwire] = ACTIONS(5484),
    [anon_sym_SEMI] = ACTIONS(5482),
    [anon_sym_extern] = ACTIONS(5484),
    [anon_sym_interface] = ACTIONS(5484),
    [anon_sym_checker] = ACTIONS(5484),
    [anon_sym_virtual] = ACTIONS(5484),
    [anon_sym_class] = ACTIONS(5484),
    [anon_sym_type] = ACTIONS(5484),
    [anon_sym_DOLLARfatal] = ACTIONS(5482),
    [anon_sym_DOLLARerror] = ACTIONS(5482),
    [anon_sym_DOLLARwarning] = ACTIONS(5482),
    [anon_sym_DOLLARinfo] = ACTIONS(5482),
    [anon_sym_default] = ACTIONS(5484),
    [anon_sym_clocking] = ACTIONS(5484),
    [anon_sym_defparam] = ACTIONS(5484),
    [anon_sym_bind] = ACTIONS(5484),
    [anon_sym_rand] = ACTIONS(5484),
    [anon_sym_const] = ACTIONS(5484),
    [anon_sym_function] = ACTIONS(5484),
    [anon_sym_static] = ACTIONS(5484),
    [anon_sym_constraint] = ACTIONS(5484),
    [anon_sym_if] = ACTIONS(5484),
    [anon_sym_else] = ACTIONS(5484),
    [anon_sym_LBRACK] = ACTIONS(5482),
    [anon_sym_localparam] = ACTIONS(5484),
    [anon_sym_parameter] = ACTIONS(5484),
    [anon_sym_var] = ACTIONS(5484),
    [anon_sym_import] = ACTIONS(5484),
    [anon_sym_export] = ACTIONS(5484),
    [anon_sym_genvar] = ACTIONS(5484),
    [anon_sym_interconnect] = ACTIONS(5484),
    [anon_sym_typedef] = ACTIONS(5484),
    [anon_sym_enum] = ACTIONS(5484),
    [anon_sym_struct] = ACTIONS(5484),
    [anon_sym_union] = ACTIONS(5484),
    [anon_sym_nettype] = ACTIONS(5484),
    [anon_sym_automatic] = ACTIONS(5484),
    [anon_sym_string] = ACTIONS(5484),
    [anon_sym_chandle] = ACTIONS(5484),
    [anon_sym_event] = ACTIONS(5484),
    [anon_sym_byte] = ACTIONS(5484),
    [anon_sym_shortint] = ACTIONS(5484),
    [anon_sym_int] = ACTIONS(5484),
    [anon_sym_longint] = ACTIONS(5484),
    [anon_sym_integer] = ACTIONS(5484),
    [anon_sym_time] = ACTIONS(5484),
    [anon_sym_bit] = ACTIONS(5484),
    [anon_sym_logic] = ACTIONS(5484),
    [anon_sym_reg] = ACTIONS(5484),
    [anon_sym_shortreal] = ACTIONS(5484),
    [anon_sym_real] = ACTIONS(5484),
    [anon_sym_realtime] = ACTIONS(5484),
    [anon_sym_supply0] = ACTIONS(5484),
    [anon_sym_supply1] = ACTIONS(5484),
    [anon_sym_signed] = ACTIONS(5484),
    [anon_sym_unsigned] = ACTIONS(5484),
    [anon_sym_task] = ACTIONS(5484),
    [anon_sym_assert] = ACTIONS(5484),
    [anon_sym_property] = ACTIONS(5484),
    [anon_sym_assume] = ACTIONS(5484),
    [anon_sym_cover] = ACTIONS(5484),
    [anon_sym_sequence] = ACTIONS(5484),
    [anon_sym_restrict] = ACTIONS(5484),
    [anon_sym_not] = ACTIONS(5484),
    [anon_sym_or] = ACTIONS(5484),
    [anon_sym_and] = ACTIONS(5484),
    [anon_sym_case] = ACTIONS(5484),
    [anon_sym_always] = ACTIONS(5484),
    [anon_sym_covergroup] = ACTIONS(5484),
    [anon_sym_end] = ACTIONS(5484),
    [anon_sym_let] = ACTIONS(5484),
    [anon_sym_pulldown] = ACTIONS(5484),
    [anon_sym_pullup] = ACTIONS(5484),
    [anon_sym_cmos] = ACTIONS(5484),
    [anon_sym_rcmos] = ACTIONS(5484),
    [anon_sym_bufif0] = ACTIONS(5484),
    [anon_sym_bufif1] = ACTIONS(5484),
    [anon_sym_notif0] = ACTIONS(5484),
    [anon_sym_notif1] = ACTIONS(5484),
    [anon_sym_nmos] = ACTIONS(5484),
    [anon_sym_pmos] = ACTIONS(5484),
    [anon_sym_rnmos] = ACTIONS(5484),
    [anon_sym_rpmos] = ACTIONS(5484),
    [anon_sym_nand] = ACTIONS(5484),
    [anon_sym_nor] = ACTIONS(5484),
    [anon_sym_xor] = ACTIONS(5484),
    [anon_sym_xnor] = ACTIONS(5484),
    [anon_sym_buf] = ACTIONS(5484),
    [anon_sym_tranif0] = ACTIONS(5484),
    [anon_sym_tranif1] = ACTIONS(5484),
    [anon_sym_rtranif1] = ACTIONS(5484),
    [anon_sym_rtranif0] = ACTIONS(5484),
    [anon_sym_tran] = ACTIONS(5484),
    [anon_sym_rtran] = ACTIONS(5484),
    [anon_sym_generate] = ACTIONS(5484),
    [anon_sym_for] = ACTIONS(5484),
    [anon_sym_initial] = ACTIONS(5484),
    [anon_sym_assign] = ACTIONS(5484),
    [anon_sym_alias] = ACTIONS(5484),
    [anon_sym_always_comb] = ACTIONS(5484),
    [anon_sym_always_latch] = ACTIONS(5484),
    [anon_sym_always_ff] = ACTIONS(5484),
    [anon_sym_final] = ACTIONS(5484),
    [anon_sym_global] = ACTIONS(5484),
    [anon_sym_LPAREN_STAR] = ACTIONS(5482),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5482),
    [anon_sym_DOLLARunit] = ACTIONS(5482),
  },
  [5098] = {
    [sym_simple_identifier] = ACTIONS(6441),
    [anon_sym_wire] = ACTIONS(6441),
    [anon_sym_tri] = ACTIONS(6441),
    [anon_sym_tri0] = ACTIONS(6441),
    [anon_sym_tri1] = ACTIONS(6441),
    [anon_sym_wand] = ACTIONS(6441),
    [anon_sym_triand] = ACTIONS(6441),
    [anon_sym_wor] = ACTIONS(6441),
    [anon_sym_trior] = ACTIONS(6441),
    [anon_sym_trireg] = ACTIONS(6441),
    [anon_sym_uwire] = ACTIONS(6441),
    [anon_sym_SEMI] = ACTIONS(6445),
    [anon_sym_extern] = ACTIONS(6441),
    [anon_sym_interface] = ACTIONS(6441),
    [anon_sym_checker] = ACTIONS(6441),
    [anon_sym_virtual] = ACTIONS(6441),
    [anon_sym_class] = ACTIONS(6441),
    [anon_sym_type] = ACTIONS(6441),
    [anon_sym_DOLLARfatal] = ACTIONS(6445),
    [anon_sym_DOLLARerror] = ACTIONS(6445),
    [anon_sym_DOLLARwarning] = ACTIONS(6445),
    [anon_sym_DOLLARinfo] = ACTIONS(6445),
    [anon_sym_default] = ACTIONS(6441),
    [anon_sym_clocking] = ACTIONS(6441),
    [anon_sym_defparam] = ACTIONS(6441),
    [anon_sym_bind] = ACTIONS(6441),
    [anon_sym_rand] = ACTIONS(6441),
    [anon_sym_const] = ACTIONS(6441),
    [anon_sym_function] = ACTIONS(6441),
    [anon_sym_static] = ACTIONS(6441),
    [anon_sym_constraint] = ACTIONS(6441),
    [anon_sym_if] = ACTIONS(6441),
    [anon_sym_else] = ACTIONS(6441),
    [anon_sym_LBRACK] = ACTIONS(6445),
    [anon_sym_localparam] = ACTIONS(6441),
    [anon_sym_parameter] = ACTIONS(6441),
    [anon_sym_var] = ACTIONS(6441),
    [anon_sym_import] = ACTIONS(6441),
    [anon_sym_export] = ACTIONS(6441),
    [anon_sym_genvar] = ACTIONS(6441),
    [anon_sym_interconnect] = ACTIONS(6441),
    [anon_sym_typedef] = ACTIONS(6441),
    [anon_sym_enum] = ACTIONS(6441),
    [anon_sym_struct] = ACTIONS(6441),
    [anon_sym_union] = ACTIONS(6441),
    [anon_sym_nettype] = ACTIONS(6441),
    [anon_sym_automatic] = ACTIONS(6441),
    [anon_sym_string] = ACTIONS(6441),
    [anon_sym_chandle] = ACTIONS(6441),
    [anon_sym_event] = ACTIONS(6441),
    [anon_sym_byte] = ACTIONS(6441),
    [anon_sym_shortint] = ACTIONS(6441),
    [anon_sym_int] = ACTIONS(6441),
    [anon_sym_longint] = ACTIONS(6441),
    [anon_sym_integer] = ACTIONS(6441),
    [anon_sym_time] = ACTIONS(6441),
    [anon_sym_bit] = ACTIONS(6441),
    [anon_sym_logic] = ACTIONS(6441),
    [anon_sym_reg] = ACTIONS(6441),
    [anon_sym_shortreal] = ACTIONS(6441),
    [anon_sym_real] = ACTIONS(6441),
    [anon_sym_realtime] = ACTIONS(6441),
    [anon_sym_supply0] = ACTIONS(6441),
    [anon_sym_supply1] = ACTIONS(6441),
    [anon_sym_signed] = ACTIONS(6441),
    [anon_sym_unsigned] = ACTIONS(6441),
    [anon_sym_task] = ACTIONS(6441),
    [anon_sym_assert] = ACTIONS(6441),
    [anon_sym_property] = ACTIONS(6441),
    [anon_sym_assume] = ACTIONS(6441),
    [anon_sym_cover] = ACTIONS(6441),
    [anon_sym_sequence] = ACTIONS(6441),
    [anon_sym_restrict] = ACTIONS(6441),
    [anon_sym_not] = ACTIONS(6441),
    [anon_sym_or] = ACTIONS(6441),
    [anon_sym_and] = ACTIONS(6441),
    [anon_sym_case] = ACTIONS(6441),
    [anon_sym_always] = ACTIONS(6441),
    [anon_sym_covergroup] = ACTIONS(6441),
    [anon_sym_end] = ACTIONS(6441),
    [anon_sym_let] = ACTIONS(6441),
    [anon_sym_pulldown] = ACTIONS(6441),
    [anon_sym_pullup] = ACTIONS(6441),
    [anon_sym_cmos] = ACTIONS(6441),
    [anon_sym_rcmos] = ACTIONS(6441),
    [anon_sym_bufif0] = ACTIONS(6441),
    [anon_sym_bufif1] = ACTIONS(6441),
    [anon_sym_notif0] = ACTIONS(6441),
    [anon_sym_notif1] = ACTIONS(6441),
    [anon_sym_nmos] = ACTIONS(6441),
    [anon_sym_pmos] = ACTIONS(6441),
    [anon_sym_rnmos] = ACTIONS(6441),
    [anon_sym_rpmos] = ACTIONS(6441),
    [anon_sym_nand] = ACTIONS(6441),
    [anon_sym_nor] = ACTIONS(6441),
    [anon_sym_xor] = ACTIONS(6441),
    [anon_sym_xnor] = ACTIONS(6441),
    [anon_sym_buf] = ACTIONS(6441),
    [anon_sym_tranif0] = ACTIONS(6441),
    [anon_sym_tranif1] = ACTIONS(6441),
    [anon_sym_rtranif1] = ACTIONS(6441),
    [anon_sym_rtranif0] = ACTIONS(6441),
    [anon_sym_tran] = ACTIONS(6441),
    [anon_sym_rtran] = ACTIONS(6441),
    [anon_sym_generate] = ACTIONS(6441),
    [anon_sym_for] = ACTIONS(6441),
    [anon_sym_initial] = ACTIONS(6441),
    [anon_sym_assign] = ACTIONS(6441),
    [anon_sym_alias] = ACTIONS(6441),
    [anon_sym_always_comb] = ACTIONS(6441),
    [anon_sym_always_latch] = ACTIONS(6441),
    [anon_sym_always_ff] = ACTIONS(6441),
    [anon_sym_final] = ACTIONS(6441),
    [anon_sym_global] = ACTIONS(6441),
    [anon_sym_LPAREN_STAR] = ACTIONS(6445),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6445),
    [anon_sym_DOLLARunit] = ACTIONS(6445),
  },
  [5099] = {
    [sym_simple_identifier] = ACTIONS(5344),
    [anon_sym_wire] = ACTIONS(5344),
    [anon_sym_tri] = ACTIONS(5344),
    [anon_sym_tri0] = ACTIONS(5344),
    [anon_sym_tri1] = ACTIONS(5344),
    [anon_sym_wand] = ACTIONS(5344),
    [anon_sym_triand] = ACTIONS(5344),
    [anon_sym_wor] = ACTIONS(5344),
    [anon_sym_trior] = ACTIONS(5344),
    [anon_sym_trireg] = ACTIONS(5344),
    [anon_sym_uwire] = ACTIONS(5344),
    [anon_sym_SEMI] = ACTIONS(5342),
    [anon_sym_extern] = ACTIONS(5344),
    [anon_sym_interface] = ACTIONS(5344),
    [anon_sym_checker] = ACTIONS(5344),
    [anon_sym_virtual] = ACTIONS(5344),
    [anon_sym_class] = ACTIONS(5344),
    [anon_sym_type] = ACTIONS(5344),
    [anon_sym_DOLLARfatal] = ACTIONS(5342),
    [anon_sym_DOLLARerror] = ACTIONS(5342),
    [anon_sym_DOLLARwarning] = ACTIONS(5342),
    [anon_sym_DOLLARinfo] = ACTIONS(5342),
    [anon_sym_default] = ACTIONS(5344),
    [anon_sym_clocking] = ACTIONS(5344),
    [anon_sym_defparam] = ACTIONS(5344),
    [anon_sym_bind] = ACTIONS(5344),
    [anon_sym_rand] = ACTIONS(5344),
    [anon_sym_const] = ACTIONS(5344),
    [anon_sym_function] = ACTIONS(5344),
    [anon_sym_static] = ACTIONS(5344),
    [anon_sym_constraint] = ACTIONS(5344),
    [anon_sym_if] = ACTIONS(5344),
    [anon_sym_else] = ACTIONS(5344),
    [anon_sym_LBRACK] = ACTIONS(5342),
    [anon_sym_localparam] = ACTIONS(5344),
    [anon_sym_parameter] = ACTIONS(5344),
    [anon_sym_var] = ACTIONS(5344),
    [anon_sym_import] = ACTIONS(5344),
    [anon_sym_export] = ACTIONS(5344),
    [anon_sym_genvar] = ACTIONS(5344),
    [anon_sym_interconnect] = ACTIONS(5344),
    [anon_sym_typedef] = ACTIONS(5344),
    [anon_sym_enum] = ACTIONS(5344),
    [anon_sym_struct] = ACTIONS(5344),
    [anon_sym_union] = ACTIONS(5344),
    [anon_sym_nettype] = ACTIONS(5344),
    [anon_sym_automatic] = ACTIONS(5344),
    [anon_sym_string] = ACTIONS(5344),
    [anon_sym_chandle] = ACTIONS(5344),
    [anon_sym_event] = ACTIONS(5344),
    [anon_sym_byte] = ACTIONS(5344),
    [anon_sym_shortint] = ACTIONS(5344),
    [anon_sym_int] = ACTIONS(5344),
    [anon_sym_longint] = ACTIONS(5344),
    [anon_sym_integer] = ACTIONS(5344),
    [anon_sym_time] = ACTIONS(5344),
    [anon_sym_bit] = ACTIONS(5344),
    [anon_sym_logic] = ACTIONS(5344),
    [anon_sym_reg] = ACTIONS(5344),
    [anon_sym_shortreal] = ACTIONS(5344),
    [anon_sym_real] = ACTIONS(5344),
    [anon_sym_realtime] = ACTIONS(5344),
    [anon_sym_supply0] = ACTIONS(5344),
    [anon_sym_supply1] = ACTIONS(5344),
    [anon_sym_signed] = ACTIONS(5344),
    [anon_sym_unsigned] = ACTIONS(5344),
    [anon_sym_task] = ACTIONS(5344),
    [anon_sym_assert] = ACTIONS(5344),
    [anon_sym_property] = ACTIONS(5344),
    [anon_sym_assume] = ACTIONS(5344),
    [anon_sym_cover] = ACTIONS(5344),
    [anon_sym_sequence] = ACTIONS(5344),
    [anon_sym_restrict] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(5344),
    [anon_sym_or] = ACTIONS(5344),
    [anon_sym_and] = ACTIONS(5344),
    [anon_sym_case] = ACTIONS(5344),
    [anon_sym_always] = ACTIONS(5344),
    [anon_sym_covergroup] = ACTIONS(5344),
    [anon_sym_let] = ACTIONS(5344),
    [anon_sym_pulldown] = ACTIONS(5344),
    [anon_sym_pullup] = ACTIONS(5344),
    [anon_sym_cmos] = ACTIONS(5344),
    [anon_sym_rcmos] = ACTIONS(5344),
    [anon_sym_bufif0] = ACTIONS(5344),
    [anon_sym_bufif1] = ACTIONS(5344),
    [anon_sym_notif0] = ACTIONS(5344),
    [anon_sym_notif1] = ACTIONS(5344),
    [anon_sym_nmos] = ACTIONS(5344),
    [anon_sym_pmos] = ACTIONS(5344),
    [anon_sym_rnmos] = ACTIONS(5344),
    [anon_sym_rpmos] = ACTIONS(5344),
    [anon_sym_nand] = ACTIONS(5344),
    [anon_sym_nor] = ACTIONS(5344),
    [anon_sym_xor] = ACTIONS(5344),
    [anon_sym_xnor] = ACTIONS(5344),
    [anon_sym_buf] = ACTIONS(5344),
    [anon_sym_tranif0] = ACTIONS(5344),
    [anon_sym_tranif1] = ACTIONS(5344),
    [anon_sym_rtranif1] = ACTIONS(5344),
    [anon_sym_rtranif0] = ACTIONS(5344),
    [anon_sym_tran] = ACTIONS(5344),
    [anon_sym_rtran] = ACTIONS(5344),
    [anon_sym_generate] = ACTIONS(5344),
    [anon_sym_endgenerate] = ACTIONS(5344),
    [anon_sym_for] = ACTIONS(5344),
    [anon_sym_initial] = ACTIONS(5344),
    [anon_sym_assign] = ACTIONS(5344),
    [anon_sym_alias] = ACTIONS(5344),
    [anon_sym_always_comb] = ACTIONS(5344),
    [anon_sym_always_latch] = ACTIONS(5344),
    [anon_sym_always_ff] = ACTIONS(5344),
    [anon_sym_final] = ACTIONS(5344),
    [anon_sym_global] = ACTIONS(5344),
    [anon_sym_LPAREN_STAR] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5342),
    [anon_sym_DOLLARunit] = ACTIONS(5342),
  },
  [5100] = {
    [sym_simple_identifier] = ACTIONS(5332),
    [anon_sym_wire] = ACTIONS(5332),
    [anon_sym_tri] = ACTIONS(5332),
    [anon_sym_tri0] = ACTIONS(5332),
    [anon_sym_tri1] = ACTIONS(5332),
    [anon_sym_wand] = ACTIONS(5332),
    [anon_sym_triand] = ACTIONS(5332),
    [anon_sym_wor] = ACTIONS(5332),
    [anon_sym_trior] = ACTIONS(5332),
    [anon_sym_trireg] = ACTIONS(5332),
    [anon_sym_uwire] = ACTIONS(5332),
    [anon_sym_SEMI] = ACTIONS(5330),
    [anon_sym_extern] = ACTIONS(5332),
    [anon_sym_interface] = ACTIONS(5332),
    [anon_sym_checker] = ACTIONS(5332),
    [anon_sym_virtual] = ACTIONS(5332),
    [anon_sym_class] = ACTIONS(5332),
    [anon_sym_type] = ACTIONS(5332),
    [anon_sym_DOLLARfatal] = ACTIONS(5330),
    [anon_sym_DOLLARerror] = ACTIONS(5330),
    [anon_sym_DOLLARwarning] = ACTIONS(5330),
    [anon_sym_DOLLARinfo] = ACTIONS(5330),
    [anon_sym_default] = ACTIONS(5332),
    [anon_sym_clocking] = ACTIONS(5332),
    [anon_sym_defparam] = ACTIONS(5332),
    [anon_sym_bind] = ACTIONS(5332),
    [anon_sym_rand] = ACTIONS(5332),
    [anon_sym_const] = ACTIONS(5332),
    [anon_sym_function] = ACTIONS(5332),
    [anon_sym_static] = ACTIONS(5332),
    [anon_sym_constraint] = ACTIONS(5332),
    [anon_sym_if] = ACTIONS(5332),
    [anon_sym_else] = ACTIONS(5332),
    [anon_sym_LBRACK] = ACTIONS(5330),
    [anon_sym_localparam] = ACTIONS(5332),
    [anon_sym_parameter] = ACTIONS(5332),
    [anon_sym_var] = ACTIONS(5332),
    [anon_sym_import] = ACTIONS(5332),
    [anon_sym_export] = ACTIONS(5332),
    [anon_sym_genvar] = ACTIONS(5332),
    [anon_sym_interconnect] = ACTIONS(5332),
    [anon_sym_typedef] = ACTIONS(5332),
    [anon_sym_enum] = ACTIONS(5332),
    [anon_sym_struct] = ACTIONS(5332),
    [anon_sym_union] = ACTIONS(5332),
    [anon_sym_nettype] = ACTIONS(5332),
    [anon_sym_automatic] = ACTIONS(5332),
    [anon_sym_string] = ACTIONS(5332),
    [anon_sym_chandle] = ACTIONS(5332),
    [anon_sym_event] = ACTIONS(5332),
    [anon_sym_byte] = ACTIONS(5332),
    [anon_sym_shortint] = ACTIONS(5332),
    [anon_sym_int] = ACTIONS(5332),
    [anon_sym_longint] = ACTIONS(5332),
    [anon_sym_integer] = ACTIONS(5332),
    [anon_sym_time] = ACTIONS(5332),
    [anon_sym_bit] = ACTIONS(5332),
    [anon_sym_logic] = ACTIONS(5332),
    [anon_sym_reg] = ACTIONS(5332),
    [anon_sym_shortreal] = ACTIONS(5332),
    [anon_sym_real] = ACTIONS(5332),
    [anon_sym_realtime] = ACTIONS(5332),
    [anon_sym_supply0] = ACTIONS(5332),
    [anon_sym_supply1] = ACTIONS(5332),
    [anon_sym_signed] = ACTIONS(5332),
    [anon_sym_unsigned] = ACTIONS(5332),
    [anon_sym_task] = ACTIONS(5332),
    [anon_sym_assert] = ACTIONS(5332),
    [anon_sym_property] = ACTIONS(5332),
    [anon_sym_assume] = ACTIONS(5332),
    [anon_sym_cover] = ACTIONS(5332),
    [anon_sym_sequence] = ACTIONS(5332),
    [anon_sym_restrict] = ACTIONS(5332),
    [anon_sym_not] = ACTIONS(5332),
    [anon_sym_or] = ACTIONS(5332),
    [anon_sym_and] = ACTIONS(5332),
    [anon_sym_case] = ACTIONS(5332),
    [anon_sym_always] = ACTIONS(5332),
    [anon_sym_covergroup] = ACTIONS(5332),
    [anon_sym_end] = ACTIONS(5332),
    [anon_sym_let] = ACTIONS(5332),
    [anon_sym_pulldown] = ACTIONS(5332),
    [anon_sym_pullup] = ACTIONS(5332),
    [anon_sym_cmos] = ACTIONS(5332),
    [anon_sym_rcmos] = ACTIONS(5332),
    [anon_sym_bufif0] = ACTIONS(5332),
    [anon_sym_bufif1] = ACTIONS(5332),
    [anon_sym_notif0] = ACTIONS(5332),
    [anon_sym_notif1] = ACTIONS(5332),
    [anon_sym_nmos] = ACTIONS(5332),
    [anon_sym_pmos] = ACTIONS(5332),
    [anon_sym_rnmos] = ACTIONS(5332),
    [anon_sym_rpmos] = ACTIONS(5332),
    [anon_sym_nand] = ACTIONS(5332),
    [anon_sym_nor] = ACTIONS(5332),
    [anon_sym_xor] = ACTIONS(5332),
    [anon_sym_xnor] = ACTIONS(5332),
    [anon_sym_buf] = ACTIONS(5332),
    [anon_sym_tranif0] = ACTIONS(5332),
    [anon_sym_tranif1] = ACTIONS(5332),
    [anon_sym_rtranif1] = ACTIONS(5332),
    [anon_sym_rtranif0] = ACTIONS(5332),
    [anon_sym_tran] = ACTIONS(5332),
    [anon_sym_rtran] = ACTIONS(5332),
    [anon_sym_generate] = ACTIONS(5332),
    [anon_sym_for] = ACTIONS(5332),
    [anon_sym_initial] = ACTIONS(5332),
    [anon_sym_assign] = ACTIONS(5332),
    [anon_sym_alias] = ACTIONS(5332),
    [anon_sym_always_comb] = ACTIONS(5332),
    [anon_sym_always_latch] = ACTIONS(5332),
    [anon_sym_always_ff] = ACTIONS(5332),
    [anon_sym_final] = ACTIONS(5332),
    [anon_sym_global] = ACTIONS(5332),
    [anon_sym_LPAREN_STAR] = ACTIONS(5330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5330),
    [anon_sym_DOLLARunit] = ACTIONS(5330),
  },
  [5101] = {
    [sym_simple_identifier] = ACTIONS(5190),
    [anon_sym_wire] = ACTIONS(5190),
    [anon_sym_tri] = ACTIONS(5190),
    [anon_sym_tri0] = ACTIONS(5190),
    [anon_sym_tri1] = ACTIONS(5190),
    [anon_sym_wand] = ACTIONS(5190),
    [anon_sym_triand] = ACTIONS(5190),
    [anon_sym_wor] = ACTIONS(5190),
    [anon_sym_trior] = ACTIONS(5190),
    [anon_sym_trireg] = ACTIONS(5190),
    [anon_sym_uwire] = ACTIONS(5190),
    [anon_sym_SEMI] = ACTIONS(5188),
    [anon_sym_extern] = ACTIONS(5190),
    [anon_sym_interface] = ACTIONS(5190),
    [anon_sym_checker] = ACTIONS(5190),
    [anon_sym_virtual] = ACTIONS(5190),
    [anon_sym_class] = ACTIONS(5190),
    [anon_sym_type] = ACTIONS(5190),
    [anon_sym_DOLLARfatal] = ACTIONS(5188),
    [anon_sym_DOLLARerror] = ACTIONS(5188),
    [anon_sym_DOLLARwarning] = ACTIONS(5188),
    [anon_sym_DOLLARinfo] = ACTIONS(5188),
    [anon_sym_default] = ACTIONS(5190),
    [anon_sym_clocking] = ACTIONS(5190),
    [anon_sym_defparam] = ACTIONS(5190),
    [anon_sym_bind] = ACTIONS(5190),
    [anon_sym_rand] = ACTIONS(5190),
    [anon_sym_const] = ACTIONS(5190),
    [anon_sym_function] = ACTIONS(5190),
    [anon_sym_static] = ACTIONS(5190),
    [anon_sym_constraint] = ACTIONS(5190),
    [anon_sym_if] = ACTIONS(5190),
    [anon_sym_else] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(5188),
    [anon_sym_localparam] = ACTIONS(5190),
    [anon_sym_parameter] = ACTIONS(5190),
    [anon_sym_var] = ACTIONS(5190),
    [anon_sym_import] = ACTIONS(5190),
    [anon_sym_export] = ACTIONS(5190),
    [anon_sym_genvar] = ACTIONS(5190),
    [anon_sym_interconnect] = ACTIONS(5190),
    [anon_sym_typedef] = ACTIONS(5190),
    [anon_sym_enum] = ACTIONS(5190),
    [anon_sym_struct] = ACTIONS(5190),
    [anon_sym_union] = ACTIONS(5190),
    [anon_sym_nettype] = ACTIONS(5190),
    [anon_sym_automatic] = ACTIONS(5190),
    [anon_sym_string] = ACTIONS(5190),
    [anon_sym_chandle] = ACTIONS(5190),
    [anon_sym_event] = ACTIONS(5190),
    [anon_sym_byte] = ACTIONS(5190),
    [anon_sym_shortint] = ACTIONS(5190),
    [anon_sym_int] = ACTIONS(5190),
    [anon_sym_longint] = ACTIONS(5190),
    [anon_sym_integer] = ACTIONS(5190),
    [anon_sym_time] = ACTIONS(5190),
    [anon_sym_bit] = ACTIONS(5190),
    [anon_sym_logic] = ACTIONS(5190),
    [anon_sym_reg] = ACTIONS(5190),
    [anon_sym_shortreal] = ACTIONS(5190),
    [anon_sym_real] = ACTIONS(5190),
    [anon_sym_realtime] = ACTIONS(5190),
    [anon_sym_supply0] = ACTIONS(5190),
    [anon_sym_supply1] = ACTIONS(5190),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_task] = ACTIONS(5190),
    [anon_sym_assert] = ACTIONS(5190),
    [anon_sym_property] = ACTIONS(5190),
    [anon_sym_assume] = ACTIONS(5190),
    [anon_sym_cover] = ACTIONS(5190),
    [anon_sym_sequence] = ACTIONS(5190),
    [anon_sym_restrict] = ACTIONS(5190),
    [anon_sym_not] = ACTIONS(5190),
    [anon_sym_or] = ACTIONS(5190),
    [anon_sym_and] = ACTIONS(5190),
    [anon_sym_case] = ACTIONS(5190),
    [anon_sym_always] = ACTIONS(5190),
    [anon_sym_covergroup] = ACTIONS(5190),
    [anon_sym_end] = ACTIONS(5190),
    [anon_sym_let] = ACTIONS(5190),
    [anon_sym_pulldown] = ACTIONS(5190),
    [anon_sym_pullup] = ACTIONS(5190),
    [anon_sym_cmos] = ACTIONS(5190),
    [anon_sym_rcmos] = ACTIONS(5190),
    [anon_sym_bufif0] = ACTIONS(5190),
    [anon_sym_bufif1] = ACTIONS(5190),
    [anon_sym_notif0] = ACTIONS(5190),
    [anon_sym_notif1] = ACTIONS(5190),
    [anon_sym_nmos] = ACTIONS(5190),
    [anon_sym_pmos] = ACTIONS(5190),
    [anon_sym_rnmos] = ACTIONS(5190),
    [anon_sym_rpmos] = ACTIONS(5190),
    [anon_sym_nand] = ACTIONS(5190),
    [anon_sym_nor] = ACTIONS(5190),
    [anon_sym_xor] = ACTIONS(5190),
    [anon_sym_xnor] = ACTIONS(5190),
    [anon_sym_buf] = ACTIONS(5190),
    [anon_sym_tranif0] = ACTIONS(5190),
    [anon_sym_tranif1] = ACTIONS(5190),
    [anon_sym_rtranif1] = ACTIONS(5190),
    [anon_sym_rtranif0] = ACTIONS(5190),
    [anon_sym_tran] = ACTIONS(5190),
    [anon_sym_rtran] = ACTIONS(5190),
    [anon_sym_generate] = ACTIONS(5190),
    [anon_sym_for] = ACTIONS(5190),
    [anon_sym_initial] = ACTIONS(5190),
    [anon_sym_assign] = ACTIONS(5190),
    [anon_sym_alias] = ACTIONS(5190),
    [anon_sym_always_comb] = ACTIONS(5190),
    [anon_sym_always_latch] = ACTIONS(5190),
    [anon_sym_always_ff] = ACTIONS(5190),
    [anon_sym_final] = ACTIONS(5190),
    [anon_sym_global] = ACTIONS(5190),
    [anon_sym_LPAREN_STAR] = ACTIONS(5188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5188),
    [anon_sym_DOLLARunit] = ACTIONS(5188),
  },
  [5102] = {
    [sym_simple_identifier] = ACTIONS(5194),
    [anon_sym_wire] = ACTIONS(5194),
    [anon_sym_tri] = ACTIONS(5194),
    [anon_sym_tri0] = ACTIONS(5194),
    [anon_sym_tri1] = ACTIONS(5194),
    [anon_sym_wand] = ACTIONS(5194),
    [anon_sym_triand] = ACTIONS(5194),
    [anon_sym_wor] = ACTIONS(5194),
    [anon_sym_trior] = ACTIONS(5194),
    [anon_sym_trireg] = ACTIONS(5194),
    [anon_sym_uwire] = ACTIONS(5194),
    [anon_sym_SEMI] = ACTIONS(5192),
    [anon_sym_extern] = ACTIONS(5194),
    [anon_sym_interface] = ACTIONS(5194),
    [anon_sym_checker] = ACTIONS(5194),
    [anon_sym_virtual] = ACTIONS(5194),
    [anon_sym_class] = ACTIONS(5194),
    [anon_sym_type] = ACTIONS(5194),
    [anon_sym_DOLLARfatal] = ACTIONS(5192),
    [anon_sym_DOLLARerror] = ACTIONS(5192),
    [anon_sym_DOLLARwarning] = ACTIONS(5192),
    [anon_sym_DOLLARinfo] = ACTIONS(5192),
    [anon_sym_default] = ACTIONS(5194),
    [anon_sym_clocking] = ACTIONS(5194),
    [anon_sym_defparam] = ACTIONS(5194),
    [anon_sym_bind] = ACTIONS(5194),
    [anon_sym_rand] = ACTIONS(5194),
    [anon_sym_const] = ACTIONS(5194),
    [anon_sym_function] = ACTIONS(5194),
    [anon_sym_static] = ACTIONS(5194),
    [anon_sym_constraint] = ACTIONS(5194),
    [anon_sym_if] = ACTIONS(5194),
    [anon_sym_else] = ACTIONS(5194),
    [anon_sym_LBRACK] = ACTIONS(5192),
    [anon_sym_localparam] = ACTIONS(5194),
    [anon_sym_parameter] = ACTIONS(5194),
    [anon_sym_var] = ACTIONS(5194),
    [anon_sym_import] = ACTIONS(5194),
    [anon_sym_export] = ACTIONS(5194),
    [anon_sym_genvar] = ACTIONS(5194),
    [anon_sym_interconnect] = ACTIONS(5194),
    [anon_sym_typedef] = ACTIONS(5194),
    [anon_sym_enum] = ACTIONS(5194),
    [anon_sym_struct] = ACTIONS(5194),
    [anon_sym_union] = ACTIONS(5194),
    [anon_sym_nettype] = ACTIONS(5194),
    [anon_sym_automatic] = ACTIONS(5194),
    [anon_sym_string] = ACTIONS(5194),
    [anon_sym_chandle] = ACTIONS(5194),
    [anon_sym_event] = ACTIONS(5194),
    [anon_sym_byte] = ACTIONS(5194),
    [anon_sym_shortint] = ACTIONS(5194),
    [anon_sym_int] = ACTIONS(5194),
    [anon_sym_longint] = ACTIONS(5194),
    [anon_sym_integer] = ACTIONS(5194),
    [anon_sym_time] = ACTIONS(5194),
    [anon_sym_bit] = ACTIONS(5194),
    [anon_sym_logic] = ACTIONS(5194),
    [anon_sym_reg] = ACTIONS(5194),
    [anon_sym_shortreal] = ACTIONS(5194),
    [anon_sym_real] = ACTIONS(5194),
    [anon_sym_realtime] = ACTIONS(5194),
    [anon_sym_supply0] = ACTIONS(5194),
    [anon_sym_supply1] = ACTIONS(5194),
    [anon_sym_signed] = ACTIONS(5194),
    [anon_sym_unsigned] = ACTIONS(5194),
    [anon_sym_task] = ACTIONS(5194),
    [anon_sym_assert] = ACTIONS(5194),
    [anon_sym_property] = ACTIONS(5194),
    [anon_sym_assume] = ACTIONS(5194),
    [anon_sym_cover] = ACTIONS(5194),
    [anon_sym_sequence] = ACTIONS(5194),
    [anon_sym_restrict] = ACTIONS(5194),
    [anon_sym_not] = ACTIONS(5194),
    [anon_sym_or] = ACTIONS(5194),
    [anon_sym_and] = ACTIONS(5194),
    [anon_sym_case] = ACTIONS(5194),
    [anon_sym_always] = ACTIONS(5194),
    [anon_sym_covergroup] = ACTIONS(5194),
    [anon_sym_end] = ACTIONS(5194),
    [anon_sym_let] = ACTIONS(5194),
    [anon_sym_pulldown] = ACTIONS(5194),
    [anon_sym_pullup] = ACTIONS(5194),
    [anon_sym_cmos] = ACTIONS(5194),
    [anon_sym_rcmos] = ACTIONS(5194),
    [anon_sym_bufif0] = ACTIONS(5194),
    [anon_sym_bufif1] = ACTIONS(5194),
    [anon_sym_notif0] = ACTIONS(5194),
    [anon_sym_notif1] = ACTIONS(5194),
    [anon_sym_nmos] = ACTIONS(5194),
    [anon_sym_pmos] = ACTIONS(5194),
    [anon_sym_rnmos] = ACTIONS(5194),
    [anon_sym_rpmos] = ACTIONS(5194),
    [anon_sym_nand] = ACTIONS(5194),
    [anon_sym_nor] = ACTIONS(5194),
    [anon_sym_xor] = ACTIONS(5194),
    [anon_sym_xnor] = ACTIONS(5194),
    [anon_sym_buf] = ACTIONS(5194),
    [anon_sym_tranif0] = ACTIONS(5194),
    [anon_sym_tranif1] = ACTIONS(5194),
    [anon_sym_rtranif1] = ACTIONS(5194),
    [anon_sym_rtranif0] = ACTIONS(5194),
    [anon_sym_tran] = ACTIONS(5194),
    [anon_sym_rtran] = ACTIONS(5194),
    [anon_sym_generate] = ACTIONS(5194),
    [anon_sym_for] = ACTIONS(5194),
    [anon_sym_initial] = ACTIONS(5194),
    [anon_sym_assign] = ACTIONS(5194),
    [anon_sym_alias] = ACTIONS(5194),
    [anon_sym_always_comb] = ACTIONS(5194),
    [anon_sym_always_latch] = ACTIONS(5194),
    [anon_sym_always_ff] = ACTIONS(5194),
    [anon_sym_final] = ACTIONS(5194),
    [anon_sym_global] = ACTIONS(5194),
    [anon_sym_LPAREN_STAR] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5192),
    [anon_sym_DOLLARunit] = ACTIONS(5192),
  },
  [5103] = {
    [sym_simple_identifier] = ACTIONS(4780),
    [anon_sym_wire] = ACTIONS(4780),
    [anon_sym_tri] = ACTIONS(4780),
    [anon_sym_tri0] = ACTIONS(4780),
    [anon_sym_tri1] = ACTIONS(4780),
    [anon_sym_wand] = ACTIONS(4780),
    [anon_sym_triand] = ACTIONS(4780),
    [anon_sym_wor] = ACTIONS(4780),
    [anon_sym_trior] = ACTIONS(4780),
    [anon_sym_trireg] = ACTIONS(4780),
    [anon_sym_uwire] = ACTIONS(4780),
    [anon_sym_SEMI] = ACTIONS(4778),
    [anon_sym_extern] = ACTIONS(4780),
    [anon_sym_interface] = ACTIONS(4780),
    [anon_sym_checker] = ACTIONS(4780),
    [anon_sym_virtual] = ACTIONS(4780),
    [anon_sym_class] = ACTIONS(4780),
    [anon_sym_type] = ACTIONS(4780),
    [anon_sym_DOLLARfatal] = ACTIONS(4778),
    [anon_sym_DOLLARerror] = ACTIONS(4778),
    [anon_sym_DOLLARwarning] = ACTIONS(4778),
    [anon_sym_DOLLARinfo] = ACTIONS(4778),
    [anon_sym_default] = ACTIONS(4780),
    [anon_sym_clocking] = ACTIONS(4780),
    [anon_sym_defparam] = ACTIONS(4780),
    [anon_sym_bind] = ACTIONS(4780),
    [anon_sym_rand] = ACTIONS(4780),
    [anon_sym_const] = ACTIONS(4780),
    [anon_sym_function] = ACTIONS(4780),
    [anon_sym_static] = ACTIONS(4780),
    [anon_sym_constraint] = ACTIONS(4780),
    [anon_sym_if] = ACTIONS(4780),
    [anon_sym_else] = ACTIONS(4780),
    [anon_sym_LBRACK] = ACTIONS(4778),
    [anon_sym_localparam] = ACTIONS(4780),
    [anon_sym_parameter] = ACTIONS(4780),
    [anon_sym_var] = ACTIONS(4780),
    [anon_sym_import] = ACTIONS(4780),
    [anon_sym_export] = ACTIONS(4780),
    [anon_sym_genvar] = ACTIONS(4780),
    [anon_sym_interconnect] = ACTIONS(4780),
    [anon_sym_typedef] = ACTIONS(4780),
    [anon_sym_enum] = ACTIONS(4780),
    [anon_sym_struct] = ACTIONS(4780),
    [anon_sym_union] = ACTIONS(4780),
    [anon_sym_nettype] = ACTIONS(4780),
    [anon_sym_automatic] = ACTIONS(4780),
    [anon_sym_string] = ACTIONS(4780),
    [anon_sym_chandle] = ACTIONS(4780),
    [anon_sym_event] = ACTIONS(4780),
    [anon_sym_byte] = ACTIONS(4780),
    [anon_sym_shortint] = ACTIONS(4780),
    [anon_sym_int] = ACTIONS(4780),
    [anon_sym_longint] = ACTIONS(4780),
    [anon_sym_integer] = ACTIONS(4780),
    [anon_sym_time] = ACTIONS(4780),
    [anon_sym_bit] = ACTIONS(4780),
    [anon_sym_logic] = ACTIONS(4780),
    [anon_sym_reg] = ACTIONS(4780),
    [anon_sym_shortreal] = ACTIONS(4780),
    [anon_sym_real] = ACTIONS(4780),
    [anon_sym_realtime] = ACTIONS(4780),
    [anon_sym_supply0] = ACTIONS(4780),
    [anon_sym_supply1] = ACTIONS(4780),
    [anon_sym_signed] = ACTIONS(4780),
    [anon_sym_unsigned] = ACTIONS(4780),
    [anon_sym_task] = ACTIONS(4780),
    [anon_sym_assert] = ACTIONS(4780),
    [anon_sym_property] = ACTIONS(4780),
    [anon_sym_assume] = ACTIONS(4780),
    [anon_sym_cover] = ACTIONS(4780),
    [anon_sym_sequence] = ACTIONS(4780),
    [anon_sym_restrict] = ACTIONS(4780),
    [anon_sym_not] = ACTIONS(4780),
    [anon_sym_or] = ACTIONS(4780),
    [anon_sym_and] = ACTIONS(4780),
    [anon_sym_case] = ACTIONS(4780),
    [anon_sym_always] = ACTIONS(4780),
    [anon_sym_covergroup] = ACTIONS(4780),
    [anon_sym_end] = ACTIONS(4780),
    [anon_sym_let] = ACTIONS(4780),
    [anon_sym_pulldown] = ACTIONS(4780),
    [anon_sym_pullup] = ACTIONS(4780),
    [anon_sym_cmos] = ACTIONS(4780),
    [anon_sym_rcmos] = ACTIONS(4780),
    [anon_sym_bufif0] = ACTIONS(4780),
    [anon_sym_bufif1] = ACTIONS(4780),
    [anon_sym_notif0] = ACTIONS(4780),
    [anon_sym_notif1] = ACTIONS(4780),
    [anon_sym_nmos] = ACTIONS(4780),
    [anon_sym_pmos] = ACTIONS(4780),
    [anon_sym_rnmos] = ACTIONS(4780),
    [anon_sym_rpmos] = ACTIONS(4780),
    [anon_sym_nand] = ACTIONS(4780),
    [anon_sym_nor] = ACTIONS(4780),
    [anon_sym_xor] = ACTIONS(4780),
    [anon_sym_xnor] = ACTIONS(4780),
    [anon_sym_buf] = ACTIONS(4780),
    [anon_sym_tranif0] = ACTIONS(4780),
    [anon_sym_tranif1] = ACTIONS(4780),
    [anon_sym_rtranif1] = ACTIONS(4780),
    [anon_sym_rtranif0] = ACTIONS(4780),
    [anon_sym_tran] = ACTIONS(4780),
    [anon_sym_rtran] = ACTIONS(4780),
    [anon_sym_generate] = ACTIONS(4780),
    [anon_sym_for] = ACTIONS(4780),
    [anon_sym_initial] = ACTIONS(4780),
    [anon_sym_assign] = ACTIONS(4780),
    [anon_sym_alias] = ACTIONS(4780),
    [anon_sym_always_comb] = ACTIONS(4780),
    [anon_sym_always_latch] = ACTIONS(4780),
    [anon_sym_always_ff] = ACTIONS(4780),
    [anon_sym_final] = ACTIONS(4780),
    [anon_sym_global] = ACTIONS(4780),
    [anon_sym_LPAREN_STAR] = ACTIONS(4778),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4778),
    [anon_sym_DOLLARunit] = ACTIONS(4778),
  },
  [5104] = {
    [sym_simple_identifier] = ACTIONS(6683),
    [anon_sym_wire] = ACTIONS(6683),
    [anon_sym_tri] = ACTIONS(6683),
    [anon_sym_tri0] = ACTIONS(6683),
    [anon_sym_tri1] = ACTIONS(6683),
    [anon_sym_wand] = ACTIONS(6683),
    [anon_sym_triand] = ACTIONS(6683),
    [anon_sym_wor] = ACTIONS(6683),
    [anon_sym_trior] = ACTIONS(6683),
    [anon_sym_trireg] = ACTIONS(6683),
    [anon_sym_uwire] = ACTIONS(6683),
    [anon_sym_SEMI] = ACTIONS(6685),
    [anon_sym_extern] = ACTIONS(6683),
    [anon_sym_interface] = ACTIONS(6683),
    [anon_sym_checker] = ACTIONS(6683),
    [anon_sym_virtual] = ACTIONS(6683),
    [anon_sym_class] = ACTIONS(6683),
    [anon_sym_type] = ACTIONS(6683),
    [anon_sym_DOLLARfatal] = ACTIONS(6685),
    [anon_sym_DOLLARerror] = ACTIONS(6685),
    [anon_sym_DOLLARwarning] = ACTIONS(6685),
    [anon_sym_DOLLARinfo] = ACTIONS(6685),
    [anon_sym_default] = ACTIONS(6683),
    [anon_sym_clocking] = ACTIONS(6683),
    [anon_sym_defparam] = ACTIONS(6683),
    [anon_sym_bind] = ACTIONS(6683),
    [anon_sym_rand] = ACTIONS(6683),
    [anon_sym_const] = ACTIONS(6683),
    [anon_sym_function] = ACTIONS(6683),
    [anon_sym_static] = ACTIONS(6683),
    [anon_sym_constraint] = ACTIONS(6683),
    [anon_sym_if] = ACTIONS(6683),
    [anon_sym_else] = ACTIONS(6683),
    [anon_sym_LBRACK] = ACTIONS(6685),
    [anon_sym_localparam] = ACTIONS(6683),
    [anon_sym_parameter] = ACTIONS(6683),
    [anon_sym_var] = ACTIONS(6683),
    [anon_sym_import] = ACTIONS(6683),
    [anon_sym_export] = ACTIONS(6683),
    [anon_sym_genvar] = ACTIONS(6683),
    [anon_sym_interconnect] = ACTIONS(6683),
    [anon_sym_typedef] = ACTIONS(6683),
    [anon_sym_enum] = ACTIONS(6683),
    [anon_sym_struct] = ACTIONS(6683),
    [anon_sym_union] = ACTIONS(6683),
    [anon_sym_nettype] = ACTIONS(6683),
    [anon_sym_automatic] = ACTIONS(6683),
    [anon_sym_string] = ACTIONS(6683),
    [anon_sym_chandle] = ACTIONS(6683),
    [anon_sym_event] = ACTIONS(6683),
    [anon_sym_byte] = ACTIONS(6683),
    [anon_sym_shortint] = ACTIONS(6683),
    [anon_sym_int] = ACTIONS(6683),
    [anon_sym_longint] = ACTIONS(6683),
    [anon_sym_integer] = ACTIONS(6683),
    [anon_sym_time] = ACTIONS(6683),
    [anon_sym_bit] = ACTIONS(6683),
    [anon_sym_logic] = ACTIONS(6683),
    [anon_sym_reg] = ACTIONS(6683),
    [anon_sym_shortreal] = ACTIONS(6683),
    [anon_sym_real] = ACTIONS(6683),
    [anon_sym_realtime] = ACTIONS(6683),
    [anon_sym_supply0] = ACTIONS(6683),
    [anon_sym_supply1] = ACTIONS(6683),
    [anon_sym_signed] = ACTIONS(6683),
    [anon_sym_unsigned] = ACTIONS(6683),
    [anon_sym_task] = ACTIONS(6683),
    [anon_sym_assert] = ACTIONS(6683),
    [anon_sym_property] = ACTIONS(6683),
    [anon_sym_assume] = ACTIONS(6683),
    [anon_sym_cover] = ACTIONS(6683),
    [anon_sym_sequence] = ACTIONS(6683),
    [anon_sym_restrict] = ACTIONS(6683),
    [anon_sym_not] = ACTIONS(6683),
    [anon_sym_or] = ACTIONS(6683),
    [anon_sym_and] = ACTIONS(6683),
    [anon_sym_case] = ACTIONS(6683),
    [anon_sym_always] = ACTIONS(6683),
    [anon_sym_covergroup] = ACTIONS(6683),
    [anon_sym_end] = ACTIONS(6683),
    [anon_sym_let] = ACTIONS(6683),
    [anon_sym_pulldown] = ACTIONS(6683),
    [anon_sym_pullup] = ACTIONS(6683),
    [anon_sym_cmos] = ACTIONS(6683),
    [anon_sym_rcmos] = ACTIONS(6683),
    [anon_sym_bufif0] = ACTIONS(6683),
    [anon_sym_bufif1] = ACTIONS(6683),
    [anon_sym_notif0] = ACTIONS(6683),
    [anon_sym_notif1] = ACTIONS(6683),
    [anon_sym_nmos] = ACTIONS(6683),
    [anon_sym_pmos] = ACTIONS(6683),
    [anon_sym_rnmos] = ACTIONS(6683),
    [anon_sym_rpmos] = ACTIONS(6683),
    [anon_sym_nand] = ACTIONS(6683),
    [anon_sym_nor] = ACTIONS(6683),
    [anon_sym_xor] = ACTIONS(6683),
    [anon_sym_xnor] = ACTIONS(6683),
    [anon_sym_buf] = ACTIONS(6683),
    [anon_sym_tranif0] = ACTIONS(6683),
    [anon_sym_tranif1] = ACTIONS(6683),
    [anon_sym_rtranif1] = ACTIONS(6683),
    [anon_sym_rtranif0] = ACTIONS(6683),
    [anon_sym_tran] = ACTIONS(6683),
    [anon_sym_rtran] = ACTIONS(6683),
    [anon_sym_generate] = ACTIONS(6683),
    [anon_sym_for] = ACTIONS(6683),
    [anon_sym_initial] = ACTIONS(6683),
    [anon_sym_assign] = ACTIONS(6683),
    [anon_sym_alias] = ACTIONS(6683),
    [anon_sym_always_comb] = ACTIONS(6683),
    [anon_sym_always_latch] = ACTIONS(6683),
    [anon_sym_always_ff] = ACTIONS(6683),
    [anon_sym_final] = ACTIONS(6683),
    [anon_sym_global] = ACTIONS(6683),
    [anon_sym_LPAREN_STAR] = ACTIONS(6685),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6685),
    [anon_sym_DOLLARunit] = ACTIONS(6685),
  },
  [5105] = {
    [sym_simple_identifier] = ACTIONS(6047),
    [anon_sym_wire] = ACTIONS(6047),
    [anon_sym_tri] = ACTIONS(6047),
    [anon_sym_tri0] = ACTIONS(6047),
    [anon_sym_tri1] = ACTIONS(6047),
    [anon_sym_wand] = ACTIONS(6047),
    [anon_sym_triand] = ACTIONS(6047),
    [anon_sym_wor] = ACTIONS(6047),
    [anon_sym_trior] = ACTIONS(6047),
    [anon_sym_trireg] = ACTIONS(6047),
    [anon_sym_uwire] = ACTIONS(6047),
    [anon_sym_SEMI] = ACTIONS(6049),
    [anon_sym_extern] = ACTIONS(6047),
    [anon_sym_interface] = ACTIONS(6047),
    [anon_sym_checker] = ACTIONS(6047),
    [anon_sym_virtual] = ACTIONS(6047),
    [anon_sym_class] = ACTIONS(6047),
    [anon_sym_type] = ACTIONS(6047),
    [anon_sym_DOLLARfatal] = ACTIONS(6049),
    [anon_sym_DOLLARerror] = ACTIONS(6049),
    [anon_sym_DOLLARwarning] = ACTIONS(6049),
    [anon_sym_DOLLARinfo] = ACTIONS(6049),
    [anon_sym_default] = ACTIONS(6047),
    [anon_sym_clocking] = ACTIONS(6047),
    [anon_sym_defparam] = ACTIONS(6047),
    [anon_sym_bind] = ACTIONS(6047),
    [anon_sym_rand] = ACTIONS(6047),
    [anon_sym_const] = ACTIONS(6047),
    [anon_sym_function] = ACTIONS(6047),
    [anon_sym_static] = ACTIONS(6047),
    [anon_sym_constraint] = ACTIONS(6047),
    [anon_sym_if] = ACTIONS(6047),
    [anon_sym_else] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(6049),
    [anon_sym_localparam] = ACTIONS(6047),
    [anon_sym_parameter] = ACTIONS(6047),
    [anon_sym_var] = ACTIONS(6047),
    [anon_sym_import] = ACTIONS(6047),
    [anon_sym_export] = ACTIONS(6047),
    [anon_sym_genvar] = ACTIONS(6047),
    [anon_sym_interconnect] = ACTIONS(6047),
    [anon_sym_typedef] = ACTIONS(6047),
    [anon_sym_enum] = ACTIONS(6047),
    [anon_sym_struct] = ACTIONS(6047),
    [anon_sym_union] = ACTIONS(6047),
    [anon_sym_nettype] = ACTIONS(6047),
    [anon_sym_automatic] = ACTIONS(6047),
    [anon_sym_string] = ACTIONS(6047),
    [anon_sym_chandle] = ACTIONS(6047),
    [anon_sym_event] = ACTIONS(6047),
    [anon_sym_byte] = ACTIONS(6047),
    [anon_sym_shortint] = ACTIONS(6047),
    [anon_sym_int] = ACTIONS(6047),
    [anon_sym_longint] = ACTIONS(6047),
    [anon_sym_integer] = ACTIONS(6047),
    [anon_sym_time] = ACTIONS(6047),
    [anon_sym_bit] = ACTIONS(6047),
    [anon_sym_logic] = ACTIONS(6047),
    [anon_sym_reg] = ACTIONS(6047),
    [anon_sym_shortreal] = ACTIONS(6047),
    [anon_sym_real] = ACTIONS(6047),
    [anon_sym_realtime] = ACTIONS(6047),
    [anon_sym_supply0] = ACTIONS(6047),
    [anon_sym_supply1] = ACTIONS(6047),
    [anon_sym_signed] = ACTIONS(6047),
    [anon_sym_unsigned] = ACTIONS(6047),
    [anon_sym_task] = ACTIONS(6047),
    [anon_sym_assert] = ACTIONS(6047),
    [anon_sym_property] = ACTIONS(6047),
    [anon_sym_assume] = ACTIONS(6047),
    [anon_sym_cover] = ACTIONS(6047),
    [anon_sym_sequence] = ACTIONS(6047),
    [anon_sym_restrict] = ACTIONS(6047),
    [anon_sym_not] = ACTIONS(6047),
    [anon_sym_or] = ACTIONS(6047),
    [anon_sym_and] = ACTIONS(6047),
    [anon_sym_case] = ACTIONS(6047),
    [anon_sym_always] = ACTIONS(6047),
    [anon_sym_covergroup] = ACTIONS(6047),
    [anon_sym_let] = ACTIONS(6047),
    [anon_sym_pulldown] = ACTIONS(6047),
    [anon_sym_pullup] = ACTIONS(6047),
    [anon_sym_cmos] = ACTIONS(6047),
    [anon_sym_rcmos] = ACTIONS(6047),
    [anon_sym_bufif0] = ACTIONS(6047),
    [anon_sym_bufif1] = ACTIONS(6047),
    [anon_sym_notif0] = ACTIONS(6047),
    [anon_sym_notif1] = ACTIONS(6047),
    [anon_sym_nmos] = ACTIONS(6047),
    [anon_sym_pmos] = ACTIONS(6047),
    [anon_sym_rnmos] = ACTIONS(6047),
    [anon_sym_rpmos] = ACTIONS(6047),
    [anon_sym_nand] = ACTIONS(6047),
    [anon_sym_nor] = ACTIONS(6047),
    [anon_sym_xor] = ACTIONS(6047),
    [anon_sym_xnor] = ACTIONS(6047),
    [anon_sym_buf] = ACTIONS(6047),
    [anon_sym_tranif0] = ACTIONS(6047),
    [anon_sym_tranif1] = ACTIONS(6047),
    [anon_sym_rtranif1] = ACTIONS(6047),
    [anon_sym_rtranif0] = ACTIONS(6047),
    [anon_sym_tran] = ACTIONS(6047),
    [anon_sym_rtran] = ACTIONS(6047),
    [anon_sym_generate] = ACTIONS(6047),
    [anon_sym_endgenerate] = ACTIONS(6047),
    [anon_sym_for] = ACTIONS(6047),
    [anon_sym_initial] = ACTIONS(6047),
    [anon_sym_assign] = ACTIONS(6047),
    [anon_sym_alias] = ACTIONS(6047),
    [anon_sym_always_comb] = ACTIONS(6047),
    [anon_sym_always_latch] = ACTIONS(6047),
    [anon_sym_always_ff] = ACTIONS(6047),
    [anon_sym_final] = ACTIONS(6047),
    [anon_sym_global] = ACTIONS(6047),
    [anon_sym_LPAREN_STAR] = ACTIONS(6049),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6049),
    [anon_sym_DOLLARunit] = ACTIONS(6049),
  },
  [5106] = {
    [sym_simple_identifier] = ACTIONS(5348),
    [anon_sym_wire] = ACTIONS(5348),
    [anon_sym_tri] = ACTIONS(5348),
    [anon_sym_tri0] = ACTIONS(5348),
    [anon_sym_tri1] = ACTIONS(5348),
    [anon_sym_wand] = ACTIONS(5348),
    [anon_sym_triand] = ACTIONS(5348),
    [anon_sym_wor] = ACTIONS(5348),
    [anon_sym_trior] = ACTIONS(5348),
    [anon_sym_trireg] = ACTIONS(5348),
    [anon_sym_uwire] = ACTIONS(5348),
    [anon_sym_SEMI] = ACTIONS(5346),
    [anon_sym_extern] = ACTIONS(5348),
    [anon_sym_interface] = ACTIONS(5348),
    [anon_sym_checker] = ACTIONS(5348),
    [anon_sym_virtual] = ACTIONS(5348),
    [anon_sym_class] = ACTIONS(5348),
    [anon_sym_type] = ACTIONS(5348),
    [anon_sym_DOLLARfatal] = ACTIONS(5346),
    [anon_sym_DOLLARerror] = ACTIONS(5346),
    [anon_sym_DOLLARwarning] = ACTIONS(5346),
    [anon_sym_DOLLARinfo] = ACTIONS(5346),
    [anon_sym_default] = ACTIONS(5348),
    [anon_sym_clocking] = ACTIONS(5348),
    [anon_sym_defparam] = ACTIONS(5348),
    [anon_sym_bind] = ACTIONS(5348),
    [anon_sym_rand] = ACTIONS(5348),
    [anon_sym_const] = ACTIONS(5348),
    [anon_sym_function] = ACTIONS(5348),
    [anon_sym_static] = ACTIONS(5348),
    [anon_sym_constraint] = ACTIONS(5348),
    [anon_sym_if] = ACTIONS(5348),
    [anon_sym_else] = ACTIONS(5348),
    [anon_sym_LBRACK] = ACTIONS(5346),
    [anon_sym_localparam] = ACTIONS(5348),
    [anon_sym_parameter] = ACTIONS(5348),
    [anon_sym_var] = ACTIONS(5348),
    [anon_sym_import] = ACTIONS(5348),
    [anon_sym_export] = ACTIONS(5348),
    [anon_sym_genvar] = ACTIONS(5348),
    [anon_sym_interconnect] = ACTIONS(5348),
    [anon_sym_typedef] = ACTIONS(5348),
    [anon_sym_enum] = ACTIONS(5348),
    [anon_sym_struct] = ACTIONS(5348),
    [anon_sym_union] = ACTIONS(5348),
    [anon_sym_nettype] = ACTIONS(5348),
    [anon_sym_automatic] = ACTIONS(5348),
    [anon_sym_string] = ACTIONS(5348),
    [anon_sym_chandle] = ACTIONS(5348),
    [anon_sym_event] = ACTIONS(5348),
    [anon_sym_byte] = ACTIONS(5348),
    [anon_sym_shortint] = ACTIONS(5348),
    [anon_sym_int] = ACTIONS(5348),
    [anon_sym_longint] = ACTIONS(5348),
    [anon_sym_integer] = ACTIONS(5348),
    [anon_sym_time] = ACTIONS(5348),
    [anon_sym_bit] = ACTIONS(5348),
    [anon_sym_logic] = ACTIONS(5348),
    [anon_sym_reg] = ACTIONS(5348),
    [anon_sym_shortreal] = ACTIONS(5348),
    [anon_sym_real] = ACTIONS(5348),
    [anon_sym_realtime] = ACTIONS(5348),
    [anon_sym_supply0] = ACTIONS(5348),
    [anon_sym_supply1] = ACTIONS(5348),
    [anon_sym_signed] = ACTIONS(5348),
    [anon_sym_unsigned] = ACTIONS(5348),
    [anon_sym_task] = ACTIONS(5348),
    [anon_sym_assert] = ACTIONS(5348),
    [anon_sym_property] = ACTIONS(5348),
    [anon_sym_assume] = ACTIONS(5348),
    [anon_sym_cover] = ACTIONS(5348),
    [anon_sym_sequence] = ACTIONS(5348),
    [anon_sym_restrict] = ACTIONS(5348),
    [anon_sym_not] = ACTIONS(5348),
    [anon_sym_or] = ACTIONS(5348),
    [anon_sym_and] = ACTIONS(5348),
    [anon_sym_case] = ACTIONS(5348),
    [anon_sym_always] = ACTIONS(5348),
    [anon_sym_covergroup] = ACTIONS(5348),
    [anon_sym_let] = ACTIONS(5348),
    [anon_sym_pulldown] = ACTIONS(5348),
    [anon_sym_pullup] = ACTIONS(5348),
    [anon_sym_cmos] = ACTIONS(5348),
    [anon_sym_rcmos] = ACTIONS(5348),
    [anon_sym_bufif0] = ACTIONS(5348),
    [anon_sym_bufif1] = ACTIONS(5348),
    [anon_sym_notif0] = ACTIONS(5348),
    [anon_sym_notif1] = ACTIONS(5348),
    [anon_sym_nmos] = ACTIONS(5348),
    [anon_sym_pmos] = ACTIONS(5348),
    [anon_sym_rnmos] = ACTIONS(5348),
    [anon_sym_rpmos] = ACTIONS(5348),
    [anon_sym_nand] = ACTIONS(5348),
    [anon_sym_nor] = ACTIONS(5348),
    [anon_sym_xor] = ACTIONS(5348),
    [anon_sym_xnor] = ACTIONS(5348),
    [anon_sym_buf] = ACTIONS(5348),
    [anon_sym_tranif0] = ACTIONS(5348),
    [anon_sym_tranif1] = ACTIONS(5348),
    [anon_sym_rtranif1] = ACTIONS(5348),
    [anon_sym_rtranif0] = ACTIONS(5348),
    [anon_sym_tran] = ACTIONS(5348),
    [anon_sym_rtran] = ACTIONS(5348),
    [anon_sym_generate] = ACTIONS(5348),
    [anon_sym_endgenerate] = ACTIONS(5348),
    [anon_sym_for] = ACTIONS(5348),
    [anon_sym_initial] = ACTIONS(5348),
    [anon_sym_assign] = ACTIONS(5348),
    [anon_sym_alias] = ACTIONS(5348),
    [anon_sym_always_comb] = ACTIONS(5348),
    [anon_sym_always_latch] = ACTIONS(5348),
    [anon_sym_always_ff] = ACTIONS(5348),
    [anon_sym_final] = ACTIONS(5348),
    [anon_sym_global] = ACTIONS(5348),
    [anon_sym_LPAREN_STAR] = ACTIONS(5346),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5346),
    [anon_sym_DOLLARunit] = ACTIONS(5346),
  },
  [5107] = {
    [sym_simple_identifier] = ACTIONS(5336),
    [anon_sym_wire] = ACTIONS(5336),
    [anon_sym_tri] = ACTIONS(5336),
    [anon_sym_tri0] = ACTIONS(5336),
    [anon_sym_tri1] = ACTIONS(5336),
    [anon_sym_wand] = ACTIONS(5336),
    [anon_sym_triand] = ACTIONS(5336),
    [anon_sym_wor] = ACTIONS(5336),
    [anon_sym_trior] = ACTIONS(5336),
    [anon_sym_trireg] = ACTIONS(5336),
    [anon_sym_uwire] = ACTIONS(5336),
    [anon_sym_SEMI] = ACTIONS(5334),
    [anon_sym_extern] = ACTIONS(5336),
    [anon_sym_interface] = ACTIONS(5336),
    [anon_sym_checker] = ACTIONS(5336),
    [anon_sym_virtual] = ACTIONS(5336),
    [anon_sym_class] = ACTIONS(5336),
    [anon_sym_type] = ACTIONS(5336),
    [anon_sym_DOLLARfatal] = ACTIONS(5334),
    [anon_sym_DOLLARerror] = ACTIONS(5334),
    [anon_sym_DOLLARwarning] = ACTIONS(5334),
    [anon_sym_DOLLARinfo] = ACTIONS(5334),
    [anon_sym_default] = ACTIONS(5336),
    [anon_sym_clocking] = ACTIONS(5336),
    [anon_sym_defparam] = ACTIONS(5336),
    [anon_sym_bind] = ACTIONS(5336),
    [anon_sym_rand] = ACTIONS(5336),
    [anon_sym_const] = ACTIONS(5336),
    [anon_sym_function] = ACTIONS(5336),
    [anon_sym_static] = ACTIONS(5336),
    [anon_sym_constraint] = ACTIONS(5336),
    [anon_sym_if] = ACTIONS(5336),
    [anon_sym_else] = ACTIONS(5336),
    [anon_sym_LBRACK] = ACTIONS(5334),
    [anon_sym_localparam] = ACTIONS(5336),
    [anon_sym_parameter] = ACTIONS(5336),
    [anon_sym_var] = ACTIONS(5336),
    [anon_sym_import] = ACTIONS(5336),
    [anon_sym_export] = ACTIONS(5336),
    [anon_sym_genvar] = ACTIONS(5336),
    [anon_sym_interconnect] = ACTIONS(5336),
    [anon_sym_typedef] = ACTIONS(5336),
    [anon_sym_enum] = ACTIONS(5336),
    [anon_sym_struct] = ACTIONS(5336),
    [anon_sym_union] = ACTIONS(5336),
    [anon_sym_nettype] = ACTIONS(5336),
    [anon_sym_automatic] = ACTIONS(5336),
    [anon_sym_string] = ACTIONS(5336),
    [anon_sym_chandle] = ACTIONS(5336),
    [anon_sym_event] = ACTIONS(5336),
    [anon_sym_byte] = ACTIONS(5336),
    [anon_sym_shortint] = ACTIONS(5336),
    [anon_sym_int] = ACTIONS(5336),
    [anon_sym_longint] = ACTIONS(5336),
    [anon_sym_integer] = ACTIONS(5336),
    [anon_sym_time] = ACTIONS(5336),
    [anon_sym_bit] = ACTIONS(5336),
    [anon_sym_logic] = ACTIONS(5336),
    [anon_sym_reg] = ACTIONS(5336),
    [anon_sym_shortreal] = ACTIONS(5336),
    [anon_sym_real] = ACTIONS(5336),
    [anon_sym_realtime] = ACTIONS(5336),
    [anon_sym_supply0] = ACTIONS(5336),
    [anon_sym_supply1] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(5336),
    [anon_sym_unsigned] = ACTIONS(5336),
    [anon_sym_task] = ACTIONS(5336),
    [anon_sym_assert] = ACTIONS(5336),
    [anon_sym_property] = ACTIONS(5336),
    [anon_sym_assume] = ACTIONS(5336),
    [anon_sym_cover] = ACTIONS(5336),
    [anon_sym_sequence] = ACTIONS(5336),
    [anon_sym_restrict] = ACTIONS(5336),
    [anon_sym_not] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5336),
    [anon_sym_and] = ACTIONS(5336),
    [anon_sym_case] = ACTIONS(5336),
    [anon_sym_always] = ACTIONS(5336),
    [anon_sym_covergroup] = ACTIONS(5336),
    [anon_sym_end] = ACTIONS(5336),
    [anon_sym_let] = ACTIONS(5336),
    [anon_sym_pulldown] = ACTIONS(5336),
    [anon_sym_pullup] = ACTIONS(5336),
    [anon_sym_cmos] = ACTIONS(5336),
    [anon_sym_rcmos] = ACTIONS(5336),
    [anon_sym_bufif0] = ACTIONS(5336),
    [anon_sym_bufif1] = ACTIONS(5336),
    [anon_sym_notif0] = ACTIONS(5336),
    [anon_sym_notif1] = ACTIONS(5336),
    [anon_sym_nmos] = ACTIONS(5336),
    [anon_sym_pmos] = ACTIONS(5336),
    [anon_sym_rnmos] = ACTIONS(5336),
    [anon_sym_rpmos] = ACTIONS(5336),
    [anon_sym_nand] = ACTIONS(5336),
    [anon_sym_nor] = ACTIONS(5336),
    [anon_sym_xor] = ACTIONS(5336),
    [anon_sym_xnor] = ACTIONS(5336),
    [anon_sym_buf] = ACTIONS(5336),
    [anon_sym_tranif0] = ACTIONS(5336),
    [anon_sym_tranif1] = ACTIONS(5336),
    [anon_sym_rtranif1] = ACTIONS(5336),
    [anon_sym_rtranif0] = ACTIONS(5336),
    [anon_sym_tran] = ACTIONS(5336),
    [anon_sym_rtran] = ACTIONS(5336),
    [anon_sym_generate] = ACTIONS(5336),
    [anon_sym_for] = ACTIONS(5336),
    [anon_sym_initial] = ACTIONS(5336),
    [anon_sym_assign] = ACTIONS(5336),
    [anon_sym_alias] = ACTIONS(5336),
    [anon_sym_always_comb] = ACTIONS(5336),
    [anon_sym_always_latch] = ACTIONS(5336),
    [anon_sym_always_ff] = ACTIONS(5336),
    [anon_sym_final] = ACTIONS(5336),
    [anon_sym_global] = ACTIONS(5336),
    [anon_sym_LPAREN_STAR] = ACTIONS(5334),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5334),
    [anon_sym_DOLLARunit] = ACTIONS(5334),
  },
  [5108] = {
    [sym_simple_identifier] = ACTIONS(6783),
    [anon_sym_wire] = ACTIONS(6783),
    [anon_sym_tri] = ACTIONS(6783),
    [anon_sym_tri0] = ACTIONS(6783),
    [anon_sym_tri1] = ACTIONS(6783),
    [anon_sym_wand] = ACTIONS(6783),
    [anon_sym_triand] = ACTIONS(6783),
    [anon_sym_wor] = ACTIONS(6783),
    [anon_sym_trior] = ACTIONS(6783),
    [anon_sym_trireg] = ACTIONS(6783),
    [anon_sym_uwire] = ACTIONS(6783),
    [anon_sym_SEMI] = ACTIONS(6786),
    [anon_sym_extern] = ACTIONS(6783),
    [anon_sym_interface] = ACTIONS(6783),
    [anon_sym_checker] = ACTIONS(6783),
    [anon_sym_virtual] = ACTIONS(6783),
    [anon_sym_class] = ACTIONS(6783),
    [anon_sym_type] = ACTIONS(6783),
    [anon_sym_DOLLARfatal] = ACTIONS(6786),
    [anon_sym_DOLLARerror] = ACTIONS(6786),
    [anon_sym_DOLLARwarning] = ACTIONS(6786),
    [anon_sym_DOLLARinfo] = ACTIONS(6786),
    [anon_sym_default] = ACTIONS(6783),
    [anon_sym_clocking] = ACTIONS(6783),
    [anon_sym_defparam] = ACTIONS(6783),
    [anon_sym_bind] = ACTIONS(6783),
    [anon_sym_rand] = ACTIONS(6783),
    [anon_sym_const] = ACTIONS(6783),
    [anon_sym_function] = ACTIONS(6783),
    [anon_sym_static] = ACTIONS(6783),
    [anon_sym_constraint] = ACTIONS(6783),
    [anon_sym_if] = ACTIONS(6783),
    [anon_sym_else] = ACTIONS(6783),
    [anon_sym_LBRACK] = ACTIONS(6786),
    [anon_sym_localparam] = ACTIONS(6783),
    [anon_sym_parameter] = ACTIONS(6783),
    [anon_sym_var] = ACTIONS(6783),
    [anon_sym_import] = ACTIONS(6783),
    [anon_sym_export] = ACTIONS(6783),
    [anon_sym_genvar] = ACTIONS(6783),
    [anon_sym_interconnect] = ACTIONS(6783),
    [anon_sym_typedef] = ACTIONS(6783),
    [anon_sym_enum] = ACTIONS(6783),
    [anon_sym_struct] = ACTIONS(6783),
    [anon_sym_union] = ACTIONS(6783),
    [anon_sym_nettype] = ACTIONS(6783),
    [anon_sym_automatic] = ACTIONS(6783),
    [anon_sym_string] = ACTIONS(6783),
    [anon_sym_chandle] = ACTIONS(6783),
    [anon_sym_event] = ACTIONS(6783),
    [anon_sym_byte] = ACTIONS(6783),
    [anon_sym_shortint] = ACTIONS(6783),
    [anon_sym_int] = ACTIONS(6783),
    [anon_sym_longint] = ACTIONS(6783),
    [anon_sym_integer] = ACTIONS(6783),
    [anon_sym_time] = ACTIONS(6783),
    [anon_sym_bit] = ACTIONS(6783),
    [anon_sym_logic] = ACTIONS(6783),
    [anon_sym_reg] = ACTIONS(6783),
    [anon_sym_shortreal] = ACTIONS(6783),
    [anon_sym_real] = ACTIONS(6783),
    [anon_sym_realtime] = ACTIONS(6783),
    [anon_sym_supply0] = ACTIONS(6783),
    [anon_sym_supply1] = ACTIONS(6783),
    [anon_sym_signed] = ACTIONS(6783),
    [anon_sym_unsigned] = ACTIONS(6783),
    [anon_sym_task] = ACTIONS(6783),
    [anon_sym_assert] = ACTIONS(6783),
    [anon_sym_property] = ACTIONS(6783),
    [anon_sym_assume] = ACTIONS(6783),
    [anon_sym_cover] = ACTIONS(6783),
    [anon_sym_sequence] = ACTIONS(6783),
    [anon_sym_restrict] = ACTIONS(6783),
    [anon_sym_not] = ACTIONS(6783),
    [anon_sym_or] = ACTIONS(6783),
    [anon_sym_and] = ACTIONS(6783),
    [anon_sym_case] = ACTIONS(6783),
    [anon_sym_always] = ACTIONS(6783),
    [anon_sym_covergroup] = ACTIONS(6783),
    [anon_sym_end] = ACTIONS(6783),
    [anon_sym_let] = ACTIONS(6783),
    [anon_sym_pulldown] = ACTIONS(6783),
    [anon_sym_pullup] = ACTIONS(6783),
    [anon_sym_cmos] = ACTIONS(6783),
    [anon_sym_rcmos] = ACTIONS(6783),
    [anon_sym_bufif0] = ACTIONS(6783),
    [anon_sym_bufif1] = ACTIONS(6783),
    [anon_sym_notif0] = ACTIONS(6783),
    [anon_sym_notif1] = ACTIONS(6783),
    [anon_sym_nmos] = ACTIONS(6783),
    [anon_sym_pmos] = ACTIONS(6783),
    [anon_sym_rnmos] = ACTIONS(6783),
    [anon_sym_rpmos] = ACTIONS(6783),
    [anon_sym_nand] = ACTIONS(6783),
    [anon_sym_nor] = ACTIONS(6783),
    [anon_sym_xor] = ACTIONS(6783),
    [anon_sym_xnor] = ACTIONS(6783),
    [anon_sym_buf] = ACTIONS(6783),
    [anon_sym_tranif0] = ACTIONS(6783),
    [anon_sym_tranif1] = ACTIONS(6783),
    [anon_sym_rtranif1] = ACTIONS(6783),
    [anon_sym_rtranif0] = ACTIONS(6783),
    [anon_sym_tran] = ACTIONS(6783),
    [anon_sym_rtran] = ACTIONS(6783),
    [anon_sym_generate] = ACTIONS(6783),
    [anon_sym_for] = ACTIONS(6783),
    [anon_sym_initial] = ACTIONS(6783),
    [anon_sym_assign] = ACTIONS(6783),
    [anon_sym_alias] = ACTIONS(6783),
    [anon_sym_always_comb] = ACTIONS(6783),
    [anon_sym_always_latch] = ACTIONS(6783),
    [anon_sym_always_ff] = ACTIONS(6783),
    [anon_sym_final] = ACTIONS(6783),
    [anon_sym_global] = ACTIONS(6783),
    [anon_sym_LPAREN_STAR] = ACTIONS(6786),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6786),
    [anon_sym_DOLLARunit] = ACTIONS(6786),
  },
  [5109] = {
    [sym_simple_identifier] = ACTIONS(5340),
    [anon_sym_wire] = ACTIONS(5340),
    [anon_sym_tri] = ACTIONS(5340),
    [anon_sym_tri0] = ACTIONS(5340),
    [anon_sym_tri1] = ACTIONS(5340),
    [anon_sym_wand] = ACTIONS(5340),
    [anon_sym_triand] = ACTIONS(5340),
    [anon_sym_wor] = ACTIONS(5340),
    [anon_sym_trior] = ACTIONS(5340),
    [anon_sym_trireg] = ACTIONS(5340),
    [anon_sym_uwire] = ACTIONS(5340),
    [anon_sym_SEMI] = ACTIONS(5338),
    [anon_sym_extern] = ACTIONS(5340),
    [anon_sym_interface] = ACTIONS(5340),
    [anon_sym_checker] = ACTIONS(5340),
    [anon_sym_virtual] = ACTIONS(5340),
    [anon_sym_class] = ACTIONS(5340),
    [anon_sym_type] = ACTIONS(5340),
    [anon_sym_DOLLARfatal] = ACTIONS(5338),
    [anon_sym_DOLLARerror] = ACTIONS(5338),
    [anon_sym_DOLLARwarning] = ACTIONS(5338),
    [anon_sym_DOLLARinfo] = ACTIONS(5338),
    [anon_sym_default] = ACTIONS(5340),
    [anon_sym_clocking] = ACTIONS(5340),
    [anon_sym_defparam] = ACTIONS(5340),
    [anon_sym_bind] = ACTIONS(5340),
    [anon_sym_rand] = ACTIONS(5340),
    [anon_sym_const] = ACTIONS(5340),
    [anon_sym_function] = ACTIONS(5340),
    [anon_sym_static] = ACTIONS(5340),
    [anon_sym_constraint] = ACTIONS(5340),
    [anon_sym_if] = ACTIONS(5340),
    [anon_sym_else] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5338),
    [anon_sym_localparam] = ACTIONS(5340),
    [anon_sym_parameter] = ACTIONS(5340),
    [anon_sym_var] = ACTIONS(5340),
    [anon_sym_import] = ACTIONS(5340),
    [anon_sym_export] = ACTIONS(5340),
    [anon_sym_genvar] = ACTIONS(5340),
    [anon_sym_interconnect] = ACTIONS(5340),
    [anon_sym_typedef] = ACTIONS(5340),
    [anon_sym_enum] = ACTIONS(5340),
    [anon_sym_struct] = ACTIONS(5340),
    [anon_sym_union] = ACTIONS(5340),
    [anon_sym_nettype] = ACTIONS(5340),
    [anon_sym_automatic] = ACTIONS(5340),
    [anon_sym_string] = ACTIONS(5340),
    [anon_sym_chandle] = ACTIONS(5340),
    [anon_sym_event] = ACTIONS(5340),
    [anon_sym_byte] = ACTIONS(5340),
    [anon_sym_shortint] = ACTIONS(5340),
    [anon_sym_int] = ACTIONS(5340),
    [anon_sym_longint] = ACTIONS(5340),
    [anon_sym_integer] = ACTIONS(5340),
    [anon_sym_time] = ACTIONS(5340),
    [anon_sym_bit] = ACTIONS(5340),
    [anon_sym_logic] = ACTIONS(5340),
    [anon_sym_reg] = ACTIONS(5340),
    [anon_sym_shortreal] = ACTIONS(5340),
    [anon_sym_real] = ACTIONS(5340),
    [anon_sym_realtime] = ACTIONS(5340),
    [anon_sym_supply0] = ACTIONS(5340),
    [anon_sym_supply1] = ACTIONS(5340),
    [anon_sym_signed] = ACTIONS(5340),
    [anon_sym_unsigned] = ACTIONS(5340),
    [anon_sym_task] = ACTIONS(5340),
    [anon_sym_assert] = ACTIONS(5340),
    [anon_sym_property] = ACTIONS(5340),
    [anon_sym_assume] = ACTIONS(5340),
    [anon_sym_cover] = ACTIONS(5340),
    [anon_sym_sequence] = ACTIONS(5340),
    [anon_sym_restrict] = ACTIONS(5340),
    [anon_sym_not] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_case] = ACTIONS(5340),
    [anon_sym_always] = ACTIONS(5340),
    [anon_sym_covergroup] = ACTIONS(5340),
    [anon_sym_end] = ACTIONS(5340),
    [anon_sym_let] = ACTIONS(5340),
    [anon_sym_pulldown] = ACTIONS(5340),
    [anon_sym_pullup] = ACTIONS(5340),
    [anon_sym_cmos] = ACTIONS(5340),
    [anon_sym_rcmos] = ACTIONS(5340),
    [anon_sym_bufif0] = ACTIONS(5340),
    [anon_sym_bufif1] = ACTIONS(5340),
    [anon_sym_notif0] = ACTIONS(5340),
    [anon_sym_notif1] = ACTIONS(5340),
    [anon_sym_nmos] = ACTIONS(5340),
    [anon_sym_pmos] = ACTIONS(5340),
    [anon_sym_rnmos] = ACTIONS(5340),
    [anon_sym_rpmos] = ACTIONS(5340),
    [anon_sym_nand] = ACTIONS(5340),
    [anon_sym_nor] = ACTIONS(5340),
    [anon_sym_xor] = ACTIONS(5340),
    [anon_sym_xnor] = ACTIONS(5340),
    [anon_sym_buf] = ACTIONS(5340),
    [anon_sym_tranif0] = ACTIONS(5340),
    [anon_sym_tranif1] = ACTIONS(5340),
    [anon_sym_rtranif1] = ACTIONS(5340),
    [anon_sym_rtranif0] = ACTIONS(5340),
    [anon_sym_tran] = ACTIONS(5340),
    [anon_sym_rtran] = ACTIONS(5340),
    [anon_sym_generate] = ACTIONS(5340),
    [anon_sym_for] = ACTIONS(5340),
    [anon_sym_initial] = ACTIONS(5340),
    [anon_sym_assign] = ACTIONS(5340),
    [anon_sym_alias] = ACTIONS(5340),
    [anon_sym_always_comb] = ACTIONS(5340),
    [anon_sym_always_latch] = ACTIONS(5340),
    [anon_sym_always_ff] = ACTIONS(5340),
    [anon_sym_final] = ACTIONS(5340),
    [anon_sym_global] = ACTIONS(5340),
    [anon_sym_LPAREN_STAR] = ACTIONS(5338),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5338),
    [anon_sym_DOLLARunit] = ACTIONS(5338),
  },
  [5110] = {
    [sym_simple_identifier] = ACTIONS(5946),
    [anon_sym_wire] = ACTIONS(5946),
    [anon_sym_tri] = ACTIONS(5946),
    [anon_sym_tri0] = ACTIONS(5946),
    [anon_sym_tri1] = ACTIONS(5946),
    [anon_sym_wand] = ACTIONS(5946),
    [anon_sym_triand] = ACTIONS(5946),
    [anon_sym_wor] = ACTIONS(5946),
    [anon_sym_trior] = ACTIONS(5946),
    [anon_sym_trireg] = ACTIONS(5946),
    [anon_sym_uwire] = ACTIONS(5946),
    [anon_sym_SEMI] = ACTIONS(5948),
    [anon_sym_extern] = ACTIONS(5946),
    [anon_sym_interface] = ACTIONS(5946),
    [anon_sym_checker] = ACTIONS(5946),
    [anon_sym_virtual] = ACTIONS(5946),
    [anon_sym_class] = ACTIONS(5946),
    [anon_sym_type] = ACTIONS(5946),
    [anon_sym_DOLLARfatal] = ACTIONS(5948),
    [anon_sym_DOLLARerror] = ACTIONS(5948),
    [anon_sym_DOLLARwarning] = ACTIONS(5948),
    [anon_sym_DOLLARinfo] = ACTIONS(5948),
    [anon_sym_default] = ACTIONS(5946),
    [anon_sym_clocking] = ACTIONS(5946),
    [anon_sym_defparam] = ACTIONS(5946),
    [anon_sym_bind] = ACTIONS(5946),
    [anon_sym_rand] = ACTIONS(5946),
    [anon_sym_const] = ACTIONS(5946),
    [anon_sym_function] = ACTIONS(5946),
    [anon_sym_static] = ACTIONS(5946),
    [anon_sym_constraint] = ACTIONS(5946),
    [anon_sym_if] = ACTIONS(5946),
    [anon_sym_else] = ACTIONS(5946),
    [anon_sym_LBRACK] = ACTIONS(5948),
    [anon_sym_localparam] = ACTIONS(5946),
    [anon_sym_parameter] = ACTIONS(5946),
    [anon_sym_var] = ACTIONS(5946),
    [anon_sym_import] = ACTIONS(5946),
    [anon_sym_export] = ACTIONS(5946),
    [anon_sym_genvar] = ACTIONS(5946),
    [anon_sym_interconnect] = ACTIONS(5946),
    [anon_sym_typedef] = ACTIONS(5946),
    [anon_sym_enum] = ACTIONS(5946),
    [anon_sym_struct] = ACTIONS(5946),
    [anon_sym_union] = ACTIONS(5946),
    [anon_sym_nettype] = ACTIONS(5946),
    [anon_sym_automatic] = ACTIONS(5946),
    [anon_sym_string] = ACTIONS(5946),
    [anon_sym_chandle] = ACTIONS(5946),
    [anon_sym_event] = ACTIONS(5946),
    [anon_sym_byte] = ACTIONS(5946),
    [anon_sym_shortint] = ACTIONS(5946),
    [anon_sym_int] = ACTIONS(5946),
    [anon_sym_longint] = ACTIONS(5946),
    [anon_sym_integer] = ACTIONS(5946),
    [anon_sym_time] = ACTIONS(5946),
    [anon_sym_bit] = ACTIONS(5946),
    [anon_sym_logic] = ACTIONS(5946),
    [anon_sym_reg] = ACTIONS(5946),
    [anon_sym_shortreal] = ACTIONS(5946),
    [anon_sym_real] = ACTIONS(5946),
    [anon_sym_realtime] = ACTIONS(5946),
    [anon_sym_supply0] = ACTIONS(5946),
    [anon_sym_supply1] = ACTIONS(5946),
    [anon_sym_signed] = ACTIONS(5946),
    [anon_sym_unsigned] = ACTIONS(5946),
    [anon_sym_task] = ACTIONS(5946),
    [anon_sym_assert] = ACTIONS(5946),
    [anon_sym_property] = ACTIONS(5946),
    [anon_sym_assume] = ACTIONS(5946),
    [anon_sym_cover] = ACTIONS(5946),
    [anon_sym_sequence] = ACTIONS(5946),
    [anon_sym_restrict] = ACTIONS(5946),
    [anon_sym_not] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_case] = ACTIONS(5946),
    [anon_sym_always] = ACTIONS(5946),
    [anon_sym_covergroup] = ACTIONS(5946),
    [anon_sym_let] = ACTIONS(5946),
    [anon_sym_pulldown] = ACTIONS(5946),
    [anon_sym_pullup] = ACTIONS(5946),
    [anon_sym_cmos] = ACTIONS(5946),
    [anon_sym_rcmos] = ACTIONS(5946),
    [anon_sym_bufif0] = ACTIONS(5946),
    [anon_sym_bufif1] = ACTIONS(5946),
    [anon_sym_notif0] = ACTIONS(5946),
    [anon_sym_notif1] = ACTIONS(5946),
    [anon_sym_nmos] = ACTIONS(5946),
    [anon_sym_pmos] = ACTIONS(5946),
    [anon_sym_rnmos] = ACTIONS(5946),
    [anon_sym_rpmos] = ACTIONS(5946),
    [anon_sym_nand] = ACTIONS(5946),
    [anon_sym_nor] = ACTIONS(5946),
    [anon_sym_xor] = ACTIONS(5946),
    [anon_sym_xnor] = ACTIONS(5946),
    [anon_sym_buf] = ACTIONS(5946),
    [anon_sym_tranif0] = ACTIONS(5946),
    [anon_sym_tranif1] = ACTIONS(5946),
    [anon_sym_rtranif1] = ACTIONS(5946),
    [anon_sym_rtranif0] = ACTIONS(5946),
    [anon_sym_tran] = ACTIONS(5946),
    [anon_sym_rtran] = ACTIONS(5946),
    [anon_sym_generate] = ACTIONS(5946),
    [anon_sym_endgenerate] = ACTIONS(5946),
    [anon_sym_for] = ACTIONS(5946),
    [anon_sym_initial] = ACTIONS(5946),
    [anon_sym_assign] = ACTIONS(5946),
    [anon_sym_alias] = ACTIONS(5946),
    [anon_sym_always_comb] = ACTIONS(5946),
    [anon_sym_always_latch] = ACTIONS(5946),
    [anon_sym_always_ff] = ACTIONS(5946),
    [anon_sym_final] = ACTIONS(5946),
    [anon_sym_global] = ACTIONS(5946),
    [anon_sym_LPAREN_STAR] = ACTIONS(5948),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5948),
    [anon_sym_DOLLARunit] = ACTIONS(5948),
  },
  [5111] = {
    [sym_simple_identifier] = ACTIONS(4812),
    [anon_sym_wire] = ACTIONS(4812),
    [anon_sym_tri] = ACTIONS(4812),
    [anon_sym_tri0] = ACTIONS(4812),
    [anon_sym_tri1] = ACTIONS(4812),
    [anon_sym_wand] = ACTIONS(4812),
    [anon_sym_triand] = ACTIONS(4812),
    [anon_sym_wor] = ACTIONS(4812),
    [anon_sym_trior] = ACTIONS(4812),
    [anon_sym_trireg] = ACTIONS(4812),
    [anon_sym_uwire] = ACTIONS(4812),
    [anon_sym_SEMI] = ACTIONS(4810),
    [anon_sym_extern] = ACTIONS(4812),
    [anon_sym_interface] = ACTIONS(4812),
    [anon_sym_checker] = ACTIONS(4812),
    [anon_sym_virtual] = ACTIONS(4812),
    [anon_sym_class] = ACTIONS(4812),
    [anon_sym_type] = ACTIONS(4812),
    [anon_sym_DOLLARfatal] = ACTIONS(4810),
    [anon_sym_DOLLARerror] = ACTIONS(4810),
    [anon_sym_DOLLARwarning] = ACTIONS(4810),
    [anon_sym_DOLLARinfo] = ACTIONS(4810),
    [anon_sym_default] = ACTIONS(4812),
    [anon_sym_clocking] = ACTIONS(4812),
    [anon_sym_defparam] = ACTIONS(4812),
    [anon_sym_bind] = ACTIONS(4812),
    [anon_sym_rand] = ACTIONS(4812),
    [anon_sym_const] = ACTIONS(4812),
    [anon_sym_function] = ACTIONS(4812),
    [anon_sym_static] = ACTIONS(4812),
    [anon_sym_constraint] = ACTIONS(4812),
    [anon_sym_if] = ACTIONS(4812),
    [anon_sym_else] = ACTIONS(4812),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [anon_sym_localparam] = ACTIONS(4812),
    [anon_sym_parameter] = ACTIONS(4812),
    [anon_sym_var] = ACTIONS(4812),
    [anon_sym_import] = ACTIONS(4812),
    [anon_sym_export] = ACTIONS(4812),
    [anon_sym_genvar] = ACTIONS(4812),
    [anon_sym_interconnect] = ACTIONS(4812),
    [anon_sym_typedef] = ACTIONS(4812),
    [anon_sym_enum] = ACTIONS(4812),
    [anon_sym_struct] = ACTIONS(4812),
    [anon_sym_union] = ACTIONS(4812),
    [anon_sym_nettype] = ACTIONS(4812),
    [anon_sym_automatic] = ACTIONS(4812),
    [anon_sym_string] = ACTIONS(4812),
    [anon_sym_chandle] = ACTIONS(4812),
    [anon_sym_event] = ACTIONS(4812),
    [anon_sym_byte] = ACTIONS(4812),
    [anon_sym_shortint] = ACTIONS(4812),
    [anon_sym_int] = ACTIONS(4812),
    [anon_sym_longint] = ACTIONS(4812),
    [anon_sym_integer] = ACTIONS(4812),
    [anon_sym_time] = ACTIONS(4812),
    [anon_sym_bit] = ACTIONS(4812),
    [anon_sym_logic] = ACTIONS(4812),
    [anon_sym_reg] = ACTIONS(4812),
    [anon_sym_shortreal] = ACTIONS(4812),
    [anon_sym_real] = ACTIONS(4812),
    [anon_sym_realtime] = ACTIONS(4812),
    [anon_sym_supply0] = ACTIONS(4812),
    [anon_sym_supply1] = ACTIONS(4812),
    [anon_sym_signed] = ACTIONS(4812),
    [anon_sym_unsigned] = ACTIONS(4812),
    [anon_sym_task] = ACTIONS(4812),
    [anon_sym_assert] = ACTIONS(4812),
    [anon_sym_property] = ACTIONS(4812),
    [anon_sym_assume] = ACTIONS(4812),
    [anon_sym_cover] = ACTIONS(4812),
    [anon_sym_sequence] = ACTIONS(4812),
    [anon_sym_restrict] = ACTIONS(4812),
    [anon_sym_not] = ACTIONS(4812),
    [anon_sym_or] = ACTIONS(4812),
    [anon_sym_and] = ACTIONS(4812),
    [anon_sym_case] = ACTIONS(4812),
    [anon_sym_always] = ACTIONS(4812),
    [anon_sym_covergroup] = ACTIONS(4812),
    [anon_sym_let] = ACTIONS(4812),
    [anon_sym_pulldown] = ACTIONS(4812),
    [anon_sym_pullup] = ACTIONS(4812),
    [anon_sym_cmos] = ACTIONS(4812),
    [anon_sym_rcmos] = ACTIONS(4812),
    [anon_sym_bufif0] = ACTIONS(4812),
    [anon_sym_bufif1] = ACTIONS(4812),
    [anon_sym_notif0] = ACTIONS(4812),
    [anon_sym_notif1] = ACTIONS(4812),
    [anon_sym_nmos] = ACTIONS(4812),
    [anon_sym_pmos] = ACTIONS(4812),
    [anon_sym_rnmos] = ACTIONS(4812),
    [anon_sym_rpmos] = ACTIONS(4812),
    [anon_sym_nand] = ACTIONS(4812),
    [anon_sym_nor] = ACTIONS(4812),
    [anon_sym_xor] = ACTIONS(4812),
    [anon_sym_xnor] = ACTIONS(4812),
    [anon_sym_buf] = ACTIONS(4812),
    [anon_sym_tranif0] = ACTIONS(4812),
    [anon_sym_tranif1] = ACTIONS(4812),
    [anon_sym_rtranif1] = ACTIONS(4812),
    [anon_sym_rtranif0] = ACTIONS(4812),
    [anon_sym_tran] = ACTIONS(4812),
    [anon_sym_rtran] = ACTIONS(4812),
    [anon_sym_generate] = ACTIONS(4812),
    [anon_sym_endgenerate] = ACTIONS(4812),
    [anon_sym_for] = ACTIONS(4812),
    [anon_sym_initial] = ACTIONS(4812),
    [anon_sym_assign] = ACTIONS(4812),
    [anon_sym_alias] = ACTIONS(4812),
    [anon_sym_always_comb] = ACTIONS(4812),
    [anon_sym_always_latch] = ACTIONS(4812),
    [anon_sym_always_ff] = ACTIONS(4812),
    [anon_sym_final] = ACTIONS(4812),
    [anon_sym_global] = ACTIONS(4812),
    [anon_sym_LPAREN_STAR] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4810),
    [anon_sym_DOLLARunit] = ACTIONS(4810),
  },
  [5112] = {
    [sym_simple_identifier] = ACTIONS(6687),
    [anon_sym_wire] = ACTIONS(6687),
    [anon_sym_tri] = ACTIONS(6687),
    [anon_sym_tri0] = ACTIONS(6687),
    [anon_sym_tri1] = ACTIONS(6687),
    [anon_sym_wand] = ACTIONS(6687),
    [anon_sym_triand] = ACTIONS(6687),
    [anon_sym_wor] = ACTIONS(6687),
    [anon_sym_trior] = ACTIONS(6687),
    [anon_sym_trireg] = ACTIONS(6687),
    [anon_sym_uwire] = ACTIONS(6687),
    [anon_sym_SEMI] = ACTIONS(6689),
    [anon_sym_extern] = ACTIONS(6687),
    [anon_sym_interface] = ACTIONS(6687),
    [anon_sym_checker] = ACTIONS(6687),
    [anon_sym_virtual] = ACTIONS(6687),
    [anon_sym_class] = ACTIONS(6687),
    [anon_sym_type] = ACTIONS(6687),
    [anon_sym_DOLLARfatal] = ACTIONS(6689),
    [anon_sym_DOLLARerror] = ACTIONS(6689),
    [anon_sym_DOLLARwarning] = ACTIONS(6689),
    [anon_sym_DOLLARinfo] = ACTIONS(6689),
    [anon_sym_default] = ACTIONS(6687),
    [anon_sym_clocking] = ACTIONS(6687),
    [anon_sym_defparam] = ACTIONS(6687),
    [anon_sym_bind] = ACTIONS(6687),
    [anon_sym_rand] = ACTIONS(6687),
    [anon_sym_const] = ACTIONS(6687),
    [anon_sym_function] = ACTIONS(6687),
    [anon_sym_static] = ACTIONS(6687),
    [anon_sym_constraint] = ACTIONS(6687),
    [anon_sym_if] = ACTIONS(6687),
    [anon_sym_else] = ACTIONS(6687),
    [anon_sym_LBRACK] = ACTIONS(6689),
    [anon_sym_localparam] = ACTIONS(6687),
    [anon_sym_parameter] = ACTIONS(6687),
    [anon_sym_var] = ACTIONS(6687),
    [anon_sym_import] = ACTIONS(6687),
    [anon_sym_export] = ACTIONS(6687),
    [anon_sym_genvar] = ACTIONS(6687),
    [anon_sym_interconnect] = ACTIONS(6687),
    [anon_sym_typedef] = ACTIONS(6687),
    [anon_sym_enum] = ACTIONS(6687),
    [anon_sym_struct] = ACTIONS(6687),
    [anon_sym_union] = ACTIONS(6687),
    [anon_sym_nettype] = ACTIONS(6687),
    [anon_sym_automatic] = ACTIONS(6687),
    [anon_sym_string] = ACTIONS(6687),
    [anon_sym_chandle] = ACTIONS(6687),
    [anon_sym_event] = ACTIONS(6687),
    [anon_sym_byte] = ACTIONS(6687),
    [anon_sym_shortint] = ACTIONS(6687),
    [anon_sym_int] = ACTIONS(6687),
    [anon_sym_longint] = ACTIONS(6687),
    [anon_sym_integer] = ACTIONS(6687),
    [anon_sym_time] = ACTIONS(6687),
    [anon_sym_bit] = ACTIONS(6687),
    [anon_sym_logic] = ACTIONS(6687),
    [anon_sym_reg] = ACTIONS(6687),
    [anon_sym_shortreal] = ACTIONS(6687),
    [anon_sym_real] = ACTIONS(6687),
    [anon_sym_realtime] = ACTIONS(6687),
    [anon_sym_supply0] = ACTIONS(6687),
    [anon_sym_supply1] = ACTIONS(6687),
    [anon_sym_signed] = ACTIONS(6687),
    [anon_sym_unsigned] = ACTIONS(6687),
    [anon_sym_task] = ACTIONS(6687),
    [anon_sym_assert] = ACTIONS(6687),
    [anon_sym_property] = ACTIONS(6687),
    [anon_sym_assume] = ACTIONS(6687),
    [anon_sym_cover] = ACTIONS(6687),
    [anon_sym_sequence] = ACTIONS(6687),
    [anon_sym_restrict] = ACTIONS(6687),
    [anon_sym_not] = ACTIONS(6687),
    [anon_sym_or] = ACTIONS(6687),
    [anon_sym_and] = ACTIONS(6687),
    [anon_sym_case] = ACTIONS(6687),
    [anon_sym_always] = ACTIONS(6687),
    [anon_sym_covergroup] = ACTIONS(6687),
    [anon_sym_end] = ACTIONS(6687),
    [anon_sym_let] = ACTIONS(6687),
    [anon_sym_pulldown] = ACTIONS(6687),
    [anon_sym_pullup] = ACTIONS(6687),
    [anon_sym_cmos] = ACTIONS(6687),
    [anon_sym_rcmos] = ACTIONS(6687),
    [anon_sym_bufif0] = ACTIONS(6687),
    [anon_sym_bufif1] = ACTIONS(6687),
    [anon_sym_notif0] = ACTIONS(6687),
    [anon_sym_notif1] = ACTIONS(6687),
    [anon_sym_nmos] = ACTIONS(6687),
    [anon_sym_pmos] = ACTIONS(6687),
    [anon_sym_rnmos] = ACTIONS(6687),
    [anon_sym_rpmos] = ACTIONS(6687),
    [anon_sym_nand] = ACTIONS(6687),
    [anon_sym_nor] = ACTIONS(6687),
    [anon_sym_xor] = ACTIONS(6687),
    [anon_sym_xnor] = ACTIONS(6687),
    [anon_sym_buf] = ACTIONS(6687),
    [anon_sym_tranif0] = ACTIONS(6687),
    [anon_sym_tranif1] = ACTIONS(6687),
    [anon_sym_rtranif1] = ACTIONS(6687),
    [anon_sym_rtranif0] = ACTIONS(6687),
    [anon_sym_tran] = ACTIONS(6687),
    [anon_sym_rtran] = ACTIONS(6687),
    [anon_sym_generate] = ACTIONS(6687),
    [anon_sym_for] = ACTIONS(6687),
    [anon_sym_initial] = ACTIONS(6687),
    [anon_sym_assign] = ACTIONS(6687),
    [anon_sym_alias] = ACTIONS(6687),
    [anon_sym_always_comb] = ACTIONS(6687),
    [anon_sym_always_latch] = ACTIONS(6687),
    [anon_sym_always_ff] = ACTIONS(6687),
    [anon_sym_final] = ACTIONS(6687),
    [anon_sym_global] = ACTIONS(6687),
    [anon_sym_LPAREN_STAR] = ACTIONS(6689),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6689),
    [anon_sym_DOLLARunit] = ACTIONS(6689),
  },
  [5113] = {
    [sym_simple_identifier] = ACTIONS(6097),
    [anon_sym_wire] = ACTIONS(6097),
    [anon_sym_tri] = ACTIONS(6097),
    [anon_sym_tri0] = ACTIONS(6097),
    [anon_sym_tri1] = ACTIONS(6097),
    [anon_sym_wand] = ACTIONS(6097),
    [anon_sym_triand] = ACTIONS(6097),
    [anon_sym_wor] = ACTIONS(6097),
    [anon_sym_trior] = ACTIONS(6097),
    [anon_sym_trireg] = ACTIONS(6097),
    [anon_sym_uwire] = ACTIONS(6097),
    [anon_sym_SEMI] = ACTIONS(6099),
    [anon_sym_extern] = ACTIONS(6097),
    [anon_sym_interface] = ACTIONS(6097),
    [anon_sym_checker] = ACTIONS(6097),
    [anon_sym_virtual] = ACTIONS(6097),
    [anon_sym_class] = ACTIONS(6097),
    [anon_sym_type] = ACTIONS(6097),
    [anon_sym_DOLLARfatal] = ACTIONS(6099),
    [anon_sym_DOLLARerror] = ACTIONS(6099),
    [anon_sym_DOLLARwarning] = ACTIONS(6099),
    [anon_sym_DOLLARinfo] = ACTIONS(6099),
    [anon_sym_default] = ACTIONS(6097),
    [anon_sym_clocking] = ACTIONS(6097),
    [anon_sym_defparam] = ACTIONS(6097),
    [anon_sym_bind] = ACTIONS(6097),
    [anon_sym_rand] = ACTIONS(6097),
    [anon_sym_const] = ACTIONS(6097),
    [anon_sym_function] = ACTIONS(6097),
    [anon_sym_static] = ACTIONS(6097),
    [anon_sym_constraint] = ACTIONS(6097),
    [anon_sym_if] = ACTIONS(6097),
    [anon_sym_else] = ACTIONS(6097),
    [anon_sym_LBRACK] = ACTIONS(6099),
    [anon_sym_localparam] = ACTIONS(6097),
    [anon_sym_parameter] = ACTIONS(6097),
    [anon_sym_var] = ACTIONS(6097),
    [anon_sym_import] = ACTIONS(6097),
    [anon_sym_export] = ACTIONS(6097),
    [anon_sym_genvar] = ACTIONS(6097),
    [anon_sym_interconnect] = ACTIONS(6097),
    [anon_sym_typedef] = ACTIONS(6097),
    [anon_sym_enum] = ACTIONS(6097),
    [anon_sym_struct] = ACTIONS(6097),
    [anon_sym_union] = ACTIONS(6097),
    [anon_sym_nettype] = ACTIONS(6097),
    [anon_sym_automatic] = ACTIONS(6097),
    [anon_sym_string] = ACTIONS(6097),
    [anon_sym_chandle] = ACTIONS(6097),
    [anon_sym_event] = ACTIONS(6097),
    [anon_sym_byte] = ACTIONS(6097),
    [anon_sym_shortint] = ACTIONS(6097),
    [anon_sym_int] = ACTIONS(6097),
    [anon_sym_longint] = ACTIONS(6097),
    [anon_sym_integer] = ACTIONS(6097),
    [anon_sym_time] = ACTIONS(6097),
    [anon_sym_bit] = ACTIONS(6097),
    [anon_sym_logic] = ACTIONS(6097),
    [anon_sym_reg] = ACTIONS(6097),
    [anon_sym_shortreal] = ACTIONS(6097),
    [anon_sym_real] = ACTIONS(6097),
    [anon_sym_realtime] = ACTIONS(6097),
    [anon_sym_supply0] = ACTIONS(6097),
    [anon_sym_supply1] = ACTIONS(6097),
    [anon_sym_signed] = ACTIONS(6097),
    [anon_sym_unsigned] = ACTIONS(6097),
    [anon_sym_task] = ACTIONS(6097),
    [anon_sym_assert] = ACTIONS(6097),
    [anon_sym_property] = ACTIONS(6097),
    [anon_sym_assume] = ACTIONS(6097),
    [anon_sym_cover] = ACTIONS(6097),
    [anon_sym_sequence] = ACTIONS(6097),
    [anon_sym_restrict] = ACTIONS(6097),
    [anon_sym_not] = ACTIONS(6097),
    [anon_sym_or] = ACTIONS(6097),
    [anon_sym_and] = ACTIONS(6097),
    [anon_sym_case] = ACTIONS(6097),
    [anon_sym_always] = ACTIONS(6097),
    [anon_sym_covergroup] = ACTIONS(6097),
    [anon_sym_let] = ACTIONS(6097),
    [anon_sym_pulldown] = ACTIONS(6097),
    [anon_sym_pullup] = ACTIONS(6097),
    [anon_sym_cmos] = ACTIONS(6097),
    [anon_sym_rcmos] = ACTIONS(6097),
    [anon_sym_bufif0] = ACTIONS(6097),
    [anon_sym_bufif1] = ACTIONS(6097),
    [anon_sym_notif0] = ACTIONS(6097),
    [anon_sym_notif1] = ACTIONS(6097),
    [anon_sym_nmos] = ACTIONS(6097),
    [anon_sym_pmos] = ACTIONS(6097),
    [anon_sym_rnmos] = ACTIONS(6097),
    [anon_sym_rpmos] = ACTIONS(6097),
    [anon_sym_nand] = ACTIONS(6097),
    [anon_sym_nor] = ACTIONS(6097),
    [anon_sym_xor] = ACTIONS(6097),
    [anon_sym_xnor] = ACTIONS(6097),
    [anon_sym_buf] = ACTIONS(6097),
    [anon_sym_tranif0] = ACTIONS(6097),
    [anon_sym_tranif1] = ACTIONS(6097),
    [anon_sym_rtranif1] = ACTIONS(6097),
    [anon_sym_rtranif0] = ACTIONS(6097),
    [anon_sym_tran] = ACTIONS(6097),
    [anon_sym_rtran] = ACTIONS(6097),
    [anon_sym_generate] = ACTIONS(6097),
    [anon_sym_endgenerate] = ACTIONS(6097),
    [anon_sym_for] = ACTIONS(6097),
    [anon_sym_initial] = ACTIONS(6097),
    [anon_sym_assign] = ACTIONS(6097),
    [anon_sym_alias] = ACTIONS(6097),
    [anon_sym_always_comb] = ACTIONS(6097),
    [anon_sym_always_latch] = ACTIONS(6097),
    [anon_sym_always_ff] = ACTIONS(6097),
    [anon_sym_final] = ACTIONS(6097),
    [anon_sym_global] = ACTIONS(6097),
    [anon_sym_LPAREN_STAR] = ACTIONS(6099),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6099),
    [anon_sym_DOLLARunit] = ACTIONS(6099),
  },
  [5114] = {
    [sym_simple_identifier] = ACTIONS(6695),
    [anon_sym_wire] = ACTIONS(6695),
    [anon_sym_tri] = ACTIONS(6695),
    [anon_sym_tri0] = ACTIONS(6695),
    [anon_sym_tri1] = ACTIONS(6695),
    [anon_sym_wand] = ACTIONS(6695),
    [anon_sym_triand] = ACTIONS(6695),
    [anon_sym_wor] = ACTIONS(6695),
    [anon_sym_trior] = ACTIONS(6695),
    [anon_sym_trireg] = ACTIONS(6695),
    [anon_sym_uwire] = ACTIONS(6695),
    [anon_sym_SEMI] = ACTIONS(6697),
    [anon_sym_extern] = ACTIONS(6695),
    [anon_sym_interface] = ACTIONS(6695),
    [anon_sym_checker] = ACTIONS(6695),
    [anon_sym_virtual] = ACTIONS(6695),
    [anon_sym_class] = ACTIONS(6695),
    [anon_sym_type] = ACTIONS(6695),
    [anon_sym_DOLLARfatal] = ACTIONS(6697),
    [anon_sym_DOLLARerror] = ACTIONS(6697),
    [anon_sym_DOLLARwarning] = ACTIONS(6697),
    [anon_sym_DOLLARinfo] = ACTIONS(6697),
    [anon_sym_default] = ACTIONS(6695),
    [anon_sym_clocking] = ACTIONS(6695),
    [anon_sym_defparam] = ACTIONS(6695),
    [anon_sym_bind] = ACTIONS(6695),
    [anon_sym_rand] = ACTIONS(6695),
    [anon_sym_const] = ACTIONS(6695),
    [anon_sym_function] = ACTIONS(6695),
    [anon_sym_static] = ACTIONS(6695),
    [anon_sym_constraint] = ACTIONS(6695),
    [anon_sym_if] = ACTIONS(6695),
    [anon_sym_else] = ACTIONS(6695),
    [anon_sym_LBRACK] = ACTIONS(6697),
    [anon_sym_localparam] = ACTIONS(6695),
    [anon_sym_parameter] = ACTIONS(6695),
    [anon_sym_var] = ACTIONS(6695),
    [anon_sym_import] = ACTIONS(6695),
    [anon_sym_export] = ACTIONS(6695),
    [anon_sym_genvar] = ACTIONS(6695),
    [anon_sym_interconnect] = ACTIONS(6695),
    [anon_sym_typedef] = ACTIONS(6695),
    [anon_sym_enum] = ACTIONS(6695),
    [anon_sym_struct] = ACTIONS(6695),
    [anon_sym_union] = ACTIONS(6695),
    [anon_sym_nettype] = ACTIONS(6695),
    [anon_sym_automatic] = ACTIONS(6695),
    [anon_sym_string] = ACTIONS(6695),
    [anon_sym_chandle] = ACTIONS(6695),
    [anon_sym_event] = ACTIONS(6695),
    [anon_sym_byte] = ACTIONS(6695),
    [anon_sym_shortint] = ACTIONS(6695),
    [anon_sym_int] = ACTIONS(6695),
    [anon_sym_longint] = ACTIONS(6695),
    [anon_sym_integer] = ACTIONS(6695),
    [anon_sym_time] = ACTIONS(6695),
    [anon_sym_bit] = ACTIONS(6695),
    [anon_sym_logic] = ACTIONS(6695),
    [anon_sym_reg] = ACTIONS(6695),
    [anon_sym_shortreal] = ACTIONS(6695),
    [anon_sym_real] = ACTIONS(6695),
    [anon_sym_realtime] = ACTIONS(6695),
    [anon_sym_supply0] = ACTIONS(6695),
    [anon_sym_supply1] = ACTIONS(6695),
    [anon_sym_signed] = ACTIONS(6695),
    [anon_sym_unsigned] = ACTIONS(6695),
    [anon_sym_task] = ACTIONS(6695),
    [anon_sym_assert] = ACTIONS(6695),
    [anon_sym_property] = ACTIONS(6695),
    [anon_sym_assume] = ACTIONS(6695),
    [anon_sym_cover] = ACTIONS(6695),
    [anon_sym_sequence] = ACTIONS(6695),
    [anon_sym_restrict] = ACTIONS(6695),
    [anon_sym_not] = ACTIONS(6695),
    [anon_sym_or] = ACTIONS(6695),
    [anon_sym_and] = ACTIONS(6695),
    [anon_sym_case] = ACTIONS(6695),
    [anon_sym_always] = ACTIONS(6695),
    [anon_sym_covergroup] = ACTIONS(6695),
    [anon_sym_end] = ACTIONS(6695),
    [anon_sym_let] = ACTIONS(6695),
    [anon_sym_pulldown] = ACTIONS(6695),
    [anon_sym_pullup] = ACTIONS(6695),
    [anon_sym_cmos] = ACTIONS(6695),
    [anon_sym_rcmos] = ACTIONS(6695),
    [anon_sym_bufif0] = ACTIONS(6695),
    [anon_sym_bufif1] = ACTIONS(6695),
    [anon_sym_notif0] = ACTIONS(6695),
    [anon_sym_notif1] = ACTIONS(6695),
    [anon_sym_nmos] = ACTIONS(6695),
    [anon_sym_pmos] = ACTIONS(6695),
    [anon_sym_rnmos] = ACTIONS(6695),
    [anon_sym_rpmos] = ACTIONS(6695),
    [anon_sym_nand] = ACTIONS(6695),
    [anon_sym_nor] = ACTIONS(6695),
    [anon_sym_xor] = ACTIONS(6695),
    [anon_sym_xnor] = ACTIONS(6695),
    [anon_sym_buf] = ACTIONS(6695),
    [anon_sym_tranif0] = ACTIONS(6695),
    [anon_sym_tranif1] = ACTIONS(6695),
    [anon_sym_rtranif1] = ACTIONS(6695),
    [anon_sym_rtranif0] = ACTIONS(6695),
    [anon_sym_tran] = ACTIONS(6695),
    [anon_sym_rtran] = ACTIONS(6695),
    [anon_sym_generate] = ACTIONS(6695),
    [anon_sym_for] = ACTIONS(6695),
    [anon_sym_initial] = ACTIONS(6695),
    [anon_sym_assign] = ACTIONS(6695),
    [anon_sym_alias] = ACTIONS(6695),
    [anon_sym_always_comb] = ACTIONS(6695),
    [anon_sym_always_latch] = ACTIONS(6695),
    [anon_sym_always_ff] = ACTIONS(6695),
    [anon_sym_final] = ACTIONS(6695),
    [anon_sym_global] = ACTIONS(6695),
    [anon_sym_LPAREN_STAR] = ACTIONS(6697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6697),
    [anon_sym_DOLLARunit] = ACTIONS(6697),
  },
  [5115] = {
    [sym_simple_identifier] = ACTIONS(4460),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_rand] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_endgenerate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [5116] = {
    [sym_simple_identifier] = ACTIONS(5190),
    [anon_sym_wire] = ACTIONS(5190),
    [anon_sym_tri] = ACTIONS(5190),
    [anon_sym_tri0] = ACTIONS(5190),
    [anon_sym_tri1] = ACTIONS(5190),
    [anon_sym_wand] = ACTIONS(5190),
    [anon_sym_triand] = ACTIONS(5190),
    [anon_sym_wor] = ACTIONS(5190),
    [anon_sym_trior] = ACTIONS(5190),
    [anon_sym_trireg] = ACTIONS(5190),
    [anon_sym_uwire] = ACTIONS(5190),
    [anon_sym_SEMI] = ACTIONS(5188),
    [anon_sym_extern] = ACTIONS(5190),
    [anon_sym_interface] = ACTIONS(5190),
    [anon_sym_checker] = ACTIONS(5190),
    [anon_sym_virtual] = ACTIONS(5190),
    [anon_sym_class] = ACTIONS(5190),
    [anon_sym_type] = ACTIONS(5190),
    [anon_sym_DOLLARfatal] = ACTIONS(5188),
    [anon_sym_DOLLARerror] = ACTIONS(5188),
    [anon_sym_DOLLARwarning] = ACTIONS(5188),
    [anon_sym_DOLLARinfo] = ACTIONS(5188),
    [anon_sym_default] = ACTIONS(5190),
    [anon_sym_clocking] = ACTIONS(5190),
    [anon_sym_defparam] = ACTIONS(5190),
    [anon_sym_bind] = ACTIONS(5190),
    [anon_sym_rand] = ACTIONS(5190),
    [anon_sym_const] = ACTIONS(5190),
    [anon_sym_function] = ACTIONS(5190),
    [anon_sym_static] = ACTIONS(5190),
    [anon_sym_constraint] = ACTIONS(5190),
    [anon_sym_if] = ACTIONS(5190),
    [anon_sym_else] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(5188),
    [anon_sym_localparam] = ACTIONS(5190),
    [anon_sym_parameter] = ACTIONS(5190),
    [anon_sym_var] = ACTIONS(5190),
    [anon_sym_import] = ACTIONS(5190),
    [anon_sym_export] = ACTIONS(5190),
    [anon_sym_genvar] = ACTIONS(5190),
    [anon_sym_interconnect] = ACTIONS(5190),
    [anon_sym_typedef] = ACTIONS(5190),
    [anon_sym_enum] = ACTIONS(5190),
    [anon_sym_struct] = ACTIONS(5190),
    [anon_sym_union] = ACTIONS(5190),
    [anon_sym_nettype] = ACTIONS(5190),
    [anon_sym_automatic] = ACTIONS(5190),
    [anon_sym_string] = ACTIONS(5190),
    [anon_sym_chandle] = ACTIONS(5190),
    [anon_sym_event] = ACTIONS(5190),
    [anon_sym_byte] = ACTIONS(5190),
    [anon_sym_shortint] = ACTIONS(5190),
    [anon_sym_int] = ACTIONS(5190),
    [anon_sym_longint] = ACTIONS(5190),
    [anon_sym_integer] = ACTIONS(5190),
    [anon_sym_time] = ACTIONS(5190),
    [anon_sym_bit] = ACTIONS(5190),
    [anon_sym_logic] = ACTIONS(5190),
    [anon_sym_reg] = ACTIONS(5190),
    [anon_sym_shortreal] = ACTIONS(5190),
    [anon_sym_real] = ACTIONS(5190),
    [anon_sym_realtime] = ACTIONS(5190),
    [anon_sym_supply0] = ACTIONS(5190),
    [anon_sym_supply1] = ACTIONS(5190),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_task] = ACTIONS(5190),
    [anon_sym_assert] = ACTIONS(5190),
    [anon_sym_property] = ACTIONS(5190),
    [anon_sym_assume] = ACTIONS(5190),
    [anon_sym_cover] = ACTIONS(5190),
    [anon_sym_sequence] = ACTIONS(5190),
    [anon_sym_restrict] = ACTIONS(5190),
    [anon_sym_not] = ACTIONS(5190),
    [anon_sym_or] = ACTIONS(5190),
    [anon_sym_and] = ACTIONS(5190),
    [anon_sym_case] = ACTIONS(5190),
    [anon_sym_always] = ACTIONS(5190),
    [anon_sym_covergroup] = ACTIONS(5190),
    [anon_sym_let] = ACTIONS(5190),
    [anon_sym_pulldown] = ACTIONS(5190),
    [anon_sym_pullup] = ACTIONS(5190),
    [anon_sym_cmos] = ACTIONS(5190),
    [anon_sym_rcmos] = ACTIONS(5190),
    [anon_sym_bufif0] = ACTIONS(5190),
    [anon_sym_bufif1] = ACTIONS(5190),
    [anon_sym_notif0] = ACTIONS(5190),
    [anon_sym_notif1] = ACTIONS(5190),
    [anon_sym_nmos] = ACTIONS(5190),
    [anon_sym_pmos] = ACTIONS(5190),
    [anon_sym_rnmos] = ACTIONS(5190),
    [anon_sym_rpmos] = ACTIONS(5190),
    [anon_sym_nand] = ACTIONS(5190),
    [anon_sym_nor] = ACTIONS(5190),
    [anon_sym_xor] = ACTIONS(5190),
    [anon_sym_xnor] = ACTIONS(5190),
    [anon_sym_buf] = ACTIONS(5190),
    [anon_sym_tranif0] = ACTIONS(5190),
    [anon_sym_tranif1] = ACTIONS(5190),
    [anon_sym_rtranif1] = ACTIONS(5190),
    [anon_sym_rtranif0] = ACTIONS(5190),
    [anon_sym_tran] = ACTIONS(5190),
    [anon_sym_rtran] = ACTIONS(5190),
    [anon_sym_generate] = ACTIONS(5190),
    [anon_sym_endgenerate] = ACTIONS(5190),
    [anon_sym_for] = ACTIONS(5190),
    [anon_sym_initial] = ACTIONS(5190),
    [anon_sym_assign] = ACTIONS(5190),
    [anon_sym_alias] = ACTIONS(5190),
    [anon_sym_always_comb] = ACTIONS(5190),
    [anon_sym_always_latch] = ACTIONS(5190),
    [anon_sym_always_ff] = ACTIONS(5190),
    [anon_sym_final] = ACTIONS(5190),
    [anon_sym_global] = ACTIONS(5190),
    [anon_sym_LPAREN_STAR] = ACTIONS(5188),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5188),
    [anon_sym_DOLLARunit] = ACTIONS(5188),
  },
  [5117] = {
    [sym_simple_identifier] = ACTIONS(5344),
    [anon_sym_wire] = ACTIONS(5344),
    [anon_sym_tri] = ACTIONS(5344),
    [anon_sym_tri0] = ACTIONS(5344),
    [anon_sym_tri1] = ACTIONS(5344),
    [anon_sym_wand] = ACTIONS(5344),
    [anon_sym_triand] = ACTIONS(5344),
    [anon_sym_wor] = ACTIONS(5344),
    [anon_sym_trior] = ACTIONS(5344),
    [anon_sym_trireg] = ACTIONS(5344),
    [anon_sym_uwire] = ACTIONS(5344),
    [anon_sym_SEMI] = ACTIONS(5342),
    [anon_sym_extern] = ACTIONS(5344),
    [anon_sym_interface] = ACTIONS(5344),
    [anon_sym_checker] = ACTIONS(5344),
    [anon_sym_virtual] = ACTIONS(5344),
    [anon_sym_class] = ACTIONS(5344),
    [anon_sym_type] = ACTIONS(5344),
    [anon_sym_DOLLARfatal] = ACTIONS(5342),
    [anon_sym_DOLLARerror] = ACTIONS(5342),
    [anon_sym_DOLLARwarning] = ACTIONS(5342),
    [anon_sym_DOLLARinfo] = ACTIONS(5342),
    [anon_sym_default] = ACTIONS(5344),
    [anon_sym_clocking] = ACTIONS(5344),
    [anon_sym_defparam] = ACTIONS(5344),
    [anon_sym_bind] = ACTIONS(5344),
    [anon_sym_rand] = ACTIONS(5344),
    [anon_sym_const] = ACTIONS(5344),
    [anon_sym_function] = ACTIONS(5344),
    [anon_sym_static] = ACTIONS(5344),
    [anon_sym_constraint] = ACTIONS(5344),
    [anon_sym_if] = ACTIONS(5344),
    [anon_sym_else] = ACTIONS(5344),
    [anon_sym_LBRACK] = ACTIONS(5342),
    [anon_sym_localparam] = ACTIONS(5344),
    [anon_sym_parameter] = ACTIONS(5344),
    [anon_sym_var] = ACTIONS(5344),
    [anon_sym_import] = ACTIONS(5344),
    [anon_sym_export] = ACTIONS(5344),
    [anon_sym_genvar] = ACTIONS(5344),
    [anon_sym_interconnect] = ACTIONS(5344),
    [anon_sym_typedef] = ACTIONS(5344),
    [anon_sym_enum] = ACTIONS(5344),
    [anon_sym_struct] = ACTIONS(5344),
    [anon_sym_union] = ACTIONS(5344),
    [anon_sym_nettype] = ACTIONS(5344),
    [anon_sym_automatic] = ACTIONS(5344),
    [anon_sym_string] = ACTIONS(5344),
    [anon_sym_chandle] = ACTIONS(5344),
    [anon_sym_event] = ACTIONS(5344),
    [anon_sym_byte] = ACTIONS(5344),
    [anon_sym_shortint] = ACTIONS(5344),
    [anon_sym_int] = ACTIONS(5344),
    [anon_sym_longint] = ACTIONS(5344),
    [anon_sym_integer] = ACTIONS(5344),
    [anon_sym_time] = ACTIONS(5344),
    [anon_sym_bit] = ACTIONS(5344),
    [anon_sym_logic] = ACTIONS(5344),
    [anon_sym_reg] = ACTIONS(5344),
    [anon_sym_shortreal] = ACTIONS(5344),
    [anon_sym_real] = ACTIONS(5344),
    [anon_sym_realtime] = ACTIONS(5344),
    [anon_sym_supply0] = ACTIONS(5344),
    [anon_sym_supply1] = ACTIONS(5344),
    [anon_sym_signed] = ACTIONS(5344),
    [anon_sym_unsigned] = ACTIONS(5344),
    [anon_sym_task] = ACTIONS(5344),
    [anon_sym_assert] = ACTIONS(5344),
    [anon_sym_property] = ACTIONS(5344),
    [anon_sym_assume] = ACTIONS(5344),
    [anon_sym_cover] = ACTIONS(5344),
    [anon_sym_sequence] = ACTIONS(5344),
    [anon_sym_restrict] = ACTIONS(5344),
    [anon_sym_not] = ACTIONS(5344),
    [anon_sym_or] = ACTIONS(5344),
    [anon_sym_and] = ACTIONS(5344),
    [anon_sym_case] = ACTIONS(5344),
    [anon_sym_always] = ACTIONS(5344),
    [anon_sym_covergroup] = ACTIONS(5344),
    [anon_sym_end] = ACTIONS(5344),
    [anon_sym_let] = ACTIONS(5344),
    [anon_sym_pulldown] = ACTIONS(5344),
    [anon_sym_pullup] = ACTIONS(5344),
    [anon_sym_cmos] = ACTIONS(5344),
    [anon_sym_rcmos] = ACTIONS(5344),
    [anon_sym_bufif0] = ACTIONS(5344),
    [anon_sym_bufif1] = ACTIONS(5344),
    [anon_sym_notif0] = ACTIONS(5344),
    [anon_sym_notif1] = ACTIONS(5344),
    [anon_sym_nmos] = ACTIONS(5344),
    [anon_sym_pmos] = ACTIONS(5344),
    [anon_sym_rnmos] = ACTIONS(5344),
    [anon_sym_rpmos] = ACTIONS(5344),
    [anon_sym_nand] = ACTIONS(5344),
    [anon_sym_nor] = ACTIONS(5344),
    [anon_sym_xor] = ACTIONS(5344),
    [anon_sym_xnor] = ACTIONS(5344),
    [anon_sym_buf] = ACTIONS(5344),
    [anon_sym_tranif0] = ACTIONS(5344),
    [anon_sym_tranif1] = ACTIONS(5344),
    [anon_sym_rtranif1] = ACTIONS(5344),
    [anon_sym_rtranif0] = ACTIONS(5344),
    [anon_sym_tran] = ACTIONS(5344),
    [anon_sym_rtran] = ACTIONS(5344),
    [anon_sym_generate] = ACTIONS(5344),
    [anon_sym_for] = ACTIONS(5344),
    [anon_sym_initial] = ACTIONS(5344),
    [anon_sym_assign] = ACTIONS(5344),
    [anon_sym_alias] = ACTIONS(5344),
    [anon_sym_always_comb] = ACTIONS(5344),
    [anon_sym_always_latch] = ACTIONS(5344),
    [anon_sym_always_ff] = ACTIONS(5344),
    [anon_sym_final] = ACTIONS(5344),
    [anon_sym_global] = ACTIONS(5344),
    [anon_sym_LPAREN_STAR] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5342),
    [anon_sym_DOLLARunit] = ACTIONS(5342),
  },
  [5118] = {
    [sym_simple_identifier] = ACTIONS(6253),
    [anon_sym_wire] = ACTIONS(6253),
    [anon_sym_tri] = ACTIONS(6253),
    [anon_sym_tri0] = ACTIONS(6253),
    [anon_sym_tri1] = ACTIONS(6253),
    [anon_sym_wand] = ACTIONS(6253),
    [anon_sym_triand] = ACTIONS(6253),
    [anon_sym_wor] = ACTIONS(6253),
    [anon_sym_trior] = ACTIONS(6253),
    [anon_sym_trireg] = ACTIONS(6253),
    [anon_sym_uwire] = ACTIONS(6253),
    [anon_sym_SEMI] = ACTIONS(6255),
    [anon_sym_extern] = ACTIONS(6253),
    [anon_sym_interface] = ACTIONS(6253),
    [anon_sym_checker] = ACTIONS(6253),
    [anon_sym_virtual] = ACTIONS(6253),
    [anon_sym_class] = ACTIONS(6253),
    [anon_sym_type] = ACTIONS(6253),
    [anon_sym_DOLLARfatal] = ACTIONS(6255),
    [anon_sym_DOLLARerror] = ACTIONS(6255),
    [anon_sym_DOLLARwarning] = ACTIONS(6255),
    [anon_sym_DOLLARinfo] = ACTIONS(6255),
    [anon_sym_default] = ACTIONS(6253),
    [anon_sym_clocking] = ACTIONS(6253),
    [anon_sym_defparam] = ACTIONS(6253),
    [anon_sym_bind] = ACTIONS(6253),
    [anon_sym_rand] = ACTIONS(6253),
    [anon_sym_const] = ACTIONS(6253),
    [anon_sym_function] = ACTIONS(6253),
    [anon_sym_static] = ACTIONS(6253),
    [anon_sym_constraint] = ACTIONS(6253),
    [anon_sym_if] = ACTIONS(6253),
    [anon_sym_else] = ACTIONS(6253),
    [anon_sym_LBRACK] = ACTIONS(6255),
    [anon_sym_localparam] = ACTIONS(6253),
    [anon_sym_parameter] = ACTIONS(6253),
    [anon_sym_var] = ACTIONS(6253),
    [anon_sym_import] = ACTIONS(6253),
    [anon_sym_export] = ACTIONS(6253),
    [anon_sym_genvar] = ACTIONS(6253),
    [anon_sym_interconnect] = ACTIONS(6253),
    [anon_sym_typedef] = ACTIONS(6253),
    [anon_sym_enum] = ACTIONS(6253),
    [anon_sym_struct] = ACTIONS(6253),
    [anon_sym_union] = ACTIONS(6253),
    [anon_sym_nettype] = ACTIONS(6253),
    [anon_sym_automatic] = ACTIONS(6253),
    [anon_sym_string] = ACTIONS(6253),
    [anon_sym_chandle] = ACTIONS(6253),
    [anon_sym_event] = ACTIONS(6253),
    [anon_sym_byte] = ACTIONS(6253),
    [anon_sym_shortint] = ACTIONS(6253),
    [anon_sym_int] = ACTIONS(6253),
    [anon_sym_longint] = ACTIONS(6253),
    [anon_sym_integer] = ACTIONS(6253),
    [anon_sym_time] = ACTIONS(6253),
    [anon_sym_bit] = ACTIONS(6253),
    [anon_sym_logic] = ACTIONS(6253),
    [anon_sym_reg] = ACTIONS(6253),
    [anon_sym_shortreal] = ACTIONS(6253),
    [anon_sym_real] = ACTIONS(6253),
    [anon_sym_realtime] = ACTIONS(6253),
    [anon_sym_supply0] = ACTIONS(6253),
    [anon_sym_supply1] = ACTIONS(6253),
    [anon_sym_signed] = ACTIONS(6253),
    [anon_sym_unsigned] = ACTIONS(6253),
    [anon_sym_task] = ACTIONS(6253),
    [anon_sym_assert] = ACTIONS(6253),
    [anon_sym_property] = ACTIONS(6253),
    [anon_sym_assume] = ACTIONS(6253),
    [anon_sym_cover] = ACTIONS(6253),
    [anon_sym_sequence] = ACTIONS(6253),
    [anon_sym_restrict] = ACTIONS(6253),
    [anon_sym_not] = ACTIONS(6253),
    [anon_sym_or] = ACTIONS(6253),
    [anon_sym_and] = ACTIONS(6253),
    [anon_sym_case] = ACTIONS(6253),
    [anon_sym_always] = ACTIONS(6253),
    [anon_sym_covergroup] = ACTIONS(6253),
    [anon_sym_let] = ACTIONS(6253),
    [anon_sym_pulldown] = ACTIONS(6253),
    [anon_sym_pullup] = ACTIONS(6253),
    [anon_sym_cmos] = ACTIONS(6253),
    [anon_sym_rcmos] = ACTIONS(6253),
    [anon_sym_bufif0] = ACTIONS(6253),
    [anon_sym_bufif1] = ACTIONS(6253),
    [anon_sym_notif0] = ACTIONS(6253),
    [anon_sym_notif1] = ACTIONS(6253),
    [anon_sym_nmos] = ACTIONS(6253),
    [anon_sym_pmos] = ACTIONS(6253),
    [anon_sym_rnmos] = ACTIONS(6253),
    [anon_sym_rpmos] = ACTIONS(6253),
    [anon_sym_nand] = ACTIONS(6253),
    [anon_sym_nor] = ACTIONS(6253),
    [anon_sym_xor] = ACTIONS(6253),
    [anon_sym_xnor] = ACTIONS(6253),
    [anon_sym_buf] = ACTIONS(6253),
    [anon_sym_tranif0] = ACTIONS(6253),
    [anon_sym_tranif1] = ACTIONS(6253),
    [anon_sym_rtranif1] = ACTIONS(6253),
    [anon_sym_rtranif0] = ACTIONS(6253),
    [anon_sym_tran] = ACTIONS(6253),
    [anon_sym_rtran] = ACTIONS(6253),
    [anon_sym_generate] = ACTIONS(6253),
    [anon_sym_endgenerate] = ACTIONS(6253),
    [anon_sym_for] = ACTIONS(6253),
    [anon_sym_initial] = ACTIONS(6253),
    [anon_sym_assign] = ACTIONS(6253),
    [anon_sym_alias] = ACTIONS(6253),
    [anon_sym_always_comb] = ACTIONS(6253),
    [anon_sym_always_latch] = ACTIONS(6253),
    [anon_sym_always_ff] = ACTIONS(6253),
    [anon_sym_final] = ACTIONS(6253),
    [anon_sym_global] = ACTIONS(6253),
    [anon_sym_LPAREN_STAR] = ACTIONS(6255),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6255),
    [anon_sym_DOLLARunit] = ACTIONS(6255),
  },
  [5119] = {
    [sym_simple_identifier] = ACTIONS(4494),
    [anon_sym_wire] = ACTIONS(4494),
    [anon_sym_tri] = ACTIONS(4494),
    [anon_sym_tri0] = ACTIONS(4494),
    [anon_sym_tri1] = ACTIONS(4494),
    [anon_sym_wand] = ACTIONS(4494),
    [anon_sym_triand] = ACTIONS(4494),
    [anon_sym_wor] = ACTIONS(4494),
    [anon_sym_trior] = ACTIONS(4494),
    [anon_sym_trireg] = ACTIONS(4494),
    [anon_sym_uwire] = ACTIONS(4494),
    [anon_sym_SEMI] = ACTIONS(4492),
    [anon_sym_extern] = ACTIONS(4494),
    [anon_sym_interface] = ACTIONS(4494),
    [anon_sym_checker] = ACTIONS(4494),
    [anon_sym_virtual] = ACTIONS(4494),
    [anon_sym_class] = ACTIONS(4494),
    [anon_sym_type] = ACTIONS(4494),
    [anon_sym_DOLLARfatal] = ACTIONS(4492),
    [anon_sym_DOLLARerror] = ACTIONS(4492),
    [anon_sym_DOLLARwarning] = ACTIONS(4492),
    [anon_sym_DOLLARinfo] = ACTIONS(4492),
    [anon_sym_default] = ACTIONS(4494),
    [anon_sym_clocking] = ACTIONS(4494),
    [anon_sym_defparam] = ACTIONS(4494),
    [anon_sym_bind] = ACTIONS(4494),
    [anon_sym_rand] = ACTIONS(4494),
    [anon_sym_const] = ACTIONS(4494),
    [anon_sym_function] = ACTIONS(4494),
    [anon_sym_static] = ACTIONS(4494),
    [anon_sym_constraint] = ACTIONS(4494),
    [anon_sym_if] = ACTIONS(4494),
    [anon_sym_else] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4492),
    [anon_sym_localparam] = ACTIONS(4494),
    [anon_sym_parameter] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4494),
    [anon_sym_import] = ACTIONS(4494),
    [anon_sym_export] = ACTIONS(4494),
    [anon_sym_genvar] = ACTIONS(4494),
    [anon_sym_interconnect] = ACTIONS(4494),
    [anon_sym_typedef] = ACTIONS(4494),
    [anon_sym_enum] = ACTIONS(4494),
    [anon_sym_struct] = ACTIONS(4494),
    [anon_sym_union] = ACTIONS(4494),
    [anon_sym_nettype] = ACTIONS(4494),
    [anon_sym_automatic] = ACTIONS(4494),
    [anon_sym_string] = ACTIONS(4494),
    [anon_sym_chandle] = ACTIONS(4494),
    [anon_sym_event] = ACTIONS(4494),
    [anon_sym_byte] = ACTIONS(4494),
    [anon_sym_shortint] = ACTIONS(4494),
    [anon_sym_int] = ACTIONS(4494),
    [anon_sym_longint] = ACTIONS(4494),
    [anon_sym_integer] = ACTIONS(4494),
    [anon_sym_time] = ACTIONS(4494),
    [anon_sym_bit] = ACTIONS(4494),
    [anon_sym_logic] = ACTIONS(4494),
    [anon_sym_reg] = ACTIONS(4494),
    [anon_sym_shortreal] = ACTIONS(4494),
    [anon_sym_real] = ACTIONS(4494),
    [anon_sym_realtime] = ACTIONS(4494),
    [anon_sym_supply0] = ACTIONS(4494),
    [anon_sym_supply1] = ACTIONS(4494),
    [anon_sym_signed] = ACTIONS(4494),
    [anon_sym_unsigned] = ACTIONS(4494),
    [anon_sym_task] = ACTIONS(4494),
    [anon_sym_assert] = ACTIONS(4494),
    [anon_sym_property] = ACTIONS(4494),
    [anon_sym_assume] = ACTIONS(4494),
    [anon_sym_cover] = ACTIONS(4494),
    [anon_sym_sequence] = ACTIONS(4494),
    [anon_sym_restrict] = ACTIONS(4494),
    [anon_sym_not] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_case] = ACTIONS(4494),
    [anon_sym_always] = ACTIONS(4494),
    [anon_sym_covergroup] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_pulldown] = ACTIONS(4494),
    [anon_sym_pullup] = ACTIONS(4494),
    [anon_sym_cmos] = ACTIONS(4494),
    [anon_sym_rcmos] = ACTIONS(4494),
    [anon_sym_bufif0] = ACTIONS(4494),
    [anon_sym_bufif1] = ACTIONS(4494),
    [anon_sym_notif0] = ACTIONS(4494),
    [anon_sym_notif1] = ACTIONS(4494),
    [anon_sym_nmos] = ACTIONS(4494),
    [anon_sym_pmos] = ACTIONS(4494),
    [anon_sym_rnmos] = ACTIONS(4494),
    [anon_sym_rpmos] = ACTIONS(4494),
    [anon_sym_nand] = ACTIONS(4494),
    [anon_sym_nor] = ACTIONS(4494),
    [anon_sym_xor] = ACTIONS(4494),
    [anon_sym_xnor] = ACTIONS(4494),
    [anon_sym_buf] = ACTIONS(4494),
    [anon_sym_tranif0] = ACTIONS(4494),
    [anon_sym_tranif1] = ACTIONS(4494),
    [anon_sym_rtranif1] = ACTIONS(4494),
    [anon_sym_rtranif0] = ACTIONS(4494),
    [anon_sym_tran] = ACTIONS(4494),
    [anon_sym_rtran] = ACTIONS(4494),
    [anon_sym_generate] = ACTIONS(4494),
    [anon_sym_endgenerate] = ACTIONS(4494),
    [anon_sym_for] = ACTIONS(4494),
    [anon_sym_initial] = ACTIONS(4494),
    [anon_sym_assign] = ACTIONS(4494),
    [anon_sym_alias] = ACTIONS(4494),
    [anon_sym_always_comb] = ACTIONS(4494),
    [anon_sym_always_latch] = ACTIONS(4494),
    [anon_sym_always_ff] = ACTIONS(4494),
    [anon_sym_final] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4494),
    [anon_sym_LPAREN_STAR] = ACTIONS(4492),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4492),
    [anon_sym_DOLLARunit] = ACTIONS(4492),
  },
  [5120] = {
    [sym_simple_identifier] = ACTIONS(6705),
    [anon_sym_wire] = ACTIONS(6705),
    [anon_sym_tri] = ACTIONS(6705),
    [anon_sym_tri0] = ACTIONS(6705),
    [anon_sym_tri1] = ACTIONS(6705),
    [anon_sym_wand] = ACTIONS(6705),
    [anon_sym_triand] = ACTIONS(6705),
    [anon_sym_wor] = ACTIONS(6705),
    [anon_sym_trior] = ACTIONS(6705),
    [anon_sym_trireg] = ACTIONS(6705),
    [anon_sym_uwire] = ACTIONS(6705),
    [anon_sym_SEMI] = ACTIONS(6707),
    [anon_sym_extern] = ACTIONS(6705),
    [anon_sym_interface] = ACTIONS(6705),
    [anon_sym_checker] = ACTIONS(6705),
    [anon_sym_virtual] = ACTIONS(6705),
    [anon_sym_class] = ACTIONS(6705),
    [anon_sym_type] = ACTIONS(6705),
    [anon_sym_DOLLARfatal] = ACTIONS(6707),
    [anon_sym_DOLLARerror] = ACTIONS(6707),
    [anon_sym_DOLLARwarning] = ACTIONS(6707),
    [anon_sym_DOLLARinfo] = ACTIONS(6707),
    [anon_sym_default] = ACTIONS(6705),
    [anon_sym_clocking] = ACTIONS(6705),
    [anon_sym_defparam] = ACTIONS(6705),
    [anon_sym_bind] = ACTIONS(6705),
    [anon_sym_rand] = ACTIONS(6705),
    [anon_sym_const] = ACTIONS(6705),
    [anon_sym_function] = ACTIONS(6705),
    [anon_sym_static] = ACTIONS(6705),
    [anon_sym_constraint] = ACTIONS(6705),
    [anon_sym_if] = ACTIONS(6705),
    [anon_sym_else] = ACTIONS(6705),
    [anon_sym_LBRACK] = ACTIONS(6707),
    [anon_sym_localparam] = ACTIONS(6705),
    [anon_sym_parameter] = ACTIONS(6705),
    [anon_sym_var] = ACTIONS(6705),
    [anon_sym_import] = ACTIONS(6705),
    [anon_sym_export] = ACTIONS(6705),
    [anon_sym_genvar] = ACTIONS(6705),
    [anon_sym_interconnect] = ACTIONS(6705),
    [anon_sym_typedef] = ACTIONS(6705),
    [anon_sym_enum] = ACTIONS(6705),
    [anon_sym_struct] = ACTIONS(6705),
    [anon_sym_union] = ACTIONS(6705),
    [anon_sym_nettype] = ACTIONS(6705),
    [anon_sym_automatic] = ACTIONS(6705),
    [anon_sym_string] = ACTIONS(6705),
    [anon_sym_chandle] = ACTIONS(6705),
    [anon_sym_event] = ACTIONS(6705),
    [anon_sym_byte] = ACTIONS(6705),
    [anon_sym_shortint] = ACTIONS(6705),
    [anon_sym_int] = ACTIONS(6705),
    [anon_sym_longint] = ACTIONS(6705),
    [anon_sym_integer] = ACTIONS(6705),
    [anon_sym_time] = ACTIONS(6705),
    [anon_sym_bit] = ACTIONS(6705),
    [anon_sym_logic] = ACTIONS(6705),
    [anon_sym_reg] = ACTIONS(6705),
    [anon_sym_shortreal] = ACTIONS(6705),
    [anon_sym_real] = ACTIONS(6705),
    [anon_sym_realtime] = ACTIONS(6705),
    [anon_sym_supply0] = ACTIONS(6705),
    [anon_sym_supply1] = ACTIONS(6705),
    [anon_sym_signed] = ACTIONS(6705),
    [anon_sym_unsigned] = ACTIONS(6705),
    [anon_sym_task] = ACTIONS(6705),
    [anon_sym_assert] = ACTIONS(6705),
    [anon_sym_property] = ACTIONS(6705),
    [anon_sym_assume] = ACTIONS(6705),
    [anon_sym_cover] = ACTIONS(6705),
    [anon_sym_sequence] = ACTIONS(6705),
    [anon_sym_restrict] = ACTIONS(6705),
    [anon_sym_not] = ACTIONS(6705),
    [anon_sym_or] = ACTIONS(6705),
    [anon_sym_and] = ACTIONS(6705),
    [anon_sym_case] = ACTIONS(6705),
    [anon_sym_always] = ACTIONS(6705),
    [anon_sym_covergroup] = ACTIONS(6705),
    [anon_sym_let] = ACTIONS(6705),
    [anon_sym_pulldown] = ACTIONS(6705),
    [anon_sym_pullup] = ACTIONS(6705),
    [anon_sym_cmos] = ACTIONS(6705),
    [anon_sym_rcmos] = ACTIONS(6705),
    [anon_sym_bufif0] = ACTIONS(6705),
    [anon_sym_bufif1] = ACTIONS(6705),
    [anon_sym_notif0] = ACTIONS(6705),
    [anon_sym_notif1] = ACTIONS(6705),
    [anon_sym_nmos] = ACTIONS(6705),
    [anon_sym_pmos] = ACTIONS(6705),
    [anon_sym_rnmos] = ACTIONS(6705),
    [anon_sym_rpmos] = ACTIONS(6705),
    [anon_sym_nand] = ACTIONS(6705),
    [anon_sym_nor] = ACTIONS(6705),
    [anon_sym_xor] = ACTIONS(6705),
    [anon_sym_xnor] = ACTIONS(6705),
    [anon_sym_buf] = ACTIONS(6705),
    [anon_sym_tranif0] = ACTIONS(6705),
    [anon_sym_tranif1] = ACTIONS(6705),
    [anon_sym_rtranif1] = ACTIONS(6705),
    [anon_sym_rtranif0] = ACTIONS(6705),
    [anon_sym_tran] = ACTIONS(6705),
    [anon_sym_rtran] = ACTIONS(6705),
    [anon_sym_generate] = ACTIONS(6705),
    [anon_sym_endgenerate] = ACTIONS(6705),
    [anon_sym_for] = ACTIONS(6705),
    [anon_sym_initial] = ACTIONS(6705),
    [anon_sym_assign] = ACTIONS(6705),
    [anon_sym_alias] = ACTIONS(6705),
    [anon_sym_always_comb] = ACTIONS(6705),
    [anon_sym_always_latch] = ACTIONS(6705),
    [anon_sym_always_ff] = ACTIONS(6705),
    [anon_sym_final] = ACTIONS(6705),
    [anon_sym_global] = ACTIONS(6705),
    [anon_sym_LPAREN_STAR] = ACTIONS(6707),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6707),
    [anon_sym_DOLLARunit] = ACTIONS(6707),
  },
  [5121] = {
    [sym_simple_identifier] = ACTIONS(5318),
    [anon_sym_wire] = ACTIONS(5318),
    [anon_sym_tri] = ACTIONS(5318),
    [anon_sym_tri0] = ACTIONS(5318),
    [anon_sym_tri1] = ACTIONS(5318),
    [anon_sym_wand] = ACTIONS(5318),
    [anon_sym_triand] = ACTIONS(5318),
    [anon_sym_wor] = ACTIONS(5318),
    [anon_sym_trior] = ACTIONS(5318),
    [anon_sym_trireg] = ACTIONS(5318),
    [anon_sym_uwire] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5316),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym_interface] = ACTIONS(5318),
    [anon_sym_checker] = ACTIONS(5318),
    [anon_sym_virtual] = ACTIONS(5318),
    [anon_sym_class] = ACTIONS(5318),
    [anon_sym_type] = ACTIONS(5318),
    [anon_sym_DOLLARfatal] = ACTIONS(5316),
    [anon_sym_DOLLARerror] = ACTIONS(5316),
    [anon_sym_DOLLARwarning] = ACTIONS(5316),
    [anon_sym_DOLLARinfo] = ACTIONS(5316),
    [anon_sym_default] = ACTIONS(5318),
    [anon_sym_clocking] = ACTIONS(5318),
    [anon_sym_defparam] = ACTIONS(5318),
    [anon_sym_bind] = ACTIONS(5318),
    [anon_sym_rand] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_function] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_constraint] = ACTIONS(5318),
    [anon_sym_if] = ACTIONS(5318),
    [anon_sym_else] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5316),
    [anon_sym_localparam] = ACTIONS(5318),
    [anon_sym_parameter] = ACTIONS(5318),
    [anon_sym_var] = ACTIONS(5318),
    [anon_sym_import] = ACTIONS(5318),
    [anon_sym_export] = ACTIONS(5318),
    [anon_sym_genvar] = ACTIONS(5318),
    [anon_sym_interconnect] = ACTIONS(5318),
    [anon_sym_typedef] = ACTIONS(5318),
    [anon_sym_enum] = ACTIONS(5318),
    [anon_sym_struct] = ACTIONS(5318),
    [anon_sym_union] = ACTIONS(5318),
    [anon_sym_nettype] = ACTIONS(5318),
    [anon_sym_automatic] = ACTIONS(5318),
    [anon_sym_string] = ACTIONS(5318),
    [anon_sym_chandle] = ACTIONS(5318),
    [anon_sym_event] = ACTIONS(5318),
    [anon_sym_byte] = ACTIONS(5318),
    [anon_sym_shortint] = ACTIONS(5318),
    [anon_sym_int] = ACTIONS(5318),
    [anon_sym_longint] = ACTIONS(5318),
    [anon_sym_integer] = ACTIONS(5318),
    [anon_sym_time] = ACTIONS(5318),
    [anon_sym_bit] = ACTIONS(5318),
    [anon_sym_logic] = ACTIONS(5318),
    [anon_sym_reg] = ACTIONS(5318),
    [anon_sym_shortreal] = ACTIONS(5318),
    [anon_sym_real] = ACTIONS(5318),
    [anon_sym_realtime] = ACTIONS(5318),
    [anon_sym_supply0] = ACTIONS(5318),
    [anon_sym_supply1] = ACTIONS(5318),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_task] = ACTIONS(5318),
    [anon_sym_assert] = ACTIONS(5318),
    [anon_sym_property] = ACTIONS(5318),
    [anon_sym_assume] = ACTIONS(5318),
    [anon_sym_cover] = ACTIONS(5318),
    [anon_sym_sequence] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym_not] = ACTIONS(5318),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_case] = ACTIONS(5318),
    [anon_sym_always] = ACTIONS(5318),
    [anon_sym_covergroup] = ACTIONS(5318),
    [anon_sym_end] = ACTIONS(5318),
    [anon_sym_let] = ACTIONS(5318),
    [anon_sym_pulldown] = ACTIONS(5318),
    [anon_sym_pullup] = ACTIONS(5318),
    [anon_sym_cmos] = ACTIONS(5318),
    [anon_sym_rcmos] = ACTIONS(5318),
    [anon_sym_bufif0] = ACTIONS(5318),
    [anon_sym_bufif1] = ACTIONS(5318),
    [anon_sym_notif0] = ACTIONS(5318),
    [anon_sym_notif1] = ACTIONS(5318),
    [anon_sym_nmos] = ACTIONS(5318),
    [anon_sym_pmos] = ACTIONS(5318),
    [anon_sym_rnmos] = ACTIONS(5318),
    [anon_sym_rpmos] = ACTIONS(5318),
    [anon_sym_nand] = ACTIONS(5318),
    [anon_sym_nor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_xnor] = ACTIONS(5318),
    [anon_sym_buf] = ACTIONS(5318),
    [anon_sym_tranif0] = ACTIONS(5318),
    [anon_sym_tranif1] = ACTIONS(5318),
    [anon_sym_rtranif1] = ACTIONS(5318),
    [anon_sym_rtranif0] = ACTIONS(5318),
    [anon_sym_tran] = ACTIONS(5318),
    [anon_sym_rtran] = ACTIONS(5318),
    [anon_sym_generate] = ACTIONS(5318),
    [anon_sym_for] = ACTIONS(5318),
    [anon_sym_initial] = ACTIONS(5318),
    [anon_sym_assign] = ACTIONS(5318),
    [anon_sym_alias] = ACTIONS(5318),
    [anon_sym_always_comb] = ACTIONS(5318),
    [anon_sym_always_latch] = ACTIONS(5318),
    [anon_sym_always_ff] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_global] = ACTIONS(5318),
    [anon_sym_LPAREN_STAR] = ACTIONS(5316),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5316),
    [anon_sym_DOLLARunit] = ACTIONS(5316),
  },
  [5122] = {
    [sym_simple_identifier] = ACTIONS(4460),
    [anon_sym_wire] = ACTIONS(4460),
    [anon_sym_tri] = ACTIONS(4460),
    [anon_sym_tri0] = ACTIONS(4460),
    [anon_sym_tri1] = ACTIONS(4460),
    [anon_sym_wand] = ACTIONS(4460),
    [anon_sym_triand] = ACTIONS(4460),
    [anon_sym_wor] = ACTIONS(4460),
    [anon_sym_trior] = ACTIONS(4460),
    [anon_sym_trireg] = ACTIONS(4460),
    [anon_sym_uwire] = ACTIONS(4460),
    [anon_sym_SEMI] = ACTIONS(4458),
    [anon_sym_extern] = ACTIONS(4460),
    [anon_sym_interface] = ACTIONS(4460),
    [anon_sym_checker] = ACTIONS(4460),
    [anon_sym_virtual] = ACTIONS(4460),
    [anon_sym_class] = ACTIONS(4460),
    [anon_sym_type] = ACTIONS(4460),
    [anon_sym_DOLLARfatal] = ACTIONS(4458),
    [anon_sym_DOLLARerror] = ACTIONS(4458),
    [anon_sym_DOLLARwarning] = ACTIONS(4458),
    [anon_sym_DOLLARinfo] = ACTIONS(4458),
    [anon_sym_default] = ACTIONS(4460),
    [anon_sym_clocking] = ACTIONS(4460),
    [anon_sym_defparam] = ACTIONS(4460),
    [anon_sym_bind] = ACTIONS(4460),
    [anon_sym_rand] = ACTIONS(4460),
    [anon_sym_const] = ACTIONS(4460),
    [anon_sym_function] = ACTIONS(4460),
    [anon_sym_static] = ACTIONS(4460),
    [anon_sym_constraint] = ACTIONS(4460),
    [anon_sym_if] = ACTIONS(4460),
    [anon_sym_else] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4458),
    [anon_sym_localparam] = ACTIONS(4460),
    [anon_sym_parameter] = ACTIONS(4460),
    [anon_sym_var] = ACTIONS(4460),
    [anon_sym_import] = ACTIONS(4460),
    [anon_sym_export] = ACTIONS(4460),
    [anon_sym_genvar] = ACTIONS(4460),
    [anon_sym_interconnect] = ACTIONS(4460),
    [anon_sym_typedef] = ACTIONS(4460),
    [anon_sym_enum] = ACTIONS(4460),
    [anon_sym_struct] = ACTIONS(4460),
    [anon_sym_union] = ACTIONS(4460),
    [anon_sym_nettype] = ACTIONS(4460),
    [anon_sym_automatic] = ACTIONS(4460),
    [anon_sym_string] = ACTIONS(4460),
    [anon_sym_chandle] = ACTIONS(4460),
    [anon_sym_event] = ACTIONS(4460),
    [anon_sym_byte] = ACTIONS(4460),
    [anon_sym_shortint] = ACTIONS(4460),
    [anon_sym_int] = ACTIONS(4460),
    [anon_sym_longint] = ACTIONS(4460),
    [anon_sym_integer] = ACTIONS(4460),
    [anon_sym_time] = ACTIONS(4460),
    [anon_sym_bit] = ACTIONS(4460),
    [anon_sym_logic] = ACTIONS(4460),
    [anon_sym_reg] = ACTIONS(4460),
    [anon_sym_shortreal] = ACTIONS(4460),
    [anon_sym_real] = ACTIONS(4460),
    [anon_sym_realtime] = ACTIONS(4460),
    [anon_sym_supply0] = ACTIONS(4460),
    [anon_sym_supply1] = ACTIONS(4460),
    [anon_sym_signed] = ACTIONS(4460),
    [anon_sym_unsigned] = ACTIONS(4460),
    [anon_sym_task] = ACTIONS(4460),
    [anon_sym_assert] = ACTIONS(4460),
    [anon_sym_property] = ACTIONS(4460),
    [anon_sym_assume] = ACTIONS(4460),
    [anon_sym_cover] = ACTIONS(4460),
    [anon_sym_sequence] = ACTIONS(4460),
    [anon_sym_restrict] = ACTIONS(4460),
    [anon_sym_not] = ACTIONS(4460),
    [anon_sym_or] = ACTIONS(4460),
    [anon_sym_and] = ACTIONS(4460),
    [anon_sym_case] = ACTIONS(4460),
    [anon_sym_always] = ACTIONS(4460),
    [anon_sym_covergroup] = ACTIONS(4460),
    [anon_sym_end] = ACTIONS(4460),
    [anon_sym_let] = ACTIONS(4460),
    [anon_sym_pulldown] = ACTIONS(4460),
    [anon_sym_pullup] = ACTIONS(4460),
    [anon_sym_cmos] = ACTIONS(4460),
    [anon_sym_rcmos] = ACTIONS(4460),
    [anon_sym_bufif0] = ACTIONS(4460),
    [anon_sym_bufif1] = ACTIONS(4460),
    [anon_sym_notif0] = ACTIONS(4460),
    [anon_sym_notif1] = ACTIONS(4460),
    [anon_sym_nmos] = ACTIONS(4460),
    [anon_sym_pmos] = ACTIONS(4460),
    [anon_sym_rnmos] = ACTIONS(4460),
    [anon_sym_rpmos] = ACTIONS(4460),
    [anon_sym_nand] = ACTIONS(4460),
    [anon_sym_nor] = ACTIONS(4460),
    [anon_sym_xor] = ACTIONS(4460),
    [anon_sym_xnor] = ACTIONS(4460),
    [anon_sym_buf] = ACTIONS(4460),
    [anon_sym_tranif0] = ACTIONS(4460),
    [anon_sym_tranif1] = ACTIONS(4460),
    [anon_sym_rtranif1] = ACTIONS(4460),
    [anon_sym_rtranif0] = ACTIONS(4460),
    [anon_sym_tran] = ACTIONS(4460),
    [anon_sym_rtran] = ACTIONS(4460),
    [anon_sym_generate] = ACTIONS(4460),
    [anon_sym_for] = ACTIONS(4460),
    [anon_sym_initial] = ACTIONS(4460),
    [anon_sym_assign] = ACTIONS(4460),
    [anon_sym_alias] = ACTIONS(4460),
    [anon_sym_always_comb] = ACTIONS(4460),
    [anon_sym_always_latch] = ACTIONS(4460),
    [anon_sym_always_ff] = ACTIONS(4460),
    [anon_sym_final] = ACTIONS(4460),
    [anon_sym_global] = ACTIONS(4460),
    [anon_sym_LPAREN_STAR] = ACTIONS(4458),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4458),
    [anon_sym_DOLLARunit] = ACTIONS(4458),
  },
  [5123] = {
    [sym_simple_identifier] = ACTIONS(5266),
    [anon_sym_wire] = ACTIONS(5266),
    [anon_sym_tri] = ACTIONS(5266),
    [anon_sym_tri0] = ACTIONS(5266),
    [anon_sym_tri1] = ACTIONS(5266),
    [anon_sym_wand] = ACTIONS(5266),
    [anon_sym_triand] = ACTIONS(5266),
    [anon_sym_wor] = ACTIONS(5266),
    [anon_sym_trior] = ACTIONS(5266),
    [anon_sym_trireg] = ACTIONS(5266),
    [anon_sym_uwire] = ACTIONS(5266),
    [anon_sym_SEMI] = ACTIONS(5264),
    [anon_sym_extern] = ACTIONS(5266),
    [anon_sym_interface] = ACTIONS(5266),
    [anon_sym_checker] = ACTIONS(5266),
    [anon_sym_virtual] = ACTIONS(5266),
    [anon_sym_class] = ACTIONS(5266),
    [anon_sym_type] = ACTIONS(5266),
    [anon_sym_DOLLARfatal] = ACTIONS(5264),
    [anon_sym_DOLLARerror] = ACTIONS(5264),
    [anon_sym_DOLLARwarning] = ACTIONS(5264),
    [anon_sym_DOLLARinfo] = ACTIONS(5264),
    [anon_sym_default] = ACTIONS(5266),
    [anon_sym_clocking] = ACTIONS(5266),
    [anon_sym_defparam] = ACTIONS(5266),
    [anon_sym_bind] = ACTIONS(5266),
    [anon_sym_rand] = ACTIONS(5266),
    [anon_sym_const] = ACTIONS(5266),
    [anon_sym_function] = ACTIONS(5266),
    [anon_sym_static] = ACTIONS(5266),
    [anon_sym_constraint] = ACTIONS(5266),
    [anon_sym_if] = ACTIONS(5266),
    [anon_sym_else] = ACTIONS(5266),
    [anon_sym_LBRACK] = ACTIONS(5264),
    [anon_sym_localparam] = ACTIONS(5266),
    [anon_sym_parameter] = ACTIONS(5266),
    [anon_sym_var] = ACTIONS(5266),
    [anon_sym_import] = ACTIONS(5266),
    [anon_sym_export] = ACTIONS(5266),
    [anon_sym_genvar] = ACTIONS(5266),
    [anon_sym_interconnect] = ACTIONS(5266),
    [anon_sym_typedef] = ACTIONS(5266),
    [anon_sym_enum] = ACTIONS(5266),
    [anon_sym_struct] = ACTIONS(5266),
    [anon_sym_union] = ACTIONS(5266),
    [anon_sym_nettype] = ACTIONS(5266),
    [anon_sym_automatic] = ACTIONS(5266),
    [anon_sym_string] = ACTIONS(5266),
    [anon_sym_chandle] = ACTIONS(5266),
    [anon_sym_event] = ACTIONS(5266),
    [anon_sym_byte] = ACTIONS(5266),
    [anon_sym_shortint] = ACTIONS(5266),
    [anon_sym_int] = ACTIONS(5266),
    [anon_sym_longint] = ACTIONS(5266),
    [anon_sym_integer] = ACTIONS(5266),
    [anon_sym_time] = ACTIONS(5266),
    [anon_sym_bit] = ACTIONS(5266),
    [anon_sym_logic] = ACTIONS(5266),
    [anon_sym_reg] = ACTIONS(5266),
    [anon_sym_shortreal] = ACTIONS(5266),
    [anon_sym_real] = ACTIONS(5266),
    [anon_sym_realtime] = ACTIONS(5266),
    [anon_sym_supply0] = ACTIONS(5266),
    [anon_sym_supply1] = ACTIONS(5266),
    [anon_sym_signed] = ACTIONS(5266),
    [anon_sym_unsigned] = ACTIONS(5266),
    [anon_sym_task] = ACTIONS(5266),
    [anon_sym_assert] = ACTIONS(5266),
    [anon_sym_property] = ACTIONS(5266),
    [anon_sym_assume] = ACTIONS(5266),
    [anon_sym_cover] = ACTIONS(5266),
    [anon_sym_sequence] = ACTIONS(5266),
    [anon_sym_restrict] = ACTIONS(5266),
    [anon_sym_not] = ACTIONS(5266),
    [anon_sym_or] = ACTIONS(5266),
    [anon_sym_and] = ACTIONS(5266),
    [anon_sym_case] = ACTIONS(5266),
    [anon_sym_always] = ACTIONS(5266),
    [anon_sym_covergroup] = ACTIONS(5266),
    [anon_sym_end] = ACTIONS(5266),
    [anon_sym_let] = ACTIONS(5266),
    [anon_sym_pulldown] = ACTIONS(5266),
    [anon_sym_pullup] = ACTIONS(5266),
    [anon_sym_cmos] = ACTIONS(5266),
    [anon_sym_rcmos] = ACTIONS(5266),
    [anon_sym_bufif0] = ACTIONS(5266),
    [anon_sym_bufif1] = ACTIONS(5266),
    [anon_sym_notif0] = ACTIONS(5266),
    [anon_sym_notif1] = ACTIONS(5266),
    [anon_sym_nmos] = ACTIONS(5266),
    [anon_sym_pmos] = ACTIONS(5266),
    [anon_sym_rnmos] = ACTIONS(5266),
    [anon_sym_rpmos] = ACTIONS(5266),
    [anon_sym_nand] = ACTIONS(5266),
    [anon_sym_nor] = ACTIONS(5266),
    [anon_sym_xor] = ACTIONS(5266),
    [anon_sym_xnor] = ACTIONS(5266),
    [anon_sym_buf] = ACTIONS(5266),
    [anon_sym_tranif0] = ACTIONS(5266),
    [anon_sym_tranif1] = ACTIONS(5266),
    [anon_sym_rtranif1] = ACTIONS(5266),
    [anon_sym_rtranif0] = ACTIONS(5266),
    [anon_sym_tran] = ACTIONS(5266),
    [anon_sym_rtran] = ACTIONS(5266),
    [anon_sym_generate] = ACTIONS(5266),
    [anon_sym_for] = ACTIONS(5266),
    [anon_sym_initial] = ACTIONS(5266),
    [anon_sym_assign] = ACTIONS(5266),
    [anon_sym_alias] = ACTIONS(5266),
    [anon_sym_always_comb] = ACTIONS(5266),
    [anon_sym_always_latch] = ACTIONS(5266),
    [anon_sym_always_ff] = ACTIONS(5266),
    [anon_sym_final] = ACTIONS(5266),
    [anon_sym_global] = ACTIONS(5266),
    [anon_sym_LPAREN_STAR] = ACTIONS(5264),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5264),
    [anon_sym_DOLLARunit] = ACTIONS(5264),
  },
  [5124] = {
    [sym_simple_identifier] = ACTIONS(5194),
    [anon_sym_wire] = ACTIONS(5194),
    [anon_sym_tri] = ACTIONS(5194),
    [anon_sym_tri0] = ACTIONS(5194),
    [anon_sym_tri1] = ACTIONS(5194),
    [anon_sym_wand] = ACTIONS(5194),
    [anon_sym_triand] = ACTIONS(5194),
    [anon_sym_wor] = ACTIONS(5194),
    [anon_sym_trior] = ACTIONS(5194),
    [anon_sym_trireg] = ACTIONS(5194),
    [anon_sym_uwire] = ACTIONS(5194),
    [anon_sym_SEMI] = ACTIONS(5192),
    [anon_sym_extern] = ACTIONS(5194),
    [anon_sym_interface] = ACTIONS(5194),
    [anon_sym_checker] = ACTIONS(5194),
    [anon_sym_virtual] = ACTIONS(5194),
    [anon_sym_class] = ACTIONS(5194),
    [anon_sym_type] = ACTIONS(5194),
    [anon_sym_DOLLARfatal] = ACTIONS(5192),
    [anon_sym_DOLLARerror] = ACTIONS(5192),
    [anon_sym_DOLLARwarning] = ACTIONS(5192),
    [anon_sym_DOLLARinfo] = ACTIONS(5192),
    [anon_sym_default] = ACTIONS(5194),
    [anon_sym_clocking] = ACTIONS(5194),
    [anon_sym_defparam] = ACTIONS(5194),
    [anon_sym_bind] = ACTIONS(5194),
    [anon_sym_rand] = ACTIONS(5194),
    [anon_sym_const] = ACTIONS(5194),
    [anon_sym_function] = ACTIONS(5194),
    [anon_sym_static] = ACTIONS(5194),
    [anon_sym_constraint] = ACTIONS(5194),
    [anon_sym_if] = ACTIONS(5194),
    [anon_sym_else] = ACTIONS(5194),
    [anon_sym_LBRACK] = ACTIONS(5192),
    [anon_sym_localparam] = ACTIONS(5194),
    [anon_sym_parameter] = ACTIONS(5194),
    [anon_sym_var] = ACTIONS(5194),
    [anon_sym_import] = ACTIONS(5194),
    [anon_sym_export] = ACTIONS(5194),
    [anon_sym_genvar] = ACTIONS(5194),
    [anon_sym_interconnect] = ACTIONS(5194),
    [anon_sym_typedef] = ACTIONS(5194),
    [anon_sym_enum] = ACTIONS(5194),
    [anon_sym_struct] = ACTIONS(5194),
    [anon_sym_union] = ACTIONS(5194),
    [anon_sym_nettype] = ACTIONS(5194),
    [anon_sym_automatic] = ACTIONS(5194),
    [anon_sym_string] = ACTIONS(5194),
    [anon_sym_chandle] = ACTIONS(5194),
    [anon_sym_event] = ACTIONS(5194),
    [anon_sym_byte] = ACTIONS(5194),
    [anon_sym_shortint] = ACTIONS(5194),
    [anon_sym_int] = ACTIONS(5194),
    [anon_sym_longint] = ACTIONS(5194),
    [anon_sym_integer] = ACTIONS(5194),
    [anon_sym_time] = ACTIONS(5194),
    [anon_sym_bit] = ACTIONS(5194),
    [anon_sym_logic] = ACTIONS(5194),
    [anon_sym_reg] = ACTIONS(5194),
    [anon_sym_shortreal] = ACTIONS(5194),
    [anon_sym_real] = ACTIONS(5194),
    [anon_sym_realtime] = ACTIONS(5194),
    [anon_sym_supply0] = ACTIONS(5194),
    [anon_sym_supply1] = ACTIONS(5194),
    [anon_sym_signed] = ACTIONS(5194),
    [anon_sym_unsigned] = ACTIONS(5194),
    [anon_sym_task] = ACTIONS(5194),
    [anon_sym_assert] = ACTIONS(5194),
    [anon_sym_property] = ACTIONS(5194),
    [anon_sym_assume] = ACTIONS(5194),
    [anon_sym_cover] = ACTIONS(5194),
    [anon_sym_sequence] = ACTIONS(5194),
    [anon_sym_restrict] = ACTIONS(5194),
    [anon_sym_not] = ACTIONS(5194),
    [anon_sym_or] = ACTIONS(5194),
    [anon_sym_and] = ACTIONS(5194),
    [anon_sym_case] = ACTIONS(5194),
    [anon_sym_always] = ACTIONS(5194),
    [anon_sym_covergroup] = ACTIONS(5194),
    [anon_sym_let] = ACTIONS(5194),
    [anon_sym_pulldown] = ACTIONS(5194),
    [anon_sym_pullup] = ACTIONS(5194),
    [anon_sym_cmos] = ACTIONS(5194),
    [anon_sym_rcmos] = ACTIONS(5194),
    [anon_sym_bufif0] = ACTIONS(5194),
    [anon_sym_bufif1] = ACTIONS(5194),
    [anon_sym_notif0] = ACTIONS(5194),
    [anon_sym_notif1] = ACTIONS(5194),
    [anon_sym_nmos] = ACTIONS(5194),
    [anon_sym_pmos] = ACTIONS(5194),
    [anon_sym_rnmos] = ACTIONS(5194),
    [anon_sym_rpmos] = ACTIONS(5194),
    [anon_sym_nand] = ACTIONS(5194),
    [anon_sym_nor] = ACTIONS(5194),
    [anon_sym_xor] = ACTIONS(5194),
    [anon_sym_xnor] = ACTIONS(5194),
    [anon_sym_buf] = ACTIONS(5194),
    [anon_sym_tranif0] = ACTIONS(5194),
    [anon_sym_tranif1] = ACTIONS(5194),
    [anon_sym_rtranif1] = ACTIONS(5194),
    [anon_sym_rtranif0] = ACTIONS(5194),
    [anon_sym_tran] = ACTIONS(5194),
    [anon_sym_rtran] = ACTIONS(5194),
    [anon_sym_generate] = ACTIONS(5194),
    [anon_sym_endgenerate] = ACTIONS(5194),
    [anon_sym_for] = ACTIONS(5194),
    [anon_sym_initial] = ACTIONS(5194),
    [anon_sym_assign] = ACTIONS(5194),
    [anon_sym_alias] = ACTIONS(5194),
    [anon_sym_always_comb] = ACTIONS(5194),
    [anon_sym_always_latch] = ACTIONS(5194),
    [anon_sym_always_ff] = ACTIONS(5194),
    [anon_sym_final] = ACTIONS(5194),
    [anon_sym_global] = ACTIONS(5194),
    [anon_sym_LPAREN_STAR] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5192),
    [anon_sym_DOLLARunit] = ACTIONS(5192),
  },
  [5125] = {
    [sym_simple_identifier] = ACTIONS(4594),
    [anon_sym_wire] = ACTIONS(4594),
    [anon_sym_tri] = ACTIONS(4594),
    [anon_sym_tri0] = ACTIONS(4594),
    [anon_sym_tri1] = ACTIONS(4594),
    [anon_sym_wand] = ACTIONS(4594),
    [anon_sym_triand] = ACTIONS(4594),
    [anon_sym_wor] = ACTIONS(4594),
    [anon_sym_trior] = ACTIONS(4594),
    [anon_sym_trireg] = ACTIONS(4594),
    [anon_sym_uwire] = ACTIONS(4594),
    [anon_sym_SEMI] = ACTIONS(4592),
    [anon_sym_extern] = ACTIONS(4594),
    [anon_sym_interface] = ACTIONS(4594),
    [anon_sym_checker] = ACTIONS(4594),
    [anon_sym_virtual] = ACTIONS(4594),
    [anon_sym_class] = ACTIONS(4594),
    [anon_sym_type] = ACTIONS(4594),
    [anon_sym_DOLLARfatal] = ACTIONS(4592),
    [anon_sym_DOLLARerror] = ACTIONS(4592),
    [anon_sym_DOLLARwarning] = ACTIONS(4592),
    [anon_sym_DOLLARinfo] = ACTIONS(4592),
    [anon_sym_default] = ACTIONS(4594),
    [anon_sym_clocking] = ACTIONS(4594),
    [anon_sym_defparam] = ACTIONS(4594),
    [anon_sym_bind] = ACTIONS(4594),
    [anon_sym_rand] = ACTIONS(4594),
    [anon_sym_const] = ACTIONS(4594),
    [anon_sym_function] = ACTIONS(4594),
    [anon_sym_static] = ACTIONS(4594),
    [anon_sym_constraint] = ACTIONS(4594),
    [anon_sym_if] = ACTIONS(4594),
    [anon_sym_else] = ACTIONS(4594),
    [anon_sym_LBRACK] = ACTIONS(4592),
    [anon_sym_localparam] = ACTIONS(4594),
    [anon_sym_parameter] = ACTIONS(4594),
    [anon_sym_var] = ACTIONS(4594),
    [anon_sym_import] = ACTIONS(4594),
    [anon_sym_export] = ACTIONS(4594),
    [anon_sym_genvar] = ACTIONS(4594),
    [anon_sym_interconnect] = ACTIONS(4594),
    [anon_sym_typedef] = ACTIONS(4594),
    [anon_sym_enum] = ACTIONS(4594),
    [anon_sym_struct] = ACTIONS(4594),
    [anon_sym_union] = ACTIONS(4594),
    [anon_sym_nettype] = ACTIONS(4594),
    [anon_sym_automatic] = ACTIONS(4594),
    [anon_sym_string] = ACTIONS(4594),
    [anon_sym_chandle] = ACTIONS(4594),
    [anon_sym_event] = ACTIONS(4594),
    [anon_sym_byte] = ACTIONS(4594),
    [anon_sym_shortint] = ACTIONS(4594),
    [anon_sym_int] = ACTIONS(4594),
    [anon_sym_longint] = ACTIONS(4594),
    [anon_sym_integer] = ACTIONS(4594),
    [anon_sym_time] = ACTIONS(4594),
    [anon_sym_bit] = ACTIONS(4594),
    [anon_sym_logic] = ACTIONS(4594),
    [anon_sym_reg] = ACTIONS(4594),
    [anon_sym_shortreal] = ACTIONS(4594),
    [anon_sym_real] = ACTIONS(4594),
    [anon_sym_realtime] = ACTIONS(4594),
    [anon_sym_supply0] = ACTIONS(4594),
    [anon_sym_supply1] = ACTIONS(4594),
    [anon_sym_signed] = ACTIONS(4594),
    [anon_sym_unsigned] = ACTIONS(4594),
    [anon_sym_task] = ACTIONS(4594),
    [anon_sym_assert] = ACTIONS(4594),
    [anon_sym_property] = ACTIONS(4594),
    [anon_sym_assume] = ACTIONS(4594),
    [anon_sym_cover] = ACTIONS(4594),
    [anon_sym_sequence] = ACTIONS(4594),
    [anon_sym_restrict] = ACTIONS(4594),
    [anon_sym_not] = ACTIONS(4594),
    [anon_sym_or] = ACTIONS(4594),
    [anon_sym_and] = ACTIONS(4594),
    [anon_sym_case] = ACTIONS(4594),
    [anon_sym_always] = ACTIONS(4594),
    [anon_sym_covergroup] = ACTIONS(4594),
    [anon_sym_end] = ACTIONS(4594),
    [anon_sym_let] = ACTIONS(4594),
    [anon_sym_pulldown] = ACTIONS(4594),
    [anon_sym_pullup] = ACTIONS(4594),
    [anon_sym_cmos] = ACTIONS(4594),
    [anon_sym_rcmos] = ACTIONS(4594),
    [anon_sym_bufif0] = ACTIONS(4594),
    [anon_sym_bufif1] = ACTIONS(4594),
    [anon_sym_notif0] = ACTIONS(4594),
    [anon_sym_notif1] = ACTIONS(4594),
    [anon_sym_nmos] = ACTIONS(4594),
    [anon_sym_pmos] = ACTIONS(4594),
    [anon_sym_rnmos] = ACTIONS(4594),
    [anon_sym_rpmos] = ACTIONS(4594),
    [anon_sym_nand] = ACTIONS(4594),
    [anon_sym_nor] = ACTIONS(4594),
    [anon_sym_xor] = ACTIONS(4594),
    [anon_sym_xnor] = ACTIONS(4594),
    [anon_sym_buf] = ACTIONS(4594),
    [anon_sym_tranif0] = ACTIONS(4594),
    [anon_sym_tranif1] = ACTIONS(4594),
    [anon_sym_rtranif1] = ACTIONS(4594),
    [anon_sym_rtranif0] = ACTIONS(4594),
    [anon_sym_tran] = ACTIONS(4594),
    [anon_sym_rtran] = ACTIONS(4594),
    [anon_sym_generate] = ACTIONS(4594),
    [anon_sym_for] = ACTIONS(4594),
    [anon_sym_initial] = ACTIONS(4594),
    [anon_sym_assign] = ACTIONS(4594),
    [anon_sym_alias] = ACTIONS(4594),
    [anon_sym_always_comb] = ACTIONS(4594),
    [anon_sym_always_latch] = ACTIONS(4594),
    [anon_sym_always_ff] = ACTIONS(4594),
    [anon_sym_final] = ACTIONS(4594),
    [anon_sym_global] = ACTIONS(4594),
    [anon_sym_LPAREN_STAR] = ACTIONS(4592),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4592),
    [anon_sym_DOLLARunit] = ACTIONS(4592),
  },
  [5126] = {
    [sym_simple_identifier] = ACTIONS(4668),
    [anon_sym_wire] = ACTIONS(4668),
    [anon_sym_tri] = ACTIONS(4668),
    [anon_sym_tri0] = ACTIONS(4668),
    [anon_sym_tri1] = ACTIONS(4668),
    [anon_sym_wand] = ACTIONS(4668),
    [anon_sym_triand] = ACTIONS(4668),
    [anon_sym_wor] = ACTIONS(4668),
    [anon_sym_trior] = ACTIONS(4668),
    [anon_sym_trireg] = ACTIONS(4668),
    [anon_sym_uwire] = ACTIONS(4668),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_extern] = ACTIONS(4668),
    [anon_sym_interface] = ACTIONS(4668),
    [anon_sym_checker] = ACTIONS(4668),
    [anon_sym_virtual] = ACTIONS(4668),
    [anon_sym_class] = ACTIONS(4668),
    [anon_sym_type] = ACTIONS(4668),
    [anon_sym_DOLLARfatal] = ACTIONS(4666),
    [anon_sym_DOLLARerror] = ACTIONS(4666),
    [anon_sym_DOLLARwarning] = ACTIONS(4666),
    [anon_sym_DOLLARinfo] = ACTIONS(4666),
    [anon_sym_default] = ACTIONS(4668),
    [anon_sym_clocking] = ACTIONS(4668),
    [anon_sym_defparam] = ACTIONS(4668),
    [anon_sym_bind] = ACTIONS(4668),
    [anon_sym_rand] = ACTIONS(4668),
    [anon_sym_const] = ACTIONS(4668),
    [anon_sym_function] = ACTIONS(4668),
    [anon_sym_static] = ACTIONS(4668),
    [anon_sym_constraint] = ACTIONS(4668),
    [anon_sym_if] = ACTIONS(4668),
    [anon_sym_else] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_localparam] = ACTIONS(4668),
    [anon_sym_parameter] = ACTIONS(4668),
    [anon_sym_var] = ACTIONS(4668),
    [anon_sym_import] = ACTIONS(4668),
    [anon_sym_export] = ACTIONS(4668),
    [anon_sym_genvar] = ACTIONS(4668),
    [anon_sym_interconnect] = ACTIONS(4668),
    [anon_sym_typedef] = ACTIONS(4668),
    [anon_sym_enum] = ACTIONS(4668),
    [anon_sym_struct] = ACTIONS(4668),
    [anon_sym_union] = ACTIONS(4668),
    [anon_sym_nettype] = ACTIONS(4668),
    [anon_sym_automatic] = ACTIONS(4668),
    [anon_sym_string] = ACTIONS(4668),
    [anon_sym_chandle] = ACTIONS(4668),
    [anon_sym_event] = ACTIONS(4668),
    [anon_sym_byte] = ACTIONS(4668),
    [anon_sym_shortint] = ACTIONS(4668),
    [anon_sym_int] = ACTIONS(4668),
    [anon_sym_longint] = ACTIONS(4668),
    [anon_sym_integer] = ACTIONS(4668),
    [anon_sym_time] = ACTIONS(4668),
    [anon_sym_bit] = ACTIONS(4668),
    [anon_sym_logic] = ACTIONS(4668),
    [anon_sym_reg] = ACTIONS(4668),
    [anon_sym_shortreal] = ACTIONS(4668),
    [anon_sym_real] = ACTIONS(4668),
    [anon_sym_realtime] = ACTIONS(4668),
    [anon_sym_supply0] = ACTIONS(4668),
    [anon_sym_supply1] = ACTIONS(4668),
    [anon_sym_signed] = ACTIONS(4668),
    [anon_sym_unsigned] = ACTIONS(4668),
    [anon_sym_task] = ACTIONS(4668),
    [anon_sym_assert] = ACTIONS(4668),
    [anon_sym_property] = ACTIONS(4668),
    [anon_sym_assume] = ACTIONS(4668),
    [anon_sym_cover] = ACTIONS(4668),
    [anon_sym_sequence] = ACTIONS(4668),
    [anon_sym_restrict] = ACTIONS(4668),
    [anon_sym_not] = ACTIONS(4668),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_and] = ACTIONS(4668),
    [anon_sym_case] = ACTIONS(4668),
    [anon_sym_always] = ACTIONS(4668),
    [anon_sym_covergroup] = ACTIONS(4668),
    [anon_sym_let] = ACTIONS(4668),
    [anon_sym_pulldown] = ACTIONS(4668),
    [anon_sym_pullup] = ACTIONS(4668),
    [anon_sym_cmos] = ACTIONS(4668),
    [anon_sym_rcmos] = ACTIONS(4668),
    [anon_sym_bufif0] = ACTIONS(4668),
    [anon_sym_bufif1] = ACTIONS(4668),
    [anon_sym_notif0] = ACTIONS(4668),
    [anon_sym_notif1] = ACTIONS(4668),
    [anon_sym_nmos] = ACTIONS(4668),
    [anon_sym_pmos] = ACTIONS(4668),
    [anon_sym_rnmos] = ACTIONS(4668),
    [anon_sym_rpmos] = ACTIONS(4668),
    [anon_sym_nand] = ACTIONS(4668),
    [anon_sym_nor] = ACTIONS(4668),
    [anon_sym_xor] = ACTIONS(4668),
    [anon_sym_xnor] = ACTIONS(4668),
    [anon_sym_buf] = ACTIONS(4668),
    [anon_sym_tranif0] = ACTIONS(4668),
    [anon_sym_tranif1] = ACTIONS(4668),
    [anon_sym_rtranif1] = ACTIONS(4668),
    [anon_sym_rtranif0] = ACTIONS(4668),
    [anon_sym_tran] = ACTIONS(4668),
    [anon_sym_rtran] = ACTIONS(4668),
    [anon_sym_generate] = ACTIONS(4668),
    [anon_sym_endgenerate] = ACTIONS(4668),
    [anon_sym_for] = ACTIONS(4668),
    [anon_sym_initial] = ACTIONS(4668),
    [anon_sym_assign] = ACTIONS(4668),
    [anon_sym_alias] = ACTIONS(4668),
    [anon_sym_always_comb] = ACTIONS(4668),
    [anon_sym_always_latch] = ACTIONS(4668),
    [anon_sym_always_ff] = ACTIONS(4668),
    [anon_sym_final] = ACTIONS(4668),
    [anon_sym_global] = ACTIONS(4668),
    [anon_sym_LPAREN_STAR] = ACTIONS(4666),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4666),
    [anon_sym_DOLLARunit] = ACTIONS(4666),
  },
  [5127] = {
    [sym_simple_identifier] = ACTIONS(6569),
    [anon_sym_wire] = ACTIONS(6569),
    [anon_sym_tri] = ACTIONS(6569),
    [anon_sym_tri0] = ACTIONS(6569),
    [anon_sym_tri1] = ACTIONS(6569),
    [anon_sym_wand] = ACTIONS(6569),
    [anon_sym_triand] = ACTIONS(6569),
    [anon_sym_wor] = ACTIONS(6569),
    [anon_sym_trior] = ACTIONS(6569),
    [anon_sym_trireg] = ACTIONS(6569),
    [anon_sym_uwire] = ACTIONS(6569),
    [anon_sym_SEMI] = ACTIONS(6571),
    [anon_sym_extern] = ACTIONS(6569),
    [anon_sym_interface] = ACTIONS(6569),
    [anon_sym_checker] = ACTIONS(6569),
    [anon_sym_virtual] = ACTIONS(6569),
    [anon_sym_class] = ACTIONS(6569),
    [anon_sym_type] = ACTIONS(6569),
    [anon_sym_DOLLARfatal] = ACTIONS(6571),
    [anon_sym_DOLLARerror] = ACTIONS(6571),
    [anon_sym_DOLLARwarning] = ACTIONS(6571),
    [anon_sym_DOLLARinfo] = ACTIONS(6571),
    [anon_sym_default] = ACTIONS(6569),
    [anon_sym_clocking] = ACTIONS(6569),
    [anon_sym_defparam] = ACTIONS(6569),
    [anon_sym_bind] = ACTIONS(6569),
    [anon_sym_rand] = ACTIONS(6569),
    [anon_sym_const] = ACTIONS(6569),
    [anon_sym_function] = ACTIONS(6569),
    [anon_sym_static] = ACTIONS(6569),
    [anon_sym_constraint] = ACTIONS(6569),
    [anon_sym_if] = ACTIONS(6569),
    [anon_sym_else] = ACTIONS(6569),
    [anon_sym_LBRACK] = ACTIONS(6571),
    [anon_sym_localparam] = ACTIONS(6569),
    [anon_sym_parameter] = ACTIONS(6569),
    [anon_sym_var] = ACTIONS(6569),
    [anon_sym_import] = ACTIONS(6569),
    [anon_sym_export] = ACTIONS(6569),
    [anon_sym_genvar] = ACTIONS(6569),
    [anon_sym_interconnect] = ACTIONS(6569),
    [anon_sym_typedef] = ACTIONS(6569),
    [anon_sym_enum] = ACTIONS(6569),
    [anon_sym_struct] = ACTIONS(6569),
    [anon_sym_union] = ACTIONS(6569),
    [anon_sym_nettype] = ACTIONS(6569),
    [anon_sym_automatic] = ACTIONS(6569),
    [anon_sym_string] = ACTIONS(6569),
    [anon_sym_chandle] = ACTIONS(6569),
    [anon_sym_event] = ACTIONS(6569),
    [anon_sym_byte] = ACTIONS(6569),
    [anon_sym_shortint] = ACTIONS(6569),
    [anon_sym_int] = ACTIONS(6569),
    [anon_sym_longint] = ACTIONS(6569),
    [anon_sym_integer] = ACTIONS(6569),
    [anon_sym_time] = ACTIONS(6569),
    [anon_sym_bit] = ACTIONS(6569),
    [anon_sym_logic] = ACTIONS(6569),
    [anon_sym_reg] = ACTIONS(6569),
    [anon_sym_shortreal] = ACTIONS(6569),
    [anon_sym_real] = ACTIONS(6569),
    [anon_sym_realtime] = ACTIONS(6569),
    [anon_sym_supply0] = ACTIONS(6569),
    [anon_sym_supply1] = ACTIONS(6569),
    [anon_sym_signed] = ACTIONS(6569),
    [anon_sym_unsigned] = ACTIONS(6569),
    [anon_sym_task] = ACTIONS(6569),
    [anon_sym_assert] = ACTIONS(6569),
    [anon_sym_property] = ACTIONS(6569),
    [anon_sym_assume] = ACTIONS(6569),
    [anon_sym_cover] = ACTIONS(6569),
    [anon_sym_sequence] = ACTIONS(6569),
    [anon_sym_restrict] = ACTIONS(6569),
    [anon_sym_not] = ACTIONS(6569),
    [anon_sym_or] = ACTIONS(6569),
    [anon_sym_and] = ACTIONS(6569),
    [anon_sym_case] = ACTIONS(6569),
    [anon_sym_always] = ACTIONS(6569),
    [anon_sym_covergroup] = ACTIONS(6569),
    [anon_sym_let] = ACTIONS(6569),
    [anon_sym_pulldown] = ACTIONS(6569),
    [anon_sym_pullup] = ACTIONS(6569),
    [anon_sym_cmos] = ACTIONS(6569),
    [anon_sym_rcmos] = ACTIONS(6569),
    [anon_sym_bufif0] = ACTIONS(6569),
    [anon_sym_bufif1] = ACTIONS(6569),
    [anon_sym_notif0] = ACTIONS(6569),
    [anon_sym_notif1] = ACTIONS(6569),
    [anon_sym_nmos] = ACTIONS(6569),
    [anon_sym_pmos] = ACTIONS(6569),
    [anon_sym_rnmos] = ACTIONS(6569),
    [anon_sym_rpmos] = ACTIONS(6569),
    [anon_sym_nand] = ACTIONS(6569),
    [anon_sym_nor] = ACTIONS(6569),
    [anon_sym_xor] = ACTIONS(6569),
    [anon_sym_xnor] = ACTIONS(6569),
    [anon_sym_buf] = ACTIONS(6569),
    [anon_sym_tranif0] = ACTIONS(6569),
    [anon_sym_tranif1] = ACTIONS(6569),
    [anon_sym_rtranif1] = ACTIONS(6569),
    [anon_sym_rtranif0] = ACTIONS(6569),
    [anon_sym_tran] = ACTIONS(6569),
    [anon_sym_rtran] = ACTIONS(6569),
    [anon_sym_generate] = ACTIONS(6569),
    [anon_sym_endgenerate] = ACTIONS(6569),
    [anon_sym_for] = ACTIONS(6569),
    [anon_sym_initial] = ACTIONS(6569),
    [anon_sym_assign] = ACTIONS(6569),
    [anon_sym_alias] = ACTIONS(6569),
    [anon_sym_always_comb] = ACTIONS(6569),
    [anon_sym_always_latch] = ACTIONS(6569),
    [anon_sym_always_ff] = ACTIONS(6569),
    [anon_sym_final] = ACTIONS(6569),
    [anon_sym_global] = ACTIONS(6569),
    [anon_sym_LPAREN_STAR] = ACTIONS(6571),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6571),
    [anon_sym_DOLLARunit] = ACTIONS(6571),
  },
  [5128] = {
    [sym_simple_identifier] = ACTIONS(4224),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_rand] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_end] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [5129] = {
    [sym_simple_identifier] = ACTIONS(4964),
    [anon_sym_wire] = ACTIONS(4964),
    [anon_sym_tri] = ACTIONS(4964),
    [anon_sym_tri0] = ACTIONS(4964),
    [anon_sym_tri1] = ACTIONS(4964),
    [anon_sym_wand] = ACTIONS(4964),
    [anon_sym_triand] = ACTIONS(4964),
    [anon_sym_wor] = ACTIONS(4964),
    [anon_sym_trior] = ACTIONS(4964),
    [anon_sym_trireg] = ACTIONS(4964),
    [anon_sym_uwire] = ACTIONS(4964),
    [anon_sym_SEMI] = ACTIONS(4962),
    [anon_sym_extern] = ACTIONS(4964),
    [anon_sym_interface] = ACTIONS(4964),
    [anon_sym_checker] = ACTIONS(4964),
    [anon_sym_virtual] = ACTIONS(4964),
    [anon_sym_class] = ACTIONS(4964),
    [anon_sym_type] = ACTIONS(4964),
    [anon_sym_DOLLARfatal] = ACTIONS(4962),
    [anon_sym_DOLLARerror] = ACTIONS(4962),
    [anon_sym_DOLLARwarning] = ACTIONS(4962),
    [anon_sym_DOLLARinfo] = ACTIONS(4962),
    [anon_sym_default] = ACTIONS(4964),
    [anon_sym_clocking] = ACTIONS(4964),
    [anon_sym_defparam] = ACTIONS(4964),
    [anon_sym_bind] = ACTIONS(4964),
    [anon_sym_rand] = ACTIONS(4964),
    [anon_sym_const] = ACTIONS(4964),
    [anon_sym_function] = ACTIONS(4964),
    [anon_sym_static] = ACTIONS(4964),
    [anon_sym_constraint] = ACTIONS(4964),
    [anon_sym_if] = ACTIONS(4964),
    [anon_sym_else] = ACTIONS(4964),
    [anon_sym_LBRACK] = ACTIONS(4962),
    [anon_sym_localparam] = ACTIONS(4964),
    [anon_sym_parameter] = ACTIONS(4964),
    [anon_sym_var] = ACTIONS(4964),
    [anon_sym_import] = ACTIONS(4964),
    [anon_sym_export] = ACTIONS(4964),
    [anon_sym_genvar] = ACTIONS(4964),
    [anon_sym_interconnect] = ACTIONS(4964),
    [anon_sym_typedef] = ACTIONS(4964),
    [anon_sym_enum] = ACTIONS(4964),
    [anon_sym_struct] = ACTIONS(4964),
    [anon_sym_union] = ACTIONS(4964),
    [anon_sym_nettype] = ACTIONS(4964),
    [anon_sym_automatic] = ACTIONS(4964),
    [anon_sym_string] = ACTIONS(4964),
    [anon_sym_chandle] = ACTIONS(4964),
    [anon_sym_event] = ACTIONS(4964),
    [anon_sym_byte] = ACTIONS(4964),
    [anon_sym_shortint] = ACTIONS(4964),
    [anon_sym_int] = ACTIONS(4964),
    [anon_sym_longint] = ACTIONS(4964),
    [anon_sym_integer] = ACTIONS(4964),
    [anon_sym_time] = ACTIONS(4964),
    [anon_sym_bit] = ACTIONS(4964),
    [anon_sym_logic] = ACTIONS(4964),
    [anon_sym_reg] = ACTIONS(4964),
    [anon_sym_shortreal] = ACTIONS(4964),
    [anon_sym_real] = ACTIONS(4964),
    [anon_sym_realtime] = ACTIONS(4964),
    [anon_sym_supply0] = ACTIONS(4964),
    [anon_sym_supply1] = ACTIONS(4964),
    [anon_sym_signed] = ACTIONS(4964),
    [anon_sym_unsigned] = ACTIONS(4964),
    [anon_sym_task] = ACTIONS(4964),
    [anon_sym_assert] = ACTIONS(4964),
    [anon_sym_property] = ACTIONS(4964),
    [anon_sym_assume] = ACTIONS(4964),
    [anon_sym_cover] = ACTIONS(4964),
    [anon_sym_sequence] = ACTIONS(4964),
    [anon_sym_restrict] = ACTIONS(4964),
    [anon_sym_not] = ACTIONS(4964),
    [anon_sym_or] = ACTIONS(4964),
    [anon_sym_and] = ACTIONS(4964),
    [anon_sym_case] = ACTIONS(4964),
    [anon_sym_always] = ACTIONS(4964),
    [anon_sym_covergroup] = ACTIONS(4964),
    [anon_sym_end] = ACTIONS(4964),
    [anon_sym_let] = ACTIONS(4964),
    [anon_sym_pulldown] = ACTIONS(4964),
    [anon_sym_pullup] = ACTIONS(4964),
    [anon_sym_cmos] = ACTIONS(4964),
    [anon_sym_rcmos] = ACTIONS(4964),
    [anon_sym_bufif0] = ACTIONS(4964),
    [anon_sym_bufif1] = ACTIONS(4964),
    [anon_sym_notif0] = ACTIONS(4964),
    [anon_sym_notif1] = ACTIONS(4964),
    [anon_sym_nmos] = ACTIONS(4964),
    [anon_sym_pmos] = ACTIONS(4964),
    [anon_sym_rnmos] = ACTIONS(4964),
    [anon_sym_rpmos] = ACTIONS(4964),
    [anon_sym_nand] = ACTIONS(4964),
    [anon_sym_nor] = ACTIONS(4964),
    [anon_sym_xor] = ACTIONS(4964),
    [anon_sym_xnor] = ACTIONS(4964),
    [anon_sym_buf] = ACTIONS(4964),
    [anon_sym_tranif0] = ACTIONS(4964),
    [anon_sym_tranif1] = ACTIONS(4964),
    [anon_sym_rtranif1] = ACTIONS(4964),
    [anon_sym_rtranif0] = ACTIONS(4964),
    [anon_sym_tran] = ACTIONS(4964),
    [anon_sym_rtran] = ACTIONS(4964),
    [anon_sym_generate] = ACTIONS(4964),
    [anon_sym_for] = ACTIONS(4964),
    [anon_sym_initial] = ACTIONS(4964),
    [anon_sym_assign] = ACTIONS(4964),
    [anon_sym_alias] = ACTIONS(4964),
    [anon_sym_always_comb] = ACTIONS(4964),
    [anon_sym_always_latch] = ACTIONS(4964),
    [anon_sym_always_ff] = ACTIONS(4964),
    [anon_sym_final] = ACTIONS(4964),
    [anon_sym_global] = ACTIONS(4964),
    [anon_sym_LPAREN_STAR] = ACTIONS(4962),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4962),
    [anon_sym_DOLLARunit] = ACTIONS(4962),
  },
  [5130] = {
    [sym_simple_identifier] = ACTIONS(6257),
    [anon_sym_wire] = ACTIONS(6257),
    [anon_sym_tri] = ACTIONS(6257),
    [anon_sym_tri0] = ACTIONS(6257),
    [anon_sym_tri1] = ACTIONS(6257),
    [anon_sym_wand] = ACTIONS(6257),
    [anon_sym_triand] = ACTIONS(6257),
    [anon_sym_wor] = ACTIONS(6257),
    [anon_sym_trior] = ACTIONS(6257),
    [anon_sym_trireg] = ACTIONS(6257),
    [anon_sym_uwire] = ACTIONS(6257),
    [anon_sym_SEMI] = ACTIONS(6259),
    [anon_sym_extern] = ACTIONS(6257),
    [anon_sym_interface] = ACTIONS(6257),
    [anon_sym_checker] = ACTIONS(6257),
    [anon_sym_virtual] = ACTIONS(6257),
    [anon_sym_class] = ACTIONS(6257),
    [anon_sym_type] = ACTIONS(6257),
    [anon_sym_DOLLARfatal] = ACTIONS(6259),
    [anon_sym_DOLLARerror] = ACTIONS(6259),
    [anon_sym_DOLLARwarning] = ACTIONS(6259),
    [anon_sym_DOLLARinfo] = ACTIONS(6259),
    [anon_sym_default] = ACTIONS(6257),
    [anon_sym_clocking] = ACTIONS(6257),
    [anon_sym_defparam] = ACTIONS(6257),
    [anon_sym_bind] = ACTIONS(6257),
    [anon_sym_rand] = ACTIONS(6257),
    [anon_sym_const] = ACTIONS(6257),
    [anon_sym_function] = ACTIONS(6257),
    [anon_sym_static] = ACTIONS(6257),
    [anon_sym_constraint] = ACTIONS(6257),
    [anon_sym_if] = ACTIONS(6257),
    [anon_sym_else] = ACTIONS(6257),
    [anon_sym_LBRACK] = ACTIONS(6259),
    [anon_sym_localparam] = ACTIONS(6257),
    [anon_sym_parameter] = ACTIONS(6257),
    [anon_sym_var] = ACTIONS(6257),
    [anon_sym_import] = ACTIONS(6257),
    [anon_sym_export] = ACTIONS(6257),
    [anon_sym_genvar] = ACTIONS(6257),
    [anon_sym_interconnect] = ACTIONS(6257),
    [anon_sym_typedef] = ACTIONS(6257),
    [anon_sym_enum] = ACTIONS(6257),
    [anon_sym_struct] = ACTIONS(6257),
    [anon_sym_union] = ACTIONS(6257),
    [anon_sym_nettype] = ACTIONS(6257),
    [anon_sym_automatic] = ACTIONS(6257),
    [anon_sym_string] = ACTIONS(6257),
    [anon_sym_chandle] = ACTIONS(6257),
    [anon_sym_event] = ACTIONS(6257),
    [anon_sym_byte] = ACTIONS(6257),
    [anon_sym_shortint] = ACTIONS(6257),
    [anon_sym_int] = ACTIONS(6257),
    [anon_sym_longint] = ACTIONS(6257),
    [anon_sym_integer] = ACTIONS(6257),
    [anon_sym_time] = ACTIONS(6257),
    [anon_sym_bit] = ACTIONS(6257),
    [anon_sym_logic] = ACTIONS(6257),
    [anon_sym_reg] = ACTIONS(6257),
    [anon_sym_shortreal] = ACTIONS(6257),
    [anon_sym_real] = ACTIONS(6257),
    [anon_sym_realtime] = ACTIONS(6257),
    [anon_sym_supply0] = ACTIONS(6257),
    [anon_sym_supply1] = ACTIONS(6257),
    [anon_sym_signed] = ACTIONS(6257),
    [anon_sym_unsigned] = ACTIONS(6257),
    [anon_sym_task] = ACTIONS(6257),
    [anon_sym_assert] = ACTIONS(6257),
    [anon_sym_property] = ACTIONS(6257),
    [anon_sym_assume] = ACTIONS(6257),
    [anon_sym_cover] = ACTIONS(6257),
    [anon_sym_sequence] = ACTIONS(6257),
    [anon_sym_restrict] = ACTIONS(6257),
    [anon_sym_not] = ACTIONS(6257),
    [anon_sym_or] = ACTIONS(6257),
    [anon_sym_and] = ACTIONS(6257),
    [anon_sym_case] = ACTIONS(6257),
    [anon_sym_always] = ACTIONS(6257),
    [anon_sym_covergroup] = ACTIONS(6257),
    [anon_sym_let] = ACTIONS(6257),
    [anon_sym_pulldown] = ACTIONS(6257),
    [anon_sym_pullup] = ACTIONS(6257),
    [anon_sym_cmos] = ACTIONS(6257),
    [anon_sym_rcmos] = ACTIONS(6257),
    [anon_sym_bufif0] = ACTIONS(6257),
    [anon_sym_bufif1] = ACTIONS(6257),
    [anon_sym_notif0] = ACTIONS(6257),
    [anon_sym_notif1] = ACTIONS(6257),
    [anon_sym_nmos] = ACTIONS(6257),
    [anon_sym_pmos] = ACTIONS(6257),
    [anon_sym_rnmos] = ACTIONS(6257),
    [anon_sym_rpmos] = ACTIONS(6257),
    [anon_sym_nand] = ACTIONS(6257),
    [anon_sym_nor] = ACTIONS(6257),
    [anon_sym_xor] = ACTIONS(6257),
    [anon_sym_xnor] = ACTIONS(6257),
    [anon_sym_buf] = ACTIONS(6257),
    [anon_sym_tranif0] = ACTIONS(6257),
    [anon_sym_tranif1] = ACTIONS(6257),
    [anon_sym_rtranif1] = ACTIONS(6257),
    [anon_sym_rtranif0] = ACTIONS(6257),
    [anon_sym_tran] = ACTIONS(6257),
    [anon_sym_rtran] = ACTIONS(6257),
    [anon_sym_generate] = ACTIONS(6257),
    [anon_sym_endgenerate] = ACTIONS(6257),
    [anon_sym_for] = ACTIONS(6257),
    [anon_sym_initial] = ACTIONS(6257),
    [anon_sym_assign] = ACTIONS(6257),
    [anon_sym_alias] = ACTIONS(6257),
    [anon_sym_always_comb] = ACTIONS(6257),
    [anon_sym_always_latch] = ACTIONS(6257),
    [anon_sym_always_ff] = ACTIONS(6257),
    [anon_sym_final] = ACTIONS(6257),
    [anon_sym_global] = ACTIONS(6257),
    [anon_sym_LPAREN_STAR] = ACTIONS(6259),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6259),
    [anon_sym_DOLLARunit] = ACTIONS(6259),
  },
  [5131] = {
    [sym_simple_identifier] = ACTIONS(4206),
    [anon_sym_wire] = ACTIONS(4206),
    [anon_sym_tri] = ACTIONS(4206),
    [anon_sym_tri0] = ACTIONS(4206),
    [anon_sym_tri1] = ACTIONS(4206),
    [anon_sym_wand] = ACTIONS(4206),
    [anon_sym_triand] = ACTIONS(4206),
    [anon_sym_wor] = ACTIONS(4206),
    [anon_sym_trior] = ACTIONS(4206),
    [anon_sym_trireg] = ACTIONS(4206),
    [anon_sym_uwire] = ACTIONS(4206),
    [anon_sym_SEMI] = ACTIONS(4204),
    [anon_sym_extern] = ACTIONS(4206),
    [anon_sym_interface] = ACTIONS(4206),
    [anon_sym_checker] = ACTIONS(4206),
    [anon_sym_virtual] = ACTIONS(4206),
    [anon_sym_class] = ACTIONS(4206),
    [anon_sym_type] = ACTIONS(4206),
    [anon_sym_DOLLARfatal] = ACTIONS(4204),
    [anon_sym_DOLLARerror] = ACTIONS(4204),
    [anon_sym_DOLLARwarning] = ACTIONS(4204),
    [anon_sym_DOLLARinfo] = ACTIONS(4204),
    [anon_sym_default] = ACTIONS(4206),
    [anon_sym_clocking] = ACTIONS(4206),
    [anon_sym_defparam] = ACTIONS(4206),
    [anon_sym_bind] = ACTIONS(4206),
    [anon_sym_rand] = ACTIONS(4206),
    [anon_sym_const] = ACTIONS(4206),
    [anon_sym_function] = ACTIONS(4206),
    [anon_sym_static] = ACTIONS(4206),
    [anon_sym_constraint] = ACTIONS(4206),
    [anon_sym_if] = ACTIONS(4206),
    [anon_sym_else] = ACTIONS(4206),
    [anon_sym_LBRACK] = ACTIONS(4204),
    [anon_sym_localparam] = ACTIONS(4206),
    [anon_sym_parameter] = ACTIONS(4206),
    [anon_sym_var] = ACTIONS(4206),
    [anon_sym_import] = ACTIONS(4206),
    [anon_sym_export] = ACTIONS(4206),
    [anon_sym_genvar] = ACTIONS(4206),
    [anon_sym_interconnect] = ACTIONS(4206),
    [anon_sym_typedef] = ACTIONS(4206),
    [anon_sym_enum] = ACTIONS(4206),
    [anon_sym_struct] = ACTIONS(4206),
    [anon_sym_union] = ACTIONS(4206),
    [anon_sym_nettype] = ACTIONS(4206),
    [anon_sym_automatic] = ACTIONS(4206),
    [anon_sym_string] = ACTIONS(4206),
    [anon_sym_chandle] = ACTIONS(4206),
    [anon_sym_event] = ACTIONS(4206),
    [anon_sym_byte] = ACTIONS(4206),
    [anon_sym_shortint] = ACTIONS(4206),
    [anon_sym_int] = ACTIONS(4206),
    [anon_sym_longint] = ACTIONS(4206),
    [anon_sym_integer] = ACTIONS(4206),
    [anon_sym_time] = ACTIONS(4206),
    [anon_sym_bit] = ACTIONS(4206),
    [anon_sym_logic] = ACTIONS(4206),
    [anon_sym_reg] = ACTIONS(4206),
    [anon_sym_shortreal] = ACTIONS(4206),
    [anon_sym_real] = ACTIONS(4206),
    [anon_sym_realtime] = ACTIONS(4206),
    [anon_sym_supply0] = ACTIONS(4206),
    [anon_sym_supply1] = ACTIONS(4206),
    [anon_sym_signed] = ACTIONS(4206),
    [anon_sym_unsigned] = ACTIONS(4206),
    [anon_sym_task] = ACTIONS(4206),
    [anon_sym_assert] = ACTIONS(4206),
    [anon_sym_property] = ACTIONS(4206),
    [anon_sym_assume] = ACTIONS(4206),
    [anon_sym_cover] = ACTIONS(4206),
    [anon_sym_sequence] = ACTIONS(4206),
    [anon_sym_restrict] = ACTIONS(4206),
    [anon_sym_not] = ACTIONS(4206),
    [anon_sym_or] = ACTIONS(4206),
    [anon_sym_and] = ACTIONS(4206),
    [anon_sym_case] = ACTIONS(4206),
    [anon_sym_always] = ACTIONS(4206),
    [anon_sym_covergroup] = ACTIONS(4206),
    [anon_sym_let] = ACTIONS(4206),
    [anon_sym_pulldown] = ACTIONS(4206),
    [anon_sym_pullup] = ACTIONS(4206),
    [anon_sym_cmos] = ACTIONS(4206),
    [anon_sym_rcmos] = ACTIONS(4206),
    [anon_sym_bufif0] = ACTIONS(4206),
    [anon_sym_bufif1] = ACTIONS(4206),
    [anon_sym_notif0] = ACTIONS(4206),
    [anon_sym_notif1] = ACTIONS(4206),
    [anon_sym_nmos] = ACTIONS(4206),
    [anon_sym_pmos] = ACTIONS(4206),
    [anon_sym_rnmos] = ACTIONS(4206),
    [anon_sym_rpmos] = ACTIONS(4206),
    [anon_sym_nand] = ACTIONS(4206),
    [anon_sym_nor] = ACTIONS(4206),
    [anon_sym_xor] = ACTIONS(4206),
    [anon_sym_xnor] = ACTIONS(4206),
    [anon_sym_buf] = ACTIONS(4206),
    [anon_sym_tranif0] = ACTIONS(4206),
    [anon_sym_tranif1] = ACTIONS(4206),
    [anon_sym_rtranif1] = ACTIONS(4206),
    [anon_sym_rtranif0] = ACTIONS(4206),
    [anon_sym_tran] = ACTIONS(4206),
    [anon_sym_rtran] = ACTIONS(4206),
    [anon_sym_generate] = ACTIONS(4206),
    [anon_sym_endgenerate] = ACTIONS(4206),
    [anon_sym_for] = ACTIONS(4206),
    [anon_sym_initial] = ACTIONS(4206),
    [anon_sym_assign] = ACTIONS(4206),
    [anon_sym_alias] = ACTIONS(4206),
    [anon_sym_always_comb] = ACTIONS(4206),
    [anon_sym_always_latch] = ACTIONS(4206),
    [anon_sym_always_ff] = ACTIONS(4206),
    [anon_sym_final] = ACTIONS(4206),
    [anon_sym_global] = ACTIONS(4206),
    [anon_sym_LPAREN_STAR] = ACTIONS(4204),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4204),
    [anon_sym_DOLLARunit] = ACTIONS(4204),
  },
  [5132] = {
    [sym_simple_identifier] = ACTIONS(4224),
    [anon_sym_wire] = ACTIONS(4224),
    [anon_sym_tri] = ACTIONS(4224),
    [anon_sym_tri0] = ACTIONS(4224),
    [anon_sym_tri1] = ACTIONS(4224),
    [anon_sym_wand] = ACTIONS(4224),
    [anon_sym_triand] = ACTIONS(4224),
    [anon_sym_wor] = ACTIONS(4224),
    [anon_sym_trior] = ACTIONS(4224),
    [anon_sym_trireg] = ACTIONS(4224),
    [anon_sym_uwire] = ACTIONS(4224),
    [anon_sym_SEMI] = ACTIONS(4222),
    [anon_sym_extern] = ACTIONS(4224),
    [anon_sym_interface] = ACTIONS(4224),
    [anon_sym_checker] = ACTIONS(4224),
    [anon_sym_virtual] = ACTIONS(4224),
    [anon_sym_class] = ACTIONS(4224),
    [anon_sym_type] = ACTIONS(4224),
    [anon_sym_DOLLARfatal] = ACTIONS(4222),
    [anon_sym_DOLLARerror] = ACTIONS(4222),
    [anon_sym_DOLLARwarning] = ACTIONS(4222),
    [anon_sym_DOLLARinfo] = ACTIONS(4222),
    [anon_sym_default] = ACTIONS(4224),
    [anon_sym_clocking] = ACTIONS(4224),
    [anon_sym_defparam] = ACTIONS(4224),
    [anon_sym_bind] = ACTIONS(4224),
    [anon_sym_rand] = ACTIONS(4224),
    [anon_sym_const] = ACTIONS(4224),
    [anon_sym_function] = ACTIONS(4224),
    [anon_sym_static] = ACTIONS(4224),
    [anon_sym_constraint] = ACTIONS(4224),
    [anon_sym_if] = ACTIONS(4224),
    [anon_sym_else] = ACTIONS(4224),
    [anon_sym_LBRACK] = ACTIONS(4222),
    [anon_sym_localparam] = ACTIONS(4224),
    [anon_sym_parameter] = ACTIONS(4224),
    [anon_sym_var] = ACTIONS(4224),
    [anon_sym_import] = ACTIONS(4224),
    [anon_sym_export] = ACTIONS(4224),
    [anon_sym_genvar] = ACTIONS(4224),
    [anon_sym_interconnect] = ACTIONS(4224),
    [anon_sym_typedef] = ACTIONS(4224),
    [anon_sym_enum] = ACTIONS(4224),
    [anon_sym_struct] = ACTIONS(4224),
    [anon_sym_union] = ACTIONS(4224),
    [anon_sym_nettype] = ACTIONS(4224),
    [anon_sym_automatic] = ACTIONS(4224),
    [anon_sym_string] = ACTIONS(4224),
    [anon_sym_chandle] = ACTIONS(4224),
    [anon_sym_event] = ACTIONS(4224),
    [anon_sym_byte] = ACTIONS(4224),
    [anon_sym_shortint] = ACTIONS(4224),
    [anon_sym_int] = ACTIONS(4224),
    [anon_sym_longint] = ACTIONS(4224),
    [anon_sym_integer] = ACTIONS(4224),
    [anon_sym_time] = ACTIONS(4224),
    [anon_sym_bit] = ACTIONS(4224),
    [anon_sym_logic] = ACTIONS(4224),
    [anon_sym_reg] = ACTIONS(4224),
    [anon_sym_shortreal] = ACTIONS(4224),
    [anon_sym_real] = ACTIONS(4224),
    [anon_sym_realtime] = ACTIONS(4224),
    [anon_sym_supply0] = ACTIONS(4224),
    [anon_sym_supply1] = ACTIONS(4224),
    [anon_sym_signed] = ACTIONS(4224),
    [anon_sym_unsigned] = ACTIONS(4224),
    [anon_sym_task] = ACTIONS(4224),
    [anon_sym_assert] = ACTIONS(4224),
    [anon_sym_property] = ACTIONS(4224),
    [anon_sym_assume] = ACTIONS(4224),
    [anon_sym_cover] = ACTIONS(4224),
    [anon_sym_sequence] = ACTIONS(4224),
    [anon_sym_restrict] = ACTIONS(4224),
    [anon_sym_not] = ACTIONS(4224),
    [anon_sym_or] = ACTIONS(4224),
    [anon_sym_and] = ACTIONS(4224),
    [anon_sym_case] = ACTIONS(4224),
    [anon_sym_always] = ACTIONS(4224),
    [anon_sym_covergroup] = ACTIONS(4224),
    [anon_sym_let] = ACTIONS(4224),
    [anon_sym_pulldown] = ACTIONS(4224),
    [anon_sym_pullup] = ACTIONS(4224),
    [anon_sym_cmos] = ACTIONS(4224),
    [anon_sym_rcmos] = ACTIONS(4224),
    [anon_sym_bufif0] = ACTIONS(4224),
    [anon_sym_bufif1] = ACTIONS(4224),
    [anon_sym_notif0] = ACTIONS(4224),
    [anon_sym_notif1] = ACTIONS(4224),
    [anon_sym_nmos] = ACTIONS(4224),
    [anon_sym_pmos] = ACTIONS(4224),
    [anon_sym_rnmos] = ACTIONS(4224),
    [anon_sym_rpmos] = ACTIONS(4224),
    [anon_sym_nand] = ACTIONS(4224),
    [anon_sym_nor] = ACTIONS(4224),
    [anon_sym_xor] = ACTIONS(4224),
    [anon_sym_xnor] = ACTIONS(4224),
    [anon_sym_buf] = ACTIONS(4224),
    [anon_sym_tranif0] = ACTIONS(4224),
    [anon_sym_tranif1] = ACTIONS(4224),
    [anon_sym_rtranif1] = ACTIONS(4224),
    [anon_sym_rtranif0] = ACTIONS(4224),
    [anon_sym_tran] = ACTIONS(4224),
    [anon_sym_rtran] = ACTIONS(4224),
    [anon_sym_generate] = ACTIONS(4224),
    [anon_sym_endgenerate] = ACTIONS(4224),
    [anon_sym_for] = ACTIONS(4224),
    [anon_sym_initial] = ACTIONS(4224),
    [anon_sym_assign] = ACTIONS(4224),
    [anon_sym_alias] = ACTIONS(4224),
    [anon_sym_always_comb] = ACTIONS(4224),
    [anon_sym_always_latch] = ACTIONS(4224),
    [anon_sym_always_ff] = ACTIONS(4224),
    [anon_sym_final] = ACTIONS(4224),
    [anon_sym_global] = ACTIONS(4224),
    [anon_sym_LPAREN_STAR] = ACTIONS(4222),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4222),
    [anon_sym_DOLLARunit] = ACTIONS(4222),
  },
  [5133] = {
    [sym_simple_identifier] = ACTIONS(4128),
    [anon_sym_wire] = ACTIONS(4128),
    [anon_sym_tri] = ACTIONS(4128),
    [anon_sym_tri0] = ACTIONS(4128),
    [anon_sym_tri1] = ACTIONS(4128),
    [anon_sym_wand] = ACTIONS(4128),
    [anon_sym_triand] = ACTIONS(4128),
    [anon_sym_wor] = ACTIONS(4128),
    [anon_sym_trior] = ACTIONS(4128),
    [anon_sym_trireg] = ACTIONS(4128),
    [anon_sym_uwire] = ACTIONS(4128),
    [anon_sym_SEMI] = ACTIONS(4126),
    [anon_sym_extern] = ACTIONS(4128),
    [anon_sym_interface] = ACTIONS(4128),
    [anon_sym_checker] = ACTIONS(4128),
    [anon_sym_virtual] = ACTIONS(4128),
    [anon_sym_class] = ACTIONS(4128),
    [anon_sym_type] = ACTIONS(4128),
    [anon_sym_DOLLARfatal] = ACTIONS(4126),
    [anon_sym_DOLLARerror] = ACTIONS(4126),
    [anon_sym_DOLLARwarning] = ACTIONS(4126),
    [anon_sym_DOLLARinfo] = ACTIONS(4126),
    [anon_sym_default] = ACTIONS(4128),
    [anon_sym_clocking] = ACTIONS(4128),
    [anon_sym_defparam] = ACTIONS(4128),
    [anon_sym_bind] = ACTIONS(4128),
    [anon_sym_rand] = ACTIONS(4128),
    [anon_sym_const] = ACTIONS(4128),
    [anon_sym_function] = ACTIONS(4128),
    [anon_sym_static] = ACTIONS(4128),
    [anon_sym_constraint] = ACTIONS(4128),
    [anon_sym_if] = ACTIONS(4128),
    [anon_sym_else] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4126),
    [anon_sym_localparam] = ACTIONS(4128),
    [anon_sym_parameter] = ACTIONS(4128),
    [anon_sym_var] = ACTIONS(4128),
    [anon_sym_import] = ACTIONS(4128),
    [anon_sym_export] = ACTIONS(4128),
    [anon_sym_genvar] = ACTIONS(4128),
    [anon_sym_interconnect] = ACTIONS(4128),
    [anon_sym_typedef] = ACTIONS(4128),
    [anon_sym_enum] = ACTIONS(4128),
    [anon_sym_struct] = ACTIONS(4128),
    [anon_sym_union] = ACTIONS(4128),
    [anon_sym_nettype] = ACTIONS(4128),
    [anon_sym_automatic] = ACTIONS(4128),
    [anon_sym_string] = ACTIONS(4128),
    [anon_sym_chandle] = ACTIONS(4128),
    [anon_sym_event] = ACTIONS(4128),
    [anon_sym_byte] = ACTIONS(4128),
    [anon_sym_shortint] = ACTIONS(4128),
    [anon_sym_int] = ACTIONS(4128),
    [anon_sym_longint] = ACTIONS(4128),
    [anon_sym_integer] = ACTIONS(4128),
    [anon_sym_time] = ACTIONS(4128),
    [anon_sym_bit] = ACTIONS(4128),
    [anon_sym_logic] = ACTIONS(4128),
    [anon_sym_reg] = ACTIONS(4128),
    [anon_sym_shortreal] = ACTIONS(4128),
    [anon_sym_real] = ACTIONS(4128),
    [anon_sym_realtime] = ACTIONS(4128),
    [anon_sym_supply0] = ACTIONS(4128),
    [anon_sym_supply1] = ACTIONS(4128),
    [anon_sym_signed] = ACTIONS(4128),
    [anon_sym_unsigned] = ACTIONS(4128),
    [anon_sym_task] = ACTIONS(4128),
    [anon_sym_assert] = ACTIONS(4128),
    [anon_sym_property] = ACTIONS(4128),
    [anon_sym_assume] = ACTIONS(4128),
    [anon_sym_cover] = ACTIONS(4128),
    [anon_sym_sequence] = ACTIONS(4128),
    [anon_sym_restrict] = ACTIONS(4128),
    [anon_sym_not] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_case] = ACTIONS(4128),
    [anon_sym_always] = ACTIONS(4128),
    [anon_sym_covergroup] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_pulldown] = ACTIONS(4128),
    [anon_sym_pullup] = ACTIONS(4128),
    [anon_sym_cmos] = ACTIONS(4128),
    [anon_sym_rcmos] = ACTIONS(4128),
    [anon_sym_bufif0] = ACTIONS(4128),
    [anon_sym_bufif1] = ACTIONS(4128),
    [anon_sym_notif0] = ACTIONS(4128),
    [anon_sym_notif1] = ACTIONS(4128),
    [anon_sym_nmos] = ACTIONS(4128),
    [anon_sym_pmos] = ACTIONS(4128),
    [anon_sym_rnmos] = ACTIONS(4128),
    [anon_sym_rpmos] = ACTIONS(4128),
    [anon_sym_nand] = ACTIONS(4128),
    [anon_sym_nor] = ACTIONS(4128),
    [anon_sym_xor] = ACTIONS(4128),
    [anon_sym_xnor] = ACTIONS(4128),
    [anon_sym_buf] = ACTIONS(4128),
    [anon_sym_tranif0] = ACTIONS(4128),
    [anon_sym_tranif1] = ACTIONS(4128),
    [anon_sym_rtranif1] = ACTIONS(4128),
    [anon_sym_rtranif0] = ACTIONS(4128),
    [anon_sym_tran] = ACTIONS(4128),
    [anon_sym_rtran] = ACTIONS(4128),
    [anon_sym_generate] = ACTIONS(4128),
    [anon_sym_endgenerate] = ACTIONS(4128),
    [anon_sym_for] = ACTIONS(4128),
    [anon_sym_initial] = ACTIONS(4128),
    [anon_sym_assign] = ACTIONS(4128),
    [anon_sym_alias] = ACTIONS(4128),
    [anon_sym_always_comb] = ACTIONS(4128),
    [anon_sym_always_latch] = ACTIONS(4128),
    [anon_sym_always_ff] = ACTIONS(4128),
    [anon_sym_final] = ACTIONS(4128),
    [anon_sym_global] = ACTIONS(4128),
    [anon_sym_LPAREN_STAR] = ACTIONS(4126),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4126),
    [anon_sym_DOLLARunit] = ACTIONS(4126),
  },
  [5134] = {
    [sym_simple_identifier] = ACTIONS(6719),
    [anon_sym_wire] = ACTIONS(6719),
    [anon_sym_tri] = ACTIONS(6719),
    [anon_sym_tri0] = ACTIONS(6719),
    [anon_sym_tri1] = ACTIONS(6719),
    [anon_sym_wand] = ACTIONS(6719),
    [anon_sym_triand] = ACTIONS(6719),
    [anon_sym_wor] = ACTIONS(6719),
    [anon_sym_trior] = ACTIONS(6719),
    [anon_sym_trireg] = ACTIONS(6719),
    [anon_sym_uwire] = ACTIONS(6719),
    [anon_sym_SEMI] = ACTIONS(6721),
    [anon_sym_extern] = ACTIONS(6719),
    [anon_sym_interface] = ACTIONS(6719),
    [anon_sym_checker] = ACTIONS(6719),
    [anon_sym_virtual] = ACTIONS(6719),
    [anon_sym_class] = ACTIONS(6719),
    [anon_sym_type] = ACTIONS(6719),
    [anon_sym_DOLLARfatal] = ACTIONS(6721),
    [anon_sym_DOLLARerror] = ACTIONS(6721),
    [anon_sym_DOLLARwarning] = ACTIONS(6721),
    [anon_sym_DOLLARinfo] = ACTIONS(6721),
    [anon_sym_default] = ACTIONS(6719),
    [anon_sym_clocking] = ACTIONS(6719),
    [anon_sym_defparam] = ACTIONS(6719),
    [anon_sym_bind] = ACTIONS(6719),
    [anon_sym_rand] = ACTIONS(6719),
    [anon_sym_const] = ACTIONS(6719),
    [anon_sym_function] = ACTIONS(6719),
    [anon_sym_static] = ACTIONS(6719),
    [anon_sym_constraint] = ACTIONS(6719),
    [anon_sym_if] = ACTIONS(6719),
    [anon_sym_else] = ACTIONS(6719),
    [anon_sym_LBRACK] = ACTIONS(6721),
    [anon_sym_localparam] = ACTIONS(6719),
    [anon_sym_parameter] = ACTIONS(6719),
    [anon_sym_var] = ACTIONS(6719),
    [anon_sym_import] = ACTIONS(6719),
    [anon_sym_export] = ACTIONS(6719),
    [anon_sym_genvar] = ACTIONS(6719),
    [anon_sym_interconnect] = ACTIONS(6719),
    [anon_sym_typedef] = ACTIONS(6719),
    [anon_sym_enum] = ACTIONS(6719),
    [anon_sym_struct] = ACTIONS(6719),
    [anon_sym_union] = ACTIONS(6719),
    [anon_sym_nettype] = ACTIONS(6719),
    [anon_sym_automatic] = ACTIONS(6719),
    [anon_sym_string] = ACTIONS(6719),
    [anon_sym_chandle] = ACTIONS(6719),
    [anon_sym_event] = ACTIONS(6719),
    [anon_sym_byte] = ACTIONS(6719),
    [anon_sym_shortint] = ACTIONS(6719),
    [anon_sym_int] = ACTIONS(6719),
    [anon_sym_longint] = ACTIONS(6719),
    [anon_sym_integer] = ACTIONS(6719),
    [anon_sym_time] = ACTIONS(6719),
    [anon_sym_bit] = ACTIONS(6719),
    [anon_sym_logic] = ACTIONS(6719),
    [anon_sym_reg] = ACTIONS(6719),
    [anon_sym_shortreal] = ACTIONS(6719),
    [anon_sym_real] = ACTIONS(6719),
    [anon_sym_realtime] = ACTIONS(6719),
    [anon_sym_supply0] = ACTIONS(6719),
    [anon_sym_supply1] = ACTIONS(6719),
    [anon_sym_signed] = ACTIONS(6719),
    [anon_sym_unsigned] = ACTIONS(6719),
    [anon_sym_task] = ACTIONS(6719),
    [anon_sym_assert] = ACTIONS(6719),
    [anon_sym_property] = ACTIONS(6719),
    [anon_sym_assume] = ACTIONS(6719),
    [anon_sym_cover] = ACTIONS(6719),
    [anon_sym_sequence] = ACTIONS(6719),
    [anon_sym_restrict] = ACTIONS(6719),
    [anon_sym_not] = ACTIONS(6719),
    [anon_sym_or] = ACTIONS(6719),
    [anon_sym_and] = ACTIONS(6719),
    [anon_sym_case] = ACTIONS(6719),
    [anon_sym_always] = ACTIONS(6719),
    [anon_sym_covergroup] = ACTIONS(6719),
    [anon_sym_let] = ACTIONS(6719),
    [anon_sym_pulldown] = ACTIONS(6719),
    [anon_sym_pullup] = ACTIONS(6719),
    [anon_sym_cmos] = ACTIONS(6719),
    [anon_sym_rcmos] = ACTIONS(6719),
    [anon_sym_bufif0] = ACTIONS(6719),
    [anon_sym_bufif1] = ACTIONS(6719),
    [anon_sym_notif0] = ACTIONS(6719),
    [anon_sym_notif1] = ACTIONS(6719),
    [anon_sym_nmos] = ACTIONS(6719),
    [anon_sym_pmos] = ACTIONS(6719),
    [anon_sym_rnmos] = ACTIONS(6719),
    [anon_sym_rpmos] = ACTIONS(6719),
    [anon_sym_nand] = ACTIONS(6719),
    [anon_sym_nor] = ACTIONS(6719),
    [anon_sym_xor] = ACTIONS(6719),
    [anon_sym_xnor] = ACTIONS(6719),
    [anon_sym_buf] = ACTIONS(6719),
    [anon_sym_tranif0] = ACTIONS(6719),
    [anon_sym_tranif1] = ACTIONS(6719),
    [anon_sym_rtranif1] = ACTIONS(6719),
    [anon_sym_rtranif0] = ACTIONS(6719),
    [anon_sym_tran] = ACTIONS(6719),
    [anon_sym_rtran] = ACTIONS(6719),
    [anon_sym_generate] = ACTIONS(6719),
    [anon_sym_endgenerate] = ACTIONS(6719),
    [anon_sym_for] = ACTIONS(6719),
    [anon_sym_initial] = ACTIONS(6719),
    [anon_sym_assign] = ACTIONS(6719),
    [anon_sym_alias] = ACTIONS(6719),
    [anon_sym_always_comb] = ACTIONS(6719),
    [anon_sym_always_latch] = ACTIONS(6719),
    [anon_sym_always_ff] = ACTIONS(6719),
    [anon_sym_final] = ACTIONS(6719),
    [anon_sym_global] = ACTIONS(6719),
    [anon_sym_LPAREN_STAR] = ACTIONS(6721),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6721),
    [anon_sym_DOLLARunit] = ACTIONS(6721),
  },
  [5135] = {
    [sym_simple_identifier] = ACTIONS(6261),
    [anon_sym_wire] = ACTIONS(6261),
    [anon_sym_tri] = ACTIONS(6261),
    [anon_sym_tri0] = ACTIONS(6261),
    [anon_sym_tri1] = ACTIONS(6261),
    [anon_sym_wand] = ACTIONS(6261),
    [anon_sym_triand] = ACTIONS(6261),
    [anon_sym_wor] = ACTIONS(6261),
    [anon_sym_trior] = ACTIONS(6261),
    [anon_sym_trireg] = ACTIONS(6261),
    [anon_sym_uwire] = ACTIONS(6261),
    [anon_sym_SEMI] = ACTIONS(6263),
    [anon_sym_extern] = ACTIONS(6261),
    [anon_sym_interface] = ACTIONS(6261),
    [anon_sym_checker] = ACTIONS(6261),
    [anon_sym_virtual] = ACTIONS(6261),
    [anon_sym_class] = ACTIONS(6261),
    [anon_sym_type] = ACTIONS(6261),
    [anon_sym_DOLLARfatal] = ACTIONS(6263),
    [anon_sym_DOLLARerror] = ACTIONS(6263),
    [anon_sym_DOLLARwarning] = ACTIONS(6263),
    [anon_sym_DOLLARinfo] = ACTIONS(6263),
    [anon_sym_default] = ACTIONS(6261),
    [anon_sym_clocking] = ACTIONS(6261),
    [anon_sym_defparam] = ACTIONS(6261),
    [anon_sym_bind] = ACTIONS(6261),
    [anon_sym_rand] = ACTIONS(6261),
    [anon_sym_const] = ACTIONS(6261),
    [anon_sym_function] = ACTIONS(6261),
    [anon_sym_static] = ACTIONS(6261),
    [anon_sym_constraint] = ACTIONS(6261),
    [anon_sym_if] = ACTIONS(6261),
    [anon_sym_else] = ACTIONS(6261),
    [anon_sym_LBRACK] = ACTIONS(6263),
    [anon_sym_localparam] = ACTIONS(6261),
    [anon_sym_parameter] = ACTIONS(6261),
    [anon_sym_var] = ACTIONS(6261),
    [anon_sym_import] = ACTIONS(6261),
    [anon_sym_export] = ACTIONS(6261),
    [anon_sym_genvar] = ACTIONS(6261),
    [anon_sym_interconnect] = ACTIONS(6261),
    [anon_sym_typedef] = ACTIONS(6261),
    [anon_sym_enum] = ACTIONS(6261),
    [anon_sym_struct] = ACTIONS(6261),
    [anon_sym_union] = ACTIONS(6261),
    [anon_sym_nettype] = ACTIONS(6261),
    [anon_sym_automatic] = ACTIONS(6261),
    [anon_sym_string] = ACTIONS(6261),
    [anon_sym_chandle] = ACTIONS(6261),
    [anon_sym_event] = ACTIONS(6261),
    [anon_sym_byte] = ACTIONS(6261),
    [anon_sym_shortint] = ACTIONS(6261),
    [anon_sym_int] = ACTIONS(6261),
    [anon_sym_longint] = ACTIONS(6261),
    [anon_sym_integer] = ACTIONS(6261),
    [anon_sym_time] = ACTIONS(6261),
    [anon_sym_bit] = ACTIONS(6261),
    [anon_sym_logic] = ACTIONS(6261),
    [anon_sym_reg] = ACTIONS(6261),
    [anon_sym_shortreal] = ACTIONS(6261),
    [anon_sym_real] = ACTIONS(6261),
    [anon_sym_realtime] = ACTIONS(6261),
    [anon_sym_supply0] = ACTIONS(6261),
    [anon_sym_supply1] = ACTIONS(6261),
    [anon_sym_signed] = ACTIONS(6261),
    [anon_sym_unsigned] = ACTIONS(6261),
    [anon_sym_task] = ACTIONS(6261),
    [anon_sym_assert] = ACTIONS(6261),
    [anon_sym_property] = ACTIONS(6261),
    [anon_sym_assume] = ACTIONS(6261),
    [anon_sym_cover] = ACTIONS(6261),
    [anon_sym_sequence] = ACTIONS(6261),
    [anon_sym_restrict] = ACTIONS(6261),
    [anon_sym_not] = ACTIONS(6261),
    [anon_sym_or] = ACTIONS(6261),
    [anon_sym_and] = ACTIONS(6261),
    [anon_sym_case] = ACTIONS(6261),
    [anon_sym_always] = ACTIONS(6261),
    [anon_sym_covergroup] = ACTIONS(6261),
    [anon_sym_let] = ACTIONS(6261),
    [anon_sym_pulldown] = ACTIONS(6261),
    [anon_sym_pullup] = ACTIONS(6261),
    [anon_sym_cmos] = ACTIONS(6261),
    [anon_sym_rcmos] = ACTIONS(6261),
    [anon_sym_bufif0] = ACTIONS(6261),
    [anon_sym_bufif1] = ACTIONS(6261),
    [anon_sym_notif0] = ACTIONS(6261),
    [anon_sym_notif1] = ACTIONS(6261),
    [anon_sym_nmos] = ACTIONS(6261),
    [anon_sym_pmos] = ACTIONS(6261),
    [anon_sym_rnmos] = ACTIONS(6261),
    [anon_sym_rpmos] = ACTIONS(6261),
    [anon_sym_nand] = ACTIONS(6261),
    [anon_sym_nor] = ACTIONS(6261),
    [anon_sym_xor] = ACTIONS(6261),
    [anon_sym_xnor] = ACTIONS(6261),
    [anon_sym_buf] = ACTIONS(6261),
    [anon_sym_tranif0] = ACTIONS(6261),
    [anon_sym_tranif1] = ACTIONS(6261),
    [anon_sym_rtranif1] = ACTIONS(6261),
    [anon_sym_rtranif0] = ACTIONS(6261),
    [anon_sym_tran] = ACTIONS(6261),
    [anon_sym_rtran] = ACTIONS(6261),
    [anon_sym_generate] = ACTIONS(6261),
    [anon_sym_endgenerate] = ACTIONS(6261),
    [anon_sym_for] = ACTIONS(6261),
    [anon_sym_initial] = ACTIONS(6261),
    [anon_sym_assign] = ACTIONS(6261),
    [anon_sym_alias] = ACTIONS(6261),
    [anon_sym_always_comb] = ACTIONS(6261),
    [anon_sym_always_latch] = ACTIONS(6261),
    [anon_sym_always_ff] = ACTIONS(6261),
    [anon_sym_final] = ACTIONS(6261),
    [anon_sym_global] = ACTIONS(6261),
    [anon_sym_LPAREN_STAR] = ACTIONS(6263),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6263),
    [anon_sym_DOLLARunit] = ACTIONS(6263),
  },
  [5136] = {
    [sym_simple_identifier] = ACTIONS(4236),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_rand] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_end] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [5137] = {
    [sym_simple_identifier] = ACTIONS(4236),
    [anon_sym_wire] = ACTIONS(4236),
    [anon_sym_tri] = ACTIONS(4236),
    [anon_sym_tri0] = ACTIONS(4236),
    [anon_sym_tri1] = ACTIONS(4236),
    [anon_sym_wand] = ACTIONS(4236),
    [anon_sym_triand] = ACTIONS(4236),
    [anon_sym_wor] = ACTIONS(4236),
    [anon_sym_trior] = ACTIONS(4236),
    [anon_sym_trireg] = ACTIONS(4236),
    [anon_sym_uwire] = ACTIONS(4236),
    [anon_sym_SEMI] = ACTIONS(4234),
    [anon_sym_extern] = ACTIONS(4236),
    [anon_sym_interface] = ACTIONS(4236),
    [anon_sym_checker] = ACTIONS(4236),
    [anon_sym_virtual] = ACTIONS(4236),
    [anon_sym_class] = ACTIONS(4236),
    [anon_sym_type] = ACTIONS(4236),
    [anon_sym_DOLLARfatal] = ACTIONS(4234),
    [anon_sym_DOLLARerror] = ACTIONS(4234),
    [anon_sym_DOLLARwarning] = ACTIONS(4234),
    [anon_sym_DOLLARinfo] = ACTIONS(4234),
    [anon_sym_default] = ACTIONS(4236),
    [anon_sym_clocking] = ACTIONS(4236),
    [anon_sym_defparam] = ACTIONS(4236),
    [anon_sym_bind] = ACTIONS(4236),
    [anon_sym_rand] = ACTIONS(4236),
    [anon_sym_const] = ACTIONS(4236),
    [anon_sym_function] = ACTIONS(4236),
    [anon_sym_static] = ACTIONS(4236),
    [anon_sym_constraint] = ACTIONS(4236),
    [anon_sym_if] = ACTIONS(4236),
    [anon_sym_else] = ACTIONS(4236),
    [anon_sym_LBRACK] = ACTIONS(4234),
    [anon_sym_localparam] = ACTIONS(4236),
    [anon_sym_parameter] = ACTIONS(4236),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_import] = ACTIONS(4236),
    [anon_sym_export] = ACTIONS(4236),
    [anon_sym_genvar] = ACTIONS(4236),
    [anon_sym_interconnect] = ACTIONS(4236),
    [anon_sym_typedef] = ACTIONS(4236),
    [anon_sym_enum] = ACTIONS(4236),
    [anon_sym_struct] = ACTIONS(4236),
    [anon_sym_union] = ACTIONS(4236),
    [anon_sym_nettype] = ACTIONS(4236),
    [anon_sym_automatic] = ACTIONS(4236),
    [anon_sym_string] = ACTIONS(4236),
    [anon_sym_chandle] = ACTIONS(4236),
    [anon_sym_event] = ACTIONS(4236),
    [anon_sym_byte] = ACTIONS(4236),
    [anon_sym_shortint] = ACTIONS(4236),
    [anon_sym_int] = ACTIONS(4236),
    [anon_sym_longint] = ACTIONS(4236),
    [anon_sym_integer] = ACTIONS(4236),
    [anon_sym_time] = ACTIONS(4236),
    [anon_sym_bit] = ACTIONS(4236),
    [anon_sym_logic] = ACTIONS(4236),
    [anon_sym_reg] = ACTIONS(4236),
    [anon_sym_shortreal] = ACTIONS(4236),
    [anon_sym_real] = ACTIONS(4236),
    [anon_sym_realtime] = ACTIONS(4236),
    [anon_sym_supply0] = ACTIONS(4236),
    [anon_sym_supply1] = ACTIONS(4236),
    [anon_sym_signed] = ACTIONS(4236),
    [anon_sym_unsigned] = ACTIONS(4236),
    [anon_sym_task] = ACTIONS(4236),
    [anon_sym_assert] = ACTIONS(4236),
    [anon_sym_property] = ACTIONS(4236),
    [anon_sym_assume] = ACTIONS(4236),
    [anon_sym_cover] = ACTIONS(4236),
    [anon_sym_sequence] = ACTIONS(4236),
    [anon_sym_restrict] = ACTIONS(4236),
    [anon_sym_not] = ACTIONS(4236),
    [anon_sym_or] = ACTIONS(4236),
    [anon_sym_and] = ACTIONS(4236),
    [anon_sym_case] = ACTIONS(4236),
    [anon_sym_always] = ACTIONS(4236),
    [anon_sym_covergroup] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_pulldown] = ACTIONS(4236),
    [anon_sym_pullup] = ACTIONS(4236),
    [anon_sym_cmos] = ACTIONS(4236),
    [anon_sym_rcmos] = ACTIONS(4236),
    [anon_sym_bufif0] = ACTIONS(4236),
    [anon_sym_bufif1] = ACTIONS(4236),
    [anon_sym_notif0] = ACTIONS(4236),
    [anon_sym_notif1] = ACTIONS(4236),
    [anon_sym_nmos] = ACTIONS(4236),
    [anon_sym_pmos] = ACTIONS(4236),
    [anon_sym_rnmos] = ACTIONS(4236),
    [anon_sym_rpmos] = ACTIONS(4236),
    [anon_sym_nand] = ACTIONS(4236),
    [anon_sym_nor] = ACTIONS(4236),
    [anon_sym_xor] = ACTIONS(4236),
    [anon_sym_xnor] = ACTIONS(4236),
    [anon_sym_buf] = ACTIONS(4236),
    [anon_sym_tranif0] = ACTIONS(4236),
    [anon_sym_tranif1] = ACTIONS(4236),
    [anon_sym_rtranif1] = ACTIONS(4236),
    [anon_sym_rtranif0] = ACTIONS(4236),
    [anon_sym_tran] = ACTIONS(4236),
    [anon_sym_rtran] = ACTIONS(4236),
    [anon_sym_generate] = ACTIONS(4236),
    [anon_sym_endgenerate] = ACTIONS(4236),
    [anon_sym_for] = ACTIONS(4236),
    [anon_sym_initial] = ACTIONS(4236),
    [anon_sym_assign] = ACTIONS(4236),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_always_comb] = ACTIONS(4236),
    [anon_sym_always_latch] = ACTIONS(4236),
    [anon_sym_always_ff] = ACTIONS(4236),
    [anon_sym_final] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_LPAREN_STAR] = ACTIONS(4234),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4234),
    [anon_sym_DOLLARunit] = ACTIONS(4234),
  },
  [5138] = {
    [sym_simple_identifier] = ACTIONS(6467),
    [anon_sym_wire] = ACTIONS(6467),
    [anon_sym_tri] = ACTIONS(6467),
    [anon_sym_tri0] = ACTIONS(6467),
    [anon_sym_tri1] = ACTIONS(6467),
    [anon_sym_wand] = ACTIONS(6467),
    [anon_sym_triand] = ACTIONS(6467),
    [anon_sym_wor] = ACTIONS(6467),
    [anon_sym_trior] = ACTIONS(6467),
    [anon_sym_trireg] = ACTIONS(6467),
    [anon_sym_uwire] = ACTIONS(6467),
    [anon_sym_SEMI] = ACTIONS(6469),
    [anon_sym_extern] = ACTIONS(6467),
    [anon_sym_interface] = ACTIONS(6467),
    [anon_sym_checker] = ACTIONS(6467),
    [anon_sym_virtual] = ACTIONS(6467),
    [anon_sym_class] = ACTIONS(6467),
    [anon_sym_type] = ACTIONS(6467),
    [anon_sym_DOLLARfatal] = ACTIONS(6469),
    [anon_sym_DOLLARerror] = ACTIONS(6469),
    [anon_sym_DOLLARwarning] = ACTIONS(6469),
    [anon_sym_DOLLARinfo] = ACTIONS(6469),
    [anon_sym_default] = ACTIONS(6467),
    [anon_sym_clocking] = ACTIONS(6467),
    [anon_sym_defparam] = ACTIONS(6467),
    [anon_sym_bind] = ACTIONS(6467),
    [anon_sym_rand] = ACTIONS(6467),
    [anon_sym_const] = ACTIONS(6467),
    [anon_sym_function] = ACTIONS(6467),
    [anon_sym_static] = ACTIONS(6467),
    [anon_sym_constraint] = ACTIONS(6467),
    [anon_sym_if] = ACTIONS(6467),
    [anon_sym_else] = ACTIONS(6467),
    [anon_sym_LBRACK] = ACTIONS(6469),
    [anon_sym_localparam] = ACTIONS(6467),
    [anon_sym_parameter] = ACTIONS(6467),
    [anon_sym_var] = ACTIONS(6467),
    [anon_sym_import] = ACTIONS(6467),
    [anon_sym_export] = ACTIONS(6467),
    [anon_sym_genvar] = ACTIONS(6467),
    [anon_sym_interconnect] = ACTIONS(6467),
    [anon_sym_typedef] = ACTIONS(6467),
    [anon_sym_enum] = ACTIONS(6467),
    [anon_sym_struct] = ACTIONS(6467),
    [anon_sym_union] = ACTIONS(6467),
    [anon_sym_nettype] = ACTIONS(6467),
    [anon_sym_automatic] = ACTIONS(6467),
    [anon_sym_string] = ACTIONS(6467),
    [anon_sym_chandle] = ACTIONS(6467),
    [anon_sym_event] = ACTIONS(6467),
    [anon_sym_byte] = ACTIONS(6467),
    [anon_sym_shortint] = ACTIONS(6467),
    [anon_sym_int] = ACTIONS(6467),
    [anon_sym_longint] = ACTIONS(6467),
    [anon_sym_integer] = ACTIONS(6467),
    [anon_sym_time] = ACTIONS(6467),
    [anon_sym_bit] = ACTIONS(6467),
    [anon_sym_logic] = ACTIONS(6467),
    [anon_sym_reg] = ACTIONS(6467),
    [anon_sym_shortreal] = ACTIONS(6467),
    [anon_sym_real] = ACTIONS(6467),
    [anon_sym_realtime] = ACTIONS(6467),
    [anon_sym_supply0] = ACTIONS(6467),
    [anon_sym_supply1] = ACTIONS(6467),
    [anon_sym_signed] = ACTIONS(6467),
    [anon_sym_unsigned] = ACTIONS(6467),
    [anon_sym_task] = ACTIONS(6467),
    [anon_sym_assert] = ACTIONS(6467),
    [anon_sym_property] = ACTIONS(6467),
    [anon_sym_assume] = ACTIONS(6467),
    [anon_sym_cover] = ACTIONS(6467),
    [anon_sym_sequence] = ACTIONS(6467),
    [anon_sym_restrict] = ACTIONS(6467),
    [anon_sym_not] = ACTIONS(6467),
    [anon_sym_or] = ACTIONS(6467),
    [anon_sym_and] = ACTIONS(6467),
    [anon_sym_case] = ACTIONS(6467),
    [anon_sym_always] = ACTIONS(6467),
    [anon_sym_covergroup] = ACTIONS(6467),
    [anon_sym_let] = ACTIONS(6467),
    [anon_sym_pulldown] = ACTIONS(6467),
    [anon_sym_pullup] = ACTIONS(6467),
    [anon_sym_cmos] = ACTIONS(6467),
    [anon_sym_rcmos] = ACTIONS(6467),
    [anon_sym_bufif0] = ACTIONS(6467),
    [anon_sym_bufif1] = ACTIONS(6467),
    [anon_sym_notif0] = ACTIONS(6467),
    [anon_sym_notif1] = ACTIONS(6467),
    [anon_sym_nmos] = ACTIONS(6467),
    [anon_sym_pmos] = ACTIONS(6467),
    [anon_sym_rnmos] = ACTIONS(6467),
    [anon_sym_rpmos] = ACTIONS(6467),
    [anon_sym_nand] = ACTIONS(6467),
    [anon_sym_nor] = ACTIONS(6467),
    [anon_sym_xor] = ACTIONS(6467),
    [anon_sym_xnor] = ACTIONS(6467),
    [anon_sym_buf] = ACTIONS(6467),
    [anon_sym_tranif0] = ACTIONS(6467),
    [anon_sym_tranif1] = ACTIONS(6467),
    [anon_sym_rtranif1] = ACTIONS(6467),
    [anon_sym_rtranif0] = ACTIONS(6467),
    [anon_sym_tran] = ACTIONS(6467),
    [anon_sym_rtran] = ACTIONS(6467),
    [anon_sym_generate] = ACTIONS(6467),
    [anon_sym_endgenerate] = ACTIONS(6467),
    [anon_sym_for] = ACTIONS(6467),
    [anon_sym_initial] = ACTIONS(6467),
    [anon_sym_assign] = ACTIONS(6467),
    [anon_sym_alias] = ACTIONS(6467),
    [anon_sym_always_comb] = ACTIONS(6467),
    [anon_sym_always_latch] = ACTIONS(6467),
    [anon_sym_always_ff] = ACTIONS(6467),
    [anon_sym_final] = ACTIONS(6467),
    [anon_sym_global] = ACTIONS(6467),
    [anon_sym_LPAREN_STAR] = ACTIONS(6469),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6469),
    [anon_sym_DOLLARunit] = ACTIONS(6469),
  },
  [5139] = {
    [sym_simple_identifier] = ACTIONS(4260),
    [anon_sym_wire] = ACTIONS(4260),
    [anon_sym_tri] = ACTIONS(4260),
    [anon_sym_tri0] = ACTIONS(4260),
    [anon_sym_tri1] = ACTIONS(4260),
    [anon_sym_wand] = ACTIONS(4260),
    [anon_sym_triand] = ACTIONS(4260),
    [anon_sym_wor] = ACTIONS(4260),
    [anon_sym_trior] = ACTIONS(4260),
    [anon_sym_trireg] = ACTIONS(4260),
    [anon_sym_uwire] = ACTIONS(4260),
    [anon_sym_SEMI] = ACTIONS(4258),
    [anon_sym_extern] = ACTIONS(4260),
    [anon_sym_interface] = ACTIONS(4260),
    [anon_sym_checker] = ACTIONS(4260),
    [anon_sym_virtual] = ACTIONS(4260),
    [anon_sym_class] = ACTIONS(4260),
    [anon_sym_type] = ACTIONS(4260),
    [anon_sym_DOLLARfatal] = ACTIONS(4258),
    [anon_sym_DOLLARerror] = ACTIONS(4258),
    [anon_sym_DOLLARwarning] = ACTIONS(4258),
    [anon_sym_DOLLARinfo] = ACTIONS(4258),
    [anon_sym_default] = ACTIONS(4260),
    [anon_sym_clocking] = ACTIONS(4260),
    [anon_sym_defparam] = ACTIONS(4260),
    [anon_sym_bind] = ACTIONS(4260),
    [anon_sym_rand] = ACTIONS(4260),
    [anon_sym_const] = ACTIONS(4260),
    [anon_sym_function] = ACTIONS(4260),
    [anon_sym_static] = ACTIONS(4260),
    [anon_sym_constraint] = ACTIONS(4260),
    [anon_sym_if] = ACTIONS(4260),
    [anon_sym_else] = ACTIONS(4260),
    [anon_sym_LBRACK] = ACTIONS(4258),
    [anon_sym_localparam] = ACTIONS(4260),
    [anon_sym_parameter] = ACTIONS(4260),
    [anon_sym_var] = ACTIONS(4260),
    [anon_sym_import] = ACTIONS(4260),
    [anon_sym_export] = ACTIONS(4260),
    [anon_sym_genvar] = ACTIONS(4260),
    [anon_sym_interconnect] = ACTIONS(4260),
    [anon_sym_typedef] = ACTIONS(4260),
    [anon_sym_enum] = ACTIONS(4260),
    [anon_sym_struct] = ACTIONS(4260),
    [anon_sym_union] = ACTIONS(4260),
    [anon_sym_nettype] = ACTIONS(4260),
    [anon_sym_automatic] = ACTIONS(4260),
    [anon_sym_string] = ACTIONS(4260),
    [anon_sym_chandle] = ACTIONS(4260),
    [anon_sym_event] = ACTIONS(4260),
    [anon_sym_byte] = ACTIONS(4260),
    [anon_sym_shortint] = ACTIONS(4260),
    [anon_sym_int] = ACTIONS(4260),
    [anon_sym_longint] = ACTIONS(4260),
    [anon_sym_integer] = ACTIONS(4260),
    [anon_sym_time] = ACTIONS(4260),
    [anon_sym_bit] = ACTIONS(4260),
    [anon_sym_logic] = ACTIONS(4260),
    [anon_sym_reg] = ACTIONS(4260),
    [anon_sym_shortreal] = ACTIONS(4260),
    [anon_sym_real] = ACTIONS(4260),
    [anon_sym_realtime] = ACTIONS(4260),
    [anon_sym_supply0] = ACTIONS(4260),
    [anon_sym_supply1] = ACTIONS(4260),
    [anon_sym_signed] = ACTIONS(4260),
    [anon_sym_unsigned] = ACTIONS(4260),
    [anon_sym_task] = ACTIONS(4260),
    [anon_sym_assert] = ACTIONS(4260),
    [anon_sym_property] = ACTIONS(4260),
    [anon_sym_assume] = ACTIONS(4260),
    [anon_sym_cover] = ACTIONS(4260),
    [anon_sym_sequence] = ACTIONS(4260),
    [anon_sym_restrict] = ACTIONS(4260),
    [anon_sym_not] = ACTIONS(4260),
    [anon_sym_or] = ACTIONS(4260),
    [anon_sym_and] = ACTIONS(4260),
    [anon_sym_case] = ACTIONS(4260),
    [anon_sym_always] = ACTIONS(4260),
    [anon_sym_covergroup] = ACTIONS(4260),
    [anon_sym_let] = ACTIONS(4260),
    [anon_sym_pulldown] = ACTIONS(4260),
    [anon_sym_pullup] = ACTIONS(4260),
    [anon_sym_cmos] = ACTIONS(4260),
    [anon_sym_rcmos] = ACTIONS(4260),
    [anon_sym_bufif0] = ACTIONS(4260),
    [anon_sym_bufif1] = ACTIONS(4260),
    [anon_sym_notif0] = ACTIONS(4260),
    [anon_sym_notif1] = ACTIONS(4260),
    [anon_sym_nmos] = ACTIONS(4260),
    [anon_sym_pmos] = ACTIONS(4260),
    [anon_sym_rnmos] = ACTIONS(4260),
    [anon_sym_rpmos] = ACTIONS(4260),
    [anon_sym_nand] = ACTIONS(4260),
    [anon_sym_nor] = ACTIONS(4260),
    [anon_sym_xor] = ACTIONS(4260),
    [anon_sym_xnor] = ACTIONS(4260),
    [anon_sym_buf] = ACTIONS(4260),
    [anon_sym_tranif0] = ACTIONS(4260),
    [anon_sym_tranif1] = ACTIONS(4260),
    [anon_sym_rtranif1] = ACTIONS(4260),
    [anon_sym_rtranif0] = ACTIONS(4260),
    [anon_sym_tran] = ACTIONS(4260),
    [anon_sym_rtran] = ACTIONS(4260),
    [anon_sym_generate] = ACTIONS(4260),
    [anon_sym_endgenerate] = ACTIONS(4260),
    [anon_sym_for] = ACTIONS(4260),
    [anon_sym_initial] = ACTIONS(4260),
    [anon_sym_assign] = ACTIONS(4260),
    [anon_sym_alias] = ACTIONS(4260),
    [anon_sym_always_comb] = ACTIONS(4260),
    [anon_sym_always_latch] = ACTIONS(4260),
    [anon_sym_always_ff] = ACTIONS(4260),
    [anon_sym_final] = ACTIONS(4260),
    [anon_sym_global] = ACTIONS(4260),
    [anon_sym_LPAREN_STAR] = ACTIONS(4258),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4258),
    [anon_sym_DOLLARunit] = ACTIONS(4258),
  },
  [5140] = {
    [sym_simple_identifier] = ACTIONS(6303),
    [anon_sym_wire] = ACTIONS(6303),
    [anon_sym_tri] = ACTIONS(6303),
    [anon_sym_tri0] = ACTIONS(6303),
    [anon_sym_tri1] = ACTIONS(6303),
    [anon_sym_wand] = ACTIONS(6303),
    [anon_sym_triand] = ACTIONS(6303),
    [anon_sym_wor] = ACTIONS(6303),
    [anon_sym_trior] = ACTIONS(6303),
    [anon_sym_trireg] = ACTIONS(6303),
    [anon_sym_uwire] = ACTIONS(6303),
    [anon_sym_SEMI] = ACTIONS(6305),
    [anon_sym_extern] = ACTIONS(6303),
    [anon_sym_interface] = ACTIONS(6303),
    [anon_sym_checker] = ACTIONS(6303),
    [anon_sym_virtual] = ACTIONS(6303),
    [anon_sym_class] = ACTIONS(6303),
    [anon_sym_type] = ACTIONS(6303),
    [anon_sym_DOLLARfatal] = ACTIONS(6305),
    [anon_sym_DOLLARerror] = ACTIONS(6305),
    [anon_sym_DOLLARwarning] = ACTIONS(6305),
    [anon_sym_DOLLARinfo] = ACTIONS(6305),
    [anon_sym_default] = ACTIONS(6303),
    [anon_sym_clocking] = ACTIONS(6303),
    [anon_sym_defparam] = ACTIONS(6303),
    [anon_sym_bind] = ACTIONS(6303),
    [anon_sym_rand] = ACTIONS(6303),
    [anon_sym_const] = ACTIONS(6303),
    [anon_sym_function] = ACTIONS(6303),
    [anon_sym_static] = ACTIONS(6303),
    [anon_sym_constraint] = ACTIONS(6303),
    [anon_sym_if] = ACTIONS(6303),
    [anon_sym_else] = ACTIONS(6303),
    [anon_sym_LBRACK] = ACTIONS(6305),
    [anon_sym_localparam] = ACTIONS(6303),
    [anon_sym_parameter] = ACTIONS(6303),
    [anon_sym_var] = ACTIONS(6303),
    [anon_sym_import] = ACTIONS(6303),
    [anon_sym_export] = ACTIONS(6303),
    [anon_sym_genvar] = ACTIONS(6303),
    [anon_sym_interconnect] = ACTIONS(6303),
    [anon_sym_typedef] = ACTIONS(6303),
    [anon_sym_enum] = ACTIONS(6303),
    [anon_sym_struct] = ACTIONS(6303),
    [anon_sym_union] = ACTIONS(6303),
    [anon_sym_nettype] = ACTIONS(6303),
    [anon_sym_automatic] = ACTIONS(6303),
    [anon_sym_string] = ACTIONS(6303),
    [anon_sym_chandle] = ACTIONS(6303),
    [anon_sym_event] = ACTIONS(6303),
    [anon_sym_byte] = ACTIONS(6303),
    [anon_sym_shortint] = ACTIONS(6303),
    [anon_sym_int] = ACTIONS(6303),
    [anon_sym_longint] = ACTIONS(6303),
    [anon_sym_integer] = ACTIONS(6303),
    [anon_sym_time] = ACTIONS(6303),
    [anon_sym_bit] = ACTIONS(6303),
    [anon_sym_logic] = ACTIONS(6303),
    [anon_sym_reg] = ACTIONS(6303),
    [anon_sym_shortreal] = ACTIONS(6303),
    [anon_sym_real] = ACTIONS(6303),
    [anon_sym_realtime] = ACTIONS(6303),
    [anon_sym_supply0] = ACTIONS(6303),
    [anon_sym_supply1] = ACTIONS(6303),
    [anon_sym_signed] = ACTIONS(6303),
    [anon_sym_unsigned] = ACTIONS(6303),
    [anon_sym_task] = ACTIONS(6303),
    [anon_sym_assert] = ACTIONS(6303),
    [anon_sym_property] = ACTIONS(6303),
    [anon_sym_assume] = ACTIONS(6303),
    [anon_sym_cover] = ACTIONS(6303),
    [anon_sym_sequence] = ACTIONS(6303),
    [anon_sym_restrict] = ACTIONS(6303),
    [anon_sym_not] = ACTIONS(6303),
    [anon_sym_or] = ACTIONS(6303),
    [anon_sym_and] = ACTIONS(6303),
    [anon_sym_case] = ACTIONS(6303),
    [anon_sym_always] = ACTIONS(6303),
    [anon_sym_covergroup] = ACTIONS(6303),
    [anon_sym_let] = ACTIONS(6303),
    [anon_sym_pulldown] = ACTIONS(6303),
    [anon_sym_pullup] = ACTIONS(6303),
    [anon_sym_cmos] = ACTIONS(6303),
    [anon_sym_rcmos] = ACTIONS(6303),
    [anon_sym_bufif0] = ACTIONS(6303),
    [anon_sym_bufif1] = ACTIONS(6303),
    [anon_sym_notif0] = ACTIONS(6303),
    [anon_sym_notif1] = ACTIONS(6303),
    [anon_sym_nmos] = ACTIONS(6303),
    [anon_sym_pmos] = ACTIONS(6303),
    [anon_sym_rnmos] = ACTIONS(6303),
    [anon_sym_rpmos] = ACTIONS(6303),
    [anon_sym_nand] = ACTIONS(6303),
    [anon_sym_nor] = ACTIONS(6303),
    [anon_sym_xor] = ACTIONS(6303),
    [anon_sym_xnor] = ACTIONS(6303),
    [anon_sym_buf] = ACTIONS(6303),
    [anon_sym_tranif0] = ACTIONS(6303),
    [anon_sym_tranif1] = ACTIONS(6303),
    [anon_sym_rtranif1] = ACTIONS(6303),
    [anon_sym_rtranif0] = ACTIONS(6303),
    [anon_sym_tran] = ACTIONS(6303),
    [anon_sym_rtran] = ACTIONS(6303),
    [anon_sym_generate] = ACTIONS(6303),
    [anon_sym_endgenerate] = ACTIONS(6303),
    [anon_sym_for] = ACTIONS(6303),
    [anon_sym_initial] = ACTIONS(6303),
    [anon_sym_assign] = ACTIONS(6303),
    [anon_sym_alias] = ACTIONS(6303),
    [anon_sym_always_comb] = ACTIONS(6303),
    [anon_sym_always_latch] = ACTIONS(6303),
    [anon_sym_always_ff] = ACTIONS(6303),
    [anon_sym_final] = ACTIONS(6303),
    [anon_sym_global] = ACTIONS(6303),
    [anon_sym_LPAREN_STAR] = ACTIONS(6305),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6305),
    [anon_sym_DOLLARunit] = ACTIONS(6305),
  },
  [5141] = {
    [sym_simple_identifier] = ACTIONS(4270),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_rand] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_endgenerate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [5142] = {
    [sym_simple_identifier] = ACTIONS(4832),
    [anon_sym_wire] = ACTIONS(4832),
    [anon_sym_tri] = ACTIONS(4832),
    [anon_sym_tri0] = ACTIONS(4832),
    [anon_sym_tri1] = ACTIONS(4832),
    [anon_sym_wand] = ACTIONS(4832),
    [anon_sym_triand] = ACTIONS(4832),
    [anon_sym_wor] = ACTIONS(4832),
    [anon_sym_trior] = ACTIONS(4832),
    [anon_sym_trireg] = ACTIONS(4832),
    [anon_sym_uwire] = ACTIONS(4832),
    [anon_sym_SEMI] = ACTIONS(4830),
    [anon_sym_extern] = ACTIONS(4832),
    [anon_sym_interface] = ACTIONS(4832),
    [anon_sym_checker] = ACTIONS(4832),
    [anon_sym_virtual] = ACTIONS(4832),
    [anon_sym_class] = ACTIONS(4832),
    [anon_sym_type] = ACTIONS(4832),
    [anon_sym_DOLLARfatal] = ACTIONS(4830),
    [anon_sym_DOLLARerror] = ACTIONS(4830),
    [anon_sym_DOLLARwarning] = ACTIONS(4830),
    [anon_sym_DOLLARinfo] = ACTIONS(4830),
    [anon_sym_default] = ACTIONS(4832),
    [anon_sym_clocking] = ACTIONS(4832),
    [anon_sym_defparam] = ACTIONS(4832),
    [anon_sym_bind] = ACTIONS(4832),
    [anon_sym_rand] = ACTIONS(4832),
    [anon_sym_const] = ACTIONS(4832),
    [anon_sym_function] = ACTIONS(4832),
    [anon_sym_static] = ACTIONS(4832),
    [anon_sym_constraint] = ACTIONS(4832),
    [anon_sym_if] = ACTIONS(4832),
    [anon_sym_else] = ACTIONS(4832),
    [anon_sym_LBRACK] = ACTIONS(4830),
    [anon_sym_localparam] = ACTIONS(4832),
    [anon_sym_parameter] = ACTIONS(4832),
    [anon_sym_var] = ACTIONS(4832),
    [anon_sym_import] = ACTIONS(4832),
    [anon_sym_export] = ACTIONS(4832),
    [anon_sym_genvar] = ACTIONS(4832),
    [anon_sym_interconnect] = ACTIONS(4832),
    [anon_sym_typedef] = ACTIONS(4832),
    [anon_sym_enum] = ACTIONS(4832),
    [anon_sym_struct] = ACTIONS(4832),
    [anon_sym_union] = ACTIONS(4832),
    [anon_sym_nettype] = ACTIONS(4832),
    [anon_sym_automatic] = ACTIONS(4832),
    [anon_sym_string] = ACTIONS(4832),
    [anon_sym_chandle] = ACTIONS(4832),
    [anon_sym_event] = ACTIONS(4832),
    [anon_sym_byte] = ACTIONS(4832),
    [anon_sym_shortint] = ACTIONS(4832),
    [anon_sym_int] = ACTIONS(4832),
    [anon_sym_longint] = ACTIONS(4832),
    [anon_sym_integer] = ACTIONS(4832),
    [anon_sym_time] = ACTIONS(4832),
    [anon_sym_bit] = ACTIONS(4832),
    [anon_sym_logic] = ACTIONS(4832),
    [anon_sym_reg] = ACTIONS(4832),
    [anon_sym_shortreal] = ACTIONS(4832),
    [anon_sym_real] = ACTIONS(4832),
    [anon_sym_realtime] = ACTIONS(4832),
    [anon_sym_supply0] = ACTIONS(4832),
    [anon_sym_supply1] = ACTIONS(4832),
    [anon_sym_signed] = ACTIONS(4832),
    [anon_sym_unsigned] = ACTIONS(4832),
    [anon_sym_task] = ACTIONS(4832),
    [anon_sym_assert] = ACTIONS(4832),
    [anon_sym_property] = ACTIONS(4832),
    [anon_sym_assume] = ACTIONS(4832),
    [anon_sym_cover] = ACTIONS(4832),
    [anon_sym_sequence] = ACTIONS(4832),
    [anon_sym_restrict] = ACTIONS(4832),
    [anon_sym_not] = ACTIONS(4832),
    [anon_sym_or] = ACTIONS(4832),
    [anon_sym_and] = ACTIONS(4832),
    [anon_sym_case] = ACTIONS(4832),
    [anon_sym_always] = ACTIONS(4832),
    [anon_sym_covergroup] = ACTIONS(4832),
    [anon_sym_let] = ACTIONS(4832),
    [anon_sym_pulldown] = ACTIONS(4832),
    [anon_sym_pullup] = ACTIONS(4832),
    [anon_sym_cmos] = ACTIONS(4832),
    [anon_sym_rcmos] = ACTIONS(4832),
    [anon_sym_bufif0] = ACTIONS(4832),
    [anon_sym_bufif1] = ACTIONS(4832),
    [anon_sym_notif0] = ACTIONS(4832),
    [anon_sym_notif1] = ACTIONS(4832),
    [anon_sym_nmos] = ACTIONS(4832),
    [anon_sym_pmos] = ACTIONS(4832),
    [anon_sym_rnmos] = ACTIONS(4832),
    [anon_sym_rpmos] = ACTIONS(4832),
    [anon_sym_nand] = ACTIONS(4832),
    [anon_sym_nor] = ACTIONS(4832),
    [anon_sym_xor] = ACTIONS(4832),
    [anon_sym_xnor] = ACTIONS(4832),
    [anon_sym_buf] = ACTIONS(4832),
    [anon_sym_tranif0] = ACTIONS(4832),
    [anon_sym_tranif1] = ACTIONS(4832),
    [anon_sym_rtranif1] = ACTIONS(4832),
    [anon_sym_rtranif0] = ACTIONS(4832),
    [anon_sym_tran] = ACTIONS(4832),
    [anon_sym_rtran] = ACTIONS(4832),
    [anon_sym_generate] = ACTIONS(4832),
    [anon_sym_endgenerate] = ACTIONS(4832),
    [anon_sym_for] = ACTIONS(4832),
    [anon_sym_initial] = ACTIONS(4832),
    [anon_sym_assign] = ACTIONS(4832),
    [anon_sym_alias] = ACTIONS(4832),
    [anon_sym_always_comb] = ACTIONS(4832),
    [anon_sym_always_latch] = ACTIONS(4832),
    [anon_sym_always_ff] = ACTIONS(4832),
    [anon_sym_final] = ACTIONS(4832),
    [anon_sym_global] = ACTIONS(4832),
    [anon_sym_LPAREN_STAR] = ACTIONS(4830),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4830),
    [anon_sym_DOLLARunit] = ACTIONS(4830),
  },
  [5143] = {
    [sym_simple_identifier] = ACTIONS(5198),
    [anon_sym_wire] = ACTIONS(5198),
    [anon_sym_tri] = ACTIONS(5198),
    [anon_sym_tri0] = ACTIONS(5198),
    [anon_sym_tri1] = ACTIONS(5198),
    [anon_sym_wand] = ACTIONS(5198),
    [anon_sym_triand] = ACTIONS(5198),
    [anon_sym_wor] = ACTIONS(5198),
    [anon_sym_trior] = ACTIONS(5198),
    [anon_sym_trireg] = ACTIONS(5198),
    [anon_sym_uwire] = ACTIONS(5198),
    [anon_sym_SEMI] = ACTIONS(5196),
    [anon_sym_extern] = ACTIONS(5198),
    [anon_sym_interface] = ACTIONS(5198),
    [anon_sym_checker] = ACTIONS(5198),
    [anon_sym_virtual] = ACTIONS(5198),
    [anon_sym_class] = ACTIONS(5198),
    [anon_sym_type] = ACTIONS(5198),
    [anon_sym_DOLLARfatal] = ACTIONS(5196),
    [anon_sym_DOLLARerror] = ACTIONS(5196),
    [anon_sym_DOLLARwarning] = ACTIONS(5196),
    [anon_sym_DOLLARinfo] = ACTIONS(5196),
    [anon_sym_default] = ACTIONS(5198),
    [anon_sym_clocking] = ACTIONS(5198),
    [anon_sym_defparam] = ACTIONS(5198),
    [anon_sym_bind] = ACTIONS(5198),
    [anon_sym_rand] = ACTIONS(5198),
    [anon_sym_const] = ACTIONS(5198),
    [anon_sym_function] = ACTIONS(5198),
    [anon_sym_static] = ACTIONS(5198),
    [anon_sym_constraint] = ACTIONS(5198),
    [anon_sym_if] = ACTIONS(5198),
    [anon_sym_else] = ACTIONS(5198),
    [anon_sym_LBRACK] = ACTIONS(5196),
    [anon_sym_localparam] = ACTIONS(5198),
    [anon_sym_parameter] = ACTIONS(5198),
    [anon_sym_var] = ACTIONS(5198),
    [anon_sym_import] = ACTIONS(5198),
    [anon_sym_export] = ACTIONS(5198),
    [anon_sym_genvar] = ACTIONS(5198),
    [anon_sym_interconnect] = ACTIONS(5198),
    [anon_sym_typedef] = ACTIONS(5198),
    [anon_sym_enum] = ACTIONS(5198),
    [anon_sym_struct] = ACTIONS(5198),
    [anon_sym_union] = ACTIONS(5198),
    [anon_sym_nettype] = ACTIONS(5198),
    [anon_sym_automatic] = ACTIONS(5198),
    [anon_sym_string] = ACTIONS(5198),
    [anon_sym_chandle] = ACTIONS(5198),
    [anon_sym_event] = ACTIONS(5198),
    [anon_sym_byte] = ACTIONS(5198),
    [anon_sym_shortint] = ACTIONS(5198),
    [anon_sym_int] = ACTIONS(5198),
    [anon_sym_longint] = ACTIONS(5198),
    [anon_sym_integer] = ACTIONS(5198),
    [anon_sym_time] = ACTIONS(5198),
    [anon_sym_bit] = ACTIONS(5198),
    [anon_sym_logic] = ACTIONS(5198),
    [anon_sym_reg] = ACTIONS(5198),
    [anon_sym_shortreal] = ACTIONS(5198),
    [anon_sym_real] = ACTIONS(5198),
    [anon_sym_realtime] = ACTIONS(5198),
    [anon_sym_supply0] = ACTIONS(5198),
    [anon_sym_supply1] = ACTIONS(5198),
    [anon_sym_signed] = ACTIONS(5198),
    [anon_sym_unsigned] = ACTIONS(5198),
    [anon_sym_task] = ACTIONS(5198),
    [anon_sym_assert] = ACTIONS(5198),
    [anon_sym_property] = ACTIONS(5198),
    [anon_sym_assume] = ACTIONS(5198),
    [anon_sym_cover] = ACTIONS(5198),
    [anon_sym_sequence] = ACTIONS(5198),
    [anon_sym_restrict] = ACTIONS(5198),
    [anon_sym_not] = ACTIONS(5198),
    [anon_sym_or] = ACTIONS(5198),
    [anon_sym_and] = ACTIONS(5198),
    [anon_sym_case] = ACTIONS(5198),
    [anon_sym_always] = ACTIONS(5198),
    [anon_sym_covergroup] = ACTIONS(5198),
    [anon_sym_let] = ACTIONS(5198),
    [anon_sym_pulldown] = ACTIONS(5198),
    [anon_sym_pullup] = ACTIONS(5198),
    [anon_sym_cmos] = ACTIONS(5198),
    [anon_sym_rcmos] = ACTIONS(5198),
    [anon_sym_bufif0] = ACTIONS(5198),
    [anon_sym_bufif1] = ACTIONS(5198),
    [anon_sym_notif0] = ACTIONS(5198),
    [anon_sym_notif1] = ACTIONS(5198),
    [anon_sym_nmos] = ACTIONS(5198),
    [anon_sym_pmos] = ACTIONS(5198),
    [anon_sym_rnmos] = ACTIONS(5198),
    [anon_sym_rpmos] = ACTIONS(5198),
    [anon_sym_nand] = ACTIONS(5198),
    [anon_sym_nor] = ACTIONS(5198),
    [anon_sym_xor] = ACTIONS(5198),
    [anon_sym_xnor] = ACTIONS(5198),
    [anon_sym_buf] = ACTIONS(5198),
    [anon_sym_tranif0] = ACTIONS(5198),
    [anon_sym_tranif1] = ACTIONS(5198),
    [anon_sym_rtranif1] = ACTIONS(5198),
    [anon_sym_rtranif0] = ACTIONS(5198),
    [anon_sym_tran] = ACTIONS(5198),
    [anon_sym_rtran] = ACTIONS(5198),
    [anon_sym_generate] = ACTIONS(5198),
    [anon_sym_endgenerate] = ACTIONS(5198),
    [anon_sym_for] = ACTIONS(5198),
    [anon_sym_initial] = ACTIONS(5198),
    [anon_sym_assign] = ACTIONS(5198),
    [anon_sym_alias] = ACTIONS(5198),
    [anon_sym_always_comb] = ACTIONS(5198),
    [anon_sym_always_latch] = ACTIONS(5198),
    [anon_sym_always_ff] = ACTIONS(5198),
    [anon_sym_final] = ACTIONS(5198),
    [anon_sym_global] = ACTIONS(5198),
    [anon_sym_LPAREN_STAR] = ACTIONS(5196),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5196),
    [anon_sym_DOLLARunit] = ACTIONS(5196),
  },
  [5144] = {
    [sym_simple_identifier] = ACTIONS(6759),
    [anon_sym_wire] = ACTIONS(6759),
    [anon_sym_tri] = ACTIONS(6759),
    [anon_sym_tri0] = ACTIONS(6759),
    [anon_sym_tri1] = ACTIONS(6759),
    [anon_sym_wand] = ACTIONS(6759),
    [anon_sym_triand] = ACTIONS(6759),
    [anon_sym_wor] = ACTIONS(6759),
    [anon_sym_trior] = ACTIONS(6759),
    [anon_sym_trireg] = ACTIONS(6759),
    [anon_sym_uwire] = ACTIONS(6759),
    [anon_sym_SEMI] = ACTIONS(6762),
    [anon_sym_extern] = ACTIONS(6759),
    [anon_sym_interface] = ACTIONS(6759),
    [anon_sym_checker] = ACTIONS(6759),
    [anon_sym_virtual] = ACTIONS(6759),
    [anon_sym_class] = ACTIONS(6759),
    [anon_sym_type] = ACTIONS(6759),
    [anon_sym_DOLLARfatal] = ACTIONS(6762),
    [anon_sym_DOLLARerror] = ACTIONS(6762),
    [anon_sym_DOLLARwarning] = ACTIONS(6762),
    [anon_sym_DOLLARinfo] = ACTIONS(6762),
    [anon_sym_default] = ACTIONS(6759),
    [anon_sym_clocking] = ACTIONS(6759),
    [anon_sym_defparam] = ACTIONS(6759),
    [anon_sym_bind] = ACTIONS(6759),
    [anon_sym_rand] = ACTIONS(6759),
    [anon_sym_const] = ACTIONS(6759),
    [anon_sym_function] = ACTIONS(6759),
    [anon_sym_static] = ACTIONS(6759),
    [anon_sym_constraint] = ACTIONS(6759),
    [anon_sym_if] = ACTIONS(6759),
    [anon_sym_else] = ACTIONS(6759),
    [anon_sym_LBRACK] = ACTIONS(6762),
    [anon_sym_localparam] = ACTIONS(6759),
    [anon_sym_parameter] = ACTIONS(6759),
    [anon_sym_var] = ACTIONS(6759),
    [anon_sym_import] = ACTIONS(6759),
    [anon_sym_export] = ACTIONS(6759),
    [anon_sym_genvar] = ACTIONS(6759),
    [anon_sym_interconnect] = ACTIONS(6759),
    [anon_sym_typedef] = ACTIONS(6759),
    [anon_sym_enum] = ACTIONS(6759),
    [anon_sym_struct] = ACTIONS(6759),
    [anon_sym_union] = ACTIONS(6759),
    [anon_sym_nettype] = ACTIONS(6759),
    [anon_sym_automatic] = ACTIONS(6759),
    [anon_sym_string] = ACTIONS(6759),
    [anon_sym_chandle] = ACTIONS(6759),
    [anon_sym_event] = ACTIONS(6759),
    [anon_sym_byte] = ACTIONS(6759),
    [anon_sym_shortint] = ACTIONS(6759),
    [anon_sym_int] = ACTIONS(6759),
    [anon_sym_longint] = ACTIONS(6759),
    [anon_sym_integer] = ACTIONS(6759),
    [anon_sym_time] = ACTIONS(6759),
    [anon_sym_bit] = ACTIONS(6759),
    [anon_sym_logic] = ACTIONS(6759),
    [anon_sym_reg] = ACTIONS(6759),
    [anon_sym_shortreal] = ACTIONS(6759),
    [anon_sym_real] = ACTIONS(6759),
    [anon_sym_realtime] = ACTIONS(6759),
    [anon_sym_supply0] = ACTIONS(6759),
    [anon_sym_supply1] = ACTIONS(6759),
    [anon_sym_signed] = ACTIONS(6759),
    [anon_sym_unsigned] = ACTIONS(6759),
    [anon_sym_task] = ACTIONS(6759),
    [anon_sym_assert] = ACTIONS(6759),
    [anon_sym_property] = ACTIONS(6759),
    [anon_sym_assume] = ACTIONS(6759),
    [anon_sym_cover] = ACTIONS(6759),
    [anon_sym_sequence] = ACTIONS(6759),
    [anon_sym_restrict] = ACTIONS(6759),
    [anon_sym_not] = ACTIONS(6759),
    [anon_sym_or] = ACTIONS(6759),
    [anon_sym_and] = ACTIONS(6759),
    [anon_sym_case] = ACTIONS(6759),
    [anon_sym_always] = ACTIONS(6759),
    [anon_sym_covergroup] = ACTIONS(6759),
    [anon_sym_let] = ACTIONS(6759),
    [anon_sym_pulldown] = ACTIONS(6759),
    [anon_sym_pullup] = ACTIONS(6759),
    [anon_sym_cmos] = ACTIONS(6759),
    [anon_sym_rcmos] = ACTIONS(6759),
    [anon_sym_bufif0] = ACTIONS(6759),
    [anon_sym_bufif1] = ACTIONS(6759),
    [anon_sym_notif0] = ACTIONS(6759),
    [anon_sym_notif1] = ACTIONS(6759),
    [anon_sym_nmos] = ACTIONS(6759),
    [anon_sym_pmos] = ACTIONS(6759),
    [anon_sym_rnmos] = ACTIONS(6759),
    [anon_sym_rpmos] = ACTIONS(6759),
    [anon_sym_nand] = ACTIONS(6759),
    [anon_sym_nor] = ACTIONS(6759),
    [anon_sym_xor] = ACTIONS(6759),
    [anon_sym_xnor] = ACTIONS(6759),
    [anon_sym_buf] = ACTIONS(6759),
    [anon_sym_tranif0] = ACTIONS(6759),
    [anon_sym_tranif1] = ACTIONS(6759),
    [anon_sym_rtranif1] = ACTIONS(6759),
    [anon_sym_rtranif0] = ACTIONS(6759),
    [anon_sym_tran] = ACTIONS(6759),
    [anon_sym_rtran] = ACTIONS(6759),
    [anon_sym_generate] = ACTIONS(6759),
    [anon_sym_endgenerate] = ACTIONS(6759),
    [anon_sym_for] = ACTIONS(6759),
    [anon_sym_initial] = ACTIONS(6759),
    [anon_sym_assign] = ACTIONS(6759),
    [anon_sym_alias] = ACTIONS(6759),
    [anon_sym_always_comb] = ACTIONS(6759),
    [anon_sym_always_latch] = ACTIONS(6759),
    [anon_sym_always_ff] = ACTIONS(6759),
    [anon_sym_final] = ACTIONS(6759),
    [anon_sym_global] = ACTIONS(6759),
    [anon_sym_LPAREN_STAR] = ACTIONS(6762),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6762),
    [anon_sym_DOLLARunit] = ACTIONS(6762),
  },
  [5145] = {
    [sym_simple_identifier] = ACTIONS(5352),
    [anon_sym_wire] = ACTIONS(5352),
    [anon_sym_tri] = ACTIONS(5352),
    [anon_sym_tri0] = ACTIONS(5352),
    [anon_sym_tri1] = ACTIONS(5352),
    [anon_sym_wand] = ACTIONS(5352),
    [anon_sym_triand] = ACTIONS(5352),
    [anon_sym_wor] = ACTIONS(5352),
    [anon_sym_trior] = ACTIONS(5352),
    [anon_sym_trireg] = ACTIONS(5352),
    [anon_sym_uwire] = ACTIONS(5352),
    [anon_sym_SEMI] = ACTIONS(5350),
    [anon_sym_extern] = ACTIONS(5352),
    [anon_sym_interface] = ACTIONS(5352),
    [anon_sym_checker] = ACTIONS(5352),
    [anon_sym_virtual] = ACTIONS(5352),
    [anon_sym_class] = ACTIONS(5352),
    [anon_sym_type] = ACTIONS(5352),
    [anon_sym_DOLLARfatal] = ACTIONS(5350),
    [anon_sym_DOLLARerror] = ACTIONS(5350),
    [anon_sym_DOLLARwarning] = ACTIONS(5350),
    [anon_sym_DOLLARinfo] = ACTIONS(5350),
    [anon_sym_default] = ACTIONS(5352),
    [anon_sym_clocking] = ACTIONS(5352),
    [anon_sym_defparam] = ACTIONS(5352),
    [anon_sym_bind] = ACTIONS(5352),
    [anon_sym_rand] = ACTIONS(5352),
    [anon_sym_const] = ACTIONS(5352),
    [anon_sym_function] = ACTIONS(5352),
    [anon_sym_static] = ACTIONS(5352),
    [anon_sym_constraint] = ACTIONS(5352),
    [anon_sym_if] = ACTIONS(5352),
    [anon_sym_else] = ACTIONS(5352),
    [anon_sym_LBRACK] = ACTIONS(5350),
    [anon_sym_localparam] = ACTIONS(5352),
    [anon_sym_parameter] = ACTIONS(5352),
    [anon_sym_var] = ACTIONS(5352),
    [anon_sym_import] = ACTIONS(5352),
    [anon_sym_export] = ACTIONS(5352),
    [anon_sym_genvar] = ACTIONS(5352),
    [anon_sym_interconnect] = ACTIONS(5352),
    [anon_sym_typedef] = ACTIONS(5352),
    [anon_sym_enum] = ACTIONS(5352),
    [anon_sym_struct] = ACTIONS(5352),
    [anon_sym_union] = ACTIONS(5352),
    [anon_sym_nettype] = ACTIONS(5352),
    [anon_sym_automatic] = ACTIONS(5352),
    [anon_sym_string] = ACTIONS(5352),
    [anon_sym_chandle] = ACTIONS(5352),
    [anon_sym_event] = ACTIONS(5352),
    [anon_sym_byte] = ACTIONS(5352),
    [anon_sym_shortint] = ACTIONS(5352),
    [anon_sym_int] = ACTIONS(5352),
    [anon_sym_longint] = ACTIONS(5352),
    [anon_sym_integer] = ACTIONS(5352),
    [anon_sym_time] = ACTIONS(5352),
    [anon_sym_bit] = ACTIONS(5352),
    [anon_sym_logic] = ACTIONS(5352),
    [anon_sym_reg] = ACTIONS(5352),
    [anon_sym_shortreal] = ACTIONS(5352),
    [anon_sym_real] = ACTIONS(5352),
    [anon_sym_realtime] = ACTIONS(5352),
    [anon_sym_supply0] = ACTIONS(5352),
    [anon_sym_supply1] = ACTIONS(5352),
    [anon_sym_signed] = ACTIONS(5352),
    [anon_sym_unsigned] = ACTIONS(5352),
    [anon_sym_task] = ACTIONS(5352),
    [anon_sym_assert] = ACTIONS(5352),
    [anon_sym_property] = ACTIONS(5352),
    [anon_sym_assume] = ACTIONS(5352),
    [anon_sym_cover] = ACTIONS(5352),
    [anon_sym_sequence] = ACTIONS(5352),
    [anon_sym_restrict] = ACTIONS(5352),
    [anon_sym_not] = ACTIONS(5352),
    [anon_sym_or] = ACTIONS(5352),
    [anon_sym_and] = ACTIONS(5352),
    [anon_sym_case] = ACTIONS(5352),
    [anon_sym_always] = ACTIONS(5352),
    [anon_sym_covergroup] = ACTIONS(5352),
    [anon_sym_let] = ACTIONS(5352),
    [anon_sym_pulldown] = ACTIONS(5352),
    [anon_sym_pullup] = ACTIONS(5352),
    [anon_sym_cmos] = ACTIONS(5352),
    [anon_sym_rcmos] = ACTIONS(5352),
    [anon_sym_bufif0] = ACTIONS(5352),
    [anon_sym_bufif1] = ACTIONS(5352),
    [anon_sym_notif0] = ACTIONS(5352),
    [anon_sym_notif1] = ACTIONS(5352),
    [anon_sym_nmos] = ACTIONS(5352),
    [anon_sym_pmos] = ACTIONS(5352),
    [anon_sym_rnmos] = ACTIONS(5352),
    [anon_sym_rpmos] = ACTIONS(5352),
    [anon_sym_nand] = ACTIONS(5352),
    [anon_sym_nor] = ACTIONS(5352),
    [anon_sym_xor] = ACTIONS(5352),
    [anon_sym_xnor] = ACTIONS(5352),
    [anon_sym_buf] = ACTIONS(5352),
    [anon_sym_tranif0] = ACTIONS(5352),
    [anon_sym_tranif1] = ACTIONS(5352),
    [anon_sym_rtranif1] = ACTIONS(5352),
    [anon_sym_rtranif0] = ACTIONS(5352),
    [anon_sym_tran] = ACTIONS(5352),
    [anon_sym_rtran] = ACTIONS(5352),
    [anon_sym_generate] = ACTIONS(5352),
    [anon_sym_endgenerate] = ACTIONS(5352),
    [anon_sym_for] = ACTIONS(5352),
    [anon_sym_initial] = ACTIONS(5352),
    [anon_sym_assign] = ACTIONS(5352),
    [anon_sym_alias] = ACTIONS(5352),
    [anon_sym_always_comb] = ACTIONS(5352),
    [anon_sym_always_latch] = ACTIONS(5352),
    [anon_sym_always_ff] = ACTIONS(5352),
    [anon_sym_final] = ACTIONS(5352),
    [anon_sym_global] = ACTIONS(5352),
    [anon_sym_LPAREN_STAR] = ACTIONS(5350),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5350),
    [anon_sym_DOLLARunit] = ACTIONS(5350),
  },
  [5146] = {
    [sym_simple_identifier] = ACTIONS(6345),
    [anon_sym_wire] = ACTIONS(6345),
    [anon_sym_tri] = ACTIONS(6345),
    [anon_sym_tri0] = ACTIONS(6345),
    [anon_sym_tri1] = ACTIONS(6345),
    [anon_sym_wand] = ACTIONS(6345),
    [anon_sym_triand] = ACTIONS(6345),
    [anon_sym_wor] = ACTIONS(6345),
    [anon_sym_trior] = ACTIONS(6345),
    [anon_sym_trireg] = ACTIONS(6345),
    [anon_sym_uwire] = ACTIONS(6345),
    [anon_sym_SEMI] = ACTIONS(6347),
    [anon_sym_extern] = ACTIONS(6345),
    [anon_sym_interface] = ACTIONS(6345),
    [anon_sym_checker] = ACTIONS(6345),
    [anon_sym_virtual] = ACTIONS(6345),
    [anon_sym_class] = ACTIONS(6345),
    [anon_sym_type] = ACTIONS(6345),
    [anon_sym_DOLLARfatal] = ACTIONS(6347),
    [anon_sym_DOLLARerror] = ACTIONS(6347),
    [anon_sym_DOLLARwarning] = ACTIONS(6347),
    [anon_sym_DOLLARinfo] = ACTIONS(6347),
    [anon_sym_default] = ACTIONS(6345),
    [anon_sym_clocking] = ACTIONS(6345),
    [anon_sym_defparam] = ACTIONS(6345),
    [anon_sym_bind] = ACTIONS(6345),
    [anon_sym_rand] = ACTIONS(6345),
    [anon_sym_const] = ACTIONS(6345),
    [anon_sym_function] = ACTIONS(6345),
    [anon_sym_static] = ACTIONS(6345),
    [anon_sym_constraint] = ACTIONS(6345),
    [anon_sym_if] = ACTIONS(6345),
    [anon_sym_else] = ACTIONS(6345),
    [anon_sym_LBRACK] = ACTIONS(6347),
    [anon_sym_localparam] = ACTIONS(6345),
    [anon_sym_parameter] = ACTIONS(6345),
    [anon_sym_var] = ACTIONS(6345),
    [anon_sym_import] = ACTIONS(6345),
    [anon_sym_export] = ACTIONS(6345),
    [anon_sym_genvar] = ACTIONS(6345),
    [anon_sym_interconnect] = ACTIONS(6345),
    [anon_sym_typedef] = ACTIONS(6345),
    [anon_sym_enum] = ACTIONS(6345),
    [anon_sym_struct] = ACTIONS(6345),
    [anon_sym_union] = ACTIONS(6345),
    [anon_sym_nettype] = ACTIONS(6345),
    [anon_sym_automatic] = ACTIONS(6345),
    [anon_sym_string] = ACTIONS(6345),
    [anon_sym_chandle] = ACTIONS(6345),
    [anon_sym_event] = ACTIONS(6345),
    [anon_sym_byte] = ACTIONS(6345),
    [anon_sym_shortint] = ACTIONS(6345),
    [anon_sym_int] = ACTIONS(6345),
    [anon_sym_longint] = ACTIONS(6345),
    [anon_sym_integer] = ACTIONS(6345),
    [anon_sym_time] = ACTIONS(6345),
    [anon_sym_bit] = ACTIONS(6345),
    [anon_sym_logic] = ACTIONS(6345),
    [anon_sym_reg] = ACTIONS(6345),
    [anon_sym_shortreal] = ACTIONS(6345),
    [anon_sym_real] = ACTIONS(6345),
    [anon_sym_realtime] = ACTIONS(6345),
    [anon_sym_supply0] = ACTIONS(6345),
    [anon_sym_supply1] = ACTIONS(6345),
    [anon_sym_signed] = ACTIONS(6345),
    [anon_sym_unsigned] = ACTIONS(6345),
    [anon_sym_task] = ACTIONS(6345),
    [anon_sym_assert] = ACTIONS(6345),
    [anon_sym_property] = ACTIONS(6345),
    [anon_sym_assume] = ACTIONS(6345),
    [anon_sym_cover] = ACTIONS(6345),
    [anon_sym_sequence] = ACTIONS(6345),
    [anon_sym_restrict] = ACTIONS(6345),
    [anon_sym_not] = ACTIONS(6345),
    [anon_sym_or] = ACTIONS(6345),
    [anon_sym_and] = ACTIONS(6345),
    [anon_sym_case] = ACTIONS(6345),
    [anon_sym_always] = ACTIONS(6345),
    [anon_sym_covergroup] = ACTIONS(6345),
    [anon_sym_let] = ACTIONS(6345),
    [anon_sym_pulldown] = ACTIONS(6345),
    [anon_sym_pullup] = ACTIONS(6345),
    [anon_sym_cmos] = ACTIONS(6345),
    [anon_sym_rcmos] = ACTIONS(6345),
    [anon_sym_bufif0] = ACTIONS(6345),
    [anon_sym_bufif1] = ACTIONS(6345),
    [anon_sym_notif0] = ACTIONS(6345),
    [anon_sym_notif1] = ACTIONS(6345),
    [anon_sym_nmos] = ACTIONS(6345),
    [anon_sym_pmos] = ACTIONS(6345),
    [anon_sym_rnmos] = ACTIONS(6345),
    [anon_sym_rpmos] = ACTIONS(6345),
    [anon_sym_nand] = ACTIONS(6345),
    [anon_sym_nor] = ACTIONS(6345),
    [anon_sym_xor] = ACTIONS(6345),
    [anon_sym_xnor] = ACTIONS(6345),
    [anon_sym_buf] = ACTIONS(6345),
    [anon_sym_tranif0] = ACTIONS(6345),
    [anon_sym_tranif1] = ACTIONS(6345),
    [anon_sym_rtranif1] = ACTIONS(6345),
    [anon_sym_rtranif0] = ACTIONS(6345),
    [anon_sym_tran] = ACTIONS(6345),
    [anon_sym_rtran] = ACTIONS(6345),
    [anon_sym_generate] = ACTIONS(6345),
    [anon_sym_endgenerate] = ACTIONS(6345),
    [anon_sym_for] = ACTIONS(6345),
    [anon_sym_initial] = ACTIONS(6345),
    [anon_sym_assign] = ACTIONS(6345),
    [anon_sym_alias] = ACTIONS(6345),
    [anon_sym_always_comb] = ACTIONS(6345),
    [anon_sym_always_latch] = ACTIONS(6345),
    [anon_sym_always_ff] = ACTIONS(6345),
    [anon_sym_final] = ACTIONS(6345),
    [anon_sym_global] = ACTIONS(6345),
    [anon_sym_LPAREN_STAR] = ACTIONS(6347),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6347),
    [anon_sym_DOLLARunit] = ACTIONS(6347),
  },
  [5147] = {
    [sym_simple_identifier] = ACTIONS(6585),
    [anon_sym_wire] = ACTIONS(6585),
    [anon_sym_tri] = ACTIONS(6585),
    [anon_sym_tri0] = ACTIONS(6585),
    [anon_sym_tri1] = ACTIONS(6585),
    [anon_sym_wand] = ACTIONS(6585),
    [anon_sym_triand] = ACTIONS(6585),
    [anon_sym_wor] = ACTIONS(6585),
    [anon_sym_trior] = ACTIONS(6585),
    [anon_sym_trireg] = ACTIONS(6585),
    [anon_sym_uwire] = ACTIONS(6585),
    [anon_sym_SEMI] = ACTIONS(6587),
    [anon_sym_extern] = ACTIONS(6585),
    [anon_sym_interface] = ACTIONS(6585),
    [anon_sym_checker] = ACTIONS(6585),
    [anon_sym_virtual] = ACTIONS(6585),
    [anon_sym_class] = ACTIONS(6585),
    [anon_sym_type] = ACTIONS(6585),
    [anon_sym_DOLLARfatal] = ACTIONS(6587),
    [anon_sym_DOLLARerror] = ACTIONS(6587),
    [anon_sym_DOLLARwarning] = ACTIONS(6587),
    [anon_sym_DOLLARinfo] = ACTIONS(6587),
    [anon_sym_default] = ACTIONS(6585),
    [anon_sym_clocking] = ACTIONS(6585),
    [anon_sym_defparam] = ACTIONS(6585),
    [anon_sym_bind] = ACTIONS(6585),
    [anon_sym_rand] = ACTIONS(6585),
    [anon_sym_const] = ACTIONS(6585),
    [anon_sym_function] = ACTIONS(6585),
    [anon_sym_static] = ACTIONS(6585),
    [anon_sym_constraint] = ACTIONS(6585),
    [anon_sym_if] = ACTIONS(6585),
    [anon_sym_else] = ACTIONS(6585),
    [anon_sym_LBRACK] = ACTIONS(6587),
    [anon_sym_localparam] = ACTIONS(6585),
    [anon_sym_parameter] = ACTIONS(6585),
    [anon_sym_var] = ACTIONS(6585),
    [anon_sym_import] = ACTIONS(6585),
    [anon_sym_export] = ACTIONS(6585),
    [anon_sym_genvar] = ACTIONS(6585),
    [anon_sym_interconnect] = ACTIONS(6585),
    [anon_sym_typedef] = ACTIONS(6585),
    [anon_sym_enum] = ACTIONS(6585),
    [anon_sym_struct] = ACTIONS(6585),
    [anon_sym_union] = ACTIONS(6585),
    [anon_sym_nettype] = ACTIONS(6585),
    [anon_sym_automatic] = ACTIONS(6585),
    [anon_sym_string] = ACTIONS(6585),
    [anon_sym_chandle] = ACTIONS(6585),
    [anon_sym_event] = ACTIONS(6585),
    [anon_sym_byte] = ACTIONS(6585),
    [anon_sym_shortint] = ACTIONS(6585),
    [anon_sym_int] = ACTIONS(6585),
    [anon_sym_longint] = ACTIONS(6585),
    [anon_sym_integer] = ACTIONS(6585),
    [anon_sym_time] = ACTIONS(6585),
    [anon_sym_bit] = ACTIONS(6585),
    [anon_sym_logic] = ACTIONS(6585),
    [anon_sym_reg] = ACTIONS(6585),
    [anon_sym_shortreal] = ACTIONS(6585),
    [anon_sym_real] = ACTIONS(6585),
    [anon_sym_realtime] = ACTIONS(6585),
    [anon_sym_supply0] = ACTIONS(6585),
    [anon_sym_supply1] = ACTIONS(6585),
    [anon_sym_signed] = ACTIONS(6585),
    [anon_sym_unsigned] = ACTIONS(6585),
    [anon_sym_task] = ACTIONS(6585),
    [anon_sym_assert] = ACTIONS(6585),
    [anon_sym_property] = ACTIONS(6585),
    [anon_sym_assume] = ACTIONS(6585),
    [anon_sym_cover] = ACTIONS(6585),
    [anon_sym_sequence] = ACTIONS(6585),
    [anon_sym_restrict] = ACTIONS(6585),
    [anon_sym_not] = ACTIONS(6585),
    [anon_sym_or] = ACTIONS(6585),
    [anon_sym_and] = ACTIONS(6585),
    [anon_sym_case] = ACTIONS(6585),
    [anon_sym_always] = ACTIONS(6585),
    [anon_sym_covergroup] = ACTIONS(6585),
    [anon_sym_let] = ACTIONS(6585),
    [anon_sym_pulldown] = ACTIONS(6585),
    [anon_sym_pullup] = ACTIONS(6585),
    [anon_sym_cmos] = ACTIONS(6585),
    [anon_sym_rcmos] = ACTIONS(6585),
    [anon_sym_bufif0] = ACTIONS(6585),
    [anon_sym_bufif1] = ACTIONS(6585),
    [anon_sym_notif0] = ACTIONS(6585),
    [anon_sym_notif1] = ACTIONS(6585),
    [anon_sym_nmos] = ACTIONS(6585),
    [anon_sym_pmos] = ACTIONS(6585),
    [anon_sym_rnmos] = ACTIONS(6585),
    [anon_sym_rpmos] = ACTIONS(6585),
    [anon_sym_nand] = ACTIONS(6585),
    [anon_sym_nor] = ACTIONS(6585),
    [anon_sym_xor] = ACTIONS(6585),
    [anon_sym_xnor] = ACTIONS(6585),
    [anon_sym_buf] = ACTIONS(6585),
    [anon_sym_tranif0] = ACTIONS(6585),
    [anon_sym_tranif1] = ACTIONS(6585),
    [anon_sym_rtranif1] = ACTIONS(6585),
    [anon_sym_rtranif0] = ACTIONS(6585),
    [anon_sym_tran] = ACTIONS(6585),
    [anon_sym_rtran] = ACTIONS(6585),
    [anon_sym_generate] = ACTIONS(6585),
    [anon_sym_endgenerate] = ACTIONS(6585),
    [anon_sym_for] = ACTIONS(6585),
    [anon_sym_initial] = ACTIONS(6585),
    [anon_sym_assign] = ACTIONS(6585),
    [anon_sym_alias] = ACTIONS(6585),
    [anon_sym_always_comb] = ACTIONS(6585),
    [anon_sym_always_latch] = ACTIONS(6585),
    [anon_sym_always_ff] = ACTIONS(6585),
    [anon_sym_final] = ACTIONS(6585),
    [anon_sym_global] = ACTIONS(6585),
    [anon_sym_LPAREN_STAR] = ACTIONS(6587),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6587),
    [anon_sym_DOLLARunit] = ACTIONS(6587),
  },
  [5148] = {
    [sym_simple_identifier] = ACTIONS(6457),
    [anon_sym_wire] = ACTIONS(6457),
    [anon_sym_tri] = ACTIONS(6457),
    [anon_sym_tri0] = ACTIONS(6457),
    [anon_sym_tri1] = ACTIONS(6457),
    [anon_sym_wand] = ACTIONS(6457),
    [anon_sym_triand] = ACTIONS(6457),
    [anon_sym_wor] = ACTIONS(6457),
    [anon_sym_trior] = ACTIONS(6457),
    [anon_sym_trireg] = ACTIONS(6457),
    [anon_sym_uwire] = ACTIONS(6457),
    [anon_sym_SEMI] = ACTIONS(6459),
    [anon_sym_extern] = ACTIONS(6457),
    [anon_sym_interface] = ACTIONS(6457),
    [anon_sym_checker] = ACTIONS(6457),
    [anon_sym_virtual] = ACTIONS(6457),
    [anon_sym_class] = ACTIONS(6457),
    [anon_sym_type] = ACTIONS(6457),
    [anon_sym_DOLLARfatal] = ACTIONS(6459),
    [anon_sym_DOLLARerror] = ACTIONS(6459),
    [anon_sym_DOLLARwarning] = ACTIONS(6459),
    [anon_sym_DOLLARinfo] = ACTIONS(6459),
    [anon_sym_default] = ACTIONS(6457),
    [anon_sym_clocking] = ACTIONS(6457),
    [anon_sym_defparam] = ACTIONS(6457),
    [anon_sym_bind] = ACTIONS(6457),
    [anon_sym_rand] = ACTIONS(6457),
    [anon_sym_const] = ACTIONS(6457),
    [anon_sym_function] = ACTIONS(6457),
    [anon_sym_static] = ACTIONS(6457),
    [anon_sym_constraint] = ACTIONS(6457),
    [anon_sym_if] = ACTIONS(6457),
    [anon_sym_else] = ACTIONS(6457),
    [anon_sym_LBRACK] = ACTIONS(6459),
    [anon_sym_localparam] = ACTIONS(6457),
    [anon_sym_parameter] = ACTIONS(6457),
    [anon_sym_var] = ACTIONS(6457),
    [anon_sym_import] = ACTIONS(6457),
    [anon_sym_export] = ACTIONS(6457),
    [anon_sym_genvar] = ACTIONS(6457),
    [anon_sym_interconnect] = ACTIONS(6457),
    [anon_sym_typedef] = ACTIONS(6457),
    [anon_sym_enum] = ACTIONS(6457),
    [anon_sym_struct] = ACTIONS(6457),
    [anon_sym_union] = ACTIONS(6457),
    [anon_sym_nettype] = ACTIONS(6457),
    [anon_sym_automatic] = ACTIONS(6457),
    [anon_sym_string] = ACTIONS(6457),
    [anon_sym_chandle] = ACTIONS(6457),
    [anon_sym_event] = ACTIONS(6457),
    [anon_sym_byte] = ACTIONS(6457),
    [anon_sym_shortint] = ACTIONS(6457),
    [anon_sym_int] = ACTIONS(6457),
    [anon_sym_longint] = ACTIONS(6457),
    [anon_sym_integer] = ACTIONS(6457),
    [anon_sym_time] = ACTIONS(6457),
    [anon_sym_bit] = ACTIONS(6457),
    [anon_sym_logic] = ACTIONS(6457),
    [anon_sym_reg] = ACTIONS(6457),
    [anon_sym_shortreal] = ACTIONS(6457),
    [anon_sym_real] = ACTIONS(6457),
    [anon_sym_realtime] = ACTIONS(6457),
    [anon_sym_supply0] = ACTIONS(6457),
    [anon_sym_supply1] = ACTIONS(6457),
    [anon_sym_signed] = ACTIONS(6457),
    [anon_sym_unsigned] = ACTIONS(6457),
    [anon_sym_task] = ACTIONS(6457),
    [anon_sym_assert] = ACTIONS(6457),
    [anon_sym_property] = ACTIONS(6457),
    [anon_sym_assume] = ACTIONS(6457),
    [anon_sym_cover] = ACTIONS(6457),
    [anon_sym_sequence] = ACTIONS(6457),
    [anon_sym_restrict] = ACTIONS(6457),
    [anon_sym_not] = ACTIONS(6457),
    [anon_sym_or] = ACTIONS(6457),
    [anon_sym_and] = ACTIONS(6457),
    [anon_sym_case] = ACTIONS(6457),
    [anon_sym_always] = ACTIONS(6457),
    [anon_sym_covergroup] = ACTIONS(6457),
    [anon_sym_end] = ACTIONS(6457),
    [anon_sym_let] = ACTIONS(6457),
    [anon_sym_pulldown] = ACTIONS(6457),
    [anon_sym_pullup] = ACTIONS(6457),
    [anon_sym_cmos] = ACTIONS(6457),
    [anon_sym_rcmos] = ACTIONS(6457),
    [anon_sym_bufif0] = ACTIONS(6457),
    [anon_sym_bufif1] = ACTIONS(6457),
    [anon_sym_notif0] = ACTIONS(6457),
    [anon_sym_notif1] = ACTIONS(6457),
    [anon_sym_nmos] = ACTIONS(6457),
    [anon_sym_pmos] = ACTIONS(6457),
    [anon_sym_rnmos] = ACTIONS(6457),
    [anon_sym_rpmos] = ACTIONS(6457),
    [anon_sym_nand] = ACTIONS(6457),
    [anon_sym_nor] = ACTIONS(6457),
    [anon_sym_xor] = ACTIONS(6457),
    [anon_sym_xnor] = ACTIONS(6457),
    [anon_sym_buf] = ACTIONS(6457),
    [anon_sym_tranif0] = ACTIONS(6457),
    [anon_sym_tranif1] = ACTIONS(6457),
    [anon_sym_rtranif1] = ACTIONS(6457),
    [anon_sym_rtranif0] = ACTIONS(6457),
    [anon_sym_tran] = ACTIONS(6457),
    [anon_sym_rtran] = ACTIONS(6457),
    [anon_sym_generate] = ACTIONS(6457),
    [anon_sym_for] = ACTIONS(6457),
    [anon_sym_initial] = ACTIONS(6457),
    [anon_sym_assign] = ACTIONS(6457),
    [anon_sym_alias] = ACTIONS(6457),
    [anon_sym_always_comb] = ACTIONS(6457),
    [anon_sym_always_latch] = ACTIONS(6457),
    [anon_sym_always_ff] = ACTIONS(6457),
    [anon_sym_final] = ACTIONS(6457),
    [anon_sym_global] = ACTIONS(6457),
    [anon_sym_LPAREN_STAR] = ACTIONS(6459),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6459),
    [anon_sym_DOLLARunit] = ACTIONS(6459),
  },
  [5149] = {
    [sym_simple_identifier] = ACTIONS(5454),
    [anon_sym_wire] = ACTIONS(5454),
    [anon_sym_tri] = ACTIONS(5454),
    [anon_sym_tri0] = ACTIONS(5454),
    [anon_sym_tri1] = ACTIONS(5454),
    [anon_sym_wand] = ACTIONS(5454),
    [anon_sym_triand] = ACTIONS(5454),
    [anon_sym_wor] = ACTIONS(5454),
    [anon_sym_trior] = ACTIONS(5454),
    [anon_sym_trireg] = ACTIONS(5454),
    [anon_sym_uwire] = ACTIONS(5454),
    [anon_sym_SEMI] = ACTIONS(5456),
    [anon_sym_extern] = ACTIONS(5454),
    [anon_sym_interface] = ACTIONS(5454),
    [anon_sym_checker] = ACTIONS(5454),
    [anon_sym_virtual] = ACTIONS(5454),
    [anon_sym_class] = ACTIONS(5454),
    [anon_sym_type] = ACTIONS(5454),
    [anon_sym_DOLLARfatal] = ACTIONS(5456),
    [anon_sym_DOLLARerror] = ACTIONS(5456),
    [anon_sym_DOLLARwarning] = ACTIONS(5456),
    [anon_sym_DOLLARinfo] = ACTIONS(5456),
    [anon_sym_default] = ACTIONS(5454),
    [anon_sym_clocking] = ACTIONS(5454),
    [anon_sym_defparam] = ACTIONS(5454),
    [anon_sym_bind] = ACTIONS(5454),
    [anon_sym_rand] = ACTIONS(5454),
    [anon_sym_const] = ACTIONS(5454),
    [anon_sym_function] = ACTIONS(5454),
    [anon_sym_static] = ACTIONS(5454),
    [anon_sym_constraint] = ACTIONS(5454),
    [anon_sym_if] = ACTIONS(5454),
    [anon_sym_else] = ACTIONS(5454),
    [anon_sym_LBRACK] = ACTIONS(5456),
    [anon_sym_localparam] = ACTIONS(5454),
    [anon_sym_parameter] = ACTIONS(5454),
    [anon_sym_var] = ACTIONS(5454),
    [anon_sym_import] = ACTIONS(5454),
    [anon_sym_export] = ACTIONS(5454),
    [anon_sym_genvar] = ACTIONS(5454),
    [anon_sym_interconnect] = ACTIONS(5454),
    [anon_sym_typedef] = ACTIONS(5454),
    [anon_sym_enum] = ACTIONS(5454),
    [anon_sym_struct] = ACTIONS(5454),
    [anon_sym_union] = ACTIONS(5454),
    [anon_sym_nettype] = ACTIONS(5454),
    [anon_sym_automatic] = ACTIONS(5454),
    [anon_sym_string] = ACTIONS(5454),
    [anon_sym_chandle] = ACTIONS(5454),
    [anon_sym_event] = ACTIONS(5454),
    [anon_sym_byte] = ACTIONS(5454),
    [anon_sym_shortint] = ACTIONS(5454),
    [anon_sym_int] = ACTIONS(5454),
    [anon_sym_longint] = ACTIONS(5454),
    [anon_sym_integer] = ACTIONS(5454),
    [anon_sym_time] = ACTIONS(5454),
    [anon_sym_bit] = ACTIONS(5454),
    [anon_sym_logic] = ACTIONS(5454),
    [anon_sym_reg] = ACTIONS(5454),
    [anon_sym_shortreal] = ACTIONS(5454),
    [anon_sym_real] = ACTIONS(5454),
    [anon_sym_realtime] = ACTIONS(5454),
    [anon_sym_supply0] = ACTIONS(5454),
    [anon_sym_supply1] = ACTIONS(5454),
    [anon_sym_signed] = ACTIONS(5454),
    [anon_sym_unsigned] = ACTIONS(5454),
    [anon_sym_task] = ACTIONS(5454),
    [anon_sym_assert] = ACTIONS(5454),
    [anon_sym_property] = ACTIONS(5454),
    [anon_sym_assume] = ACTIONS(5454),
    [anon_sym_cover] = ACTIONS(5454),
    [anon_sym_sequence] = ACTIONS(5454),
    [anon_sym_restrict] = ACTIONS(5454),
    [anon_sym_not] = ACTIONS(5454),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_and] = ACTIONS(5454),
    [anon_sym_case] = ACTIONS(5454),
    [anon_sym_always] = ACTIONS(5454),
    [anon_sym_covergroup] = ACTIONS(5454),
    [anon_sym_let] = ACTIONS(5454),
    [anon_sym_pulldown] = ACTIONS(5454),
    [anon_sym_pullup] = ACTIONS(5454),
    [anon_sym_cmos] = ACTIONS(5454),
    [anon_sym_rcmos] = ACTIONS(5454),
    [anon_sym_bufif0] = ACTIONS(5454),
    [anon_sym_bufif1] = ACTIONS(5454),
    [anon_sym_notif0] = ACTIONS(5454),
    [anon_sym_notif1] = ACTIONS(5454),
    [anon_sym_nmos] = ACTIONS(5454),
    [anon_sym_pmos] = ACTIONS(5454),
    [anon_sym_rnmos] = ACTIONS(5454),
    [anon_sym_rpmos] = ACTIONS(5454),
    [anon_sym_nand] = ACTIONS(5454),
    [anon_sym_nor] = ACTIONS(5454),
    [anon_sym_xor] = ACTIONS(5454),
    [anon_sym_xnor] = ACTIONS(5454),
    [anon_sym_buf] = ACTIONS(5454),
    [anon_sym_tranif0] = ACTIONS(5454),
    [anon_sym_tranif1] = ACTIONS(5454),
    [anon_sym_rtranif1] = ACTIONS(5454),
    [anon_sym_rtranif0] = ACTIONS(5454),
    [anon_sym_tran] = ACTIONS(5454),
    [anon_sym_rtran] = ACTIONS(5454),
    [anon_sym_generate] = ACTIONS(5454),
    [anon_sym_endgenerate] = ACTIONS(5454),
    [anon_sym_for] = ACTIONS(5454),
    [anon_sym_initial] = ACTIONS(5454),
    [anon_sym_assign] = ACTIONS(5454),
    [anon_sym_alias] = ACTIONS(5454),
    [anon_sym_always_comb] = ACTIONS(5454),
    [anon_sym_always_latch] = ACTIONS(5454),
    [anon_sym_always_ff] = ACTIONS(5454),
    [anon_sym_final] = ACTIONS(5454),
    [anon_sym_global] = ACTIONS(5454),
    [anon_sym_LPAREN_STAR] = ACTIONS(5456),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5456),
    [anon_sym_DOLLARunit] = ACTIONS(5456),
  },
  [5150] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4956),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4952),
    [sym_package_or_generate_item_declaration] = STATE(4952),
    [sym_anonymous_program] = STATE(4952),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4952),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4952),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_endpackage] = ACTIONS(11184),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [5151] = {
    [sym_simple_identifier] = ACTIONS(6169),
    [anon_sym_wire] = ACTIONS(6169),
    [anon_sym_tri] = ACTIONS(6169),
    [anon_sym_tri0] = ACTIONS(6169),
    [anon_sym_tri1] = ACTIONS(6169),
    [anon_sym_wand] = ACTIONS(6169),
    [anon_sym_triand] = ACTIONS(6169),
    [anon_sym_wor] = ACTIONS(6169),
    [anon_sym_trior] = ACTIONS(6169),
    [anon_sym_trireg] = ACTIONS(6169),
    [anon_sym_uwire] = ACTIONS(6169),
    [anon_sym_SEMI] = ACTIONS(6171),
    [anon_sym_extern] = ACTIONS(6169),
    [anon_sym_interface] = ACTIONS(6169),
    [anon_sym_checker] = ACTIONS(6169),
    [anon_sym_virtual] = ACTIONS(6169),
    [anon_sym_class] = ACTIONS(6169),
    [anon_sym_type] = ACTIONS(6169),
    [anon_sym_DOLLARfatal] = ACTIONS(6171),
    [anon_sym_DOLLARerror] = ACTIONS(6171),
    [anon_sym_DOLLARwarning] = ACTIONS(6171),
    [anon_sym_DOLLARinfo] = ACTIONS(6171),
    [anon_sym_default] = ACTIONS(6169),
    [anon_sym_clocking] = ACTIONS(6169),
    [anon_sym_defparam] = ACTIONS(6169),
    [anon_sym_bind] = ACTIONS(6169),
    [anon_sym_rand] = ACTIONS(6169),
    [anon_sym_const] = ACTIONS(6169),
    [anon_sym_function] = ACTIONS(6169),
    [anon_sym_static] = ACTIONS(6169),
    [anon_sym_constraint] = ACTIONS(6169),
    [anon_sym_if] = ACTIONS(6169),
    [anon_sym_else] = ACTIONS(6169),
    [anon_sym_LBRACK] = ACTIONS(6171),
    [anon_sym_localparam] = ACTIONS(6169),
    [anon_sym_parameter] = ACTIONS(6169),
    [anon_sym_var] = ACTIONS(6169),
    [anon_sym_import] = ACTIONS(6169),
    [anon_sym_export] = ACTIONS(6169),
    [anon_sym_genvar] = ACTIONS(6169),
    [anon_sym_interconnect] = ACTIONS(6169),
    [anon_sym_typedef] = ACTIONS(6169),
    [anon_sym_enum] = ACTIONS(6169),
    [anon_sym_struct] = ACTIONS(6169),
    [anon_sym_union] = ACTIONS(6169),
    [anon_sym_nettype] = ACTIONS(6169),
    [anon_sym_automatic] = ACTIONS(6169),
    [anon_sym_string] = ACTIONS(6169),
    [anon_sym_chandle] = ACTIONS(6169),
    [anon_sym_event] = ACTIONS(6169),
    [anon_sym_byte] = ACTIONS(6169),
    [anon_sym_shortint] = ACTIONS(6169),
    [anon_sym_int] = ACTIONS(6169),
    [anon_sym_longint] = ACTIONS(6169),
    [anon_sym_integer] = ACTIONS(6169),
    [anon_sym_time] = ACTIONS(6169),
    [anon_sym_bit] = ACTIONS(6169),
    [anon_sym_logic] = ACTIONS(6169),
    [anon_sym_reg] = ACTIONS(6169),
    [anon_sym_shortreal] = ACTIONS(6169),
    [anon_sym_real] = ACTIONS(6169),
    [anon_sym_realtime] = ACTIONS(6169),
    [anon_sym_supply0] = ACTIONS(6169),
    [anon_sym_supply1] = ACTIONS(6169),
    [anon_sym_signed] = ACTIONS(6169),
    [anon_sym_unsigned] = ACTIONS(6169),
    [anon_sym_task] = ACTIONS(6169),
    [anon_sym_assert] = ACTIONS(6169),
    [anon_sym_property] = ACTIONS(6169),
    [anon_sym_assume] = ACTIONS(6169),
    [anon_sym_cover] = ACTIONS(6169),
    [anon_sym_sequence] = ACTIONS(6169),
    [anon_sym_restrict] = ACTIONS(6169),
    [anon_sym_not] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6169),
    [anon_sym_and] = ACTIONS(6169),
    [anon_sym_case] = ACTIONS(6169),
    [anon_sym_always] = ACTIONS(6169),
    [anon_sym_covergroup] = ACTIONS(6169),
    [anon_sym_let] = ACTIONS(6169),
    [anon_sym_pulldown] = ACTIONS(6169),
    [anon_sym_pullup] = ACTIONS(6169),
    [anon_sym_cmos] = ACTIONS(6169),
    [anon_sym_rcmos] = ACTIONS(6169),
    [anon_sym_bufif0] = ACTIONS(6169),
    [anon_sym_bufif1] = ACTIONS(6169),
    [anon_sym_notif0] = ACTIONS(6169),
    [anon_sym_notif1] = ACTIONS(6169),
    [anon_sym_nmos] = ACTIONS(6169),
    [anon_sym_pmos] = ACTIONS(6169),
    [anon_sym_rnmos] = ACTIONS(6169),
    [anon_sym_rpmos] = ACTIONS(6169),
    [anon_sym_nand] = ACTIONS(6169),
    [anon_sym_nor] = ACTIONS(6169),
    [anon_sym_xor] = ACTIONS(6169),
    [anon_sym_xnor] = ACTIONS(6169),
    [anon_sym_buf] = ACTIONS(6169),
    [anon_sym_tranif0] = ACTIONS(6169),
    [anon_sym_tranif1] = ACTIONS(6169),
    [anon_sym_rtranif1] = ACTIONS(6169),
    [anon_sym_rtranif0] = ACTIONS(6169),
    [anon_sym_tran] = ACTIONS(6169),
    [anon_sym_rtran] = ACTIONS(6169),
    [anon_sym_generate] = ACTIONS(6169),
    [anon_sym_endgenerate] = ACTIONS(6169),
    [anon_sym_for] = ACTIONS(6169),
    [anon_sym_initial] = ACTIONS(6169),
    [anon_sym_assign] = ACTIONS(6169),
    [anon_sym_alias] = ACTIONS(6169),
    [anon_sym_always_comb] = ACTIONS(6169),
    [anon_sym_always_latch] = ACTIONS(6169),
    [anon_sym_always_ff] = ACTIONS(6169),
    [anon_sym_final] = ACTIONS(6169),
    [anon_sym_global] = ACTIONS(6169),
    [anon_sym_LPAREN_STAR] = ACTIONS(6171),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6171),
    [anon_sym_DOLLARunit] = ACTIONS(6171),
  },
  [5152] = {
    [sym_simple_identifier] = ACTIONS(6173),
    [anon_sym_wire] = ACTIONS(6173),
    [anon_sym_tri] = ACTIONS(6173),
    [anon_sym_tri0] = ACTIONS(6173),
    [anon_sym_tri1] = ACTIONS(6173),
    [anon_sym_wand] = ACTIONS(6173),
    [anon_sym_triand] = ACTIONS(6173),
    [anon_sym_wor] = ACTIONS(6173),
    [anon_sym_trior] = ACTIONS(6173),
    [anon_sym_trireg] = ACTIONS(6173),
    [anon_sym_uwire] = ACTIONS(6173),
    [anon_sym_SEMI] = ACTIONS(6175),
    [anon_sym_extern] = ACTIONS(6173),
    [anon_sym_interface] = ACTIONS(6173),
    [anon_sym_checker] = ACTIONS(6173),
    [anon_sym_virtual] = ACTIONS(6173),
    [anon_sym_class] = ACTIONS(6173),
    [anon_sym_type] = ACTIONS(6173),
    [anon_sym_DOLLARfatal] = ACTIONS(6175),
    [anon_sym_DOLLARerror] = ACTIONS(6175),
    [anon_sym_DOLLARwarning] = ACTIONS(6175),
    [anon_sym_DOLLARinfo] = ACTIONS(6175),
    [anon_sym_default] = ACTIONS(6173),
    [anon_sym_clocking] = ACTIONS(6173),
    [anon_sym_defparam] = ACTIONS(6173),
    [anon_sym_bind] = ACTIONS(6173),
    [anon_sym_rand] = ACTIONS(6173),
    [anon_sym_const] = ACTIONS(6173),
    [anon_sym_function] = ACTIONS(6173),
    [anon_sym_static] = ACTIONS(6173),
    [anon_sym_constraint] = ACTIONS(6173),
    [anon_sym_if] = ACTIONS(6173),
    [anon_sym_else] = ACTIONS(6173),
    [anon_sym_LBRACK] = ACTIONS(6175),
    [anon_sym_localparam] = ACTIONS(6173),
    [anon_sym_parameter] = ACTIONS(6173),
    [anon_sym_var] = ACTIONS(6173),
    [anon_sym_import] = ACTIONS(6173),
    [anon_sym_export] = ACTIONS(6173),
    [anon_sym_genvar] = ACTIONS(6173),
    [anon_sym_interconnect] = ACTIONS(6173),
    [anon_sym_typedef] = ACTIONS(6173),
    [anon_sym_enum] = ACTIONS(6173),
    [anon_sym_struct] = ACTIONS(6173),
    [anon_sym_union] = ACTIONS(6173),
    [anon_sym_nettype] = ACTIONS(6173),
    [anon_sym_automatic] = ACTIONS(6173),
    [anon_sym_string] = ACTIONS(6173),
    [anon_sym_chandle] = ACTIONS(6173),
    [anon_sym_event] = ACTIONS(6173),
    [anon_sym_byte] = ACTIONS(6173),
    [anon_sym_shortint] = ACTIONS(6173),
    [anon_sym_int] = ACTIONS(6173),
    [anon_sym_longint] = ACTIONS(6173),
    [anon_sym_integer] = ACTIONS(6173),
    [anon_sym_time] = ACTIONS(6173),
    [anon_sym_bit] = ACTIONS(6173),
    [anon_sym_logic] = ACTIONS(6173),
    [anon_sym_reg] = ACTIONS(6173),
    [anon_sym_shortreal] = ACTIONS(6173),
    [anon_sym_real] = ACTIONS(6173),
    [anon_sym_realtime] = ACTIONS(6173),
    [anon_sym_supply0] = ACTIONS(6173),
    [anon_sym_supply1] = ACTIONS(6173),
    [anon_sym_signed] = ACTIONS(6173),
    [anon_sym_unsigned] = ACTIONS(6173),
    [anon_sym_task] = ACTIONS(6173),
    [anon_sym_assert] = ACTIONS(6173),
    [anon_sym_property] = ACTIONS(6173),
    [anon_sym_assume] = ACTIONS(6173),
    [anon_sym_cover] = ACTIONS(6173),
    [anon_sym_sequence] = ACTIONS(6173),
    [anon_sym_restrict] = ACTIONS(6173),
    [anon_sym_not] = ACTIONS(6173),
    [anon_sym_or] = ACTIONS(6173),
    [anon_sym_and] = ACTIONS(6173),
    [anon_sym_case] = ACTIONS(6173),
    [anon_sym_always] = ACTIONS(6173),
    [anon_sym_covergroup] = ACTIONS(6173),
    [anon_sym_let] = ACTIONS(6173),
    [anon_sym_pulldown] = ACTIONS(6173),
    [anon_sym_pullup] = ACTIONS(6173),
    [anon_sym_cmos] = ACTIONS(6173),
    [anon_sym_rcmos] = ACTIONS(6173),
    [anon_sym_bufif0] = ACTIONS(6173),
    [anon_sym_bufif1] = ACTIONS(6173),
    [anon_sym_notif0] = ACTIONS(6173),
    [anon_sym_notif1] = ACTIONS(6173),
    [anon_sym_nmos] = ACTIONS(6173),
    [anon_sym_pmos] = ACTIONS(6173),
    [anon_sym_rnmos] = ACTIONS(6173),
    [anon_sym_rpmos] = ACTIONS(6173),
    [anon_sym_nand] = ACTIONS(6173),
    [anon_sym_nor] = ACTIONS(6173),
    [anon_sym_xor] = ACTIONS(6173),
    [anon_sym_xnor] = ACTIONS(6173),
    [anon_sym_buf] = ACTIONS(6173),
    [anon_sym_tranif0] = ACTIONS(6173),
    [anon_sym_tranif1] = ACTIONS(6173),
    [anon_sym_rtranif1] = ACTIONS(6173),
    [anon_sym_rtranif0] = ACTIONS(6173),
    [anon_sym_tran] = ACTIONS(6173),
    [anon_sym_rtran] = ACTIONS(6173),
    [anon_sym_generate] = ACTIONS(6173),
    [anon_sym_endgenerate] = ACTIONS(6173),
    [anon_sym_for] = ACTIONS(6173),
    [anon_sym_initial] = ACTIONS(6173),
    [anon_sym_assign] = ACTIONS(6173),
    [anon_sym_alias] = ACTIONS(6173),
    [anon_sym_always_comb] = ACTIONS(6173),
    [anon_sym_always_latch] = ACTIONS(6173),
    [anon_sym_always_ff] = ACTIONS(6173),
    [anon_sym_final] = ACTIONS(6173),
    [anon_sym_global] = ACTIONS(6173),
    [anon_sym_LPAREN_STAR] = ACTIONS(6175),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6175),
    [anon_sym_DOLLARunit] = ACTIONS(6175),
  },
  [5153] = {
    [sym_simple_identifier] = ACTIONS(6177),
    [anon_sym_wire] = ACTIONS(6177),
    [anon_sym_tri] = ACTIONS(6177),
    [anon_sym_tri0] = ACTIONS(6177),
    [anon_sym_tri1] = ACTIONS(6177),
    [anon_sym_wand] = ACTIONS(6177),
    [anon_sym_triand] = ACTIONS(6177),
    [anon_sym_wor] = ACTIONS(6177),
    [anon_sym_trior] = ACTIONS(6177),
    [anon_sym_trireg] = ACTIONS(6177),
    [anon_sym_uwire] = ACTIONS(6177),
    [anon_sym_SEMI] = ACTIONS(6179),
    [anon_sym_extern] = ACTIONS(6177),
    [anon_sym_interface] = ACTIONS(6177),
    [anon_sym_checker] = ACTIONS(6177),
    [anon_sym_virtual] = ACTIONS(6177),
    [anon_sym_class] = ACTIONS(6177),
    [anon_sym_type] = ACTIONS(6177),
    [anon_sym_DOLLARfatal] = ACTIONS(6179),
    [anon_sym_DOLLARerror] = ACTIONS(6179),
    [anon_sym_DOLLARwarning] = ACTIONS(6179),
    [anon_sym_DOLLARinfo] = ACTIONS(6179),
    [anon_sym_default] = ACTIONS(6177),
    [anon_sym_clocking] = ACTIONS(6177),
    [anon_sym_defparam] = ACTIONS(6177),
    [anon_sym_bind] = ACTIONS(6177),
    [anon_sym_rand] = ACTIONS(6177),
    [anon_sym_const] = ACTIONS(6177),
    [anon_sym_function] = ACTIONS(6177),
    [anon_sym_static] = ACTIONS(6177),
    [anon_sym_constraint] = ACTIONS(6177),
    [anon_sym_if] = ACTIONS(6177),
    [anon_sym_else] = ACTIONS(6177),
    [anon_sym_LBRACK] = ACTIONS(6179),
    [anon_sym_localparam] = ACTIONS(6177),
    [anon_sym_parameter] = ACTIONS(6177),
    [anon_sym_var] = ACTIONS(6177),
    [anon_sym_import] = ACTIONS(6177),
    [anon_sym_export] = ACTIONS(6177),
    [anon_sym_genvar] = ACTIONS(6177),
    [anon_sym_interconnect] = ACTIONS(6177),
    [anon_sym_typedef] = ACTIONS(6177),
    [anon_sym_enum] = ACTIONS(6177),
    [anon_sym_struct] = ACTIONS(6177),
    [anon_sym_union] = ACTIONS(6177),
    [anon_sym_nettype] = ACTIONS(6177),
    [anon_sym_automatic] = ACTIONS(6177),
    [anon_sym_string] = ACTIONS(6177),
    [anon_sym_chandle] = ACTIONS(6177),
    [anon_sym_event] = ACTIONS(6177),
    [anon_sym_byte] = ACTIONS(6177),
    [anon_sym_shortint] = ACTIONS(6177),
    [anon_sym_int] = ACTIONS(6177),
    [anon_sym_longint] = ACTIONS(6177),
    [anon_sym_integer] = ACTIONS(6177),
    [anon_sym_time] = ACTIONS(6177),
    [anon_sym_bit] = ACTIONS(6177),
    [anon_sym_logic] = ACTIONS(6177),
    [anon_sym_reg] = ACTIONS(6177),
    [anon_sym_shortreal] = ACTIONS(6177),
    [anon_sym_real] = ACTIONS(6177),
    [anon_sym_realtime] = ACTIONS(6177),
    [anon_sym_supply0] = ACTIONS(6177),
    [anon_sym_supply1] = ACTIONS(6177),
    [anon_sym_signed] = ACTIONS(6177),
    [anon_sym_unsigned] = ACTIONS(6177),
    [anon_sym_task] = ACTIONS(6177),
    [anon_sym_assert] = ACTIONS(6177),
    [anon_sym_property] = ACTIONS(6177),
    [anon_sym_assume] = ACTIONS(6177),
    [anon_sym_cover] = ACTIONS(6177),
    [anon_sym_sequence] = ACTIONS(6177),
    [anon_sym_restrict] = ACTIONS(6177),
    [anon_sym_not] = ACTIONS(6177),
    [anon_sym_or] = ACTIONS(6177),
    [anon_sym_and] = ACTIONS(6177),
    [anon_sym_case] = ACTIONS(6177),
    [anon_sym_always] = ACTIONS(6177),
    [anon_sym_covergroup] = ACTIONS(6177),
    [anon_sym_let] = ACTIONS(6177),
    [anon_sym_pulldown] = ACTIONS(6177),
    [anon_sym_pullup] = ACTIONS(6177),
    [anon_sym_cmos] = ACTIONS(6177),
    [anon_sym_rcmos] = ACTIONS(6177),
    [anon_sym_bufif0] = ACTIONS(6177),
    [anon_sym_bufif1] = ACTIONS(6177),
    [anon_sym_notif0] = ACTIONS(6177),
    [anon_sym_notif1] = ACTIONS(6177),
    [anon_sym_nmos] = ACTIONS(6177),
    [anon_sym_pmos] = ACTIONS(6177),
    [anon_sym_rnmos] = ACTIONS(6177),
    [anon_sym_rpmos] = ACTIONS(6177),
    [anon_sym_nand] = ACTIONS(6177),
    [anon_sym_nor] = ACTIONS(6177),
    [anon_sym_xor] = ACTIONS(6177),
    [anon_sym_xnor] = ACTIONS(6177),
    [anon_sym_buf] = ACTIONS(6177),
    [anon_sym_tranif0] = ACTIONS(6177),
    [anon_sym_tranif1] = ACTIONS(6177),
    [anon_sym_rtranif1] = ACTIONS(6177),
    [anon_sym_rtranif0] = ACTIONS(6177),
    [anon_sym_tran] = ACTIONS(6177),
    [anon_sym_rtran] = ACTIONS(6177),
    [anon_sym_generate] = ACTIONS(6177),
    [anon_sym_endgenerate] = ACTIONS(6177),
    [anon_sym_for] = ACTIONS(6177),
    [anon_sym_initial] = ACTIONS(6177),
    [anon_sym_assign] = ACTIONS(6177),
    [anon_sym_alias] = ACTIONS(6177),
    [anon_sym_always_comb] = ACTIONS(6177),
    [anon_sym_always_latch] = ACTIONS(6177),
    [anon_sym_always_ff] = ACTIONS(6177),
    [anon_sym_final] = ACTIONS(6177),
    [anon_sym_global] = ACTIONS(6177),
    [anon_sym_LPAREN_STAR] = ACTIONS(6179),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6179),
    [anon_sym_DOLLARunit] = ACTIONS(6179),
  },
  [5154] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(4871),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(4871),
    [sym_package_or_generate_item_declaration] = STATE(4871),
    [sym_anonymous_program] = STATE(4871),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(4871),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(5222),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(5222),
    [aux_sym_package_declaration_repeat1] = STATE(4871),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(10893),
    [anon_sym_wire] = ACTIONS(10896),
    [anon_sym_tri] = ACTIONS(10896),
    [anon_sym_tri0] = ACTIONS(10896),
    [anon_sym_tri1] = ACTIONS(10896),
    [anon_sym_wand] = ACTIONS(10896),
    [anon_sym_triand] = ACTIONS(10896),
    [anon_sym_wor] = ACTIONS(10896),
    [anon_sym_trior] = ACTIONS(10896),
    [anon_sym_trireg] = ACTIONS(10896),
    [anon_sym_uwire] = ACTIONS(10896),
    [anon_sym_SEMI] = ACTIONS(10899),
    [anon_sym_interface] = ACTIONS(10902),
    [anon_sym_program] = ACTIONS(10905),
    [anon_sym_checker] = ACTIONS(10908),
    [anon_sym_virtual] = ACTIONS(10911),
    [anon_sym_class] = ACTIONS(10914),
    [anon_sym_endpackage] = ACTIONS(11186),
    [anon_sym_timeunit] = ACTIONS(10920),
    [anon_sym_timeprecision] = ACTIONS(10923),
    [anon_sym_type] = ACTIONS(10926),
    [anon_sym_bind] = ACTIONS(10929),
    [anon_sym_const] = ACTIONS(10932),
    [anon_sym_function] = ACTIONS(10935),
    [anon_sym_static] = ACTIONS(10938),
    [anon_sym_constraint] = ACTIONS(10941),
    [anon_sym_LBRACK] = ACTIONS(10944),
    [anon_sym_localparam] = ACTIONS(10947),
    [anon_sym_parameter] = ACTIONS(10950),
    [anon_sym_var] = ACTIONS(10953),
    [anon_sym_import] = ACTIONS(10956),
    [anon_sym_export] = ACTIONS(10959),
    [anon_sym_interconnect] = ACTIONS(10962),
    [anon_sym_typedef] = ACTIONS(10965),
    [anon_sym_enum] = ACTIONS(10968),
    [anon_sym_struct] = ACTIONS(10971),
    [anon_sym_union] = ACTIONS(10974),
    [anon_sym_nettype] = ACTIONS(10977),
    [anon_sym_automatic] = ACTIONS(10980),
    [anon_sym_string] = ACTIONS(10983),
    [anon_sym_chandle] = ACTIONS(10983),
    [anon_sym_event] = ACTIONS(10983),
    [anon_sym_byte] = ACTIONS(10986),
    [anon_sym_shortint] = ACTIONS(10986),
    [anon_sym_int] = ACTIONS(10986),
    [anon_sym_longint] = ACTIONS(10986),
    [anon_sym_integer] = ACTIONS(10986),
    [anon_sym_time] = ACTIONS(10986),
    [anon_sym_bit] = ACTIONS(10989),
    [anon_sym_logic] = ACTIONS(10989),
    [anon_sym_reg] = ACTIONS(10989),
    [anon_sym_shortreal] = ACTIONS(10992),
    [anon_sym_real] = ACTIONS(10992),
    [anon_sym_realtime] = ACTIONS(10992),
    [anon_sym_supply0] = ACTIONS(10896),
    [anon_sym_supply1] = ACTIONS(10896),
    [anon_sym_signed] = ACTIONS(10995),
    [anon_sym_unsigned] = ACTIONS(10995),
    [anon_sym_task] = ACTIONS(10998),
    [anon_sym_property] = ACTIONS(11001),
    [anon_sym_sequence] = ACTIONS(11004),
    [anon_sym_covergroup] = ACTIONS(11007),
    [anon_sym_let] = ACTIONS(11010),
    [anon_sym_LPAREN_STAR] = ACTIONS(11013),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11016),
    [anon_sym_DOLLARunit] = ACTIONS(11019),
  },
  [5155] = {
    [sym_simple_identifier] = ACTIONS(5950),
    [anon_sym_wire] = ACTIONS(5950),
    [anon_sym_tri] = ACTIONS(5950),
    [anon_sym_tri0] = ACTIONS(5950),
    [anon_sym_tri1] = ACTIONS(5950),
    [anon_sym_wand] = ACTIONS(5950),
    [anon_sym_triand] = ACTIONS(5950),
    [anon_sym_wor] = ACTIONS(5950),
    [anon_sym_trior] = ACTIONS(5950),
    [anon_sym_trireg] = ACTIONS(5950),
    [anon_sym_uwire] = ACTIONS(5950),
    [anon_sym_SEMI] = ACTIONS(5952),
    [anon_sym_extern] = ACTIONS(5950),
    [anon_sym_interface] = ACTIONS(5950),
    [anon_sym_checker] = ACTIONS(5950),
    [anon_sym_virtual] = ACTIONS(5950),
    [anon_sym_class] = ACTIONS(5950),
    [anon_sym_type] = ACTIONS(5950),
    [anon_sym_DOLLARfatal] = ACTIONS(5952),
    [anon_sym_DOLLARerror] = ACTIONS(5952),
    [anon_sym_DOLLARwarning] = ACTIONS(5952),
    [anon_sym_DOLLARinfo] = ACTIONS(5952),
    [anon_sym_default] = ACTIONS(5950),
    [anon_sym_clocking] = ACTIONS(5950),
    [anon_sym_defparam] = ACTIONS(5950),
    [anon_sym_bind] = ACTIONS(5950),
    [anon_sym_rand] = ACTIONS(5950),
    [anon_sym_const] = ACTIONS(5950),
    [anon_sym_function] = ACTIONS(5950),
    [anon_sym_static] = ACTIONS(5950),
    [anon_sym_constraint] = ACTIONS(5950),
    [anon_sym_if] = ACTIONS(5950),
    [anon_sym_else] = ACTIONS(5950),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_localparam] = ACTIONS(5950),
    [anon_sym_parameter] = ACTIONS(5950),
    [anon_sym_var] = ACTIONS(5950),
    [anon_sym_import] = ACTIONS(5950),
    [anon_sym_export] = ACTIONS(5950),
    [anon_sym_genvar] = ACTIONS(5950),
    [anon_sym_interconnect] = ACTIONS(5950),
    [anon_sym_typedef] = ACTIONS(5950),
    [anon_sym_enum] = ACTIONS(5950),
    [anon_sym_struct] = ACTIONS(5950),
    [anon_sym_union] = ACTIONS(5950),
    [anon_sym_nettype] = ACTIONS(5950),
    [anon_sym_automatic] = ACTIONS(5950),
    [anon_sym_string] = ACTIONS(5950),
    [anon_sym_chandle] = ACTIONS(5950),
    [anon_sym_event] = ACTIONS(5950),
    [anon_sym_byte] = ACTIONS(5950),
    [anon_sym_shortint] = ACTIONS(5950),
    [anon_sym_int] = ACTIONS(5950),
    [anon_sym_longint] = ACTIONS(5950),
    [anon_sym_integer] = ACTIONS(5950),
    [anon_sym_time] = ACTIONS(5950),
    [anon_sym_bit] = ACTIONS(5950),
    [anon_sym_logic] = ACTIONS(5950),
    [anon_sym_reg] = ACTIONS(5950),
    [anon_sym_shortreal] = ACTIONS(5950),
    [anon_sym_real] = ACTIONS(5950),
    [anon_sym_realtime] = ACTIONS(5950),
    [anon_sym_supply0] = ACTIONS(5950),
    [anon_sym_supply1] = ACTIONS(5950),
    [anon_sym_signed] = ACTIONS(5950),
    [anon_sym_unsigned] = ACTIONS(5950),
    [anon_sym_task] = ACTIONS(5950),
    [anon_sym_assert] = ACTIONS(5950),
    [anon_sym_property] = ACTIONS(5950),
    [anon_sym_assume] = ACTIONS(5950),
    [anon_sym_cover] = ACTIONS(5950),
    [anon_sym_sequence] = ACTIONS(5950),
    [anon_sym_restrict] = ACTIONS(5950),
    [anon_sym_not] = ACTIONS(5950),
    [anon_sym_or] = ACTIONS(5950),
    [anon_sym_and] = ACTIONS(5950),
    [anon_sym_case] = ACTIONS(5950),
    [anon_sym_always] = ACTIONS(5950),
    [anon_sym_covergroup] = ACTIONS(5950),
    [anon_sym_end] = ACTIONS(5950),
    [anon_sym_let] = ACTIONS(5950),
    [anon_sym_pulldown] = ACTIONS(5950),
    [anon_sym_pullup] = ACTIONS(5950),
    [anon_sym_cmos] = ACTIONS(5950),
    [anon_sym_rcmos] = ACTIONS(5950),
    [anon_sym_bufif0] = ACTIONS(5950),
    [anon_sym_bufif1] = ACTIONS(5950),
    [anon_sym_notif0] = ACTIONS(5950),
    [anon_sym_notif1] = ACTIONS(5950),
    [anon_sym_nmos] = ACTIONS(5950),
    [anon_sym_pmos] = ACTIONS(5950),
    [anon_sym_rnmos] = ACTIONS(5950),
    [anon_sym_rpmos] = ACTIONS(5950),
    [anon_sym_nand] = ACTIONS(5950),
    [anon_sym_nor] = ACTIONS(5950),
    [anon_sym_xor] = ACTIONS(5950),
    [anon_sym_xnor] = ACTIONS(5950),
    [anon_sym_buf] = ACTIONS(5950),
    [anon_sym_tranif0] = ACTIONS(5950),
    [anon_sym_tranif1] = ACTIONS(5950),
    [anon_sym_rtranif1] = ACTIONS(5950),
    [anon_sym_rtranif0] = ACTIONS(5950),
    [anon_sym_tran] = ACTIONS(5950),
    [anon_sym_rtran] = ACTIONS(5950),
    [anon_sym_generate] = ACTIONS(5950),
    [anon_sym_for] = ACTIONS(5950),
    [anon_sym_initial] = ACTIONS(5950),
    [anon_sym_assign] = ACTIONS(5950),
    [anon_sym_alias] = ACTIONS(5950),
    [anon_sym_always_comb] = ACTIONS(5950),
    [anon_sym_always_latch] = ACTIONS(5950),
    [anon_sym_always_ff] = ACTIONS(5950),
    [anon_sym_final] = ACTIONS(5950),
    [anon_sym_global] = ACTIONS(5950),
    [anon_sym_LPAREN_STAR] = ACTIONS(5952),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5952),
    [anon_sym_DOLLARunit] = ACTIONS(5952),
  },
  [5156] = {
    [sym_simple_identifier] = ACTIONS(6307),
    [anon_sym_wire] = ACTIONS(6307),
    [anon_sym_tri] = ACTIONS(6307),
    [anon_sym_tri0] = ACTIONS(6307),
    [anon_sym_tri1] = ACTIONS(6307),
    [anon_sym_wand] = ACTIONS(6307),
    [anon_sym_triand] = ACTIONS(6307),
    [anon_sym_wor] = ACTIONS(6307),
    [anon_sym_trior] = ACTIONS(6307),
    [anon_sym_trireg] = ACTIONS(6307),
    [anon_sym_uwire] = ACTIONS(6307),
    [anon_sym_SEMI] = ACTIONS(6309),
    [anon_sym_extern] = ACTIONS(6307),
    [anon_sym_interface] = ACTIONS(6307),
    [anon_sym_checker] = ACTIONS(6307),
    [anon_sym_virtual] = ACTIONS(6307),
    [anon_sym_class] = ACTIONS(6307),
    [anon_sym_type] = ACTIONS(6307),
    [anon_sym_DOLLARfatal] = ACTIONS(6309),
    [anon_sym_DOLLARerror] = ACTIONS(6309),
    [anon_sym_DOLLARwarning] = ACTIONS(6309),
    [anon_sym_DOLLARinfo] = ACTIONS(6309),
    [anon_sym_default] = ACTIONS(6307),
    [anon_sym_clocking] = ACTIONS(6307),
    [anon_sym_defparam] = ACTIONS(6307),
    [anon_sym_bind] = ACTIONS(6307),
    [anon_sym_rand] = ACTIONS(6307),
    [anon_sym_const] = ACTIONS(6307),
    [anon_sym_function] = ACTIONS(6307),
    [anon_sym_static] = ACTIONS(6307),
    [anon_sym_constraint] = ACTIONS(6307),
    [anon_sym_if] = ACTIONS(6307),
    [anon_sym_else] = ACTIONS(6307),
    [anon_sym_LBRACK] = ACTIONS(6309),
    [anon_sym_localparam] = ACTIONS(6307),
    [anon_sym_parameter] = ACTIONS(6307),
    [anon_sym_var] = ACTIONS(6307),
    [anon_sym_import] = ACTIONS(6307),
    [anon_sym_export] = ACTIONS(6307),
    [anon_sym_genvar] = ACTIONS(6307),
    [anon_sym_interconnect] = ACTIONS(6307),
    [anon_sym_typedef] = ACTIONS(6307),
    [anon_sym_enum] = ACTIONS(6307),
    [anon_sym_struct] = ACTIONS(6307),
    [anon_sym_union] = ACTIONS(6307),
    [anon_sym_nettype] = ACTIONS(6307),
    [anon_sym_automatic] = ACTIONS(6307),
    [anon_sym_string] = ACTIONS(6307),
    [anon_sym_chandle] = ACTIONS(6307),
    [anon_sym_event] = ACTIONS(6307),
    [anon_sym_byte] = ACTIONS(6307),
    [anon_sym_shortint] = ACTIONS(6307),
    [anon_sym_int] = ACTIONS(6307),
    [anon_sym_longint] = ACTIONS(6307),
    [anon_sym_integer] = ACTIONS(6307),
    [anon_sym_time] = ACTIONS(6307),
    [anon_sym_bit] = ACTIONS(6307),
    [anon_sym_logic] = ACTIONS(6307),
    [anon_sym_reg] = ACTIONS(6307),
    [anon_sym_shortreal] = ACTIONS(6307),
    [anon_sym_real] = ACTIONS(6307),
    [anon_sym_realtime] = ACTIONS(6307),
    [anon_sym_supply0] = ACTIONS(6307),
    [anon_sym_supply1] = ACTIONS(6307),
    [anon_sym_signed] = ACTIONS(6307),
    [anon_sym_unsigned] = ACTIONS(6307),
    [anon_sym_task] = ACTIONS(6307),
    [anon_sym_assert] = ACTIONS(6307),
    [anon_sym_property] = ACTIONS(6307),
    [anon_sym_assume] = ACTIONS(6307),
    [anon_sym_cover] = ACTIONS(6307),
    [anon_sym_sequence] = ACTIONS(6307),
    [anon_sym_restrict] = ACTIONS(6307),
    [anon_sym_not] = ACTIONS(6307),
    [anon_sym_or] = ACTIONS(6307),
    [anon_sym_and] = ACTIONS(6307),
    [anon_sym_case] = ACTIONS(6307),
    [anon_sym_always] = ACTIONS(6307),
    [anon_sym_covergroup] = ACTIONS(6307),
    [anon_sym_let] = ACTIONS(6307),
    [anon_sym_pulldown] = ACTIONS(6307),
    [anon_sym_pullup] = ACTIONS(6307),
    [anon_sym_cmos] = ACTIONS(6307),
    [anon_sym_rcmos] = ACTIONS(6307),
    [anon_sym_bufif0] = ACTIONS(6307),
    [anon_sym_bufif1] = ACTIONS(6307),
    [anon_sym_notif0] = ACTIONS(6307),
    [anon_sym_notif1] = ACTIONS(6307),
    [anon_sym_nmos] = ACTIONS(6307),
    [anon_sym_pmos] = ACTIONS(6307),
    [anon_sym_rnmos] = ACTIONS(6307),
    [anon_sym_rpmos] = ACTIONS(6307),
    [anon_sym_nand] = ACTIONS(6307),
    [anon_sym_nor] = ACTIONS(6307),
    [anon_sym_xor] = ACTIONS(6307),
    [anon_sym_xnor] = ACTIONS(6307),
    [anon_sym_buf] = ACTIONS(6307),
    [anon_sym_tranif0] = ACTIONS(6307),
    [anon_sym_tranif1] = ACTIONS(6307),
    [anon_sym_rtranif1] = ACTIONS(6307),
    [anon_sym_rtranif0] = ACTIONS(6307),
    [anon_sym_tran] = ACTIONS(6307),
    [anon_sym_rtran] = ACTIONS(6307),
    [anon_sym_generate] = ACTIONS(6307),
    [anon_sym_endgenerate] = ACTIONS(6307),
    [anon_sym_for] = ACTIONS(6307),
    [anon_sym_initial] = ACTIONS(6307),
    [anon_sym_assign] = ACTIONS(6307),
    [anon_sym_alias] = ACTIONS(6307),
    [anon_sym_always_comb] = ACTIONS(6307),
    [anon_sym_always_latch] = ACTIONS(6307),
    [anon_sym_always_ff] = ACTIONS(6307),
    [anon_sym_final] = ACTIONS(6307),
    [anon_sym_global] = ACTIONS(6307),
    [anon_sym_LPAREN_STAR] = ACTIONS(6309),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6309),
    [anon_sym_DOLLARunit] = ACTIONS(6309),
  },
  [5157] = {
    [sym_simple_identifier] = ACTIONS(6311),
    [anon_sym_wire] = ACTIONS(6311),
    [anon_sym_tri] = ACTIONS(6311),
    [anon_sym_tri0] = ACTIONS(6311),
    [anon_sym_tri1] = ACTIONS(6311),
    [anon_sym_wand] = ACTIONS(6311),
    [anon_sym_triand] = ACTIONS(6311),
    [anon_sym_wor] = ACTIONS(6311),
    [anon_sym_trior] = ACTIONS(6311),
    [anon_sym_trireg] = ACTIONS(6311),
    [anon_sym_uwire] = ACTIONS(6311),
    [anon_sym_SEMI] = ACTIONS(6313),
    [anon_sym_extern] = ACTIONS(6311),
    [anon_sym_interface] = ACTIONS(6311),
    [anon_sym_checker] = ACTIONS(6311),
    [anon_sym_virtual] = ACTIONS(6311),
    [anon_sym_class] = ACTIONS(6311),
    [anon_sym_type] = ACTIONS(6311),
    [anon_sym_DOLLARfatal] = ACTIONS(6313),
    [anon_sym_DOLLARerror] = ACTIONS(6313),
    [anon_sym_DOLLARwarning] = ACTIONS(6313),
    [anon_sym_DOLLARinfo] = ACTIONS(6313),
    [anon_sym_default] = ACTIONS(6311),
    [anon_sym_clocking] = ACTIONS(6311),
    [anon_sym_defparam] = ACTIONS(6311),
    [anon_sym_bind] = ACTIONS(6311),
    [anon_sym_rand] = ACTIONS(6311),
    [anon_sym_const] = ACTIONS(6311),
    [anon_sym_function] = ACTIONS(6311),
    [anon_sym_static] = ACTIONS(6311),
    [anon_sym_constraint] = ACTIONS(6311),
    [anon_sym_if] = ACTIONS(6311),
    [anon_sym_else] = ACTIONS(6311),
    [anon_sym_LBRACK] = ACTIONS(6313),
    [anon_sym_localparam] = ACTIONS(6311),
    [anon_sym_parameter] = ACTIONS(6311),
    [anon_sym_var] = ACTIONS(6311),
    [anon_sym_import] = ACTIONS(6311),
    [anon_sym_export] = ACTIONS(6311),
    [anon_sym_genvar] = ACTIONS(6311),
    [anon_sym_interconnect] = ACTIONS(6311),
    [anon_sym_typedef] = ACTIONS(6311),
    [anon_sym_enum] = ACTIONS(6311),
    [anon_sym_struct] = ACTIONS(6311),
    [anon_sym_union] = ACTIONS(6311),
    [anon_sym_nettype] = ACTIONS(6311),
    [anon_sym_automatic] = ACTIONS(6311),
    [anon_sym_string] = ACTIONS(6311),
    [anon_sym_chandle] = ACTIONS(6311),
    [anon_sym_event] = ACTIONS(6311),
    [anon_sym_byte] = ACTIONS(6311),
    [anon_sym_shortint] = ACTIONS(6311),
    [anon_sym_int] = ACTIONS(6311),
    [anon_sym_longint] = ACTIONS(6311),
    [anon_sym_integer] = ACTIONS(6311),
    [anon_sym_time] = ACTIONS(6311),
    [anon_sym_bit] = ACTIONS(6311),
    [anon_sym_logic] = ACTIONS(6311),
    [anon_sym_reg] = ACTIONS(6311),
    [anon_sym_shortreal] = ACTIONS(6311),
    [anon_sym_real] = ACTIONS(6311),
    [anon_sym_realtime] = ACTIONS(6311),
    [anon_sym_supply0] = ACTIONS(6311),
    [anon_sym_supply1] = ACTIONS(6311),
    [anon_sym_signed] = ACTIONS(6311),
    [anon_sym_unsigned] = ACTIONS(6311),
    [anon_sym_task] = ACTIONS(6311),
    [anon_sym_assert] = ACTIONS(6311),
    [anon_sym_property] = ACTIONS(6311),
    [anon_sym_assume] = ACTIONS(6311),
    [anon_sym_cover] = ACTIONS(6311),
    [anon_sym_sequence] = ACTIONS(6311),
    [anon_sym_restrict] = ACTIONS(6311),
    [anon_sym_not] = ACTIONS(6311),
    [anon_sym_or] = ACTIONS(6311),
    [anon_sym_and] = ACTIONS(6311),
    [anon_sym_case] = ACTIONS(6311),
    [anon_sym_always] = ACTIONS(6311),
    [anon_sym_covergroup] = ACTIONS(6311),
    [anon_sym_let] = ACTIONS(6311),
    [anon_sym_pulldown] = ACTIONS(6311),
    [anon_sym_pullup] = ACTIONS(6311),
    [anon_sym_cmos] = ACTIONS(6311),
    [anon_sym_rcmos] = ACTIONS(6311),
    [anon_sym_bufif0] = ACTIONS(6311),
    [anon_sym_bufif1] = ACTIONS(6311),
    [anon_sym_notif0] = ACTIONS(6311),
    [anon_sym_notif1] = ACTIONS(6311),
    [anon_sym_nmos] = ACTIONS(6311),
    [anon_sym_pmos] = ACTIONS(6311),
    [anon_sym_rnmos] = ACTIONS(6311),
    [anon_sym_rpmos] = ACTIONS(6311),
    [anon_sym_nand] = ACTIONS(6311),
    [anon_sym_nor] = ACTIONS(6311),
    [anon_sym_xor] = ACTIONS(6311),
    [anon_sym_xnor] = ACTIONS(6311),
    [anon_sym_buf] = ACTIONS(6311),
    [anon_sym_tranif0] = ACTIONS(6311),
    [anon_sym_tranif1] = ACTIONS(6311),
    [anon_sym_rtranif1] = ACTIONS(6311),
    [anon_sym_rtranif0] = ACTIONS(6311),
    [anon_sym_tran] = ACTIONS(6311),
    [anon_sym_rtran] = ACTIONS(6311),
    [anon_sym_generate] = ACTIONS(6311),
    [anon_sym_endgenerate] = ACTIONS(6311),
    [anon_sym_for] = ACTIONS(6311),
    [anon_sym_initial] = ACTIONS(6311),
    [anon_sym_assign] = ACTIONS(6311),
    [anon_sym_alias] = ACTIONS(6311),
    [anon_sym_always_comb] = ACTIONS(6311),
    [anon_sym_always_latch] = ACTIONS(6311),
    [anon_sym_always_ff] = ACTIONS(6311),
    [anon_sym_final] = ACTIONS(6311),
    [anon_sym_global] = ACTIONS(6311),
    [anon_sym_LPAREN_STAR] = ACTIONS(6313),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6313),
    [anon_sym_DOLLARunit] = ACTIONS(6313),
  },
  [5158] = {
    [sym_simple_identifier] = ACTIONS(4900),
    [anon_sym_wire] = ACTIONS(4900),
    [anon_sym_tri] = ACTIONS(4900),
    [anon_sym_tri0] = ACTIONS(4900),
    [anon_sym_tri1] = ACTIONS(4900),
    [anon_sym_wand] = ACTIONS(4900),
    [anon_sym_triand] = ACTIONS(4900),
    [anon_sym_wor] = ACTIONS(4900),
    [anon_sym_trior] = ACTIONS(4900),
    [anon_sym_trireg] = ACTIONS(4900),
    [anon_sym_uwire] = ACTIONS(4900),
    [anon_sym_SEMI] = ACTIONS(4898),
    [anon_sym_extern] = ACTIONS(4900),
    [anon_sym_interface] = ACTIONS(4900),
    [anon_sym_checker] = ACTIONS(4900),
    [anon_sym_virtual] = ACTIONS(4900),
    [anon_sym_class] = ACTIONS(4900),
    [anon_sym_type] = ACTIONS(4900),
    [anon_sym_DOLLARfatal] = ACTIONS(4898),
    [anon_sym_DOLLARerror] = ACTIONS(4898),
    [anon_sym_DOLLARwarning] = ACTIONS(4898),
    [anon_sym_DOLLARinfo] = ACTIONS(4898),
    [anon_sym_default] = ACTIONS(4900),
    [anon_sym_clocking] = ACTIONS(4900),
    [anon_sym_defparam] = ACTIONS(4900),
    [anon_sym_bind] = ACTIONS(4900),
    [anon_sym_rand] = ACTIONS(4900),
    [anon_sym_const] = ACTIONS(4900),
    [anon_sym_function] = ACTIONS(4900),
    [anon_sym_static] = ACTIONS(4900),
    [anon_sym_constraint] = ACTIONS(4900),
    [anon_sym_if] = ACTIONS(4900),
    [anon_sym_else] = ACTIONS(4900),
    [anon_sym_LBRACK] = ACTIONS(4898),
    [anon_sym_localparam] = ACTIONS(4900),
    [anon_sym_parameter] = ACTIONS(4900),
    [anon_sym_var] = ACTIONS(4900),
    [anon_sym_import] = ACTIONS(4900),
    [anon_sym_export] = ACTIONS(4900),
    [anon_sym_genvar] = ACTIONS(4900),
    [anon_sym_interconnect] = ACTIONS(4900),
    [anon_sym_typedef] = ACTIONS(4900),
    [anon_sym_enum] = ACTIONS(4900),
    [anon_sym_struct] = ACTIONS(4900),
    [anon_sym_union] = ACTIONS(4900),
    [anon_sym_nettype] = ACTIONS(4900),
    [anon_sym_automatic] = ACTIONS(4900),
    [anon_sym_string] = ACTIONS(4900),
    [anon_sym_chandle] = ACTIONS(4900),
    [anon_sym_event] = ACTIONS(4900),
    [anon_sym_byte] = ACTIONS(4900),
    [anon_sym_shortint] = ACTIONS(4900),
    [anon_sym_int] = ACTIONS(4900),
    [anon_sym_longint] = ACTIONS(4900),
    [anon_sym_integer] = ACTIONS(4900),
    [anon_sym_time] = ACTIONS(4900),
    [anon_sym_bit] = ACTIONS(4900),
    [anon_sym_logic] = ACTIONS(4900),
    [anon_sym_reg] = ACTIONS(4900),
    [anon_sym_shortreal] = ACTIONS(4900),
    [anon_sym_real] = ACTIONS(4900),
    [anon_sym_realtime] = ACTIONS(4900),
    [anon_sym_supply0] = ACTIONS(4900),
    [anon_sym_supply1] = ACTIONS(4900),
    [anon_sym_signed] = ACTIONS(4900),
    [anon_sym_unsigned] = ACTIONS(4900),
    [anon_sym_task] = ACTIONS(4900),
    [anon_sym_assert] = ACTIONS(4900),
    [anon_sym_property] = ACTIONS(4900),
    [anon_sym_assume] = ACTIONS(4900),
    [anon_sym_cover] = ACTIONS(4900),
    [anon_sym_sequence] = ACTIONS(4900),
    [anon_sym_restrict] = ACTIONS(4900),
    [anon_sym_not] = ACTIONS(4900),
    [anon_sym_or] = ACTIONS(4900),
    [anon_sym_and] = ACTIONS(4900),
    [anon_sym_case] = ACTIONS(4900),
    [anon_sym_always] = ACTIONS(4900),
    [anon_sym_covergroup] = ACTIONS(4900),
    [anon_sym_let] = ACTIONS(4900),
    [anon_sym_pulldown] = ACTIONS(4900),
    [anon_sym_pullup] = ACTIONS(4900),
    [anon_sym_cmos] = ACTIONS(4900),
    [anon_sym_rcmos] = ACTIONS(4900),
    [anon_sym_bufif0] = ACTIONS(4900),
    [anon_sym_bufif1] = ACTIONS(4900),
    [anon_sym_notif0] = ACTIONS(4900),
    [anon_sym_notif1] = ACTIONS(4900),
    [anon_sym_nmos] = ACTIONS(4900),
    [anon_sym_pmos] = ACTIONS(4900),
    [anon_sym_rnmos] = ACTIONS(4900),
    [anon_sym_rpmos] = ACTIONS(4900),
    [anon_sym_nand] = ACTIONS(4900),
    [anon_sym_nor] = ACTIONS(4900),
    [anon_sym_xor] = ACTIONS(4900),
    [anon_sym_xnor] = ACTIONS(4900),
    [anon_sym_buf] = ACTIONS(4900),
    [anon_sym_tranif0] = ACTIONS(4900),
    [anon_sym_tranif1] = ACTIONS(4900),
    [anon_sym_rtranif1] = ACTIONS(4900),
    [anon_sym_rtranif0] = ACTIONS(4900),
    [anon_sym_tran] = ACTIONS(4900),
    [anon_sym_rtran] = ACTIONS(4900),
    [anon_sym_generate] = ACTIONS(4900),
    [anon_sym_endgenerate] = ACTIONS(4900),
    [anon_sym_for] = ACTIONS(4900),
    [anon_sym_initial] = ACTIONS(4900),
    [anon_sym_assign] = ACTIONS(4900),
    [anon_sym_alias] = ACTIONS(4900),
    [anon_sym_always_comb] = ACTIONS(4900),
    [anon_sym_always_latch] = ACTIONS(4900),
    [anon_sym_always_ff] = ACTIONS(4900),
    [anon_sym_final] = ACTIONS(4900),
    [anon_sym_global] = ACTIONS(4900),
    [anon_sym_LPAREN_STAR] = ACTIONS(4898),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4898),
    [anon_sym_DOLLARunit] = ACTIONS(4898),
  },
  [5159] = {
    [sym_simple_identifier] = ACTIONS(6315),
    [anon_sym_wire] = ACTIONS(6315),
    [anon_sym_tri] = ACTIONS(6315),
    [anon_sym_tri0] = ACTIONS(6315),
    [anon_sym_tri1] = ACTIONS(6315),
    [anon_sym_wand] = ACTIONS(6315),
    [anon_sym_triand] = ACTIONS(6315),
    [anon_sym_wor] = ACTIONS(6315),
    [anon_sym_trior] = ACTIONS(6315),
    [anon_sym_trireg] = ACTIONS(6315),
    [anon_sym_uwire] = ACTIONS(6315),
    [anon_sym_SEMI] = ACTIONS(6317),
    [anon_sym_extern] = ACTIONS(6315),
    [anon_sym_interface] = ACTIONS(6315),
    [anon_sym_checker] = ACTIONS(6315),
    [anon_sym_virtual] = ACTIONS(6315),
    [anon_sym_class] = ACTIONS(6315),
    [anon_sym_type] = ACTIONS(6315),
    [anon_sym_DOLLARfatal] = ACTIONS(6317),
    [anon_sym_DOLLARerror] = ACTIONS(6317),
    [anon_sym_DOLLARwarning] = ACTIONS(6317),
    [anon_sym_DOLLARinfo] = ACTIONS(6317),
    [anon_sym_default] = ACTIONS(6315),
    [anon_sym_clocking] = ACTIONS(6315),
    [anon_sym_defparam] = ACTIONS(6315),
    [anon_sym_bind] = ACTIONS(6315),
    [anon_sym_rand] = ACTIONS(6315),
    [anon_sym_const] = ACTIONS(6315),
    [anon_sym_function] = ACTIONS(6315),
    [anon_sym_static] = ACTIONS(6315),
    [anon_sym_constraint] = ACTIONS(6315),
    [anon_sym_if] = ACTIONS(6315),
    [anon_sym_else] = ACTIONS(6315),
    [anon_sym_LBRACK] = ACTIONS(6317),
    [anon_sym_localparam] = ACTIONS(6315),
    [anon_sym_parameter] = ACTIONS(6315),
    [anon_sym_var] = ACTIONS(6315),
    [anon_sym_import] = ACTIONS(6315),
    [anon_sym_export] = ACTIONS(6315),
    [anon_sym_genvar] = ACTIONS(6315),
    [anon_sym_interconnect] = ACTIONS(6315),
    [anon_sym_typedef] = ACTIONS(6315),
    [anon_sym_enum] = ACTIONS(6315),
    [anon_sym_struct] = ACTIONS(6315),
    [anon_sym_union] = ACTIONS(6315),
    [anon_sym_nettype] = ACTIONS(6315),
    [anon_sym_automatic] = ACTIONS(6315),
    [anon_sym_string] = ACTIONS(6315),
    [anon_sym_chandle] = ACTIONS(6315),
    [anon_sym_event] = ACTIONS(6315),
    [anon_sym_byte] = ACTIONS(6315),
    [anon_sym_shortint] = ACTIONS(6315),
    [anon_sym_int] = ACTIONS(6315),
    [anon_sym_longint] = ACTIONS(6315),
    [anon_sym_integer] = ACTIONS(6315),
    [anon_sym_time] = ACTIONS(6315),
    [anon_sym_bit] = ACTIONS(6315),
    [anon_sym_logic] = ACTIONS(6315),
    [anon_sym_reg] = ACTIONS(6315),
    [anon_sym_shortreal] = ACTIONS(6315),
    [anon_sym_real] = ACTIONS(6315),
    [anon_sym_realtime] = ACTIONS(6315),
    [anon_sym_supply0] = ACTIONS(6315),
    [anon_sym_supply1] = ACTIONS(6315),
    [anon_sym_signed] = ACTIONS(6315),
    [anon_sym_unsigned] = ACTIONS(6315),
    [anon_sym_task] = ACTIONS(6315),
    [anon_sym_assert] = ACTIONS(6315),
    [anon_sym_property] = ACTIONS(6315),
    [anon_sym_assume] = ACTIONS(6315),
    [anon_sym_cover] = ACTIONS(6315),
    [anon_sym_sequence] = ACTIONS(6315),
    [anon_sym_restrict] = ACTIONS(6315),
    [anon_sym_not] = ACTIONS(6315),
    [anon_sym_or] = ACTIONS(6315),
    [anon_sym_and] = ACTIONS(6315),
    [anon_sym_case] = ACTIONS(6315),
    [anon_sym_always] = ACTIONS(6315),
    [anon_sym_covergroup] = ACTIONS(6315),
    [anon_sym_let] = ACTIONS(6315),
    [anon_sym_pulldown] = ACTIONS(6315),
    [anon_sym_pullup] = ACTIONS(6315),
    [anon_sym_cmos] = ACTIONS(6315),
    [anon_sym_rcmos] = ACTIONS(6315),
    [anon_sym_bufif0] = ACTIONS(6315),
    [anon_sym_bufif1] = ACTIONS(6315),
    [anon_sym_notif0] = ACTIONS(6315),
    [anon_sym_notif1] = ACTIONS(6315),
    [anon_sym_nmos] = ACTIONS(6315),
    [anon_sym_pmos] = ACTIONS(6315),
    [anon_sym_rnmos] = ACTIONS(6315),
    [anon_sym_rpmos] = ACTIONS(6315),
    [anon_sym_nand] = ACTIONS(6315),
    [anon_sym_nor] = ACTIONS(6315),
    [anon_sym_xor] = ACTIONS(6315),
    [anon_sym_xnor] = ACTIONS(6315),
    [anon_sym_buf] = ACTIONS(6315),
    [anon_sym_tranif0] = ACTIONS(6315),
    [anon_sym_tranif1] = ACTIONS(6315),
    [anon_sym_rtranif1] = ACTIONS(6315),
    [anon_sym_rtranif0] = ACTIONS(6315),
    [anon_sym_tran] = ACTIONS(6315),
    [anon_sym_rtran] = ACTIONS(6315),
    [anon_sym_generate] = ACTIONS(6315),
    [anon_sym_endgenerate] = ACTIONS(6315),
    [anon_sym_for] = ACTIONS(6315),
    [anon_sym_initial] = ACTIONS(6315),
    [anon_sym_assign] = ACTIONS(6315),
    [anon_sym_alias] = ACTIONS(6315),
    [anon_sym_always_comb] = ACTIONS(6315),
    [anon_sym_always_latch] = ACTIONS(6315),
    [anon_sym_always_ff] = ACTIONS(6315),
    [anon_sym_final] = ACTIONS(6315),
    [anon_sym_global] = ACTIONS(6315),
    [anon_sym_LPAREN_STAR] = ACTIONS(6317),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6317),
    [anon_sym_DOLLARunit] = ACTIONS(6317),
  },
  [5160] = {
    [sym_simple_identifier] = ACTIONS(6319),
    [anon_sym_wire] = ACTIONS(6319),
    [anon_sym_tri] = ACTIONS(6319),
    [anon_sym_tri0] = ACTIONS(6319),
    [anon_sym_tri1] = ACTIONS(6319),
    [anon_sym_wand] = ACTIONS(6319),
    [anon_sym_triand] = ACTIONS(6319),
    [anon_sym_wor] = ACTIONS(6319),
    [anon_sym_trior] = ACTIONS(6319),
    [anon_sym_trireg] = ACTIONS(6319),
    [anon_sym_uwire] = ACTIONS(6319),
    [anon_sym_SEMI] = ACTIONS(6321),
    [anon_sym_extern] = ACTIONS(6319),
    [anon_sym_interface] = ACTIONS(6319),
    [anon_sym_checker] = ACTIONS(6319),
    [anon_sym_virtual] = ACTIONS(6319),
    [anon_sym_class] = ACTIONS(6319),
    [anon_sym_type] = ACTIONS(6319),
    [anon_sym_DOLLARfatal] = ACTIONS(6321),
    [anon_sym_DOLLARerror] = ACTIONS(6321),
    [anon_sym_DOLLARwarning] = ACTIONS(6321),
    [anon_sym_DOLLARinfo] = ACTIONS(6321),
    [anon_sym_default] = ACTIONS(6319),
    [anon_sym_clocking] = ACTIONS(6319),
    [anon_sym_defparam] = ACTIONS(6319),
    [anon_sym_bind] = ACTIONS(6319),
    [anon_sym_rand] = ACTIONS(6319),
    [anon_sym_const] = ACTIONS(6319),
    [anon_sym_function] = ACTIONS(6319),
    [anon_sym_static] = ACTIONS(6319),
    [anon_sym_constraint] = ACTIONS(6319),
    [anon_sym_if] = ACTIONS(6319),
    [anon_sym_else] = ACTIONS(6319),
    [anon_sym_LBRACK] = ACTIONS(6321),
    [anon_sym_localparam] = ACTIONS(6319),
    [anon_sym_parameter] = ACTIONS(6319),
    [anon_sym_var] = ACTIONS(6319),
    [anon_sym_import] = ACTIONS(6319),
    [anon_sym_export] = ACTIONS(6319),
    [anon_sym_genvar] = ACTIONS(6319),
    [anon_sym_interconnect] = ACTIONS(6319),
    [anon_sym_typedef] = ACTIONS(6319),
    [anon_sym_enum] = ACTIONS(6319),
    [anon_sym_struct] = ACTIONS(6319),
    [anon_sym_union] = ACTIONS(6319),
    [anon_sym_nettype] = ACTIONS(6319),
    [anon_sym_automatic] = ACTIONS(6319),
    [anon_sym_string] = ACTIONS(6319),
    [anon_sym_chandle] = ACTIONS(6319),
    [anon_sym_event] = ACTIONS(6319),
    [anon_sym_byte] = ACTIONS(6319),
    [anon_sym_shortint] = ACTIONS(6319),
    [anon_sym_int] = ACTIONS(6319),
    [anon_sym_longint] = ACTIONS(6319),
    [anon_sym_integer] = ACTIONS(6319),
    [anon_sym_time] = ACTIONS(6319),
    [anon_sym_bit] = ACTIONS(6319),
    [anon_sym_logic] = ACTIONS(6319),
    [anon_sym_reg] = ACTIONS(6319),
    [anon_sym_shortreal] = ACTIONS(6319),
    [anon_sym_real] = ACTIONS(6319),
    [anon_sym_realtime] = ACTIONS(6319),
    [anon_sym_supply0] = ACTIONS(6319),
    [anon_sym_supply1] = ACTIONS(6319),
    [anon_sym_signed] = ACTIONS(6319),
    [anon_sym_unsigned] = ACTIONS(6319),
    [anon_sym_task] = ACTIONS(6319),
    [anon_sym_assert] = ACTIONS(6319),
    [anon_sym_property] = ACTIONS(6319),
    [anon_sym_assume] = ACTIONS(6319),
    [anon_sym_cover] = ACTIONS(6319),
    [anon_sym_sequence] = ACTIONS(6319),
    [anon_sym_restrict] = ACTIONS(6319),
    [anon_sym_not] = ACTIONS(6319),
    [anon_sym_or] = ACTIONS(6319),
    [anon_sym_and] = ACTIONS(6319),
    [anon_sym_case] = ACTIONS(6319),
    [anon_sym_always] = ACTIONS(6319),
    [anon_sym_covergroup] = ACTIONS(6319),
    [anon_sym_let] = ACTIONS(6319),
    [anon_sym_pulldown] = ACTIONS(6319),
    [anon_sym_pullup] = ACTIONS(6319),
    [anon_sym_cmos] = ACTIONS(6319),
    [anon_sym_rcmos] = ACTIONS(6319),
    [anon_sym_bufif0] = ACTIONS(6319),
    [anon_sym_bufif1] = ACTIONS(6319),
    [anon_sym_notif0] = ACTIONS(6319),
    [anon_sym_notif1] = ACTIONS(6319),
    [anon_sym_nmos] = ACTIONS(6319),
    [anon_sym_pmos] = ACTIONS(6319),
    [anon_sym_rnmos] = ACTIONS(6319),
    [anon_sym_rpmos] = ACTIONS(6319),
    [anon_sym_nand] = ACTIONS(6319),
    [anon_sym_nor] = ACTIONS(6319),
    [anon_sym_xor] = ACTIONS(6319),
    [anon_sym_xnor] = ACTIONS(6319),
    [anon_sym_buf] = ACTIONS(6319),
    [anon_sym_tranif0] = ACTIONS(6319),
    [anon_sym_tranif1] = ACTIONS(6319),
    [anon_sym_rtranif1] = ACTIONS(6319),
    [anon_sym_rtranif0] = ACTIONS(6319),
    [anon_sym_tran] = ACTIONS(6319),
    [anon_sym_rtran] = ACTIONS(6319),
    [anon_sym_generate] = ACTIONS(6319),
    [anon_sym_endgenerate] = ACTIONS(6319),
    [anon_sym_for] = ACTIONS(6319),
    [anon_sym_initial] = ACTIONS(6319),
    [anon_sym_assign] = ACTIONS(6319),
    [anon_sym_alias] = ACTIONS(6319),
    [anon_sym_always_comb] = ACTIONS(6319),
    [anon_sym_always_latch] = ACTIONS(6319),
    [anon_sym_always_ff] = ACTIONS(6319),
    [anon_sym_final] = ACTIONS(6319),
    [anon_sym_global] = ACTIONS(6319),
    [anon_sym_LPAREN_STAR] = ACTIONS(6321),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6321),
    [anon_sym_DOLLARunit] = ACTIONS(6321),
  },
  [5161] = {
    [sym_simple_identifier] = ACTIONS(6323),
    [anon_sym_wire] = ACTIONS(6323),
    [anon_sym_tri] = ACTIONS(6323),
    [anon_sym_tri0] = ACTIONS(6323),
    [anon_sym_tri1] = ACTIONS(6323),
    [anon_sym_wand] = ACTIONS(6323),
    [anon_sym_triand] = ACTIONS(6323),
    [anon_sym_wor] = ACTIONS(6323),
    [anon_sym_trior] = ACTIONS(6323),
    [anon_sym_trireg] = ACTIONS(6323),
    [anon_sym_uwire] = ACTIONS(6323),
    [anon_sym_SEMI] = ACTIONS(6325),
    [anon_sym_extern] = ACTIONS(6323),
    [anon_sym_interface] = ACTIONS(6323),
    [anon_sym_checker] = ACTIONS(6323),
    [anon_sym_virtual] = ACTIONS(6323),
    [anon_sym_class] = ACTIONS(6323),
    [anon_sym_type] = ACTIONS(6323),
    [anon_sym_DOLLARfatal] = ACTIONS(6325),
    [anon_sym_DOLLARerror] = ACTIONS(6325),
    [anon_sym_DOLLARwarning] = ACTIONS(6325),
    [anon_sym_DOLLARinfo] = ACTIONS(6325),
    [anon_sym_default] = ACTIONS(6323),
    [anon_sym_clocking] = ACTIONS(6323),
    [anon_sym_defparam] = ACTIONS(6323),
    [anon_sym_bind] = ACTIONS(6323),
    [anon_sym_rand] = ACTIONS(6323),
    [anon_sym_const] = ACTIONS(6323),
    [anon_sym_function] = ACTIONS(6323),
    [anon_sym_static] = ACTIONS(6323),
    [anon_sym_constraint] = ACTIONS(6323),
    [anon_sym_if] = ACTIONS(6323),
    [anon_sym_else] = ACTIONS(6323),
    [anon_sym_LBRACK] = ACTIONS(6325),
    [anon_sym_localparam] = ACTIONS(6323),
    [anon_sym_parameter] = ACTIONS(6323),
    [anon_sym_var] = ACTIONS(6323),
    [anon_sym_import] = ACTIONS(6323),
    [anon_sym_export] = ACTIONS(6323),
    [anon_sym_genvar] = ACTIONS(6323),
    [anon_sym_interconnect] = ACTIONS(6323),
    [anon_sym_typedef] = ACTIONS(6323),
    [anon_sym_enum] = ACTIONS(6323),
    [anon_sym_struct] = ACTIONS(6323),
    [anon_sym_union] = ACTIONS(6323),
    [anon_sym_nettype] = ACTIONS(6323),
    [anon_sym_automatic] = ACTIONS(6323),
    [anon_sym_string] = ACTIONS(6323),
    [anon_sym_chandle] = ACTIONS(6323),
    [anon_sym_event] = ACTIONS(6323),
    [anon_sym_byte] = ACTIONS(6323),
    [anon_sym_shortint] = ACTIONS(6323),
    [anon_sym_int] = ACTIONS(6323),
    [anon_sym_longint] = ACTIONS(6323),
    [anon_sym_integer] = ACTIONS(6323),
    [anon_sym_time] = ACTIONS(6323),
    [anon_sym_bit] = ACTIONS(6323),
    [anon_sym_logic] = ACTIONS(6323),
    [anon_sym_reg] = ACTIONS(6323),
    [anon_sym_shortreal] = ACTIONS(6323),
    [anon_sym_real] = ACTIONS(6323),
    [anon_sym_realtime] = ACTIONS(6323),
    [anon_sym_supply0] = ACTIONS(6323),
    [anon_sym_supply1] = ACTIONS(6323),
    [anon_sym_signed] = ACTIONS(6323),
    [anon_sym_unsigned] = ACTIONS(6323),
    [anon_sym_task] = ACTIONS(6323),
    [anon_sym_assert] = ACTIONS(6323),
    [anon_sym_property] = ACTIONS(6323),
    [anon_sym_assume] = ACTIONS(6323),
    [anon_sym_cover] = ACTIONS(6323),
    [anon_sym_sequence] = ACTIONS(6323),
    [anon_sym_restrict] = ACTIONS(6323),
    [anon_sym_not] = ACTIONS(6323),
    [anon_sym_or] = ACTIONS(6323),
    [anon_sym_and] = ACTIONS(6323),
    [anon_sym_case] = ACTIONS(6323),
    [anon_sym_always] = ACTIONS(6323),
    [anon_sym_covergroup] = ACTIONS(6323),
    [anon_sym_let] = ACTIONS(6323),
    [anon_sym_pulldown] = ACTIONS(6323),
    [anon_sym_pullup] = ACTIONS(6323),
    [anon_sym_cmos] = ACTIONS(6323),
    [anon_sym_rcmos] = ACTIONS(6323),
    [anon_sym_bufif0] = ACTIONS(6323),
    [anon_sym_bufif1] = ACTIONS(6323),
    [anon_sym_notif0] = ACTIONS(6323),
    [anon_sym_notif1] = ACTIONS(6323),
    [anon_sym_nmos] = ACTIONS(6323),
    [anon_sym_pmos] = ACTIONS(6323),
    [anon_sym_rnmos] = ACTIONS(6323),
    [anon_sym_rpmos] = ACTIONS(6323),
    [anon_sym_nand] = ACTIONS(6323),
    [anon_sym_nor] = ACTIONS(6323),
    [anon_sym_xor] = ACTIONS(6323),
    [anon_sym_xnor] = ACTIONS(6323),
    [anon_sym_buf] = ACTIONS(6323),
    [anon_sym_tranif0] = ACTIONS(6323),
    [anon_sym_tranif1] = ACTIONS(6323),
    [anon_sym_rtranif1] = ACTIONS(6323),
    [anon_sym_rtranif0] = ACTIONS(6323),
    [anon_sym_tran] = ACTIONS(6323),
    [anon_sym_rtran] = ACTIONS(6323),
    [anon_sym_generate] = ACTIONS(6323),
    [anon_sym_endgenerate] = ACTIONS(6323),
    [anon_sym_for] = ACTIONS(6323),
    [anon_sym_initial] = ACTIONS(6323),
    [anon_sym_assign] = ACTIONS(6323),
    [anon_sym_alias] = ACTIONS(6323),
    [anon_sym_always_comb] = ACTIONS(6323),
    [anon_sym_always_latch] = ACTIONS(6323),
    [anon_sym_always_ff] = ACTIONS(6323),
    [anon_sym_final] = ACTIONS(6323),
    [anon_sym_global] = ACTIONS(6323),
    [anon_sym_LPAREN_STAR] = ACTIONS(6325),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6325),
    [anon_sym_DOLLARunit] = ACTIONS(6325),
  },
  [5162] = {
    [sym_simple_identifier] = ACTIONS(6597),
    [anon_sym_wire] = ACTIONS(6597),
    [anon_sym_tri] = ACTIONS(6597),
    [anon_sym_tri0] = ACTIONS(6597),
    [anon_sym_tri1] = ACTIONS(6597),
    [anon_sym_wand] = ACTIONS(6597),
    [anon_sym_triand] = ACTIONS(6597),
    [anon_sym_wor] = ACTIONS(6597),
    [anon_sym_trior] = ACTIONS(6597),
    [anon_sym_trireg] = ACTIONS(6597),
    [anon_sym_uwire] = ACTIONS(6597),
    [anon_sym_SEMI] = ACTIONS(6599),
    [anon_sym_extern] = ACTIONS(6597),
    [anon_sym_interface] = ACTIONS(6597),
    [anon_sym_checker] = ACTIONS(6597),
    [anon_sym_virtual] = ACTIONS(6597),
    [anon_sym_class] = ACTIONS(6597),
    [anon_sym_type] = ACTIONS(6597),
    [anon_sym_DOLLARfatal] = ACTIONS(6599),
    [anon_sym_DOLLARerror] = ACTIONS(6599),
    [anon_sym_DOLLARwarning] = ACTIONS(6599),
    [anon_sym_DOLLARinfo] = ACTIONS(6599),
    [anon_sym_default] = ACTIONS(6597),
    [anon_sym_clocking] = ACTIONS(6597),
    [anon_sym_defparam] = ACTIONS(6597),
    [anon_sym_bind] = ACTIONS(6597),
    [anon_sym_rand] = ACTIONS(6597),
    [anon_sym_const] = ACTIONS(6597),
    [anon_sym_function] = ACTIONS(6597),
    [anon_sym_static] = ACTIONS(6597),
    [anon_sym_constraint] = ACTIONS(6597),
    [anon_sym_if] = ACTIONS(6597),
    [anon_sym_else] = ACTIONS(6597),
    [anon_sym_LBRACK] = ACTIONS(6599),
    [anon_sym_localparam] = ACTIONS(6597),
    [anon_sym_parameter] = ACTIONS(6597),
    [anon_sym_var] = ACTIONS(6597),
    [anon_sym_import] = ACTIONS(6597),
    [anon_sym_export] = ACTIONS(6597),
    [anon_sym_genvar] = ACTIONS(6597),
    [anon_sym_interconnect] = ACTIONS(6597),
    [anon_sym_typedef] = ACTIONS(6597),
    [anon_sym_enum] = ACTIONS(6597),
    [anon_sym_struct] = ACTIONS(6597),
    [anon_sym_union] = ACTIONS(6597),
    [anon_sym_nettype] = ACTIONS(6597),
    [anon_sym_automatic] = ACTIONS(6597),
    [anon_sym_string] = ACTIONS(6597),
    [anon_sym_chandle] = ACTIONS(6597),
    [anon_sym_event] = ACTIONS(6597),
    [anon_sym_byte] = ACTIONS(6597),
    [anon_sym_shortint] = ACTIONS(6597),
    [anon_sym_int] = ACTIONS(6597),
    [anon_sym_longint] = ACTIONS(6597),
    [anon_sym_integer] = ACTIONS(6597),
    [anon_sym_time] = ACTIONS(6597),
    [anon_sym_bit] = ACTIONS(6597),
    [anon_sym_logic] = ACTIONS(6597),
    [anon_sym_reg] = ACTIONS(6597),
    [anon_sym_shortreal] = ACTIONS(6597),
    [anon_sym_real] = ACTIONS(6597),
    [anon_sym_realtime] = ACTIONS(6597),
    [anon_sym_supply0] = ACTIONS(6597),
    [anon_sym_supply1] = ACTIONS(6597),
    [anon_sym_signed] = ACTIONS(6597),
    [anon_sym_unsigned] = ACTIONS(6597),
    [anon_sym_task] = ACTIONS(6597),
    [anon_sym_assert] = ACTIONS(6597),
    [anon_sym_property] = ACTIONS(6597),
    [anon_sym_assume] = ACTIONS(6597),
    [anon_sym_cover] = ACTIONS(6597),
    [anon_sym_sequence] = ACTIONS(6597),
    [anon_sym_restrict] = ACTIONS(6597),
    [anon_sym_not] = ACTIONS(6597),
    [anon_sym_or] = ACTIONS(6597),
    [anon_sym_and] = ACTIONS(6597),
    [anon_sym_case] = ACTIONS(6597),
    [anon_sym_always] = ACTIONS(6597),
    [anon_sym_covergroup] = ACTIONS(6597),
    [anon_sym_let] = ACTIONS(6597),
    [anon_sym_pulldown] = ACTIONS(6597),
    [anon_sym_pullup] = ACTIONS(6597),
    [anon_sym_cmos] = ACTIONS(6597),
    [anon_sym_rcmos] = ACTIONS(6597),
    [anon_sym_bufif0] = ACTIONS(6597),
    [anon_sym_bufif1] = ACTIONS(6597),
    [anon_sym_notif0] = ACTIONS(6597),
    [anon_sym_notif1] = ACTIONS(6597),
    [anon_sym_nmos] = ACTIONS(6597),
    [anon_sym_pmos] = ACTIONS(6597),
    [anon_sym_rnmos] = ACTIONS(6597),
    [anon_sym_rpmos] = ACTIONS(6597),
    [anon_sym_nand] = ACTIONS(6597),
    [anon_sym_nor] = ACTIONS(6597),
    [anon_sym_xor] = ACTIONS(6597),
    [anon_sym_xnor] = ACTIONS(6597),
    [anon_sym_buf] = ACTIONS(6597),
    [anon_sym_tranif0] = ACTIONS(6597),
    [anon_sym_tranif1] = ACTIONS(6597),
    [anon_sym_rtranif1] = ACTIONS(6597),
    [anon_sym_rtranif0] = ACTIONS(6597),
    [anon_sym_tran] = ACTIONS(6597),
    [anon_sym_rtran] = ACTIONS(6597),
    [anon_sym_generate] = ACTIONS(6597),
    [anon_sym_endgenerate] = ACTIONS(6597),
    [anon_sym_for] = ACTIONS(6597),
    [anon_sym_initial] = ACTIONS(6597),
    [anon_sym_assign] = ACTIONS(6597),
    [anon_sym_alias] = ACTIONS(6597),
    [anon_sym_always_comb] = ACTIONS(6597),
    [anon_sym_always_latch] = ACTIONS(6597),
    [anon_sym_always_ff] = ACTIONS(6597),
    [anon_sym_final] = ACTIONS(6597),
    [anon_sym_global] = ACTIONS(6597),
    [anon_sym_LPAREN_STAR] = ACTIONS(6599),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6599),
    [anon_sym_DOLLARunit] = ACTIONS(6599),
  },
  [5163] = {
    [sym_simple_identifier] = ACTIONS(5366),
    [anon_sym_wire] = ACTIONS(5366),
    [anon_sym_tri] = ACTIONS(5366),
    [anon_sym_tri0] = ACTIONS(5366),
    [anon_sym_tri1] = ACTIONS(5366),
    [anon_sym_wand] = ACTIONS(5366),
    [anon_sym_triand] = ACTIONS(5366),
    [anon_sym_wor] = ACTIONS(5366),
    [anon_sym_trior] = ACTIONS(5366),
    [anon_sym_trireg] = ACTIONS(5366),
    [anon_sym_uwire] = ACTIONS(5366),
    [anon_sym_SEMI] = ACTIONS(5364),
    [anon_sym_extern] = ACTIONS(5366),
    [anon_sym_interface] = ACTIONS(5366),
    [anon_sym_checker] = ACTIONS(5366),
    [anon_sym_virtual] = ACTIONS(5366),
    [anon_sym_class] = ACTIONS(5366),
    [anon_sym_type] = ACTIONS(5366),
    [anon_sym_DOLLARfatal] = ACTIONS(5364),
    [anon_sym_DOLLARerror] = ACTIONS(5364),
    [anon_sym_DOLLARwarning] = ACTIONS(5364),
    [anon_sym_DOLLARinfo] = ACTIONS(5364),
    [anon_sym_default] = ACTIONS(5366),
    [anon_sym_clocking] = ACTIONS(5366),
    [anon_sym_defparam] = ACTIONS(5366),
    [anon_sym_bind] = ACTIONS(5366),
    [anon_sym_rand] = ACTIONS(5366),
    [anon_sym_const] = ACTIONS(5366),
    [anon_sym_function] = ACTIONS(5366),
    [anon_sym_static] = ACTIONS(5366),
    [anon_sym_constraint] = ACTIONS(5366),
    [anon_sym_if] = ACTIONS(5366),
    [anon_sym_else] = ACTIONS(5366),
    [anon_sym_LBRACK] = ACTIONS(5364),
    [anon_sym_localparam] = ACTIONS(5366),
    [anon_sym_parameter] = ACTIONS(5366),
    [anon_sym_var] = ACTIONS(5366),
    [anon_sym_import] = ACTIONS(5366),
    [anon_sym_export] = ACTIONS(5366),
    [anon_sym_genvar] = ACTIONS(5366),
    [anon_sym_interconnect] = ACTIONS(5366),
    [anon_sym_typedef] = ACTIONS(5366),
    [anon_sym_enum] = ACTIONS(5366),
    [anon_sym_struct] = ACTIONS(5366),
    [anon_sym_union] = ACTIONS(5366),
    [anon_sym_nettype] = ACTIONS(5366),
    [anon_sym_automatic] = ACTIONS(5366),
    [anon_sym_string] = ACTIONS(5366),
    [anon_sym_chandle] = ACTIONS(5366),
    [anon_sym_event] = ACTIONS(5366),
    [anon_sym_byte] = ACTIONS(5366),
    [anon_sym_shortint] = ACTIONS(5366),
    [anon_sym_int] = ACTIONS(5366),
    [anon_sym_longint] = ACTIONS(5366),
    [anon_sym_integer] = ACTIONS(5366),
    [anon_sym_time] = ACTIONS(5366),
    [anon_sym_bit] = ACTIONS(5366),
    [anon_sym_logic] = ACTIONS(5366),
    [anon_sym_reg] = ACTIONS(5366),
    [anon_sym_shortreal] = ACTIONS(5366),
    [anon_sym_real] = ACTIONS(5366),
    [anon_sym_realtime] = ACTIONS(5366),
    [anon_sym_supply0] = ACTIONS(5366),
    [anon_sym_supply1] = ACTIONS(5366),
    [anon_sym_signed] = ACTIONS(5366),
    [anon_sym_unsigned] = ACTIONS(5366),
    [anon_sym_task] = ACTIONS(5366),
    [anon_sym_assert] = ACTIONS(5366),
    [anon_sym_property] = ACTIONS(5366),
    [anon_sym_assume] = ACTIONS(5366),
    [anon_sym_cover] = ACTIONS(5366),
    [anon_sym_sequence] = ACTIONS(5366),
    [anon_sym_restrict] = ACTIONS(5366),
    [anon_sym_not] = ACTIONS(5366),
    [anon_sym_or] = ACTIONS(5366),
    [anon_sym_and] = ACTIONS(5366),
    [anon_sym_case] = ACTIONS(5366),
    [anon_sym_always] = ACTIONS(5366),
    [anon_sym_covergroup] = ACTIONS(5366),
    [anon_sym_let] = ACTIONS(5366),
    [anon_sym_pulldown] = ACTIONS(5366),
    [anon_sym_pullup] = ACTIONS(5366),
    [anon_sym_cmos] = ACTIONS(5366),
    [anon_sym_rcmos] = ACTIONS(5366),
    [anon_sym_bufif0] = ACTIONS(5366),
    [anon_sym_bufif1] = ACTIONS(5366),
    [anon_sym_notif0] = ACTIONS(5366),
    [anon_sym_notif1] = ACTIONS(5366),
    [anon_sym_nmos] = ACTIONS(5366),
    [anon_sym_pmos] = ACTIONS(5366),
    [anon_sym_rnmos] = ACTIONS(5366),
    [anon_sym_rpmos] = ACTIONS(5366),
    [anon_sym_nand] = ACTIONS(5366),
    [anon_sym_nor] = ACTIONS(5366),
    [anon_sym_xor] = ACTIONS(5366),
    [anon_sym_xnor] = ACTIONS(5366),
    [anon_sym_buf] = ACTIONS(5366),
    [anon_sym_tranif0] = ACTIONS(5366),
    [anon_sym_tranif1] = ACTIONS(5366),
    [anon_sym_rtranif1] = ACTIONS(5366),
    [anon_sym_rtranif0] = ACTIONS(5366),
    [anon_sym_tran] = ACTIONS(5366),
    [anon_sym_rtran] = ACTIONS(5366),
    [anon_sym_generate] = ACTIONS(5366),
    [anon_sym_endgenerate] = ACTIONS(5366),
    [anon_sym_for] = ACTIONS(5366),
    [anon_sym_initial] = ACTIONS(5366),
    [anon_sym_assign] = ACTIONS(5366),
    [anon_sym_alias] = ACTIONS(5366),
    [anon_sym_always_comb] = ACTIONS(5366),
    [anon_sym_always_latch] = ACTIONS(5366),
    [anon_sym_always_ff] = ACTIONS(5366),
    [anon_sym_final] = ACTIONS(5366),
    [anon_sym_global] = ACTIONS(5366),
    [anon_sym_LPAREN_STAR] = ACTIONS(5364),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5364),
    [anon_sym_DOLLARunit] = ACTIONS(5364),
  },
  [5164] = {
    [sym_simple_identifier] = ACTIONS(4542),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_rand] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_endgenerate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [5165] = {
    [sym_simple_identifier] = ACTIONS(6357),
    [anon_sym_wire] = ACTIONS(6357),
    [anon_sym_tri] = ACTIONS(6357),
    [anon_sym_tri0] = ACTIONS(6357),
    [anon_sym_tri1] = ACTIONS(6357),
    [anon_sym_wand] = ACTIONS(6357),
    [anon_sym_triand] = ACTIONS(6357),
    [anon_sym_wor] = ACTIONS(6357),
    [anon_sym_trior] = ACTIONS(6357),
    [anon_sym_trireg] = ACTIONS(6357),
    [anon_sym_uwire] = ACTIONS(6357),
    [anon_sym_SEMI] = ACTIONS(6359),
    [anon_sym_extern] = ACTIONS(6357),
    [anon_sym_interface] = ACTIONS(6357),
    [anon_sym_checker] = ACTIONS(6357),
    [anon_sym_virtual] = ACTIONS(6357),
    [anon_sym_class] = ACTIONS(6357),
    [anon_sym_type] = ACTIONS(6357),
    [anon_sym_DOLLARfatal] = ACTIONS(6359),
    [anon_sym_DOLLARerror] = ACTIONS(6359),
    [anon_sym_DOLLARwarning] = ACTIONS(6359),
    [anon_sym_DOLLARinfo] = ACTIONS(6359),
    [anon_sym_default] = ACTIONS(6357),
    [anon_sym_clocking] = ACTIONS(6357),
    [anon_sym_defparam] = ACTIONS(6357),
    [anon_sym_bind] = ACTIONS(6357),
    [anon_sym_rand] = ACTIONS(6357),
    [anon_sym_const] = ACTIONS(6357),
    [anon_sym_function] = ACTIONS(6357),
    [anon_sym_static] = ACTIONS(6357),
    [anon_sym_constraint] = ACTIONS(6357),
    [anon_sym_if] = ACTIONS(6357),
    [anon_sym_else] = ACTIONS(6357),
    [anon_sym_LBRACK] = ACTIONS(6359),
    [anon_sym_localparam] = ACTIONS(6357),
    [anon_sym_parameter] = ACTIONS(6357),
    [anon_sym_var] = ACTIONS(6357),
    [anon_sym_import] = ACTIONS(6357),
    [anon_sym_export] = ACTIONS(6357),
    [anon_sym_genvar] = ACTIONS(6357),
    [anon_sym_interconnect] = ACTIONS(6357),
    [anon_sym_typedef] = ACTIONS(6357),
    [anon_sym_enum] = ACTIONS(6357),
    [anon_sym_struct] = ACTIONS(6357),
    [anon_sym_union] = ACTIONS(6357),
    [anon_sym_nettype] = ACTIONS(6357),
    [anon_sym_automatic] = ACTIONS(6357),
    [anon_sym_string] = ACTIONS(6357),
    [anon_sym_chandle] = ACTIONS(6357),
    [anon_sym_event] = ACTIONS(6357),
    [anon_sym_byte] = ACTIONS(6357),
    [anon_sym_shortint] = ACTIONS(6357),
    [anon_sym_int] = ACTIONS(6357),
    [anon_sym_longint] = ACTIONS(6357),
    [anon_sym_integer] = ACTIONS(6357),
    [anon_sym_time] = ACTIONS(6357),
    [anon_sym_bit] = ACTIONS(6357),
    [anon_sym_logic] = ACTIONS(6357),
    [anon_sym_reg] = ACTIONS(6357),
    [anon_sym_shortreal] = ACTIONS(6357),
    [anon_sym_real] = ACTIONS(6357),
    [anon_sym_realtime] = ACTIONS(6357),
    [anon_sym_supply0] = ACTIONS(6357),
    [anon_sym_supply1] = ACTIONS(6357),
    [anon_sym_signed] = ACTIONS(6357),
    [anon_sym_unsigned] = ACTIONS(6357),
    [anon_sym_task] = ACTIONS(6357),
    [anon_sym_assert] = ACTIONS(6357),
    [anon_sym_property] = ACTIONS(6357),
    [anon_sym_assume] = ACTIONS(6357),
    [anon_sym_cover] = ACTIONS(6357),
    [anon_sym_sequence] = ACTIONS(6357),
    [anon_sym_restrict] = ACTIONS(6357),
    [anon_sym_not] = ACTIONS(6357),
    [anon_sym_or] = ACTIONS(6357),
    [anon_sym_and] = ACTIONS(6357),
    [anon_sym_case] = ACTIONS(6357),
    [anon_sym_always] = ACTIONS(6357),
    [anon_sym_covergroup] = ACTIONS(6357),
    [anon_sym_let] = ACTIONS(6357),
    [anon_sym_pulldown] = ACTIONS(6357),
    [anon_sym_pullup] = ACTIONS(6357),
    [anon_sym_cmos] = ACTIONS(6357),
    [anon_sym_rcmos] = ACTIONS(6357),
    [anon_sym_bufif0] = ACTIONS(6357),
    [anon_sym_bufif1] = ACTIONS(6357),
    [anon_sym_notif0] = ACTIONS(6357),
    [anon_sym_notif1] = ACTIONS(6357),
    [anon_sym_nmos] = ACTIONS(6357),
    [anon_sym_pmos] = ACTIONS(6357),
    [anon_sym_rnmos] = ACTIONS(6357),
    [anon_sym_rpmos] = ACTIONS(6357),
    [anon_sym_nand] = ACTIONS(6357),
    [anon_sym_nor] = ACTIONS(6357),
    [anon_sym_xor] = ACTIONS(6357),
    [anon_sym_xnor] = ACTIONS(6357),
    [anon_sym_buf] = ACTIONS(6357),
    [anon_sym_tranif0] = ACTIONS(6357),
    [anon_sym_tranif1] = ACTIONS(6357),
    [anon_sym_rtranif1] = ACTIONS(6357),
    [anon_sym_rtranif0] = ACTIONS(6357),
    [anon_sym_tran] = ACTIONS(6357),
    [anon_sym_rtran] = ACTIONS(6357),
    [anon_sym_generate] = ACTIONS(6357),
    [anon_sym_endgenerate] = ACTIONS(6357),
    [anon_sym_for] = ACTIONS(6357),
    [anon_sym_initial] = ACTIONS(6357),
    [anon_sym_assign] = ACTIONS(6357),
    [anon_sym_alias] = ACTIONS(6357),
    [anon_sym_always_comb] = ACTIONS(6357),
    [anon_sym_always_latch] = ACTIONS(6357),
    [anon_sym_always_ff] = ACTIONS(6357),
    [anon_sym_final] = ACTIONS(6357),
    [anon_sym_global] = ACTIONS(6357),
    [anon_sym_LPAREN_STAR] = ACTIONS(6359),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6359),
    [anon_sym_DOLLARunit] = ACTIONS(6359),
  },
  [5166] = {
    [sym_simple_identifier] = ACTIONS(4260),
    [anon_sym_wire] = ACTIONS(4260),
    [anon_sym_tri] = ACTIONS(4260),
    [anon_sym_tri0] = ACTIONS(4260),
    [anon_sym_tri1] = ACTIONS(4260),
    [anon_sym_wand] = ACTIONS(4260),
    [anon_sym_triand] = ACTIONS(4260),
    [anon_sym_wor] = ACTIONS(4260),
    [anon_sym_trior] = ACTIONS(4260),
    [anon_sym_trireg] = ACTIONS(4260),
    [anon_sym_uwire] = ACTIONS(4260),
    [anon_sym_SEMI] = ACTIONS(4258),
    [anon_sym_extern] = ACTIONS(4260),
    [anon_sym_interface] = ACTIONS(4260),
    [anon_sym_checker] = ACTIONS(4260),
    [anon_sym_virtual] = ACTIONS(4260),
    [anon_sym_class] = ACTIONS(4260),
    [anon_sym_type] = ACTIONS(4260),
    [anon_sym_DOLLARfatal] = ACTIONS(4258),
    [anon_sym_DOLLARerror] = ACTIONS(4258),
    [anon_sym_DOLLARwarning] = ACTIONS(4258),
    [anon_sym_DOLLARinfo] = ACTIONS(4258),
    [anon_sym_default] = ACTIONS(4260),
    [anon_sym_clocking] = ACTIONS(4260),
    [anon_sym_defparam] = ACTIONS(4260),
    [anon_sym_bind] = ACTIONS(4260),
    [anon_sym_rand] = ACTIONS(4260),
    [anon_sym_const] = ACTIONS(4260),
    [anon_sym_function] = ACTIONS(4260),
    [anon_sym_static] = ACTIONS(4260),
    [anon_sym_constraint] = ACTIONS(4260),
    [anon_sym_if] = ACTIONS(4260),
    [anon_sym_else] = ACTIONS(4260),
    [anon_sym_LBRACK] = ACTIONS(4258),
    [anon_sym_localparam] = ACTIONS(4260),
    [anon_sym_parameter] = ACTIONS(4260),
    [anon_sym_var] = ACTIONS(4260),
    [anon_sym_import] = ACTIONS(4260),
    [anon_sym_export] = ACTIONS(4260),
    [anon_sym_genvar] = ACTIONS(4260),
    [anon_sym_interconnect] = ACTIONS(4260),
    [anon_sym_typedef] = ACTIONS(4260),
    [anon_sym_enum] = ACTIONS(4260),
    [anon_sym_struct] = ACTIONS(4260),
    [anon_sym_union] = ACTIONS(4260),
    [anon_sym_nettype] = ACTIONS(4260),
    [anon_sym_automatic] = ACTIONS(4260),
    [anon_sym_string] = ACTIONS(4260),
    [anon_sym_chandle] = ACTIONS(4260),
    [anon_sym_event] = ACTIONS(4260),
    [anon_sym_byte] = ACTIONS(4260),
    [anon_sym_shortint] = ACTIONS(4260),
    [anon_sym_int] = ACTIONS(4260),
    [anon_sym_longint] = ACTIONS(4260),
    [anon_sym_integer] = ACTIONS(4260),
    [anon_sym_time] = ACTIONS(4260),
    [anon_sym_bit] = ACTIONS(4260),
    [anon_sym_logic] = ACTIONS(4260),
    [anon_sym_reg] = ACTIONS(4260),
    [anon_sym_shortreal] = ACTIONS(4260),
    [anon_sym_real] = ACTIONS(4260),
    [anon_sym_realtime] = ACTIONS(4260),
    [anon_sym_supply0] = ACTIONS(4260),
    [anon_sym_supply1] = ACTIONS(4260),
    [anon_sym_signed] = ACTIONS(4260),
    [anon_sym_unsigned] = ACTIONS(4260),
    [anon_sym_task] = ACTIONS(4260),
    [anon_sym_assert] = ACTIONS(4260),
    [anon_sym_property] = ACTIONS(4260),
    [anon_sym_assume] = ACTIONS(4260),
    [anon_sym_cover] = ACTIONS(4260),
    [anon_sym_sequence] = ACTIONS(4260),
    [anon_sym_restrict] = ACTIONS(4260),
    [anon_sym_not] = ACTIONS(4260),
    [anon_sym_or] = ACTIONS(4260),
    [anon_sym_and] = ACTIONS(4260),
    [anon_sym_case] = ACTIONS(4260),
    [anon_sym_always] = ACTIONS(4260),
    [anon_sym_covergroup] = ACTIONS(4260),
    [anon_sym_end] = ACTIONS(4260),
    [anon_sym_let] = ACTIONS(4260),
    [anon_sym_pulldown] = ACTIONS(4260),
    [anon_sym_pullup] = ACTIONS(4260),
    [anon_sym_cmos] = ACTIONS(4260),
    [anon_sym_rcmos] = ACTIONS(4260),
    [anon_sym_bufif0] = ACTIONS(4260),
    [anon_sym_bufif1] = ACTIONS(4260),
    [anon_sym_notif0] = ACTIONS(4260),
    [anon_sym_notif1] = ACTIONS(4260),
    [anon_sym_nmos] = ACTIONS(4260),
    [anon_sym_pmos] = ACTIONS(4260),
    [anon_sym_rnmos] = ACTIONS(4260),
    [anon_sym_rpmos] = ACTIONS(4260),
    [anon_sym_nand] = ACTIONS(4260),
    [anon_sym_nor] = ACTIONS(4260),
    [anon_sym_xor] = ACTIONS(4260),
    [anon_sym_xnor] = ACTIONS(4260),
    [anon_sym_buf] = ACTIONS(4260),
    [anon_sym_tranif0] = ACTIONS(4260),
    [anon_sym_tranif1] = ACTIONS(4260),
    [anon_sym_rtranif1] = ACTIONS(4260),
    [anon_sym_rtranif0] = ACTIONS(4260),
    [anon_sym_tran] = ACTIONS(4260),
    [anon_sym_rtran] = ACTIONS(4260),
    [anon_sym_generate] = ACTIONS(4260),
    [anon_sym_for] = ACTIONS(4260),
    [anon_sym_initial] = ACTIONS(4260),
    [anon_sym_assign] = ACTIONS(4260),
    [anon_sym_alias] = ACTIONS(4260),
    [anon_sym_always_comb] = ACTIONS(4260),
    [anon_sym_always_latch] = ACTIONS(4260),
    [anon_sym_always_ff] = ACTIONS(4260),
    [anon_sym_final] = ACTIONS(4260),
    [anon_sym_global] = ACTIONS(4260),
    [anon_sym_LPAREN_STAR] = ACTIONS(4258),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4258),
    [anon_sym_DOLLARunit] = ACTIONS(4258),
  },
  [5167] = {
    [sym_simple_identifier] = ACTIONS(4844),
    [anon_sym_wire] = ACTIONS(4844),
    [anon_sym_tri] = ACTIONS(4844),
    [anon_sym_tri0] = ACTIONS(4844),
    [anon_sym_tri1] = ACTIONS(4844),
    [anon_sym_wand] = ACTIONS(4844),
    [anon_sym_triand] = ACTIONS(4844),
    [anon_sym_wor] = ACTIONS(4844),
    [anon_sym_trior] = ACTIONS(4844),
    [anon_sym_trireg] = ACTIONS(4844),
    [anon_sym_uwire] = ACTIONS(4844),
    [anon_sym_SEMI] = ACTIONS(4842),
    [anon_sym_extern] = ACTIONS(4844),
    [anon_sym_interface] = ACTIONS(4844),
    [anon_sym_checker] = ACTIONS(4844),
    [anon_sym_virtual] = ACTIONS(4844),
    [anon_sym_class] = ACTIONS(4844),
    [anon_sym_type] = ACTIONS(4844),
    [anon_sym_DOLLARfatal] = ACTIONS(4842),
    [anon_sym_DOLLARerror] = ACTIONS(4842),
    [anon_sym_DOLLARwarning] = ACTIONS(4842),
    [anon_sym_DOLLARinfo] = ACTIONS(4842),
    [anon_sym_default] = ACTIONS(4844),
    [anon_sym_clocking] = ACTIONS(4844),
    [anon_sym_defparam] = ACTIONS(4844),
    [anon_sym_bind] = ACTIONS(4844),
    [anon_sym_rand] = ACTIONS(4844),
    [anon_sym_const] = ACTIONS(4844),
    [anon_sym_function] = ACTIONS(4844),
    [anon_sym_static] = ACTIONS(4844),
    [anon_sym_constraint] = ACTIONS(4844),
    [anon_sym_if] = ACTIONS(4844),
    [anon_sym_else] = ACTIONS(4844),
    [anon_sym_LBRACK] = ACTIONS(4842),
    [anon_sym_localparam] = ACTIONS(4844),
    [anon_sym_parameter] = ACTIONS(4844),
    [anon_sym_var] = ACTIONS(4844),
    [anon_sym_import] = ACTIONS(4844),
    [anon_sym_export] = ACTIONS(4844),
    [anon_sym_genvar] = ACTIONS(4844),
    [anon_sym_interconnect] = ACTIONS(4844),
    [anon_sym_typedef] = ACTIONS(4844),
    [anon_sym_enum] = ACTIONS(4844),
    [anon_sym_struct] = ACTIONS(4844),
    [anon_sym_union] = ACTIONS(4844),
    [anon_sym_nettype] = ACTIONS(4844),
    [anon_sym_automatic] = ACTIONS(4844),
    [anon_sym_string] = ACTIONS(4844),
    [anon_sym_chandle] = ACTIONS(4844),
    [anon_sym_event] = ACTIONS(4844),
    [anon_sym_byte] = ACTIONS(4844),
    [anon_sym_shortint] = ACTIONS(4844),
    [anon_sym_int] = ACTIONS(4844),
    [anon_sym_longint] = ACTIONS(4844),
    [anon_sym_integer] = ACTIONS(4844),
    [anon_sym_time] = ACTIONS(4844),
    [anon_sym_bit] = ACTIONS(4844),
    [anon_sym_logic] = ACTIONS(4844),
    [anon_sym_reg] = ACTIONS(4844),
    [anon_sym_shortreal] = ACTIONS(4844),
    [anon_sym_real] = ACTIONS(4844),
    [anon_sym_realtime] = ACTIONS(4844),
    [anon_sym_supply0] = ACTIONS(4844),
    [anon_sym_supply1] = ACTIONS(4844),
    [anon_sym_signed] = ACTIONS(4844),
    [anon_sym_unsigned] = ACTIONS(4844),
    [anon_sym_task] = ACTIONS(4844),
    [anon_sym_assert] = ACTIONS(4844),
    [anon_sym_property] = ACTIONS(4844),
    [anon_sym_assume] = ACTIONS(4844),
    [anon_sym_cover] = ACTIONS(4844),
    [anon_sym_sequence] = ACTIONS(4844),
    [anon_sym_restrict] = ACTIONS(4844),
    [anon_sym_not] = ACTIONS(4844),
    [anon_sym_or] = ACTIONS(4844),
    [anon_sym_and] = ACTIONS(4844),
    [anon_sym_case] = ACTIONS(4844),
    [anon_sym_always] = ACTIONS(4844),
    [anon_sym_covergroup] = ACTIONS(4844),
    [anon_sym_end] = ACTIONS(4844),
    [anon_sym_let] = ACTIONS(4844),
    [anon_sym_pulldown] = ACTIONS(4844),
    [anon_sym_pullup] = ACTIONS(4844),
    [anon_sym_cmos] = ACTIONS(4844),
    [anon_sym_rcmos] = ACTIONS(4844),
    [anon_sym_bufif0] = ACTIONS(4844),
    [anon_sym_bufif1] = ACTIONS(4844),
    [anon_sym_notif0] = ACTIONS(4844),
    [anon_sym_notif1] = ACTIONS(4844),
    [anon_sym_nmos] = ACTIONS(4844),
    [anon_sym_pmos] = ACTIONS(4844),
    [anon_sym_rnmos] = ACTIONS(4844),
    [anon_sym_rpmos] = ACTIONS(4844),
    [anon_sym_nand] = ACTIONS(4844),
    [anon_sym_nor] = ACTIONS(4844),
    [anon_sym_xor] = ACTIONS(4844),
    [anon_sym_xnor] = ACTIONS(4844),
    [anon_sym_buf] = ACTIONS(4844),
    [anon_sym_tranif0] = ACTIONS(4844),
    [anon_sym_tranif1] = ACTIONS(4844),
    [anon_sym_rtranif1] = ACTIONS(4844),
    [anon_sym_rtranif0] = ACTIONS(4844),
    [anon_sym_tran] = ACTIONS(4844),
    [anon_sym_rtran] = ACTIONS(4844),
    [anon_sym_generate] = ACTIONS(4844),
    [anon_sym_for] = ACTIONS(4844),
    [anon_sym_initial] = ACTIONS(4844),
    [anon_sym_assign] = ACTIONS(4844),
    [anon_sym_alias] = ACTIONS(4844),
    [anon_sym_always_comb] = ACTIONS(4844),
    [anon_sym_always_latch] = ACTIONS(4844),
    [anon_sym_always_ff] = ACTIONS(4844),
    [anon_sym_final] = ACTIONS(4844),
    [anon_sym_global] = ACTIONS(4844),
    [anon_sym_LPAREN_STAR] = ACTIONS(4842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4842),
    [anon_sym_DOLLARunit] = ACTIONS(4842),
  },
  [5168] = {
    [sym_simple_identifier] = ACTIONS(4270),
    [anon_sym_wire] = ACTIONS(4270),
    [anon_sym_tri] = ACTIONS(4270),
    [anon_sym_tri0] = ACTIONS(4270),
    [anon_sym_tri1] = ACTIONS(4270),
    [anon_sym_wand] = ACTIONS(4270),
    [anon_sym_triand] = ACTIONS(4270),
    [anon_sym_wor] = ACTIONS(4270),
    [anon_sym_trior] = ACTIONS(4270),
    [anon_sym_trireg] = ACTIONS(4270),
    [anon_sym_uwire] = ACTIONS(4270),
    [anon_sym_SEMI] = ACTIONS(4268),
    [anon_sym_extern] = ACTIONS(4270),
    [anon_sym_interface] = ACTIONS(4270),
    [anon_sym_checker] = ACTIONS(4270),
    [anon_sym_virtual] = ACTIONS(4270),
    [anon_sym_class] = ACTIONS(4270),
    [anon_sym_type] = ACTIONS(4270),
    [anon_sym_DOLLARfatal] = ACTIONS(4268),
    [anon_sym_DOLLARerror] = ACTIONS(4268),
    [anon_sym_DOLLARwarning] = ACTIONS(4268),
    [anon_sym_DOLLARinfo] = ACTIONS(4268),
    [anon_sym_default] = ACTIONS(4270),
    [anon_sym_clocking] = ACTIONS(4270),
    [anon_sym_defparam] = ACTIONS(4270),
    [anon_sym_bind] = ACTIONS(4270),
    [anon_sym_rand] = ACTIONS(4270),
    [anon_sym_const] = ACTIONS(4270),
    [anon_sym_function] = ACTIONS(4270),
    [anon_sym_static] = ACTIONS(4270),
    [anon_sym_constraint] = ACTIONS(4270),
    [anon_sym_if] = ACTIONS(4270),
    [anon_sym_else] = ACTIONS(4270),
    [anon_sym_LBRACK] = ACTIONS(4268),
    [anon_sym_localparam] = ACTIONS(4270),
    [anon_sym_parameter] = ACTIONS(4270),
    [anon_sym_var] = ACTIONS(4270),
    [anon_sym_import] = ACTIONS(4270),
    [anon_sym_export] = ACTIONS(4270),
    [anon_sym_genvar] = ACTIONS(4270),
    [anon_sym_interconnect] = ACTIONS(4270),
    [anon_sym_typedef] = ACTIONS(4270),
    [anon_sym_enum] = ACTIONS(4270),
    [anon_sym_struct] = ACTIONS(4270),
    [anon_sym_union] = ACTIONS(4270),
    [anon_sym_nettype] = ACTIONS(4270),
    [anon_sym_automatic] = ACTIONS(4270),
    [anon_sym_string] = ACTIONS(4270),
    [anon_sym_chandle] = ACTIONS(4270),
    [anon_sym_event] = ACTIONS(4270),
    [anon_sym_byte] = ACTIONS(4270),
    [anon_sym_shortint] = ACTIONS(4270),
    [anon_sym_int] = ACTIONS(4270),
    [anon_sym_longint] = ACTIONS(4270),
    [anon_sym_integer] = ACTIONS(4270),
    [anon_sym_time] = ACTIONS(4270),
    [anon_sym_bit] = ACTIONS(4270),
    [anon_sym_logic] = ACTIONS(4270),
    [anon_sym_reg] = ACTIONS(4270),
    [anon_sym_shortreal] = ACTIONS(4270),
    [anon_sym_real] = ACTIONS(4270),
    [anon_sym_realtime] = ACTIONS(4270),
    [anon_sym_supply0] = ACTIONS(4270),
    [anon_sym_supply1] = ACTIONS(4270),
    [anon_sym_signed] = ACTIONS(4270),
    [anon_sym_unsigned] = ACTIONS(4270),
    [anon_sym_task] = ACTIONS(4270),
    [anon_sym_assert] = ACTIONS(4270),
    [anon_sym_property] = ACTIONS(4270),
    [anon_sym_assume] = ACTIONS(4270),
    [anon_sym_cover] = ACTIONS(4270),
    [anon_sym_sequence] = ACTIONS(4270),
    [anon_sym_restrict] = ACTIONS(4270),
    [anon_sym_not] = ACTIONS(4270),
    [anon_sym_or] = ACTIONS(4270),
    [anon_sym_and] = ACTIONS(4270),
    [anon_sym_case] = ACTIONS(4270),
    [anon_sym_always] = ACTIONS(4270),
    [anon_sym_covergroup] = ACTIONS(4270),
    [anon_sym_end] = ACTIONS(4270),
    [anon_sym_let] = ACTIONS(4270),
    [anon_sym_pulldown] = ACTIONS(4270),
    [anon_sym_pullup] = ACTIONS(4270),
    [anon_sym_cmos] = ACTIONS(4270),
    [anon_sym_rcmos] = ACTIONS(4270),
    [anon_sym_bufif0] = ACTIONS(4270),
    [anon_sym_bufif1] = ACTIONS(4270),
    [anon_sym_notif0] = ACTIONS(4270),
    [anon_sym_notif1] = ACTIONS(4270),
    [anon_sym_nmos] = ACTIONS(4270),
    [anon_sym_pmos] = ACTIONS(4270),
    [anon_sym_rnmos] = ACTIONS(4270),
    [anon_sym_rpmos] = ACTIONS(4270),
    [anon_sym_nand] = ACTIONS(4270),
    [anon_sym_nor] = ACTIONS(4270),
    [anon_sym_xor] = ACTIONS(4270),
    [anon_sym_xnor] = ACTIONS(4270),
    [anon_sym_buf] = ACTIONS(4270),
    [anon_sym_tranif0] = ACTIONS(4270),
    [anon_sym_tranif1] = ACTIONS(4270),
    [anon_sym_rtranif1] = ACTIONS(4270),
    [anon_sym_rtranif0] = ACTIONS(4270),
    [anon_sym_tran] = ACTIONS(4270),
    [anon_sym_rtran] = ACTIONS(4270),
    [anon_sym_generate] = ACTIONS(4270),
    [anon_sym_for] = ACTIONS(4270),
    [anon_sym_initial] = ACTIONS(4270),
    [anon_sym_assign] = ACTIONS(4270),
    [anon_sym_alias] = ACTIONS(4270),
    [anon_sym_always_comb] = ACTIONS(4270),
    [anon_sym_always_latch] = ACTIONS(4270),
    [anon_sym_always_ff] = ACTIONS(4270),
    [anon_sym_final] = ACTIONS(4270),
    [anon_sym_global] = ACTIONS(4270),
    [anon_sym_LPAREN_STAR] = ACTIONS(4268),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4268),
    [anon_sym_DOLLARunit] = ACTIONS(4268),
  },
  [5169] = {
    [sym_simple_identifier] = ACTIONS(6379),
    [anon_sym_wire] = ACTIONS(6379),
    [anon_sym_tri] = ACTIONS(6379),
    [anon_sym_tri0] = ACTIONS(6379),
    [anon_sym_tri1] = ACTIONS(6379),
    [anon_sym_wand] = ACTIONS(6379),
    [anon_sym_triand] = ACTIONS(6379),
    [anon_sym_wor] = ACTIONS(6379),
    [anon_sym_trior] = ACTIONS(6379),
    [anon_sym_trireg] = ACTIONS(6379),
    [anon_sym_uwire] = ACTIONS(6379),
    [anon_sym_SEMI] = ACTIONS(6381),
    [anon_sym_extern] = ACTIONS(6379),
    [anon_sym_interface] = ACTIONS(6379),
    [anon_sym_checker] = ACTIONS(6379),
    [anon_sym_virtual] = ACTIONS(6379),
    [anon_sym_class] = ACTIONS(6379),
    [anon_sym_type] = ACTIONS(6379),
    [anon_sym_DOLLARfatal] = ACTIONS(6381),
    [anon_sym_DOLLARerror] = ACTIONS(6381),
    [anon_sym_DOLLARwarning] = ACTIONS(6381),
    [anon_sym_DOLLARinfo] = ACTIONS(6381),
    [anon_sym_default] = ACTIONS(6379),
    [anon_sym_clocking] = ACTIONS(6379),
    [anon_sym_defparam] = ACTIONS(6379),
    [anon_sym_bind] = ACTIONS(6379),
    [anon_sym_rand] = ACTIONS(6379),
    [anon_sym_const] = ACTIONS(6379),
    [anon_sym_function] = ACTIONS(6379),
    [anon_sym_static] = ACTIONS(6379),
    [anon_sym_constraint] = ACTIONS(6379),
    [anon_sym_if] = ACTIONS(6379),
    [anon_sym_else] = ACTIONS(6379),
    [anon_sym_LBRACK] = ACTIONS(6381),
    [anon_sym_localparam] = ACTIONS(6379),
    [anon_sym_parameter] = ACTIONS(6379),
    [anon_sym_var] = ACTIONS(6379),
    [anon_sym_import] = ACTIONS(6379),
    [anon_sym_export] = ACTIONS(6379),
    [anon_sym_genvar] = ACTIONS(6379),
    [anon_sym_interconnect] = ACTIONS(6379),
    [anon_sym_typedef] = ACTIONS(6379),
    [anon_sym_enum] = ACTIONS(6379),
    [anon_sym_struct] = ACTIONS(6379),
    [anon_sym_union] = ACTIONS(6379),
    [anon_sym_nettype] = ACTIONS(6379),
    [anon_sym_automatic] = ACTIONS(6379),
    [anon_sym_string] = ACTIONS(6379),
    [anon_sym_chandle] = ACTIONS(6379),
    [anon_sym_event] = ACTIONS(6379),
    [anon_sym_byte] = ACTIONS(6379),
    [anon_sym_shortint] = ACTIONS(6379),
    [anon_sym_int] = ACTIONS(6379),
    [anon_sym_longint] = ACTIONS(6379),
    [anon_sym_integer] = ACTIONS(6379),
    [anon_sym_time] = ACTIONS(6379),
    [anon_sym_bit] = ACTIONS(6379),
    [anon_sym_logic] = ACTIONS(6379),
    [anon_sym_reg] = ACTIONS(6379),
    [anon_sym_shortreal] = ACTIONS(6379),
    [anon_sym_real] = ACTIONS(6379),
    [anon_sym_realtime] = ACTIONS(6379),
    [anon_sym_supply0] = ACTIONS(6379),
    [anon_sym_supply1] = ACTIONS(6379),
    [anon_sym_signed] = ACTIONS(6379),
    [anon_sym_unsigned] = ACTIONS(6379),
    [anon_sym_task] = ACTIONS(6379),
    [anon_sym_assert] = ACTIONS(6379),
    [anon_sym_property] = ACTIONS(6379),
    [anon_sym_assume] = ACTIONS(6379),
    [anon_sym_cover] = ACTIONS(6379),
    [anon_sym_sequence] = ACTIONS(6379),
    [anon_sym_restrict] = ACTIONS(6379),
    [anon_sym_not] = ACTIONS(6379),
    [anon_sym_or] = ACTIONS(6379),
    [anon_sym_and] = ACTIONS(6379),
    [anon_sym_case] = ACTIONS(6379),
    [anon_sym_always] = ACTIONS(6379),
    [anon_sym_covergroup] = ACTIONS(6379),
    [anon_sym_let] = ACTIONS(6379),
    [anon_sym_pulldown] = ACTIONS(6379),
    [anon_sym_pullup] = ACTIONS(6379),
    [anon_sym_cmos] = ACTIONS(6379),
    [anon_sym_rcmos] = ACTIONS(6379),
    [anon_sym_bufif0] = ACTIONS(6379),
    [anon_sym_bufif1] = ACTIONS(6379),
    [anon_sym_notif0] = ACTIONS(6379),
    [anon_sym_notif1] = ACTIONS(6379),
    [anon_sym_nmos] = ACTIONS(6379),
    [anon_sym_pmos] = ACTIONS(6379),
    [anon_sym_rnmos] = ACTIONS(6379),
    [anon_sym_rpmos] = ACTIONS(6379),
    [anon_sym_nand] = ACTIONS(6379),
    [anon_sym_nor] = ACTIONS(6379),
    [anon_sym_xor] = ACTIONS(6379),
    [anon_sym_xnor] = ACTIONS(6379),
    [anon_sym_buf] = ACTIONS(6379),
    [anon_sym_tranif0] = ACTIONS(6379),
    [anon_sym_tranif1] = ACTIONS(6379),
    [anon_sym_rtranif1] = ACTIONS(6379),
    [anon_sym_rtranif0] = ACTIONS(6379),
    [anon_sym_tran] = ACTIONS(6379),
    [anon_sym_rtran] = ACTIONS(6379),
    [anon_sym_generate] = ACTIONS(6379),
    [anon_sym_endgenerate] = ACTIONS(6379),
    [anon_sym_for] = ACTIONS(6379),
    [anon_sym_initial] = ACTIONS(6379),
    [anon_sym_assign] = ACTIONS(6379),
    [anon_sym_alias] = ACTIONS(6379),
    [anon_sym_always_comb] = ACTIONS(6379),
    [anon_sym_always_latch] = ACTIONS(6379),
    [anon_sym_always_ff] = ACTIONS(6379),
    [anon_sym_final] = ACTIONS(6379),
    [anon_sym_global] = ACTIONS(6379),
    [anon_sym_LPAREN_STAR] = ACTIONS(6381),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6381),
    [anon_sym_DOLLARunit] = ACTIONS(6381),
  },
  [5170] = {
    [sym_simple_identifier] = ACTIONS(6585),
    [anon_sym_wire] = ACTIONS(6585),
    [anon_sym_tri] = ACTIONS(6585),
    [anon_sym_tri0] = ACTIONS(6585),
    [anon_sym_tri1] = ACTIONS(6585),
    [anon_sym_wand] = ACTIONS(6585),
    [anon_sym_triand] = ACTIONS(6585),
    [anon_sym_wor] = ACTIONS(6585),
    [anon_sym_trior] = ACTIONS(6585),
    [anon_sym_trireg] = ACTIONS(6585),
    [anon_sym_uwire] = ACTIONS(6585),
    [anon_sym_SEMI] = ACTIONS(6587),
    [anon_sym_extern] = ACTIONS(6585),
    [anon_sym_interface] = ACTIONS(6585),
    [anon_sym_checker] = ACTIONS(6585),
    [anon_sym_virtual] = ACTIONS(6585),
    [anon_sym_class] = ACTIONS(6585),
    [anon_sym_type] = ACTIONS(6585),
    [anon_sym_DOLLARfatal] = ACTIONS(6587),
    [anon_sym_DOLLARerror] = ACTIONS(6587),
    [anon_sym_DOLLARwarning] = ACTIONS(6587),
    [anon_sym_DOLLARinfo] = ACTIONS(6587),
    [anon_sym_default] = ACTIONS(6585),
    [anon_sym_clocking] = ACTIONS(6585),
    [anon_sym_defparam] = ACTIONS(6585),
    [anon_sym_bind] = ACTIONS(6585),
    [anon_sym_rand] = ACTIONS(6585),
    [anon_sym_const] = ACTIONS(6585),
    [anon_sym_function] = ACTIONS(6585),
    [anon_sym_static] = ACTIONS(6585),
    [anon_sym_constraint] = ACTIONS(6585),
    [anon_sym_if] = ACTIONS(6585),
    [anon_sym_else] = ACTIONS(6585),
    [anon_sym_LBRACK] = ACTIONS(6587),
    [anon_sym_localparam] = ACTIONS(6585),
    [anon_sym_parameter] = ACTIONS(6585),
    [anon_sym_var] = ACTIONS(6585),
    [anon_sym_import] = ACTIONS(6585),
    [anon_sym_export] = ACTIONS(6585),
    [anon_sym_genvar] = ACTIONS(6585),
    [anon_sym_interconnect] = ACTIONS(6585),
    [anon_sym_typedef] = ACTIONS(6585),
    [anon_sym_enum] = ACTIONS(6585),
    [anon_sym_struct] = ACTIONS(6585),
    [anon_sym_union] = ACTIONS(6585),
    [anon_sym_nettype] = ACTIONS(6585),
    [anon_sym_automatic] = ACTIONS(6585),
    [anon_sym_string] = ACTIONS(6585),
    [anon_sym_chandle] = ACTIONS(6585),
    [anon_sym_event] = ACTIONS(6585),
    [anon_sym_byte] = ACTIONS(6585),
    [anon_sym_shortint] = ACTIONS(6585),
    [anon_sym_int] = ACTIONS(6585),
    [anon_sym_longint] = ACTIONS(6585),
    [anon_sym_integer] = ACTIONS(6585),
    [anon_sym_time] = ACTIONS(6585),
    [anon_sym_bit] = ACTIONS(6585),
    [anon_sym_logic] = ACTIONS(6585),
    [anon_sym_reg] = ACTIONS(6585),
    [anon_sym_shortreal] = ACTIONS(6585),
    [anon_sym_real] = ACTIONS(6585),
    [anon_sym_realtime] = ACTIONS(6585),
    [anon_sym_supply0] = ACTIONS(6585),
    [anon_sym_supply1] = ACTIONS(6585),
    [anon_sym_signed] = ACTIONS(6585),
    [anon_sym_unsigned] = ACTIONS(6585),
    [anon_sym_task] = ACTIONS(6585),
    [anon_sym_assert] = ACTIONS(6585),
    [anon_sym_property] = ACTIONS(6585),
    [anon_sym_assume] = ACTIONS(6585),
    [anon_sym_cover] = ACTIONS(6585),
    [anon_sym_sequence] = ACTIONS(6585),
    [anon_sym_restrict] = ACTIONS(6585),
    [anon_sym_not] = ACTIONS(6585),
    [anon_sym_or] = ACTIONS(6585),
    [anon_sym_and] = ACTIONS(6585),
    [anon_sym_case] = ACTIONS(6585),
    [anon_sym_always] = ACTIONS(6585),
    [anon_sym_covergroup] = ACTIONS(6585),
    [anon_sym_end] = ACTIONS(6585),
    [anon_sym_let] = ACTIONS(6585),
    [anon_sym_pulldown] = ACTIONS(6585),
    [anon_sym_pullup] = ACTIONS(6585),
    [anon_sym_cmos] = ACTIONS(6585),
    [anon_sym_rcmos] = ACTIONS(6585),
    [anon_sym_bufif0] = ACTIONS(6585),
    [anon_sym_bufif1] = ACTIONS(6585),
    [anon_sym_notif0] = ACTIONS(6585),
    [anon_sym_notif1] = ACTIONS(6585),
    [anon_sym_nmos] = ACTIONS(6585),
    [anon_sym_pmos] = ACTIONS(6585),
    [anon_sym_rnmos] = ACTIONS(6585),
    [anon_sym_rpmos] = ACTIONS(6585),
    [anon_sym_nand] = ACTIONS(6585),
    [anon_sym_nor] = ACTIONS(6585),
    [anon_sym_xor] = ACTIONS(6585),
    [anon_sym_xnor] = ACTIONS(6585),
    [anon_sym_buf] = ACTIONS(6585),
    [anon_sym_tranif0] = ACTIONS(6585),
    [anon_sym_tranif1] = ACTIONS(6585),
    [anon_sym_rtranif1] = ACTIONS(6585),
    [anon_sym_rtranif0] = ACTIONS(6585),
    [anon_sym_tran] = ACTIONS(6585),
    [anon_sym_rtran] = ACTIONS(6585),
    [anon_sym_generate] = ACTIONS(6585),
    [anon_sym_for] = ACTIONS(6585),
    [anon_sym_initial] = ACTIONS(6585),
    [anon_sym_assign] = ACTIONS(6585),
    [anon_sym_alias] = ACTIONS(6585),
    [anon_sym_always_comb] = ACTIONS(6585),
    [anon_sym_always_latch] = ACTIONS(6585),
    [anon_sym_always_ff] = ACTIONS(6585),
    [anon_sym_final] = ACTIONS(6585),
    [anon_sym_global] = ACTIONS(6585),
    [anon_sym_LPAREN_STAR] = ACTIONS(6587),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6587),
    [anon_sym_DOLLARunit] = ACTIONS(6587),
  },
  [5171] = {
    [sym_simple_identifier] = ACTIONS(6545),
    [anon_sym_wire] = ACTIONS(6545),
    [anon_sym_tri] = ACTIONS(6545),
    [anon_sym_tri0] = ACTIONS(6545),
    [anon_sym_tri1] = ACTIONS(6545),
    [anon_sym_wand] = ACTIONS(6545),
    [anon_sym_triand] = ACTIONS(6545),
    [anon_sym_wor] = ACTIONS(6545),
    [anon_sym_trior] = ACTIONS(6545),
    [anon_sym_trireg] = ACTIONS(6545),
    [anon_sym_uwire] = ACTIONS(6545),
    [anon_sym_SEMI] = ACTIONS(6547),
    [anon_sym_extern] = ACTIONS(6545),
    [anon_sym_interface] = ACTIONS(6545),
    [anon_sym_checker] = ACTIONS(6545),
    [anon_sym_virtual] = ACTIONS(6545),
    [anon_sym_class] = ACTIONS(6545),
    [anon_sym_type] = ACTIONS(6545),
    [anon_sym_DOLLARfatal] = ACTIONS(6547),
    [anon_sym_DOLLARerror] = ACTIONS(6547),
    [anon_sym_DOLLARwarning] = ACTIONS(6547),
    [anon_sym_DOLLARinfo] = ACTIONS(6547),
    [anon_sym_default] = ACTIONS(6545),
    [anon_sym_clocking] = ACTIONS(6545),
    [anon_sym_defparam] = ACTIONS(6545),
    [anon_sym_bind] = ACTIONS(6545),
    [anon_sym_rand] = ACTIONS(6545),
    [anon_sym_const] = ACTIONS(6545),
    [anon_sym_function] = ACTIONS(6545),
    [anon_sym_static] = ACTIONS(6545),
    [anon_sym_constraint] = ACTIONS(6545),
    [anon_sym_if] = ACTIONS(6545),
    [anon_sym_else] = ACTIONS(6545),
    [anon_sym_LBRACK] = ACTIONS(6547),
    [anon_sym_localparam] = ACTIONS(6545),
    [anon_sym_parameter] = ACTIONS(6545),
    [anon_sym_var] = ACTIONS(6545),
    [anon_sym_import] = ACTIONS(6545),
    [anon_sym_export] = ACTIONS(6545),
    [anon_sym_genvar] = ACTIONS(6545),
    [anon_sym_interconnect] = ACTIONS(6545),
    [anon_sym_typedef] = ACTIONS(6545),
    [anon_sym_enum] = ACTIONS(6545),
    [anon_sym_struct] = ACTIONS(6545),
    [anon_sym_union] = ACTIONS(6545),
    [anon_sym_nettype] = ACTIONS(6545),
    [anon_sym_automatic] = ACTIONS(6545),
    [anon_sym_string] = ACTIONS(6545),
    [anon_sym_chandle] = ACTIONS(6545),
    [anon_sym_event] = ACTIONS(6545),
    [anon_sym_byte] = ACTIONS(6545),
    [anon_sym_shortint] = ACTIONS(6545),
    [anon_sym_int] = ACTIONS(6545),
    [anon_sym_longint] = ACTIONS(6545),
    [anon_sym_integer] = ACTIONS(6545),
    [anon_sym_time] = ACTIONS(6545),
    [anon_sym_bit] = ACTIONS(6545),
    [anon_sym_logic] = ACTIONS(6545),
    [anon_sym_reg] = ACTIONS(6545),
    [anon_sym_shortreal] = ACTIONS(6545),
    [anon_sym_real] = ACTIONS(6545),
    [anon_sym_realtime] = ACTIONS(6545),
    [anon_sym_supply0] = ACTIONS(6545),
    [anon_sym_supply1] = ACTIONS(6545),
    [anon_sym_signed] = ACTIONS(6545),
    [anon_sym_unsigned] = ACTIONS(6545),
    [anon_sym_task] = ACTIONS(6545),
    [anon_sym_assert] = ACTIONS(6545),
    [anon_sym_property] = ACTIONS(6545),
    [anon_sym_assume] = ACTIONS(6545),
    [anon_sym_cover] = ACTIONS(6545),
    [anon_sym_sequence] = ACTIONS(6545),
    [anon_sym_restrict] = ACTIONS(6545),
    [anon_sym_not] = ACTIONS(6545),
    [anon_sym_or] = ACTIONS(6545),
    [anon_sym_and] = ACTIONS(6545),
    [anon_sym_case] = ACTIONS(6545),
    [anon_sym_always] = ACTIONS(6545),
    [anon_sym_covergroup] = ACTIONS(6545),
    [anon_sym_let] = ACTIONS(6545),
    [anon_sym_pulldown] = ACTIONS(6545),
    [anon_sym_pullup] = ACTIONS(6545),
    [anon_sym_cmos] = ACTIONS(6545),
    [anon_sym_rcmos] = ACTIONS(6545),
    [anon_sym_bufif0] = ACTIONS(6545),
    [anon_sym_bufif1] = ACTIONS(6545),
    [anon_sym_notif0] = ACTIONS(6545),
    [anon_sym_notif1] = ACTIONS(6545),
    [anon_sym_nmos] = ACTIONS(6545),
    [anon_sym_pmos] = ACTIONS(6545),
    [anon_sym_rnmos] = ACTIONS(6545),
    [anon_sym_rpmos] = ACTIONS(6545),
    [anon_sym_nand] = ACTIONS(6545),
    [anon_sym_nor] = ACTIONS(6545),
    [anon_sym_xor] = ACTIONS(6545),
    [anon_sym_xnor] = ACTIONS(6545),
    [anon_sym_buf] = ACTIONS(6545),
    [anon_sym_tranif0] = ACTIONS(6545),
    [anon_sym_tranif1] = ACTIONS(6545),
    [anon_sym_rtranif1] = ACTIONS(6545),
    [anon_sym_rtranif0] = ACTIONS(6545),
    [anon_sym_tran] = ACTIONS(6545),
    [anon_sym_rtran] = ACTIONS(6545),
    [anon_sym_generate] = ACTIONS(6545),
    [anon_sym_endgenerate] = ACTIONS(6545),
    [anon_sym_for] = ACTIONS(6545),
    [anon_sym_initial] = ACTIONS(6545),
    [anon_sym_assign] = ACTIONS(6545),
    [anon_sym_alias] = ACTIONS(6545),
    [anon_sym_always_comb] = ACTIONS(6545),
    [anon_sym_always_latch] = ACTIONS(6545),
    [anon_sym_always_ff] = ACTIONS(6545),
    [anon_sym_final] = ACTIONS(6545),
    [anon_sym_global] = ACTIONS(6545),
    [anon_sym_LPAREN_STAR] = ACTIONS(6547),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6547),
    [anon_sym_DOLLARunit] = ACTIONS(6547),
  },
  [5172] = {
    [sym_simple_identifier] = ACTIONS(6793),
    [anon_sym_wire] = ACTIONS(6793),
    [anon_sym_tri] = ACTIONS(6793),
    [anon_sym_tri0] = ACTIONS(6793),
    [anon_sym_tri1] = ACTIONS(6793),
    [anon_sym_wand] = ACTIONS(6793),
    [anon_sym_triand] = ACTIONS(6793),
    [anon_sym_wor] = ACTIONS(6793),
    [anon_sym_trior] = ACTIONS(6793),
    [anon_sym_trireg] = ACTIONS(6793),
    [anon_sym_uwire] = ACTIONS(6793),
    [anon_sym_SEMI] = ACTIONS(6796),
    [anon_sym_extern] = ACTIONS(6793),
    [anon_sym_interface] = ACTIONS(6793),
    [anon_sym_checker] = ACTIONS(6793),
    [anon_sym_virtual] = ACTIONS(6793),
    [anon_sym_class] = ACTIONS(6793),
    [anon_sym_type] = ACTIONS(6793),
    [anon_sym_DOLLARfatal] = ACTIONS(6796),
    [anon_sym_DOLLARerror] = ACTIONS(6796),
    [anon_sym_DOLLARwarning] = ACTIONS(6796),
    [anon_sym_DOLLARinfo] = ACTIONS(6796),
    [anon_sym_default] = ACTIONS(6793),
    [anon_sym_clocking] = ACTIONS(6793),
    [anon_sym_defparam] = ACTIONS(6793),
    [anon_sym_bind] = ACTIONS(6793),
    [anon_sym_rand] = ACTIONS(6793),
    [anon_sym_const] = ACTIONS(6793),
    [anon_sym_function] = ACTIONS(6793),
    [anon_sym_static] = ACTIONS(6793),
    [anon_sym_constraint] = ACTIONS(6793),
    [anon_sym_if] = ACTIONS(6793),
    [anon_sym_else] = ACTIONS(6793),
    [anon_sym_LBRACK] = ACTIONS(6796),
    [anon_sym_localparam] = ACTIONS(6793),
    [anon_sym_parameter] = ACTIONS(6793),
    [anon_sym_var] = ACTIONS(6793),
    [anon_sym_import] = ACTIONS(6793),
    [anon_sym_export] = ACTIONS(6793),
    [anon_sym_genvar] = ACTIONS(6793),
    [anon_sym_interconnect] = ACTIONS(6793),
    [anon_sym_typedef] = ACTIONS(6793),
    [anon_sym_enum] = ACTIONS(6793),
    [anon_sym_struct] = ACTIONS(6793),
    [anon_sym_union] = ACTIONS(6793),
    [anon_sym_nettype] = ACTIONS(6793),
    [anon_sym_automatic] = ACTIONS(6793),
    [anon_sym_string] = ACTIONS(6793),
    [anon_sym_chandle] = ACTIONS(6793),
    [anon_sym_event] = ACTIONS(6793),
    [anon_sym_byte] = ACTIONS(6793),
    [anon_sym_shortint] = ACTIONS(6793),
    [anon_sym_int] = ACTIONS(6793),
    [anon_sym_longint] = ACTIONS(6793),
    [anon_sym_integer] = ACTIONS(6793),
    [anon_sym_time] = ACTIONS(6793),
    [anon_sym_bit] = ACTIONS(6793),
    [anon_sym_logic] = ACTIONS(6793),
    [anon_sym_reg] = ACTIONS(6793),
    [anon_sym_shortreal] = ACTIONS(6793),
    [anon_sym_real] = ACTIONS(6793),
    [anon_sym_realtime] = ACTIONS(6793),
    [anon_sym_supply0] = ACTIONS(6793),
    [anon_sym_supply1] = ACTIONS(6793),
    [anon_sym_signed] = ACTIONS(6793),
    [anon_sym_unsigned] = ACTIONS(6793),
    [anon_sym_task] = ACTIONS(6793),
    [anon_sym_assert] = ACTIONS(6793),
    [anon_sym_property] = ACTIONS(6793),
    [anon_sym_assume] = ACTIONS(6793),
    [anon_sym_cover] = ACTIONS(6793),
    [anon_sym_sequence] = ACTIONS(6793),
    [anon_sym_restrict] = ACTIONS(6793),
    [anon_sym_not] = ACTIONS(6793),
    [anon_sym_or] = ACTIONS(6793),
    [anon_sym_and] = ACTIONS(6793),
    [anon_sym_case] = ACTIONS(6793),
    [anon_sym_always] = ACTIONS(6793),
    [anon_sym_covergroup] = ACTIONS(6793),
    [anon_sym_end] = ACTIONS(6793),
    [anon_sym_let] = ACTIONS(6793),
    [anon_sym_pulldown] = ACTIONS(6793),
    [anon_sym_pullup] = ACTIONS(6793),
    [anon_sym_cmos] = ACTIONS(6793),
    [anon_sym_rcmos] = ACTIONS(6793),
    [anon_sym_bufif0] = ACTIONS(6793),
    [anon_sym_bufif1] = ACTIONS(6793),
    [anon_sym_notif0] = ACTIONS(6793),
    [anon_sym_notif1] = ACTIONS(6793),
    [anon_sym_nmos] = ACTIONS(6793),
    [anon_sym_pmos] = ACTIONS(6793),
    [anon_sym_rnmos] = ACTIONS(6793),
    [anon_sym_rpmos] = ACTIONS(6793),
    [anon_sym_nand] = ACTIONS(6793),
    [anon_sym_nor] = ACTIONS(6793),
    [anon_sym_xor] = ACTIONS(6793),
    [anon_sym_xnor] = ACTIONS(6793),
    [anon_sym_buf] = ACTIONS(6793),
    [anon_sym_tranif0] = ACTIONS(6793),
    [anon_sym_tranif1] = ACTIONS(6793),
    [anon_sym_rtranif1] = ACTIONS(6793),
    [anon_sym_rtranif0] = ACTIONS(6793),
    [anon_sym_tran] = ACTIONS(6793),
    [anon_sym_rtran] = ACTIONS(6793),
    [anon_sym_generate] = ACTIONS(6793),
    [anon_sym_for] = ACTIONS(6793),
    [anon_sym_initial] = ACTIONS(6793),
    [anon_sym_assign] = ACTIONS(6793),
    [anon_sym_alias] = ACTIONS(6793),
    [anon_sym_always_comb] = ACTIONS(6793),
    [anon_sym_always_latch] = ACTIONS(6793),
    [anon_sym_always_ff] = ACTIONS(6793),
    [anon_sym_final] = ACTIONS(6793),
    [anon_sym_global] = ACTIONS(6793),
    [anon_sym_LPAREN_STAR] = ACTIONS(6796),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6796),
    [anon_sym_DOLLARunit] = ACTIONS(6796),
  },
  [5173] = {
    [sym_simple_identifier] = ACTIONS(5202),
    [anon_sym_wire] = ACTIONS(5202),
    [anon_sym_tri] = ACTIONS(5202),
    [anon_sym_tri0] = ACTIONS(5202),
    [anon_sym_tri1] = ACTIONS(5202),
    [anon_sym_wand] = ACTIONS(5202),
    [anon_sym_triand] = ACTIONS(5202),
    [anon_sym_wor] = ACTIONS(5202),
    [anon_sym_trior] = ACTIONS(5202),
    [anon_sym_trireg] = ACTIONS(5202),
    [anon_sym_uwire] = ACTIONS(5202),
    [anon_sym_SEMI] = ACTIONS(5200),
    [anon_sym_extern] = ACTIONS(5202),
    [anon_sym_interface] = ACTIONS(5202),
    [anon_sym_checker] = ACTIONS(5202),
    [anon_sym_virtual] = ACTIONS(5202),
    [anon_sym_class] = ACTIONS(5202),
    [anon_sym_type] = ACTIONS(5202),
    [anon_sym_DOLLARfatal] = ACTIONS(5200),
    [anon_sym_DOLLARerror] = ACTIONS(5200),
    [anon_sym_DOLLARwarning] = ACTIONS(5200),
    [anon_sym_DOLLARinfo] = ACTIONS(5200),
    [anon_sym_default] = ACTIONS(5202),
    [anon_sym_clocking] = ACTIONS(5202),
    [anon_sym_defparam] = ACTIONS(5202),
    [anon_sym_bind] = ACTIONS(5202),
    [anon_sym_rand] = ACTIONS(5202),
    [anon_sym_const] = ACTIONS(5202),
    [anon_sym_function] = ACTIONS(5202),
    [anon_sym_static] = ACTIONS(5202),
    [anon_sym_constraint] = ACTIONS(5202),
    [anon_sym_if] = ACTIONS(5202),
    [anon_sym_else] = ACTIONS(5202),
    [anon_sym_LBRACK] = ACTIONS(5200),
    [anon_sym_localparam] = ACTIONS(5202),
    [anon_sym_parameter] = ACTIONS(5202),
    [anon_sym_var] = ACTIONS(5202),
    [anon_sym_import] = ACTIONS(5202),
    [anon_sym_export] = ACTIONS(5202),
    [anon_sym_genvar] = ACTIONS(5202),
    [anon_sym_interconnect] = ACTIONS(5202),
    [anon_sym_typedef] = ACTIONS(5202),
    [anon_sym_enum] = ACTIONS(5202),
    [anon_sym_struct] = ACTIONS(5202),
    [anon_sym_union] = ACTIONS(5202),
    [anon_sym_nettype] = ACTIONS(5202),
    [anon_sym_automatic] = ACTIONS(5202),
    [anon_sym_string] = ACTIONS(5202),
    [anon_sym_chandle] = ACTIONS(5202),
    [anon_sym_event] = ACTIONS(5202),
    [anon_sym_byte] = ACTIONS(5202),
    [anon_sym_shortint] = ACTIONS(5202),
    [anon_sym_int] = ACTIONS(5202),
    [anon_sym_longint] = ACTIONS(5202),
    [anon_sym_integer] = ACTIONS(5202),
    [anon_sym_time] = ACTIONS(5202),
    [anon_sym_bit] = ACTIONS(5202),
    [anon_sym_logic] = ACTIONS(5202),
    [anon_sym_reg] = ACTIONS(5202),
    [anon_sym_shortreal] = ACTIONS(5202),
    [anon_sym_real] = ACTIONS(5202),
    [anon_sym_realtime] = ACTIONS(5202),
    [anon_sym_supply0] = ACTIONS(5202),
    [anon_sym_supply1] = ACTIONS(5202),
    [anon_sym_signed] = ACTIONS(5202),
    [anon_sym_unsigned] = ACTIONS(5202),
    [anon_sym_task] = ACTIONS(5202),
    [anon_sym_assert] = ACTIONS(5202),
    [anon_sym_property] = ACTIONS(5202),
    [anon_sym_assume] = ACTIONS(5202),
    [anon_sym_cover] = ACTIONS(5202),
    [anon_sym_sequence] = ACTIONS(5202),
    [anon_sym_restrict] = ACTIONS(5202),
    [anon_sym_not] = ACTIONS(5202),
    [anon_sym_or] = ACTIONS(5202),
    [anon_sym_and] = ACTIONS(5202),
    [anon_sym_case] = ACTIONS(5202),
    [anon_sym_always] = ACTIONS(5202),
    [anon_sym_covergroup] = ACTIONS(5202),
    [anon_sym_let] = ACTIONS(5202),
    [anon_sym_pulldown] = ACTIONS(5202),
    [anon_sym_pullup] = ACTIONS(5202),
    [anon_sym_cmos] = ACTIONS(5202),
    [anon_sym_rcmos] = ACTIONS(5202),
    [anon_sym_bufif0] = ACTIONS(5202),
    [anon_sym_bufif1] = ACTIONS(5202),
    [anon_sym_notif0] = ACTIONS(5202),
    [anon_sym_notif1] = ACTIONS(5202),
    [anon_sym_nmos] = ACTIONS(5202),
    [anon_sym_pmos] = ACTIONS(5202),
    [anon_sym_rnmos] = ACTIONS(5202),
    [anon_sym_rpmos] = ACTIONS(5202),
    [anon_sym_nand] = ACTIONS(5202),
    [anon_sym_nor] = ACTIONS(5202),
    [anon_sym_xor] = ACTIONS(5202),
    [anon_sym_xnor] = ACTIONS(5202),
    [anon_sym_buf] = ACTIONS(5202),
    [anon_sym_tranif0] = ACTIONS(5202),
    [anon_sym_tranif1] = ACTIONS(5202),
    [anon_sym_rtranif1] = ACTIONS(5202),
    [anon_sym_rtranif0] = ACTIONS(5202),
    [anon_sym_tran] = ACTIONS(5202),
    [anon_sym_rtran] = ACTIONS(5202),
    [anon_sym_generate] = ACTIONS(5202),
    [anon_sym_endgenerate] = ACTIONS(5202),
    [anon_sym_for] = ACTIONS(5202),
    [anon_sym_initial] = ACTIONS(5202),
    [anon_sym_assign] = ACTIONS(5202),
    [anon_sym_alias] = ACTIONS(5202),
    [anon_sym_always_comb] = ACTIONS(5202),
    [anon_sym_always_latch] = ACTIONS(5202),
    [anon_sym_always_ff] = ACTIONS(5202),
    [anon_sym_final] = ACTIONS(5202),
    [anon_sym_global] = ACTIONS(5202),
    [anon_sym_LPAREN_STAR] = ACTIONS(5200),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5200),
    [anon_sym_DOLLARunit] = ACTIONS(5200),
  },
  [5174] = {
    [sym_simple_identifier] = ACTIONS(4230),
    [anon_sym_wire] = ACTIONS(4230),
    [anon_sym_tri] = ACTIONS(4230),
    [anon_sym_tri0] = ACTIONS(4230),
    [anon_sym_tri1] = ACTIONS(4230),
    [anon_sym_wand] = ACTIONS(4230),
    [anon_sym_triand] = ACTIONS(4230),
    [anon_sym_wor] = ACTIONS(4230),
    [anon_sym_trior] = ACTIONS(4230),
    [anon_sym_trireg] = ACTIONS(4230),
    [anon_sym_uwire] = ACTIONS(4230),
    [anon_sym_SEMI] = ACTIONS(4228),
    [anon_sym_extern] = ACTIONS(4230),
    [anon_sym_interface] = ACTIONS(4230),
    [anon_sym_checker] = ACTIONS(4230),
    [anon_sym_virtual] = ACTIONS(4230),
    [anon_sym_class] = ACTIONS(4230),
    [anon_sym_type] = ACTIONS(4230),
    [anon_sym_DOLLARfatal] = ACTIONS(4228),
    [anon_sym_DOLLARerror] = ACTIONS(4228),
    [anon_sym_DOLLARwarning] = ACTIONS(4228),
    [anon_sym_DOLLARinfo] = ACTIONS(4228),
    [anon_sym_default] = ACTIONS(4230),
    [anon_sym_clocking] = ACTIONS(4230),
    [anon_sym_defparam] = ACTIONS(4230),
    [anon_sym_bind] = ACTIONS(4230),
    [anon_sym_rand] = ACTIONS(4230),
    [anon_sym_const] = ACTIONS(4230),
    [anon_sym_function] = ACTIONS(4230),
    [anon_sym_static] = ACTIONS(4230),
    [anon_sym_constraint] = ACTIONS(4230),
    [anon_sym_if] = ACTIONS(4230),
    [anon_sym_else] = ACTIONS(4230),
    [anon_sym_LBRACK] = ACTIONS(4228),
    [anon_sym_localparam] = ACTIONS(4230),
    [anon_sym_parameter] = ACTIONS(4230),
    [anon_sym_var] = ACTIONS(4230),
    [anon_sym_import] = ACTIONS(4230),
    [anon_sym_export] = ACTIONS(4230),
    [anon_sym_genvar] = ACTIONS(4230),
    [anon_sym_interconnect] = ACTIONS(4230),
    [anon_sym_typedef] = ACTIONS(4230),
    [anon_sym_enum] = ACTIONS(4230),
    [anon_sym_struct] = ACTIONS(4230),
    [anon_sym_union] = ACTIONS(4230),
    [anon_sym_nettype] = ACTIONS(4230),
    [anon_sym_automatic] = ACTIONS(4230),
    [anon_sym_string] = ACTIONS(4230),
    [anon_sym_chandle] = ACTIONS(4230),
    [anon_sym_event] = ACTIONS(4230),
    [anon_sym_byte] = ACTIONS(4230),
    [anon_sym_shortint] = ACTIONS(4230),
    [anon_sym_int] = ACTIONS(4230),
    [anon_sym_longint] = ACTIONS(4230),
    [anon_sym_integer] = ACTIONS(4230),
    [anon_sym_time] = ACTIONS(4230),
    [anon_sym_bit] = ACTIONS(4230),
    [anon_sym_logic] = ACTIONS(4230),
    [anon_sym_reg] = ACTIONS(4230),
    [anon_sym_shortreal] = ACTIONS(4230),
    [anon_sym_real] = ACTIONS(4230),
    [anon_sym_realtime] = ACTIONS(4230),
    [anon_sym_supply0] = ACTIONS(4230),
    [anon_sym_supply1] = ACTIONS(4230),
    [anon_sym_signed] = ACTIONS(4230),
    [anon_sym_unsigned] = ACTIONS(4230),
    [anon_sym_task] = ACTIONS(4230),
    [anon_sym_assert] = ACTIONS(4230),
    [anon_sym_property] = ACTIONS(4230),
    [anon_sym_assume] = ACTIONS(4230),
    [anon_sym_cover] = ACTIONS(4230),
    [anon_sym_sequence] = ACTIONS(4230),
    [anon_sym_restrict] = ACTIONS(4230),
    [anon_sym_not] = ACTIONS(4230),
    [anon_sym_or] = ACTIONS(4230),
    [anon_sym_and] = ACTIONS(4230),
    [anon_sym_case] = ACTIONS(4230),
    [anon_sym_always] = ACTIONS(4230),
    [anon_sym_covergroup] = ACTIONS(4230),
    [anon_sym_end] = ACTIONS(4230),
    [anon_sym_let] = ACTIONS(4230),
    [anon_sym_pulldown] = ACTIONS(4230),
    [anon_sym_pullup] = ACTIONS(4230),
    [anon_sym_cmos] = ACTIONS(4230),
    [anon_sym_rcmos] = ACTIONS(4230),
    [anon_sym_bufif0] = ACTIONS(4230),
    [anon_sym_bufif1] = ACTIONS(4230),
    [anon_sym_notif0] = ACTIONS(4230),
    [anon_sym_notif1] = ACTIONS(4230),
    [anon_sym_nmos] = ACTIONS(4230),
    [anon_sym_pmos] = ACTIONS(4230),
    [anon_sym_rnmos] = ACTIONS(4230),
    [anon_sym_rpmos] = ACTIONS(4230),
    [anon_sym_nand] = ACTIONS(4230),
    [anon_sym_nor] = ACTIONS(4230),
    [anon_sym_xor] = ACTIONS(4230),
    [anon_sym_xnor] = ACTIONS(4230),
    [anon_sym_buf] = ACTIONS(4230),
    [anon_sym_tranif0] = ACTIONS(4230),
    [anon_sym_tranif1] = ACTIONS(4230),
    [anon_sym_rtranif1] = ACTIONS(4230),
    [anon_sym_rtranif0] = ACTIONS(4230),
    [anon_sym_tran] = ACTIONS(4230),
    [anon_sym_rtran] = ACTIONS(4230),
    [anon_sym_generate] = ACTIONS(4230),
    [anon_sym_for] = ACTIONS(4230),
    [anon_sym_initial] = ACTIONS(4230),
    [anon_sym_assign] = ACTIONS(4230),
    [anon_sym_alias] = ACTIONS(4230),
    [anon_sym_always_comb] = ACTIONS(4230),
    [anon_sym_always_latch] = ACTIONS(4230),
    [anon_sym_always_ff] = ACTIONS(4230),
    [anon_sym_final] = ACTIONS(4230),
    [anon_sym_global] = ACTIONS(4230),
    [anon_sym_LPAREN_STAR] = ACTIONS(4228),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4228),
    [anon_sym_DOLLARunit] = ACTIONS(4228),
  },
  [5175] = {
    [sym_simple_identifier] = ACTIONS(5370),
    [anon_sym_wire] = ACTIONS(5370),
    [anon_sym_tri] = ACTIONS(5370),
    [anon_sym_tri0] = ACTIONS(5370),
    [anon_sym_tri1] = ACTIONS(5370),
    [anon_sym_wand] = ACTIONS(5370),
    [anon_sym_triand] = ACTIONS(5370),
    [anon_sym_wor] = ACTIONS(5370),
    [anon_sym_trior] = ACTIONS(5370),
    [anon_sym_trireg] = ACTIONS(5370),
    [anon_sym_uwire] = ACTIONS(5370),
    [anon_sym_SEMI] = ACTIONS(5368),
    [anon_sym_extern] = ACTIONS(5370),
    [anon_sym_interface] = ACTIONS(5370),
    [anon_sym_checker] = ACTIONS(5370),
    [anon_sym_virtual] = ACTIONS(5370),
    [anon_sym_class] = ACTIONS(5370),
    [anon_sym_type] = ACTIONS(5370),
    [anon_sym_DOLLARfatal] = ACTIONS(5368),
    [anon_sym_DOLLARerror] = ACTIONS(5368),
    [anon_sym_DOLLARwarning] = ACTIONS(5368),
    [anon_sym_DOLLARinfo] = ACTIONS(5368),
    [anon_sym_default] = ACTIONS(5370),
    [anon_sym_clocking] = ACTIONS(5370),
    [anon_sym_defparam] = ACTIONS(5370),
    [anon_sym_bind] = ACTIONS(5370),
    [anon_sym_rand] = ACTIONS(5370),
    [anon_sym_const] = ACTIONS(5370),
    [anon_sym_function] = ACTIONS(5370),
    [anon_sym_static] = ACTIONS(5370),
    [anon_sym_constraint] = ACTIONS(5370),
    [anon_sym_if] = ACTIONS(5370),
    [anon_sym_else] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5368),
    [anon_sym_localparam] = ACTIONS(5370),
    [anon_sym_parameter] = ACTIONS(5370),
    [anon_sym_var] = ACTIONS(5370),
    [anon_sym_import] = ACTIONS(5370),
    [anon_sym_export] = ACTIONS(5370),
    [anon_sym_genvar] = ACTIONS(5370),
    [anon_sym_interconnect] = ACTIONS(5370),
    [anon_sym_typedef] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_struct] = ACTIONS(5370),
    [anon_sym_union] = ACTIONS(5370),
    [anon_sym_nettype] = ACTIONS(5370),
    [anon_sym_automatic] = ACTIONS(5370),
    [anon_sym_string] = ACTIONS(5370),
    [anon_sym_chandle] = ACTIONS(5370),
    [anon_sym_event] = ACTIONS(5370),
    [anon_sym_byte] = ACTIONS(5370),
    [anon_sym_shortint] = ACTIONS(5370),
    [anon_sym_int] = ACTIONS(5370),
    [anon_sym_longint] = ACTIONS(5370),
    [anon_sym_integer] = ACTIONS(5370),
    [anon_sym_time] = ACTIONS(5370),
    [anon_sym_bit] = ACTIONS(5370),
    [anon_sym_logic] = ACTIONS(5370),
    [anon_sym_reg] = ACTIONS(5370),
    [anon_sym_shortreal] = ACTIONS(5370),
    [anon_sym_real] = ACTIONS(5370),
    [anon_sym_realtime] = ACTIONS(5370),
    [anon_sym_supply0] = ACTIONS(5370),
    [anon_sym_supply1] = ACTIONS(5370),
    [anon_sym_signed] = ACTIONS(5370),
    [anon_sym_unsigned] = ACTIONS(5370),
    [anon_sym_task] = ACTIONS(5370),
    [anon_sym_assert] = ACTIONS(5370),
    [anon_sym_property] = ACTIONS(5370),
    [anon_sym_assume] = ACTIONS(5370),
    [anon_sym_cover] = ACTIONS(5370),
    [anon_sym_sequence] = ACTIONS(5370),
    [anon_sym_restrict] = ACTIONS(5370),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_or] = ACTIONS(5370),
    [anon_sym_and] = ACTIONS(5370),
    [anon_sym_case] = ACTIONS(5370),
    [anon_sym_always] = ACTIONS(5370),
    [anon_sym_covergroup] = ACTIONS(5370),
    [anon_sym_end] = ACTIONS(5370),
    [anon_sym_let] = ACTIONS(5370),
    [anon_sym_pulldown] = ACTIONS(5370),
    [anon_sym_pullup] = ACTIONS(5370),
    [anon_sym_cmos] = ACTIONS(5370),
    [anon_sym_rcmos] = ACTIONS(5370),
    [anon_sym_bufif0] = ACTIONS(5370),
    [anon_sym_bufif1] = ACTIONS(5370),
    [anon_sym_notif0] = ACTIONS(5370),
    [anon_sym_notif1] = ACTIONS(5370),
    [anon_sym_nmos] = ACTIONS(5370),
    [anon_sym_pmos] = ACTIONS(5370),
    [anon_sym_rnmos] = ACTIONS(5370),
    [anon_sym_rpmos] = ACTIONS(5370),
    [anon_sym_nand] = ACTIONS(5370),
    [anon_sym_nor] = ACTIONS(5370),
    [anon_sym_xor] = ACTIONS(5370),
    [anon_sym_xnor] = ACTIONS(5370),
    [anon_sym_buf] = ACTIONS(5370),
    [anon_sym_tranif0] = ACTIONS(5370),
    [anon_sym_tranif1] = ACTIONS(5370),
    [anon_sym_rtranif1] = ACTIONS(5370),
    [anon_sym_rtranif0] = ACTIONS(5370),
    [anon_sym_tran] = ACTIONS(5370),
    [anon_sym_rtran] = ACTIONS(5370),
    [anon_sym_generate] = ACTIONS(5370),
    [anon_sym_for] = ACTIONS(5370),
    [anon_sym_initial] = ACTIONS(5370),
    [anon_sym_assign] = ACTIONS(5370),
    [anon_sym_alias] = ACTIONS(5370),
    [anon_sym_always_comb] = ACTIONS(5370),
    [anon_sym_always_latch] = ACTIONS(5370),
    [anon_sym_always_ff] = ACTIONS(5370),
    [anon_sym_final] = ACTIONS(5370),
    [anon_sym_global] = ACTIONS(5370),
    [anon_sym_LPAREN_STAR] = ACTIONS(5368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5368),
    [anon_sym_DOLLARunit] = ACTIONS(5368),
  },
  [5176] = {
    [sym_simple_identifier] = ACTIONS(5374),
    [anon_sym_wire] = ACTIONS(5374),
    [anon_sym_tri] = ACTIONS(5374),
    [anon_sym_tri0] = ACTIONS(5374),
    [anon_sym_tri1] = ACTIONS(5374),
    [anon_sym_wand] = ACTIONS(5374),
    [anon_sym_triand] = ACTIONS(5374),
    [anon_sym_wor] = ACTIONS(5374),
    [anon_sym_trior] = ACTIONS(5374),
    [anon_sym_trireg] = ACTIONS(5374),
    [anon_sym_uwire] = ACTIONS(5374),
    [anon_sym_SEMI] = ACTIONS(5372),
    [anon_sym_extern] = ACTIONS(5374),
    [anon_sym_interface] = ACTIONS(5374),
    [anon_sym_checker] = ACTIONS(5374),
    [anon_sym_virtual] = ACTIONS(5374),
    [anon_sym_class] = ACTIONS(5374),
    [anon_sym_type] = ACTIONS(5374),
    [anon_sym_DOLLARfatal] = ACTIONS(5372),
    [anon_sym_DOLLARerror] = ACTIONS(5372),
    [anon_sym_DOLLARwarning] = ACTIONS(5372),
    [anon_sym_DOLLARinfo] = ACTIONS(5372),
    [anon_sym_default] = ACTIONS(5374),
    [anon_sym_clocking] = ACTIONS(5374),
    [anon_sym_defparam] = ACTIONS(5374),
    [anon_sym_bind] = ACTIONS(5374),
    [anon_sym_rand] = ACTIONS(5374),
    [anon_sym_const] = ACTIONS(5374),
    [anon_sym_function] = ACTIONS(5374),
    [anon_sym_static] = ACTIONS(5374),
    [anon_sym_constraint] = ACTIONS(5374),
    [anon_sym_if] = ACTIONS(5374),
    [anon_sym_else] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [anon_sym_localparam] = ACTIONS(5374),
    [anon_sym_parameter] = ACTIONS(5374),
    [anon_sym_var] = ACTIONS(5374),
    [anon_sym_import] = ACTIONS(5374),
    [anon_sym_export] = ACTIONS(5374),
    [anon_sym_genvar] = ACTIONS(5374),
    [anon_sym_interconnect] = ACTIONS(5374),
    [anon_sym_typedef] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_struct] = ACTIONS(5374),
    [anon_sym_union] = ACTIONS(5374),
    [anon_sym_nettype] = ACTIONS(5374),
    [anon_sym_automatic] = ACTIONS(5374),
    [anon_sym_string] = ACTIONS(5374),
    [anon_sym_chandle] = ACTIONS(5374),
    [anon_sym_event] = ACTIONS(5374),
    [anon_sym_byte] = ACTIONS(5374),
    [anon_sym_shortint] = ACTIONS(5374),
    [anon_sym_int] = ACTIONS(5374),
    [anon_sym_longint] = ACTIONS(5374),
    [anon_sym_integer] = ACTIONS(5374),
    [anon_sym_time] = ACTIONS(5374),
    [anon_sym_bit] = ACTIONS(5374),
    [anon_sym_logic] = ACTIONS(5374),
    [anon_sym_reg] = ACTIONS(5374),
    [anon_sym_shortreal] = ACTIONS(5374),
    [anon_sym_real] = ACTIONS(5374),
    [anon_sym_realtime] = ACTIONS(5374),
    [anon_sym_supply0] = ACTIONS(5374),
    [anon_sym_supply1] = ACTIONS(5374),
    [anon_sym_signed] = ACTIONS(5374),
    [anon_sym_unsigned] = ACTIONS(5374),
    [anon_sym_task] = ACTIONS(5374),
    [anon_sym_assert] = ACTIONS(5374),
    [anon_sym_property] = ACTIONS(5374),
    [anon_sym_assume] = ACTIONS(5374),
    [anon_sym_cover] = ACTIONS(5374),
    [anon_sym_sequence] = ACTIONS(5374),
    [anon_sym_restrict] = ACTIONS(5374),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_or] = ACTIONS(5374),
    [anon_sym_and] = ACTIONS(5374),
    [anon_sym_case] = ACTIONS(5374),
    [anon_sym_always] = ACTIONS(5374),
    [anon_sym_covergroup] = ACTIONS(5374),
    [anon_sym_end] = ACTIONS(5374),
    [anon_sym_let] = ACTIONS(5374),
    [anon_sym_pulldown] = ACTIONS(5374),
    [anon_sym_pullup] = ACTIONS(5374),
    [anon_sym_cmos] = ACTIONS(5374),
    [anon_sym_rcmos] = ACTIONS(5374),
    [anon_sym_bufif0] = ACTIONS(5374),
    [anon_sym_bufif1] = ACTIONS(5374),
    [anon_sym_notif0] = ACTIONS(5374),
    [anon_sym_notif1] = ACTIONS(5374),
    [anon_sym_nmos] = ACTIONS(5374),
    [anon_sym_pmos] = ACTIONS(5374),
    [anon_sym_rnmos] = ACTIONS(5374),
    [anon_sym_rpmos] = ACTIONS(5374),
    [anon_sym_nand] = ACTIONS(5374),
    [anon_sym_nor] = ACTIONS(5374),
    [anon_sym_xor] = ACTIONS(5374),
    [anon_sym_xnor] = ACTIONS(5374),
    [anon_sym_buf] = ACTIONS(5374),
    [anon_sym_tranif0] = ACTIONS(5374),
    [anon_sym_tranif1] = ACTIONS(5374),
    [anon_sym_rtranif1] = ACTIONS(5374),
    [anon_sym_rtranif0] = ACTIONS(5374),
    [anon_sym_tran] = ACTIONS(5374),
    [anon_sym_rtran] = ACTIONS(5374),
    [anon_sym_generate] = ACTIONS(5374),
    [anon_sym_for] = ACTIONS(5374),
    [anon_sym_initial] = ACTIONS(5374),
    [anon_sym_assign] = ACTIONS(5374),
    [anon_sym_alias] = ACTIONS(5374),
    [anon_sym_always_comb] = ACTIONS(5374),
    [anon_sym_always_latch] = ACTIONS(5374),
    [anon_sym_always_ff] = ACTIONS(5374),
    [anon_sym_final] = ACTIONS(5374),
    [anon_sym_global] = ACTIONS(5374),
    [anon_sym_LPAREN_STAR] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5372),
    [anon_sym_DOLLARunit] = ACTIONS(5372),
  },
  [5177] = {
    [sym_simple_identifier] = ACTIONS(6471),
    [anon_sym_wire] = ACTIONS(6471),
    [anon_sym_tri] = ACTIONS(6471),
    [anon_sym_tri0] = ACTIONS(6471),
    [anon_sym_tri1] = ACTIONS(6471),
    [anon_sym_wand] = ACTIONS(6471),
    [anon_sym_triand] = ACTIONS(6471),
    [anon_sym_wor] = ACTIONS(6471),
    [anon_sym_trior] = ACTIONS(6471),
    [anon_sym_trireg] = ACTIONS(6471),
    [anon_sym_uwire] = ACTIONS(6471),
    [anon_sym_SEMI] = ACTIONS(6473),
    [anon_sym_extern] = ACTIONS(6471),
    [anon_sym_interface] = ACTIONS(6471),
    [anon_sym_checker] = ACTIONS(6471),
    [anon_sym_virtual] = ACTIONS(6471),
    [anon_sym_class] = ACTIONS(6471),
    [anon_sym_type] = ACTIONS(6471),
    [anon_sym_DOLLARfatal] = ACTIONS(6473),
    [anon_sym_DOLLARerror] = ACTIONS(6473),
    [anon_sym_DOLLARwarning] = ACTIONS(6473),
    [anon_sym_DOLLARinfo] = ACTIONS(6473),
    [anon_sym_default] = ACTIONS(6471),
    [anon_sym_clocking] = ACTIONS(6471),
    [anon_sym_defparam] = ACTIONS(6471),
    [anon_sym_bind] = ACTIONS(6471),
    [anon_sym_rand] = ACTIONS(6471),
    [anon_sym_const] = ACTIONS(6471),
    [anon_sym_function] = ACTIONS(6471),
    [anon_sym_static] = ACTIONS(6471),
    [anon_sym_constraint] = ACTIONS(6471),
    [anon_sym_if] = ACTIONS(6471),
    [anon_sym_else] = ACTIONS(6471),
    [anon_sym_LBRACK] = ACTIONS(6473),
    [anon_sym_localparam] = ACTIONS(6471),
    [anon_sym_parameter] = ACTIONS(6471),
    [anon_sym_var] = ACTIONS(6471),
    [anon_sym_import] = ACTIONS(6471),
    [anon_sym_export] = ACTIONS(6471),
    [anon_sym_genvar] = ACTIONS(6471),
    [anon_sym_interconnect] = ACTIONS(6471),
    [anon_sym_typedef] = ACTIONS(6471),
    [anon_sym_enum] = ACTIONS(6471),
    [anon_sym_struct] = ACTIONS(6471),
    [anon_sym_union] = ACTIONS(6471),
    [anon_sym_nettype] = ACTIONS(6471),
    [anon_sym_automatic] = ACTIONS(6471),
    [anon_sym_string] = ACTIONS(6471),
    [anon_sym_chandle] = ACTIONS(6471),
    [anon_sym_event] = ACTIONS(6471),
    [anon_sym_byte] = ACTIONS(6471),
    [anon_sym_shortint] = ACTIONS(6471),
    [anon_sym_int] = ACTIONS(6471),
    [anon_sym_longint] = ACTIONS(6471),
    [anon_sym_integer] = ACTIONS(6471),
    [anon_sym_time] = ACTIONS(6471),
    [anon_sym_bit] = ACTIONS(6471),
    [anon_sym_logic] = ACTIONS(6471),
    [anon_sym_reg] = ACTIONS(6471),
    [anon_sym_shortreal] = ACTIONS(6471),
    [anon_sym_real] = ACTIONS(6471),
    [anon_sym_realtime] = ACTIONS(6471),
    [anon_sym_supply0] = ACTIONS(6471),
    [anon_sym_supply1] = ACTIONS(6471),
    [anon_sym_signed] = ACTIONS(6471),
    [anon_sym_unsigned] = ACTIONS(6471),
    [anon_sym_task] = ACTIONS(6471),
    [anon_sym_assert] = ACTIONS(6471),
    [anon_sym_property] = ACTIONS(6471),
    [anon_sym_assume] = ACTIONS(6471),
    [anon_sym_cover] = ACTIONS(6471),
    [anon_sym_sequence] = ACTIONS(6471),
    [anon_sym_restrict] = ACTIONS(6471),
    [anon_sym_not] = ACTIONS(6471),
    [anon_sym_or] = ACTIONS(6471),
    [anon_sym_and] = ACTIONS(6471),
    [anon_sym_case] = ACTIONS(6471),
    [anon_sym_always] = ACTIONS(6471),
    [anon_sym_covergroup] = ACTIONS(6471),
    [anon_sym_end] = ACTIONS(6471),
    [anon_sym_let] = ACTIONS(6471),
    [anon_sym_pulldown] = ACTIONS(6471),
    [anon_sym_pullup] = ACTIONS(6471),
    [anon_sym_cmos] = ACTIONS(6471),
    [anon_sym_rcmos] = ACTIONS(6471),
    [anon_sym_bufif0] = ACTIONS(6471),
    [anon_sym_bufif1] = ACTIONS(6471),
    [anon_sym_notif0] = ACTIONS(6471),
    [anon_sym_notif1] = ACTIONS(6471),
    [anon_sym_nmos] = ACTIONS(6471),
    [anon_sym_pmos] = ACTIONS(6471),
    [anon_sym_rnmos] = ACTIONS(6471),
    [anon_sym_rpmos] = ACTIONS(6471),
    [anon_sym_nand] = ACTIONS(6471),
    [anon_sym_nor] = ACTIONS(6471),
    [anon_sym_xor] = ACTIONS(6471),
    [anon_sym_xnor] = ACTIONS(6471),
    [anon_sym_buf] = ACTIONS(6471),
    [anon_sym_tranif0] = ACTIONS(6471),
    [anon_sym_tranif1] = ACTIONS(6471),
    [anon_sym_rtranif1] = ACTIONS(6471),
    [anon_sym_rtranif0] = ACTIONS(6471),
    [anon_sym_tran] = ACTIONS(6471),
    [anon_sym_rtran] = ACTIONS(6471),
    [anon_sym_generate] = ACTIONS(6471),
    [anon_sym_for] = ACTIONS(6471),
    [anon_sym_initial] = ACTIONS(6471),
    [anon_sym_assign] = ACTIONS(6471),
    [anon_sym_alias] = ACTIONS(6471),
    [anon_sym_always_comb] = ACTIONS(6471),
    [anon_sym_always_latch] = ACTIONS(6471),
    [anon_sym_always_ff] = ACTIONS(6471),
    [anon_sym_final] = ACTIONS(6471),
    [anon_sym_global] = ACTIONS(6471),
    [anon_sym_LPAREN_STAR] = ACTIONS(6473),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6473),
    [anon_sym_DOLLARunit] = ACTIONS(6473),
  },
  [5178] = {
    [sym_simple_identifier] = ACTIONS(5382),
    [anon_sym_wire] = ACTIONS(5382),
    [anon_sym_tri] = ACTIONS(5382),
    [anon_sym_tri0] = ACTIONS(5382),
    [anon_sym_tri1] = ACTIONS(5382),
    [anon_sym_wand] = ACTIONS(5382),
    [anon_sym_triand] = ACTIONS(5382),
    [anon_sym_wor] = ACTIONS(5382),
    [anon_sym_trior] = ACTIONS(5382),
    [anon_sym_trireg] = ACTIONS(5382),
    [anon_sym_uwire] = ACTIONS(5382),
    [anon_sym_SEMI] = ACTIONS(5380),
    [anon_sym_extern] = ACTIONS(5382),
    [anon_sym_interface] = ACTIONS(5382),
    [anon_sym_checker] = ACTIONS(5382),
    [anon_sym_virtual] = ACTIONS(5382),
    [anon_sym_class] = ACTIONS(5382),
    [anon_sym_type] = ACTIONS(5382),
    [anon_sym_DOLLARfatal] = ACTIONS(5380),
    [anon_sym_DOLLARerror] = ACTIONS(5380),
    [anon_sym_DOLLARwarning] = ACTIONS(5380),
    [anon_sym_DOLLARinfo] = ACTIONS(5380),
    [anon_sym_default] = ACTIONS(5382),
    [anon_sym_clocking] = ACTIONS(5382),
    [anon_sym_defparam] = ACTIONS(5382),
    [anon_sym_bind] = ACTIONS(5382),
    [anon_sym_rand] = ACTIONS(5382),
    [anon_sym_const] = ACTIONS(5382),
    [anon_sym_function] = ACTIONS(5382),
    [anon_sym_static] = ACTIONS(5382),
    [anon_sym_constraint] = ACTIONS(5382),
    [anon_sym_if] = ACTIONS(5382),
    [anon_sym_else] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [anon_sym_localparam] = ACTIONS(5382),
    [anon_sym_parameter] = ACTIONS(5382),
    [anon_sym_var] = ACTIONS(5382),
    [anon_sym_import] = ACTIONS(5382),
    [anon_sym_export] = ACTIONS(5382),
    [anon_sym_genvar] = ACTIONS(5382),
    [anon_sym_interconnect] = ACTIONS(5382),
    [anon_sym_typedef] = ACTIONS(5382),
    [anon_sym_enum] = ACTIONS(5382),
    [anon_sym_struct] = ACTIONS(5382),
    [anon_sym_union] = ACTIONS(5382),
    [anon_sym_nettype] = ACTIONS(5382),
    [anon_sym_automatic] = ACTIONS(5382),
    [anon_sym_string] = ACTIONS(5382),
    [anon_sym_chandle] = ACTIONS(5382),
    [anon_sym_event] = ACTIONS(5382),
    [anon_sym_byte] = ACTIONS(5382),
    [anon_sym_shortint] = ACTIONS(5382),
    [anon_sym_int] = ACTIONS(5382),
    [anon_sym_longint] = ACTIONS(5382),
    [anon_sym_integer] = ACTIONS(5382),
    [anon_sym_time] = ACTIONS(5382),
    [anon_sym_bit] = ACTIONS(5382),
    [anon_sym_logic] = ACTIONS(5382),
    [anon_sym_reg] = ACTIONS(5382),
    [anon_sym_shortreal] = ACTIONS(5382),
    [anon_sym_real] = ACTIONS(5382),
    [anon_sym_realtime] = ACTIONS(5382),
    [anon_sym_supply0] = ACTIONS(5382),
    [anon_sym_supply1] = ACTIONS(5382),
    [anon_sym_signed] = ACTIONS(5382),
    [anon_sym_unsigned] = ACTIONS(5382),
    [anon_sym_task] = ACTIONS(5382),
    [anon_sym_assert] = ACTIONS(5382),
    [anon_sym_property] = ACTIONS(5382),
    [anon_sym_assume] = ACTIONS(5382),
    [anon_sym_cover] = ACTIONS(5382),
    [anon_sym_sequence] = ACTIONS(5382),
    [anon_sym_restrict] = ACTIONS(5382),
    [anon_sym_not] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_case] = ACTIONS(5382),
    [anon_sym_always] = ACTIONS(5382),
    [anon_sym_covergroup] = ACTIONS(5382),
    [anon_sym_end] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_pulldown] = ACTIONS(5382),
    [anon_sym_pullup] = ACTIONS(5382),
    [anon_sym_cmos] = ACTIONS(5382),
    [anon_sym_rcmos] = ACTIONS(5382),
    [anon_sym_bufif0] = ACTIONS(5382),
    [anon_sym_bufif1] = ACTIONS(5382),
    [anon_sym_notif0] = ACTIONS(5382),
    [anon_sym_notif1] = ACTIONS(5382),
    [anon_sym_nmos] = ACTIONS(5382),
    [anon_sym_pmos] = ACTIONS(5382),
    [anon_sym_rnmos] = ACTIONS(5382),
    [anon_sym_rpmos] = ACTIONS(5382),
    [anon_sym_nand] = ACTIONS(5382),
    [anon_sym_nor] = ACTIONS(5382),
    [anon_sym_xor] = ACTIONS(5382),
    [anon_sym_xnor] = ACTIONS(5382),
    [anon_sym_buf] = ACTIONS(5382),
    [anon_sym_tranif0] = ACTIONS(5382),
    [anon_sym_tranif1] = ACTIONS(5382),
    [anon_sym_rtranif1] = ACTIONS(5382),
    [anon_sym_rtranif0] = ACTIONS(5382),
    [anon_sym_tran] = ACTIONS(5382),
    [anon_sym_rtran] = ACTIONS(5382),
    [anon_sym_generate] = ACTIONS(5382),
    [anon_sym_for] = ACTIONS(5382),
    [anon_sym_initial] = ACTIONS(5382),
    [anon_sym_assign] = ACTIONS(5382),
    [anon_sym_alias] = ACTIONS(5382),
    [anon_sym_always_comb] = ACTIONS(5382),
    [anon_sym_always_latch] = ACTIONS(5382),
    [anon_sym_always_ff] = ACTIONS(5382),
    [anon_sym_final] = ACTIONS(5382),
    [anon_sym_global] = ACTIONS(5382),
    [anon_sym_LPAREN_STAR] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5380),
    [anon_sym_DOLLARunit] = ACTIONS(5380),
  },
  [5179] = {
    [sym_simple_identifier] = ACTIONS(5950),
    [anon_sym_wire] = ACTIONS(5950),
    [anon_sym_tri] = ACTIONS(5950),
    [anon_sym_tri0] = ACTIONS(5950),
    [anon_sym_tri1] = ACTIONS(5950),
    [anon_sym_wand] = ACTIONS(5950),
    [anon_sym_triand] = ACTIONS(5950),
    [anon_sym_wor] = ACTIONS(5950),
    [anon_sym_trior] = ACTIONS(5950),
    [anon_sym_trireg] = ACTIONS(5950),
    [anon_sym_uwire] = ACTIONS(5950),
    [anon_sym_SEMI] = ACTIONS(5952),
    [anon_sym_extern] = ACTIONS(5950),
    [anon_sym_interface] = ACTIONS(5950),
    [anon_sym_checker] = ACTIONS(5950),
    [anon_sym_virtual] = ACTIONS(5950),
    [anon_sym_class] = ACTIONS(5950),
    [anon_sym_type] = ACTIONS(5950),
    [anon_sym_DOLLARfatal] = ACTIONS(5952),
    [anon_sym_DOLLARerror] = ACTIONS(5952),
    [anon_sym_DOLLARwarning] = ACTIONS(5952),
    [anon_sym_DOLLARinfo] = ACTIONS(5952),
    [anon_sym_default] = ACTIONS(5950),
    [anon_sym_clocking] = ACTIONS(5950),
    [anon_sym_defparam] = ACTIONS(5950),
    [anon_sym_bind] = ACTIONS(5950),
    [anon_sym_rand] = ACTIONS(5950),
    [anon_sym_const] = ACTIONS(5950),
    [anon_sym_function] = ACTIONS(5950),
    [anon_sym_static] = ACTIONS(5950),
    [anon_sym_constraint] = ACTIONS(5950),
    [anon_sym_if] = ACTIONS(5950),
    [anon_sym_else] = ACTIONS(5950),
    [anon_sym_LBRACK] = ACTIONS(5952),
    [anon_sym_localparam] = ACTIONS(5950),
    [anon_sym_parameter] = ACTIONS(5950),
    [anon_sym_var] = ACTIONS(5950),
    [anon_sym_import] = ACTIONS(5950),
    [anon_sym_export] = ACTIONS(5950),
    [anon_sym_genvar] = ACTIONS(5950),
    [anon_sym_interconnect] = ACTIONS(5950),
    [anon_sym_typedef] = ACTIONS(5950),
    [anon_sym_enum] = ACTIONS(5950),
    [anon_sym_struct] = ACTIONS(5950),
    [anon_sym_union] = ACTIONS(5950),
    [anon_sym_nettype] = ACTIONS(5950),
    [anon_sym_automatic] = ACTIONS(5950),
    [anon_sym_string] = ACTIONS(5950),
    [anon_sym_chandle] = ACTIONS(5950),
    [anon_sym_event] = ACTIONS(5950),
    [anon_sym_byte] = ACTIONS(5950),
    [anon_sym_shortint] = ACTIONS(5950),
    [anon_sym_int] = ACTIONS(5950),
    [anon_sym_longint] = ACTIONS(5950),
    [anon_sym_integer] = ACTIONS(5950),
    [anon_sym_time] = ACTIONS(5950),
    [anon_sym_bit] = ACTIONS(5950),
    [anon_sym_logic] = ACTIONS(5950),
    [anon_sym_reg] = ACTIONS(5950),
    [anon_sym_shortreal] = ACTIONS(5950),
    [anon_sym_real] = ACTIONS(5950),
    [anon_sym_realtime] = ACTIONS(5950),
    [anon_sym_supply0] = ACTIONS(5950),
    [anon_sym_supply1] = ACTIONS(5950),
    [anon_sym_signed] = ACTIONS(5950),
    [anon_sym_unsigned] = ACTIONS(5950),
    [anon_sym_task] = ACTIONS(5950),
    [anon_sym_assert] = ACTIONS(5950),
    [anon_sym_property] = ACTIONS(5950),
    [anon_sym_assume] = ACTIONS(5950),
    [anon_sym_cover] = ACTIONS(5950),
    [anon_sym_sequence] = ACTIONS(5950),
    [anon_sym_restrict] = ACTIONS(5950),
    [anon_sym_not] = ACTIONS(5950),
    [anon_sym_or] = ACTIONS(5950),
    [anon_sym_and] = ACTIONS(5950),
    [anon_sym_case] = ACTIONS(5950),
    [anon_sym_always] = ACTIONS(5950),
    [anon_sym_covergroup] = ACTIONS(5950),
    [anon_sym_let] = ACTIONS(5950),
    [anon_sym_pulldown] = ACTIONS(5950),
    [anon_sym_pullup] = ACTIONS(5950),
    [anon_sym_cmos] = ACTIONS(5950),
    [anon_sym_rcmos] = ACTIONS(5950),
    [anon_sym_bufif0] = ACTIONS(5950),
    [anon_sym_bufif1] = ACTIONS(5950),
    [anon_sym_notif0] = ACTIONS(5950),
    [anon_sym_notif1] = ACTIONS(5950),
    [anon_sym_nmos] = ACTIONS(5950),
    [anon_sym_pmos] = ACTIONS(5950),
    [anon_sym_rnmos] = ACTIONS(5950),
    [anon_sym_rpmos] = ACTIONS(5950),
    [anon_sym_nand] = ACTIONS(5950),
    [anon_sym_nor] = ACTIONS(5950),
    [anon_sym_xor] = ACTIONS(5950),
    [anon_sym_xnor] = ACTIONS(5950),
    [anon_sym_buf] = ACTIONS(5950),
    [anon_sym_tranif0] = ACTIONS(5950),
    [anon_sym_tranif1] = ACTIONS(5950),
    [anon_sym_rtranif1] = ACTIONS(5950),
    [anon_sym_rtranif0] = ACTIONS(5950),
    [anon_sym_tran] = ACTIONS(5950),
    [anon_sym_rtran] = ACTIONS(5950),
    [anon_sym_generate] = ACTIONS(5950),
    [anon_sym_endgenerate] = ACTIONS(5950),
    [anon_sym_for] = ACTIONS(5950),
    [anon_sym_initial] = ACTIONS(5950),
    [anon_sym_assign] = ACTIONS(5950),
    [anon_sym_alias] = ACTIONS(5950),
    [anon_sym_always_comb] = ACTIONS(5950),
    [anon_sym_always_latch] = ACTIONS(5950),
    [anon_sym_always_ff] = ACTIONS(5950),
    [anon_sym_final] = ACTIONS(5950),
    [anon_sym_global] = ACTIONS(5950),
    [anon_sym_LPAREN_STAR] = ACTIONS(5952),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5952),
    [anon_sym_DOLLARunit] = ACTIONS(5952),
  },
  [5180] = {
    [sym_simple_identifier] = ACTIONS(5388),
    [anon_sym_wire] = ACTIONS(5388),
    [anon_sym_tri] = ACTIONS(5388),
    [anon_sym_tri0] = ACTIONS(5388),
    [anon_sym_tri1] = ACTIONS(5388),
    [anon_sym_wand] = ACTIONS(5388),
    [anon_sym_triand] = ACTIONS(5388),
    [anon_sym_wor] = ACTIONS(5388),
    [anon_sym_trior] = ACTIONS(5388),
    [anon_sym_trireg] = ACTIONS(5388),
    [anon_sym_uwire] = ACTIONS(5388),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_extern] = ACTIONS(5388),
    [anon_sym_interface] = ACTIONS(5388),
    [anon_sym_checker] = ACTIONS(5388),
    [anon_sym_virtual] = ACTIONS(5388),
    [anon_sym_class] = ACTIONS(5388),
    [anon_sym_type] = ACTIONS(5388),
    [anon_sym_DOLLARfatal] = ACTIONS(5386),
    [anon_sym_DOLLARerror] = ACTIONS(5386),
    [anon_sym_DOLLARwarning] = ACTIONS(5386),
    [anon_sym_DOLLARinfo] = ACTIONS(5386),
    [anon_sym_default] = ACTIONS(5388),
    [anon_sym_clocking] = ACTIONS(5388),
    [anon_sym_defparam] = ACTIONS(5388),
    [anon_sym_bind] = ACTIONS(5388),
    [anon_sym_rand] = ACTIONS(5388),
    [anon_sym_const] = ACTIONS(5388),
    [anon_sym_function] = ACTIONS(5388),
    [anon_sym_static] = ACTIONS(5388),
    [anon_sym_constraint] = ACTIONS(5388),
    [anon_sym_if] = ACTIONS(5388),
    [anon_sym_else] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [anon_sym_localparam] = ACTIONS(5388),
    [anon_sym_parameter] = ACTIONS(5388),
    [anon_sym_var] = ACTIONS(5388),
    [anon_sym_import] = ACTIONS(5388),
    [anon_sym_export] = ACTIONS(5388),
    [anon_sym_genvar] = ACTIONS(5388),
    [anon_sym_interconnect] = ACTIONS(5388),
    [anon_sym_typedef] = ACTIONS(5388),
    [anon_sym_enum] = ACTIONS(5388),
    [anon_sym_struct] = ACTIONS(5388),
    [anon_sym_union] = ACTIONS(5388),
    [anon_sym_nettype] = ACTIONS(5388),
    [anon_sym_automatic] = ACTIONS(5388),
    [anon_sym_string] = ACTIONS(5388),
    [anon_sym_chandle] = ACTIONS(5388),
    [anon_sym_event] = ACTIONS(5388),
    [anon_sym_byte] = ACTIONS(5388),
    [anon_sym_shortint] = ACTIONS(5388),
    [anon_sym_int] = ACTIONS(5388),
    [anon_sym_longint] = ACTIONS(5388),
    [anon_sym_integer] = ACTIONS(5388),
    [anon_sym_time] = ACTIONS(5388),
    [anon_sym_bit] = ACTIONS(5388),
    [anon_sym_logic] = ACTIONS(5388),
    [anon_sym_reg] = ACTIONS(5388),
    [anon_sym_shortreal] = ACTIONS(5388),
    [anon_sym_real] = ACTIONS(5388),
    [anon_sym_realtime] = ACTIONS(5388),
    [anon_sym_supply0] = ACTIONS(5388),
    [anon_sym_supply1] = ACTIONS(5388),
    [anon_sym_signed] = ACTIONS(5388),
    [anon_sym_unsigned] = ACTIONS(5388),
    [anon_sym_task] = ACTIONS(5388),
    [anon_sym_assert] = ACTIONS(5388),
    [anon_sym_property] = ACTIONS(5388),
    [anon_sym_assume] = ACTIONS(5388),
    [anon_sym_cover] = ACTIONS(5388),
    [anon_sym_sequence] = ACTIONS(5388),
    [anon_sym_restrict] = ACTIONS(5388),
    [anon_sym_not] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_case] = ACTIONS(5388),
    [anon_sym_always] = ACTIONS(5388),
    [anon_sym_covergroup] = ACTIONS(5388),
    [anon_sym_end] = ACTIONS(5388),
    [anon_sym_let] = ACTIONS(5388),
    [anon_sym_pulldown] = ACTIONS(5388),
    [anon_sym_pullup] = ACTIONS(5388),
    [anon_sym_cmos] = ACTIONS(5388),
    [anon_sym_rcmos] = ACTIONS(5388),
    [anon_sym_bufif0] = ACTIONS(5388),
    [anon_sym_bufif1] = ACTIONS(5388),
    [anon_sym_notif0] = ACTIONS(5388),
    [anon_sym_notif1] = ACTIONS(5388),
    [anon_sym_nmos] = ACTIONS(5388),
    [anon_sym_pmos] = ACTIONS(5388),
    [anon_sym_rnmos] = ACTIONS(5388),
    [anon_sym_rpmos] = ACTIONS(5388),
    [anon_sym_nand] = ACTIONS(5388),
    [anon_sym_nor] = ACTIONS(5388),
    [anon_sym_xor] = ACTIONS(5388),
    [anon_sym_xnor] = ACTIONS(5388),
    [anon_sym_buf] = ACTIONS(5388),
    [anon_sym_tranif0] = ACTIONS(5388),
    [anon_sym_tranif1] = ACTIONS(5388),
    [anon_sym_rtranif1] = ACTIONS(5388),
    [anon_sym_rtranif0] = ACTIONS(5388),
    [anon_sym_tran] = ACTIONS(5388),
    [anon_sym_rtran] = ACTIONS(5388),
    [anon_sym_generate] = ACTIONS(5388),
    [anon_sym_for] = ACTIONS(5388),
    [anon_sym_initial] = ACTIONS(5388),
    [anon_sym_assign] = ACTIONS(5388),
    [anon_sym_alias] = ACTIONS(5388),
    [anon_sym_always_comb] = ACTIONS(5388),
    [anon_sym_always_latch] = ACTIONS(5388),
    [anon_sym_always_ff] = ACTIONS(5388),
    [anon_sym_final] = ACTIONS(5388),
    [anon_sym_global] = ACTIONS(5388),
    [anon_sym_LPAREN_STAR] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5386),
    [anon_sym_DOLLARunit] = ACTIONS(5386),
  },
  [5181] = {
    [sym_simple_identifier] = ACTIONS(6417),
    [anon_sym_wire] = ACTIONS(6417),
    [anon_sym_tri] = ACTIONS(6417),
    [anon_sym_tri0] = ACTIONS(6417),
    [anon_sym_tri1] = ACTIONS(6417),
    [anon_sym_wand] = ACTIONS(6417),
    [anon_sym_triand] = ACTIONS(6417),
    [anon_sym_wor] = ACTIONS(6417),
    [anon_sym_trior] = ACTIONS(6417),
    [anon_sym_trireg] = ACTIONS(6417),
    [anon_sym_uwire] = ACTIONS(6417),
    [anon_sym_SEMI] = ACTIONS(6419),
    [anon_sym_extern] = ACTIONS(6417),
    [anon_sym_interface] = ACTIONS(6417),
    [anon_sym_checker] = ACTIONS(6417),
    [anon_sym_virtual] = ACTIONS(6417),
    [anon_sym_class] = ACTIONS(6417),
    [anon_sym_type] = ACTIONS(6417),
    [anon_sym_DOLLARfatal] = ACTIONS(6419),
    [anon_sym_DOLLARerror] = ACTIONS(6419),
    [anon_sym_DOLLARwarning] = ACTIONS(6419),
    [anon_sym_DOLLARinfo] = ACTIONS(6419),
    [anon_sym_default] = ACTIONS(6417),
    [anon_sym_clocking] = ACTIONS(6417),
    [anon_sym_defparam] = ACTIONS(6417),
    [anon_sym_bind] = ACTIONS(6417),
    [anon_sym_rand] = ACTIONS(6417),
    [anon_sym_const] = ACTIONS(6417),
    [anon_sym_function] = ACTIONS(6417),
    [anon_sym_static] = ACTIONS(6417),
    [anon_sym_constraint] = ACTIONS(6417),
    [anon_sym_if] = ACTIONS(6417),
    [anon_sym_else] = ACTIONS(6417),
    [anon_sym_LBRACK] = ACTIONS(6419),
    [anon_sym_localparam] = ACTIONS(6417),
    [anon_sym_parameter] = ACTIONS(6417),
    [anon_sym_var] = ACTIONS(6417),
    [anon_sym_import] = ACTIONS(6417),
    [anon_sym_export] = ACTIONS(6417),
    [anon_sym_genvar] = ACTIONS(6417),
    [anon_sym_interconnect] = ACTIONS(6417),
    [anon_sym_typedef] = ACTIONS(6417),
    [anon_sym_enum] = ACTIONS(6417),
    [anon_sym_struct] = ACTIONS(6417),
    [anon_sym_union] = ACTIONS(6417),
    [anon_sym_nettype] = ACTIONS(6417),
    [anon_sym_automatic] = ACTIONS(6417),
    [anon_sym_string] = ACTIONS(6417),
    [anon_sym_chandle] = ACTIONS(6417),
    [anon_sym_event] = ACTIONS(6417),
    [anon_sym_byte] = ACTIONS(6417),
    [anon_sym_shortint] = ACTIONS(6417),
    [anon_sym_int] = ACTIONS(6417),
    [anon_sym_longint] = ACTIONS(6417),
    [anon_sym_integer] = ACTIONS(6417),
    [anon_sym_time] = ACTIONS(6417),
    [anon_sym_bit] = ACTIONS(6417),
    [anon_sym_logic] = ACTIONS(6417),
    [anon_sym_reg] = ACTIONS(6417),
    [anon_sym_shortreal] = ACTIONS(6417),
    [anon_sym_real] = ACTIONS(6417),
    [anon_sym_realtime] = ACTIONS(6417),
    [anon_sym_supply0] = ACTIONS(6417),
    [anon_sym_supply1] = ACTIONS(6417),
    [anon_sym_signed] = ACTIONS(6417),
    [anon_sym_unsigned] = ACTIONS(6417),
    [anon_sym_task] = ACTIONS(6417),
    [anon_sym_assert] = ACTIONS(6417),
    [anon_sym_property] = ACTIONS(6417),
    [anon_sym_assume] = ACTIONS(6417),
    [anon_sym_cover] = ACTIONS(6417),
    [anon_sym_sequence] = ACTIONS(6417),
    [anon_sym_restrict] = ACTIONS(6417),
    [anon_sym_not] = ACTIONS(6417),
    [anon_sym_or] = ACTIONS(6417),
    [anon_sym_and] = ACTIONS(6417),
    [anon_sym_case] = ACTIONS(6417),
    [anon_sym_always] = ACTIONS(6417),
    [anon_sym_covergroup] = ACTIONS(6417),
    [anon_sym_let] = ACTIONS(6417),
    [anon_sym_pulldown] = ACTIONS(6417),
    [anon_sym_pullup] = ACTIONS(6417),
    [anon_sym_cmos] = ACTIONS(6417),
    [anon_sym_rcmos] = ACTIONS(6417),
    [anon_sym_bufif0] = ACTIONS(6417),
    [anon_sym_bufif1] = ACTIONS(6417),
    [anon_sym_notif0] = ACTIONS(6417),
    [anon_sym_notif1] = ACTIONS(6417),
    [anon_sym_nmos] = ACTIONS(6417),
    [anon_sym_pmos] = ACTIONS(6417),
    [anon_sym_rnmos] = ACTIONS(6417),
    [anon_sym_rpmos] = ACTIONS(6417),
    [anon_sym_nand] = ACTIONS(6417),
    [anon_sym_nor] = ACTIONS(6417),
    [anon_sym_xor] = ACTIONS(6417),
    [anon_sym_xnor] = ACTIONS(6417),
    [anon_sym_buf] = ACTIONS(6417),
    [anon_sym_tranif0] = ACTIONS(6417),
    [anon_sym_tranif1] = ACTIONS(6417),
    [anon_sym_rtranif1] = ACTIONS(6417),
    [anon_sym_rtranif0] = ACTIONS(6417),
    [anon_sym_tran] = ACTIONS(6417),
    [anon_sym_rtran] = ACTIONS(6417),
    [anon_sym_generate] = ACTIONS(6417),
    [anon_sym_endgenerate] = ACTIONS(6417),
    [anon_sym_for] = ACTIONS(6417),
    [anon_sym_initial] = ACTIONS(6417),
    [anon_sym_assign] = ACTIONS(6417),
    [anon_sym_alias] = ACTIONS(6417),
    [anon_sym_always_comb] = ACTIONS(6417),
    [anon_sym_always_latch] = ACTIONS(6417),
    [anon_sym_always_ff] = ACTIONS(6417),
    [anon_sym_final] = ACTIONS(6417),
    [anon_sym_global] = ACTIONS(6417),
    [anon_sym_LPAREN_STAR] = ACTIONS(6419),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6419),
    [anon_sym_DOLLARunit] = ACTIONS(6419),
  },
  [5182] = {
    [sym_simple_identifier] = ACTIONS(5370),
    [anon_sym_wire] = ACTIONS(5370),
    [anon_sym_tri] = ACTIONS(5370),
    [anon_sym_tri0] = ACTIONS(5370),
    [anon_sym_tri1] = ACTIONS(5370),
    [anon_sym_wand] = ACTIONS(5370),
    [anon_sym_triand] = ACTIONS(5370),
    [anon_sym_wor] = ACTIONS(5370),
    [anon_sym_trior] = ACTIONS(5370),
    [anon_sym_trireg] = ACTIONS(5370),
    [anon_sym_uwire] = ACTIONS(5370),
    [anon_sym_SEMI] = ACTIONS(5368),
    [anon_sym_extern] = ACTIONS(5370),
    [anon_sym_interface] = ACTIONS(5370),
    [anon_sym_checker] = ACTIONS(5370),
    [anon_sym_virtual] = ACTIONS(5370),
    [anon_sym_class] = ACTIONS(5370),
    [anon_sym_type] = ACTIONS(5370),
    [anon_sym_DOLLARfatal] = ACTIONS(5368),
    [anon_sym_DOLLARerror] = ACTIONS(5368),
    [anon_sym_DOLLARwarning] = ACTIONS(5368),
    [anon_sym_DOLLARinfo] = ACTIONS(5368),
    [anon_sym_default] = ACTIONS(5370),
    [anon_sym_clocking] = ACTIONS(5370),
    [anon_sym_defparam] = ACTIONS(5370),
    [anon_sym_bind] = ACTIONS(5370),
    [anon_sym_rand] = ACTIONS(5370),
    [anon_sym_const] = ACTIONS(5370),
    [anon_sym_function] = ACTIONS(5370),
    [anon_sym_static] = ACTIONS(5370),
    [anon_sym_constraint] = ACTIONS(5370),
    [anon_sym_if] = ACTIONS(5370),
    [anon_sym_else] = ACTIONS(5370),
    [anon_sym_LBRACK] = ACTIONS(5368),
    [anon_sym_localparam] = ACTIONS(5370),
    [anon_sym_parameter] = ACTIONS(5370),
    [anon_sym_var] = ACTIONS(5370),
    [anon_sym_import] = ACTIONS(5370),
    [anon_sym_export] = ACTIONS(5370),
    [anon_sym_genvar] = ACTIONS(5370),
    [anon_sym_interconnect] = ACTIONS(5370),
    [anon_sym_typedef] = ACTIONS(5370),
    [anon_sym_enum] = ACTIONS(5370),
    [anon_sym_struct] = ACTIONS(5370),
    [anon_sym_union] = ACTIONS(5370),
    [anon_sym_nettype] = ACTIONS(5370),
    [anon_sym_automatic] = ACTIONS(5370),
    [anon_sym_string] = ACTIONS(5370),
    [anon_sym_chandle] = ACTIONS(5370),
    [anon_sym_event] = ACTIONS(5370),
    [anon_sym_byte] = ACTIONS(5370),
    [anon_sym_shortint] = ACTIONS(5370),
    [anon_sym_int] = ACTIONS(5370),
    [anon_sym_longint] = ACTIONS(5370),
    [anon_sym_integer] = ACTIONS(5370),
    [anon_sym_time] = ACTIONS(5370),
    [anon_sym_bit] = ACTIONS(5370),
    [anon_sym_logic] = ACTIONS(5370),
    [anon_sym_reg] = ACTIONS(5370),
    [anon_sym_shortreal] = ACTIONS(5370),
    [anon_sym_real] = ACTIONS(5370),
    [anon_sym_realtime] = ACTIONS(5370),
    [anon_sym_supply0] = ACTIONS(5370),
    [anon_sym_supply1] = ACTIONS(5370),
    [anon_sym_signed] = ACTIONS(5370),
    [anon_sym_unsigned] = ACTIONS(5370),
    [anon_sym_task] = ACTIONS(5370),
    [anon_sym_assert] = ACTIONS(5370),
    [anon_sym_property] = ACTIONS(5370),
    [anon_sym_assume] = ACTIONS(5370),
    [anon_sym_cover] = ACTIONS(5370),
    [anon_sym_sequence] = ACTIONS(5370),
    [anon_sym_restrict] = ACTIONS(5370),
    [anon_sym_not] = ACTIONS(5370),
    [anon_sym_or] = ACTIONS(5370),
    [anon_sym_and] = ACTIONS(5370),
    [anon_sym_case] = ACTIONS(5370),
    [anon_sym_always] = ACTIONS(5370),
    [anon_sym_covergroup] = ACTIONS(5370),
    [anon_sym_let] = ACTIONS(5370),
    [anon_sym_pulldown] = ACTIONS(5370),
    [anon_sym_pullup] = ACTIONS(5370),
    [anon_sym_cmos] = ACTIONS(5370),
    [anon_sym_rcmos] = ACTIONS(5370),
    [anon_sym_bufif0] = ACTIONS(5370),
    [anon_sym_bufif1] = ACTIONS(5370),
    [anon_sym_notif0] = ACTIONS(5370),
    [anon_sym_notif1] = ACTIONS(5370),
    [anon_sym_nmos] = ACTIONS(5370),
    [anon_sym_pmos] = ACTIONS(5370),
    [anon_sym_rnmos] = ACTIONS(5370),
    [anon_sym_rpmos] = ACTIONS(5370),
    [anon_sym_nand] = ACTIONS(5370),
    [anon_sym_nor] = ACTIONS(5370),
    [anon_sym_xor] = ACTIONS(5370),
    [anon_sym_xnor] = ACTIONS(5370),
    [anon_sym_buf] = ACTIONS(5370),
    [anon_sym_tranif0] = ACTIONS(5370),
    [anon_sym_tranif1] = ACTIONS(5370),
    [anon_sym_rtranif1] = ACTIONS(5370),
    [anon_sym_rtranif0] = ACTIONS(5370),
    [anon_sym_tran] = ACTIONS(5370),
    [anon_sym_rtran] = ACTIONS(5370),
    [anon_sym_generate] = ACTIONS(5370),
    [anon_sym_endgenerate] = ACTIONS(5370),
    [anon_sym_for] = ACTIONS(5370),
    [anon_sym_initial] = ACTIONS(5370),
    [anon_sym_assign] = ACTIONS(5370),
    [anon_sym_alias] = ACTIONS(5370),
    [anon_sym_always_comb] = ACTIONS(5370),
    [anon_sym_always_latch] = ACTIONS(5370),
    [anon_sym_always_ff] = ACTIONS(5370),
    [anon_sym_final] = ACTIONS(5370),
    [anon_sym_global] = ACTIONS(5370),
    [anon_sym_LPAREN_STAR] = ACTIONS(5368),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5368),
    [anon_sym_DOLLARunit] = ACTIONS(5368),
  },
  [5183] = {
    [sym_simple_identifier] = ACTIONS(4424),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_rand] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_end] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [5184] = {
    [sym_simple_identifier] = ACTIONS(6385),
    [anon_sym_wire] = ACTIONS(6385),
    [anon_sym_tri] = ACTIONS(6385),
    [anon_sym_tri0] = ACTIONS(6385),
    [anon_sym_tri1] = ACTIONS(6385),
    [anon_sym_wand] = ACTIONS(6385),
    [anon_sym_triand] = ACTIONS(6385),
    [anon_sym_wor] = ACTIONS(6385),
    [anon_sym_trior] = ACTIONS(6385),
    [anon_sym_trireg] = ACTIONS(6385),
    [anon_sym_uwire] = ACTIONS(6385),
    [anon_sym_SEMI] = ACTIONS(6387),
    [anon_sym_extern] = ACTIONS(6385),
    [anon_sym_interface] = ACTIONS(6385),
    [anon_sym_checker] = ACTIONS(6385),
    [anon_sym_virtual] = ACTIONS(6385),
    [anon_sym_class] = ACTIONS(6385),
    [anon_sym_type] = ACTIONS(6385),
    [anon_sym_DOLLARfatal] = ACTIONS(6387),
    [anon_sym_DOLLARerror] = ACTIONS(6387),
    [anon_sym_DOLLARwarning] = ACTIONS(6387),
    [anon_sym_DOLLARinfo] = ACTIONS(6387),
    [anon_sym_default] = ACTIONS(6385),
    [anon_sym_clocking] = ACTIONS(6385),
    [anon_sym_defparam] = ACTIONS(6385),
    [anon_sym_bind] = ACTIONS(6385),
    [anon_sym_rand] = ACTIONS(6385),
    [anon_sym_const] = ACTIONS(6385),
    [anon_sym_function] = ACTIONS(6385),
    [anon_sym_static] = ACTIONS(6385),
    [anon_sym_constraint] = ACTIONS(6385),
    [anon_sym_if] = ACTIONS(6385),
    [anon_sym_else] = ACTIONS(6385),
    [anon_sym_LBRACK] = ACTIONS(6387),
    [anon_sym_localparam] = ACTIONS(6385),
    [anon_sym_parameter] = ACTIONS(6385),
    [anon_sym_var] = ACTIONS(6385),
    [anon_sym_import] = ACTIONS(6385),
    [anon_sym_export] = ACTIONS(6385),
    [anon_sym_genvar] = ACTIONS(6385),
    [anon_sym_interconnect] = ACTIONS(6385),
    [anon_sym_typedef] = ACTIONS(6385),
    [anon_sym_enum] = ACTIONS(6385),
    [anon_sym_struct] = ACTIONS(6385),
    [anon_sym_union] = ACTIONS(6385),
    [anon_sym_nettype] = ACTIONS(6385),
    [anon_sym_automatic] = ACTIONS(6385),
    [anon_sym_string] = ACTIONS(6385),
    [anon_sym_chandle] = ACTIONS(6385),
    [anon_sym_event] = ACTIONS(6385),
    [anon_sym_byte] = ACTIONS(6385),
    [anon_sym_shortint] = ACTIONS(6385),
    [anon_sym_int] = ACTIONS(6385),
    [anon_sym_longint] = ACTIONS(6385),
    [anon_sym_integer] = ACTIONS(6385),
    [anon_sym_time] = ACTIONS(6385),
    [anon_sym_bit] = ACTIONS(6385),
    [anon_sym_logic] = ACTIONS(6385),
    [anon_sym_reg] = ACTIONS(6385),
    [anon_sym_shortreal] = ACTIONS(6385),
    [anon_sym_real] = ACTIONS(6385),
    [anon_sym_realtime] = ACTIONS(6385),
    [anon_sym_supply0] = ACTIONS(6385),
    [anon_sym_supply1] = ACTIONS(6385),
    [anon_sym_signed] = ACTIONS(6385),
    [anon_sym_unsigned] = ACTIONS(6385),
    [anon_sym_task] = ACTIONS(6385),
    [anon_sym_assert] = ACTIONS(6385),
    [anon_sym_property] = ACTIONS(6385),
    [anon_sym_assume] = ACTIONS(6385),
    [anon_sym_cover] = ACTIONS(6385),
    [anon_sym_sequence] = ACTIONS(6385),
    [anon_sym_restrict] = ACTIONS(6385),
    [anon_sym_not] = ACTIONS(6385),
    [anon_sym_or] = ACTIONS(6385),
    [anon_sym_and] = ACTIONS(6385),
    [anon_sym_case] = ACTIONS(6385),
    [anon_sym_always] = ACTIONS(6385),
    [anon_sym_covergroup] = ACTIONS(6385),
    [anon_sym_end] = ACTIONS(6385),
    [anon_sym_let] = ACTIONS(6385),
    [anon_sym_pulldown] = ACTIONS(6385),
    [anon_sym_pullup] = ACTIONS(6385),
    [anon_sym_cmos] = ACTIONS(6385),
    [anon_sym_rcmos] = ACTIONS(6385),
    [anon_sym_bufif0] = ACTIONS(6385),
    [anon_sym_bufif1] = ACTIONS(6385),
    [anon_sym_notif0] = ACTIONS(6385),
    [anon_sym_notif1] = ACTIONS(6385),
    [anon_sym_nmos] = ACTIONS(6385),
    [anon_sym_pmos] = ACTIONS(6385),
    [anon_sym_rnmos] = ACTIONS(6385),
    [anon_sym_rpmos] = ACTIONS(6385),
    [anon_sym_nand] = ACTIONS(6385),
    [anon_sym_nor] = ACTIONS(6385),
    [anon_sym_xor] = ACTIONS(6385),
    [anon_sym_xnor] = ACTIONS(6385),
    [anon_sym_buf] = ACTIONS(6385),
    [anon_sym_tranif0] = ACTIONS(6385),
    [anon_sym_tranif1] = ACTIONS(6385),
    [anon_sym_rtranif1] = ACTIONS(6385),
    [anon_sym_rtranif0] = ACTIONS(6385),
    [anon_sym_tran] = ACTIONS(6385),
    [anon_sym_rtran] = ACTIONS(6385),
    [anon_sym_generate] = ACTIONS(6385),
    [anon_sym_for] = ACTIONS(6385),
    [anon_sym_initial] = ACTIONS(6385),
    [anon_sym_assign] = ACTIONS(6385),
    [anon_sym_alias] = ACTIONS(6385),
    [anon_sym_always_comb] = ACTIONS(6385),
    [anon_sym_always_latch] = ACTIONS(6385),
    [anon_sym_always_ff] = ACTIONS(6385),
    [anon_sym_final] = ACTIONS(6385),
    [anon_sym_global] = ACTIONS(6385),
    [anon_sym_LPAREN_STAR] = ACTIONS(6387),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6387),
    [anon_sym_DOLLARunit] = ACTIONS(6387),
  },
  [5185] = {
    [sym_simple_identifier] = ACTIONS(5374),
    [anon_sym_wire] = ACTIONS(5374),
    [anon_sym_tri] = ACTIONS(5374),
    [anon_sym_tri0] = ACTIONS(5374),
    [anon_sym_tri1] = ACTIONS(5374),
    [anon_sym_wand] = ACTIONS(5374),
    [anon_sym_triand] = ACTIONS(5374),
    [anon_sym_wor] = ACTIONS(5374),
    [anon_sym_trior] = ACTIONS(5374),
    [anon_sym_trireg] = ACTIONS(5374),
    [anon_sym_uwire] = ACTIONS(5374),
    [anon_sym_SEMI] = ACTIONS(5372),
    [anon_sym_extern] = ACTIONS(5374),
    [anon_sym_interface] = ACTIONS(5374),
    [anon_sym_checker] = ACTIONS(5374),
    [anon_sym_virtual] = ACTIONS(5374),
    [anon_sym_class] = ACTIONS(5374),
    [anon_sym_type] = ACTIONS(5374),
    [anon_sym_DOLLARfatal] = ACTIONS(5372),
    [anon_sym_DOLLARerror] = ACTIONS(5372),
    [anon_sym_DOLLARwarning] = ACTIONS(5372),
    [anon_sym_DOLLARinfo] = ACTIONS(5372),
    [anon_sym_default] = ACTIONS(5374),
    [anon_sym_clocking] = ACTIONS(5374),
    [anon_sym_defparam] = ACTIONS(5374),
    [anon_sym_bind] = ACTIONS(5374),
    [anon_sym_rand] = ACTIONS(5374),
    [anon_sym_const] = ACTIONS(5374),
    [anon_sym_function] = ACTIONS(5374),
    [anon_sym_static] = ACTIONS(5374),
    [anon_sym_constraint] = ACTIONS(5374),
    [anon_sym_if] = ACTIONS(5374),
    [anon_sym_else] = ACTIONS(5374),
    [anon_sym_LBRACK] = ACTIONS(5372),
    [anon_sym_localparam] = ACTIONS(5374),
    [anon_sym_parameter] = ACTIONS(5374),
    [anon_sym_var] = ACTIONS(5374),
    [anon_sym_import] = ACTIONS(5374),
    [anon_sym_export] = ACTIONS(5374),
    [anon_sym_genvar] = ACTIONS(5374),
    [anon_sym_interconnect] = ACTIONS(5374),
    [anon_sym_typedef] = ACTIONS(5374),
    [anon_sym_enum] = ACTIONS(5374),
    [anon_sym_struct] = ACTIONS(5374),
    [anon_sym_union] = ACTIONS(5374),
    [anon_sym_nettype] = ACTIONS(5374),
    [anon_sym_automatic] = ACTIONS(5374),
    [anon_sym_string] = ACTIONS(5374),
    [anon_sym_chandle] = ACTIONS(5374),
    [anon_sym_event] = ACTIONS(5374),
    [anon_sym_byte] = ACTIONS(5374),
    [anon_sym_shortint] = ACTIONS(5374),
    [anon_sym_int] = ACTIONS(5374),
    [anon_sym_longint] = ACTIONS(5374),
    [anon_sym_integer] = ACTIONS(5374),
    [anon_sym_time] = ACTIONS(5374),
    [anon_sym_bit] = ACTIONS(5374),
    [anon_sym_logic] = ACTIONS(5374),
    [anon_sym_reg] = ACTIONS(5374),
    [anon_sym_shortreal] = ACTIONS(5374),
    [anon_sym_real] = ACTIONS(5374),
    [anon_sym_realtime] = ACTIONS(5374),
    [anon_sym_supply0] = ACTIONS(5374),
    [anon_sym_supply1] = ACTIONS(5374),
    [anon_sym_signed] = ACTIONS(5374),
    [anon_sym_unsigned] = ACTIONS(5374),
    [anon_sym_task] = ACTIONS(5374),
    [anon_sym_assert] = ACTIONS(5374),
    [anon_sym_property] = ACTIONS(5374),
    [anon_sym_assume] = ACTIONS(5374),
    [anon_sym_cover] = ACTIONS(5374),
    [anon_sym_sequence] = ACTIONS(5374),
    [anon_sym_restrict] = ACTIONS(5374),
    [anon_sym_not] = ACTIONS(5374),
    [anon_sym_or] = ACTIONS(5374),
    [anon_sym_and] = ACTIONS(5374),
    [anon_sym_case] = ACTIONS(5374),
    [anon_sym_always] = ACTIONS(5374),
    [anon_sym_covergroup] = ACTIONS(5374),
    [anon_sym_let] = ACTIONS(5374),
    [anon_sym_pulldown] = ACTIONS(5374),
    [anon_sym_pullup] = ACTIONS(5374),
    [anon_sym_cmos] = ACTIONS(5374),
    [anon_sym_rcmos] = ACTIONS(5374),
    [anon_sym_bufif0] = ACTIONS(5374),
    [anon_sym_bufif1] = ACTIONS(5374),
    [anon_sym_notif0] = ACTIONS(5374),
    [anon_sym_notif1] = ACTIONS(5374),
    [anon_sym_nmos] = ACTIONS(5374),
    [anon_sym_pmos] = ACTIONS(5374),
    [anon_sym_rnmos] = ACTIONS(5374),
    [anon_sym_rpmos] = ACTIONS(5374),
    [anon_sym_nand] = ACTIONS(5374),
    [anon_sym_nor] = ACTIONS(5374),
    [anon_sym_xor] = ACTIONS(5374),
    [anon_sym_xnor] = ACTIONS(5374),
    [anon_sym_buf] = ACTIONS(5374),
    [anon_sym_tranif0] = ACTIONS(5374),
    [anon_sym_tranif1] = ACTIONS(5374),
    [anon_sym_rtranif1] = ACTIONS(5374),
    [anon_sym_rtranif0] = ACTIONS(5374),
    [anon_sym_tran] = ACTIONS(5374),
    [anon_sym_rtran] = ACTIONS(5374),
    [anon_sym_generate] = ACTIONS(5374),
    [anon_sym_endgenerate] = ACTIONS(5374),
    [anon_sym_for] = ACTIONS(5374),
    [anon_sym_initial] = ACTIONS(5374),
    [anon_sym_assign] = ACTIONS(5374),
    [anon_sym_alias] = ACTIONS(5374),
    [anon_sym_always_comb] = ACTIONS(5374),
    [anon_sym_always_latch] = ACTIONS(5374),
    [anon_sym_always_ff] = ACTIONS(5374),
    [anon_sym_final] = ACTIONS(5374),
    [anon_sym_global] = ACTIONS(5374),
    [anon_sym_LPAREN_STAR] = ACTIONS(5372),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5372),
    [anon_sym_DOLLARunit] = ACTIONS(5372),
  },
  [5186] = {
    [sym_simple_identifier] = ACTIONS(4518),
    [anon_sym_wire] = ACTIONS(4518),
    [anon_sym_tri] = ACTIONS(4518),
    [anon_sym_tri0] = ACTIONS(4518),
    [anon_sym_tri1] = ACTIONS(4518),
    [anon_sym_wand] = ACTIONS(4518),
    [anon_sym_triand] = ACTIONS(4518),
    [anon_sym_wor] = ACTIONS(4518),
    [anon_sym_trior] = ACTIONS(4518),
    [anon_sym_trireg] = ACTIONS(4518),
    [anon_sym_uwire] = ACTIONS(4518),
    [anon_sym_SEMI] = ACTIONS(4516),
    [anon_sym_extern] = ACTIONS(4518),
    [anon_sym_interface] = ACTIONS(4518),
    [anon_sym_checker] = ACTIONS(4518),
    [anon_sym_virtual] = ACTIONS(4518),
    [anon_sym_class] = ACTIONS(4518),
    [anon_sym_type] = ACTIONS(4518),
    [anon_sym_DOLLARfatal] = ACTIONS(4516),
    [anon_sym_DOLLARerror] = ACTIONS(4516),
    [anon_sym_DOLLARwarning] = ACTIONS(4516),
    [anon_sym_DOLLARinfo] = ACTIONS(4516),
    [anon_sym_default] = ACTIONS(4518),
    [anon_sym_clocking] = ACTIONS(4518),
    [anon_sym_defparam] = ACTIONS(4518),
    [anon_sym_bind] = ACTIONS(4518),
    [anon_sym_rand] = ACTIONS(4518),
    [anon_sym_const] = ACTIONS(4518),
    [anon_sym_function] = ACTIONS(4518),
    [anon_sym_static] = ACTIONS(4518),
    [anon_sym_constraint] = ACTIONS(4518),
    [anon_sym_if] = ACTIONS(4518),
    [anon_sym_else] = ACTIONS(4518),
    [anon_sym_LBRACK] = ACTIONS(4516),
    [anon_sym_localparam] = ACTIONS(4518),
    [anon_sym_parameter] = ACTIONS(4518),
    [anon_sym_var] = ACTIONS(4518),
    [anon_sym_import] = ACTIONS(4518),
    [anon_sym_export] = ACTIONS(4518),
    [anon_sym_genvar] = ACTIONS(4518),
    [anon_sym_interconnect] = ACTIONS(4518),
    [anon_sym_typedef] = ACTIONS(4518),
    [anon_sym_enum] = ACTIONS(4518),
    [anon_sym_struct] = ACTIONS(4518),
    [anon_sym_union] = ACTIONS(4518),
    [anon_sym_nettype] = ACTIONS(4518),
    [anon_sym_automatic] = ACTIONS(4518),
    [anon_sym_string] = ACTIONS(4518),
    [anon_sym_chandle] = ACTIONS(4518),
    [anon_sym_event] = ACTIONS(4518),
    [anon_sym_byte] = ACTIONS(4518),
    [anon_sym_shortint] = ACTIONS(4518),
    [anon_sym_int] = ACTIONS(4518),
    [anon_sym_longint] = ACTIONS(4518),
    [anon_sym_integer] = ACTIONS(4518),
    [anon_sym_time] = ACTIONS(4518),
    [anon_sym_bit] = ACTIONS(4518),
    [anon_sym_logic] = ACTIONS(4518),
    [anon_sym_reg] = ACTIONS(4518),
    [anon_sym_shortreal] = ACTIONS(4518),
    [anon_sym_real] = ACTIONS(4518),
    [anon_sym_realtime] = ACTIONS(4518),
    [anon_sym_supply0] = ACTIONS(4518),
    [anon_sym_supply1] = ACTIONS(4518),
    [anon_sym_signed] = ACTIONS(4518),
    [anon_sym_unsigned] = ACTIONS(4518),
    [anon_sym_task] = ACTIONS(4518),
    [anon_sym_assert] = ACTIONS(4518),
    [anon_sym_property] = ACTIONS(4518),
    [anon_sym_assume] = ACTIONS(4518),
    [anon_sym_cover] = ACTIONS(4518),
    [anon_sym_sequence] = ACTIONS(4518),
    [anon_sym_restrict] = ACTIONS(4518),
    [anon_sym_not] = ACTIONS(4518),
    [anon_sym_or] = ACTIONS(4518),
    [anon_sym_and] = ACTIONS(4518),
    [anon_sym_case] = ACTIONS(4518),
    [anon_sym_always] = ACTIONS(4518),
    [anon_sym_covergroup] = ACTIONS(4518),
    [anon_sym_end] = ACTIONS(4518),
    [anon_sym_let] = ACTIONS(4518),
    [anon_sym_pulldown] = ACTIONS(4518),
    [anon_sym_pullup] = ACTIONS(4518),
    [anon_sym_cmos] = ACTIONS(4518),
    [anon_sym_rcmos] = ACTIONS(4518),
    [anon_sym_bufif0] = ACTIONS(4518),
    [anon_sym_bufif1] = ACTIONS(4518),
    [anon_sym_notif0] = ACTIONS(4518),
    [anon_sym_notif1] = ACTIONS(4518),
    [anon_sym_nmos] = ACTIONS(4518),
    [anon_sym_pmos] = ACTIONS(4518),
    [anon_sym_rnmos] = ACTIONS(4518),
    [anon_sym_rpmos] = ACTIONS(4518),
    [anon_sym_nand] = ACTIONS(4518),
    [anon_sym_nor] = ACTIONS(4518),
    [anon_sym_xor] = ACTIONS(4518),
    [anon_sym_xnor] = ACTIONS(4518),
    [anon_sym_buf] = ACTIONS(4518),
    [anon_sym_tranif0] = ACTIONS(4518),
    [anon_sym_tranif1] = ACTIONS(4518),
    [anon_sym_rtranif1] = ACTIONS(4518),
    [anon_sym_rtranif0] = ACTIONS(4518),
    [anon_sym_tran] = ACTIONS(4518),
    [anon_sym_rtran] = ACTIONS(4518),
    [anon_sym_generate] = ACTIONS(4518),
    [anon_sym_for] = ACTIONS(4518),
    [anon_sym_initial] = ACTIONS(4518),
    [anon_sym_assign] = ACTIONS(4518),
    [anon_sym_alias] = ACTIONS(4518),
    [anon_sym_always_comb] = ACTIONS(4518),
    [anon_sym_always_latch] = ACTIONS(4518),
    [anon_sym_always_ff] = ACTIONS(4518),
    [anon_sym_final] = ACTIONS(4518),
    [anon_sym_global] = ACTIONS(4518),
    [anon_sym_LPAREN_STAR] = ACTIONS(4516),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4516),
    [anon_sym_DOLLARunit] = ACTIONS(4516),
  },
  [5187] = {
    [sym_simple_identifier] = ACTIONS(4844),
    [anon_sym_wire] = ACTIONS(4844),
    [anon_sym_tri] = ACTIONS(4844),
    [anon_sym_tri0] = ACTIONS(4844),
    [anon_sym_tri1] = ACTIONS(4844),
    [anon_sym_wand] = ACTIONS(4844),
    [anon_sym_triand] = ACTIONS(4844),
    [anon_sym_wor] = ACTIONS(4844),
    [anon_sym_trior] = ACTIONS(4844),
    [anon_sym_trireg] = ACTIONS(4844),
    [anon_sym_uwire] = ACTIONS(4844),
    [anon_sym_SEMI] = ACTIONS(4842),
    [anon_sym_extern] = ACTIONS(4844),
    [anon_sym_interface] = ACTIONS(4844),
    [anon_sym_checker] = ACTIONS(4844),
    [anon_sym_virtual] = ACTIONS(4844),
    [anon_sym_class] = ACTIONS(4844),
    [anon_sym_type] = ACTIONS(4844),
    [anon_sym_DOLLARfatal] = ACTIONS(4842),
    [anon_sym_DOLLARerror] = ACTIONS(4842),
    [anon_sym_DOLLARwarning] = ACTIONS(4842),
    [anon_sym_DOLLARinfo] = ACTIONS(4842),
    [anon_sym_default] = ACTIONS(4844),
    [anon_sym_clocking] = ACTIONS(4844),
    [anon_sym_defparam] = ACTIONS(4844),
    [anon_sym_bind] = ACTIONS(4844),
    [anon_sym_rand] = ACTIONS(4844),
    [anon_sym_const] = ACTIONS(4844),
    [anon_sym_function] = ACTIONS(4844),
    [anon_sym_static] = ACTIONS(4844),
    [anon_sym_constraint] = ACTIONS(4844),
    [anon_sym_if] = ACTIONS(4844),
    [anon_sym_else] = ACTIONS(4844),
    [anon_sym_LBRACK] = ACTIONS(4842),
    [anon_sym_localparam] = ACTIONS(4844),
    [anon_sym_parameter] = ACTIONS(4844),
    [anon_sym_var] = ACTIONS(4844),
    [anon_sym_import] = ACTIONS(4844),
    [anon_sym_export] = ACTIONS(4844),
    [anon_sym_genvar] = ACTIONS(4844),
    [anon_sym_interconnect] = ACTIONS(4844),
    [anon_sym_typedef] = ACTIONS(4844),
    [anon_sym_enum] = ACTIONS(4844),
    [anon_sym_struct] = ACTIONS(4844),
    [anon_sym_union] = ACTIONS(4844),
    [anon_sym_nettype] = ACTIONS(4844),
    [anon_sym_automatic] = ACTIONS(4844),
    [anon_sym_string] = ACTIONS(4844),
    [anon_sym_chandle] = ACTIONS(4844),
    [anon_sym_event] = ACTIONS(4844),
    [anon_sym_byte] = ACTIONS(4844),
    [anon_sym_shortint] = ACTIONS(4844),
    [anon_sym_int] = ACTIONS(4844),
    [anon_sym_longint] = ACTIONS(4844),
    [anon_sym_integer] = ACTIONS(4844),
    [anon_sym_time] = ACTIONS(4844),
    [anon_sym_bit] = ACTIONS(4844),
    [anon_sym_logic] = ACTIONS(4844),
    [anon_sym_reg] = ACTIONS(4844),
    [anon_sym_shortreal] = ACTIONS(4844),
    [anon_sym_real] = ACTIONS(4844),
    [anon_sym_realtime] = ACTIONS(4844),
    [anon_sym_supply0] = ACTIONS(4844),
    [anon_sym_supply1] = ACTIONS(4844),
    [anon_sym_signed] = ACTIONS(4844),
    [anon_sym_unsigned] = ACTIONS(4844),
    [anon_sym_task] = ACTIONS(4844),
    [anon_sym_assert] = ACTIONS(4844),
    [anon_sym_property] = ACTIONS(4844),
    [anon_sym_assume] = ACTIONS(4844),
    [anon_sym_cover] = ACTIONS(4844),
    [anon_sym_sequence] = ACTIONS(4844),
    [anon_sym_restrict] = ACTIONS(4844),
    [anon_sym_not] = ACTIONS(4844),
    [anon_sym_or] = ACTIONS(4844),
    [anon_sym_and] = ACTIONS(4844),
    [anon_sym_case] = ACTIONS(4844),
    [anon_sym_always] = ACTIONS(4844),
    [anon_sym_covergroup] = ACTIONS(4844),
    [anon_sym_let] = ACTIONS(4844),
    [anon_sym_pulldown] = ACTIONS(4844),
    [anon_sym_pullup] = ACTIONS(4844),
    [anon_sym_cmos] = ACTIONS(4844),
    [anon_sym_rcmos] = ACTIONS(4844),
    [anon_sym_bufif0] = ACTIONS(4844),
    [anon_sym_bufif1] = ACTIONS(4844),
    [anon_sym_notif0] = ACTIONS(4844),
    [anon_sym_notif1] = ACTIONS(4844),
    [anon_sym_nmos] = ACTIONS(4844),
    [anon_sym_pmos] = ACTIONS(4844),
    [anon_sym_rnmos] = ACTIONS(4844),
    [anon_sym_rpmos] = ACTIONS(4844),
    [anon_sym_nand] = ACTIONS(4844),
    [anon_sym_nor] = ACTIONS(4844),
    [anon_sym_xor] = ACTIONS(4844),
    [anon_sym_xnor] = ACTIONS(4844),
    [anon_sym_buf] = ACTIONS(4844),
    [anon_sym_tranif0] = ACTIONS(4844),
    [anon_sym_tranif1] = ACTIONS(4844),
    [anon_sym_rtranif1] = ACTIONS(4844),
    [anon_sym_rtranif0] = ACTIONS(4844),
    [anon_sym_tran] = ACTIONS(4844),
    [anon_sym_rtran] = ACTIONS(4844),
    [anon_sym_generate] = ACTIONS(4844),
    [anon_sym_endgenerate] = ACTIONS(4844),
    [anon_sym_for] = ACTIONS(4844),
    [anon_sym_initial] = ACTIONS(4844),
    [anon_sym_assign] = ACTIONS(4844),
    [anon_sym_alias] = ACTIONS(4844),
    [anon_sym_always_comb] = ACTIONS(4844),
    [anon_sym_always_latch] = ACTIONS(4844),
    [anon_sym_always_ff] = ACTIONS(4844),
    [anon_sym_final] = ACTIONS(4844),
    [anon_sym_global] = ACTIONS(4844),
    [anon_sym_LPAREN_STAR] = ACTIONS(4842),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4842),
    [anon_sym_DOLLARunit] = ACTIONS(4842),
  },
  [5188] = {
    [sym_simple_identifier] = ACTIONS(6389),
    [anon_sym_wire] = ACTIONS(6389),
    [anon_sym_tri] = ACTIONS(6389),
    [anon_sym_tri0] = ACTIONS(6389),
    [anon_sym_tri1] = ACTIONS(6389),
    [anon_sym_wand] = ACTIONS(6389),
    [anon_sym_triand] = ACTIONS(6389),
    [anon_sym_wor] = ACTIONS(6389),
    [anon_sym_trior] = ACTIONS(6389),
    [anon_sym_trireg] = ACTIONS(6389),
    [anon_sym_uwire] = ACTIONS(6389),
    [anon_sym_SEMI] = ACTIONS(6391),
    [anon_sym_extern] = ACTIONS(6389),
    [anon_sym_interface] = ACTIONS(6389),
    [anon_sym_checker] = ACTIONS(6389),
    [anon_sym_virtual] = ACTIONS(6389),
    [anon_sym_class] = ACTIONS(6389),
    [anon_sym_type] = ACTIONS(6389),
    [anon_sym_DOLLARfatal] = ACTIONS(6391),
    [anon_sym_DOLLARerror] = ACTIONS(6391),
    [anon_sym_DOLLARwarning] = ACTIONS(6391),
    [anon_sym_DOLLARinfo] = ACTIONS(6391),
    [anon_sym_default] = ACTIONS(6389),
    [anon_sym_clocking] = ACTIONS(6389),
    [anon_sym_defparam] = ACTIONS(6389),
    [anon_sym_bind] = ACTIONS(6389),
    [anon_sym_rand] = ACTIONS(6389),
    [anon_sym_const] = ACTIONS(6389),
    [anon_sym_function] = ACTIONS(6389),
    [anon_sym_static] = ACTIONS(6389),
    [anon_sym_constraint] = ACTIONS(6389),
    [anon_sym_if] = ACTIONS(6389),
    [anon_sym_else] = ACTIONS(6389),
    [anon_sym_LBRACK] = ACTIONS(6391),
    [anon_sym_localparam] = ACTIONS(6389),
    [anon_sym_parameter] = ACTIONS(6389),
    [anon_sym_var] = ACTIONS(6389),
    [anon_sym_import] = ACTIONS(6389),
    [anon_sym_export] = ACTIONS(6389),
    [anon_sym_genvar] = ACTIONS(6389),
    [anon_sym_interconnect] = ACTIONS(6389),
    [anon_sym_typedef] = ACTIONS(6389),
    [anon_sym_enum] = ACTIONS(6389),
    [anon_sym_struct] = ACTIONS(6389),
    [anon_sym_union] = ACTIONS(6389),
    [anon_sym_nettype] = ACTIONS(6389),
    [anon_sym_automatic] = ACTIONS(6389),
    [anon_sym_string] = ACTIONS(6389),
    [anon_sym_chandle] = ACTIONS(6389),
    [anon_sym_event] = ACTIONS(6389),
    [anon_sym_byte] = ACTIONS(6389),
    [anon_sym_shortint] = ACTIONS(6389),
    [anon_sym_int] = ACTIONS(6389),
    [anon_sym_longint] = ACTIONS(6389),
    [anon_sym_integer] = ACTIONS(6389),
    [anon_sym_time] = ACTIONS(6389),
    [anon_sym_bit] = ACTIONS(6389),
    [anon_sym_logic] = ACTIONS(6389),
    [anon_sym_reg] = ACTIONS(6389),
    [anon_sym_shortreal] = ACTIONS(6389),
    [anon_sym_real] = ACTIONS(6389),
    [anon_sym_realtime] = ACTIONS(6389),
    [anon_sym_supply0] = ACTIONS(6389),
    [anon_sym_supply1] = ACTIONS(6389),
    [anon_sym_signed] = ACTIONS(6389),
    [anon_sym_unsigned] = ACTIONS(6389),
    [anon_sym_task] = ACTIONS(6389),
    [anon_sym_assert] = ACTIONS(6389),
    [anon_sym_property] = ACTIONS(6389),
    [anon_sym_assume] = ACTIONS(6389),
    [anon_sym_cover] = ACTIONS(6389),
    [anon_sym_sequence] = ACTIONS(6389),
    [anon_sym_restrict] = ACTIONS(6389),
    [anon_sym_not] = ACTIONS(6389),
    [anon_sym_or] = ACTIONS(6389),
    [anon_sym_and] = ACTIONS(6389),
    [anon_sym_case] = ACTIONS(6389),
    [anon_sym_always] = ACTIONS(6389),
    [anon_sym_covergroup] = ACTIONS(6389),
    [anon_sym_end] = ACTIONS(6389),
    [anon_sym_let] = ACTIONS(6389),
    [anon_sym_pulldown] = ACTIONS(6389),
    [anon_sym_pullup] = ACTIONS(6389),
    [anon_sym_cmos] = ACTIONS(6389),
    [anon_sym_rcmos] = ACTIONS(6389),
    [anon_sym_bufif0] = ACTIONS(6389),
    [anon_sym_bufif1] = ACTIONS(6389),
    [anon_sym_notif0] = ACTIONS(6389),
    [anon_sym_notif1] = ACTIONS(6389),
    [anon_sym_nmos] = ACTIONS(6389),
    [anon_sym_pmos] = ACTIONS(6389),
    [anon_sym_rnmos] = ACTIONS(6389),
    [anon_sym_rpmos] = ACTIONS(6389),
    [anon_sym_nand] = ACTIONS(6389),
    [anon_sym_nor] = ACTIONS(6389),
    [anon_sym_xor] = ACTIONS(6389),
    [anon_sym_xnor] = ACTIONS(6389),
    [anon_sym_buf] = ACTIONS(6389),
    [anon_sym_tranif0] = ACTIONS(6389),
    [anon_sym_tranif1] = ACTIONS(6389),
    [anon_sym_rtranif1] = ACTIONS(6389),
    [anon_sym_rtranif0] = ACTIONS(6389),
    [anon_sym_tran] = ACTIONS(6389),
    [anon_sym_rtran] = ACTIONS(6389),
    [anon_sym_generate] = ACTIONS(6389),
    [anon_sym_for] = ACTIONS(6389),
    [anon_sym_initial] = ACTIONS(6389),
    [anon_sym_assign] = ACTIONS(6389),
    [anon_sym_alias] = ACTIONS(6389),
    [anon_sym_always_comb] = ACTIONS(6389),
    [anon_sym_always_latch] = ACTIONS(6389),
    [anon_sym_always_ff] = ACTIONS(6389),
    [anon_sym_final] = ACTIONS(6389),
    [anon_sym_global] = ACTIONS(6389),
    [anon_sym_LPAREN_STAR] = ACTIONS(6391),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6391),
    [anon_sym_DOLLARunit] = ACTIONS(6391),
  },
  [5189] = {
    [sym_simple_identifier] = ACTIONS(5892),
    [anon_sym_wire] = ACTIONS(5892),
    [anon_sym_tri] = ACTIONS(5892),
    [anon_sym_tri0] = ACTIONS(5892),
    [anon_sym_tri1] = ACTIONS(5892),
    [anon_sym_wand] = ACTIONS(5892),
    [anon_sym_triand] = ACTIONS(5892),
    [anon_sym_wor] = ACTIONS(5892),
    [anon_sym_trior] = ACTIONS(5892),
    [anon_sym_trireg] = ACTIONS(5892),
    [anon_sym_uwire] = ACTIONS(5892),
    [anon_sym_SEMI] = ACTIONS(5894),
    [anon_sym_extern] = ACTIONS(5892),
    [anon_sym_interface] = ACTIONS(5892),
    [anon_sym_checker] = ACTIONS(5892),
    [anon_sym_virtual] = ACTIONS(5892),
    [anon_sym_class] = ACTIONS(5892),
    [anon_sym_type] = ACTIONS(5892),
    [anon_sym_DOLLARfatal] = ACTIONS(5894),
    [anon_sym_DOLLARerror] = ACTIONS(5894),
    [anon_sym_DOLLARwarning] = ACTIONS(5894),
    [anon_sym_DOLLARinfo] = ACTIONS(5894),
    [anon_sym_default] = ACTIONS(5892),
    [anon_sym_clocking] = ACTIONS(5892),
    [anon_sym_defparam] = ACTIONS(5892),
    [anon_sym_bind] = ACTIONS(5892),
    [anon_sym_rand] = ACTIONS(5892),
    [anon_sym_const] = ACTIONS(5892),
    [anon_sym_function] = ACTIONS(5892),
    [anon_sym_static] = ACTIONS(5892),
    [anon_sym_constraint] = ACTIONS(5892),
    [anon_sym_if] = ACTIONS(5892),
    [anon_sym_else] = ACTIONS(5892),
    [anon_sym_LBRACK] = ACTIONS(5894),
    [anon_sym_localparam] = ACTIONS(5892),
    [anon_sym_parameter] = ACTIONS(5892),
    [anon_sym_var] = ACTIONS(5892),
    [anon_sym_import] = ACTIONS(5892),
    [anon_sym_export] = ACTIONS(5892),
    [anon_sym_genvar] = ACTIONS(5892),
    [anon_sym_interconnect] = ACTIONS(5892),
    [anon_sym_typedef] = ACTIONS(5892),
    [anon_sym_enum] = ACTIONS(5892),
    [anon_sym_struct] = ACTIONS(5892),
    [anon_sym_union] = ACTIONS(5892),
    [anon_sym_nettype] = ACTIONS(5892),
    [anon_sym_automatic] = ACTIONS(5892),
    [anon_sym_string] = ACTIONS(5892),
    [anon_sym_chandle] = ACTIONS(5892),
    [anon_sym_event] = ACTIONS(5892),
    [anon_sym_byte] = ACTIONS(5892),
    [anon_sym_shortint] = ACTIONS(5892),
    [anon_sym_int] = ACTIONS(5892),
    [anon_sym_longint] = ACTIONS(5892),
    [anon_sym_integer] = ACTIONS(5892),
    [anon_sym_time] = ACTIONS(5892),
    [anon_sym_bit] = ACTIONS(5892),
    [anon_sym_logic] = ACTIONS(5892),
    [anon_sym_reg] = ACTIONS(5892),
    [anon_sym_shortreal] = ACTIONS(5892),
    [anon_sym_real] = ACTIONS(5892),
    [anon_sym_realtime] = ACTIONS(5892),
    [anon_sym_supply0] = ACTIONS(5892),
    [anon_sym_supply1] = ACTIONS(5892),
    [anon_sym_signed] = ACTIONS(5892),
    [anon_sym_unsigned] = ACTIONS(5892),
    [anon_sym_task] = ACTIONS(5892),
    [anon_sym_assert] = ACTIONS(5892),
    [anon_sym_property] = ACTIONS(5892),
    [anon_sym_assume] = ACTIONS(5892),
    [anon_sym_cover] = ACTIONS(5892),
    [anon_sym_sequence] = ACTIONS(5892),
    [anon_sym_restrict] = ACTIONS(5892),
    [anon_sym_not] = ACTIONS(5892),
    [anon_sym_or] = ACTIONS(5892),
    [anon_sym_and] = ACTIONS(5892),
    [anon_sym_case] = ACTIONS(5892),
    [anon_sym_always] = ACTIONS(5892),
    [anon_sym_covergroup] = ACTIONS(5892),
    [anon_sym_end] = ACTIONS(5892),
    [anon_sym_let] = ACTIONS(5892),
    [anon_sym_pulldown] = ACTIONS(5892),
    [anon_sym_pullup] = ACTIONS(5892),
    [anon_sym_cmos] = ACTIONS(5892),
    [anon_sym_rcmos] = ACTIONS(5892),
    [anon_sym_bufif0] = ACTIONS(5892),
    [anon_sym_bufif1] = ACTIONS(5892),
    [anon_sym_notif0] = ACTIONS(5892),
    [anon_sym_notif1] = ACTIONS(5892),
    [anon_sym_nmos] = ACTIONS(5892),
    [anon_sym_pmos] = ACTIONS(5892),
    [anon_sym_rnmos] = ACTIONS(5892),
    [anon_sym_rpmos] = ACTIONS(5892),
    [anon_sym_nand] = ACTIONS(5892),
    [anon_sym_nor] = ACTIONS(5892),
    [anon_sym_xor] = ACTIONS(5892),
    [anon_sym_xnor] = ACTIONS(5892),
    [anon_sym_buf] = ACTIONS(5892),
    [anon_sym_tranif0] = ACTIONS(5892),
    [anon_sym_tranif1] = ACTIONS(5892),
    [anon_sym_rtranif1] = ACTIONS(5892),
    [anon_sym_rtranif0] = ACTIONS(5892),
    [anon_sym_tran] = ACTIONS(5892),
    [anon_sym_rtran] = ACTIONS(5892),
    [anon_sym_generate] = ACTIONS(5892),
    [anon_sym_for] = ACTIONS(5892),
    [anon_sym_initial] = ACTIONS(5892),
    [anon_sym_assign] = ACTIONS(5892),
    [anon_sym_alias] = ACTIONS(5892),
    [anon_sym_always_comb] = ACTIONS(5892),
    [anon_sym_always_latch] = ACTIONS(5892),
    [anon_sym_always_ff] = ACTIONS(5892),
    [anon_sym_final] = ACTIONS(5892),
    [anon_sym_global] = ACTIONS(5892),
    [anon_sym_LPAREN_STAR] = ACTIONS(5894),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5894),
    [anon_sym_DOLLARunit] = ACTIONS(5894),
  },
  [5190] = {
    [sym_simple_identifier] = ACTIONS(6421),
    [anon_sym_wire] = ACTIONS(6421),
    [anon_sym_tri] = ACTIONS(6421),
    [anon_sym_tri0] = ACTIONS(6421),
    [anon_sym_tri1] = ACTIONS(6421),
    [anon_sym_wand] = ACTIONS(6421),
    [anon_sym_triand] = ACTIONS(6421),
    [anon_sym_wor] = ACTIONS(6421),
    [anon_sym_trior] = ACTIONS(6421),
    [anon_sym_trireg] = ACTIONS(6421),
    [anon_sym_uwire] = ACTIONS(6421),
    [anon_sym_SEMI] = ACTIONS(6423),
    [anon_sym_extern] = ACTIONS(6421),
    [anon_sym_interface] = ACTIONS(6421),
    [anon_sym_checker] = ACTIONS(6421),
    [anon_sym_virtual] = ACTIONS(6421),
    [anon_sym_class] = ACTIONS(6421),
    [anon_sym_type] = ACTIONS(6421),
    [anon_sym_DOLLARfatal] = ACTIONS(6423),
    [anon_sym_DOLLARerror] = ACTIONS(6423),
    [anon_sym_DOLLARwarning] = ACTIONS(6423),
    [anon_sym_DOLLARinfo] = ACTIONS(6423),
    [anon_sym_default] = ACTIONS(6421),
    [anon_sym_clocking] = ACTIONS(6421),
    [anon_sym_defparam] = ACTIONS(6421),
    [anon_sym_bind] = ACTIONS(6421),
    [anon_sym_rand] = ACTIONS(6421),
    [anon_sym_const] = ACTIONS(6421),
    [anon_sym_function] = ACTIONS(6421),
    [anon_sym_static] = ACTIONS(6421),
    [anon_sym_constraint] = ACTIONS(6421),
    [anon_sym_if] = ACTIONS(6421),
    [anon_sym_else] = ACTIONS(6421),
    [anon_sym_LBRACK] = ACTIONS(6423),
    [anon_sym_localparam] = ACTIONS(6421),
    [anon_sym_parameter] = ACTIONS(6421),
    [anon_sym_var] = ACTIONS(6421),
    [anon_sym_import] = ACTIONS(6421),
    [anon_sym_export] = ACTIONS(6421),
    [anon_sym_genvar] = ACTIONS(6421),
    [anon_sym_interconnect] = ACTIONS(6421),
    [anon_sym_typedef] = ACTIONS(6421),
    [anon_sym_enum] = ACTIONS(6421),
    [anon_sym_struct] = ACTIONS(6421),
    [anon_sym_union] = ACTIONS(6421),
    [anon_sym_nettype] = ACTIONS(6421),
    [anon_sym_automatic] = ACTIONS(6421),
    [anon_sym_string] = ACTIONS(6421),
    [anon_sym_chandle] = ACTIONS(6421),
    [anon_sym_event] = ACTIONS(6421),
    [anon_sym_byte] = ACTIONS(6421),
    [anon_sym_shortint] = ACTIONS(6421),
    [anon_sym_int] = ACTIONS(6421),
    [anon_sym_longint] = ACTIONS(6421),
    [anon_sym_integer] = ACTIONS(6421),
    [anon_sym_time] = ACTIONS(6421),
    [anon_sym_bit] = ACTIONS(6421),
    [anon_sym_logic] = ACTIONS(6421),
    [anon_sym_reg] = ACTIONS(6421),
    [anon_sym_shortreal] = ACTIONS(6421),
    [anon_sym_real] = ACTIONS(6421),
    [anon_sym_realtime] = ACTIONS(6421),
    [anon_sym_supply0] = ACTIONS(6421),
    [anon_sym_supply1] = ACTIONS(6421),
    [anon_sym_signed] = ACTIONS(6421),
    [anon_sym_unsigned] = ACTIONS(6421),
    [anon_sym_task] = ACTIONS(6421),
    [anon_sym_assert] = ACTIONS(6421),
    [anon_sym_property] = ACTIONS(6421),
    [anon_sym_assume] = ACTIONS(6421),
    [anon_sym_cover] = ACTIONS(6421),
    [anon_sym_sequence] = ACTIONS(6421),
    [anon_sym_restrict] = ACTIONS(6421),
    [anon_sym_not] = ACTIONS(6421),
    [anon_sym_or] = ACTIONS(6421),
    [anon_sym_and] = ACTIONS(6421),
    [anon_sym_case] = ACTIONS(6421),
    [anon_sym_always] = ACTIONS(6421),
    [anon_sym_covergroup] = ACTIONS(6421),
    [anon_sym_end] = ACTIONS(6421),
    [anon_sym_let] = ACTIONS(6421),
    [anon_sym_pulldown] = ACTIONS(6421),
    [anon_sym_pullup] = ACTIONS(6421),
    [anon_sym_cmos] = ACTIONS(6421),
    [anon_sym_rcmos] = ACTIONS(6421),
    [anon_sym_bufif0] = ACTIONS(6421),
    [anon_sym_bufif1] = ACTIONS(6421),
    [anon_sym_notif0] = ACTIONS(6421),
    [anon_sym_notif1] = ACTIONS(6421),
    [anon_sym_nmos] = ACTIONS(6421),
    [anon_sym_pmos] = ACTIONS(6421),
    [anon_sym_rnmos] = ACTIONS(6421),
    [anon_sym_rpmos] = ACTIONS(6421),
    [anon_sym_nand] = ACTIONS(6421),
    [anon_sym_nor] = ACTIONS(6421),
    [anon_sym_xor] = ACTIONS(6421),
    [anon_sym_xnor] = ACTIONS(6421),
    [anon_sym_buf] = ACTIONS(6421),
    [anon_sym_tranif0] = ACTIONS(6421),
    [anon_sym_tranif1] = ACTIONS(6421),
    [anon_sym_rtranif1] = ACTIONS(6421),
    [anon_sym_rtranif0] = ACTIONS(6421),
    [anon_sym_tran] = ACTIONS(6421),
    [anon_sym_rtran] = ACTIONS(6421),
    [anon_sym_generate] = ACTIONS(6421),
    [anon_sym_for] = ACTIONS(6421),
    [anon_sym_initial] = ACTIONS(6421),
    [anon_sym_assign] = ACTIONS(6421),
    [anon_sym_alias] = ACTIONS(6421),
    [anon_sym_always_comb] = ACTIONS(6421),
    [anon_sym_always_latch] = ACTIONS(6421),
    [anon_sym_always_ff] = ACTIONS(6421),
    [anon_sym_final] = ACTIONS(6421),
    [anon_sym_global] = ACTIONS(6421),
    [anon_sym_LPAREN_STAR] = ACTIONS(6423),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6423),
    [anon_sym_DOLLARunit] = ACTIONS(6423),
  },
  [5191] = {
    [sym_simple_identifier] = ACTIONS(6789),
    [anon_sym_wire] = ACTIONS(6789),
    [anon_sym_tri] = ACTIONS(6789),
    [anon_sym_tri0] = ACTIONS(6789),
    [anon_sym_tri1] = ACTIONS(6789),
    [anon_sym_wand] = ACTIONS(6789),
    [anon_sym_triand] = ACTIONS(6789),
    [anon_sym_wor] = ACTIONS(6789),
    [anon_sym_trior] = ACTIONS(6789),
    [anon_sym_trireg] = ACTIONS(6789),
    [anon_sym_uwire] = ACTIONS(6789),
    [anon_sym_SEMI] = ACTIONS(6791),
    [anon_sym_extern] = ACTIONS(6789),
    [anon_sym_interface] = ACTIONS(6789),
    [anon_sym_checker] = ACTIONS(6789),
    [anon_sym_virtual] = ACTIONS(6789),
    [anon_sym_class] = ACTIONS(6789),
    [anon_sym_type] = ACTIONS(6789),
    [anon_sym_DOLLARfatal] = ACTIONS(6791),
    [anon_sym_DOLLARerror] = ACTIONS(6791),
    [anon_sym_DOLLARwarning] = ACTIONS(6791),
    [anon_sym_DOLLARinfo] = ACTIONS(6791),
    [anon_sym_default] = ACTIONS(6789),
    [anon_sym_clocking] = ACTIONS(6789),
    [anon_sym_defparam] = ACTIONS(6789),
    [anon_sym_bind] = ACTIONS(6789),
    [anon_sym_rand] = ACTIONS(6789),
    [anon_sym_const] = ACTIONS(6789),
    [anon_sym_function] = ACTIONS(6789),
    [anon_sym_static] = ACTIONS(6789),
    [anon_sym_constraint] = ACTIONS(6789),
    [anon_sym_if] = ACTIONS(6789),
    [anon_sym_else] = ACTIONS(6789),
    [anon_sym_LBRACK] = ACTIONS(6791),
    [anon_sym_localparam] = ACTIONS(6789),
    [anon_sym_parameter] = ACTIONS(6789),
    [anon_sym_var] = ACTIONS(6789),
    [anon_sym_import] = ACTIONS(6789),
    [anon_sym_export] = ACTIONS(6789),
    [anon_sym_genvar] = ACTIONS(6789),
    [anon_sym_interconnect] = ACTIONS(6789),
    [anon_sym_typedef] = ACTIONS(6789),
    [anon_sym_enum] = ACTIONS(6789),
    [anon_sym_struct] = ACTIONS(6789),
    [anon_sym_union] = ACTIONS(6789),
    [anon_sym_nettype] = ACTIONS(6789),
    [anon_sym_automatic] = ACTIONS(6789),
    [anon_sym_string] = ACTIONS(6789),
    [anon_sym_chandle] = ACTIONS(6789),
    [anon_sym_event] = ACTIONS(6789),
    [anon_sym_byte] = ACTIONS(6789),
    [anon_sym_shortint] = ACTIONS(6789),
    [anon_sym_int] = ACTIONS(6789),
    [anon_sym_longint] = ACTIONS(6789),
    [anon_sym_integer] = ACTIONS(6789),
    [anon_sym_time] = ACTIONS(6789),
    [anon_sym_bit] = ACTIONS(6789),
    [anon_sym_logic] = ACTIONS(6789),
    [anon_sym_reg] = ACTIONS(6789),
    [anon_sym_shortreal] = ACTIONS(6789),
    [anon_sym_real] = ACTIONS(6789),
    [anon_sym_realtime] = ACTIONS(6789),
    [anon_sym_supply0] = ACTIONS(6789),
    [anon_sym_supply1] = ACTIONS(6789),
    [anon_sym_signed] = ACTIONS(6789),
    [anon_sym_unsigned] = ACTIONS(6789),
    [anon_sym_task] = ACTIONS(6789),
    [anon_sym_assert] = ACTIONS(6789),
    [anon_sym_property] = ACTIONS(6789),
    [anon_sym_assume] = ACTIONS(6789),
    [anon_sym_cover] = ACTIONS(6789),
    [anon_sym_sequence] = ACTIONS(6789),
    [anon_sym_restrict] = ACTIONS(6789),
    [anon_sym_not] = ACTIONS(6789),
    [anon_sym_or] = ACTIONS(6789),
    [anon_sym_and] = ACTIONS(6789),
    [anon_sym_case] = ACTIONS(6789),
    [anon_sym_always] = ACTIONS(6789),
    [anon_sym_covergroup] = ACTIONS(6789),
    [anon_sym_let] = ACTIONS(6789),
    [anon_sym_pulldown] = ACTIONS(6789),
    [anon_sym_pullup] = ACTIONS(6789),
    [anon_sym_cmos] = ACTIONS(6789),
    [anon_sym_rcmos] = ACTIONS(6789),
    [anon_sym_bufif0] = ACTIONS(6789),
    [anon_sym_bufif1] = ACTIONS(6789),
    [anon_sym_notif0] = ACTIONS(6789),
    [anon_sym_notif1] = ACTIONS(6789),
    [anon_sym_nmos] = ACTIONS(6789),
    [anon_sym_pmos] = ACTIONS(6789),
    [anon_sym_rnmos] = ACTIONS(6789),
    [anon_sym_rpmos] = ACTIONS(6789),
    [anon_sym_nand] = ACTIONS(6789),
    [anon_sym_nor] = ACTIONS(6789),
    [anon_sym_xor] = ACTIONS(6789),
    [anon_sym_xnor] = ACTIONS(6789),
    [anon_sym_buf] = ACTIONS(6789),
    [anon_sym_tranif0] = ACTIONS(6789),
    [anon_sym_tranif1] = ACTIONS(6789),
    [anon_sym_rtranif1] = ACTIONS(6789),
    [anon_sym_rtranif0] = ACTIONS(6789),
    [anon_sym_tran] = ACTIONS(6789),
    [anon_sym_rtran] = ACTIONS(6789),
    [anon_sym_generate] = ACTIONS(6789),
    [anon_sym_endgenerate] = ACTIONS(6789),
    [anon_sym_for] = ACTIONS(6789),
    [anon_sym_initial] = ACTIONS(6789),
    [anon_sym_assign] = ACTIONS(6789),
    [anon_sym_alias] = ACTIONS(6789),
    [anon_sym_always_comb] = ACTIONS(6789),
    [anon_sym_always_latch] = ACTIONS(6789),
    [anon_sym_always_ff] = ACTIONS(6789),
    [anon_sym_final] = ACTIONS(6789),
    [anon_sym_global] = ACTIONS(6789),
    [anon_sym_LPAREN_STAR] = ACTIONS(6791),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6791),
    [anon_sym_DOLLARunit] = ACTIONS(6791),
  },
  [5192] = {
    [sym_simple_identifier] = ACTIONS(6421),
    [anon_sym_wire] = ACTIONS(6421),
    [anon_sym_tri] = ACTIONS(6421),
    [anon_sym_tri0] = ACTIONS(6421),
    [anon_sym_tri1] = ACTIONS(6421),
    [anon_sym_wand] = ACTIONS(6421),
    [anon_sym_triand] = ACTIONS(6421),
    [anon_sym_wor] = ACTIONS(6421),
    [anon_sym_trior] = ACTIONS(6421),
    [anon_sym_trireg] = ACTIONS(6421),
    [anon_sym_uwire] = ACTIONS(6421),
    [anon_sym_SEMI] = ACTIONS(6423),
    [anon_sym_extern] = ACTIONS(6421),
    [anon_sym_interface] = ACTIONS(6421),
    [anon_sym_checker] = ACTIONS(6421),
    [anon_sym_virtual] = ACTIONS(6421),
    [anon_sym_class] = ACTIONS(6421),
    [anon_sym_type] = ACTIONS(6421),
    [anon_sym_DOLLARfatal] = ACTIONS(6423),
    [anon_sym_DOLLARerror] = ACTIONS(6423),
    [anon_sym_DOLLARwarning] = ACTIONS(6423),
    [anon_sym_DOLLARinfo] = ACTIONS(6423),
    [anon_sym_default] = ACTIONS(6421),
    [anon_sym_clocking] = ACTIONS(6421),
    [anon_sym_defparam] = ACTIONS(6421),
    [anon_sym_bind] = ACTIONS(6421),
    [anon_sym_rand] = ACTIONS(6421),
    [anon_sym_const] = ACTIONS(6421),
    [anon_sym_function] = ACTIONS(6421),
    [anon_sym_static] = ACTIONS(6421),
    [anon_sym_constraint] = ACTIONS(6421),
    [anon_sym_if] = ACTIONS(6421),
    [anon_sym_else] = ACTIONS(6421),
    [anon_sym_LBRACK] = ACTIONS(6423),
    [anon_sym_localparam] = ACTIONS(6421),
    [anon_sym_parameter] = ACTIONS(6421),
    [anon_sym_var] = ACTIONS(6421),
    [anon_sym_import] = ACTIONS(6421),
    [anon_sym_export] = ACTIONS(6421),
    [anon_sym_genvar] = ACTIONS(6421),
    [anon_sym_interconnect] = ACTIONS(6421),
    [anon_sym_typedef] = ACTIONS(6421),
    [anon_sym_enum] = ACTIONS(6421),
    [anon_sym_struct] = ACTIONS(6421),
    [anon_sym_union] = ACTIONS(6421),
    [anon_sym_nettype] = ACTIONS(6421),
    [anon_sym_automatic] = ACTIONS(6421),
    [anon_sym_string] = ACTIONS(6421),
    [anon_sym_chandle] = ACTIONS(6421),
    [anon_sym_event] = ACTIONS(6421),
    [anon_sym_byte] = ACTIONS(6421),
    [anon_sym_shortint] = ACTIONS(6421),
    [anon_sym_int] = ACTIONS(6421),
    [anon_sym_longint] = ACTIONS(6421),
    [anon_sym_integer] = ACTIONS(6421),
    [anon_sym_time] = ACTIONS(6421),
    [anon_sym_bit] = ACTIONS(6421),
    [anon_sym_logic] = ACTIONS(6421),
    [anon_sym_reg] = ACTIONS(6421),
    [anon_sym_shortreal] = ACTIONS(6421),
    [anon_sym_real] = ACTIONS(6421),
    [anon_sym_realtime] = ACTIONS(6421),
    [anon_sym_supply0] = ACTIONS(6421),
    [anon_sym_supply1] = ACTIONS(6421),
    [anon_sym_signed] = ACTIONS(6421),
    [anon_sym_unsigned] = ACTIONS(6421),
    [anon_sym_task] = ACTIONS(6421),
    [anon_sym_assert] = ACTIONS(6421),
    [anon_sym_property] = ACTIONS(6421),
    [anon_sym_assume] = ACTIONS(6421),
    [anon_sym_cover] = ACTIONS(6421),
    [anon_sym_sequence] = ACTIONS(6421),
    [anon_sym_restrict] = ACTIONS(6421),
    [anon_sym_not] = ACTIONS(6421),
    [anon_sym_or] = ACTIONS(6421),
    [anon_sym_and] = ACTIONS(6421),
    [anon_sym_case] = ACTIONS(6421),
    [anon_sym_always] = ACTIONS(6421),
    [anon_sym_covergroup] = ACTIONS(6421),
    [anon_sym_let] = ACTIONS(6421),
    [anon_sym_pulldown] = ACTIONS(6421),
    [anon_sym_pullup] = ACTIONS(6421),
    [anon_sym_cmos] = ACTIONS(6421),
    [anon_sym_rcmos] = ACTIONS(6421),
    [anon_sym_bufif0] = ACTIONS(6421),
    [anon_sym_bufif1] = ACTIONS(6421),
    [anon_sym_notif0] = ACTIONS(6421),
    [anon_sym_notif1] = ACTIONS(6421),
    [anon_sym_nmos] = ACTIONS(6421),
    [anon_sym_pmos] = ACTIONS(6421),
    [anon_sym_rnmos] = ACTIONS(6421),
    [anon_sym_rpmos] = ACTIONS(6421),
    [anon_sym_nand] = ACTIONS(6421),
    [anon_sym_nor] = ACTIONS(6421),
    [anon_sym_xor] = ACTIONS(6421),
    [anon_sym_xnor] = ACTIONS(6421),
    [anon_sym_buf] = ACTIONS(6421),
    [anon_sym_tranif0] = ACTIONS(6421),
    [anon_sym_tranif1] = ACTIONS(6421),
    [anon_sym_rtranif1] = ACTIONS(6421),
    [anon_sym_rtranif0] = ACTIONS(6421),
    [anon_sym_tran] = ACTIONS(6421),
    [anon_sym_rtran] = ACTIONS(6421),
    [anon_sym_generate] = ACTIONS(6421),
    [anon_sym_endgenerate] = ACTIONS(6421),
    [anon_sym_for] = ACTIONS(6421),
    [anon_sym_initial] = ACTIONS(6421),
    [anon_sym_assign] = ACTIONS(6421),
    [anon_sym_alias] = ACTIONS(6421),
    [anon_sym_always_comb] = ACTIONS(6421),
    [anon_sym_always_latch] = ACTIONS(6421),
    [anon_sym_always_ff] = ACTIONS(6421),
    [anon_sym_final] = ACTIONS(6421),
    [anon_sym_global] = ACTIONS(6421),
    [anon_sym_LPAREN_STAR] = ACTIONS(6423),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6423),
    [anon_sym_DOLLARunit] = ACTIONS(6423),
  },
  [5193] = {
    [sym_simple_identifier] = ACTIONS(4944),
    [anon_sym_wire] = ACTIONS(4944),
    [anon_sym_tri] = ACTIONS(4944),
    [anon_sym_tri0] = ACTIONS(4944),
    [anon_sym_tri1] = ACTIONS(4944),
    [anon_sym_wand] = ACTIONS(4944),
    [anon_sym_triand] = ACTIONS(4944),
    [anon_sym_wor] = ACTIONS(4944),
    [anon_sym_trior] = ACTIONS(4944),
    [anon_sym_trireg] = ACTIONS(4944),
    [anon_sym_uwire] = ACTIONS(4944),
    [anon_sym_SEMI] = ACTIONS(4942),
    [anon_sym_extern] = ACTIONS(4944),
    [anon_sym_interface] = ACTIONS(4944),
    [anon_sym_checker] = ACTIONS(4944),
    [anon_sym_virtual] = ACTIONS(4944),
    [anon_sym_class] = ACTIONS(4944),
    [anon_sym_type] = ACTIONS(4944),
    [anon_sym_DOLLARfatal] = ACTIONS(4942),
    [anon_sym_DOLLARerror] = ACTIONS(4942),
    [anon_sym_DOLLARwarning] = ACTIONS(4942),
    [anon_sym_DOLLARinfo] = ACTIONS(4942),
    [anon_sym_default] = ACTIONS(4944),
    [anon_sym_clocking] = ACTIONS(4944),
    [anon_sym_defparam] = ACTIONS(4944),
    [anon_sym_bind] = ACTIONS(4944),
    [anon_sym_rand] = ACTIONS(4944),
    [anon_sym_const] = ACTIONS(4944),
    [anon_sym_function] = ACTIONS(4944),
    [anon_sym_static] = ACTIONS(4944),
    [anon_sym_constraint] = ACTIONS(4944),
    [anon_sym_if] = ACTIONS(4944),
    [anon_sym_else] = ACTIONS(4944),
    [anon_sym_LBRACK] = ACTIONS(4942),
    [anon_sym_localparam] = ACTIONS(4944),
    [anon_sym_parameter] = ACTIONS(4944),
    [anon_sym_var] = ACTIONS(4944),
    [anon_sym_import] = ACTIONS(4944),
    [anon_sym_export] = ACTIONS(4944),
    [anon_sym_genvar] = ACTIONS(4944),
    [anon_sym_interconnect] = ACTIONS(4944),
    [anon_sym_typedef] = ACTIONS(4944),
    [anon_sym_enum] = ACTIONS(4944),
    [anon_sym_struct] = ACTIONS(4944),
    [anon_sym_union] = ACTIONS(4944),
    [anon_sym_nettype] = ACTIONS(4944),
    [anon_sym_automatic] = ACTIONS(4944),
    [anon_sym_string] = ACTIONS(4944),
    [anon_sym_chandle] = ACTIONS(4944),
    [anon_sym_event] = ACTIONS(4944),
    [anon_sym_byte] = ACTIONS(4944),
    [anon_sym_shortint] = ACTIONS(4944),
    [anon_sym_int] = ACTIONS(4944),
    [anon_sym_longint] = ACTIONS(4944),
    [anon_sym_integer] = ACTIONS(4944),
    [anon_sym_time] = ACTIONS(4944),
    [anon_sym_bit] = ACTIONS(4944),
    [anon_sym_logic] = ACTIONS(4944),
    [anon_sym_reg] = ACTIONS(4944),
    [anon_sym_shortreal] = ACTIONS(4944),
    [anon_sym_real] = ACTIONS(4944),
    [anon_sym_realtime] = ACTIONS(4944),
    [anon_sym_supply0] = ACTIONS(4944),
    [anon_sym_supply1] = ACTIONS(4944),
    [anon_sym_signed] = ACTIONS(4944),
    [anon_sym_unsigned] = ACTIONS(4944),
    [anon_sym_task] = ACTIONS(4944),
    [anon_sym_assert] = ACTIONS(4944),
    [anon_sym_property] = ACTIONS(4944),
    [anon_sym_assume] = ACTIONS(4944),
    [anon_sym_cover] = ACTIONS(4944),
    [anon_sym_sequence] = ACTIONS(4944),
    [anon_sym_restrict] = ACTIONS(4944),
    [anon_sym_not] = ACTIONS(4944),
    [anon_sym_or] = ACTIONS(4944),
    [anon_sym_and] = ACTIONS(4944),
    [anon_sym_case] = ACTIONS(4944),
    [anon_sym_always] = ACTIONS(4944),
    [anon_sym_covergroup] = ACTIONS(4944),
    [anon_sym_end] = ACTIONS(4944),
    [anon_sym_let] = ACTIONS(4944),
    [anon_sym_pulldown] = ACTIONS(4944),
    [anon_sym_pullup] = ACTIONS(4944),
    [anon_sym_cmos] = ACTIONS(4944),
    [anon_sym_rcmos] = ACTIONS(4944),
    [anon_sym_bufif0] = ACTIONS(4944),
    [anon_sym_bufif1] = ACTIONS(4944),
    [anon_sym_notif0] = ACTIONS(4944),
    [anon_sym_notif1] = ACTIONS(4944),
    [anon_sym_nmos] = ACTIONS(4944),
    [anon_sym_pmos] = ACTIONS(4944),
    [anon_sym_rnmos] = ACTIONS(4944),
    [anon_sym_rpmos] = ACTIONS(4944),
    [anon_sym_nand] = ACTIONS(4944),
    [anon_sym_nor] = ACTIONS(4944),
    [anon_sym_xor] = ACTIONS(4944),
    [anon_sym_xnor] = ACTIONS(4944),
    [anon_sym_buf] = ACTIONS(4944),
    [anon_sym_tranif0] = ACTIONS(4944),
    [anon_sym_tranif1] = ACTIONS(4944),
    [anon_sym_rtranif1] = ACTIONS(4944),
    [anon_sym_rtranif0] = ACTIONS(4944),
    [anon_sym_tran] = ACTIONS(4944),
    [anon_sym_rtran] = ACTIONS(4944),
    [anon_sym_generate] = ACTIONS(4944),
    [anon_sym_for] = ACTIONS(4944),
    [anon_sym_initial] = ACTIONS(4944),
    [anon_sym_assign] = ACTIONS(4944),
    [anon_sym_alias] = ACTIONS(4944),
    [anon_sym_always_comb] = ACTIONS(4944),
    [anon_sym_always_latch] = ACTIONS(4944),
    [anon_sym_always_ff] = ACTIONS(4944),
    [anon_sym_final] = ACTIONS(4944),
    [anon_sym_global] = ACTIONS(4944),
    [anon_sym_LPAREN_STAR] = ACTIONS(4942),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4942),
    [anon_sym_DOLLARunit] = ACTIONS(4942),
  },
  [5194] = {
    [sym_simple_identifier] = ACTIONS(5382),
    [anon_sym_wire] = ACTIONS(5382),
    [anon_sym_tri] = ACTIONS(5382),
    [anon_sym_tri0] = ACTIONS(5382),
    [anon_sym_tri1] = ACTIONS(5382),
    [anon_sym_wand] = ACTIONS(5382),
    [anon_sym_triand] = ACTIONS(5382),
    [anon_sym_wor] = ACTIONS(5382),
    [anon_sym_trior] = ACTIONS(5382),
    [anon_sym_trireg] = ACTIONS(5382),
    [anon_sym_uwire] = ACTIONS(5382),
    [anon_sym_SEMI] = ACTIONS(5380),
    [anon_sym_extern] = ACTIONS(5382),
    [anon_sym_interface] = ACTIONS(5382),
    [anon_sym_checker] = ACTIONS(5382),
    [anon_sym_virtual] = ACTIONS(5382),
    [anon_sym_class] = ACTIONS(5382),
    [anon_sym_type] = ACTIONS(5382),
    [anon_sym_DOLLARfatal] = ACTIONS(5380),
    [anon_sym_DOLLARerror] = ACTIONS(5380),
    [anon_sym_DOLLARwarning] = ACTIONS(5380),
    [anon_sym_DOLLARinfo] = ACTIONS(5380),
    [anon_sym_default] = ACTIONS(5382),
    [anon_sym_clocking] = ACTIONS(5382),
    [anon_sym_defparam] = ACTIONS(5382),
    [anon_sym_bind] = ACTIONS(5382),
    [anon_sym_rand] = ACTIONS(5382),
    [anon_sym_const] = ACTIONS(5382),
    [anon_sym_function] = ACTIONS(5382),
    [anon_sym_static] = ACTIONS(5382),
    [anon_sym_constraint] = ACTIONS(5382),
    [anon_sym_if] = ACTIONS(5382),
    [anon_sym_else] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5380),
    [anon_sym_localparam] = ACTIONS(5382),
    [anon_sym_parameter] = ACTIONS(5382),
    [anon_sym_var] = ACTIONS(5382),
    [anon_sym_import] = ACTIONS(5382),
    [anon_sym_export] = ACTIONS(5382),
    [anon_sym_genvar] = ACTIONS(5382),
    [anon_sym_interconnect] = ACTIONS(5382),
    [anon_sym_typedef] = ACTIONS(5382),
    [anon_sym_enum] = ACTIONS(5382),
    [anon_sym_struct] = ACTIONS(5382),
    [anon_sym_union] = ACTIONS(5382),
    [anon_sym_nettype] = ACTIONS(5382),
    [anon_sym_automatic] = ACTIONS(5382),
    [anon_sym_string] = ACTIONS(5382),
    [anon_sym_chandle] = ACTIONS(5382),
    [anon_sym_event] = ACTIONS(5382),
    [anon_sym_byte] = ACTIONS(5382),
    [anon_sym_shortint] = ACTIONS(5382),
    [anon_sym_int] = ACTIONS(5382),
    [anon_sym_longint] = ACTIONS(5382),
    [anon_sym_integer] = ACTIONS(5382),
    [anon_sym_time] = ACTIONS(5382),
    [anon_sym_bit] = ACTIONS(5382),
    [anon_sym_logic] = ACTIONS(5382),
    [anon_sym_reg] = ACTIONS(5382),
    [anon_sym_shortreal] = ACTIONS(5382),
    [anon_sym_real] = ACTIONS(5382),
    [anon_sym_realtime] = ACTIONS(5382),
    [anon_sym_supply0] = ACTIONS(5382),
    [anon_sym_supply1] = ACTIONS(5382),
    [anon_sym_signed] = ACTIONS(5382),
    [anon_sym_unsigned] = ACTIONS(5382),
    [anon_sym_task] = ACTIONS(5382),
    [anon_sym_assert] = ACTIONS(5382),
    [anon_sym_property] = ACTIONS(5382),
    [anon_sym_assume] = ACTIONS(5382),
    [anon_sym_cover] = ACTIONS(5382),
    [anon_sym_sequence] = ACTIONS(5382),
    [anon_sym_restrict] = ACTIONS(5382),
    [anon_sym_not] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_case] = ACTIONS(5382),
    [anon_sym_always] = ACTIONS(5382),
    [anon_sym_covergroup] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_pulldown] = ACTIONS(5382),
    [anon_sym_pullup] = ACTIONS(5382),
    [anon_sym_cmos] = ACTIONS(5382),
    [anon_sym_rcmos] = ACTIONS(5382),
    [anon_sym_bufif0] = ACTIONS(5382),
    [anon_sym_bufif1] = ACTIONS(5382),
    [anon_sym_notif0] = ACTIONS(5382),
    [anon_sym_notif1] = ACTIONS(5382),
    [anon_sym_nmos] = ACTIONS(5382),
    [anon_sym_pmos] = ACTIONS(5382),
    [anon_sym_rnmos] = ACTIONS(5382),
    [anon_sym_rpmos] = ACTIONS(5382),
    [anon_sym_nand] = ACTIONS(5382),
    [anon_sym_nor] = ACTIONS(5382),
    [anon_sym_xor] = ACTIONS(5382),
    [anon_sym_xnor] = ACTIONS(5382),
    [anon_sym_buf] = ACTIONS(5382),
    [anon_sym_tranif0] = ACTIONS(5382),
    [anon_sym_tranif1] = ACTIONS(5382),
    [anon_sym_rtranif1] = ACTIONS(5382),
    [anon_sym_rtranif0] = ACTIONS(5382),
    [anon_sym_tran] = ACTIONS(5382),
    [anon_sym_rtran] = ACTIONS(5382),
    [anon_sym_generate] = ACTIONS(5382),
    [anon_sym_endgenerate] = ACTIONS(5382),
    [anon_sym_for] = ACTIONS(5382),
    [anon_sym_initial] = ACTIONS(5382),
    [anon_sym_assign] = ACTIONS(5382),
    [anon_sym_alias] = ACTIONS(5382),
    [anon_sym_always_comb] = ACTIONS(5382),
    [anon_sym_always_latch] = ACTIONS(5382),
    [anon_sym_always_ff] = ACTIONS(5382),
    [anon_sym_final] = ACTIONS(5382),
    [anon_sym_global] = ACTIONS(5382),
    [anon_sym_LPAREN_STAR] = ACTIONS(5380),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5380),
    [anon_sym_DOLLARunit] = ACTIONS(5380),
  },
  [5195] = {
    [sym_simple_identifier] = ACTIONS(6157),
    [anon_sym_wire] = ACTIONS(6157),
    [anon_sym_tri] = ACTIONS(6157),
    [anon_sym_tri0] = ACTIONS(6157),
    [anon_sym_tri1] = ACTIONS(6157),
    [anon_sym_wand] = ACTIONS(6157),
    [anon_sym_triand] = ACTIONS(6157),
    [anon_sym_wor] = ACTIONS(6157),
    [anon_sym_trior] = ACTIONS(6157),
    [anon_sym_trireg] = ACTIONS(6157),
    [anon_sym_uwire] = ACTIONS(6157),
    [anon_sym_SEMI] = ACTIONS(6159),
    [anon_sym_extern] = ACTIONS(6157),
    [anon_sym_interface] = ACTIONS(6157),
    [anon_sym_checker] = ACTIONS(6157),
    [anon_sym_virtual] = ACTIONS(6157),
    [anon_sym_class] = ACTIONS(6157),
    [anon_sym_type] = ACTIONS(6157),
    [anon_sym_DOLLARfatal] = ACTIONS(6159),
    [anon_sym_DOLLARerror] = ACTIONS(6159),
    [anon_sym_DOLLARwarning] = ACTIONS(6159),
    [anon_sym_DOLLARinfo] = ACTIONS(6159),
    [anon_sym_default] = ACTIONS(6157),
    [anon_sym_clocking] = ACTIONS(6157),
    [anon_sym_defparam] = ACTIONS(6157),
    [anon_sym_bind] = ACTIONS(6157),
    [anon_sym_rand] = ACTIONS(6157),
    [anon_sym_const] = ACTIONS(6157),
    [anon_sym_function] = ACTIONS(6157),
    [anon_sym_static] = ACTIONS(6157),
    [anon_sym_constraint] = ACTIONS(6157),
    [anon_sym_if] = ACTIONS(6157),
    [anon_sym_else] = ACTIONS(6157),
    [anon_sym_LBRACK] = ACTIONS(6159),
    [anon_sym_localparam] = ACTIONS(6157),
    [anon_sym_parameter] = ACTIONS(6157),
    [anon_sym_var] = ACTIONS(6157),
    [anon_sym_import] = ACTIONS(6157),
    [anon_sym_export] = ACTIONS(6157),
    [anon_sym_genvar] = ACTIONS(6157),
    [anon_sym_interconnect] = ACTIONS(6157),
    [anon_sym_typedef] = ACTIONS(6157),
    [anon_sym_enum] = ACTIONS(6157),
    [anon_sym_struct] = ACTIONS(6157),
    [anon_sym_union] = ACTIONS(6157),
    [anon_sym_nettype] = ACTIONS(6157),
    [anon_sym_automatic] = ACTIONS(6157),
    [anon_sym_string] = ACTIONS(6157),
    [anon_sym_chandle] = ACTIONS(6157),
    [anon_sym_event] = ACTIONS(6157),
    [anon_sym_byte] = ACTIONS(6157),
    [anon_sym_shortint] = ACTIONS(6157),
    [anon_sym_int] = ACTIONS(6157),
    [anon_sym_longint] = ACTIONS(6157),
    [anon_sym_integer] = ACTIONS(6157),
    [anon_sym_time] = ACTIONS(6157),
    [anon_sym_bit] = ACTIONS(6157),
    [anon_sym_logic] = ACTIONS(6157),
    [anon_sym_reg] = ACTIONS(6157),
    [anon_sym_shortreal] = ACTIONS(6157),
    [anon_sym_real] = ACTIONS(6157),
    [anon_sym_realtime] = ACTIONS(6157),
    [anon_sym_supply0] = ACTIONS(6157),
    [anon_sym_supply1] = ACTIONS(6157),
    [anon_sym_signed] = ACTIONS(6157),
    [anon_sym_unsigned] = ACTIONS(6157),
    [anon_sym_task] = ACTIONS(6157),
    [anon_sym_assert] = ACTIONS(6157),
    [anon_sym_property] = ACTIONS(6157),
    [anon_sym_assume] = ACTIONS(6157),
    [anon_sym_cover] = ACTIONS(6157),
    [anon_sym_sequence] = ACTIONS(6157),
    [anon_sym_restrict] = ACTIONS(6157),
    [anon_sym_not] = ACTIONS(6157),
    [anon_sym_or] = ACTIONS(6157),
    [anon_sym_and] = ACTIONS(6157),
    [anon_sym_case] = ACTIONS(6157),
    [anon_sym_always] = ACTIONS(6157),
    [anon_sym_covergroup] = ACTIONS(6157),
    [anon_sym_end] = ACTIONS(6157),
    [anon_sym_let] = ACTIONS(6157),
    [anon_sym_pulldown] = ACTIONS(6157),
    [anon_sym_pullup] = ACTIONS(6157),
    [anon_sym_cmos] = ACTIONS(6157),
    [anon_sym_rcmos] = ACTIONS(6157),
    [anon_sym_bufif0] = ACTIONS(6157),
    [anon_sym_bufif1] = ACTIONS(6157),
    [anon_sym_notif0] = ACTIONS(6157),
    [anon_sym_notif1] = ACTIONS(6157),
    [anon_sym_nmos] = ACTIONS(6157),
    [anon_sym_pmos] = ACTIONS(6157),
    [anon_sym_rnmos] = ACTIONS(6157),
    [anon_sym_rpmos] = ACTIONS(6157),
    [anon_sym_nand] = ACTIONS(6157),
    [anon_sym_nor] = ACTIONS(6157),
    [anon_sym_xor] = ACTIONS(6157),
    [anon_sym_xnor] = ACTIONS(6157),
    [anon_sym_buf] = ACTIONS(6157),
    [anon_sym_tranif0] = ACTIONS(6157),
    [anon_sym_tranif1] = ACTIONS(6157),
    [anon_sym_rtranif1] = ACTIONS(6157),
    [anon_sym_rtranif0] = ACTIONS(6157),
    [anon_sym_tran] = ACTIONS(6157),
    [anon_sym_rtran] = ACTIONS(6157),
    [anon_sym_generate] = ACTIONS(6157),
    [anon_sym_for] = ACTIONS(6157),
    [anon_sym_initial] = ACTIONS(6157),
    [anon_sym_assign] = ACTIONS(6157),
    [anon_sym_alias] = ACTIONS(6157),
    [anon_sym_always_comb] = ACTIONS(6157),
    [anon_sym_always_latch] = ACTIONS(6157),
    [anon_sym_always_ff] = ACTIONS(6157),
    [anon_sym_final] = ACTIONS(6157),
    [anon_sym_global] = ACTIONS(6157),
    [anon_sym_LPAREN_STAR] = ACTIONS(6159),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6159),
    [anon_sym_DOLLARunit] = ACTIONS(6159),
  },
  [5196] = {
    [sym_simple_identifier] = ACTIONS(4524),
    [anon_sym_wire] = ACTIONS(4524),
    [anon_sym_tri] = ACTIONS(4524),
    [anon_sym_tri0] = ACTIONS(4524),
    [anon_sym_tri1] = ACTIONS(4524),
    [anon_sym_wand] = ACTIONS(4524),
    [anon_sym_triand] = ACTIONS(4524),
    [anon_sym_wor] = ACTIONS(4524),
    [anon_sym_trior] = ACTIONS(4524),
    [anon_sym_trireg] = ACTIONS(4524),
    [anon_sym_uwire] = ACTIONS(4524),
    [anon_sym_SEMI] = ACTIONS(4522),
    [anon_sym_extern] = ACTIONS(4524),
    [anon_sym_interface] = ACTIONS(4524),
    [anon_sym_checker] = ACTIONS(4524),
    [anon_sym_virtual] = ACTIONS(4524),
    [anon_sym_class] = ACTIONS(4524),
    [anon_sym_type] = ACTIONS(4524),
    [anon_sym_DOLLARfatal] = ACTIONS(4522),
    [anon_sym_DOLLARerror] = ACTIONS(4522),
    [anon_sym_DOLLARwarning] = ACTIONS(4522),
    [anon_sym_DOLLARinfo] = ACTIONS(4522),
    [anon_sym_default] = ACTIONS(4524),
    [anon_sym_clocking] = ACTIONS(4524),
    [anon_sym_defparam] = ACTIONS(4524),
    [anon_sym_bind] = ACTIONS(4524),
    [anon_sym_rand] = ACTIONS(4524),
    [anon_sym_const] = ACTIONS(4524),
    [anon_sym_function] = ACTIONS(4524),
    [anon_sym_static] = ACTIONS(4524),
    [anon_sym_constraint] = ACTIONS(4524),
    [anon_sym_if] = ACTIONS(4524),
    [anon_sym_else] = ACTIONS(4524),
    [anon_sym_LBRACK] = ACTIONS(4522),
    [anon_sym_localparam] = ACTIONS(4524),
    [anon_sym_parameter] = ACTIONS(4524),
    [anon_sym_var] = ACTIONS(4524),
    [anon_sym_import] = ACTIONS(4524),
    [anon_sym_export] = ACTIONS(4524),
    [anon_sym_genvar] = ACTIONS(4524),
    [anon_sym_interconnect] = ACTIONS(4524),
    [anon_sym_typedef] = ACTIONS(4524),
    [anon_sym_enum] = ACTIONS(4524),
    [anon_sym_struct] = ACTIONS(4524),
    [anon_sym_union] = ACTIONS(4524),
    [anon_sym_nettype] = ACTIONS(4524),
    [anon_sym_automatic] = ACTIONS(4524),
    [anon_sym_string] = ACTIONS(4524),
    [anon_sym_chandle] = ACTIONS(4524),
    [anon_sym_event] = ACTIONS(4524),
    [anon_sym_byte] = ACTIONS(4524),
    [anon_sym_shortint] = ACTIONS(4524),
    [anon_sym_int] = ACTIONS(4524),
    [anon_sym_longint] = ACTIONS(4524),
    [anon_sym_integer] = ACTIONS(4524),
    [anon_sym_time] = ACTIONS(4524),
    [anon_sym_bit] = ACTIONS(4524),
    [anon_sym_logic] = ACTIONS(4524),
    [anon_sym_reg] = ACTIONS(4524),
    [anon_sym_shortreal] = ACTIONS(4524),
    [anon_sym_real] = ACTIONS(4524),
    [anon_sym_realtime] = ACTIONS(4524),
    [anon_sym_supply0] = ACTIONS(4524),
    [anon_sym_supply1] = ACTIONS(4524),
    [anon_sym_signed] = ACTIONS(4524),
    [anon_sym_unsigned] = ACTIONS(4524),
    [anon_sym_task] = ACTIONS(4524),
    [anon_sym_assert] = ACTIONS(4524),
    [anon_sym_property] = ACTIONS(4524),
    [anon_sym_assume] = ACTIONS(4524),
    [anon_sym_cover] = ACTIONS(4524),
    [anon_sym_sequence] = ACTIONS(4524),
    [anon_sym_restrict] = ACTIONS(4524),
    [anon_sym_not] = ACTIONS(4524),
    [anon_sym_or] = ACTIONS(4524),
    [anon_sym_and] = ACTIONS(4524),
    [anon_sym_case] = ACTIONS(4524),
    [anon_sym_always] = ACTIONS(4524),
    [anon_sym_covergroup] = ACTIONS(4524),
    [anon_sym_end] = ACTIONS(4524),
    [anon_sym_let] = ACTIONS(4524),
    [anon_sym_pulldown] = ACTIONS(4524),
    [anon_sym_pullup] = ACTIONS(4524),
    [anon_sym_cmos] = ACTIONS(4524),
    [anon_sym_rcmos] = ACTIONS(4524),
    [anon_sym_bufif0] = ACTIONS(4524),
    [anon_sym_bufif1] = ACTIONS(4524),
    [anon_sym_notif0] = ACTIONS(4524),
    [anon_sym_notif1] = ACTIONS(4524),
    [anon_sym_nmos] = ACTIONS(4524),
    [anon_sym_pmos] = ACTIONS(4524),
    [anon_sym_rnmos] = ACTIONS(4524),
    [anon_sym_rpmos] = ACTIONS(4524),
    [anon_sym_nand] = ACTIONS(4524),
    [anon_sym_nor] = ACTIONS(4524),
    [anon_sym_xor] = ACTIONS(4524),
    [anon_sym_xnor] = ACTIONS(4524),
    [anon_sym_buf] = ACTIONS(4524),
    [anon_sym_tranif0] = ACTIONS(4524),
    [anon_sym_tranif1] = ACTIONS(4524),
    [anon_sym_rtranif1] = ACTIONS(4524),
    [anon_sym_rtranif0] = ACTIONS(4524),
    [anon_sym_tran] = ACTIONS(4524),
    [anon_sym_rtran] = ACTIONS(4524),
    [anon_sym_generate] = ACTIONS(4524),
    [anon_sym_for] = ACTIONS(4524),
    [anon_sym_initial] = ACTIONS(4524),
    [anon_sym_assign] = ACTIONS(4524),
    [anon_sym_alias] = ACTIONS(4524),
    [anon_sym_always_comb] = ACTIONS(4524),
    [anon_sym_always_latch] = ACTIONS(4524),
    [anon_sym_always_ff] = ACTIONS(4524),
    [anon_sym_final] = ACTIONS(4524),
    [anon_sym_global] = ACTIONS(4524),
    [anon_sym_LPAREN_STAR] = ACTIONS(4522),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4522),
    [anon_sym_DOLLARunit] = ACTIONS(4522),
  },
  [5197] = {
    [sym_simple_identifier] = ACTIONS(4636),
    [anon_sym_wire] = ACTIONS(4636),
    [anon_sym_tri] = ACTIONS(4636),
    [anon_sym_tri0] = ACTIONS(4636),
    [anon_sym_tri1] = ACTIONS(4636),
    [anon_sym_wand] = ACTIONS(4636),
    [anon_sym_triand] = ACTIONS(4636),
    [anon_sym_wor] = ACTIONS(4636),
    [anon_sym_trior] = ACTIONS(4636),
    [anon_sym_trireg] = ACTIONS(4636),
    [anon_sym_uwire] = ACTIONS(4636),
    [anon_sym_SEMI] = ACTIONS(4634),
    [anon_sym_extern] = ACTIONS(4636),
    [anon_sym_interface] = ACTIONS(4636),
    [anon_sym_checker] = ACTIONS(4636),
    [anon_sym_virtual] = ACTIONS(4636),
    [anon_sym_class] = ACTIONS(4636),
    [anon_sym_type] = ACTIONS(4636),
    [anon_sym_DOLLARfatal] = ACTIONS(4634),
    [anon_sym_DOLLARerror] = ACTIONS(4634),
    [anon_sym_DOLLARwarning] = ACTIONS(4634),
    [anon_sym_DOLLARinfo] = ACTIONS(4634),
    [anon_sym_default] = ACTIONS(4636),
    [anon_sym_clocking] = ACTIONS(4636),
    [anon_sym_defparam] = ACTIONS(4636),
    [anon_sym_bind] = ACTIONS(4636),
    [anon_sym_rand] = ACTIONS(4636),
    [anon_sym_const] = ACTIONS(4636),
    [anon_sym_function] = ACTIONS(4636),
    [anon_sym_static] = ACTIONS(4636),
    [anon_sym_constraint] = ACTIONS(4636),
    [anon_sym_if] = ACTIONS(4636),
    [anon_sym_else] = ACTIONS(4636),
    [anon_sym_LBRACK] = ACTIONS(4634),
    [anon_sym_localparam] = ACTIONS(4636),
    [anon_sym_parameter] = ACTIONS(4636),
    [anon_sym_var] = ACTIONS(4636),
    [anon_sym_import] = ACTIONS(4636),
    [anon_sym_export] = ACTIONS(4636),
    [anon_sym_genvar] = ACTIONS(4636),
    [anon_sym_interconnect] = ACTIONS(4636),
    [anon_sym_typedef] = ACTIONS(4636),
    [anon_sym_enum] = ACTIONS(4636),
    [anon_sym_struct] = ACTIONS(4636),
    [anon_sym_union] = ACTIONS(4636),
    [anon_sym_nettype] = ACTIONS(4636),
    [anon_sym_automatic] = ACTIONS(4636),
    [anon_sym_string] = ACTIONS(4636),
    [anon_sym_chandle] = ACTIONS(4636),
    [anon_sym_event] = ACTIONS(4636),
    [anon_sym_byte] = ACTIONS(4636),
    [anon_sym_shortint] = ACTIONS(4636),
    [anon_sym_int] = ACTIONS(4636),
    [anon_sym_longint] = ACTIONS(4636),
    [anon_sym_integer] = ACTIONS(4636),
    [anon_sym_time] = ACTIONS(4636),
    [anon_sym_bit] = ACTIONS(4636),
    [anon_sym_logic] = ACTIONS(4636),
    [anon_sym_reg] = ACTIONS(4636),
    [anon_sym_shortreal] = ACTIONS(4636),
    [anon_sym_real] = ACTIONS(4636),
    [anon_sym_realtime] = ACTIONS(4636),
    [anon_sym_supply0] = ACTIONS(4636),
    [anon_sym_supply1] = ACTIONS(4636),
    [anon_sym_signed] = ACTIONS(4636),
    [anon_sym_unsigned] = ACTIONS(4636),
    [anon_sym_task] = ACTIONS(4636),
    [anon_sym_assert] = ACTIONS(4636),
    [anon_sym_property] = ACTIONS(4636),
    [anon_sym_assume] = ACTIONS(4636),
    [anon_sym_cover] = ACTIONS(4636),
    [anon_sym_sequence] = ACTIONS(4636),
    [anon_sym_restrict] = ACTIONS(4636),
    [anon_sym_not] = ACTIONS(4636),
    [anon_sym_or] = ACTIONS(4636),
    [anon_sym_and] = ACTIONS(4636),
    [anon_sym_case] = ACTIONS(4636),
    [anon_sym_always] = ACTIONS(4636),
    [anon_sym_covergroup] = ACTIONS(4636),
    [anon_sym_let] = ACTIONS(4636),
    [anon_sym_pulldown] = ACTIONS(4636),
    [anon_sym_pullup] = ACTIONS(4636),
    [anon_sym_cmos] = ACTIONS(4636),
    [anon_sym_rcmos] = ACTIONS(4636),
    [anon_sym_bufif0] = ACTIONS(4636),
    [anon_sym_bufif1] = ACTIONS(4636),
    [anon_sym_notif0] = ACTIONS(4636),
    [anon_sym_notif1] = ACTIONS(4636),
    [anon_sym_nmos] = ACTIONS(4636),
    [anon_sym_pmos] = ACTIONS(4636),
    [anon_sym_rnmos] = ACTIONS(4636),
    [anon_sym_rpmos] = ACTIONS(4636),
    [anon_sym_nand] = ACTIONS(4636),
    [anon_sym_nor] = ACTIONS(4636),
    [anon_sym_xor] = ACTIONS(4636),
    [anon_sym_xnor] = ACTIONS(4636),
    [anon_sym_buf] = ACTIONS(4636),
    [anon_sym_tranif0] = ACTIONS(4636),
    [anon_sym_tranif1] = ACTIONS(4636),
    [anon_sym_rtranif1] = ACTIONS(4636),
    [anon_sym_rtranif0] = ACTIONS(4636),
    [anon_sym_tran] = ACTIONS(4636),
    [anon_sym_rtran] = ACTIONS(4636),
    [anon_sym_generate] = ACTIONS(4636),
    [anon_sym_endgenerate] = ACTIONS(4636),
    [anon_sym_for] = ACTIONS(4636),
    [anon_sym_initial] = ACTIONS(4636),
    [anon_sym_assign] = ACTIONS(4636),
    [anon_sym_alias] = ACTIONS(4636),
    [anon_sym_always_comb] = ACTIONS(4636),
    [anon_sym_always_latch] = ACTIONS(4636),
    [anon_sym_always_ff] = ACTIONS(4636),
    [anon_sym_final] = ACTIONS(4636),
    [anon_sym_global] = ACTIONS(4636),
    [anon_sym_LPAREN_STAR] = ACTIONS(4634),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4634),
    [anon_sym_DOLLARunit] = ACTIONS(4634),
  },
  [5198] = {
    [sym_simple_identifier] = ACTIONS(5388),
    [anon_sym_wire] = ACTIONS(5388),
    [anon_sym_tri] = ACTIONS(5388),
    [anon_sym_tri0] = ACTIONS(5388),
    [anon_sym_tri1] = ACTIONS(5388),
    [anon_sym_wand] = ACTIONS(5388),
    [anon_sym_triand] = ACTIONS(5388),
    [anon_sym_wor] = ACTIONS(5388),
    [anon_sym_trior] = ACTIONS(5388),
    [anon_sym_trireg] = ACTIONS(5388),
    [anon_sym_uwire] = ACTIONS(5388),
    [anon_sym_SEMI] = ACTIONS(5386),
    [anon_sym_extern] = ACTIONS(5388),
    [anon_sym_interface] = ACTIONS(5388),
    [anon_sym_checker] = ACTIONS(5388),
    [anon_sym_virtual] = ACTIONS(5388),
    [anon_sym_class] = ACTIONS(5388),
    [anon_sym_type] = ACTIONS(5388),
    [anon_sym_DOLLARfatal] = ACTIONS(5386),
    [anon_sym_DOLLARerror] = ACTIONS(5386),
    [anon_sym_DOLLARwarning] = ACTIONS(5386),
    [anon_sym_DOLLARinfo] = ACTIONS(5386),
    [anon_sym_default] = ACTIONS(5388),
    [anon_sym_clocking] = ACTIONS(5388),
    [anon_sym_defparam] = ACTIONS(5388),
    [anon_sym_bind] = ACTIONS(5388),
    [anon_sym_rand] = ACTIONS(5388),
    [anon_sym_const] = ACTIONS(5388),
    [anon_sym_function] = ACTIONS(5388),
    [anon_sym_static] = ACTIONS(5388),
    [anon_sym_constraint] = ACTIONS(5388),
    [anon_sym_if] = ACTIONS(5388),
    [anon_sym_else] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5386),
    [anon_sym_localparam] = ACTIONS(5388),
    [anon_sym_parameter] = ACTIONS(5388),
    [anon_sym_var] = ACTIONS(5388),
    [anon_sym_import] = ACTIONS(5388),
    [anon_sym_export] = ACTIONS(5388),
    [anon_sym_genvar] = ACTIONS(5388),
    [anon_sym_interconnect] = ACTIONS(5388),
    [anon_sym_typedef] = ACTIONS(5388),
    [anon_sym_enum] = ACTIONS(5388),
    [anon_sym_struct] = ACTIONS(5388),
    [anon_sym_union] = ACTIONS(5388),
    [anon_sym_nettype] = ACTIONS(5388),
    [anon_sym_automatic] = ACTIONS(5388),
    [anon_sym_string] = ACTIONS(5388),
    [anon_sym_chandle] = ACTIONS(5388),
    [anon_sym_event] = ACTIONS(5388),
    [anon_sym_byte] = ACTIONS(5388),
    [anon_sym_shortint] = ACTIONS(5388),
    [anon_sym_int] = ACTIONS(5388),
    [anon_sym_longint] = ACTIONS(5388),
    [anon_sym_integer] = ACTIONS(5388),
    [anon_sym_time] = ACTIONS(5388),
    [anon_sym_bit] = ACTIONS(5388),
    [anon_sym_logic] = ACTIONS(5388),
    [anon_sym_reg] = ACTIONS(5388),
    [anon_sym_shortreal] = ACTIONS(5388),
    [anon_sym_real] = ACTIONS(5388),
    [anon_sym_realtime] = ACTIONS(5388),
    [anon_sym_supply0] = ACTIONS(5388),
    [anon_sym_supply1] = ACTIONS(5388),
    [anon_sym_signed] = ACTIONS(5388),
    [anon_sym_unsigned] = ACTIONS(5388),
    [anon_sym_task] = ACTIONS(5388),
    [anon_sym_assert] = ACTIONS(5388),
    [anon_sym_property] = ACTIONS(5388),
    [anon_sym_assume] = ACTIONS(5388),
    [anon_sym_cover] = ACTIONS(5388),
    [anon_sym_sequence] = ACTIONS(5388),
    [anon_sym_restrict] = ACTIONS(5388),
    [anon_sym_not] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_case] = ACTIONS(5388),
    [anon_sym_always] = ACTIONS(5388),
    [anon_sym_covergroup] = ACTIONS(5388),
    [anon_sym_let] = ACTIONS(5388),
    [anon_sym_pulldown] = ACTIONS(5388),
    [anon_sym_pullup] = ACTIONS(5388),
    [anon_sym_cmos] = ACTIONS(5388),
    [anon_sym_rcmos] = ACTIONS(5388),
    [anon_sym_bufif0] = ACTIONS(5388),
    [anon_sym_bufif1] = ACTIONS(5388),
    [anon_sym_notif0] = ACTIONS(5388),
    [anon_sym_notif1] = ACTIONS(5388),
    [anon_sym_nmos] = ACTIONS(5388),
    [anon_sym_pmos] = ACTIONS(5388),
    [anon_sym_rnmos] = ACTIONS(5388),
    [anon_sym_rpmos] = ACTIONS(5388),
    [anon_sym_nand] = ACTIONS(5388),
    [anon_sym_nor] = ACTIONS(5388),
    [anon_sym_xor] = ACTIONS(5388),
    [anon_sym_xnor] = ACTIONS(5388),
    [anon_sym_buf] = ACTIONS(5388),
    [anon_sym_tranif0] = ACTIONS(5388),
    [anon_sym_tranif1] = ACTIONS(5388),
    [anon_sym_rtranif1] = ACTIONS(5388),
    [anon_sym_rtranif0] = ACTIONS(5388),
    [anon_sym_tran] = ACTIONS(5388),
    [anon_sym_rtran] = ACTIONS(5388),
    [anon_sym_generate] = ACTIONS(5388),
    [anon_sym_endgenerate] = ACTIONS(5388),
    [anon_sym_for] = ACTIONS(5388),
    [anon_sym_initial] = ACTIONS(5388),
    [anon_sym_assign] = ACTIONS(5388),
    [anon_sym_alias] = ACTIONS(5388),
    [anon_sym_always_comb] = ACTIONS(5388),
    [anon_sym_always_latch] = ACTIONS(5388),
    [anon_sym_always_ff] = ACTIONS(5388),
    [anon_sym_final] = ACTIONS(5388),
    [anon_sym_global] = ACTIONS(5388),
    [anon_sym_LPAREN_STAR] = ACTIONS(5386),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5386),
    [anon_sym_DOLLARunit] = ACTIONS(5386),
  },
  [5199] = {
    [sym_simple_identifier] = ACTIONS(6393),
    [anon_sym_wire] = ACTIONS(6393),
    [anon_sym_tri] = ACTIONS(6393),
    [anon_sym_tri0] = ACTIONS(6393),
    [anon_sym_tri1] = ACTIONS(6393),
    [anon_sym_wand] = ACTIONS(6393),
    [anon_sym_triand] = ACTIONS(6393),
    [anon_sym_wor] = ACTIONS(6393),
    [anon_sym_trior] = ACTIONS(6393),
    [anon_sym_trireg] = ACTIONS(6393),
    [anon_sym_uwire] = ACTIONS(6393),
    [anon_sym_SEMI] = ACTIONS(6395),
    [anon_sym_extern] = ACTIONS(6393),
    [anon_sym_interface] = ACTIONS(6393),
    [anon_sym_checker] = ACTIONS(6393),
    [anon_sym_virtual] = ACTIONS(6393),
    [anon_sym_class] = ACTIONS(6393),
    [anon_sym_type] = ACTIONS(6393),
    [anon_sym_DOLLARfatal] = ACTIONS(6395),
    [anon_sym_DOLLARerror] = ACTIONS(6395),
    [anon_sym_DOLLARwarning] = ACTIONS(6395),
    [anon_sym_DOLLARinfo] = ACTIONS(6395),
    [anon_sym_default] = ACTIONS(6393),
    [anon_sym_clocking] = ACTIONS(6393),
    [anon_sym_defparam] = ACTIONS(6393),
    [anon_sym_bind] = ACTIONS(6393),
    [anon_sym_rand] = ACTIONS(6393),
    [anon_sym_const] = ACTIONS(6393),
    [anon_sym_function] = ACTIONS(6393),
    [anon_sym_static] = ACTIONS(6393),
    [anon_sym_constraint] = ACTIONS(6393),
    [anon_sym_if] = ACTIONS(6393),
    [anon_sym_else] = ACTIONS(6393),
    [anon_sym_LBRACK] = ACTIONS(6395),
    [anon_sym_localparam] = ACTIONS(6393),
    [anon_sym_parameter] = ACTIONS(6393),
    [anon_sym_var] = ACTIONS(6393),
    [anon_sym_import] = ACTIONS(6393),
    [anon_sym_export] = ACTIONS(6393),
    [anon_sym_genvar] = ACTIONS(6393),
    [anon_sym_interconnect] = ACTIONS(6393),
    [anon_sym_typedef] = ACTIONS(6393),
    [anon_sym_enum] = ACTIONS(6393),
    [anon_sym_struct] = ACTIONS(6393),
    [anon_sym_union] = ACTIONS(6393),
    [anon_sym_nettype] = ACTIONS(6393),
    [anon_sym_automatic] = ACTIONS(6393),
    [anon_sym_string] = ACTIONS(6393),
    [anon_sym_chandle] = ACTIONS(6393),
    [anon_sym_event] = ACTIONS(6393),
    [anon_sym_byte] = ACTIONS(6393),
    [anon_sym_shortint] = ACTIONS(6393),
    [anon_sym_int] = ACTIONS(6393),
    [anon_sym_longint] = ACTIONS(6393),
    [anon_sym_integer] = ACTIONS(6393),
    [anon_sym_time] = ACTIONS(6393),
    [anon_sym_bit] = ACTIONS(6393),
    [anon_sym_logic] = ACTIONS(6393),
    [anon_sym_reg] = ACTIONS(6393),
    [anon_sym_shortreal] = ACTIONS(6393),
    [anon_sym_real] = ACTIONS(6393),
    [anon_sym_realtime] = ACTIONS(6393),
    [anon_sym_supply0] = ACTIONS(6393),
    [anon_sym_supply1] = ACTIONS(6393),
    [anon_sym_signed] = ACTIONS(6393),
    [anon_sym_unsigned] = ACTIONS(6393),
    [anon_sym_task] = ACTIONS(6393),
    [anon_sym_assert] = ACTIONS(6393),
    [anon_sym_property] = ACTIONS(6393),
    [anon_sym_assume] = ACTIONS(6393),
    [anon_sym_cover] = ACTIONS(6393),
    [anon_sym_sequence] = ACTIONS(6393),
    [anon_sym_restrict] = ACTIONS(6393),
    [anon_sym_not] = ACTIONS(6393),
    [anon_sym_or] = ACTIONS(6393),
    [anon_sym_and] = ACTIONS(6393),
    [anon_sym_case] = ACTIONS(6393),
    [anon_sym_always] = ACTIONS(6393),
    [anon_sym_covergroup] = ACTIONS(6393),
    [anon_sym_end] = ACTIONS(6393),
    [anon_sym_let] = ACTIONS(6393),
    [anon_sym_pulldown] = ACTIONS(6393),
    [anon_sym_pullup] = ACTIONS(6393),
    [anon_sym_cmos] = ACTIONS(6393),
    [anon_sym_rcmos] = ACTIONS(6393),
    [anon_sym_bufif0] = ACTIONS(6393),
    [anon_sym_bufif1] = ACTIONS(6393),
    [anon_sym_notif0] = ACTIONS(6393),
    [anon_sym_notif1] = ACTIONS(6393),
    [anon_sym_nmos] = ACTIONS(6393),
    [anon_sym_pmos] = ACTIONS(6393),
    [anon_sym_rnmos] = ACTIONS(6393),
    [anon_sym_rpmos] = ACTIONS(6393),
    [anon_sym_nand] = ACTIONS(6393),
    [anon_sym_nor] = ACTIONS(6393),
    [anon_sym_xor] = ACTIONS(6393),
    [anon_sym_xnor] = ACTIONS(6393),
    [anon_sym_buf] = ACTIONS(6393),
    [anon_sym_tranif0] = ACTIONS(6393),
    [anon_sym_tranif1] = ACTIONS(6393),
    [anon_sym_rtranif1] = ACTIONS(6393),
    [anon_sym_rtranif0] = ACTIONS(6393),
    [anon_sym_tran] = ACTIONS(6393),
    [anon_sym_rtran] = ACTIONS(6393),
    [anon_sym_generate] = ACTIONS(6393),
    [anon_sym_for] = ACTIONS(6393),
    [anon_sym_initial] = ACTIONS(6393),
    [anon_sym_assign] = ACTIONS(6393),
    [anon_sym_alias] = ACTIONS(6393),
    [anon_sym_always_comb] = ACTIONS(6393),
    [anon_sym_always_latch] = ACTIONS(6393),
    [anon_sym_always_ff] = ACTIONS(6393),
    [anon_sym_final] = ACTIONS(6393),
    [anon_sym_global] = ACTIONS(6393),
    [anon_sym_LPAREN_STAR] = ACTIONS(6395),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6395),
    [anon_sym_DOLLARunit] = ACTIONS(6395),
  },
  [5200] = {
    [sym_simple_identifier] = ACTIONS(4424),
    [anon_sym_wire] = ACTIONS(4424),
    [anon_sym_tri] = ACTIONS(4424),
    [anon_sym_tri0] = ACTIONS(4424),
    [anon_sym_tri1] = ACTIONS(4424),
    [anon_sym_wand] = ACTIONS(4424),
    [anon_sym_triand] = ACTIONS(4424),
    [anon_sym_wor] = ACTIONS(4424),
    [anon_sym_trior] = ACTIONS(4424),
    [anon_sym_trireg] = ACTIONS(4424),
    [anon_sym_uwire] = ACTIONS(4424),
    [anon_sym_SEMI] = ACTIONS(4422),
    [anon_sym_extern] = ACTIONS(4424),
    [anon_sym_interface] = ACTIONS(4424),
    [anon_sym_checker] = ACTIONS(4424),
    [anon_sym_virtual] = ACTIONS(4424),
    [anon_sym_class] = ACTIONS(4424),
    [anon_sym_type] = ACTIONS(4424),
    [anon_sym_DOLLARfatal] = ACTIONS(4422),
    [anon_sym_DOLLARerror] = ACTIONS(4422),
    [anon_sym_DOLLARwarning] = ACTIONS(4422),
    [anon_sym_DOLLARinfo] = ACTIONS(4422),
    [anon_sym_default] = ACTIONS(4424),
    [anon_sym_clocking] = ACTIONS(4424),
    [anon_sym_defparam] = ACTIONS(4424),
    [anon_sym_bind] = ACTIONS(4424),
    [anon_sym_rand] = ACTIONS(4424),
    [anon_sym_const] = ACTIONS(4424),
    [anon_sym_function] = ACTIONS(4424),
    [anon_sym_static] = ACTIONS(4424),
    [anon_sym_constraint] = ACTIONS(4424),
    [anon_sym_if] = ACTIONS(4424),
    [anon_sym_else] = ACTIONS(4424),
    [anon_sym_LBRACK] = ACTIONS(4422),
    [anon_sym_localparam] = ACTIONS(4424),
    [anon_sym_parameter] = ACTIONS(4424),
    [anon_sym_var] = ACTIONS(4424),
    [anon_sym_import] = ACTIONS(4424),
    [anon_sym_export] = ACTIONS(4424),
    [anon_sym_genvar] = ACTIONS(4424),
    [anon_sym_interconnect] = ACTIONS(4424),
    [anon_sym_typedef] = ACTIONS(4424),
    [anon_sym_enum] = ACTIONS(4424),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4424),
    [anon_sym_nettype] = ACTIONS(4424),
    [anon_sym_automatic] = ACTIONS(4424),
    [anon_sym_string] = ACTIONS(4424),
    [anon_sym_chandle] = ACTIONS(4424),
    [anon_sym_event] = ACTIONS(4424),
    [anon_sym_byte] = ACTIONS(4424),
    [anon_sym_shortint] = ACTIONS(4424),
    [anon_sym_int] = ACTIONS(4424),
    [anon_sym_longint] = ACTIONS(4424),
    [anon_sym_integer] = ACTIONS(4424),
    [anon_sym_time] = ACTIONS(4424),
    [anon_sym_bit] = ACTIONS(4424),
    [anon_sym_logic] = ACTIONS(4424),
    [anon_sym_reg] = ACTIONS(4424),
    [anon_sym_shortreal] = ACTIONS(4424),
    [anon_sym_real] = ACTIONS(4424),
    [anon_sym_realtime] = ACTIONS(4424),
    [anon_sym_supply0] = ACTIONS(4424),
    [anon_sym_supply1] = ACTIONS(4424),
    [anon_sym_signed] = ACTIONS(4424),
    [anon_sym_unsigned] = ACTIONS(4424),
    [anon_sym_task] = ACTIONS(4424),
    [anon_sym_assert] = ACTIONS(4424),
    [anon_sym_property] = ACTIONS(4424),
    [anon_sym_assume] = ACTIONS(4424),
    [anon_sym_cover] = ACTIONS(4424),
    [anon_sym_sequence] = ACTIONS(4424),
    [anon_sym_restrict] = ACTIONS(4424),
    [anon_sym_not] = ACTIONS(4424),
    [anon_sym_or] = ACTIONS(4424),
    [anon_sym_and] = ACTIONS(4424),
    [anon_sym_case] = ACTIONS(4424),
    [anon_sym_always] = ACTIONS(4424),
    [anon_sym_covergroup] = ACTIONS(4424),
    [anon_sym_let] = ACTIONS(4424),
    [anon_sym_pulldown] = ACTIONS(4424),
    [anon_sym_pullup] = ACTIONS(4424),
    [anon_sym_cmos] = ACTIONS(4424),
    [anon_sym_rcmos] = ACTIONS(4424),
    [anon_sym_bufif0] = ACTIONS(4424),
    [anon_sym_bufif1] = ACTIONS(4424),
    [anon_sym_notif0] = ACTIONS(4424),
    [anon_sym_notif1] = ACTIONS(4424),
    [anon_sym_nmos] = ACTIONS(4424),
    [anon_sym_pmos] = ACTIONS(4424),
    [anon_sym_rnmos] = ACTIONS(4424),
    [anon_sym_rpmos] = ACTIONS(4424),
    [anon_sym_nand] = ACTIONS(4424),
    [anon_sym_nor] = ACTIONS(4424),
    [anon_sym_xor] = ACTIONS(4424),
    [anon_sym_xnor] = ACTIONS(4424),
    [anon_sym_buf] = ACTIONS(4424),
    [anon_sym_tranif0] = ACTIONS(4424),
    [anon_sym_tranif1] = ACTIONS(4424),
    [anon_sym_rtranif1] = ACTIONS(4424),
    [anon_sym_rtranif0] = ACTIONS(4424),
    [anon_sym_tran] = ACTIONS(4424),
    [anon_sym_rtran] = ACTIONS(4424),
    [anon_sym_generate] = ACTIONS(4424),
    [anon_sym_endgenerate] = ACTIONS(4424),
    [anon_sym_for] = ACTIONS(4424),
    [anon_sym_initial] = ACTIONS(4424),
    [anon_sym_assign] = ACTIONS(4424),
    [anon_sym_alias] = ACTIONS(4424),
    [anon_sym_always_comb] = ACTIONS(4424),
    [anon_sym_always_latch] = ACTIONS(4424),
    [anon_sym_always_ff] = ACTIONS(4424),
    [anon_sym_final] = ACTIONS(4424),
    [anon_sym_global] = ACTIONS(4424),
    [anon_sym_LPAREN_STAR] = ACTIONS(4422),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4422),
    [anon_sym_DOLLARunit] = ACTIONS(4422),
  },
  [5201] = {
    [sym_simple_identifier] = ACTIONS(4630),
    [anon_sym_wire] = ACTIONS(4630),
    [anon_sym_tri] = ACTIONS(4630),
    [anon_sym_tri0] = ACTIONS(4630),
    [anon_sym_tri1] = ACTIONS(4630),
    [anon_sym_wand] = ACTIONS(4630),
    [anon_sym_triand] = ACTIONS(4630),
    [anon_sym_wor] = ACTIONS(4630),
    [anon_sym_trior] = ACTIONS(4630),
    [anon_sym_trireg] = ACTIONS(4630),
    [anon_sym_uwire] = ACTIONS(4630),
    [anon_sym_SEMI] = ACTIONS(4628),
    [anon_sym_extern] = ACTIONS(4630),
    [anon_sym_interface] = ACTIONS(4630),
    [anon_sym_checker] = ACTIONS(4630),
    [anon_sym_virtual] = ACTIONS(4630),
    [anon_sym_class] = ACTIONS(4630),
    [anon_sym_type] = ACTIONS(4630),
    [anon_sym_DOLLARfatal] = ACTIONS(4628),
    [anon_sym_DOLLARerror] = ACTIONS(4628),
    [anon_sym_DOLLARwarning] = ACTIONS(4628),
    [anon_sym_DOLLARinfo] = ACTIONS(4628),
    [anon_sym_default] = ACTIONS(4630),
    [anon_sym_clocking] = ACTIONS(4630),
    [anon_sym_defparam] = ACTIONS(4630),
    [anon_sym_bind] = ACTIONS(4630),
    [anon_sym_rand] = ACTIONS(4630),
    [anon_sym_const] = ACTIONS(4630),
    [anon_sym_function] = ACTIONS(4630),
    [anon_sym_static] = ACTIONS(4630),
    [anon_sym_constraint] = ACTIONS(4630),
    [anon_sym_if] = ACTIONS(4630),
    [anon_sym_else] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4628),
    [anon_sym_localparam] = ACTIONS(4630),
    [anon_sym_parameter] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4630),
    [anon_sym_import] = ACTIONS(4630),
    [anon_sym_export] = ACTIONS(4630),
    [anon_sym_genvar] = ACTIONS(4630),
    [anon_sym_interconnect] = ACTIONS(4630),
    [anon_sym_typedef] = ACTIONS(4630),
    [anon_sym_enum] = ACTIONS(4630),
    [anon_sym_struct] = ACTIONS(4630),
    [anon_sym_union] = ACTIONS(4630),
    [anon_sym_nettype] = ACTIONS(4630),
    [anon_sym_automatic] = ACTIONS(4630),
    [anon_sym_string] = ACTIONS(4630),
    [anon_sym_chandle] = ACTIONS(4630),
    [anon_sym_event] = ACTIONS(4630),
    [anon_sym_byte] = ACTIONS(4630),
    [anon_sym_shortint] = ACTIONS(4630),
    [anon_sym_int] = ACTIONS(4630),
    [anon_sym_longint] = ACTIONS(4630),
    [anon_sym_integer] = ACTIONS(4630),
    [anon_sym_time] = ACTIONS(4630),
    [anon_sym_bit] = ACTIONS(4630),
    [anon_sym_logic] = ACTIONS(4630),
    [anon_sym_reg] = ACTIONS(4630),
    [anon_sym_shortreal] = ACTIONS(4630),
    [anon_sym_real] = ACTIONS(4630),
    [anon_sym_realtime] = ACTIONS(4630),
    [anon_sym_supply0] = ACTIONS(4630),
    [anon_sym_supply1] = ACTIONS(4630),
    [anon_sym_signed] = ACTIONS(4630),
    [anon_sym_unsigned] = ACTIONS(4630),
    [anon_sym_task] = ACTIONS(4630),
    [anon_sym_assert] = ACTIONS(4630),
    [anon_sym_property] = ACTIONS(4630),
    [anon_sym_assume] = ACTIONS(4630),
    [anon_sym_cover] = ACTIONS(4630),
    [anon_sym_sequence] = ACTIONS(4630),
    [anon_sym_restrict] = ACTIONS(4630),
    [anon_sym_not] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_case] = ACTIONS(4630),
    [anon_sym_always] = ACTIONS(4630),
    [anon_sym_covergroup] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_pulldown] = ACTIONS(4630),
    [anon_sym_pullup] = ACTIONS(4630),
    [anon_sym_cmos] = ACTIONS(4630),
    [anon_sym_rcmos] = ACTIONS(4630),
    [anon_sym_bufif0] = ACTIONS(4630),
    [anon_sym_bufif1] = ACTIONS(4630),
    [anon_sym_notif0] = ACTIONS(4630),
    [anon_sym_notif1] = ACTIONS(4630),
    [anon_sym_nmos] = ACTIONS(4630),
    [anon_sym_pmos] = ACTIONS(4630),
    [anon_sym_rnmos] = ACTIONS(4630),
    [anon_sym_rpmos] = ACTIONS(4630),
    [anon_sym_nand] = ACTIONS(4630),
    [anon_sym_nor] = ACTIONS(4630),
    [anon_sym_xor] = ACTIONS(4630),
    [anon_sym_xnor] = ACTIONS(4630),
    [anon_sym_buf] = ACTIONS(4630),
    [anon_sym_tranif0] = ACTIONS(4630),
    [anon_sym_tranif1] = ACTIONS(4630),
    [anon_sym_rtranif1] = ACTIONS(4630),
    [anon_sym_rtranif0] = ACTIONS(4630),
    [anon_sym_tran] = ACTIONS(4630),
    [anon_sym_rtran] = ACTIONS(4630),
    [anon_sym_generate] = ACTIONS(4630),
    [anon_sym_endgenerate] = ACTIONS(4630),
    [anon_sym_for] = ACTIONS(4630),
    [anon_sym_initial] = ACTIONS(4630),
    [anon_sym_assign] = ACTIONS(4630),
    [anon_sym_alias] = ACTIONS(4630),
    [anon_sym_always_comb] = ACTIONS(4630),
    [anon_sym_always_latch] = ACTIONS(4630),
    [anon_sym_always_ff] = ACTIONS(4630),
    [anon_sym_final] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4630),
    [anon_sym_LPAREN_STAR] = ACTIONS(4628),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4628),
    [anon_sym_DOLLARunit] = ACTIONS(4628),
  },
  [5202] = {
    [sym_simple_identifier] = ACTIONS(6241),
    [anon_sym_wire] = ACTIONS(6241),
    [anon_sym_tri] = ACTIONS(6241),
    [anon_sym_tri0] = ACTIONS(6241),
    [anon_sym_tri1] = ACTIONS(6241),
    [anon_sym_wand] = ACTIONS(6241),
    [anon_sym_triand] = ACTIONS(6241),
    [anon_sym_wor] = ACTIONS(6241),
    [anon_sym_trior] = ACTIONS(6241),
    [anon_sym_trireg] = ACTIONS(6241),
    [anon_sym_uwire] = ACTIONS(6241),
    [anon_sym_SEMI] = ACTIONS(6243),
    [anon_sym_extern] = ACTIONS(6241),
    [anon_sym_interface] = ACTIONS(6241),
    [anon_sym_checker] = ACTIONS(6241),
    [anon_sym_virtual] = ACTIONS(6241),
    [anon_sym_class] = ACTIONS(6241),
    [anon_sym_type] = ACTIONS(6241),
    [anon_sym_DOLLARfatal] = ACTIONS(6243),
    [anon_sym_DOLLARerror] = ACTIONS(6243),
    [anon_sym_DOLLARwarning] = ACTIONS(6243),
    [anon_sym_DOLLARinfo] = ACTIONS(6243),
    [anon_sym_default] = ACTIONS(6241),
    [anon_sym_clocking] = ACTIONS(6241),
    [anon_sym_defparam] = ACTIONS(6241),
    [anon_sym_bind] = ACTIONS(6241),
    [anon_sym_rand] = ACTIONS(6241),
    [anon_sym_const] = ACTIONS(6241),
    [anon_sym_function] = ACTIONS(6241),
    [anon_sym_static] = ACTIONS(6241),
    [anon_sym_constraint] = ACTIONS(6241),
    [anon_sym_if] = ACTIONS(6241),
    [anon_sym_else] = ACTIONS(6241),
    [anon_sym_LBRACK] = ACTIONS(6243),
    [anon_sym_localparam] = ACTIONS(6241),
    [anon_sym_parameter] = ACTIONS(6241),
    [anon_sym_var] = ACTIONS(6241),
    [anon_sym_import] = ACTIONS(6241),
    [anon_sym_export] = ACTIONS(6241),
    [anon_sym_genvar] = ACTIONS(6241),
    [anon_sym_interconnect] = ACTIONS(6241),
    [anon_sym_typedef] = ACTIONS(6241),
    [anon_sym_enum] = ACTIONS(6241),
    [anon_sym_struct] = ACTIONS(6241),
    [anon_sym_union] = ACTIONS(6241),
    [anon_sym_nettype] = ACTIONS(6241),
    [anon_sym_automatic] = ACTIONS(6241),
    [anon_sym_string] = ACTIONS(6241),
    [anon_sym_chandle] = ACTIONS(6241),
    [anon_sym_event] = ACTIONS(6241),
    [anon_sym_byte] = ACTIONS(6241),
    [anon_sym_shortint] = ACTIONS(6241),
    [anon_sym_int] = ACTIONS(6241),
    [anon_sym_longint] = ACTIONS(6241),
    [anon_sym_integer] = ACTIONS(6241),
    [anon_sym_time] = ACTIONS(6241),
    [anon_sym_bit] = ACTIONS(6241),
    [anon_sym_logic] = ACTIONS(6241),
    [anon_sym_reg] = ACTIONS(6241),
    [anon_sym_shortreal] = ACTIONS(6241),
    [anon_sym_real] = ACTIONS(6241),
    [anon_sym_realtime] = ACTIONS(6241),
    [anon_sym_supply0] = ACTIONS(6241),
    [anon_sym_supply1] = ACTIONS(6241),
    [anon_sym_signed] = ACTIONS(6241),
    [anon_sym_unsigned] = ACTIONS(6241),
    [anon_sym_task] = ACTIONS(6241),
    [anon_sym_assert] = ACTIONS(6241),
    [anon_sym_property] = ACTIONS(6241),
    [anon_sym_assume] = ACTIONS(6241),
    [anon_sym_cover] = ACTIONS(6241),
    [anon_sym_sequence] = ACTIONS(6241),
    [anon_sym_restrict] = ACTIONS(6241),
    [anon_sym_not] = ACTIONS(6241),
    [anon_sym_or] = ACTIONS(6241),
    [anon_sym_and] = ACTIONS(6241),
    [anon_sym_case] = ACTIONS(6241),
    [anon_sym_always] = ACTIONS(6241),
    [anon_sym_covergroup] = ACTIONS(6241),
    [anon_sym_let] = ACTIONS(6241),
    [anon_sym_pulldown] = ACTIONS(6241),
    [anon_sym_pullup] = ACTIONS(6241),
    [anon_sym_cmos] = ACTIONS(6241),
    [anon_sym_rcmos] = ACTIONS(6241),
    [anon_sym_bufif0] = ACTIONS(6241),
    [anon_sym_bufif1] = ACTIONS(6241),
    [anon_sym_notif0] = ACTIONS(6241),
    [anon_sym_notif1] = ACTIONS(6241),
    [anon_sym_nmos] = ACTIONS(6241),
    [anon_sym_pmos] = ACTIONS(6241),
    [anon_sym_rnmos] = ACTIONS(6241),
    [anon_sym_rpmos] = ACTIONS(6241),
    [anon_sym_nand] = ACTIONS(6241),
    [anon_sym_nor] = ACTIONS(6241),
    [anon_sym_xor] = ACTIONS(6241),
    [anon_sym_xnor] = ACTIONS(6241),
    [anon_sym_buf] = ACTIONS(6241),
    [anon_sym_tranif0] = ACTIONS(6241),
    [anon_sym_tranif1] = ACTIONS(6241),
    [anon_sym_rtranif1] = ACTIONS(6241),
    [anon_sym_rtranif0] = ACTIONS(6241),
    [anon_sym_tran] = ACTIONS(6241),
    [anon_sym_rtran] = ACTIONS(6241),
    [anon_sym_generate] = ACTIONS(6241),
    [anon_sym_endgenerate] = ACTIONS(6241),
    [anon_sym_for] = ACTIONS(6241),
    [anon_sym_initial] = ACTIONS(6241),
    [anon_sym_assign] = ACTIONS(6241),
    [anon_sym_alias] = ACTIONS(6241),
    [anon_sym_always_comb] = ACTIONS(6241),
    [anon_sym_always_latch] = ACTIONS(6241),
    [anon_sym_always_ff] = ACTIONS(6241),
    [anon_sym_final] = ACTIONS(6241),
    [anon_sym_global] = ACTIONS(6241),
    [anon_sym_LPAREN_STAR] = ACTIONS(6243),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6243),
    [anon_sym_DOLLARunit] = ACTIONS(6243),
  },
  [5203] = {
    [sym_simple_identifier] = ACTIONS(4812),
    [anon_sym_wire] = ACTIONS(4812),
    [anon_sym_tri] = ACTIONS(4812),
    [anon_sym_tri0] = ACTIONS(4812),
    [anon_sym_tri1] = ACTIONS(4812),
    [anon_sym_wand] = ACTIONS(4812),
    [anon_sym_triand] = ACTIONS(4812),
    [anon_sym_wor] = ACTIONS(4812),
    [anon_sym_trior] = ACTIONS(4812),
    [anon_sym_trireg] = ACTIONS(4812),
    [anon_sym_uwire] = ACTIONS(4812),
    [anon_sym_SEMI] = ACTIONS(4810),
    [anon_sym_extern] = ACTIONS(4812),
    [anon_sym_interface] = ACTIONS(4812),
    [anon_sym_checker] = ACTIONS(4812),
    [anon_sym_virtual] = ACTIONS(4812),
    [anon_sym_class] = ACTIONS(4812),
    [anon_sym_type] = ACTIONS(4812),
    [anon_sym_DOLLARfatal] = ACTIONS(4810),
    [anon_sym_DOLLARerror] = ACTIONS(4810),
    [anon_sym_DOLLARwarning] = ACTIONS(4810),
    [anon_sym_DOLLARinfo] = ACTIONS(4810),
    [anon_sym_default] = ACTIONS(4812),
    [anon_sym_clocking] = ACTIONS(4812),
    [anon_sym_defparam] = ACTIONS(4812),
    [anon_sym_bind] = ACTIONS(4812),
    [anon_sym_rand] = ACTIONS(4812),
    [anon_sym_const] = ACTIONS(4812),
    [anon_sym_function] = ACTIONS(4812),
    [anon_sym_static] = ACTIONS(4812),
    [anon_sym_constraint] = ACTIONS(4812),
    [anon_sym_if] = ACTIONS(4812),
    [anon_sym_else] = ACTIONS(4812),
    [anon_sym_LBRACK] = ACTIONS(4810),
    [anon_sym_localparam] = ACTIONS(4812),
    [anon_sym_parameter] = ACTIONS(4812),
    [anon_sym_var] = ACTIONS(4812),
    [anon_sym_import] = ACTIONS(4812),
    [anon_sym_export] = ACTIONS(4812),
    [anon_sym_genvar] = ACTIONS(4812),
    [anon_sym_interconnect] = ACTIONS(4812),
    [anon_sym_typedef] = ACTIONS(4812),
    [anon_sym_enum] = ACTIONS(4812),
    [anon_sym_struct] = ACTIONS(4812),
    [anon_sym_union] = ACTIONS(4812),
    [anon_sym_nettype] = ACTIONS(4812),
    [anon_sym_automatic] = ACTIONS(4812),
    [anon_sym_string] = ACTIONS(4812),
    [anon_sym_chandle] = ACTIONS(4812),
    [anon_sym_event] = ACTIONS(4812),
    [anon_sym_byte] = ACTIONS(4812),
    [anon_sym_shortint] = ACTIONS(4812),
    [anon_sym_int] = ACTIONS(4812),
    [anon_sym_longint] = ACTIONS(4812),
    [anon_sym_integer] = ACTIONS(4812),
    [anon_sym_time] = ACTIONS(4812),
    [anon_sym_bit] = ACTIONS(4812),
    [anon_sym_logic] = ACTIONS(4812),
    [anon_sym_reg] = ACTIONS(4812),
    [anon_sym_shortreal] = ACTIONS(4812),
    [anon_sym_real] = ACTIONS(4812),
    [anon_sym_realtime] = ACTIONS(4812),
    [anon_sym_supply0] = ACTIONS(4812),
    [anon_sym_supply1] = ACTIONS(4812),
    [anon_sym_signed] = ACTIONS(4812),
    [anon_sym_unsigned] = ACTIONS(4812),
    [anon_sym_task] = ACTIONS(4812),
    [anon_sym_assert] = ACTIONS(4812),
    [anon_sym_property] = ACTIONS(4812),
    [anon_sym_assume] = ACTIONS(4812),
    [anon_sym_cover] = ACTIONS(4812),
    [anon_sym_sequence] = ACTIONS(4812),
    [anon_sym_restrict] = ACTIONS(4812),
    [anon_sym_not] = ACTIONS(4812),
    [anon_sym_or] = ACTIONS(4812),
    [anon_sym_and] = ACTIONS(4812),
    [anon_sym_case] = ACTIONS(4812),
    [anon_sym_always] = ACTIONS(4812),
    [anon_sym_covergroup] = ACTIONS(4812),
    [anon_sym_end] = ACTIONS(4812),
    [anon_sym_let] = ACTIONS(4812),
    [anon_sym_pulldown] = ACTIONS(4812),
    [anon_sym_pullup] = ACTIONS(4812),
    [anon_sym_cmos] = ACTIONS(4812),
    [anon_sym_rcmos] = ACTIONS(4812),
    [anon_sym_bufif0] = ACTIONS(4812),
    [anon_sym_bufif1] = ACTIONS(4812),
    [anon_sym_notif0] = ACTIONS(4812),
    [anon_sym_notif1] = ACTIONS(4812),
    [anon_sym_nmos] = ACTIONS(4812),
    [anon_sym_pmos] = ACTIONS(4812),
    [anon_sym_rnmos] = ACTIONS(4812),
    [anon_sym_rpmos] = ACTIONS(4812),
    [anon_sym_nand] = ACTIONS(4812),
    [anon_sym_nor] = ACTIONS(4812),
    [anon_sym_xor] = ACTIONS(4812),
    [anon_sym_xnor] = ACTIONS(4812),
    [anon_sym_buf] = ACTIONS(4812),
    [anon_sym_tranif0] = ACTIONS(4812),
    [anon_sym_tranif1] = ACTIONS(4812),
    [anon_sym_rtranif1] = ACTIONS(4812),
    [anon_sym_rtranif0] = ACTIONS(4812),
    [anon_sym_tran] = ACTIONS(4812),
    [anon_sym_rtran] = ACTIONS(4812),
    [anon_sym_generate] = ACTIONS(4812),
    [anon_sym_for] = ACTIONS(4812),
    [anon_sym_initial] = ACTIONS(4812),
    [anon_sym_assign] = ACTIONS(4812),
    [anon_sym_alias] = ACTIONS(4812),
    [anon_sym_always_comb] = ACTIONS(4812),
    [anon_sym_always_latch] = ACTIONS(4812),
    [anon_sym_always_ff] = ACTIONS(4812),
    [anon_sym_final] = ACTIONS(4812),
    [anon_sym_global] = ACTIONS(4812),
    [anon_sym_LPAREN_STAR] = ACTIONS(4810),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4810),
    [anon_sym_DOLLARunit] = ACTIONS(4810),
  },
  [5204] = {
    [sym_simple_identifier] = ACTIONS(6035),
    [anon_sym_wire] = ACTIONS(6035),
    [anon_sym_tri] = ACTIONS(6035),
    [anon_sym_tri0] = ACTIONS(6035),
    [anon_sym_tri1] = ACTIONS(6035),
    [anon_sym_wand] = ACTIONS(6035),
    [anon_sym_triand] = ACTIONS(6035),
    [anon_sym_wor] = ACTIONS(6035),
    [anon_sym_trior] = ACTIONS(6035),
    [anon_sym_trireg] = ACTIONS(6035),
    [anon_sym_uwire] = ACTIONS(6035),
    [anon_sym_SEMI] = ACTIONS(6037),
    [anon_sym_extern] = ACTIONS(6035),
    [anon_sym_interface] = ACTIONS(6035),
    [anon_sym_checker] = ACTIONS(6035),
    [anon_sym_virtual] = ACTIONS(6035),
    [anon_sym_class] = ACTIONS(6035),
    [anon_sym_type] = ACTIONS(6035),
    [anon_sym_DOLLARfatal] = ACTIONS(6037),
    [anon_sym_DOLLARerror] = ACTIONS(6037),
    [anon_sym_DOLLARwarning] = ACTIONS(6037),
    [anon_sym_DOLLARinfo] = ACTIONS(6037),
    [anon_sym_default] = ACTIONS(6035),
    [anon_sym_clocking] = ACTIONS(6035),
    [anon_sym_defparam] = ACTIONS(6035),
    [anon_sym_bind] = ACTIONS(6035),
    [anon_sym_rand] = ACTIONS(6035),
    [anon_sym_const] = ACTIONS(6035),
    [anon_sym_function] = ACTIONS(6035),
    [anon_sym_static] = ACTIONS(6035),
    [anon_sym_constraint] = ACTIONS(6035),
    [anon_sym_if] = ACTIONS(6035),
    [anon_sym_else] = ACTIONS(6035),
    [anon_sym_LBRACK] = ACTIONS(6037),
    [anon_sym_localparam] = ACTIONS(6035),
    [anon_sym_parameter] = ACTIONS(6035),
    [anon_sym_var] = ACTIONS(6035),
    [anon_sym_import] = ACTIONS(6035),
    [anon_sym_export] = ACTIONS(6035),
    [anon_sym_genvar] = ACTIONS(6035),
    [anon_sym_interconnect] = ACTIONS(6035),
    [anon_sym_typedef] = ACTIONS(6035),
    [anon_sym_enum] = ACTIONS(6035),
    [anon_sym_struct] = ACTIONS(6035),
    [anon_sym_union] = ACTIONS(6035),
    [anon_sym_nettype] = ACTIONS(6035),
    [anon_sym_automatic] = ACTIONS(6035),
    [anon_sym_string] = ACTIONS(6035),
    [anon_sym_chandle] = ACTIONS(6035),
    [anon_sym_event] = ACTIONS(6035),
    [anon_sym_byte] = ACTIONS(6035),
    [anon_sym_shortint] = ACTIONS(6035),
    [anon_sym_int] = ACTIONS(6035),
    [anon_sym_longint] = ACTIONS(6035),
    [anon_sym_integer] = ACTIONS(6035),
    [anon_sym_time] = ACTIONS(6035),
    [anon_sym_bit] = ACTIONS(6035),
    [anon_sym_logic] = ACTIONS(6035),
    [anon_sym_reg] = ACTIONS(6035),
    [anon_sym_shortreal] = ACTIONS(6035),
    [anon_sym_real] = ACTIONS(6035),
    [anon_sym_realtime] = ACTIONS(6035),
    [anon_sym_supply0] = ACTIONS(6035),
    [anon_sym_supply1] = ACTIONS(6035),
    [anon_sym_signed] = ACTIONS(6035),
    [anon_sym_unsigned] = ACTIONS(6035),
    [anon_sym_task] = ACTIONS(6035),
    [anon_sym_assert] = ACTIONS(6035),
    [anon_sym_property] = ACTIONS(6035),
    [anon_sym_assume] = ACTIONS(6035),
    [anon_sym_cover] = ACTIONS(6035),
    [anon_sym_sequence] = ACTIONS(6035),
    [anon_sym_restrict] = ACTIONS(6035),
    [anon_sym_not] = ACTIONS(6035),
    [anon_sym_or] = ACTIONS(6035),
    [anon_sym_and] = ACTIONS(6035),
    [anon_sym_case] = ACTIONS(6035),
    [anon_sym_always] = ACTIONS(6035),
    [anon_sym_covergroup] = ACTIONS(6035),
    [anon_sym_end] = ACTIONS(6035),
    [anon_sym_let] = ACTIONS(6035),
    [anon_sym_pulldown] = ACTIONS(6035),
    [anon_sym_pullup] = ACTIONS(6035),
    [anon_sym_cmos] = ACTIONS(6035),
    [anon_sym_rcmos] = ACTIONS(6035),
    [anon_sym_bufif0] = ACTIONS(6035),
    [anon_sym_bufif1] = ACTIONS(6035),
    [anon_sym_notif0] = ACTIONS(6035),
    [anon_sym_notif1] = ACTIONS(6035),
    [anon_sym_nmos] = ACTIONS(6035),
    [anon_sym_pmos] = ACTIONS(6035),
    [anon_sym_rnmos] = ACTIONS(6035),
    [anon_sym_rpmos] = ACTIONS(6035),
    [anon_sym_nand] = ACTIONS(6035),
    [anon_sym_nor] = ACTIONS(6035),
    [anon_sym_xor] = ACTIONS(6035),
    [anon_sym_xnor] = ACTIONS(6035),
    [anon_sym_buf] = ACTIONS(6035),
    [anon_sym_tranif0] = ACTIONS(6035),
    [anon_sym_tranif1] = ACTIONS(6035),
    [anon_sym_rtranif1] = ACTIONS(6035),
    [anon_sym_rtranif0] = ACTIONS(6035),
    [anon_sym_tran] = ACTIONS(6035),
    [anon_sym_rtran] = ACTIONS(6035),
    [anon_sym_generate] = ACTIONS(6035),
    [anon_sym_for] = ACTIONS(6035),
    [anon_sym_initial] = ACTIONS(6035),
    [anon_sym_assign] = ACTIONS(6035),
    [anon_sym_alias] = ACTIONS(6035),
    [anon_sym_always_comb] = ACTIONS(6035),
    [anon_sym_always_latch] = ACTIONS(6035),
    [anon_sym_always_ff] = ACTIONS(6035),
    [anon_sym_final] = ACTIONS(6035),
    [anon_sym_global] = ACTIONS(6035),
    [anon_sym_LPAREN_STAR] = ACTIONS(6037),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6037),
    [anon_sym_DOLLARunit] = ACTIONS(6037),
  },
  [5205] = {
    [sym_simple_identifier] = ACTIONS(4542),
    [anon_sym_wire] = ACTIONS(4542),
    [anon_sym_tri] = ACTIONS(4542),
    [anon_sym_tri0] = ACTIONS(4542),
    [anon_sym_tri1] = ACTIONS(4542),
    [anon_sym_wand] = ACTIONS(4542),
    [anon_sym_triand] = ACTIONS(4542),
    [anon_sym_wor] = ACTIONS(4542),
    [anon_sym_trior] = ACTIONS(4542),
    [anon_sym_trireg] = ACTIONS(4542),
    [anon_sym_uwire] = ACTIONS(4542),
    [anon_sym_SEMI] = ACTIONS(4540),
    [anon_sym_extern] = ACTIONS(4542),
    [anon_sym_interface] = ACTIONS(4542),
    [anon_sym_checker] = ACTIONS(4542),
    [anon_sym_virtual] = ACTIONS(4542),
    [anon_sym_class] = ACTIONS(4542),
    [anon_sym_type] = ACTIONS(4542),
    [anon_sym_DOLLARfatal] = ACTIONS(4540),
    [anon_sym_DOLLARerror] = ACTIONS(4540),
    [anon_sym_DOLLARwarning] = ACTIONS(4540),
    [anon_sym_DOLLARinfo] = ACTIONS(4540),
    [anon_sym_default] = ACTIONS(4542),
    [anon_sym_clocking] = ACTIONS(4542),
    [anon_sym_defparam] = ACTIONS(4542),
    [anon_sym_bind] = ACTIONS(4542),
    [anon_sym_rand] = ACTIONS(4542),
    [anon_sym_const] = ACTIONS(4542),
    [anon_sym_function] = ACTIONS(4542),
    [anon_sym_static] = ACTIONS(4542),
    [anon_sym_constraint] = ACTIONS(4542),
    [anon_sym_if] = ACTIONS(4542),
    [anon_sym_else] = ACTIONS(4542),
    [anon_sym_LBRACK] = ACTIONS(4540),
    [anon_sym_localparam] = ACTIONS(4542),
    [anon_sym_parameter] = ACTIONS(4542),
    [anon_sym_var] = ACTIONS(4542),
    [anon_sym_import] = ACTIONS(4542),
    [anon_sym_export] = ACTIONS(4542),
    [anon_sym_genvar] = ACTIONS(4542),
    [anon_sym_interconnect] = ACTIONS(4542),
    [anon_sym_typedef] = ACTIONS(4542),
    [anon_sym_enum] = ACTIONS(4542),
    [anon_sym_struct] = ACTIONS(4542),
    [anon_sym_union] = ACTIONS(4542),
    [anon_sym_nettype] = ACTIONS(4542),
    [anon_sym_automatic] = ACTIONS(4542),
    [anon_sym_string] = ACTIONS(4542),
    [anon_sym_chandle] = ACTIONS(4542),
    [anon_sym_event] = ACTIONS(4542),
    [anon_sym_byte] = ACTIONS(4542),
    [anon_sym_shortint] = ACTIONS(4542),
    [anon_sym_int] = ACTIONS(4542),
    [anon_sym_longint] = ACTIONS(4542),
    [anon_sym_integer] = ACTIONS(4542),
    [anon_sym_time] = ACTIONS(4542),
    [anon_sym_bit] = ACTIONS(4542),
    [anon_sym_logic] = ACTIONS(4542),
    [anon_sym_reg] = ACTIONS(4542),
    [anon_sym_shortreal] = ACTIONS(4542),
    [anon_sym_real] = ACTIONS(4542),
    [anon_sym_realtime] = ACTIONS(4542),
    [anon_sym_supply0] = ACTIONS(4542),
    [anon_sym_supply1] = ACTIONS(4542),
    [anon_sym_signed] = ACTIONS(4542),
    [anon_sym_unsigned] = ACTIONS(4542),
    [anon_sym_task] = ACTIONS(4542),
    [anon_sym_assert] = ACTIONS(4542),
    [anon_sym_property] = ACTIONS(4542),
    [anon_sym_assume] = ACTIONS(4542),
    [anon_sym_cover] = ACTIONS(4542),
    [anon_sym_sequence] = ACTIONS(4542),
    [anon_sym_restrict] = ACTIONS(4542),
    [anon_sym_not] = ACTIONS(4542),
    [anon_sym_or] = ACTIONS(4542),
    [anon_sym_and] = ACTIONS(4542),
    [anon_sym_case] = ACTIONS(4542),
    [anon_sym_always] = ACTIONS(4542),
    [anon_sym_covergroup] = ACTIONS(4542),
    [anon_sym_end] = ACTIONS(4542),
    [anon_sym_let] = ACTIONS(4542),
    [anon_sym_pulldown] = ACTIONS(4542),
    [anon_sym_pullup] = ACTIONS(4542),
    [anon_sym_cmos] = ACTIONS(4542),
    [anon_sym_rcmos] = ACTIONS(4542),
    [anon_sym_bufif0] = ACTIONS(4542),
    [anon_sym_bufif1] = ACTIONS(4542),
    [anon_sym_notif0] = ACTIONS(4542),
    [anon_sym_notif1] = ACTIONS(4542),
    [anon_sym_nmos] = ACTIONS(4542),
    [anon_sym_pmos] = ACTIONS(4542),
    [anon_sym_rnmos] = ACTIONS(4542),
    [anon_sym_rpmos] = ACTIONS(4542),
    [anon_sym_nand] = ACTIONS(4542),
    [anon_sym_nor] = ACTIONS(4542),
    [anon_sym_xor] = ACTIONS(4542),
    [anon_sym_xnor] = ACTIONS(4542),
    [anon_sym_buf] = ACTIONS(4542),
    [anon_sym_tranif0] = ACTIONS(4542),
    [anon_sym_tranif1] = ACTIONS(4542),
    [anon_sym_rtranif1] = ACTIONS(4542),
    [anon_sym_rtranif0] = ACTIONS(4542),
    [anon_sym_tran] = ACTIONS(4542),
    [anon_sym_rtran] = ACTIONS(4542),
    [anon_sym_generate] = ACTIONS(4542),
    [anon_sym_for] = ACTIONS(4542),
    [anon_sym_initial] = ACTIONS(4542),
    [anon_sym_assign] = ACTIONS(4542),
    [anon_sym_alias] = ACTIONS(4542),
    [anon_sym_always_comb] = ACTIONS(4542),
    [anon_sym_always_latch] = ACTIONS(4542),
    [anon_sym_always_ff] = ACTIONS(4542),
    [anon_sym_final] = ACTIONS(4542),
    [anon_sym_global] = ACTIONS(4542),
    [anon_sym_LPAREN_STAR] = ACTIONS(4540),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4540),
    [anon_sym_DOLLARunit] = ACTIONS(4540),
  },
  [5206] = {
    [sym_simple_identifier] = ACTIONS(4868),
    [anon_sym_wire] = ACTIONS(4868),
    [anon_sym_tri] = ACTIONS(4868),
    [anon_sym_tri0] = ACTIONS(4868),
    [anon_sym_tri1] = ACTIONS(4868),
    [anon_sym_wand] = ACTIONS(4868),
    [anon_sym_triand] = ACTIONS(4868),
    [anon_sym_wor] = ACTIONS(4868),
    [anon_sym_trior] = ACTIONS(4868),
    [anon_sym_trireg] = ACTIONS(4868),
    [anon_sym_uwire] = ACTIONS(4868),
    [anon_sym_SEMI] = ACTIONS(4866),
    [anon_sym_extern] = ACTIONS(4868),
    [anon_sym_interface] = ACTIONS(4868),
    [anon_sym_checker] = ACTIONS(4868),
    [anon_sym_virtual] = ACTIONS(4868),
    [anon_sym_class] = ACTIONS(4868),
    [anon_sym_type] = ACTIONS(4868),
    [anon_sym_DOLLARfatal] = ACTIONS(4866),
    [anon_sym_DOLLARerror] = ACTIONS(4866),
    [anon_sym_DOLLARwarning] = ACTIONS(4866),
    [anon_sym_DOLLARinfo] = ACTIONS(4866),
    [anon_sym_default] = ACTIONS(4868),
    [anon_sym_clocking] = ACTIONS(4868),
    [anon_sym_defparam] = ACTIONS(4868),
    [anon_sym_bind] = ACTIONS(4868),
    [anon_sym_rand] = ACTIONS(4868),
    [anon_sym_const] = ACTIONS(4868),
    [anon_sym_function] = ACTIONS(4868),
    [anon_sym_static] = ACTIONS(4868),
    [anon_sym_constraint] = ACTIONS(4868),
    [anon_sym_if] = ACTIONS(4868),
    [anon_sym_else] = ACTIONS(4868),
    [anon_sym_LBRACK] = ACTIONS(4866),
    [anon_sym_localparam] = ACTIONS(4868),
    [anon_sym_parameter] = ACTIONS(4868),
    [anon_sym_var] = ACTIONS(4868),
    [anon_sym_import] = ACTIONS(4868),
    [anon_sym_export] = ACTIONS(4868),
    [anon_sym_genvar] = ACTIONS(4868),
    [anon_sym_interconnect] = ACTIONS(4868),
    [anon_sym_typedef] = ACTIONS(4868),
    [anon_sym_enum] = ACTIONS(4868),
    [anon_sym_struct] = ACTIONS(4868),
    [anon_sym_union] = ACTIONS(4868),
    [anon_sym_nettype] = ACTIONS(4868),
    [anon_sym_automatic] = ACTIONS(4868),
    [anon_sym_string] = ACTIONS(4868),
    [anon_sym_chandle] = ACTIONS(4868),
    [anon_sym_event] = ACTIONS(4868),
    [anon_sym_byte] = ACTIONS(4868),
    [anon_sym_shortint] = ACTIONS(4868),
    [anon_sym_int] = ACTIONS(4868),
    [anon_sym_longint] = ACTIONS(4868),
    [anon_sym_integer] = ACTIONS(4868),
    [anon_sym_time] = ACTIONS(4868),
    [anon_sym_bit] = ACTIONS(4868),
    [anon_sym_logic] = ACTIONS(4868),
    [anon_sym_reg] = ACTIONS(4868),
    [anon_sym_shortreal] = ACTIONS(4868),
    [anon_sym_real] = ACTIONS(4868),
    [anon_sym_realtime] = ACTIONS(4868),
    [anon_sym_supply0] = ACTIONS(4868),
    [anon_sym_supply1] = ACTIONS(4868),
    [anon_sym_signed] = ACTIONS(4868),
    [anon_sym_unsigned] = ACTIONS(4868),
    [anon_sym_task] = ACTIONS(4868),
    [anon_sym_assert] = ACTIONS(4868),
    [anon_sym_property] = ACTIONS(4868),
    [anon_sym_assume] = ACTIONS(4868),
    [anon_sym_cover] = ACTIONS(4868),
    [anon_sym_sequence] = ACTIONS(4868),
    [anon_sym_restrict] = ACTIONS(4868),
    [anon_sym_not] = ACTIONS(4868),
    [anon_sym_or] = ACTIONS(4868),
    [anon_sym_and] = ACTIONS(4868),
    [anon_sym_case] = ACTIONS(4868),
    [anon_sym_always] = ACTIONS(4868),
    [anon_sym_covergroup] = ACTIONS(4868),
    [anon_sym_end] = ACTIONS(4868),
    [anon_sym_let] = ACTIONS(4868),
    [anon_sym_pulldown] = ACTIONS(4868),
    [anon_sym_pullup] = ACTIONS(4868),
    [anon_sym_cmos] = ACTIONS(4868),
    [anon_sym_rcmos] = ACTIONS(4868),
    [anon_sym_bufif0] = ACTIONS(4868),
    [anon_sym_bufif1] = ACTIONS(4868),
    [anon_sym_notif0] = ACTIONS(4868),
    [anon_sym_notif1] = ACTIONS(4868),
    [anon_sym_nmos] = ACTIONS(4868),
    [anon_sym_pmos] = ACTIONS(4868),
    [anon_sym_rnmos] = ACTIONS(4868),
    [anon_sym_rpmos] = ACTIONS(4868),
    [anon_sym_nand] = ACTIONS(4868),
    [anon_sym_nor] = ACTIONS(4868),
    [anon_sym_xor] = ACTIONS(4868),
    [anon_sym_xnor] = ACTIONS(4868),
    [anon_sym_buf] = ACTIONS(4868),
    [anon_sym_tranif0] = ACTIONS(4868),
    [anon_sym_tranif1] = ACTIONS(4868),
    [anon_sym_rtranif1] = ACTIONS(4868),
    [anon_sym_rtranif0] = ACTIONS(4868),
    [anon_sym_tran] = ACTIONS(4868),
    [anon_sym_rtran] = ACTIONS(4868),
    [anon_sym_generate] = ACTIONS(4868),
    [anon_sym_for] = ACTIONS(4868),
    [anon_sym_initial] = ACTIONS(4868),
    [anon_sym_assign] = ACTIONS(4868),
    [anon_sym_alias] = ACTIONS(4868),
    [anon_sym_always_comb] = ACTIONS(4868),
    [anon_sym_always_latch] = ACTIONS(4868),
    [anon_sym_always_ff] = ACTIONS(4868),
    [anon_sym_final] = ACTIONS(4868),
    [anon_sym_global] = ACTIONS(4868),
    [anon_sym_LPAREN_STAR] = ACTIONS(4866),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4866),
    [anon_sym_DOLLARunit] = ACTIONS(4866),
  },
  [5207] = {
    [sym_simple_identifier] = ACTIONS(6573),
    [anon_sym_wire] = ACTIONS(6573),
    [anon_sym_tri] = ACTIONS(6573),
    [anon_sym_tri0] = ACTIONS(6573),
    [anon_sym_tri1] = ACTIONS(6573),
    [anon_sym_wand] = ACTIONS(6573),
    [anon_sym_triand] = ACTIONS(6573),
    [anon_sym_wor] = ACTIONS(6573),
    [anon_sym_trior] = ACTIONS(6573),
    [anon_sym_trireg] = ACTIONS(6573),
    [anon_sym_uwire] = ACTIONS(6573),
    [anon_sym_SEMI] = ACTIONS(6575),
    [anon_sym_extern] = ACTIONS(6573),
    [anon_sym_interface] = ACTIONS(6573),
    [anon_sym_checker] = ACTIONS(6573),
    [anon_sym_virtual] = ACTIONS(6573),
    [anon_sym_class] = ACTIONS(6573),
    [anon_sym_type] = ACTIONS(6573),
    [anon_sym_DOLLARfatal] = ACTIONS(6575),
    [anon_sym_DOLLARerror] = ACTIONS(6575),
    [anon_sym_DOLLARwarning] = ACTIONS(6575),
    [anon_sym_DOLLARinfo] = ACTIONS(6575),
    [anon_sym_default] = ACTIONS(6573),
    [anon_sym_clocking] = ACTIONS(6573),
    [anon_sym_defparam] = ACTIONS(6573),
    [anon_sym_bind] = ACTIONS(6573),
    [anon_sym_rand] = ACTIONS(6573),
    [anon_sym_const] = ACTIONS(6573),
    [anon_sym_function] = ACTIONS(6573),
    [anon_sym_static] = ACTIONS(6573),
    [anon_sym_constraint] = ACTIONS(6573),
    [anon_sym_if] = ACTIONS(6573),
    [anon_sym_else] = ACTIONS(6573),
    [anon_sym_LBRACK] = ACTIONS(6575),
    [anon_sym_localparam] = ACTIONS(6573),
    [anon_sym_parameter] = ACTIONS(6573),
    [anon_sym_var] = ACTIONS(6573),
    [anon_sym_import] = ACTIONS(6573),
    [anon_sym_export] = ACTIONS(6573),
    [anon_sym_genvar] = ACTIONS(6573),
    [anon_sym_interconnect] = ACTIONS(6573),
    [anon_sym_typedef] = ACTIONS(6573),
    [anon_sym_enum] = ACTIONS(6573),
    [anon_sym_struct] = ACTIONS(6573),
    [anon_sym_union] = ACTIONS(6573),
    [anon_sym_nettype] = ACTIONS(6573),
    [anon_sym_automatic] = ACTIONS(6573),
    [anon_sym_string] = ACTIONS(6573),
    [anon_sym_chandle] = ACTIONS(6573),
    [anon_sym_event] = ACTIONS(6573),
    [anon_sym_byte] = ACTIONS(6573),
    [anon_sym_shortint] = ACTIONS(6573),
    [anon_sym_int] = ACTIONS(6573),
    [anon_sym_longint] = ACTIONS(6573),
    [anon_sym_integer] = ACTIONS(6573),
    [anon_sym_time] = ACTIONS(6573),
    [anon_sym_bit] = ACTIONS(6573),
    [anon_sym_logic] = ACTIONS(6573),
    [anon_sym_reg] = ACTIONS(6573),
    [anon_sym_shortreal] = ACTIONS(6573),
    [anon_sym_real] = ACTIONS(6573),
    [anon_sym_realtime] = ACTIONS(6573),
    [anon_sym_supply0] = ACTIONS(6573),
    [anon_sym_supply1] = ACTIONS(6573),
    [anon_sym_signed] = ACTIONS(6573),
    [anon_sym_unsigned] = ACTIONS(6573),
    [anon_sym_task] = ACTIONS(6573),
    [anon_sym_assert] = ACTIONS(6573),
    [anon_sym_property] = ACTIONS(6573),
    [anon_sym_assume] = ACTIONS(6573),
    [anon_sym_cover] = ACTIONS(6573),
    [anon_sym_sequence] = ACTIONS(6573),
    [anon_sym_restrict] = ACTIONS(6573),
    [anon_sym_not] = ACTIONS(6573),
    [anon_sym_or] = ACTIONS(6573),
    [anon_sym_and] = ACTIONS(6573),
    [anon_sym_case] = ACTIONS(6573),
    [anon_sym_always] = ACTIONS(6573),
    [anon_sym_covergroup] = ACTIONS(6573),
    [anon_sym_end] = ACTIONS(6573),
    [anon_sym_let] = ACTIONS(6573),
    [anon_sym_pulldown] = ACTIONS(6573),
    [anon_sym_pullup] = ACTIONS(6573),
    [anon_sym_cmos] = ACTIONS(6573),
    [anon_sym_rcmos] = ACTIONS(6573),
    [anon_sym_bufif0] = ACTIONS(6573),
    [anon_sym_bufif1] = ACTIONS(6573),
    [anon_sym_notif0] = ACTIONS(6573),
    [anon_sym_notif1] = ACTIONS(6573),
    [anon_sym_nmos] = ACTIONS(6573),
    [anon_sym_pmos] = ACTIONS(6573),
    [anon_sym_rnmos] = ACTIONS(6573),
    [anon_sym_rpmos] = ACTIONS(6573),
    [anon_sym_nand] = ACTIONS(6573),
    [anon_sym_nor] = ACTIONS(6573),
    [anon_sym_xor] = ACTIONS(6573),
    [anon_sym_xnor] = ACTIONS(6573),
    [anon_sym_buf] = ACTIONS(6573),
    [anon_sym_tranif0] = ACTIONS(6573),
    [anon_sym_tranif1] = ACTIONS(6573),
    [anon_sym_rtranif1] = ACTIONS(6573),
    [anon_sym_rtranif0] = ACTIONS(6573),
    [anon_sym_tran] = ACTIONS(6573),
    [anon_sym_rtran] = ACTIONS(6573),
    [anon_sym_generate] = ACTIONS(6573),
    [anon_sym_for] = ACTIONS(6573),
    [anon_sym_initial] = ACTIONS(6573),
    [anon_sym_assign] = ACTIONS(6573),
    [anon_sym_alias] = ACTIONS(6573),
    [anon_sym_always_comb] = ACTIONS(6573),
    [anon_sym_always_latch] = ACTIONS(6573),
    [anon_sym_always_ff] = ACTIONS(6573),
    [anon_sym_final] = ACTIONS(6573),
    [anon_sym_global] = ACTIONS(6573),
    [anon_sym_LPAREN_STAR] = ACTIONS(6575),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6575),
    [anon_sym_DOLLARunit] = ACTIONS(6575),
  },
  [5208] = {
    [sym_simple_identifier] = ACTIONS(6533),
    [anon_sym_wire] = ACTIONS(6533),
    [anon_sym_tri] = ACTIONS(6533),
    [anon_sym_tri0] = ACTIONS(6533),
    [anon_sym_tri1] = ACTIONS(6533),
    [anon_sym_wand] = ACTIONS(6533),
    [anon_sym_triand] = ACTIONS(6533),
    [anon_sym_wor] = ACTIONS(6533),
    [anon_sym_trior] = ACTIONS(6533),
    [anon_sym_trireg] = ACTIONS(6533),
    [anon_sym_uwire] = ACTIONS(6533),
    [anon_sym_SEMI] = ACTIONS(6535),
    [anon_sym_extern] = ACTIONS(6533),
    [anon_sym_interface] = ACTIONS(6533),
    [anon_sym_checker] = ACTIONS(6533),
    [anon_sym_virtual] = ACTIONS(6533),
    [anon_sym_class] = ACTIONS(6533),
    [anon_sym_type] = ACTIONS(6533),
    [anon_sym_DOLLARfatal] = ACTIONS(6535),
    [anon_sym_DOLLARerror] = ACTIONS(6535),
    [anon_sym_DOLLARwarning] = ACTIONS(6535),
    [anon_sym_DOLLARinfo] = ACTIONS(6535),
    [anon_sym_default] = ACTIONS(6533),
    [anon_sym_clocking] = ACTIONS(6533),
    [anon_sym_defparam] = ACTIONS(6533),
    [anon_sym_bind] = ACTIONS(6533),
    [anon_sym_rand] = ACTIONS(6533),
    [anon_sym_const] = ACTIONS(6533),
    [anon_sym_function] = ACTIONS(6533),
    [anon_sym_static] = ACTIONS(6533),
    [anon_sym_constraint] = ACTIONS(6533),
    [anon_sym_if] = ACTIONS(6533),
    [anon_sym_else] = ACTIONS(6533),
    [anon_sym_LBRACK] = ACTIONS(6535),
    [anon_sym_localparam] = ACTIONS(6533),
    [anon_sym_parameter] = ACTIONS(6533),
    [anon_sym_var] = ACTIONS(6533),
    [anon_sym_import] = ACTIONS(6533),
    [anon_sym_export] = ACTIONS(6533),
    [anon_sym_genvar] = ACTIONS(6533),
    [anon_sym_interconnect] = ACTIONS(6533),
    [anon_sym_typedef] = ACTIONS(6533),
    [anon_sym_enum] = ACTIONS(6533),
    [anon_sym_struct] = ACTIONS(6533),
    [anon_sym_union] = ACTIONS(6533),
    [anon_sym_nettype] = ACTIONS(6533),
    [anon_sym_automatic] = ACTIONS(6533),
    [anon_sym_string] = ACTIONS(6533),
    [anon_sym_chandle] = ACTIONS(6533),
    [anon_sym_event] = ACTIONS(6533),
    [anon_sym_byte] = ACTIONS(6533),
    [anon_sym_shortint] = ACTIONS(6533),
    [anon_sym_int] = ACTIONS(6533),
    [anon_sym_longint] = ACTIONS(6533),
    [anon_sym_integer] = ACTIONS(6533),
    [anon_sym_time] = ACTIONS(6533),
    [anon_sym_bit] = ACTIONS(6533),
    [anon_sym_logic] = ACTIONS(6533),
    [anon_sym_reg] = ACTIONS(6533),
    [anon_sym_shortreal] = ACTIONS(6533),
    [anon_sym_real] = ACTIONS(6533),
    [anon_sym_realtime] = ACTIONS(6533),
    [anon_sym_supply0] = ACTIONS(6533),
    [anon_sym_supply1] = ACTIONS(6533),
    [anon_sym_signed] = ACTIONS(6533),
    [anon_sym_unsigned] = ACTIONS(6533),
    [anon_sym_task] = ACTIONS(6533),
    [anon_sym_assert] = ACTIONS(6533),
    [anon_sym_property] = ACTIONS(6533),
    [anon_sym_assume] = ACTIONS(6533),
    [anon_sym_cover] = ACTIONS(6533),
    [anon_sym_sequence] = ACTIONS(6533),
    [anon_sym_restrict] = ACTIONS(6533),
    [anon_sym_not] = ACTIONS(6533),
    [anon_sym_or] = ACTIONS(6533),
    [anon_sym_and] = ACTIONS(6533),
    [anon_sym_case] = ACTIONS(6533),
    [anon_sym_always] = ACTIONS(6533),
    [anon_sym_covergroup] = ACTIONS(6533),
    [anon_sym_end] = ACTIONS(6533),
    [anon_sym_let] = ACTIONS(6533),
    [anon_sym_pulldown] = ACTIONS(6533),
    [anon_sym_pullup] = ACTIONS(6533),
    [anon_sym_cmos] = ACTIONS(6533),
    [anon_sym_rcmos] = ACTIONS(6533),
    [anon_sym_bufif0] = ACTIONS(6533),
    [anon_sym_bufif1] = ACTIONS(6533),
    [anon_sym_notif0] = ACTIONS(6533),
    [anon_sym_notif1] = ACTIONS(6533),
    [anon_sym_nmos] = ACTIONS(6533),
    [anon_sym_pmos] = ACTIONS(6533),
    [anon_sym_rnmos] = ACTIONS(6533),
    [anon_sym_rpmos] = ACTIONS(6533),
    [anon_sym_nand] = ACTIONS(6533),
    [anon_sym_nor] = ACTIONS(6533),
    [anon_sym_xor] = ACTIONS(6533),
    [anon_sym_xnor] = ACTIONS(6533),
    [anon_sym_buf] = ACTIONS(6533),
    [anon_sym_tranif0] = ACTIONS(6533),
    [anon_sym_tranif1] = ACTIONS(6533),
    [anon_sym_rtranif1] = ACTIONS(6533),
    [anon_sym_rtranif0] = ACTIONS(6533),
    [anon_sym_tran] = ACTIONS(6533),
    [anon_sym_rtran] = ACTIONS(6533),
    [anon_sym_generate] = ACTIONS(6533),
    [anon_sym_for] = ACTIONS(6533),
    [anon_sym_initial] = ACTIONS(6533),
    [anon_sym_assign] = ACTIONS(6533),
    [anon_sym_alias] = ACTIONS(6533),
    [anon_sym_always_comb] = ACTIONS(6533),
    [anon_sym_always_latch] = ACTIONS(6533),
    [anon_sym_always_ff] = ACTIONS(6533),
    [anon_sym_final] = ACTIONS(6533),
    [anon_sym_global] = ACTIONS(6533),
    [anon_sym_LPAREN_STAR] = ACTIONS(6535),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6535),
    [anon_sym_DOLLARunit] = ACTIONS(6535),
  },
  [5209] = {
    [sym_simple_identifier] = ACTIONS(6589),
    [anon_sym_wire] = ACTIONS(6589),
    [anon_sym_tri] = ACTIONS(6589),
    [anon_sym_tri0] = ACTIONS(6589),
    [anon_sym_tri1] = ACTIONS(6589),
    [anon_sym_wand] = ACTIONS(6589),
    [anon_sym_triand] = ACTIONS(6589),
    [anon_sym_wor] = ACTIONS(6589),
    [anon_sym_trior] = ACTIONS(6589),
    [anon_sym_trireg] = ACTIONS(6589),
    [anon_sym_uwire] = ACTIONS(6589),
    [anon_sym_SEMI] = ACTIONS(6591),
    [anon_sym_extern] = ACTIONS(6589),
    [anon_sym_interface] = ACTIONS(6589),
    [anon_sym_checker] = ACTIONS(6589),
    [anon_sym_virtual] = ACTIONS(6589),
    [anon_sym_class] = ACTIONS(6589),
    [anon_sym_type] = ACTIONS(6589),
    [anon_sym_DOLLARfatal] = ACTIONS(6591),
    [anon_sym_DOLLARerror] = ACTIONS(6591),
    [anon_sym_DOLLARwarning] = ACTIONS(6591),
    [anon_sym_DOLLARinfo] = ACTIONS(6591),
    [anon_sym_default] = ACTIONS(6589),
    [anon_sym_clocking] = ACTIONS(6589),
    [anon_sym_defparam] = ACTIONS(6589),
    [anon_sym_bind] = ACTIONS(6589),
    [anon_sym_rand] = ACTIONS(6589),
    [anon_sym_const] = ACTIONS(6589),
    [anon_sym_function] = ACTIONS(6589),
    [anon_sym_static] = ACTIONS(6589),
    [anon_sym_constraint] = ACTIONS(6589),
    [anon_sym_if] = ACTIONS(6589),
    [anon_sym_else] = ACTIONS(6589),
    [anon_sym_LBRACK] = ACTIONS(6591),
    [anon_sym_localparam] = ACTIONS(6589),
    [anon_sym_parameter] = ACTIONS(6589),
    [anon_sym_var] = ACTIONS(6589),
    [anon_sym_import] = ACTIONS(6589),
    [anon_sym_export] = ACTIONS(6589),
    [anon_sym_genvar] = ACTIONS(6589),
    [anon_sym_interconnect] = ACTIONS(6589),
    [anon_sym_typedef] = ACTIONS(6589),
    [anon_sym_enum] = ACTIONS(6589),
    [anon_sym_struct] = ACTIONS(6589),
    [anon_sym_union] = ACTIONS(6589),
    [anon_sym_nettype] = ACTIONS(6589),
    [anon_sym_automatic] = ACTIONS(6589),
    [anon_sym_string] = ACTIONS(6589),
    [anon_sym_chandle] = ACTIONS(6589),
    [anon_sym_event] = ACTIONS(6589),
    [anon_sym_byte] = ACTIONS(6589),
    [anon_sym_shortint] = ACTIONS(6589),
    [anon_sym_int] = ACTIONS(6589),
    [anon_sym_longint] = ACTIONS(6589),
    [anon_sym_integer] = ACTIONS(6589),
    [anon_sym_time] = ACTIONS(6589),
    [anon_sym_bit] = ACTIONS(6589),
    [anon_sym_logic] = ACTIONS(6589),
    [anon_sym_reg] = ACTIONS(6589),
    [anon_sym_shortreal] = ACTIONS(6589),
    [anon_sym_real] = ACTIONS(6589),
    [anon_sym_realtime] = ACTIONS(6589),
    [anon_sym_supply0] = ACTIONS(6589),
    [anon_sym_supply1] = ACTIONS(6589),
    [anon_sym_signed] = ACTIONS(6589),
    [anon_sym_unsigned] = ACTIONS(6589),
    [anon_sym_task] = ACTIONS(6589),
    [anon_sym_assert] = ACTIONS(6589),
    [anon_sym_property] = ACTIONS(6589),
    [anon_sym_assume] = ACTIONS(6589),
    [anon_sym_cover] = ACTIONS(6589),
    [anon_sym_sequence] = ACTIONS(6589),
    [anon_sym_restrict] = ACTIONS(6589),
    [anon_sym_not] = ACTIONS(6589),
    [anon_sym_or] = ACTIONS(6589),
    [anon_sym_and] = ACTIONS(6589),
    [anon_sym_case] = ACTIONS(6589),
    [anon_sym_always] = ACTIONS(6589),
    [anon_sym_covergroup] = ACTIONS(6589),
    [anon_sym_let] = ACTIONS(6589),
    [anon_sym_pulldown] = ACTIONS(6589),
    [anon_sym_pullup] = ACTIONS(6589),
    [anon_sym_cmos] = ACTIONS(6589),
    [anon_sym_rcmos] = ACTIONS(6589),
    [anon_sym_bufif0] = ACTIONS(6589),
    [anon_sym_bufif1] = ACTIONS(6589),
    [anon_sym_notif0] = ACTIONS(6589),
    [anon_sym_notif1] = ACTIONS(6589),
    [anon_sym_nmos] = ACTIONS(6589),
    [anon_sym_pmos] = ACTIONS(6589),
    [anon_sym_rnmos] = ACTIONS(6589),
    [anon_sym_rpmos] = ACTIONS(6589),
    [anon_sym_nand] = ACTIONS(6589),
    [anon_sym_nor] = ACTIONS(6589),
    [anon_sym_xor] = ACTIONS(6589),
    [anon_sym_xnor] = ACTIONS(6589),
    [anon_sym_buf] = ACTIONS(6589),
    [anon_sym_tranif0] = ACTIONS(6589),
    [anon_sym_tranif1] = ACTIONS(6589),
    [anon_sym_rtranif1] = ACTIONS(6589),
    [anon_sym_rtranif0] = ACTIONS(6589),
    [anon_sym_tran] = ACTIONS(6589),
    [anon_sym_rtran] = ACTIONS(6589),
    [anon_sym_generate] = ACTIONS(6589),
    [anon_sym_endgenerate] = ACTIONS(6589),
    [anon_sym_for] = ACTIONS(6589),
    [anon_sym_initial] = ACTIONS(6589),
    [anon_sym_assign] = ACTIONS(6589),
    [anon_sym_alias] = ACTIONS(6589),
    [anon_sym_always_comb] = ACTIONS(6589),
    [anon_sym_always_latch] = ACTIONS(6589),
    [anon_sym_always_ff] = ACTIONS(6589),
    [anon_sym_final] = ACTIONS(6589),
    [anon_sym_global] = ACTIONS(6589),
    [anon_sym_LPAREN_STAR] = ACTIONS(6591),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6591),
    [anon_sym_DOLLARunit] = ACTIONS(6591),
  },
  [5210] = {
    [sym_simple_identifier] = ACTIONS(5214),
    [anon_sym_wire] = ACTIONS(5214),
    [anon_sym_tri] = ACTIONS(5214),
    [anon_sym_tri0] = ACTIONS(5214),
    [anon_sym_tri1] = ACTIONS(5214),
    [anon_sym_wand] = ACTIONS(5214),
    [anon_sym_triand] = ACTIONS(5214),
    [anon_sym_wor] = ACTIONS(5214),
    [anon_sym_trior] = ACTIONS(5214),
    [anon_sym_trireg] = ACTIONS(5214),
    [anon_sym_uwire] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5212),
    [anon_sym_extern] = ACTIONS(5214),
    [anon_sym_interface] = ACTIONS(5214),
    [anon_sym_checker] = ACTIONS(5214),
    [anon_sym_virtual] = ACTIONS(5214),
    [anon_sym_class] = ACTIONS(5214),
    [anon_sym_type] = ACTIONS(5214),
    [anon_sym_DOLLARfatal] = ACTIONS(5212),
    [anon_sym_DOLLARerror] = ACTIONS(5212),
    [anon_sym_DOLLARwarning] = ACTIONS(5212),
    [anon_sym_DOLLARinfo] = ACTIONS(5212),
    [anon_sym_default] = ACTIONS(5214),
    [anon_sym_clocking] = ACTIONS(5214),
    [anon_sym_defparam] = ACTIONS(5214),
    [anon_sym_bind] = ACTIONS(5214),
    [anon_sym_rand] = ACTIONS(5214),
    [anon_sym_const] = ACTIONS(5214),
    [anon_sym_function] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(5214),
    [anon_sym_constraint] = ACTIONS(5214),
    [anon_sym_if] = ACTIONS(5214),
    [anon_sym_else] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5212),
    [anon_sym_localparam] = ACTIONS(5214),
    [anon_sym_parameter] = ACTIONS(5214),
    [anon_sym_var] = ACTIONS(5214),
    [anon_sym_import] = ACTIONS(5214),
    [anon_sym_export] = ACTIONS(5214),
    [anon_sym_genvar] = ACTIONS(5214),
    [anon_sym_interconnect] = ACTIONS(5214),
    [anon_sym_typedef] = ACTIONS(5214),
    [anon_sym_enum] = ACTIONS(5214),
    [anon_sym_struct] = ACTIONS(5214),
    [anon_sym_union] = ACTIONS(5214),
    [anon_sym_nettype] = ACTIONS(5214),
    [anon_sym_automatic] = ACTIONS(5214),
    [anon_sym_string] = ACTIONS(5214),
    [anon_sym_chandle] = ACTIONS(5214),
    [anon_sym_event] = ACTIONS(5214),
    [anon_sym_byte] = ACTIONS(5214),
    [anon_sym_shortint] = ACTIONS(5214),
    [anon_sym_int] = ACTIONS(5214),
    [anon_sym_longint] = ACTIONS(5214),
    [anon_sym_integer] = ACTIONS(5214),
    [anon_sym_time] = ACTIONS(5214),
    [anon_sym_bit] = ACTIONS(5214),
    [anon_sym_logic] = ACTIONS(5214),
    [anon_sym_reg] = ACTIONS(5214),
    [anon_sym_shortreal] = ACTIONS(5214),
    [anon_sym_real] = ACTIONS(5214),
    [anon_sym_realtime] = ACTIONS(5214),
    [anon_sym_supply0] = ACTIONS(5214),
    [anon_sym_supply1] = ACTIONS(5214),
    [anon_sym_signed] = ACTIONS(5214),
    [anon_sym_unsigned] = ACTIONS(5214),
    [anon_sym_task] = ACTIONS(5214),
    [anon_sym_assert] = ACTIONS(5214),
    [anon_sym_property] = ACTIONS(5214),
    [anon_sym_assume] = ACTIONS(5214),
    [anon_sym_cover] = ACTIONS(5214),
    [anon_sym_sequence] = ACTIONS(5214),
    [anon_sym_restrict] = ACTIONS(5214),
    [anon_sym_not] = ACTIONS(5214),
    [anon_sym_or] = ACTIONS(5214),
    [anon_sym_and] = ACTIONS(5214),
    [anon_sym_case] = ACTIONS(5214),
    [anon_sym_always] = ACTIONS(5214),
    [anon_sym_covergroup] = ACTIONS(5214),
    [anon_sym_end] = ACTIONS(5214),
    [anon_sym_let] = ACTIONS(5214),
    [anon_sym_pulldown] = ACTIONS(5214),
    [anon_sym_pullup] = ACTIONS(5214),
    [anon_sym_cmos] = ACTIONS(5214),
    [anon_sym_rcmos] = ACTIONS(5214),
    [anon_sym_bufif0] = ACTIONS(5214),
    [anon_sym_bufif1] = ACTIONS(5214),
    [anon_sym_notif0] = ACTIONS(5214),
    [anon_sym_notif1] = ACTIONS(5214),
    [anon_sym_nmos] = ACTIONS(5214),
    [anon_sym_pmos] = ACTIONS(5214),
    [anon_sym_rnmos] = ACTIONS(5214),
    [anon_sym_rpmos] = ACTIONS(5214),
    [anon_sym_nand] = ACTIONS(5214),
    [anon_sym_nor] = ACTIONS(5214),
    [anon_sym_xor] = ACTIONS(5214),
    [anon_sym_xnor] = ACTIONS(5214),
    [anon_sym_buf] = ACTIONS(5214),
    [anon_sym_tranif0] = ACTIONS(5214),
    [anon_sym_tranif1] = ACTIONS(5214),
    [anon_sym_rtranif1] = ACTIONS(5214),
    [anon_sym_rtranif0] = ACTIONS(5214),
    [anon_sym_tran] = ACTIONS(5214),
    [anon_sym_rtran] = ACTIONS(5214),
    [anon_sym_generate] = ACTIONS(5214),
    [anon_sym_for] = ACTIONS(5214),
    [anon_sym_initial] = ACTIONS(5214),
    [anon_sym_assign] = ACTIONS(5214),
    [anon_sym_alias] = ACTIONS(5214),
    [anon_sym_always_comb] = ACTIONS(5214),
    [anon_sym_always_latch] = ACTIONS(5214),
    [anon_sym_always_ff] = ACTIONS(5214),
    [anon_sym_final] = ACTIONS(5214),
    [anon_sym_global] = ACTIONS(5214),
    [anon_sym_LPAREN_STAR] = ACTIONS(5212),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5212),
    [anon_sym_DOLLARunit] = ACTIONS(5212),
  },
  [5211] = {
    [sym_simple_identifier] = ACTIONS(4848),
    [anon_sym_wire] = ACTIONS(4848),
    [anon_sym_tri] = ACTIONS(4848),
    [anon_sym_tri0] = ACTIONS(4848),
    [anon_sym_tri1] = ACTIONS(4848),
    [anon_sym_wand] = ACTIONS(4848),
    [anon_sym_triand] = ACTIONS(4848),
    [anon_sym_wor] = ACTIONS(4848),
    [anon_sym_trior] = ACTIONS(4848),
    [anon_sym_trireg] = ACTIONS(4848),
    [anon_sym_uwire] = ACTIONS(4848),
    [anon_sym_SEMI] = ACTIONS(4846),
    [anon_sym_extern] = ACTIONS(4848),
    [anon_sym_interface] = ACTIONS(4848),
    [anon_sym_checker] = ACTIONS(4848),
    [anon_sym_virtual] = ACTIONS(4848),
    [anon_sym_class] = ACTIONS(4848),
    [anon_sym_type] = ACTIONS(4848),
    [anon_sym_DOLLARfatal] = ACTIONS(4846),
    [anon_sym_DOLLARerror] = ACTIONS(4846),
    [anon_sym_DOLLARwarning] = ACTIONS(4846),
    [anon_sym_DOLLARinfo] = ACTIONS(4846),
    [anon_sym_default] = ACTIONS(4848),
    [anon_sym_clocking] = ACTIONS(4848),
    [anon_sym_defparam] = ACTIONS(4848),
    [anon_sym_bind] = ACTIONS(4848),
    [anon_sym_rand] = ACTIONS(4848),
    [anon_sym_const] = ACTIONS(4848),
    [anon_sym_function] = ACTIONS(4848),
    [anon_sym_static] = ACTIONS(4848),
    [anon_sym_constraint] = ACTIONS(4848),
    [anon_sym_if] = ACTIONS(4848),
    [anon_sym_else] = ACTIONS(4848),
    [anon_sym_LBRACK] = ACTIONS(4846),
    [anon_sym_localparam] = ACTIONS(4848),
    [anon_sym_parameter] = ACTIONS(4848),
    [anon_sym_var] = ACTIONS(4848),
    [anon_sym_import] = ACTIONS(4848),
    [anon_sym_export] = ACTIONS(4848),
    [anon_sym_genvar] = ACTIONS(4848),
    [anon_sym_interconnect] = ACTIONS(4848),
    [anon_sym_typedef] = ACTIONS(4848),
    [anon_sym_enum] = ACTIONS(4848),
    [anon_sym_struct] = ACTIONS(4848),
    [anon_sym_union] = ACTIONS(4848),
    [anon_sym_nettype] = ACTIONS(4848),
    [anon_sym_automatic] = ACTIONS(4848),
    [anon_sym_string] = ACTIONS(4848),
    [anon_sym_chandle] = ACTIONS(4848),
    [anon_sym_event] = ACTIONS(4848),
    [anon_sym_byte] = ACTIONS(4848),
    [anon_sym_shortint] = ACTIONS(4848),
    [anon_sym_int] = ACTIONS(4848),
    [anon_sym_longint] = ACTIONS(4848),
    [anon_sym_integer] = ACTIONS(4848),
    [anon_sym_time] = ACTIONS(4848),
    [anon_sym_bit] = ACTIONS(4848),
    [anon_sym_logic] = ACTIONS(4848),
    [anon_sym_reg] = ACTIONS(4848),
    [anon_sym_shortreal] = ACTIONS(4848),
    [anon_sym_real] = ACTIONS(4848),
    [anon_sym_realtime] = ACTIONS(4848),
    [anon_sym_supply0] = ACTIONS(4848),
    [anon_sym_supply1] = ACTIONS(4848),
    [anon_sym_signed] = ACTIONS(4848),
    [anon_sym_unsigned] = ACTIONS(4848),
    [anon_sym_task] = ACTIONS(4848),
    [anon_sym_assert] = ACTIONS(4848),
    [anon_sym_property] = ACTIONS(4848),
    [anon_sym_assume] = ACTIONS(4848),
    [anon_sym_cover] = ACTIONS(4848),
    [anon_sym_sequence] = ACTIONS(4848),
    [anon_sym_restrict] = ACTIONS(4848),
    [anon_sym_not] = ACTIONS(4848),
    [anon_sym_or] = ACTIONS(4848),
    [anon_sym_and] = ACTIONS(4848),
    [anon_sym_case] = ACTIONS(4848),
    [anon_sym_always] = ACTIONS(4848),
    [anon_sym_covergroup] = ACTIONS(4848),
    [anon_sym_end] = ACTIONS(4848),
    [anon_sym_let] = ACTIONS(4848),
    [anon_sym_pulldown] = ACTIONS(4848),
    [anon_sym_pullup] = ACTIONS(4848),
    [anon_sym_cmos] = ACTIONS(4848),
    [anon_sym_rcmos] = ACTIONS(4848),
    [anon_sym_bufif0] = ACTIONS(4848),
    [anon_sym_bufif1] = ACTIONS(4848),
    [anon_sym_notif0] = ACTIONS(4848),
    [anon_sym_notif1] = ACTIONS(4848),
    [anon_sym_nmos] = ACTIONS(4848),
    [anon_sym_pmos] = ACTIONS(4848),
    [anon_sym_rnmos] = ACTIONS(4848),
    [anon_sym_rpmos] = ACTIONS(4848),
    [anon_sym_nand] = ACTIONS(4848),
    [anon_sym_nor] = ACTIONS(4848),
    [anon_sym_xor] = ACTIONS(4848),
    [anon_sym_xnor] = ACTIONS(4848),
    [anon_sym_buf] = ACTIONS(4848),
    [anon_sym_tranif0] = ACTIONS(4848),
    [anon_sym_tranif1] = ACTIONS(4848),
    [anon_sym_rtranif1] = ACTIONS(4848),
    [anon_sym_rtranif0] = ACTIONS(4848),
    [anon_sym_tran] = ACTIONS(4848),
    [anon_sym_rtran] = ACTIONS(4848),
    [anon_sym_generate] = ACTIONS(4848),
    [anon_sym_for] = ACTIONS(4848),
    [anon_sym_initial] = ACTIONS(4848),
    [anon_sym_assign] = ACTIONS(4848),
    [anon_sym_alias] = ACTIONS(4848),
    [anon_sym_always_comb] = ACTIONS(4848),
    [anon_sym_always_latch] = ACTIONS(4848),
    [anon_sym_always_ff] = ACTIONS(4848),
    [anon_sym_final] = ACTIONS(4848),
    [anon_sym_global] = ACTIONS(4848),
    [anon_sym_LPAREN_STAR] = ACTIONS(4846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4846),
    [anon_sym_DOLLARunit] = ACTIONS(4846),
  },
  [5212] = {
    [sym_simple_identifier] = ACTIONS(6073),
    [anon_sym_wire] = ACTIONS(6073),
    [anon_sym_tri] = ACTIONS(6073),
    [anon_sym_tri0] = ACTIONS(6073),
    [anon_sym_tri1] = ACTIONS(6073),
    [anon_sym_wand] = ACTIONS(6073),
    [anon_sym_triand] = ACTIONS(6073),
    [anon_sym_wor] = ACTIONS(6073),
    [anon_sym_trior] = ACTIONS(6073),
    [anon_sym_trireg] = ACTIONS(6073),
    [anon_sym_uwire] = ACTIONS(6073),
    [anon_sym_SEMI] = ACTIONS(6075),
    [anon_sym_extern] = ACTIONS(6073),
    [anon_sym_interface] = ACTIONS(6073),
    [anon_sym_checker] = ACTIONS(6073),
    [anon_sym_virtual] = ACTIONS(6073),
    [anon_sym_class] = ACTIONS(6073),
    [anon_sym_type] = ACTIONS(6073),
    [anon_sym_DOLLARfatal] = ACTIONS(6075),
    [anon_sym_DOLLARerror] = ACTIONS(6075),
    [anon_sym_DOLLARwarning] = ACTIONS(6075),
    [anon_sym_DOLLARinfo] = ACTIONS(6075),
    [anon_sym_default] = ACTIONS(6073),
    [anon_sym_clocking] = ACTIONS(6073),
    [anon_sym_defparam] = ACTIONS(6073),
    [anon_sym_bind] = ACTIONS(6073),
    [anon_sym_rand] = ACTIONS(6073),
    [anon_sym_const] = ACTIONS(6073),
    [anon_sym_function] = ACTIONS(6073),
    [anon_sym_static] = ACTIONS(6073),
    [anon_sym_constraint] = ACTIONS(6073),
    [anon_sym_if] = ACTIONS(6073),
    [anon_sym_else] = ACTIONS(6073),
    [anon_sym_LBRACK] = ACTIONS(6075),
    [anon_sym_localparam] = ACTIONS(6073),
    [anon_sym_parameter] = ACTIONS(6073),
    [anon_sym_var] = ACTIONS(6073),
    [anon_sym_import] = ACTIONS(6073),
    [anon_sym_export] = ACTIONS(6073),
    [anon_sym_genvar] = ACTIONS(6073),
    [anon_sym_interconnect] = ACTIONS(6073),
    [anon_sym_typedef] = ACTIONS(6073),
    [anon_sym_enum] = ACTIONS(6073),
    [anon_sym_struct] = ACTIONS(6073),
    [anon_sym_union] = ACTIONS(6073),
    [anon_sym_nettype] = ACTIONS(6073),
    [anon_sym_automatic] = ACTIONS(6073),
    [anon_sym_string] = ACTIONS(6073),
    [anon_sym_chandle] = ACTIONS(6073),
    [anon_sym_event] = ACTIONS(6073),
    [anon_sym_byte] = ACTIONS(6073),
    [anon_sym_shortint] = ACTIONS(6073),
    [anon_sym_int] = ACTIONS(6073),
    [anon_sym_longint] = ACTIONS(6073),
    [anon_sym_integer] = ACTIONS(6073),
    [anon_sym_time] = ACTIONS(6073),
    [anon_sym_bit] = ACTIONS(6073),
    [anon_sym_logic] = ACTIONS(6073),
    [anon_sym_reg] = ACTIONS(6073),
    [anon_sym_shortreal] = ACTIONS(6073),
    [anon_sym_real] = ACTIONS(6073),
    [anon_sym_realtime] = ACTIONS(6073),
    [anon_sym_supply0] = ACTIONS(6073),
    [anon_sym_supply1] = ACTIONS(6073),
    [anon_sym_signed] = ACTIONS(6073),
    [anon_sym_unsigned] = ACTIONS(6073),
    [anon_sym_task] = ACTIONS(6073),
    [anon_sym_assert] = ACTIONS(6073),
    [anon_sym_property] = ACTIONS(6073),
    [anon_sym_assume] = ACTIONS(6073),
    [anon_sym_cover] = ACTIONS(6073),
    [anon_sym_sequence] = ACTIONS(6073),
    [anon_sym_restrict] = ACTIONS(6073),
    [anon_sym_not] = ACTIONS(6073),
    [anon_sym_or] = ACTIONS(6073),
    [anon_sym_and] = ACTIONS(6073),
    [anon_sym_case] = ACTIONS(6073),
    [anon_sym_always] = ACTIONS(6073),
    [anon_sym_covergroup] = ACTIONS(6073),
    [anon_sym_let] = ACTIONS(6073),
    [anon_sym_pulldown] = ACTIONS(6073),
    [anon_sym_pullup] = ACTIONS(6073),
    [anon_sym_cmos] = ACTIONS(6073),
    [anon_sym_rcmos] = ACTIONS(6073),
    [anon_sym_bufif0] = ACTIONS(6073),
    [anon_sym_bufif1] = ACTIONS(6073),
    [anon_sym_notif0] = ACTIONS(6073),
    [anon_sym_notif1] = ACTIONS(6073),
    [anon_sym_nmos] = ACTIONS(6073),
    [anon_sym_pmos] = ACTIONS(6073),
    [anon_sym_rnmos] = ACTIONS(6073),
    [anon_sym_rpmos] = ACTIONS(6073),
    [anon_sym_nand] = ACTIONS(6073),
    [anon_sym_nor] = ACTIONS(6073),
    [anon_sym_xor] = ACTIONS(6073),
    [anon_sym_xnor] = ACTIONS(6073),
    [anon_sym_buf] = ACTIONS(6073),
    [anon_sym_tranif0] = ACTIONS(6073),
    [anon_sym_tranif1] = ACTIONS(6073),
    [anon_sym_rtranif1] = ACTIONS(6073),
    [anon_sym_rtranif0] = ACTIONS(6073),
    [anon_sym_tran] = ACTIONS(6073),
    [anon_sym_rtran] = ACTIONS(6073),
    [anon_sym_generate] = ACTIONS(6073),
    [anon_sym_endgenerate] = ACTIONS(6073),
    [anon_sym_for] = ACTIONS(6073),
    [anon_sym_initial] = ACTIONS(6073),
    [anon_sym_assign] = ACTIONS(6073),
    [anon_sym_alias] = ACTIONS(6073),
    [anon_sym_always_comb] = ACTIONS(6073),
    [anon_sym_always_latch] = ACTIONS(6073),
    [anon_sym_always_ff] = ACTIONS(6073),
    [anon_sym_final] = ACTIONS(6073),
    [anon_sym_global] = ACTIONS(6073),
    [anon_sym_LPAREN_STAR] = ACTIONS(6075),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6075),
    [anon_sym_DOLLARunit] = ACTIONS(6075),
  },
  [5213] = {
    [sym_simple_identifier] = ACTIONS(4852),
    [anon_sym_wire] = ACTIONS(4852),
    [anon_sym_tri] = ACTIONS(4852),
    [anon_sym_tri0] = ACTIONS(4852),
    [anon_sym_tri1] = ACTIONS(4852),
    [anon_sym_wand] = ACTIONS(4852),
    [anon_sym_triand] = ACTIONS(4852),
    [anon_sym_wor] = ACTIONS(4852),
    [anon_sym_trior] = ACTIONS(4852),
    [anon_sym_trireg] = ACTIONS(4852),
    [anon_sym_uwire] = ACTIONS(4852),
    [anon_sym_SEMI] = ACTIONS(4850),
    [anon_sym_extern] = ACTIONS(4852),
    [anon_sym_interface] = ACTIONS(4852),
    [anon_sym_checker] = ACTIONS(4852),
    [anon_sym_virtual] = ACTIONS(4852),
    [anon_sym_class] = ACTIONS(4852),
    [anon_sym_type] = ACTIONS(4852),
    [anon_sym_DOLLARfatal] = ACTIONS(4850),
    [anon_sym_DOLLARerror] = ACTIONS(4850),
    [anon_sym_DOLLARwarning] = ACTIONS(4850),
    [anon_sym_DOLLARinfo] = ACTIONS(4850),
    [anon_sym_default] = ACTIONS(4852),
    [anon_sym_clocking] = ACTIONS(4852),
    [anon_sym_defparam] = ACTIONS(4852),
    [anon_sym_bind] = ACTIONS(4852),
    [anon_sym_rand] = ACTIONS(4852),
    [anon_sym_const] = ACTIONS(4852),
    [anon_sym_function] = ACTIONS(4852),
    [anon_sym_static] = ACTIONS(4852),
    [anon_sym_constraint] = ACTIONS(4852),
    [anon_sym_if] = ACTIONS(4852),
    [anon_sym_else] = ACTIONS(4852),
    [anon_sym_LBRACK] = ACTIONS(4850),
    [anon_sym_localparam] = ACTIONS(4852),
    [anon_sym_parameter] = ACTIONS(4852),
    [anon_sym_var] = ACTIONS(4852),
    [anon_sym_import] = ACTIONS(4852),
    [anon_sym_export] = ACTIONS(4852),
    [anon_sym_genvar] = ACTIONS(4852),
    [anon_sym_interconnect] = ACTIONS(4852),
    [anon_sym_typedef] = ACTIONS(4852),
    [anon_sym_enum] = ACTIONS(4852),
    [anon_sym_struct] = ACTIONS(4852),
    [anon_sym_union] = ACTIONS(4852),
    [anon_sym_nettype] = ACTIONS(4852),
    [anon_sym_automatic] = ACTIONS(4852),
    [anon_sym_string] = ACTIONS(4852),
    [anon_sym_chandle] = ACTIONS(4852),
    [anon_sym_event] = ACTIONS(4852),
    [anon_sym_byte] = ACTIONS(4852),
    [anon_sym_shortint] = ACTIONS(4852),
    [anon_sym_int] = ACTIONS(4852),
    [anon_sym_longint] = ACTIONS(4852),
    [anon_sym_integer] = ACTIONS(4852),
    [anon_sym_time] = ACTIONS(4852),
    [anon_sym_bit] = ACTIONS(4852),
    [anon_sym_logic] = ACTIONS(4852),
    [anon_sym_reg] = ACTIONS(4852),
    [anon_sym_shortreal] = ACTIONS(4852),
    [anon_sym_real] = ACTIONS(4852),
    [anon_sym_realtime] = ACTIONS(4852),
    [anon_sym_supply0] = ACTIONS(4852),
    [anon_sym_supply1] = ACTIONS(4852),
    [anon_sym_signed] = ACTIONS(4852),
    [anon_sym_unsigned] = ACTIONS(4852),
    [anon_sym_task] = ACTIONS(4852),
    [anon_sym_assert] = ACTIONS(4852),
    [anon_sym_property] = ACTIONS(4852),
    [anon_sym_assume] = ACTIONS(4852),
    [anon_sym_cover] = ACTIONS(4852),
    [anon_sym_sequence] = ACTIONS(4852),
    [anon_sym_restrict] = ACTIONS(4852),
    [anon_sym_not] = ACTIONS(4852),
    [anon_sym_or] = ACTIONS(4852),
    [anon_sym_and] = ACTIONS(4852),
    [anon_sym_case] = ACTIONS(4852),
    [anon_sym_always] = ACTIONS(4852),
    [anon_sym_covergroup] = ACTIONS(4852),
    [anon_sym_end] = ACTIONS(4852),
    [anon_sym_let] = ACTIONS(4852),
    [anon_sym_pulldown] = ACTIONS(4852),
    [anon_sym_pullup] = ACTIONS(4852),
    [anon_sym_cmos] = ACTIONS(4852),
    [anon_sym_rcmos] = ACTIONS(4852),
    [anon_sym_bufif0] = ACTIONS(4852),
    [anon_sym_bufif1] = ACTIONS(4852),
    [anon_sym_notif0] = ACTIONS(4852),
    [anon_sym_notif1] = ACTIONS(4852),
    [anon_sym_nmos] = ACTIONS(4852),
    [anon_sym_pmos] = ACTIONS(4852),
    [anon_sym_rnmos] = ACTIONS(4852),
    [anon_sym_rpmos] = ACTIONS(4852),
    [anon_sym_nand] = ACTIONS(4852),
    [anon_sym_nor] = ACTIONS(4852),
    [anon_sym_xor] = ACTIONS(4852),
    [anon_sym_xnor] = ACTIONS(4852),
    [anon_sym_buf] = ACTIONS(4852),
    [anon_sym_tranif0] = ACTIONS(4852),
    [anon_sym_tranif1] = ACTIONS(4852),
    [anon_sym_rtranif1] = ACTIONS(4852),
    [anon_sym_rtranif0] = ACTIONS(4852),
    [anon_sym_tran] = ACTIONS(4852),
    [anon_sym_rtran] = ACTIONS(4852),
    [anon_sym_generate] = ACTIONS(4852),
    [anon_sym_for] = ACTIONS(4852),
    [anon_sym_initial] = ACTIONS(4852),
    [anon_sym_assign] = ACTIONS(4852),
    [anon_sym_alias] = ACTIONS(4852),
    [anon_sym_always_comb] = ACTIONS(4852),
    [anon_sym_always_latch] = ACTIONS(4852),
    [anon_sym_always_ff] = ACTIONS(4852),
    [anon_sym_final] = ACTIONS(4852),
    [anon_sym_global] = ACTIONS(4852),
    [anon_sym_LPAREN_STAR] = ACTIONS(4850),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4850),
    [anon_sym_DOLLARunit] = ACTIONS(4850),
  },
  [5214] = {
    [sym_simple_identifier] = ACTIONS(4856),
    [anon_sym_wire] = ACTIONS(4856),
    [anon_sym_tri] = ACTIONS(4856),
    [anon_sym_tri0] = ACTIONS(4856),
    [anon_sym_tri1] = ACTIONS(4856),
    [anon_sym_wand] = ACTIONS(4856),
    [anon_sym_triand] = ACTIONS(4856),
    [anon_sym_wor] = ACTIONS(4856),
    [anon_sym_trior] = ACTIONS(4856),
    [anon_sym_trireg] = ACTIONS(4856),
    [anon_sym_uwire] = ACTIONS(4856),
    [anon_sym_SEMI] = ACTIONS(4854),
    [anon_sym_extern] = ACTIONS(4856),
    [anon_sym_interface] = ACTIONS(4856),
    [anon_sym_checker] = ACTIONS(4856),
    [anon_sym_virtual] = ACTIONS(4856),
    [anon_sym_class] = ACTIONS(4856),
    [anon_sym_type] = ACTIONS(4856),
    [anon_sym_DOLLARfatal] = ACTIONS(4854),
    [anon_sym_DOLLARerror] = ACTIONS(4854),
    [anon_sym_DOLLARwarning] = ACTIONS(4854),
    [anon_sym_DOLLARinfo] = ACTIONS(4854),
    [anon_sym_default] = ACTIONS(4856),
    [anon_sym_clocking] = ACTIONS(4856),
    [anon_sym_defparam] = ACTIONS(4856),
    [anon_sym_bind] = ACTIONS(4856),
    [anon_sym_rand] = ACTIONS(4856),
    [anon_sym_const] = ACTIONS(4856),
    [anon_sym_function] = ACTIONS(4856),
    [anon_sym_static] = ACTIONS(4856),
    [anon_sym_constraint] = ACTIONS(4856),
    [anon_sym_if] = ACTIONS(4856),
    [anon_sym_else] = ACTIONS(4856),
    [anon_sym_LBRACK] = ACTIONS(4854),
    [anon_sym_localparam] = ACTIONS(4856),
    [anon_sym_parameter] = ACTIONS(4856),
    [anon_sym_var] = ACTIONS(4856),
    [anon_sym_import] = ACTIONS(4856),
    [anon_sym_export] = ACTIONS(4856),
    [anon_sym_genvar] = ACTIONS(4856),
    [anon_sym_interconnect] = ACTIONS(4856),
    [anon_sym_typedef] = ACTIONS(4856),
    [anon_sym_enum] = ACTIONS(4856),
    [anon_sym_struct] = ACTIONS(4856),
    [anon_sym_union] = ACTIONS(4856),
    [anon_sym_nettype] = ACTIONS(4856),
    [anon_sym_automatic] = ACTIONS(4856),
    [anon_sym_string] = ACTIONS(4856),
    [anon_sym_chandle] = ACTIONS(4856),
    [anon_sym_event] = ACTIONS(4856),
    [anon_sym_byte] = ACTIONS(4856),
    [anon_sym_shortint] = ACTIONS(4856),
    [anon_sym_int] = ACTIONS(4856),
    [anon_sym_longint] = ACTIONS(4856),
    [anon_sym_integer] = ACTIONS(4856),
    [anon_sym_time] = ACTIONS(4856),
    [anon_sym_bit] = ACTIONS(4856),
    [anon_sym_logic] = ACTIONS(4856),
    [anon_sym_reg] = ACTIONS(4856),
    [anon_sym_shortreal] = ACTIONS(4856),
    [anon_sym_real] = ACTIONS(4856),
    [anon_sym_realtime] = ACTIONS(4856),
    [anon_sym_supply0] = ACTIONS(4856),
    [anon_sym_supply1] = ACTIONS(4856),
    [anon_sym_signed] = ACTIONS(4856),
    [anon_sym_unsigned] = ACTIONS(4856),
    [anon_sym_task] = ACTIONS(4856),
    [anon_sym_assert] = ACTIONS(4856),
    [anon_sym_property] = ACTIONS(4856),
    [anon_sym_assume] = ACTIONS(4856),
    [anon_sym_cover] = ACTIONS(4856),
    [anon_sym_sequence] = ACTIONS(4856),
    [anon_sym_restrict] = ACTIONS(4856),
    [anon_sym_not] = ACTIONS(4856),
    [anon_sym_or] = ACTIONS(4856),
    [anon_sym_and] = ACTIONS(4856),
    [anon_sym_case] = ACTIONS(4856),
    [anon_sym_always] = ACTIONS(4856),
    [anon_sym_covergroup] = ACTIONS(4856),
    [anon_sym_end] = ACTIONS(4856),
    [anon_sym_let] = ACTIONS(4856),
    [anon_sym_pulldown] = ACTIONS(4856),
    [anon_sym_pullup] = ACTIONS(4856),
    [anon_sym_cmos] = ACTIONS(4856),
    [anon_sym_rcmos] = ACTIONS(4856),
    [anon_sym_bufif0] = ACTIONS(4856),
    [anon_sym_bufif1] = ACTIONS(4856),
    [anon_sym_notif0] = ACTIONS(4856),
    [anon_sym_notif1] = ACTIONS(4856),
    [anon_sym_nmos] = ACTIONS(4856),
    [anon_sym_pmos] = ACTIONS(4856),
    [anon_sym_rnmos] = ACTIONS(4856),
    [anon_sym_rpmos] = ACTIONS(4856),
    [anon_sym_nand] = ACTIONS(4856),
    [anon_sym_nor] = ACTIONS(4856),
    [anon_sym_xor] = ACTIONS(4856),
    [anon_sym_xnor] = ACTIONS(4856),
    [anon_sym_buf] = ACTIONS(4856),
    [anon_sym_tranif0] = ACTIONS(4856),
    [anon_sym_tranif1] = ACTIONS(4856),
    [anon_sym_rtranif1] = ACTIONS(4856),
    [anon_sym_rtranif0] = ACTIONS(4856),
    [anon_sym_tran] = ACTIONS(4856),
    [anon_sym_rtran] = ACTIONS(4856),
    [anon_sym_generate] = ACTIONS(4856),
    [anon_sym_for] = ACTIONS(4856),
    [anon_sym_initial] = ACTIONS(4856),
    [anon_sym_assign] = ACTIONS(4856),
    [anon_sym_alias] = ACTIONS(4856),
    [anon_sym_always_comb] = ACTIONS(4856),
    [anon_sym_always_latch] = ACTIONS(4856),
    [anon_sym_always_ff] = ACTIONS(4856),
    [anon_sym_final] = ACTIONS(4856),
    [anon_sym_global] = ACTIONS(4856),
    [anon_sym_LPAREN_STAR] = ACTIONS(4854),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4854),
    [anon_sym_DOLLARunit] = ACTIONS(4854),
  },
  [5215] = {
    [sym_simple_identifier] = ACTIONS(4600),
    [anon_sym_wire] = ACTIONS(4600),
    [anon_sym_tri] = ACTIONS(4600),
    [anon_sym_tri0] = ACTIONS(4600),
    [anon_sym_tri1] = ACTIONS(4600),
    [anon_sym_wand] = ACTIONS(4600),
    [anon_sym_triand] = ACTIONS(4600),
    [anon_sym_wor] = ACTIONS(4600),
    [anon_sym_trior] = ACTIONS(4600),
    [anon_sym_trireg] = ACTIONS(4600),
    [anon_sym_uwire] = ACTIONS(4600),
    [anon_sym_SEMI] = ACTIONS(4598),
    [anon_sym_extern] = ACTIONS(4600),
    [anon_sym_interface] = ACTIONS(4600),
    [anon_sym_checker] = ACTIONS(4600),
    [anon_sym_virtual] = ACTIONS(4600),
    [anon_sym_class] = ACTIONS(4600),
    [anon_sym_type] = ACTIONS(4600),
    [anon_sym_DOLLARfatal] = ACTIONS(4598),
    [anon_sym_DOLLARerror] = ACTIONS(4598),
    [anon_sym_DOLLARwarning] = ACTIONS(4598),
    [anon_sym_DOLLARinfo] = ACTIONS(4598),
    [anon_sym_default] = ACTIONS(4600),
    [anon_sym_clocking] = ACTIONS(4600),
    [anon_sym_defparam] = ACTIONS(4600),
    [anon_sym_bind] = ACTIONS(4600),
    [anon_sym_rand] = ACTIONS(4600),
    [anon_sym_const] = ACTIONS(4600),
    [anon_sym_function] = ACTIONS(4600),
    [anon_sym_static] = ACTIONS(4600),
    [anon_sym_constraint] = ACTIONS(4600),
    [anon_sym_if] = ACTIONS(4600),
    [anon_sym_else] = ACTIONS(4600),
    [anon_sym_LBRACK] = ACTIONS(4598),
    [anon_sym_localparam] = ACTIONS(4600),
    [anon_sym_parameter] = ACTIONS(4600),
    [anon_sym_var] = ACTIONS(4600),
    [anon_sym_import] = ACTIONS(4600),
    [anon_sym_export] = ACTIONS(4600),
    [anon_sym_genvar] = ACTIONS(4600),
    [anon_sym_interconnect] = ACTIONS(4600),
    [anon_sym_typedef] = ACTIONS(4600),
    [anon_sym_enum] = ACTIONS(4600),
    [anon_sym_struct] = ACTIONS(4600),
    [anon_sym_union] = ACTIONS(4600),
    [anon_sym_nettype] = ACTIONS(4600),
    [anon_sym_automatic] = ACTIONS(4600),
    [anon_sym_string] = ACTIONS(4600),
    [anon_sym_chandle] = ACTIONS(4600),
    [anon_sym_event] = ACTIONS(4600),
    [anon_sym_byte] = ACTIONS(4600),
    [anon_sym_shortint] = ACTIONS(4600),
    [anon_sym_int] = ACTIONS(4600),
    [anon_sym_longint] = ACTIONS(4600),
    [anon_sym_integer] = ACTIONS(4600),
    [anon_sym_time] = ACTIONS(4600),
    [anon_sym_bit] = ACTIONS(4600),
    [anon_sym_logic] = ACTIONS(4600),
    [anon_sym_reg] = ACTIONS(4600),
    [anon_sym_shortreal] = ACTIONS(4600),
    [anon_sym_real] = ACTIONS(4600),
    [anon_sym_realtime] = ACTIONS(4600),
    [anon_sym_supply0] = ACTIONS(4600),
    [anon_sym_supply1] = ACTIONS(4600),
    [anon_sym_signed] = ACTIONS(4600),
    [anon_sym_unsigned] = ACTIONS(4600),
    [anon_sym_task] = ACTIONS(4600),
    [anon_sym_assert] = ACTIONS(4600),
    [anon_sym_property] = ACTIONS(4600),
    [anon_sym_assume] = ACTIONS(4600),
    [anon_sym_cover] = ACTIONS(4600),
    [anon_sym_sequence] = ACTIONS(4600),
    [anon_sym_restrict] = ACTIONS(4600),
    [anon_sym_not] = ACTIONS(4600),
    [anon_sym_or] = ACTIONS(4600),
    [anon_sym_and] = ACTIONS(4600),
    [anon_sym_case] = ACTIONS(4600),
    [anon_sym_always] = ACTIONS(4600),
    [anon_sym_covergroup] = ACTIONS(4600),
    [anon_sym_end] = ACTIONS(4600),
    [anon_sym_let] = ACTIONS(4600),
    [anon_sym_pulldown] = ACTIONS(4600),
    [anon_sym_pullup] = ACTIONS(4600),
    [anon_sym_cmos] = ACTIONS(4600),
    [anon_sym_rcmos] = ACTIONS(4600),
    [anon_sym_bufif0] = ACTIONS(4600),
    [anon_sym_bufif1] = ACTIONS(4600),
    [anon_sym_notif0] = ACTIONS(4600),
    [anon_sym_notif1] = ACTIONS(4600),
    [anon_sym_nmos] = ACTIONS(4600),
    [anon_sym_pmos] = ACTIONS(4600),
    [anon_sym_rnmos] = ACTIONS(4600),
    [anon_sym_rpmos] = ACTIONS(4600),
    [anon_sym_nand] = ACTIONS(4600),
    [anon_sym_nor] = ACTIONS(4600),
    [anon_sym_xor] = ACTIONS(4600),
    [anon_sym_xnor] = ACTIONS(4600),
    [anon_sym_buf] = ACTIONS(4600),
    [anon_sym_tranif0] = ACTIONS(4600),
    [anon_sym_tranif1] = ACTIONS(4600),
    [anon_sym_rtranif1] = ACTIONS(4600),
    [anon_sym_rtranif0] = ACTIONS(4600),
    [anon_sym_tran] = ACTIONS(4600),
    [anon_sym_rtran] = ACTIONS(4600),
    [anon_sym_generate] = ACTIONS(4600),
    [anon_sym_for] = ACTIONS(4600),
    [anon_sym_initial] = ACTIONS(4600),
    [anon_sym_assign] = ACTIONS(4600),
    [anon_sym_alias] = ACTIONS(4600),
    [anon_sym_always_comb] = ACTIONS(4600),
    [anon_sym_always_latch] = ACTIONS(4600),
    [anon_sym_always_ff] = ACTIONS(4600),
    [anon_sym_final] = ACTIONS(4600),
    [anon_sym_global] = ACTIONS(4600),
    [anon_sym_LPAREN_STAR] = ACTIONS(4598),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4598),
    [anon_sym_DOLLARunit] = ACTIONS(4598),
  },
  [5216] = {
    [sym_simple_identifier] = ACTIONS(4848),
    [anon_sym_wire] = ACTIONS(4848),
    [anon_sym_tri] = ACTIONS(4848),
    [anon_sym_tri0] = ACTIONS(4848),
    [anon_sym_tri1] = ACTIONS(4848),
    [anon_sym_wand] = ACTIONS(4848),
    [anon_sym_triand] = ACTIONS(4848),
    [anon_sym_wor] = ACTIONS(4848),
    [anon_sym_trior] = ACTIONS(4848),
    [anon_sym_trireg] = ACTIONS(4848),
    [anon_sym_uwire] = ACTIONS(4848),
    [anon_sym_SEMI] = ACTIONS(4846),
    [anon_sym_extern] = ACTIONS(4848),
    [anon_sym_interface] = ACTIONS(4848),
    [anon_sym_checker] = ACTIONS(4848),
    [anon_sym_virtual] = ACTIONS(4848),
    [anon_sym_class] = ACTIONS(4848),
    [anon_sym_type] = ACTIONS(4848),
    [anon_sym_DOLLARfatal] = ACTIONS(4846),
    [anon_sym_DOLLARerror] = ACTIONS(4846),
    [anon_sym_DOLLARwarning] = ACTIONS(4846),
    [anon_sym_DOLLARinfo] = ACTIONS(4846),
    [anon_sym_default] = ACTIONS(4848),
    [anon_sym_clocking] = ACTIONS(4848),
    [anon_sym_defparam] = ACTIONS(4848),
    [anon_sym_bind] = ACTIONS(4848),
    [anon_sym_rand] = ACTIONS(4848),
    [anon_sym_const] = ACTIONS(4848),
    [anon_sym_function] = ACTIONS(4848),
    [anon_sym_static] = ACTIONS(4848),
    [anon_sym_constraint] = ACTIONS(4848),
    [anon_sym_if] = ACTIONS(4848),
    [anon_sym_else] = ACTIONS(4848),
    [anon_sym_LBRACK] = ACTIONS(4846),
    [anon_sym_localparam] = ACTIONS(4848),
    [anon_sym_parameter] = ACTIONS(4848),
    [anon_sym_var] = ACTIONS(4848),
    [anon_sym_import] = ACTIONS(4848),
    [anon_sym_export] = ACTIONS(4848),
    [anon_sym_genvar] = ACTIONS(4848),
    [anon_sym_interconnect] = ACTIONS(4848),
    [anon_sym_typedef] = ACTIONS(4848),
    [anon_sym_enum] = ACTIONS(4848),
    [anon_sym_struct] = ACTIONS(4848),
    [anon_sym_union] = ACTIONS(4848),
    [anon_sym_nettype] = ACTIONS(4848),
    [anon_sym_automatic] = ACTIONS(4848),
    [anon_sym_string] = ACTIONS(4848),
    [anon_sym_chandle] = ACTIONS(4848),
    [anon_sym_event] = ACTIONS(4848),
    [anon_sym_byte] = ACTIONS(4848),
    [anon_sym_shortint] = ACTIONS(4848),
    [anon_sym_int] = ACTIONS(4848),
    [anon_sym_longint] = ACTIONS(4848),
    [anon_sym_integer] = ACTIONS(4848),
    [anon_sym_time] = ACTIONS(4848),
    [anon_sym_bit] = ACTIONS(4848),
    [anon_sym_logic] = ACTIONS(4848),
    [anon_sym_reg] = ACTIONS(4848),
    [anon_sym_shortreal] = ACTIONS(4848),
    [anon_sym_real] = ACTIONS(4848),
    [anon_sym_realtime] = ACTIONS(4848),
    [anon_sym_supply0] = ACTIONS(4848),
    [anon_sym_supply1] = ACTIONS(4848),
    [anon_sym_signed] = ACTIONS(4848),
    [anon_sym_unsigned] = ACTIONS(4848),
    [anon_sym_task] = ACTIONS(4848),
    [anon_sym_assert] = ACTIONS(4848),
    [anon_sym_property] = ACTIONS(4848),
    [anon_sym_assume] = ACTIONS(4848),
    [anon_sym_cover] = ACTIONS(4848),
    [anon_sym_sequence] = ACTIONS(4848),
    [anon_sym_restrict] = ACTIONS(4848),
    [anon_sym_not] = ACTIONS(4848),
    [anon_sym_or] = ACTIONS(4848),
    [anon_sym_and] = ACTIONS(4848),
    [anon_sym_case] = ACTIONS(4848),
    [anon_sym_always] = ACTIONS(4848),
    [anon_sym_covergroup] = ACTIONS(4848),
    [anon_sym_let] = ACTIONS(4848),
    [anon_sym_pulldown] = ACTIONS(4848),
    [anon_sym_pullup] = ACTIONS(4848),
    [anon_sym_cmos] = ACTIONS(4848),
    [anon_sym_rcmos] = ACTIONS(4848),
    [anon_sym_bufif0] = ACTIONS(4848),
    [anon_sym_bufif1] = ACTIONS(4848),
    [anon_sym_notif0] = ACTIONS(4848),
    [anon_sym_notif1] = ACTIONS(4848),
    [anon_sym_nmos] = ACTIONS(4848),
    [anon_sym_pmos] = ACTIONS(4848),
    [anon_sym_rnmos] = ACTIONS(4848),
    [anon_sym_rpmos] = ACTIONS(4848),
    [anon_sym_nand] = ACTIONS(4848),
    [anon_sym_nor] = ACTIONS(4848),
    [anon_sym_xor] = ACTIONS(4848),
    [anon_sym_xnor] = ACTIONS(4848),
    [anon_sym_buf] = ACTIONS(4848),
    [anon_sym_tranif0] = ACTIONS(4848),
    [anon_sym_tranif1] = ACTIONS(4848),
    [anon_sym_rtranif1] = ACTIONS(4848),
    [anon_sym_rtranif0] = ACTIONS(4848),
    [anon_sym_tran] = ACTIONS(4848),
    [anon_sym_rtran] = ACTIONS(4848),
    [anon_sym_generate] = ACTIONS(4848),
    [anon_sym_endgenerate] = ACTIONS(4848),
    [anon_sym_for] = ACTIONS(4848),
    [anon_sym_initial] = ACTIONS(4848),
    [anon_sym_assign] = ACTIONS(4848),
    [anon_sym_alias] = ACTIONS(4848),
    [anon_sym_always_comb] = ACTIONS(4848),
    [anon_sym_always_latch] = ACTIONS(4848),
    [anon_sym_always_ff] = ACTIONS(4848),
    [anon_sym_final] = ACTIONS(4848),
    [anon_sym_global] = ACTIONS(4848),
    [anon_sym_LPAREN_STAR] = ACTIONS(4846),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4846),
    [anon_sym_DOLLARunit] = ACTIONS(4846),
  },
  [5217] = {
    [sym_simple_identifier] = ACTIONS(6699),
    [anon_sym_wire] = ACTIONS(6699),
    [anon_sym_tri] = ACTIONS(6699),
    [anon_sym_tri0] = ACTIONS(6699),
    [anon_sym_tri1] = ACTIONS(6699),
    [anon_sym_wand] = ACTIONS(6699),
    [anon_sym_triand] = ACTIONS(6699),
    [anon_sym_wor] = ACTIONS(6699),
    [anon_sym_trior] = ACTIONS(6699),
    [anon_sym_trireg] = ACTIONS(6699),
    [anon_sym_uwire] = ACTIONS(6699),
    [anon_sym_SEMI] = ACTIONS(6701),
    [anon_sym_extern] = ACTIONS(6699),
    [anon_sym_interface] = ACTIONS(6699),
    [anon_sym_checker] = ACTIONS(6699),
    [anon_sym_virtual] = ACTIONS(6699),
    [anon_sym_class] = ACTIONS(6699),
    [anon_sym_type] = ACTIONS(6699),
    [anon_sym_DOLLARfatal] = ACTIONS(6701),
    [anon_sym_DOLLARerror] = ACTIONS(6701),
    [anon_sym_DOLLARwarning] = ACTIONS(6701),
    [anon_sym_DOLLARinfo] = ACTIONS(6701),
    [anon_sym_default] = ACTIONS(6699),
    [anon_sym_clocking] = ACTIONS(6699),
    [anon_sym_defparam] = ACTIONS(6699),
    [anon_sym_bind] = ACTIONS(6699),
    [anon_sym_rand] = ACTIONS(6699),
    [anon_sym_const] = ACTIONS(6699),
    [anon_sym_function] = ACTIONS(6699),
    [anon_sym_static] = ACTIONS(6699),
    [anon_sym_constraint] = ACTIONS(6699),
    [anon_sym_if] = ACTIONS(6699),
    [anon_sym_else] = ACTIONS(11189),
    [anon_sym_LBRACK] = ACTIONS(6701),
    [anon_sym_localparam] = ACTIONS(6699),
    [anon_sym_parameter] = ACTIONS(6699),
    [anon_sym_var] = ACTIONS(6699),
    [anon_sym_import] = ACTIONS(6699),
    [anon_sym_export] = ACTIONS(6699),
    [anon_sym_genvar] = ACTIONS(6699),
    [anon_sym_interconnect] = ACTIONS(6699),
    [anon_sym_typedef] = ACTIONS(6699),
    [anon_sym_enum] = ACTIONS(6699),
    [anon_sym_struct] = ACTIONS(6699),
    [anon_sym_union] = ACTIONS(6699),
    [anon_sym_nettype] = ACTIONS(6699),
    [anon_sym_automatic] = ACTIONS(6699),
    [anon_sym_string] = ACTIONS(6699),
    [anon_sym_chandle] = ACTIONS(6699),
    [anon_sym_event] = ACTIONS(6699),
    [anon_sym_byte] = ACTIONS(6699),
    [anon_sym_shortint] = ACTIONS(6699),
    [anon_sym_int] = ACTIONS(6699),
    [anon_sym_longint] = ACTIONS(6699),
    [anon_sym_integer] = ACTIONS(6699),
    [anon_sym_time] = ACTIONS(6699),
    [anon_sym_bit] = ACTIONS(6699),
    [anon_sym_logic] = ACTIONS(6699),
    [anon_sym_reg] = ACTIONS(6699),
    [anon_sym_shortreal] = ACTIONS(6699),
    [anon_sym_real] = ACTIONS(6699),
    [anon_sym_realtime] = ACTIONS(6699),
    [anon_sym_supply0] = ACTIONS(6699),
    [anon_sym_supply1] = ACTIONS(6699),
    [anon_sym_signed] = ACTIONS(6699),
    [anon_sym_unsigned] = ACTIONS(6699),
    [anon_sym_task] = ACTIONS(6699),
    [anon_sym_assert] = ACTIONS(6699),
    [anon_sym_property] = ACTIONS(6699),
    [anon_sym_assume] = ACTIONS(6699),
    [anon_sym_cover] = ACTIONS(6699),
    [anon_sym_sequence] = ACTIONS(6699),
    [anon_sym_restrict] = ACTIONS(6699),
    [anon_sym_not] = ACTIONS(6699),
    [anon_sym_or] = ACTIONS(6699),
    [anon_sym_and] = ACTIONS(6699),
    [anon_sym_case] = ACTIONS(6699),
    [anon_sym_always] = ACTIONS(6699),
    [anon_sym_covergroup] = ACTIONS(6699),
    [anon_sym_end] = ACTIONS(6699),
    [anon_sym_let] = ACTIONS(6699),
    [anon_sym_pulldown] = ACTIONS(6699),
    [anon_sym_pullup] = ACTIONS(6699),
    [anon_sym_cmos] = ACTIONS(6699),
    [anon_sym_rcmos] = ACTIONS(6699),
    [anon_sym_bufif0] = ACTIONS(6699),
    [anon_sym_bufif1] = ACTIONS(6699),
    [anon_sym_notif0] = ACTIONS(6699),
    [anon_sym_notif1] = ACTIONS(6699),
    [anon_sym_nmos] = ACTIONS(6699),
    [anon_sym_pmos] = ACTIONS(6699),
    [anon_sym_rnmos] = ACTIONS(6699),
    [anon_sym_rpmos] = ACTIONS(6699),
    [anon_sym_nand] = ACTIONS(6699),
    [anon_sym_nor] = ACTIONS(6699),
    [anon_sym_xor] = ACTIONS(6699),
    [anon_sym_xnor] = ACTIONS(6699),
    [anon_sym_buf] = ACTIONS(6699),
    [anon_sym_tranif0] = ACTIONS(6699),
    [anon_sym_tranif1] = ACTIONS(6699),
    [anon_sym_rtranif1] = ACTIONS(6699),
    [anon_sym_rtranif0] = ACTIONS(6699),
    [anon_sym_tran] = ACTIONS(6699),
    [anon_sym_rtran] = ACTIONS(6699),
    [anon_sym_generate] = ACTIONS(6699),
    [anon_sym_for] = ACTIONS(6699),
    [anon_sym_initial] = ACTIONS(6699),
    [anon_sym_assign] = ACTIONS(6699),
    [anon_sym_alias] = ACTIONS(6699),
    [anon_sym_always_comb] = ACTIONS(6699),
    [anon_sym_always_latch] = ACTIONS(6699),
    [anon_sym_always_ff] = ACTIONS(6699),
    [anon_sym_final] = ACTIONS(6699),
    [anon_sym_global] = ACTIONS(6699),
    [anon_sym_LPAREN_STAR] = ACTIONS(6701),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6701),
    [anon_sym_DOLLARunit] = ACTIONS(6701),
  },
  [5218] = {
    [sym_simple_identifier] = ACTIONS(5810),
    [anon_sym_wire] = ACTIONS(5810),
    [anon_sym_tri] = ACTIONS(5810),
    [anon_sym_tri0] = ACTIONS(5810),
    [anon_sym_tri1] = ACTIONS(5810),
    [anon_sym_wand] = ACTIONS(5810),
    [anon_sym_triand] = ACTIONS(5810),
    [anon_sym_wor] = ACTIONS(5810),
    [anon_sym_trior] = ACTIONS(5810),
    [anon_sym_trireg] = ACTIONS(5810),
    [anon_sym_uwire] = ACTIONS(5810),
    [anon_sym_SEMI] = ACTIONS(5812),
    [anon_sym_extern] = ACTIONS(5810),
    [anon_sym_interface] = ACTIONS(5810),
    [anon_sym_checker] = ACTIONS(5810),
    [anon_sym_virtual] = ACTIONS(5810),
    [anon_sym_class] = ACTIONS(5810),
    [anon_sym_type] = ACTIONS(5810),
    [anon_sym_DOLLARfatal] = ACTIONS(5812),
    [anon_sym_DOLLARerror] = ACTIONS(5812),
    [anon_sym_DOLLARwarning] = ACTIONS(5812),
    [anon_sym_DOLLARinfo] = ACTIONS(5812),
    [anon_sym_default] = ACTIONS(5810),
    [anon_sym_clocking] = ACTIONS(5810),
    [anon_sym_defparam] = ACTIONS(5810),
    [anon_sym_bind] = ACTIONS(5810),
    [anon_sym_rand] = ACTIONS(5810),
    [anon_sym_const] = ACTIONS(5810),
    [anon_sym_function] = ACTIONS(5810),
    [anon_sym_static] = ACTIONS(5810),
    [anon_sym_constraint] = ACTIONS(5810),
    [anon_sym_if] = ACTIONS(5810),
    [anon_sym_else] = ACTIONS(5810),
    [anon_sym_LBRACK] = ACTIONS(5812),
    [anon_sym_localparam] = ACTIONS(5810),
    [anon_sym_parameter] = ACTIONS(5810),
    [anon_sym_var] = ACTIONS(5810),
    [anon_sym_import] = ACTIONS(5810),
    [anon_sym_export] = ACTIONS(5810),
    [anon_sym_genvar] = ACTIONS(5810),
    [anon_sym_interconnect] = ACTIONS(5810),
    [anon_sym_typedef] = ACTIONS(5810),
    [anon_sym_enum] = ACTIONS(5810),
    [anon_sym_struct] = ACTIONS(5810),
    [anon_sym_union] = ACTIONS(5810),
    [anon_sym_nettype] = ACTIONS(5810),
    [anon_sym_automatic] = ACTIONS(5810),
    [anon_sym_string] = ACTIONS(5810),
    [anon_sym_chandle] = ACTIONS(5810),
    [anon_sym_event] = ACTIONS(5810),
    [anon_sym_byte] = ACTIONS(5810),
    [anon_sym_shortint] = ACTIONS(5810),
    [anon_sym_int] = ACTIONS(5810),
    [anon_sym_longint] = ACTIONS(5810),
    [anon_sym_integer] = ACTIONS(5810),
    [anon_sym_time] = ACTIONS(5810),
    [anon_sym_bit] = ACTIONS(5810),
    [anon_sym_logic] = ACTIONS(5810),
    [anon_sym_reg] = ACTIONS(5810),
    [anon_sym_shortreal] = ACTIONS(5810),
    [anon_sym_real] = ACTIONS(5810),
    [anon_sym_realtime] = ACTIONS(5810),
    [anon_sym_supply0] = ACTIONS(5810),
    [anon_sym_supply1] = ACTIONS(5810),
    [anon_sym_signed] = ACTIONS(5810),
    [anon_sym_unsigned] = ACTIONS(5810),
    [anon_sym_task] = ACTIONS(5810),
    [anon_sym_assert] = ACTIONS(5810),
    [anon_sym_property] = ACTIONS(5810),
    [anon_sym_assume] = ACTIONS(5810),
    [anon_sym_cover] = ACTIONS(5810),
    [anon_sym_sequence] = ACTIONS(5810),
    [anon_sym_restrict] = ACTIONS(5810),
    [anon_sym_not] = ACTIONS(5810),
    [anon_sym_or] = ACTIONS(5810),
    [anon_sym_and] = ACTIONS(5810),
    [anon_sym_case] = ACTIONS(5810),
    [anon_sym_always] = ACTIONS(5810),
    [anon_sym_covergroup] = ACTIONS(5810),
    [anon_sym_let] = ACTIONS(5810),
    [anon_sym_pulldown] = ACTIONS(5810),
    [anon_sym_pullup] = ACTIONS(5810),
    [anon_sym_cmos] = ACTIONS(5810),
    [anon_sym_rcmos] = ACTIONS(5810),
    [anon_sym_bufif0] = ACTIONS(5810),
    [anon_sym_bufif1] = ACTIONS(5810),
    [anon_sym_notif0] = ACTIONS(5810),
    [anon_sym_notif1] = ACTIONS(5810),
    [anon_sym_nmos] = ACTIONS(5810),
    [anon_sym_pmos] = ACTIONS(5810),
    [anon_sym_rnmos] = ACTIONS(5810),
    [anon_sym_rpmos] = ACTIONS(5810),
    [anon_sym_nand] = ACTIONS(5810),
    [anon_sym_nor] = ACTIONS(5810),
    [anon_sym_xor] = ACTIONS(5810),
    [anon_sym_xnor] = ACTIONS(5810),
    [anon_sym_buf] = ACTIONS(5810),
    [anon_sym_tranif0] = ACTIONS(5810),
    [anon_sym_tranif1] = ACTIONS(5810),
    [anon_sym_rtranif1] = ACTIONS(5810),
    [anon_sym_rtranif0] = ACTIONS(5810),
    [anon_sym_tran] = ACTIONS(5810),
    [anon_sym_rtran] = ACTIONS(5810),
    [anon_sym_generate] = ACTIONS(5810),
    [anon_sym_endgenerate] = ACTIONS(5810),
    [anon_sym_for] = ACTIONS(5810),
    [anon_sym_initial] = ACTIONS(5810),
    [anon_sym_assign] = ACTIONS(5810),
    [anon_sym_alias] = ACTIONS(5810),
    [anon_sym_always_comb] = ACTIONS(5810),
    [anon_sym_always_latch] = ACTIONS(5810),
    [anon_sym_always_ff] = ACTIONS(5810),
    [anon_sym_final] = ACTIONS(5810),
    [anon_sym_global] = ACTIONS(5810),
    [anon_sym_LPAREN_STAR] = ACTIONS(5812),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(5812),
    [anon_sym_DOLLARunit] = ACTIONS(5812),
  },
  [5219] = {
    [sym_simple_identifier] = ACTIONS(6169),
    [anon_sym_wire] = ACTIONS(6169),
    [anon_sym_tri] = ACTIONS(6169),
    [anon_sym_tri0] = ACTIONS(6169),
    [anon_sym_tri1] = ACTIONS(6169),
    [anon_sym_wand] = ACTIONS(6169),
    [anon_sym_triand] = ACTIONS(6169),
    [anon_sym_wor] = ACTIONS(6169),
    [anon_sym_trior] = ACTIONS(6169),
    [anon_sym_trireg] = ACTIONS(6169),
    [anon_sym_uwire] = ACTIONS(6169),
    [anon_sym_SEMI] = ACTIONS(6171),
    [anon_sym_extern] = ACTIONS(6169),
    [anon_sym_interface] = ACTIONS(6169),
    [anon_sym_checker] = ACTIONS(6169),
    [anon_sym_virtual] = ACTIONS(6169),
    [anon_sym_class] = ACTIONS(6169),
    [anon_sym_type] = ACTIONS(6169),
    [anon_sym_DOLLARfatal] = ACTIONS(6171),
    [anon_sym_DOLLARerror] = ACTIONS(6171),
    [anon_sym_DOLLARwarning] = ACTIONS(6171),
    [anon_sym_DOLLARinfo] = ACTIONS(6171),
    [anon_sym_default] = ACTIONS(6169),
    [anon_sym_clocking] = ACTIONS(6169),
    [anon_sym_defparam] = ACTIONS(6169),
    [anon_sym_bind] = ACTIONS(6169),
    [anon_sym_rand] = ACTIONS(6169),
    [anon_sym_const] = ACTIONS(6169),
    [anon_sym_function] = ACTIONS(6169),
    [anon_sym_static] = ACTIONS(6169),
    [anon_sym_constraint] = ACTIONS(6169),
    [anon_sym_if] = ACTIONS(6169),
    [anon_sym_else] = ACTIONS(6169),
    [anon_sym_LBRACK] = ACTIONS(6171),
    [anon_sym_localparam] = ACTIONS(6169),
    [anon_sym_parameter] = ACTIONS(6169),
    [anon_sym_var] = ACTIONS(6169),
    [anon_sym_import] = ACTIONS(6169),
    [anon_sym_export] = ACTIONS(6169),
    [anon_sym_genvar] = ACTIONS(6169),
    [anon_sym_interconnect] = ACTIONS(6169),
    [anon_sym_typedef] = ACTIONS(6169),
    [anon_sym_enum] = ACTIONS(6169),
    [anon_sym_struct] = ACTIONS(6169),
    [anon_sym_union] = ACTIONS(6169),
    [anon_sym_nettype] = ACTIONS(6169),
    [anon_sym_automatic] = ACTIONS(6169),
    [anon_sym_string] = ACTIONS(6169),
    [anon_sym_chandle] = ACTIONS(6169),
    [anon_sym_event] = ACTIONS(6169),
    [anon_sym_byte] = ACTIONS(6169),
    [anon_sym_shortint] = ACTIONS(6169),
    [anon_sym_int] = ACTIONS(6169),
    [anon_sym_longint] = ACTIONS(6169),
    [anon_sym_integer] = ACTIONS(6169),
    [anon_sym_time] = ACTIONS(6169),
    [anon_sym_bit] = ACTIONS(6169),
    [anon_sym_logic] = ACTIONS(6169),
    [anon_sym_reg] = ACTIONS(6169),
    [anon_sym_shortreal] = ACTIONS(6169),
    [anon_sym_real] = ACTIONS(6169),
    [anon_sym_realtime] = ACTIONS(6169),
    [anon_sym_supply0] = ACTIONS(6169),
    [anon_sym_supply1] = ACTIONS(6169),
    [anon_sym_signed] = ACTIONS(6169),
    [anon_sym_unsigned] = ACTIONS(6169),
    [anon_sym_task] = ACTIONS(6169),
    [anon_sym_assert] = ACTIONS(6169),
    [anon_sym_property] = ACTIONS(6169),
    [anon_sym_assume] = ACTIONS(6169),
    [anon_sym_cover] = ACTIONS(6169),
    [anon_sym_sequence] = ACTIONS(6169),
    [anon_sym_restrict] = ACTIONS(6169),
    [anon_sym_not] = ACTIONS(6169),
    [anon_sym_or] = ACTIONS(6169),
    [anon_sym_and] = ACTIONS(6169),
    [anon_sym_case] = ACTIONS(6169),
    [anon_sym_always] = ACTIONS(6169),
    [anon_sym_covergroup] = ACTIONS(6169),
    [anon_sym_end] = ACTIONS(6169),
    [anon_sym_let] = ACTIONS(6169),
    [anon_sym_pulldown] = ACTIONS(6169),
    [anon_sym_pullup] = ACTIONS(6169),
    [anon_sym_cmos] = ACTIONS(6169),
    [anon_sym_rcmos] = ACTIONS(6169),
    [anon_sym_bufif0] = ACTIONS(6169),
    [anon_sym_bufif1] = ACTIONS(6169),
    [anon_sym_notif0] = ACTIONS(6169),
    [anon_sym_notif1] = ACTIONS(6169),
    [anon_sym_nmos] = ACTIONS(6169),
    [anon_sym_pmos] = ACTIONS(6169),
    [anon_sym_rnmos] = ACTIONS(6169),
    [anon_sym_rpmos] = ACTIONS(6169),
    [anon_sym_nand] = ACTIONS(6169),
    [anon_sym_nor] = ACTIONS(6169),
    [anon_sym_xor] = ACTIONS(6169),
    [anon_sym_xnor] = ACTIONS(6169),
    [anon_sym_buf] = ACTIONS(6169),
    [anon_sym_tranif0] = ACTIONS(6169),
    [anon_sym_tranif1] = ACTIONS(6169),
    [anon_sym_rtranif1] = ACTIONS(6169),
    [anon_sym_rtranif0] = ACTIONS(6169),
    [anon_sym_tran] = ACTIONS(6169),
    [anon_sym_rtran] = ACTIONS(6169),
    [anon_sym_generate] = ACTIONS(6169),
    [anon_sym_for] = ACTIONS(6169),
    [anon_sym_initial] = ACTIONS(6169),
    [anon_sym_assign] = ACTIONS(6169),
    [anon_sym_alias] = ACTIONS(6169),
    [anon_sym_always_comb] = ACTIONS(6169),
    [anon_sym_always_latch] = ACTIONS(6169),
    [anon_sym_always_ff] = ACTIONS(6169),
    [anon_sym_final] = ACTIONS(6169),
    [anon_sym_global] = ACTIONS(6169),
    [anon_sym_LPAREN_STAR] = ACTIONS(6171),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(6171),
    [anon_sym_DOLLARunit] = ACTIONS(6171),
  },
  [5220] = {
    [sym_simple_identifier] = ACTIONS(2127),
    [anon_sym_LT] = ACTIONS(2127),
    [anon_sym_GT] = ACTIONS(2127),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(2125),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_RPAREN] = ACTIONS(2125),
    [anon_sym_COMMA] = ACTIONS(2125),
    [aux_sym_text_macro_definition_token1] = ACTIONS(2125),
    [anon_sym_BQUOTE] = ACTIONS(2127),
    [aux_sym_id_directive_token1] = ACTIONS(2125),
    [aux_sym_id_directive_token2] = ACTIONS(2125),
    [aux_sym_id_directive_token3] = ACTIONS(2125),
    [aux_sym_id_directive_token4] = ACTIONS(2127),
    [aux_sym_zero_directive_token1] = ACTIONS(2125),
    [aux_sym_zero_directive_token2] = ACTIONS(2125),
    [aux_sym_zero_directive_token3] = ACTIONS(2125),
    [aux_sym_zero_directive_token4] = ACTIONS(2125),
    [aux_sym_zero_directive_token5] = ACTIONS(2125),
    [aux_sym_zero_directive_token6] = ACTIONS(2125),
    [aux_sym_zero_directive_token7] = ACTIONS(2125),
    [aux_sym_zero_directive_token8] = ACTIONS(2125),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(2125),
    [anon_sym_SLASH] = ACTIONS(2127),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(2125),
    [aux_sym_unconnected_drive_token1] = ACTIONS(2125),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(2125),
    [aux_sym_begin_keywords_token1] = ACTIONS(2125),
    [anon_sym_SEMI] = ACTIONS(2125),
    [anon_sym_COLON] = ACTIONS(2125),
    [anon_sym_extern] = ACTIONS(2127),
    [anon_sym_virtual] = ACTIONS(2127),
    [anon_sym_class] = ACTIONS(2127),
    [anon_sym_endclass] = ACTIONS(2127),
    [anon_sym_pure] = ACTIONS(2127),
    [anon_sym_type] = ACTIONS(2127),
    [anon_sym_DOT] = ACTIONS(2125),
    [anon_sym_LBRACE] = ACTIONS(2125),
    [anon_sym_RBRACE] = ACTIONS(2125),
    [anon_sym_iff] = ACTIONS(2127),
    [anon_sym_rand] = ACTIONS(2127),
    [anon_sym_const] = ACTIONS(2127),
    [anon_sym_function] = ACTIONS(2127),
    [anon_sym_static] = ACTIONS(2127),
    [anon_sym_protected] = ACTIONS(2127),
    [anon_sym_local] = ACTIONS(2127),
    [anon_sym_randc] = ACTIONS(2127),
    [anon_sym_constraint] = ACTIONS(2127),
    [anon_sym_u2013_GT] = ACTIONS(2125),
    [anon_sym_LBRACK] = ACTIONS(2125),
    [anon_sym_RBRACK] = ACTIONS(2125),
    [anon_sym_localparam] = ACTIONS(2127),
    [anon_sym_parameter] = ACTIONS(2127),
    [anon_sym_var] = ACTIONS(2127),
    [anon_sym_import] = ACTIONS(2127),
    [anon_sym_STAR] = ACTIONS(2127),
    [anon_sym_typedef] = ACTIONS(2127),
    [anon_sym_enum] = ACTIONS(2127),
    [anon_sym_struct] = ACTIONS(2127),
    [anon_sym_union] = ACTIONS(2127),
    [anon_sym_nettype] = ACTIONS(2127),
    [anon_sym_with] = ACTIONS(2127),
    [anon_sym_automatic] = ACTIONS(2127),
    [anon_sym_string] = ACTIONS(2127),
    [anon_sym_chandle] = ACTIONS(2127),
    [anon_sym_event] = ACTIONS(2127),
    [anon_sym_byte] = ACTIONS(2127),
    [anon_sym_shortint] = ACTIONS(2127),
    [anon_sym_int] = ACTIONS(2127),
    [anon_sym_longint] = ACTIONS(2127),
    [anon_sym_integer] = ACTIONS(2127),
    [anon_sym_time] = ACTIONS(2127),
    [anon_sym_bit] = ACTIONS(2127),
    [anon_sym_logic] = ACTIONS(2127),
    [anon_sym_reg] = ACTIONS(2127),
    [anon_sym_shortreal] = ACTIONS(2127),
    [anon_sym_real] = ACTIONS(2127),
    [anon_sym_realtime] = ACTIONS(2127),
    [anon_sym_signed] = ACTIONS(2127),
    [anon_sym_unsigned] = ACTIONS(2127),
    [anon_sym_task] = ACTIONS(2127),
    [anon_sym_PLUS] = ACTIONS(2125),
    [anon_sym_STAR_STAR] = ACTIONS(2125),
    [anon_sym_PERCENT] = ACTIONS(2125),
    [anon_sym_EQ_EQ] = ACTIONS(2127),
    [anon_sym_BANG_EQ] = ACTIONS(2127),
    [anon_sym_LT_EQ] = ACTIONS(2125),
    [anon_sym_GT_EQ] = ACTIONS(2125),
    [anon_sym_or] = ACTIONS(2127),
    [anon_sym_dist] = ACTIONS(2127),
    [anon_sym_covergroup] = ACTIONS(2127),
    [anon_sym_AMP_AMP] = ACTIONS(2127),
    [anon_sym_PIPE_PIPE] = ACTIONS(2125),
    [anon_sym_matches] = ACTIONS(2127),
    [anon_sym_DASH] = ACTIONS(2127),
    [anon_sym_DASH_GT] = ACTIONS(2125),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(2125),
    [anon_sym_inside] = ACTIONS(2127),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(2125),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(2125),
    [anon_sym_GT_GT] = ACTIONS(2127),
    [anon_sym_LT_LT] = ACTIONS(2127),
    [anon_sym_QMARK] = ACTIONS(2125),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(2125),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(2125),
    [anon_sym_AMP] = ACTIONS(2127),
    [anon_sym_PIPE] = ACTIONS(2127),
    [anon_sym_CARET] = ACTIONS(2127),
    [anon_sym_CARET_TILDE] = ACTIONS(2125),
    [anon_sym_TILDE_CARET] = ACTIONS(2125),
    [anon_sym_GT_GT_GT] = ACTIONS(2125),
    [anon_sym_LT_LT_LT] = ACTIONS(2125),
    [anon_sym_LT_DASH_GT] = ACTIONS(2125),
    [anon_sym_SQUOTE] = ACTIONS(2125),
    [anon_sym_LPAREN_STAR] = ACTIONS(2125),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(2125),
    [anon_sym_DOLLARunit] = ACTIONS(2125),
  },
  [5221] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_DQUOTE] = ACTIONS(1686),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1686),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_iff] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_tagged] = ACTIONS(1688),
    [anon_sym_DOLLAR] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_endproperty] = ACTIONS(1688),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_and] = ACTIONS(1688),
    [anon_sym_PIPE_DASH_GT] = ACTIONS(1686),
    [anon_sym_PIPE_EQ_GT] = ACTIONS(1686),
    [anon_sym_POUND_DASH_POUND] = ACTIONS(1686),
    [anon_sym_POUND_EQ_POUND] = ACTIONS(1686),
    [anon_sym_until] = ACTIONS(1688),
    [anon_sym_s_until] = ACTIONS(1688),
    [anon_sym_until_with] = ACTIONS(1688),
    [anon_sym_s_until_with] = ACTIONS(1688),
    [anon_sym_implies] = ACTIONS(1688),
    [anon_sym_intersect] = ACTIONS(1688),
    [anon_sym_throughout] = ACTIONS(1688),
    [anon_sym_within] = ACTIONS(1688),
    [anon_sym_POUND_POUND] = ACTIONS(1688),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(1686),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_STAR] = ACTIONS(1688),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_EQ] = ACTIONS(1686),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(1686),
    [anon_sym_dist] = ACTIONS(1688),
    [anon_sym_BANG] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_TILDE] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_std] = ACTIONS(1688),
    [anon_sym_randomize] = ACTIONS(1688),
    [anon_sym_null] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_TILDE_AMP] = ACTIONS(1686),
    [anon_sym_TILDE_PIPE] = ACTIONS(1686),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [aux_sym_decimal_number_token1] = ACTIONS(1686),
    [aux_sym_decimal_number_token2] = ACTIONS(1686),
    [sym_binary_number] = ACTIONS(1686),
    [sym_octal_number] = ACTIONS(1686),
    [sym_hex_number] = ACTIONS(1686),
    [aux_sym_real_number_token1] = ACTIONS(1686),
    [sym_fixed_point_number] = ACTIONS(1688),
    [sym_unsigned_number] = ACTIONS(1688),
    [anon_sym_SQUOTE0] = ACTIONS(1686),
    [anon_sym_SQUOTE1] = ACTIONS(1686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [5222] = {
    [sym_checker_declaration] = STATE(818),
    [sym_class_declaration] = STATE(818),
    [sym_interface_class_declaration] = STATE(818),
    [sym_timeunits_declaration] = STATE(6638),
    [sym_class_constructor_declaration] = STATE(818),
    [sym_extern_constraint_declaration] = STATE(818),
    [sym__package_item] = STATE(6638),
    [sym_package_or_generate_item_declaration] = STATE(6638),
    [sym_anonymous_program] = STATE(6638),
    [sym_local_parameter_declaration] = STATE(18092),
    [sym_parameter_declaration] = STATE(18092),
    [sym__any_parameter_declaration] = STATE(18092),
    [sym_data_declaration] = STATE(818),
    [sym_package_import_declaration] = STATE(837),
    [sym_package_export_declaration] = STATE(6638),
    [sym_net_declaration] = STATE(818),
    [sym_type_declaration] = STATE(837),
    [sym_net_type_declaration] = STATE(837),
    [sym_lifetime] = STATE(8395),
    [sym_data_type] = STATE(13340),
    [sym_data_type_or_implicit1] = STATE(12681),
    [sym_implicit_data_type1] = STATE(13340),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym_net_type] = STATE(8107),
    [sym__signing] = STATE(11604),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_list_of_variable_decl_assignments] = STATE(17836),
    [sym_variable_decl_assignment] = STATE(16027),
    [sym_packed_dimension] = STATE(11636),
    [sym_unsized_dimension] = STATE(11625),
    [sym_function_declaration] = STATE(818),
    [sym_dpi_import_export] = STATE(818),
    [sym_task_declaration] = STATE(818),
    [sym_overload_declaration] = STATE(818),
    [sym__assertion_item_declaration] = STATE(818),
    [sym_property_declaration] = STATE(818),
    [sym_sequence_declaration] = STATE(818),
    [sym_covergroup_declaration] = STATE(818),
    [sym_let_declaration] = STATE(818),
    [sym_attribute_instance] = STATE(2639),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(10800),
    [sym_package_scope] = STATE(14220),
    [aux_sym__description_repeat1] = STATE(2639),
    [aux_sym_data_type_repeat1] = STATE(11636),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_wire] = ACTIONS(25),
    [anon_sym_tri] = ACTIONS(25),
    [anon_sym_tri0] = ACTIONS(25),
    [anon_sym_tri1] = ACTIONS(25),
    [anon_sym_wand] = ACTIONS(25),
    [anon_sym_triand] = ACTIONS(25),
    [anon_sym_wor] = ACTIONS(25),
    [anon_sym_trior] = ACTIONS(25),
    [anon_sym_trireg] = ACTIONS(25),
    [anon_sym_uwire] = ACTIONS(25),
    [anon_sym_SEMI] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(958),
    [anon_sym_program] = ACTIONS(10889),
    [anon_sym_checker] = ACTIONS(43),
    [anon_sym_virtual] = ACTIONS(45),
    [anon_sym_class] = ACTIONS(47),
    [anon_sym_timeunit] = ACTIONS(51),
    [anon_sym_timeprecision] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_bind] = ACTIONS(3666),
    [anon_sym_const] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(61),
    [anon_sym_static] = ACTIONS(63),
    [anon_sym_constraint] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_localparam] = ACTIONS(69),
    [anon_sym_parameter] = ACTIONS(71),
    [anon_sym_var] = ACTIONS(73),
    [anon_sym_import] = ACTIONS(75),
    [anon_sym_export] = ACTIONS(77),
    [anon_sym_interconnect] = ACTIONS(79),
    [anon_sym_typedef] = ACTIONS(81),
    [anon_sym_enum] = ACTIONS(83),
    [anon_sym_struct] = ACTIONS(85),
    [anon_sym_union] = ACTIONS(87),
    [anon_sym_nettype] = ACTIONS(89),
    [anon_sym_automatic] = ACTIONS(91),
    [anon_sym_string] = ACTIONS(93),
    [anon_sym_chandle] = ACTIONS(93),
    [anon_sym_event] = ACTIONS(93),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_supply0] = ACTIONS(25),
    [anon_sym_supply1] = ACTIONS(25),
    [anon_sym_signed] = ACTIONS(101),
    [anon_sym_unsigned] = ACTIONS(101),
    [anon_sym_task] = ACTIONS(103),
    [anon_sym_property] = ACTIONS(105),
    [anon_sym_sequence] = ACTIONS(107),
    [anon_sym_covergroup] = ACTIONS(109),
    [anon_sym_let] = ACTIONS(111),
    [anon_sym_LPAREN_STAR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARunit] = ACTIONS(119),
  },
  [5223] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_DQUOTE] = ACTIONS(1682),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1682),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_iff] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_tagged] = ACTIONS(1684),
    [anon_sym_DOLLAR] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_endproperty] = ACTIONS(1684),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_and] = ACTIONS(1684),
    [anon_sym_PIPE_DASH_GT] = ACTIONS(1682),
    [anon_sym_PIPE_EQ_GT] = ACTIONS(1682),
    [anon_sym_POUND_DASH_POUND] = ACTIONS(1682),
    [anon_sym_POUND_EQ_POUND] = ACTIONS(1682),
    [anon_sym_until] = ACTIONS(1684),
    [anon_sym_s_until] = ACTIONS(1684),
    [anon_sym_until_with] = ACTIONS(1684),
    [anon_sym_s_until_with] = ACTIONS(1684),
    [anon_sym_implies] = ACTIONS(1684),
    [anon_sym_intersect] = ACTIONS(1684),
    [anon_sym_throughout] = ACTIONS(1684),
    [anon_sym_within] = ACTIONS(1684),
    [anon_sym_POUND_POUND] = ACTIONS(1684),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(1682),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_STAR] = ACTIONS(1684),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_EQ] = ACTIONS(1682),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(1682),
    [anon_sym_dist] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_std] = ACTIONS(1684),
    [anon_sym_randomize] = ACTIONS(1684),
    [anon_sym_null] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_TILDE_AMP] = ACTIONS(1682),
    [anon_sym_TILDE_PIPE] = ACTIONS(1682),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [aux_sym_decimal_number_token1] = ACTIONS(1682),
    [aux_sym_decimal_number_token2] = ACTIONS(1682),
    [sym_binary_number] = ACTIONS(1682),
    [sym_octal_number] = ACTIONS(1682),
    [sym_hex_number] = ACTIONS(1682),
    [aux_sym_real_number_token1] = ACTIONS(1682),
    [sym_fixed_point_number] = ACTIONS(1684),
    [sym_unsigned_number] = ACTIONS(1684),
    [anon_sym_SQUOTE0] = ACTIONS(1682),
    [anon_sym_SQUOTE1] = ACTIONS(1682),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [5224] = {
    [sym_simple_identifier] = ACTIONS(9947),
    [anon_sym_DQUOTE] = ACTIONS(9949),
    [anon_sym_LPAREN] = ACTIONS(9947),
    [anon_sym_BQUOTE] = ACTIONS(9949),
    [anon_sym_DOT_STAR] = ACTIONS(9949),
    [anon_sym_SEMI] = ACTIONS(9949),
    [anon_sym_virtual] = ACTIONS(9947),
    [anon_sym_POUND] = ACTIONS(9947),
    [anon_sym_type] = ACTIONS(9947),
    [anon_sym_DOT] = ACTIONS(9947),
    [anon_sym_LBRACE] = ACTIONS(9949),
    [anon_sym_input] = ACTIONS(9947),
    [anon_sym_output] = ACTIONS(9947),
    [anon_sym_inout] = ACTIONS(9947),
    [anon_sym_ref] = ACTIONS(9947),
    [anon_sym_disable] = ACTIONS(9947),
    [anon_sym_const] = ACTIONS(9947),
    [anon_sym_local] = ACTIONS(9947),
    [anon_sym_super] = ACTIONS(9947),
    [anon_sym_if] = ACTIONS(9947),
    [anon_sym_foreach] = ACTIONS(9947),
    [anon_sym_LBRACK] = ACTIONS(9949),
    [anon_sym_unique] = ACTIONS(9947),
    [anon_sym_var] = ACTIONS(9947),
    [anon_sym_enum] = ACTIONS(9947),
    [anon_sym_struct] = ACTIONS(9947),
    [anon_sym_union] = ACTIONS(9947),
    [anon_sym_string] = ACTIONS(9947),
    [anon_sym_chandle] = ACTIONS(9947),
    [anon_sym_event] = ACTIONS(9947),
    [anon_sym_byte] = ACTIONS(9947),
    [anon_sym_shortint] = ACTIONS(9947),
    [anon_sym_int] = ACTIONS(9947),
    [anon_sym_longint] = ACTIONS(9947),
    [anon_sym_integer] = ACTIONS(9947),
    [anon_sym_time] = ACTIONS(9947),
    [anon_sym_bit] = ACTIONS(9947),
    [anon_sym_logic] = ACTIONS(9947),
    [anon_sym_reg] = ACTIONS(9947),
    [anon_sym_shortreal] = ACTIONS(9947),
    [anon_sym_real] = ACTIONS(9947),
    [anon_sym_realtime] = ACTIONS(9947),
    [anon_sym_signed] = ACTIONS(9947),
    [anon_sym_unsigned] = ACTIONS(9947),
    [anon_sym_tagged] = ACTIONS(9947),
    [anon_sym_DOLLAR] = ACTIONS(9947),
    [anon_sym_PLUS] = ACTIONS(9947),
    [anon_sym_PLUS_PLUS] = ACTIONS(9949),
    [anon_sym_assert] = ACTIONS(9947),
    [anon_sym_property] = ACTIONS(9947),
    [anon_sym_assume] = ACTIONS(9947),
    [anon_sym_cover] = ACTIONS(9947),
    [anon_sym_expect] = ACTIONS(9947),
    [anon_sym_sequence] = ACTIONS(9947),
    [anon_sym_restrict] = ACTIONS(9947),
    [anon_sym_case] = ACTIONS(9947),
    [anon_sym_untyped] = ACTIONS(9947),
    [anon_sym_POUND_POUND] = ACTIONS(9949),
    [anon_sym_begin] = ACTIONS(9947),
    [anon_sym_BANG] = ACTIONS(9949),
    [anon_sym_for] = ACTIONS(9947),
    [anon_sym_DASH] = ACTIONS(9947),
    [anon_sym_assign] = ACTIONS(9947),
    [anon_sym_deassign] = ACTIONS(9947),
    [anon_sym_force] = ACTIONS(9947),
    [anon_sym_release] = ACTIONS(9947),
    [anon_sym_fork] = ACTIONS(9947),
    [anon_sym_repeat] = ACTIONS(9947),
    [anon_sym_AT] = ACTIONS(9947),
    [anon_sym_AT_STAR] = ACTIONS(9949),
    [anon_sym_return] = ACTIONS(9947),
    [anon_sym_break] = ACTIONS(9947),
    [anon_sym_continue] = ACTIONS(9947),
    [anon_sym_wait] = ACTIONS(9947),
    [anon_sym_wait_order] = ACTIONS(9947),
    [anon_sym_DASH_GT] = ACTIONS(9947),
    [anon_sym_DASH_GT_GT] = ACTIONS(9949),
    [anon_sym_unique0] = ACTIONS(9947),
    [anon_sym_priority] = ACTIONS(9947),
    [anon_sym_casez] = ACTIONS(9947),
    [anon_sym_casex] = ACTIONS(9947),
    [anon_sym_randcase] = ACTIONS(9947),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9949),
    [anon_sym_forever] = ACTIONS(9947),
    [anon_sym_while] = ACTIONS(9947),
    [anon_sym_do] = ACTIONS(9947),
    [anon_sym_TILDE] = ACTIONS(9947),
    [anon_sym_std] = ACTIONS(9947),
    [anon_sym_randomize] = ACTIONS(9947),
    [anon_sym_null] = ACTIONS(9947),
    [anon_sym_AMP] = ACTIONS(9949),
    [anon_sym_PIPE] = ACTIONS(9949),
    [anon_sym_CARET] = ACTIONS(9947),
    [anon_sym_CARET_TILDE] = ACTIONS(9949),
    [anon_sym_TILDE_CARET] = ACTIONS(9949),
    [anon_sym_this] = ACTIONS(9947),
    [anon_sym_TILDE_AMP] = ACTIONS(9949),
    [anon_sym_TILDE_PIPE] = ACTIONS(9949),
    [anon_sym_DASH_DASH] = ACTIONS(9949),
    [aux_sym_decimal_number_token1] = ACTIONS(9949),
    [aux_sym_decimal_number_token2] = ACTIONS(9949),
    [sym_binary_number] = ACTIONS(9949),
    [sym_octal_number] = ACTIONS(9949),
    [sym_hex_number] = ACTIONS(9949),
    [aux_sym_real_number_token1] = ACTIONS(9949),
    [sym_fixed_point_number] = ACTIONS(9947),
    [sym_unsigned_number] = ACTIONS(9947),
    [anon_sym_SQUOTE0] = ACTIONS(9949),
    [anon_sym_SQUOTE1] = ACTIONS(9949),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(9949),
    [anon_sym_LPAREN_STAR] = ACTIONS(9949),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9949),
    [anon_sym_DOLLARroot] = ACTIONS(9947),
    [anon_sym_DOLLARunit] = ACTIONS(9947),
    [sym_system_tf_identifier] = ACTIONS(9947),
  },
  [5225] = {
    [sym_simple_identifier] = ACTIONS(9953),
    [anon_sym_DQUOTE] = ACTIONS(9955),
    [anon_sym_LPAREN] = ACTIONS(9953),
    [anon_sym_BQUOTE] = ACTIONS(9955),
    [anon_sym_DOT_STAR] = ACTIONS(9955),
    [anon_sym_SEMI] = ACTIONS(9955),
    [anon_sym_virtual] = ACTIONS(9953),
    [anon_sym_POUND] = ACTIONS(9953),
    [anon_sym_type] = ACTIONS(9953),
    [anon_sym_DOT] = ACTIONS(9953),
    [anon_sym_LBRACE] = ACTIONS(9955),
    [anon_sym_input] = ACTIONS(9953),
    [anon_sym_output] = ACTIONS(9953),
    [anon_sym_inout] = ACTIONS(9953),
    [anon_sym_ref] = ACTIONS(9953),
    [anon_sym_disable] = ACTIONS(9953),
    [anon_sym_const] = ACTIONS(9953),
    [anon_sym_local] = ACTIONS(9953),
    [anon_sym_super] = ACTIONS(9953),
    [anon_sym_if] = ACTIONS(9953),
    [anon_sym_foreach] = ACTIONS(9953),
    [anon_sym_LBRACK] = ACTIONS(9955),
    [anon_sym_unique] = ACTIONS(9953),
    [anon_sym_var] = ACTIONS(9953),
    [anon_sym_enum] = ACTIONS(9953),
    [anon_sym_struct] = ACTIONS(9953),
    [anon_sym_union] = ACTIONS(9953),
    [anon_sym_string] = ACTIONS(9953),
    [anon_sym_chandle] = ACTIONS(9953),
    [anon_sym_event] = ACTIONS(9953),
    [anon_sym_byte] = ACTIONS(9953),
    [anon_sym_shortint] = ACTIONS(9953),
    [anon_sym_int] = ACTIONS(9953),
    [anon_sym_longint] = ACTIONS(9953),
    [anon_sym_integer] = ACTIONS(9953),
    [anon_sym_time] = ACTIONS(9953),
    [anon_sym_bit] = ACTIONS(9953),
    [anon_sym_logic] = ACTIONS(9953),
    [anon_sym_reg] = ACTIONS(9953),
    [anon_sym_shortreal] = ACTIONS(9953),
    [anon_sym_real] = ACTIONS(9953),
    [anon_sym_realtime] = ACTIONS(9953),
    [anon_sym_signed] = ACTIONS(9953),
    [anon_sym_unsigned] = ACTIONS(9953),
    [anon_sym_tagged] = ACTIONS(9953),
    [anon_sym_DOLLAR] = ACTIONS(9953),
    [anon_sym_PLUS] = ACTIONS(9953),
    [anon_sym_PLUS_PLUS] = ACTIONS(9955),
    [anon_sym_assert] = ACTIONS(9953),
    [anon_sym_property] = ACTIONS(9953),
    [anon_sym_assume] = ACTIONS(9953),
    [anon_sym_cover] = ACTIONS(9953),
    [anon_sym_expect] = ACTIONS(9953),
    [anon_sym_sequence] = ACTIONS(9953),
    [anon_sym_restrict] = ACTIONS(9953),
    [anon_sym_case] = ACTIONS(9953),
    [anon_sym_untyped] = ACTIONS(9953),
    [anon_sym_POUND_POUND] = ACTIONS(9955),
    [anon_sym_begin] = ACTIONS(9953),
    [anon_sym_BANG] = ACTIONS(9955),
    [anon_sym_for] = ACTIONS(9953),
    [anon_sym_DASH] = ACTIONS(9953),
    [anon_sym_assign] = ACTIONS(9953),
    [anon_sym_deassign] = ACTIONS(9953),
    [anon_sym_force] = ACTIONS(9953),
    [anon_sym_release] = ACTIONS(9953),
    [anon_sym_fork] = ACTIONS(9953),
    [anon_sym_repeat] = ACTIONS(9953),
    [anon_sym_AT] = ACTIONS(9953),
    [anon_sym_AT_STAR] = ACTIONS(9955),
    [anon_sym_return] = ACTIONS(9953),
    [anon_sym_break] = ACTIONS(9953),
    [anon_sym_continue] = ACTIONS(9953),
    [anon_sym_wait] = ACTIONS(9953),
    [anon_sym_wait_order] = ACTIONS(9953),
    [anon_sym_DASH_GT] = ACTIONS(9953),
    [anon_sym_DASH_GT_GT] = ACTIONS(9955),
    [anon_sym_unique0] = ACTIONS(9953),
    [anon_sym_priority] = ACTIONS(9953),
    [anon_sym_casez] = ACTIONS(9953),
    [anon_sym_casex] = ACTIONS(9953),
    [anon_sym_randcase] = ACTIONS(9953),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(9955),
    [anon_sym_forever] = ACTIONS(9953),
    [anon_sym_while] = ACTIONS(9953),
    [anon_sym_do] = ACTIONS(9953),
    [anon_sym_TILDE] = ACTIONS(9953),
    [anon_sym_std] = ACTIONS(9953),
    [anon_sym_randomize] = ACTIONS(9953),
    [anon_sym_null] = ACTIONS(9953),
    [anon_sym_AMP] = ACTIONS(9955),
    [anon_sym_PIPE] = ACTIONS(9955),
    [anon_sym_CARET] = ACTIONS(9953),
    [anon_sym_CARET_TILDE] = ACTIONS(9955),
    [anon_sym_TILDE_CARET] = ACTIONS(9955),
    [anon_sym_this] = ACTIONS(9953),
    [anon_sym_TILDE_AMP] = ACTIONS(9955),
    [anon_sym_TILDE_PIPE] = ACTIONS(9955),
    [anon_sym_DASH_DASH] = ACTIONS(9955),
    [aux_sym_decimal_number_token1] = ACTIONS(9955),
    [aux_sym_decimal_number_token2] = ACTIONS(9955),
    [sym_binary_number] = ACTIONS(9955),
    [sym_octal_number] = ACTIONS(9955),
    [sym_hex_number] = ACTIONS(9955),
    [aux_sym_real_number_token1] = ACTIONS(9955),
    [sym_fixed_point_number] = ACTIONS(9953),
    [sym_unsigned_number] = ACTIONS(9953),
    [anon_sym_SQUOTE0] = ACTIONS(9955),
    [anon_sym_SQUOTE1] = ACTIONS(9955),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(9955),
    [anon_sym_LPAREN_STAR] = ACTIONS(9955),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9955),
    [anon_sym_DOLLARroot] = ACTIONS(9953),
    [anon_sym_DOLLARunit] = ACTIONS(9953),
    [sym_system_tf_identifier] = ACTIONS(9953),
  },
  [5226] = {
    [sym_attribute_instance] = STATE(5226),
    [aux_sym__description_repeat1] = STATE(5226),
    [sym_simple_identifier] = ACTIONS(9204),
    [anon_sym_LT] = ACTIONS(9204),
    [anon_sym_GT] = ACTIONS(9204),
    [anon_sym_LPAREN] = ACTIONS(9204),
    [anon_sym_SLASH] = ACTIONS(9204),
    [anon_sym_SEMI] = ACTIONS(9206),
    [anon_sym_COLON] = ACTIONS(9206),
    [anon_sym_checker] = ACTIONS(9204),
    [anon_sym_virtual] = ACTIONS(9204),
    [anon_sym_type] = ACTIONS(9204),
    [anon_sym_DOT] = ACTIONS(9206),
    [anon_sym_input] = ACTIONS(9204),
    [anon_sym_output] = ACTIONS(9204),
    [anon_sym_inout] = ACTIONS(9204),
    [anon_sym_ref] = ACTIONS(9204),
    [anon_sym_DOLLARfatal] = ACTIONS(9206),
    [anon_sym_DOLLARerror] = ACTIONS(9206),
    [anon_sym_DOLLARwarning] = ACTIONS(9206),
    [anon_sym_DOLLARinfo] = ACTIONS(9206),
    [anon_sym_default] = ACTIONS(9204),
    [anon_sym_clocking] = ACTIONS(9204),
    [anon_sym_bind] = ACTIONS(9204),
    [anon_sym_rand] = ACTIONS(9204),
    [anon_sym_const] = ACTIONS(9204),
    [anon_sym_function] = ACTIONS(9204),
    [anon_sym_static] = ACTIONS(9204),
    [anon_sym_if] = ACTIONS(9204),
    [anon_sym_LBRACK] = ACTIONS(9206),
    [anon_sym_RBRACK] = ACTIONS(9206),
    [anon_sym_localparam] = ACTIONS(9204),
    [anon_sym_parameter] = ACTIONS(9204),
    [anon_sym_var] = ACTIONS(9204),
    [anon_sym_import] = ACTIONS(9204),
    [anon_sym_STAR] = ACTIONS(9204),
    [anon_sym_genvar] = ACTIONS(9204),
    [anon_sym_typedef] = ACTIONS(9204),
    [anon_sym_enum] = ACTIONS(9204),
    [anon_sym_struct] = ACTIONS(9204),
    [anon_sym_union] = ACTIONS(9204),
    [anon_sym_nettype] = ACTIONS(9204),
    [anon_sym_with] = ACTIONS(9204),
    [anon_sym_automatic] = ACTIONS(9204),
    [anon_sym_string] = ACTIONS(9204),
    [anon_sym_chandle] = ACTIONS(9204),
    [anon_sym_event] = ACTIONS(9204),
    [anon_sym_byte] = ACTIONS(9204),
    [anon_sym_shortint] = ACTIONS(9204),
    [anon_sym_int] = ACTIONS(9204),
    [anon_sym_longint] = ACTIONS(9204),
    [anon_sym_integer] = ACTIONS(9204),
    [anon_sym_time] = ACTIONS(9204),
    [anon_sym_bit] = ACTIONS(9204),
    [anon_sym_logic] = ACTIONS(9204),
    [anon_sym_reg] = ACTIONS(9204),
    [anon_sym_shortreal] = ACTIONS(9204),
    [anon_sym_real] = ACTIONS(9204),
    [anon_sym_realtime] = ACTIONS(9204),
    [anon_sym_signed] = ACTIONS(9204),
    [anon_sym_unsigned] = ACTIONS(9204),
    [anon_sym_PLUS] = ACTIONS(9204),
    [anon_sym_STAR_STAR] = ACTIONS(9206),
    [anon_sym_PERCENT] = ACTIONS(9206),
    [anon_sym_EQ_EQ] = ACTIONS(9204),
    [anon_sym_BANG_EQ] = ACTIONS(9204),
    [anon_sym_LT_EQ] = ACTIONS(9206),
    [anon_sym_GT_EQ] = ACTIONS(9206),
    [anon_sym_assert] = ACTIONS(9204),
    [anon_sym_property] = ACTIONS(9204),
    [anon_sym_assume] = ACTIONS(9204),
    [anon_sym_cover] = ACTIONS(9204),
    [anon_sym_sequence] = ACTIONS(9204),
    [anon_sym_restrict] = ACTIONS(9204),
    [anon_sym_case] = ACTIONS(9204),
    [anon_sym_always] = ACTIONS(9204),
    [anon_sym_covergroup] = ACTIONS(9204),
    [anon_sym_AMP_AMP] = ACTIONS(9204),
    [anon_sym_PIPE_PIPE] = ACTIONS(9206),
    [anon_sym_matches] = ACTIONS(9204),
    [anon_sym_let] = ACTIONS(9204),
    [anon_sym_generate] = ACTIONS(9204),
    [anon_sym_for] = ACTIONS(9204),
    [anon_sym_initial] = ACTIONS(9204),
    [anon_sym_DASH] = ACTIONS(9204),
    [anon_sym_assign] = ACTIONS(9204),
    [anon_sym_always_comb] = ACTIONS(9204),
    [anon_sym_always_latch] = ACTIONS(9204),
    [anon_sym_always_ff] = ACTIONS(9204),
    [anon_sym_final] = ACTIONS(9204),
    [anon_sym_DASH_GT] = ACTIONS(9206),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9206),
    [anon_sym_inside] = ACTIONS(9204),
    [anon_sym_global] = ACTIONS(9204),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9206),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9206),
    [anon_sym_GT_GT] = ACTIONS(9204),
    [anon_sym_LT_LT] = ACTIONS(9204),
    [anon_sym_PLUS_COLON] = ACTIONS(9206),
    [anon_sym_DASH_COLON] = ACTIONS(9206),
    [anon_sym_QMARK] = ACTIONS(9206),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9206),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9206),
    [anon_sym_AMP] = ACTIONS(9204),
    [anon_sym_PIPE] = ACTIONS(9204),
    [anon_sym_CARET] = ACTIONS(9204),
    [anon_sym_CARET_TILDE] = ACTIONS(9206),
    [anon_sym_TILDE_CARET] = ACTIONS(9206),
    [anon_sym_GT_GT_GT] = ACTIONS(9206),
    [anon_sym_LT_LT_LT] = ACTIONS(9206),
    [anon_sym_LT_DASH_GT] = ACTIONS(9206),
    [anon_sym_LPAREN_STAR] = ACTIONS(11191),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9206),
    [anon_sym_DOLLARunit] = ACTIONS(9206),
  },
  [5227] = {
    [sym_simple_identifier] = ACTIONS(9947),
    [anon_sym_LT] = ACTIONS(9947),
    [anon_sym_GT] = ACTIONS(9947),
    [anon_sym_LPAREN] = ACTIONS(9947),
    [anon_sym_SLASH] = ACTIONS(9947),
    [anon_sym_SEMI] = ACTIONS(9949),
    [anon_sym_COLON] = ACTIONS(9949),
    [anon_sym_checker] = ACTIONS(9947),
    [anon_sym_virtual] = ACTIONS(9947),
    [anon_sym_type] = ACTIONS(9947),
    [anon_sym_DOT] = ACTIONS(9949),
    [anon_sym_input] = ACTIONS(9947),
    [anon_sym_output] = ACTIONS(9947),
    [anon_sym_inout] = ACTIONS(9947),
    [anon_sym_ref] = ACTIONS(9947),
    [anon_sym_DOLLARfatal] = ACTIONS(9949),
    [anon_sym_DOLLARerror] = ACTIONS(9949),
    [anon_sym_DOLLARwarning] = ACTIONS(9949),
    [anon_sym_DOLLARinfo] = ACTIONS(9949),
    [anon_sym_default] = ACTIONS(9947),
    [anon_sym_clocking] = ACTIONS(9947),
    [anon_sym_bind] = ACTIONS(9947),
    [anon_sym_rand] = ACTIONS(9947),
    [anon_sym_const] = ACTIONS(9947),
    [anon_sym_function] = ACTIONS(9947),
    [anon_sym_static] = ACTIONS(9947),
    [anon_sym_if] = ACTIONS(9947),
    [anon_sym_LBRACK] = ACTIONS(9949),
    [anon_sym_RBRACK] = ACTIONS(9949),
    [anon_sym_localparam] = ACTIONS(9947),
    [anon_sym_parameter] = ACTIONS(9947),
    [anon_sym_var] = ACTIONS(9947),
    [anon_sym_import] = ACTIONS(9947),
    [anon_sym_STAR] = ACTIONS(9947),
    [anon_sym_genvar] = ACTIONS(9947),
    [anon_sym_typedef] = ACTIONS(9947),
    [anon_sym_enum] = ACTIONS(9947),
    [anon_sym_struct] = ACTIONS(9947),
    [anon_sym_union] = ACTIONS(9947),
    [anon_sym_nettype] = ACTIONS(9947),
    [anon_sym_with] = ACTIONS(9947),
    [anon_sym_automatic] = ACTIONS(9947),
    [anon_sym_string] = ACTIONS(9947),
    [anon_sym_chandle] = ACTIONS(9947),
    [anon_sym_event] = ACTIONS(9947),
    [anon_sym_byte] = ACTIONS(9947),
    [anon_sym_shortint] = ACTIONS(9947),
    [anon_sym_int] = ACTIONS(9947),
    [anon_sym_longint] = ACTIONS(9947),
    [anon_sym_integer] = ACTIONS(9947),
    [anon_sym_time] = ACTIONS(9947),
    [anon_sym_bit] = ACTIONS(9947),
    [anon_sym_logic] = ACTIONS(9947),
    [anon_sym_reg] = ACTIONS(9947),
    [anon_sym_shortreal] = ACTIONS(9947),
    [anon_sym_real] = ACTIONS(9947),
    [anon_sym_realtime] = ACTIONS(9947),
    [anon_sym_signed] = ACTIONS(9947),
    [anon_sym_unsigned] = ACTIONS(9947),
    [anon_sym_PLUS] = ACTIONS(9947),
    [anon_sym_STAR_STAR] = ACTIONS(9949),
    [anon_sym_PERCENT] = ACTIONS(9949),
    [anon_sym_EQ_EQ] = ACTIONS(9947),
    [anon_sym_BANG_EQ] = ACTIONS(9947),
    [anon_sym_LT_EQ] = ACTIONS(9949),
    [anon_sym_GT_EQ] = ACTIONS(9949),
    [anon_sym_assert] = ACTIONS(9947),
    [anon_sym_property] = ACTIONS(9947),
    [anon_sym_assume] = ACTIONS(9947),
    [anon_sym_cover] = ACTIONS(9947),
    [anon_sym_sequence] = ACTIONS(9947),
    [anon_sym_restrict] = ACTIONS(9947),
    [anon_sym_case] = ACTIONS(9947),
    [anon_sym_always] = ACTIONS(9947),
    [anon_sym_covergroup] = ACTIONS(9947),
    [anon_sym_AMP_AMP] = ACTIONS(9947),
    [anon_sym_PIPE_PIPE] = ACTIONS(9949),
    [anon_sym_matches] = ACTIONS(9947),
    [anon_sym_let] = ACTIONS(9947),
    [anon_sym_generate] = ACTIONS(9947),
    [anon_sym_for] = ACTIONS(9947),
    [anon_sym_initial] = ACTIONS(9947),
    [anon_sym_DASH] = ACTIONS(9947),
    [anon_sym_assign] = ACTIONS(9947),
    [anon_sym_always_comb] = ACTIONS(9947),
    [anon_sym_always_latch] = ACTIONS(9947),
    [anon_sym_always_ff] = ACTIONS(9947),
    [anon_sym_final] = ACTIONS(9947),
    [anon_sym_DASH_GT] = ACTIONS(9949),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9949),
    [anon_sym_inside] = ACTIONS(9947),
    [anon_sym_global] = ACTIONS(9947),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9949),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9949),
    [anon_sym_GT_GT] = ACTIONS(9947),
    [anon_sym_LT_LT] = ACTIONS(9947),
    [anon_sym_PLUS_COLON] = ACTIONS(9949),
    [anon_sym_DASH_COLON] = ACTIONS(9949),
    [anon_sym_QMARK] = ACTIONS(9949),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9949),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9949),
    [anon_sym_AMP] = ACTIONS(9947),
    [anon_sym_PIPE] = ACTIONS(9947),
    [anon_sym_CARET] = ACTIONS(9947),
    [anon_sym_CARET_TILDE] = ACTIONS(9949),
    [anon_sym_TILDE_CARET] = ACTIONS(9949),
    [anon_sym_GT_GT_GT] = ACTIONS(9949),
    [anon_sym_LT_LT_LT] = ACTIONS(9949),
    [anon_sym_LT_DASH_GT] = ACTIONS(9949),
    [anon_sym_LPAREN_STAR] = ACTIONS(9949),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9949),
    [anon_sym_DOLLARunit] = ACTIONS(9949),
  },
  [5228] = {
    [sym_simple_identifier] = ACTIONS(9953),
    [anon_sym_LT] = ACTIONS(9953),
    [anon_sym_GT] = ACTIONS(9953),
    [anon_sym_LPAREN] = ACTIONS(9953),
    [anon_sym_SLASH] = ACTIONS(9953),
    [anon_sym_SEMI] = ACTIONS(9955),
    [anon_sym_COLON] = ACTIONS(9955),
    [anon_sym_checker] = ACTIONS(9953),
    [anon_sym_virtual] = ACTIONS(9953),
    [anon_sym_type] = ACTIONS(9953),
    [anon_sym_DOT] = ACTIONS(9955),
    [anon_sym_input] = ACTIONS(9953),
    [anon_sym_output] = ACTIONS(9953),
    [anon_sym_inout] = ACTIONS(9953),
    [anon_sym_ref] = ACTIONS(9953),
    [anon_sym_DOLLARfatal] = ACTIONS(9955),
    [anon_sym_DOLLARerror] = ACTIONS(9955),
    [anon_sym_DOLLARwarning] = ACTIONS(9955),
    [anon_sym_DOLLARinfo] = ACTIONS(9955),
    [anon_sym_default] = ACTIONS(9953),
    [anon_sym_clocking] = ACTIONS(9953),
    [anon_sym_bind] = ACTIONS(9953),
    [anon_sym_rand] = ACTIONS(9953),
    [anon_sym_const] = ACTIONS(9953),
    [anon_sym_function] = ACTIONS(9953),
    [anon_sym_static] = ACTIONS(9953),
    [anon_sym_if] = ACTIONS(9953),
    [anon_sym_LBRACK] = ACTIONS(9955),
    [anon_sym_RBRACK] = ACTIONS(9955),
    [anon_sym_localparam] = ACTIONS(9953),
    [anon_sym_parameter] = ACTIONS(9953),
    [anon_sym_var] = ACTIONS(9953),
    [anon_sym_import] = ACTIONS(9953),
    [anon_sym_STAR] = ACTIONS(9953),
    [anon_sym_genvar] = ACTIONS(9953),
    [anon_sym_typedef] = ACTIONS(9953),
    [anon_sym_enum] = ACTIONS(9953),
    [anon_sym_struct] = ACTIONS(9953),
    [anon_sym_union] = ACTIONS(9953),
    [anon_sym_nettype] = ACTIONS(9953),
    [anon_sym_with] = ACTIONS(9953),
    [anon_sym_automatic] = ACTIONS(9953),
    [anon_sym_string] = ACTIONS(9953),
    [anon_sym_chandle] = ACTIONS(9953),
    [anon_sym_event] = ACTIONS(9953),
    [anon_sym_byte] = ACTIONS(9953),
    [anon_sym_shortint] = ACTIONS(9953),
    [anon_sym_int] = ACTIONS(9953),
    [anon_sym_longint] = ACTIONS(9953),
    [anon_sym_integer] = ACTIONS(9953),
    [anon_sym_time] = ACTIONS(9953),
    [anon_sym_bit] = ACTIONS(9953),
    [anon_sym_logic] = ACTIONS(9953),
    [anon_sym_reg] = ACTIONS(9953),
    [anon_sym_shortreal] = ACTIONS(9953),
    [anon_sym_real] = ACTIONS(9953),
    [anon_sym_realtime] = ACTIONS(9953),
    [anon_sym_signed] = ACTIONS(9953),
    [anon_sym_unsigned] = ACTIONS(9953),
    [anon_sym_PLUS] = ACTIONS(9953),
    [anon_sym_STAR_STAR] = ACTIONS(9955),
    [anon_sym_PERCENT] = ACTIONS(9955),
    [anon_sym_EQ_EQ] = ACTIONS(9953),
    [anon_sym_BANG_EQ] = ACTIONS(9953),
    [anon_sym_LT_EQ] = ACTIONS(9955),
    [anon_sym_GT_EQ] = ACTIONS(9955),
    [anon_sym_assert] = ACTIONS(9953),
    [anon_sym_property] = ACTIONS(9953),
    [anon_sym_assume] = ACTIONS(9953),
    [anon_sym_cover] = ACTIONS(9953),
    [anon_sym_sequence] = ACTIONS(9953),
    [anon_sym_restrict] = ACTIONS(9953),
    [anon_sym_case] = ACTIONS(9953),
    [anon_sym_always] = ACTIONS(9953),
    [anon_sym_covergroup] = ACTIONS(9953),
    [anon_sym_AMP_AMP] = ACTIONS(9953),
    [anon_sym_PIPE_PIPE] = ACTIONS(9955),
    [anon_sym_matches] = ACTIONS(9953),
    [anon_sym_let] = ACTIONS(9953),
    [anon_sym_generate] = ACTIONS(9953),
    [anon_sym_for] = ACTIONS(9953),
    [anon_sym_initial] = ACTIONS(9953),
    [anon_sym_DASH] = ACTIONS(9953),
    [anon_sym_assign] = ACTIONS(9953),
    [anon_sym_always_comb] = ACTIONS(9953),
    [anon_sym_always_latch] = ACTIONS(9953),
    [anon_sym_always_ff] = ACTIONS(9953),
    [anon_sym_final] = ACTIONS(9953),
    [anon_sym_DASH_GT] = ACTIONS(9955),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(9955),
    [anon_sym_inside] = ACTIONS(9953),
    [anon_sym_global] = ACTIONS(9953),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(9955),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(9955),
    [anon_sym_GT_GT] = ACTIONS(9953),
    [anon_sym_LT_LT] = ACTIONS(9953),
    [anon_sym_PLUS_COLON] = ACTIONS(9955),
    [anon_sym_DASH_COLON] = ACTIONS(9955),
    [anon_sym_QMARK] = ACTIONS(9955),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(9955),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(9955),
    [anon_sym_AMP] = ACTIONS(9953),
    [anon_sym_PIPE] = ACTIONS(9953),
    [anon_sym_CARET] = ACTIONS(9953),
    [anon_sym_CARET_TILDE] = ACTIONS(9955),
    [anon_sym_TILDE_CARET] = ACTIONS(9955),
    [anon_sym_GT_GT_GT] = ACTIONS(9955),
    [anon_sym_LT_LT_LT] = ACTIONS(9955),
    [anon_sym_LT_DASH_GT] = ACTIONS(9955),
    [anon_sym_LPAREN_STAR] = ACTIONS(9955),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(9955),
    [anon_sym_DOLLARunit] = ACTIONS(9955),
  },
  [5229] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8957),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_constant_expression] = STATE(10422),
    [sym_module_path_expression] = STATE(15780),
    [sym_constant_primary] = STATE(9258),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(9808),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym_unary_operator] = STATE(8532),
    [sym__number] = STATE(9920),
    [sym_integral_number] = STATE(9920),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(9920),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(7138),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(8045),
    [sym_package_scope] = STATE(12489),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13820),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11194),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11198),
    [anon_sym_BQUOTE] = ACTIONS(11200),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11202),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS] = ACTIONS(2674),
    [anon_sym_BANG] = ACTIONS(2674),
    [anon_sym_DASH] = ACTIONS(2674),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_TILDE] = ACTIONS(2662),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(11206),
    [anon_sym_AMP] = ACTIONS(2674),
    [anon_sym_PIPE] = ACTIONS(2674),
    [anon_sym_CARET] = ACTIONS(2662),
    [anon_sym_CARET_TILDE] = ACTIONS(2674),
    [anon_sym_TILDE_CARET] = ACTIONS(2674),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_TILDE_AMP] = ACTIONS(2674),
    [anon_sym_TILDE_PIPE] = ACTIONS(2674),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11220),
    [anon_sym_DOLLARroot] = ACTIONS(11222),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5230] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_checker] = ACTIONS(1688),
    [anon_sym_endchecker] = ACTIONS(1688),
    [anon_sym_virtual] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_DOLLARfatal] = ACTIONS(1686),
    [anon_sym_DOLLARerror] = ACTIONS(1686),
    [anon_sym_DOLLARwarning] = ACTIONS(1686),
    [anon_sym_DOLLARinfo] = ACTIONS(1686),
    [anon_sym_default] = ACTIONS(1688),
    [anon_sym_clocking] = ACTIONS(1688),
    [anon_sym_rand] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_function] = ACTIONS(1688),
    [anon_sym_static] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_var] = ACTIONS(1688),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_genvar] = ACTIONS(1688),
    [anon_sym_typedef] = ACTIONS(1688),
    [anon_sym_enum] = ACTIONS(1688),
    [anon_sym_struct] = ACTIONS(1688),
    [anon_sym_union] = ACTIONS(1688),
    [anon_sym_nettype] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_automatic] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_chandle] = ACTIONS(1688),
    [anon_sym_event] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_property] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_sequence] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_always] = ACTIONS(1688),
    [anon_sym_covergroup] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_let] = ACTIONS(1688),
    [anon_sym_generate] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_initial] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_always_comb] = ACTIONS(1688),
    [anon_sym_always_latch] = ACTIONS(1688),
    [anon_sym_always_ff] = ACTIONS(1688),
    [anon_sym_final] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_global] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_PLUS_COLON] = ACTIONS(1686),
    [anon_sym_DASH_COLON] = ACTIONS(1686),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARunit] = ACTIONS(1686),
  },
  [5231] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_checker] = ACTIONS(1684),
    [anon_sym_endchecker] = ACTIONS(1684),
    [anon_sym_virtual] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_DOLLARfatal] = ACTIONS(1682),
    [anon_sym_DOLLARerror] = ACTIONS(1682),
    [anon_sym_DOLLARwarning] = ACTIONS(1682),
    [anon_sym_DOLLARinfo] = ACTIONS(1682),
    [anon_sym_default] = ACTIONS(1684),
    [anon_sym_clocking] = ACTIONS(1684),
    [anon_sym_rand] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_function] = ACTIONS(1684),
    [anon_sym_static] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_var] = ACTIONS(1684),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_genvar] = ACTIONS(1684),
    [anon_sym_typedef] = ACTIONS(1684),
    [anon_sym_enum] = ACTIONS(1684),
    [anon_sym_struct] = ACTIONS(1684),
    [anon_sym_union] = ACTIONS(1684),
    [anon_sym_nettype] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_automatic] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_chandle] = ACTIONS(1684),
    [anon_sym_event] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_property] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_sequence] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_always] = ACTIONS(1684),
    [anon_sym_covergroup] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_let] = ACTIONS(1684),
    [anon_sym_generate] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_initial] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_always_comb] = ACTIONS(1684),
    [anon_sym_always_latch] = ACTIONS(1684),
    [anon_sym_always_ff] = ACTIONS(1684),
    [anon_sym_final] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_global] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_PLUS_COLON] = ACTIONS(1682),
    [anon_sym_DASH_COLON] = ACTIONS(1682),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARunit] = ACTIONS(1682),
  },
  [5232] = {
    [sym_packed_dimension] = STATE(11366),
    [sym_unsized_dimension] = STATE(11625),
    [sym_parameter_value_assignment] = STATE(11716),
    [sym_list_of_arguments_parent] = STATE(5608),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5460),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8358),
    [sym_attribute_instance] = STATE(5440),
    [aux_sym__description_repeat1] = STATE(5440),
    [aux_sym_data_type_repeat1] = STATE(11366),
    [aux_sym_class_type_repeat1] = STATE(11664),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11224),
    [anon_sym_DQUOTE] = ACTIONS(11228),
    [anon_sym_LT] = ACTIONS(11224),
    [anon_sym_GT] = ACTIONS(11224),
    [anon_sym_LPAREN] = ACTIONS(11232),
    [anon_sym_RPAREN] = ACTIONS(11238),
    [anon_sym_COMMA] = ACTIONS(11238),
    [anon_sym_BQUOTE] = ACTIONS(11228),
    [anon_sym_SLASH] = ACTIONS(11224),
    [anon_sym_COLON] = ACTIONS(11224),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11224),
    [anon_sym_DOT] = ACTIONS(11247),
    [anon_sym_LBRACE] = ACTIONS(11228),
    [anon_sym_const] = ACTIONS(11224),
    [anon_sym_local] = ACTIONS(11224),
    [anon_sym_super] = ACTIONS(11224),
    [anon_sym_LBRACK] = ACTIONS(11255),
    [anon_sym_COLON_COLON] = ACTIONS(11258),
    [anon_sym_STAR] = ACTIONS(11224),
    [anon_sym_string] = ACTIONS(11224),
    [anon_sym_byte] = ACTIONS(11224),
    [anon_sym_shortint] = ACTIONS(11224),
    [anon_sym_int] = ACTIONS(11224),
    [anon_sym_longint] = ACTIONS(11224),
    [anon_sym_integer] = ACTIONS(11224),
    [anon_sym_time] = ACTIONS(11224),
    [anon_sym_bit] = ACTIONS(11224),
    [anon_sym_logic] = ACTIONS(11224),
    [anon_sym_reg] = ACTIONS(11224),
    [anon_sym_shortreal] = ACTIONS(11224),
    [anon_sym_real] = ACTIONS(11224),
    [anon_sym_realtime] = ACTIONS(11224),
    [anon_sym_signed] = ACTIONS(11224),
    [anon_sym_unsigned] = ACTIONS(11224),
    [anon_sym_tagged] = ACTIONS(11224),
    [anon_sym_DOLLAR] = ACTIONS(11224),
    [anon_sym_PLUS] = ACTIONS(11224),
    [anon_sym_PLUS_PLUS] = ACTIONS(11260),
    [anon_sym_STAR_STAR] = ACTIONS(11228),
    [anon_sym_PERCENT] = ACTIONS(11228),
    [anon_sym_EQ_EQ] = ACTIONS(11224),
    [anon_sym_BANG_EQ] = ACTIONS(11224),
    [anon_sym_LT_EQ] = ACTIONS(11228),
    [anon_sym_GT_EQ] = ACTIONS(11228),
    [anon_sym_BANG] = ACTIONS(11224),
    [anon_sym_AMP_AMP] = ACTIONS(11224),
    [anon_sym_PIPE_PIPE] = ACTIONS(11228),
    [anon_sym_matches] = ACTIONS(11224),
    [anon_sym_DASH] = ACTIONS(11224),
    [anon_sym_DASH_GT] = ACTIONS(11228),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11228),
    [anon_sym_inside] = ACTIONS(11224),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11265),
    [anon_sym_TILDE] = ACTIONS(11224),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11228),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11228),
    [anon_sym_GT_GT] = ACTIONS(11224),
    [anon_sym_LT_LT] = ACTIONS(11224),
    [anon_sym_std] = ACTIONS(11224),
    [anon_sym_randomize] = ACTIONS(11224),
    [anon_sym_null] = ACTIONS(11224),
    [anon_sym_QMARK] = ACTIONS(11228),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_AMP] = ACTIONS(11224),
    [anon_sym_PIPE] = ACTIONS(11224),
    [anon_sym_CARET] = ACTIONS(11224),
    [anon_sym_CARET_TILDE] = ACTIONS(11228),
    [anon_sym_TILDE_CARET] = ACTIONS(11228),
    [anon_sym_GT_GT_GT] = ACTIONS(11228),
    [anon_sym_LT_LT_LT] = ACTIONS(11228),
    [anon_sym_LT_DASH_GT] = ACTIONS(11228),
    [anon_sym_this] = ACTIONS(11224),
    [anon_sym_SQUOTE] = ACTIONS(11270),
    [anon_sym_TILDE_AMP] = ACTIONS(11228),
    [anon_sym_TILDE_PIPE] = ACTIONS(11228),
    [anon_sym_DASH_DASH] = ACTIONS(11260),
    [aux_sym_decimal_number_token1] = ACTIONS(11228),
    [aux_sym_decimal_number_token2] = ACTIONS(11228),
    [sym_binary_number] = ACTIONS(11228),
    [sym_octal_number] = ACTIONS(11228),
    [sym_hex_number] = ACTIONS(11228),
    [aux_sym_real_number_token1] = ACTIONS(11228),
    [sym_fixed_point_number] = ACTIONS(11224),
    [sym_unsigned_number] = ACTIONS(11224),
    [anon_sym_SQUOTE0] = ACTIONS(11228),
    [anon_sym_SQUOTE1] = ACTIONS(11228),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11228),
    [anon_sym_LPAREN_STAR] = ACTIONS(11274),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11228),
    [anon_sym_DOLLARroot] = ACTIONS(11224),
    [anon_sym_DOLLARunit] = ACTIONS(11224),
    [sym_system_tf_identifier] = ACTIONS(11224),
  },
  [5233] = {
    [sym_simple_identifier] = ACTIONS(1676),
    [anon_sym_LT] = ACTIONS(1676),
    [anon_sym_GT] = ACTIONS(1676),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1674),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1674),
    [anon_sym_BQUOTE] = ACTIONS(1676),
    [aux_sym_id_directive_token1] = ACTIONS(1674),
    [aux_sym_id_directive_token2] = ACTIONS(1674),
    [aux_sym_id_directive_token3] = ACTIONS(1674),
    [aux_sym_id_directive_token4] = ACTIONS(1676),
    [aux_sym_zero_directive_token1] = ACTIONS(1674),
    [aux_sym_zero_directive_token2] = ACTIONS(1674),
    [aux_sym_zero_directive_token3] = ACTIONS(1674),
    [aux_sym_zero_directive_token4] = ACTIONS(1674),
    [aux_sym_zero_directive_token5] = ACTIONS(1674),
    [aux_sym_zero_directive_token6] = ACTIONS(1674),
    [aux_sym_zero_directive_token7] = ACTIONS(1674),
    [aux_sym_zero_directive_token8] = ACTIONS(1674),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1674),
    [anon_sym_SLASH] = ACTIONS(1676),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1674),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1674),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1674),
    [aux_sym_begin_keywords_token1] = ACTIONS(1674),
    [anon_sym_SEMI] = ACTIONS(1674),
    [anon_sym_COLON] = ACTIONS(1674),
    [anon_sym_extern] = ACTIONS(1676),
    [anon_sym_virtual] = ACTIONS(1676),
    [anon_sym_class] = ACTIONS(1676),
    [anon_sym_endclass] = ACTIONS(1676),
    [anon_sym_pure] = ACTIONS(1676),
    [anon_sym_type] = ACTIONS(1676),
    [anon_sym_DOT] = ACTIONS(1674),
    [anon_sym_rand] = ACTIONS(1676),
    [anon_sym_const] = ACTIONS(1676),
    [anon_sym_function] = ACTIONS(1676),
    [anon_sym_static] = ACTIONS(1676),
    [anon_sym_protected] = ACTIONS(1676),
    [anon_sym_local] = ACTIONS(1676),
    [anon_sym_randc] = ACTIONS(1676),
    [anon_sym_constraint] = ACTIONS(1676),
    [anon_sym_LBRACK] = ACTIONS(1674),
    [anon_sym_RBRACK] = ACTIONS(1674),
    [anon_sym_localparam] = ACTIONS(1676),
    [anon_sym_parameter] = ACTIONS(1676),
    [anon_sym_var] = ACTIONS(1676),
    [anon_sym_import] = ACTIONS(1676),
    [anon_sym_STAR] = ACTIONS(1676),
    [anon_sym_typedef] = ACTIONS(1676),
    [anon_sym_enum] = ACTIONS(1676),
    [anon_sym_struct] = ACTIONS(1676),
    [anon_sym_union] = ACTIONS(1676),
    [anon_sym_nettype] = ACTIONS(1676),
    [anon_sym_automatic] = ACTIONS(1676),
    [anon_sym_string] = ACTIONS(1676),
    [anon_sym_chandle] = ACTIONS(1676),
    [anon_sym_event] = ACTIONS(1676),
    [anon_sym_byte] = ACTIONS(1676),
    [anon_sym_shortint] = ACTIONS(1676),
    [anon_sym_int] = ACTIONS(1676),
    [anon_sym_longint] = ACTIONS(1676),
    [anon_sym_integer] = ACTIONS(1676),
    [anon_sym_time] = ACTIONS(1676),
    [anon_sym_bit] = ACTIONS(1676),
    [anon_sym_logic] = ACTIONS(1676),
    [anon_sym_reg] = ACTIONS(1676),
    [anon_sym_shortreal] = ACTIONS(1676),
    [anon_sym_real] = ACTIONS(1676),
    [anon_sym_realtime] = ACTIONS(1676),
    [anon_sym_signed] = ACTIONS(1676),
    [anon_sym_unsigned] = ACTIONS(1676),
    [anon_sym_task] = ACTIONS(1676),
    [anon_sym_PLUS] = ACTIONS(1676),
    [anon_sym_STAR_STAR] = ACTIONS(1674),
    [anon_sym_PERCENT] = ACTIONS(1674),
    [anon_sym_EQ_EQ] = ACTIONS(1676),
    [anon_sym_BANG_EQ] = ACTIONS(1676),
    [anon_sym_LT_EQ] = ACTIONS(1674),
    [anon_sym_GT_EQ] = ACTIONS(1674),
    [anon_sym_covergroup] = ACTIONS(1676),
    [anon_sym_AMP_AMP] = ACTIONS(1676),
    [anon_sym_PIPE_PIPE] = ACTIONS(1674),
    [anon_sym_matches] = ACTIONS(1676),
    [anon_sym_DASH] = ACTIONS(1676),
    [anon_sym_DASH_GT] = ACTIONS(1674),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1674),
    [anon_sym_inside] = ACTIONS(1676),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1674),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1674),
    [anon_sym_GT_GT] = ACTIONS(1676),
    [anon_sym_LT_LT] = ACTIONS(1676),
    [anon_sym_PLUS_COLON] = ACTIONS(1674),
    [anon_sym_DASH_COLON] = ACTIONS(1674),
    [anon_sym_QMARK] = ACTIONS(1674),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1674),
    [anon_sym_AMP] = ACTIONS(1676),
    [anon_sym_PIPE] = ACTIONS(1676),
    [anon_sym_CARET] = ACTIONS(1676),
    [anon_sym_CARET_TILDE] = ACTIONS(1674),
    [anon_sym_TILDE_CARET] = ACTIONS(1674),
    [anon_sym_GT_GT_GT] = ACTIONS(1674),
    [anon_sym_LT_LT_LT] = ACTIONS(1674),
    [anon_sym_LT_DASH_GT] = ACTIONS(1674),
    [anon_sym_LPAREN_STAR] = ACTIONS(1674),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1674),
    [anon_sym_DOLLARunit] = ACTIONS(1674),
  },
  [5234] = {
    [sym_simple_identifier] = ACTIONS(1680),
    [anon_sym_LT] = ACTIONS(1680),
    [anon_sym_GT] = ACTIONS(1680),
    [aux_sym_include_compiler_directive_token1] = ACTIONS(1678),
    [aux_sym_text_macro_definition_token1] = ACTIONS(1678),
    [anon_sym_BQUOTE] = ACTIONS(1680),
    [aux_sym_id_directive_token1] = ACTIONS(1678),
    [aux_sym_id_directive_token2] = ACTIONS(1678),
    [aux_sym_id_directive_token3] = ACTIONS(1678),
    [aux_sym_id_directive_token4] = ACTIONS(1680),
    [aux_sym_zero_directive_token1] = ACTIONS(1678),
    [aux_sym_zero_directive_token2] = ACTIONS(1678),
    [aux_sym_zero_directive_token3] = ACTIONS(1678),
    [aux_sym_zero_directive_token4] = ACTIONS(1678),
    [aux_sym_zero_directive_token5] = ACTIONS(1678),
    [aux_sym_zero_directive_token6] = ACTIONS(1678),
    [aux_sym_zero_directive_token7] = ACTIONS(1678),
    [aux_sym_zero_directive_token8] = ACTIONS(1678),
    [aux_sym_timescale_compiler_directive_token1] = ACTIONS(1678),
    [anon_sym_SLASH] = ACTIONS(1680),
    [aux_sym_default_nettype_compiler_directive_token1] = ACTIONS(1678),
    [aux_sym_unconnected_drive_token1] = ACTIONS(1678),
    [aux_sym_line_compiler_directive_token1] = ACTIONS(1678),
    [aux_sym_begin_keywords_token1] = ACTIONS(1678),
    [anon_sym_SEMI] = ACTIONS(1678),
    [anon_sym_COLON] = ACTIONS(1678),
    [anon_sym_extern] = ACTIONS(1680),
    [anon_sym_virtual] = ACTIONS(1680),
    [anon_sym_class] = ACTIONS(1680),
    [anon_sym_endclass] = ACTIONS(1680),
    [anon_sym_pure] = ACTIONS(1680),
    [anon_sym_type] = ACTIONS(1680),
    [anon_sym_DOT] = ACTIONS(1678),
    [anon_sym_rand] = ACTIONS(1680),
    [anon_sym_const] = ACTIONS(1680),
    [anon_sym_function] = ACTIONS(1680),
    [anon_sym_static] = ACTIONS(1680),
    [anon_sym_protected] = ACTIONS(1680),
    [anon_sym_local] = ACTIONS(1680),
    [anon_sym_randc] = ACTIONS(1680),
    [anon_sym_constraint] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1678),
    [anon_sym_RBRACK] = ACTIONS(1678),
    [anon_sym_localparam] = ACTIONS(1680),
    [anon_sym_parameter] = ACTIONS(1680),
    [anon_sym_var] = ACTIONS(1680),
    [anon_sym_import] = ACTIONS(1680),
    [anon_sym_STAR] = ACTIONS(1680),
    [anon_sym_typedef] = ACTIONS(1680),
    [anon_sym_enum] = ACTIONS(1680),
    [anon_sym_struct] = ACTIONS(1680),
    [anon_sym_union] = ACTIONS(1680),
    [anon_sym_nettype] = ACTIONS(1680),
    [anon_sym_automatic] = ACTIONS(1680),
    [anon_sym_string] = ACTIONS(1680),
    [anon_sym_chandle] = ACTIONS(1680),
    [anon_sym_event] = ACTIONS(1680),
    [anon_sym_byte] = ACTIONS(1680),
    [anon_sym_shortint] = ACTIONS(1680),
    [anon_sym_int] = ACTIONS(1680),
    [anon_sym_longint] = ACTIONS(1680),
    [anon_sym_integer] = ACTIONS(1680),
    [anon_sym_time] = ACTIONS(1680),
    [anon_sym_bit] = ACTIONS(1680),
    [anon_sym_logic] = ACTIONS(1680),
    [anon_sym_reg] = ACTIONS(1680),
    [anon_sym_shortreal] = ACTIONS(1680),
    [anon_sym_real] = ACTIONS(1680),
    [anon_sym_realtime] = ACTIONS(1680),
    [anon_sym_signed] = ACTIONS(1680),
    [anon_sym_unsigned] = ACTIONS(1680),
    [anon_sym_task] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1680),
    [anon_sym_STAR_STAR] = ACTIONS(1678),
    [anon_sym_PERCENT] = ACTIONS(1678),
    [anon_sym_EQ_EQ] = ACTIONS(1680),
    [anon_sym_BANG_EQ] = ACTIONS(1680),
    [anon_sym_LT_EQ] = ACTIONS(1678),
    [anon_sym_GT_EQ] = ACTIONS(1678),
    [anon_sym_covergroup] = ACTIONS(1680),
    [anon_sym_AMP_AMP] = ACTIONS(1680),
    [anon_sym_PIPE_PIPE] = ACTIONS(1678),
    [anon_sym_matches] = ACTIONS(1680),
    [anon_sym_DASH] = ACTIONS(1680),
    [anon_sym_DASH_GT] = ACTIONS(1678),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1678),
    [anon_sym_inside] = ACTIONS(1680),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1678),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1678),
    [anon_sym_GT_GT] = ACTIONS(1680),
    [anon_sym_LT_LT] = ACTIONS(1680),
    [anon_sym_PLUS_COLON] = ACTIONS(1678),
    [anon_sym_DASH_COLON] = ACTIONS(1678),
    [anon_sym_QMARK] = ACTIONS(1678),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1678),
    [anon_sym_AMP] = ACTIONS(1680),
    [anon_sym_PIPE] = ACTIONS(1680),
    [anon_sym_CARET] = ACTIONS(1680),
    [anon_sym_CARET_TILDE] = ACTIONS(1678),
    [anon_sym_TILDE_CARET] = ACTIONS(1678),
    [anon_sym_GT_GT_GT] = ACTIONS(1678),
    [anon_sym_LT_LT_LT] = ACTIONS(1678),
    [anon_sym_LT_DASH_GT] = ACTIONS(1678),
    [anon_sym_LPAREN_STAR] = ACTIONS(1678),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1678),
    [anon_sym_DOLLARunit] = ACTIONS(1678),
  },
  [5235] = {
    [sym_packed_dimension] = STATE(11367),
    [sym_unsized_dimension] = STATE(11625),
    [sym_parameter_value_assignment] = STATE(11752),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5461),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8350),
    [aux_sym_data_type_repeat1] = STATE(11367),
    [aux_sym_class_type_repeat1] = STATE(11753),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11276),
    [anon_sym_DQUOTE] = ACTIONS(11279),
    [anon_sym_LT] = ACTIONS(11276),
    [anon_sym_GT] = ACTIONS(11276),
    [anon_sym_LPAREN] = ACTIONS(11282),
    [anon_sym_RPAREN] = ACTIONS(11287),
    [anon_sym_COMMA] = ACTIONS(11287),
    [anon_sym_BQUOTE] = ACTIONS(11279),
    [anon_sym_SLASH] = ACTIONS(11276),
    [anon_sym_COLON] = ACTIONS(11276),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11276),
    [anon_sym_DOT] = ACTIONS(11293),
    [anon_sym_LBRACE] = ACTIONS(11279),
    [anon_sym_const] = ACTIONS(11276),
    [anon_sym_local] = ACTIONS(11276),
    [anon_sym_super] = ACTIONS(11276),
    [anon_sym_LBRACK] = ACTIONS(11298),
    [anon_sym_COLON_COLON] = ACTIONS(11300),
    [anon_sym_STAR] = ACTIONS(11276),
    [anon_sym_string] = ACTIONS(11276),
    [anon_sym_byte] = ACTIONS(11276),
    [anon_sym_shortint] = ACTIONS(11276),
    [anon_sym_int] = ACTIONS(11276),
    [anon_sym_longint] = ACTIONS(11276),
    [anon_sym_integer] = ACTIONS(11276),
    [anon_sym_time] = ACTIONS(11276),
    [anon_sym_bit] = ACTIONS(11276),
    [anon_sym_logic] = ACTIONS(11276),
    [anon_sym_reg] = ACTIONS(11276),
    [anon_sym_shortreal] = ACTIONS(11276),
    [anon_sym_real] = ACTIONS(11276),
    [anon_sym_realtime] = ACTIONS(11276),
    [anon_sym_signed] = ACTIONS(11276),
    [anon_sym_unsigned] = ACTIONS(11276),
    [anon_sym_tagged] = ACTIONS(11276),
    [anon_sym_DOLLAR] = ACTIONS(11276),
    [anon_sym_PLUS] = ACTIONS(11276),
    [anon_sym_PLUS_PLUS] = ACTIONS(11302),
    [anon_sym_STAR_STAR] = ACTIONS(11279),
    [anon_sym_PERCENT] = ACTIONS(11279),
    [anon_sym_EQ_EQ] = ACTIONS(11276),
    [anon_sym_BANG_EQ] = ACTIONS(11276),
    [anon_sym_LT_EQ] = ACTIONS(11279),
    [anon_sym_GT_EQ] = ACTIONS(11279),
    [anon_sym_BANG] = ACTIONS(11276),
    [anon_sym_AMP_AMP] = ACTIONS(11276),
    [anon_sym_PIPE_PIPE] = ACTIONS(11279),
    [anon_sym_matches] = ACTIONS(11276),
    [anon_sym_DASH] = ACTIONS(11276),
    [anon_sym_DASH_GT] = ACTIONS(11279),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11279),
    [anon_sym_inside] = ACTIONS(11276),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11306),
    [anon_sym_TILDE] = ACTIONS(11276),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11279),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11279),
    [anon_sym_GT_GT] = ACTIONS(11276),
    [anon_sym_LT_LT] = ACTIONS(11276),
    [anon_sym_std] = ACTIONS(11276),
    [anon_sym_randomize] = ACTIONS(11276),
    [anon_sym_null] = ACTIONS(11276),
    [anon_sym_QMARK] = ACTIONS(11279),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_AMP] = ACTIONS(11276),
    [anon_sym_PIPE] = ACTIONS(11276),
    [anon_sym_CARET] = ACTIONS(11276),
    [anon_sym_CARET_TILDE] = ACTIONS(11279),
    [anon_sym_TILDE_CARET] = ACTIONS(11279),
    [anon_sym_GT_GT_GT] = ACTIONS(11279),
    [anon_sym_LT_LT_LT] = ACTIONS(11279),
    [anon_sym_LT_DASH_GT] = ACTIONS(11279),
    [anon_sym_this] = ACTIONS(11276),
    [anon_sym_SQUOTE] = ACTIONS(11310),
    [anon_sym_TILDE_AMP] = ACTIONS(11279),
    [anon_sym_TILDE_PIPE] = ACTIONS(11279),
    [anon_sym_DASH_DASH] = ACTIONS(11302),
    [aux_sym_decimal_number_token1] = ACTIONS(11279),
    [aux_sym_decimal_number_token2] = ACTIONS(11279),
    [sym_binary_number] = ACTIONS(11279),
    [sym_octal_number] = ACTIONS(11279),
    [sym_hex_number] = ACTIONS(11279),
    [aux_sym_real_number_token1] = ACTIONS(11279),
    [sym_fixed_point_number] = ACTIONS(11276),
    [sym_unsigned_number] = ACTIONS(11276),
    [anon_sym_SQUOTE0] = ACTIONS(11279),
    [anon_sym_SQUOTE1] = ACTIONS(11279),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11279),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11279),
    [anon_sym_DOLLARroot] = ACTIONS(11276),
    [anon_sym_DOLLARunit] = ACTIONS(11276),
    [sym_system_tf_identifier] = ACTIONS(11276),
  },
  [5236] = {
    [sym_parameter_value_assignment] = STATE(11716),
    [sym_list_of_arguments_parent] = STATE(5608),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5460),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8358),
    [sym_attribute_instance] = STATE(5440),
    [aux_sym__description_repeat1] = STATE(5440),
    [aux_sym_class_type_repeat1] = STATE(11664),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11224),
    [anon_sym_DQUOTE] = ACTIONS(11228),
    [anon_sym_LT] = ACTIONS(11224),
    [anon_sym_GT] = ACTIONS(11224),
    [anon_sym_LPAREN] = ACTIONS(11232),
    [anon_sym_RPAREN] = ACTIONS(11228),
    [anon_sym_COMMA] = ACTIONS(11228),
    [anon_sym_BQUOTE] = ACTIONS(11228),
    [anon_sym_SLASH] = ACTIONS(11224),
    [anon_sym_COLON] = ACTIONS(11224),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11224),
    [anon_sym_DOT] = ACTIONS(11247),
    [anon_sym_LBRACE] = ACTIONS(11228),
    [anon_sym_const] = ACTIONS(11224),
    [anon_sym_local] = ACTIONS(11224),
    [anon_sym_super] = ACTIONS(11224),
    [anon_sym_LBRACK] = ACTIONS(11316),
    [anon_sym_COLON_COLON] = ACTIONS(11258),
    [anon_sym_STAR] = ACTIONS(11224),
    [anon_sym_string] = ACTIONS(11224),
    [anon_sym_byte] = ACTIONS(11224),
    [anon_sym_shortint] = ACTIONS(11224),
    [anon_sym_int] = ACTIONS(11224),
    [anon_sym_longint] = ACTIONS(11224),
    [anon_sym_integer] = ACTIONS(11224),
    [anon_sym_time] = ACTIONS(11224),
    [anon_sym_bit] = ACTIONS(11224),
    [anon_sym_logic] = ACTIONS(11224),
    [anon_sym_reg] = ACTIONS(11224),
    [anon_sym_shortreal] = ACTIONS(11224),
    [anon_sym_real] = ACTIONS(11224),
    [anon_sym_realtime] = ACTIONS(11224),
    [anon_sym_signed] = ACTIONS(11224),
    [anon_sym_unsigned] = ACTIONS(11224),
    [anon_sym_tagged] = ACTIONS(11224),
    [anon_sym_DOLLAR] = ACTIONS(11224),
    [anon_sym_PLUS] = ACTIONS(11224),
    [anon_sym_PLUS_PLUS] = ACTIONS(11260),
    [anon_sym_STAR_STAR] = ACTIONS(11228),
    [anon_sym_PERCENT] = ACTIONS(11228),
    [anon_sym_EQ_EQ] = ACTIONS(11224),
    [anon_sym_BANG_EQ] = ACTIONS(11224),
    [anon_sym_LT_EQ] = ACTIONS(11228),
    [anon_sym_GT_EQ] = ACTIONS(11228),
    [anon_sym_BANG] = ACTIONS(11224),
    [anon_sym_AMP_AMP] = ACTIONS(11224),
    [anon_sym_PIPE_PIPE] = ACTIONS(11228),
    [anon_sym_matches] = ACTIONS(11224),
    [anon_sym_DASH] = ACTIONS(11224),
    [anon_sym_DASH_GT] = ACTIONS(11228),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11228),
    [anon_sym_inside] = ACTIONS(11224),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11265),
    [anon_sym_TILDE] = ACTIONS(11224),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11228),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11228),
    [anon_sym_GT_GT] = ACTIONS(11224),
    [anon_sym_LT_LT] = ACTIONS(11224),
    [anon_sym_std] = ACTIONS(11224),
    [anon_sym_randomize] = ACTIONS(11224),
    [anon_sym_null] = ACTIONS(11224),
    [anon_sym_QMARK] = ACTIONS(11228),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_AMP] = ACTIONS(11224),
    [anon_sym_PIPE] = ACTIONS(11224),
    [anon_sym_CARET] = ACTIONS(11224),
    [anon_sym_CARET_TILDE] = ACTIONS(11228),
    [anon_sym_TILDE_CARET] = ACTIONS(11228),
    [anon_sym_GT_GT_GT] = ACTIONS(11228),
    [anon_sym_LT_LT_LT] = ACTIONS(11228),
    [anon_sym_LT_DASH_GT] = ACTIONS(11228),
    [anon_sym_this] = ACTIONS(11224),
    [anon_sym_SQUOTE] = ACTIONS(11270),
    [anon_sym_TILDE_AMP] = ACTIONS(11228),
    [anon_sym_TILDE_PIPE] = ACTIONS(11228),
    [anon_sym_DASH_DASH] = ACTIONS(11260),
    [aux_sym_decimal_number_token1] = ACTIONS(11228),
    [aux_sym_decimal_number_token2] = ACTIONS(11228),
    [sym_binary_number] = ACTIONS(11228),
    [sym_octal_number] = ACTIONS(11228),
    [sym_hex_number] = ACTIONS(11228),
    [aux_sym_real_number_token1] = ACTIONS(11228),
    [sym_fixed_point_number] = ACTIONS(11224),
    [sym_unsigned_number] = ACTIONS(11224),
    [anon_sym_SQUOTE0] = ACTIONS(11228),
    [anon_sym_SQUOTE1] = ACTIONS(11228),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11228),
    [anon_sym_LPAREN_STAR] = ACTIONS(11274),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11228),
    [anon_sym_DOLLARroot] = ACTIONS(11224),
    [anon_sym_DOLLARunit] = ACTIONS(11224),
    [sym_system_tf_identifier] = ACTIONS(11224),
  },
  [5237] = {
    [sym_parameter_value_assignment] = STATE(11716),
    [sym_list_of_arguments_parent] = STATE(5608),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5579),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8358),
    [sym_attribute_instance] = STATE(5440),
    [aux_sym__description_repeat1] = STATE(5440),
    [aux_sym_class_type_repeat1] = STATE(11664),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11224),
    [anon_sym_DQUOTE] = ACTIONS(11228),
    [anon_sym_LT] = ACTIONS(11224),
    [anon_sym_GT] = ACTIONS(11224),
    [anon_sym_LPAREN] = ACTIONS(11232),
    [anon_sym_RPAREN] = ACTIONS(11228),
    [anon_sym_COMMA] = ACTIONS(11228),
    [anon_sym_BQUOTE] = ACTIONS(11228),
    [anon_sym_SLASH] = ACTIONS(11224),
    [anon_sym_COLON] = ACTIONS(11224),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11224),
    [anon_sym_DOT] = ACTIONS(11319),
    [anon_sym_LBRACE] = ACTIONS(11228),
    [anon_sym_const] = ACTIONS(11224),
    [anon_sym_local] = ACTIONS(11224),
    [anon_sym_super] = ACTIONS(11224),
    [anon_sym_LBRACK] = ACTIONS(11327),
    [anon_sym_COLON_COLON] = ACTIONS(11258),
    [anon_sym_STAR] = ACTIONS(11224),
    [anon_sym_string] = ACTIONS(11224),
    [anon_sym_byte] = ACTIONS(11224),
    [anon_sym_shortint] = ACTIONS(11224),
    [anon_sym_int] = ACTIONS(11224),
    [anon_sym_longint] = ACTIONS(11224),
    [anon_sym_integer] = ACTIONS(11224),
    [anon_sym_time] = ACTIONS(11224),
    [anon_sym_bit] = ACTIONS(11224),
    [anon_sym_logic] = ACTIONS(11224),
    [anon_sym_reg] = ACTIONS(11224),
    [anon_sym_shortreal] = ACTIONS(11224),
    [anon_sym_real] = ACTIONS(11224),
    [anon_sym_realtime] = ACTIONS(11224),
    [anon_sym_signed] = ACTIONS(11224),
    [anon_sym_unsigned] = ACTIONS(11224),
    [anon_sym_tagged] = ACTIONS(11224),
    [anon_sym_DOLLAR] = ACTIONS(11224),
    [anon_sym_PLUS] = ACTIONS(11224),
    [anon_sym_PLUS_PLUS] = ACTIONS(11228),
    [anon_sym_STAR_STAR] = ACTIONS(11228),
    [anon_sym_PERCENT] = ACTIONS(11228),
    [anon_sym_EQ_EQ] = ACTIONS(11224),
    [anon_sym_BANG_EQ] = ACTIONS(11224),
    [anon_sym_LT_EQ] = ACTIONS(11228),
    [anon_sym_GT_EQ] = ACTIONS(11228),
    [anon_sym_BANG] = ACTIONS(11224),
    [anon_sym_AMP_AMP] = ACTIONS(11224),
    [anon_sym_PIPE_PIPE] = ACTIONS(11228),
    [anon_sym_matches] = ACTIONS(11224),
    [anon_sym_DASH] = ACTIONS(11224),
    [anon_sym_DASH_GT] = ACTIONS(11228),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11228),
    [anon_sym_inside] = ACTIONS(11224),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11265),
    [anon_sym_TILDE] = ACTIONS(11224),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11228),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11228),
    [anon_sym_GT_GT] = ACTIONS(11224),
    [anon_sym_LT_LT] = ACTIONS(11224),
    [anon_sym_std] = ACTIONS(11224),
    [anon_sym_randomize] = ACTIONS(11224),
    [anon_sym_null] = ACTIONS(11224),
    [anon_sym_QMARK] = ACTIONS(11228),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_AMP] = ACTIONS(11224),
    [anon_sym_PIPE] = ACTIONS(11224),
    [anon_sym_CARET] = ACTIONS(11224),
    [anon_sym_CARET_TILDE] = ACTIONS(11228),
    [anon_sym_TILDE_CARET] = ACTIONS(11228),
    [anon_sym_GT_GT_GT] = ACTIONS(11228),
    [anon_sym_LT_LT_LT] = ACTIONS(11228),
    [anon_sym_LT_DASH_GT] = ACTIONS(11228),
    [anon_sym_this] = ACTIONS(11224),
    [anon_sym_SQUOTE] = ACTIONS(11270),
    [anon_sym_TILDE_AMP] = ACTIONS(11228),
    [anon_sym_TILDE_PIPE] = ACTIONS(11228),
    [anon_sym_DASH_DASH] = ACTIONS(11228),
    [aux_sym_decimal_number_token1] = ACTIONS(11228),
    [aux_sym_decimal_number_token2] = ACTIONS(11228),
    [sym_binary_number] = ACTIONS(11228),
    [sym_octal_number] = ACTIONS(11228),
    [sym_hex_number] = ACTIONS(11228),
    [aux_sym_real_number_token1] = ACTIONS(11228),
    [sym_fixed_point_number] = ACTIONS(11224),
    [sym_unsigned_number] = ACTIONS(11224),
    [anon_sym_SQUOTE0] = ACTIONS(11228),
    [anon_sym_SQUOTE1] = ACTIONS(11228),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11228),
    [anon_sym_LPAREN_STAR] = ACTIONS(11330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11228),
    [anon_sym_DOLLARroot] = ACTIONS(11224),
    [anon_sym_DOLLARunit] = ACTIONS(11224),
    [sym_system_tf_identifier] = ACTIONS(11224),
  },
  [5238] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(20213),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11334),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5239] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(20217),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11342),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5240] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18307),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11344),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5241] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_DQUOTE] = ACTIONS(1686),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1686),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_implements] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_RBRACE] = ACTIONS(1686),
    [anon_sym_iff] = ACTIONS(1688),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_u2013_GT] = ACTIONS(1686),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_import] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_with] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_tagged] = ACTIONS(1688),
    [anon_sym_DOLLAR] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_dist] = ACTIONS(1688),
    [anon_sym_AT_AT] = ACTIONS(1686),
    [anon_sym_BANG] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_AT] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_TILDE] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_std] = ACTIONS(1688),
    [anon_sym_randomize] = ACTIONS(1688),
    [anon_sym_null] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_TILDE_AMP] = ACTIONS(1686),
    [anon_sym_TILDE_PIPE] = ACTIONS(1686),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [aux_sym_decimal_number_token1] = ACTIONS(1686),
    [aux_sym_decimal_number_token2] = ACTIONS(1686),
    [sym_binary_number] = ACTIONS(1686),
    [sym_octal_number] = ACTIONS(1686),
    [sym_hex_number] = ACTIONS(1686),
    [aux_sym_real_number_token1] = ACTIONS(1686),
    [sym_fixed_point_number] = ACTIONS(1688),
    [sym_unsigned_number] = ACTIONS(1688),
    [anon_sym_SQUOTE0] = ACTIONS(1686),
    [anon_sym_SQUOTE1] = ACTIONS(1686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [5242] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17673),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11346),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5243] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17908),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11348),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5244] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18165),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11350),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5245] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17444),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11352),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5246] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18710),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11354),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5247] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18960),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11356),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5248] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19127),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11358),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5249] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17442),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11360),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5250] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17576),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11362),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5251] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17657),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11364),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5252] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19224),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11366),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5253] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19406),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11368),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5254] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19487),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11370),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5255] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18799),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11372),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5256] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17375),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11374),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5257] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17656),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11376),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5258] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19368),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11378),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5259] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19453),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11380),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5260] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19519),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11382),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5261] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_DQUOTE] = ACTIONS(1682),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1682),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_implements] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_RBRACE] = ACTIONS(1682),
    [anon_sym_iff] = ACTIONS(1684),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_u2013_GT] = ACTIONS(1682),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_import] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_with] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_tagged] = ACTIONS(1684),
    [anon_sym_DOLLAR] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_dist] = ACTIONS(1684),
    [anon_sym_AT_AT] = ACTIONS(1682),
    [anon_sym_BANG] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_AT] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_std] = ACTIONS(1684),
    [anon_sym_randomize] = ACTIONS(1684),
    [anon_sym_null] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_TILDE_AMP] = ACTIONS(1682),
    [anon_sym_TILDE_PIPE] = ACTIONS(1682),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [aux_sym_decimal_number_token1] = ACTIONS(1682),
    [aux_sym_decimal_number_token2] = ACTIONS(1682),
    [sym_binary_number] = ACTIONS(1682),
    [sym_octal_number] = ACTIONS(1682),
    [sym_hex_number] = ACTIONS(1682),
    [aux_sym_real_number_token1] = ACTIONS(1682),
    [sym_fixed_point_number] = ACTIONS(1684),
    [sym_unsigned_number] = ACTIONS(1684),
    [anon_sym_SQUOTE0] = ACTIONS(1682),
    [anon_sym_SQUOTE1] = ACTIONS(1682),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [5262] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17459),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11384),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5263] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17483),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11386),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5264] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(20220),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11388),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5265] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(18876),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11390),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5266] = {
    [sym_parameter_value_assignment] = STATE(11716),
    [sym_list_of_arguments_parent] = STATE(5608),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5380),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8358),
    [sym_attribute_instance] = STATE(5440),
    [aux_sym__description_repeat1] = STATE(5440),
    [aux_sym_class_type_repeat1] = STATE(11664),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11224),
    [anon_sym_DQUOTE] = ACTIONS(11228),
    [anon_sym_LT] = ACTIONS(11224),
    [anon_sym_GT] = ACTIONS(11224),
    [anon_sym_LPAREN] = ACTIONS(11232),
    [anon_sym_RPAREN] = ACTIONS(11228),
    [anon_sym_BQUOTE] = ACTIONS(11228),
    [anon_sym_SLASH] = ACTIONS(11224),
    [anon_sym_COLON] = ACTIONS(11224),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11224),
    [anon_sym_DOT] = ACTIONS(11247),
    [anon_sym_LBRACE] = ACTIONS(11228),
    [anon_sym_const] = ACTIONS(11224),
    [anon_sym_local] = ACTIONS(11224),
    [anon_sym_super] = ACTIONS(11224),
    [anon_sym_LBRACK] = ACTIONS(11316),
    [anon_sym_COLON_COLON] = ACTIONS(11258),
    [anon_sym_STAR] = ACTIONS(11224),
    [anon_sym_string] = ACTIONS(11224),
    [anon_sym_byte] = ACTIONS(11224),
    [anon_sym_shortint] = ACTIONS(11224),
    [anon_sym_int] = ACTIONS(11224),
    [anon_sym_longint] = ACTIONS(11224),
    [anon_sym_integer] = ACTIONS(11224),
    [anon_sym_time] = ACTIONS(11224),
    [anon_sym_bit] = ACTIONS(11224),
    [anon_sym_logic] = ACTIONS(11224),
    [anon_sym_reg] = ACTIONS(11224),
    [anon_sym_shortreal] = ACTIONS(11224),
    [anon_sym_real] = ACTIONS(11224),
    [anon_sym_realtime] = ACTIONS(11224),
    [anon_sym_signed] = ACTIONS(11224),
    [anon_sym_unsigned] = ACTIONS(11224),
    [anon_sym_tagged] = ACTIONS(11224),
    [anon_sym_DOLLAR] = ACTIONS(11224),
    [anon_sym_PLUS] = ACTIONS(11224),
    [anon_sym_PLUS_PLUS] = ACTIONS(11260),
    [anon_sym_STAR_STAR] = ACTIONS(11228),
    [anon_sym_PERCENT] = ACTIONS(11228),
    [anon_sym_EQ_EQ] = ACTIONS(11224),
    [anon_sym_BANG_EQ] = ACTIONS(11224),
    [anon_sym_LT_EQ] = ACTIONS(11228),
    [anon_sym_GT_EQ] = ACTIONS(11228),
    [anon_sym_BANG] = ACTIONS(11224),
    [anon_sym_AMP_AMP] = ACTIONS(11224),
    [anon_sym_PIPE_PIPE] = ACTIONS(11228),
    [anon_sym_matches] = ACTIONS(11224),
    [anon_sym_DASH] = ACTIONS(11224),
    [anon_sym_DASH_GT] = ACTIONS(11228),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11228),
    [anon_sym_inside] = ACTIONS(11224),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11265),
    [anon_sym_TILDE] = ACTIONS(11224),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11228),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11228),
    [anon_sym_GT_GT] = ACTIONS(11224),
    [anon_sym_LT_LT] = ACTIONS(11224),
    [anon_sym_std] = ACTIONS(11224),
    [anon_sym_randomize] = ACTIONS(11224),
    [anon_sym_null] = ACTIONS(11224),
    [anon_sym_QMARK] = ACTIONS(11228),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11228),
    [anon_sym_AMP] = ACTIONS(11224),
    [anon_sym_PIPE] = ACTIONS(11224),
    [anon_sym_CARET] = ACTIONS(11224),
    [anon_sym_CARET_TILDE] = ACTIONS(11228),
    [anon_sym_TILDE_CARET] = ACTIONS(11228),
    [anon_sym_GT_GT_GT] = ACTIONS(11228),
    [anon_sym_LT_LT_LT] = ACTIONS(11228),
    [anon_sym_LT_DASH_GT] = ACTIONS(11228),
    [anon_sym_this] = ACTIONS(11224),
    [anon_sym_SQUOTE] = ACTIONS(11270),
    [anon_sym_TILDE_AMP] = ACTIONS(11228),
    [anon_sym_TILDE_PIPE] = ACTIONS(11228),
    [anon_sym_DASH_DASH] = ACTIONS(11260),
    [aux_sym_decimal_number_token1] = ACTIONS(11228),
    [aux_sym_decimal_number_token2] = ACTIONS(11228),
    [sym_binary_number] = ACTIONS(11228),
    [sym_octal_number] = ACTIONS(11228),
    [sym_hex_number] = ACTIONS(11228),
    [aux_sym_real_number_token1] = ACTIONS(11228),
    [sym_fixed_point_number] = ACTIONS(11224),
    [sym_unsigned_number] = ACTIONS(11224),
    [anon_sym_SQUOTE0] = ACTIONS(11228),
    [anon_sym_SQUOTE1] = ACTIONS(11228),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11228),
    [anon_sym_LPAREN_STAR] = ACTIONS(11274),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11228),
    [anon_sym_DOLLARroot] = ACTIONS(11224),
    [anon_sym_DOLLARunit] = ACTIONS(11224),
    [sym_system_tf_identifier] = ACTIONS(11224),
  },
  [5267] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19559),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11392),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5268] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19563),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11394),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5269] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19565),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11396),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5270] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19587),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11398),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5271] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19590),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11400),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5272] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19592),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11402),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5273] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19615),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11404),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5274] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19618),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11406),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5275] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19620),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11408),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5276] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19642),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11410),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5277] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19645),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11412),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5278] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19647),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11414),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5279] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19666),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11416),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5280] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19669),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11418),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5281] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19671),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11420),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5282] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19690),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11422),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5283] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19693),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11424),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5284] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19695),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11426),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5285] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19707),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11428),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5286] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19710),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11430),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5287] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(19712),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11432),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5288] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(16611),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_for_step] = STATE(17445),
    [sym__for_step_assignment] = STATE(16611),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(16611),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_RPAREN] = ACTIONS(11434),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5289] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_DQUOTE] = ACTIONS(1686),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1686),
    [anon_sym_RPAREN] = ACTIONS(1686),
    [anon_sym_COMMA] = ACTIONS(1686),
    [anon_sym_BQUOTE] = ACTIONS(1686),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1686),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_const] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_string] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_bit] = ACTIONS(1688),
    [anon_sym_logic] = ACTIONS(1688),
    [anon_sym_reg] = ACTIONS(1688),
    [anon_sym_shortreal] = ACTIONS(1688),
    [anon_sym_real] = ACTIONS(1688),
    [anon_sym_realtime] = ACTIONS(1688),
    [anon_sym_signed] = ACTIONS(1688),
    [anon_sym_unsigned] = ACTIONS(1688),
    [anon_sym_tagged] = ACTIONS(1688),
    [anon_sym_DOLLAR] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_or] = ACTIONS(1688),
    [anon_sym_and] = ACTIONS(1688),
    [anon_sym_endsequence] = ACTIONS(1688),
    [anon_sym_intersect] = ACTIONS(1688),
    [anon_sym_throughout] = ACTIONS(1688),
    [anon_sym_within] = ACTIONS(1688),
    [anon_sym_POUND_POUND] = ACTIONS(1688),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(1686),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_STAR] = ACTIONS(1688),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(1686),
    [anon_sym_LBRACK_EQ] = ACTIONS(1686),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(1686),
    [anon_sym_dist] = ACTIONS(1688),
    [anon_sym_BANG] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1686),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_TILDE] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_std] = ACTIONS(1688),
    [anon_sym_randomize] = ACTIONS(1688),
    [anon_sym_null] = ACTIONS(1688),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_TILDE_AMP] = ACTIONS(1686),
    [anon_sym_TILDE_PIPE] = ACTIONS(1686),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [aux_sym_decimal_number_token1] = ACTIONS(1686),
    [aux_sym_decimal_number_token2] = ACTIONS(1686),
    [sym_binary_number] = ACTIONS(1686),
    [sym_octal_number] = ACTIONS(1686),
    [sym_hex_number] = ACTIONS(1686),
    [aux_sym_real_number_token1] = ACTIONS(1686),
    [sym_fixed_point_number] = ACTIONS(1688),
    [sym_unsigned_number] = ACTIONS(1688),
    [anon_sym_SQUOTE0] = ACTIONS(1686),
    [anon_sym_SQUOTE1] = ACTIONS(1686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [5290] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_DQUOTE] = ACTIONS(1682),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1682),
    [anon_sym_RPAREN] = ACTIONS(1682),
    [anon_sym_COMMA] = ACTIONS(1682),
    [anon_sym_BQUOTE] = ACTIONS(1682),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1682),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_const] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_string] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_bit] = ACTIONS(1684),
    [anon_sym_logic] = ACTIONS(1684),
    [anon_sym_reg] = ACTIONS(1684),
    [anon_sym_shortreal] = ACTIONS(1684),
    [anon_sym_real] = ACTIONS(1684),
    [anon_sym_realtime] = ACTIONS(1684),
    [anon_sym_signed] = ACTIONS(1684),
    [anon_sym_unsigned] = ACTIONS(1684),
    [anon_sym_tagged] = ACTIONS(1684),
    [anon_sym_DOLLAR] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_or] = ACTIONS(1684),
    [anon_sym_and] = ACTIONS(1684),
    [anon_sym_endsequence] = ACTIONS(1684),
    [anon_sym_intersect] = ACTIONS(1684),
    [anon_sym_throughout] = ACTIONS(1684),
    [anon_sym_within] = ACTIONS(1684),
    [anon_sym_POUND_POUND] = ACTIONS(1684),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(1682),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_STAR] = ACTIONS(1684),
    [anon_sym_LBRACK_STAR_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_PLUS_RBRACK] = ACTIONS(1682),
    [anon_sym_LBRACK_EQ] = ACTIONS(1682),
    [anon_sym_LBRACK_DASH_GT] = ACTIONS(1682),
    [anon_sym_dist] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_std] = ACTIONS(1684),
    [anon_sym_randomize] = ACTIONS(1684),
    [anon_sym_null] = ACTIONS(1684),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_TILDE_AMP] = ACTIONS(1682),
    [anon_sym_TILDE_PIPE] = ACTIONS(1682),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [aux_sym_decimal_number_token1] = ACTIONS(1682),
    [aux_sym_decimal_number_token2] = ACTIONS(1682),
    [sym_binary_number] = ACTIONS(1682),
    [sym_octal_number] = ACTIONS(1682),
    [sym_hex_number] = ACTIONS(1682),
    [aux_sym_real_number_token1] = ACTIONS(1682),
    [sym_fixed_point_number] = ACTIONS(1684),
    [sym_unsigned_number] = ACTIONS(1684),
    [anon_sym_SQUOTE0] = ACTIONS(1682),
    [anon_sym_SQUOTE1] = ACTIONS(1682),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [5291] = {
    [sym_parameter_value_assignment] = STATE(11752),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5461),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8350),
    [aux_sym_class_type_repeat1] = STATE(11753),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11276),
    [anon_sym_DQUOTE] = ACTIONS(11279),
    [anon_sym_LT] = ACTIONS(11276),
    [anon_sym_GT] = ACTIONS(11276),
    [anon_sym_LPAREN] = ACTIONS(11282),
    [anon_sym_RPAREN] = ACTIONS(11279),
    [anon_sym_COMMA] = ACTIONS(11279),
    [anon_sym_BQUOTE] = ACTIONS(11279),
    [anon_sym_SLASH] = ACTIONS(11276),
    [anon_sym_COLON] = ACTIONS(11276),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11276),
    [anon_sym_DOT] = ACTIONS(11293),
    [anon_sym_LBRACE] = ACTIONS(11279),
    [anon_sym_const] = ACTIONS(11276),
    [anon_sym_local] = ACTIONS(11276),
    [anon_sym_super] = ACTIONS(11276),
    [anon_sym_LBRACK] = ACTIONS(11436),
    [anon_sym_COLON_COLON] = ACTIONS(11300),
    [anon_sym_STAR] = ACTIONS(11276),
    [anon_sym_string] = ACTIONS(11276),
    [anon_sym_byte] = ACTIONS(11276),
    [anon_sym_shortint] = ACTIONS(11276),
    [anon_sym_int] = ACTIONS(11276),
    [anon_sym_longint] = ACTIONS(11276),
    [anon_sym_integer] = ACTIONS(11276),
    [anon_sym_time] = ACTIONS(11276),
    [anon_sym_bit] = ACTIONS(11276),
    [anon_sym_logic] = ACTIONS(11276),
    [anon_sym_reg] = ACTIONS(11276),
    [anon_sym_shortreal] = ACTIONS(11276),
    [anon_sym_real] = ACTIONS(11276),
    [anon_sym_realtime] = ACTIONS(11276),
    [anon_sym_signed] = ACTIONS(11276),
    [anon_sym_unsigned] = ACTIONS(11276),
    [anon_sym_tagged] = ACTIONS(11276),
    [anon_sym_DOLLAR] = ACTIONS(11276),
    [anon_sym_PLUS] = ACTIONS(11276),
    [anon_sym_PLUS_PLUS] = ACTIONS(11302),
    [anon_sym_STAR_STAR] = ACTIONS(11279),
    [anon_sym_PERCENT] = ACTIONS(11279),
    [anon_sym_EQ_EQ] = ACTIONS(11276),
    [anon_sym_BANG_EQ] = ACTIONS(11276),
    [anon_sym_LT_EQ] = ACTIONS(11279),
    [anon_sym_GT_EQ] = ACTIONS(11279),
    [anon_sym_BANG] = ACTIONS(11276),
    [anon_sym_AMP_AMP] = ACTIONS(11276),
    [anon_sym_PIPE_PIPE] = ACTIONS(11279),
    [anon_sym_matches] = ACTIONS(11276),
    [anon_sym_DASH] = ACTIONS(11276),
    [anon_sym_DASH_GT] = ACTIONS(11279),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11279),
    [anon_sym_inside] = ACTIONS(11276),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11306),
    [anon_sym_TILDE] = ACTIONS(11276),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11279),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11279),
    [anon_sym_GT_GT] = ACTIONS(11276),
    [anon_sym_LT_LT] = ACTIONS(11276),
    [anon_sym_std] = ACTIONS(11276),
    [anon_sym_randomize] = ACTIONS(11276),
    [anon_sym_null] = ACTIONS(11276),
    [anon_sym_QMARK] = ACTIONS(11279),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_AMP] = ACTIONS(11276),
    [anon_sym_PIPE] = ACTIONS(11276),
    [anon_sym_CARET] = ACTIONS(11276),
    [anon_sym_CARET_TILDE] = ACTIONS(11279),
    [anon_sym_TILDE_CARET] = ACTIONS(11279),
    [anon_sym_GT_GT_GT] = ACTIONS(11279),
    [anon_sym_LT_LT_LT] = ACTIONS(11279),
    [anon_sym_LT_DASH_GT] = ACTIONS(11279),
    [anon_sym_this] = ACTIONS(11276),
    [anon_sym_SQUOTE] = ACTIONS(11310),
    [anon_sym_TILDE_AMP] = ACTIONS(11279),
    [anon_sym_TILDE_PIPE] = ACTIONS(11279),
    [anon_sym_DASH_DASH] = ACTIONS(11302),
    [aux_sym_decimal_number_token1] = ACTIONS(11279),
    [aux_sym_decimal_number_token2] = ACTIONS(11279),
    [sym_binary_number] = ACTIONS(11279),
    [sym_octal_number] = ACTIONS(11279),
    [sym_hex_number] = ACTIONS(11279),
    [aux_sym_real_number_token1] = ACTIONS(11279),
    [sym_fixed_point_number] = ACTIONS(11276),
    [sym_unsigned_number] = ACTIONS(11276),
    [anon_sym_SQUOTE0] = ACTIONS(11279),
    [anon_sym_SQUOTE1] = ACTIONS(11279),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11279),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11279),
    [anon_sym_DOLLARroot] = ACTIONS(11276),
    [anon_sym_DOLLARunit] = ACTIONS(11276),
    [sym_system_tf_identifier] = ACTIONS(11276),
  },
  [5292] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym__sequence_match_item] = STATE(17201),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(17201),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(15426),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(17201),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5293] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_operator_assignment] = STATE(17003),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16408),
    [sym_assignment_pattern_variable_lvalue] = STATE(10842),
    [sym__for_step_assignment] = STATE(17003),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(11060),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(16616),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_inc_or_dec_expression] = STATE(17003),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(18104),
    [sym_cast] = STATE(7174),
    [sym_variable_lvalue] = STATE(10941),
    [sym_inc_or_dec_operator] = STATE(10526),
    [sym__number] = STATE(8333),
    [sym_integral_number] = STATE(8333),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8333),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(9382),
    [sym_package_scope] = STATE(12361),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13121),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11332),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11338),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(2165),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(3449),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_DASH_DASH] = ACTIONS(2165),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11340),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5294] = {
    [sym_parameter_value_assignment] = STATE(11752),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5387),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8350),
    [aux_sym_class_type_repeat1] = STATE(11753),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11276),
    [anon_sym_DQUOTE] = ACTIONS(11279),
    [anon_sym_LT] = ACTIONS(11276),
    [anon_sym_GT] = ACTIONS(11276),
    [anon_sym_LPAREN] = ACTIONS(11282),
    [anon_sym_RPAREN] = ACTIONS(11279),
    [anon_sym_BQUOTE] = ACTIONS(11279),
    [anon_sym_SLASH] = ACTIONS(11276),
    [anon_sym_COLON] = ACTIONS(11276),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11276),
    [anon_sym_DOT] = ACTIONS(11293),
    [anon_sym_LBRACE] = ACTIONS(11279),
    [anon_sym_const] = ACTIONS(11276),
    [anon_sym_local] = ACTIONS(11276),
    [anon_sym_super] = ACTIONS(11276),
    [anon_sym_LBRACK] = ACTIONS(11436),
    [anon_sym_COLON_COLON] = ACTIONS(11300),
    [anon_sym_STAR] = ACTIONS(11276),
    [anon_sym_string] = ACTIONS(11276),
    [anon_sym_byte] = ACTIONS(11276),
    [anon_sym_shortint] = ACTIONS(11276),
    [anon_sym_int] = ACTIONS(11276),
    [anon_sym_longint] = ACTIONS(11276),
    [anon_sym_integer] = ACTIONS(11276),
    [anon_sym_time] = ACTIONS(11276),
    [anon_sym_bit] = ACTIONS(11276),
    [anon_sym_logic] = ACTIONS(11276),
    [anon_sym_reg] = ACTIONS(11276),
    [anon_sym_shortreal] = ACTIONS(11276),
    [anon_sym_real] = ACTIONS(11276),
    [anon_sym_realtime] = ACTIONS(11276),
    [anon_sym_signed] = ACTIONS(11276),
    [anon_sym_unsigned] = ACTIONS(11276),
    [anon_sym_tagged] = ACTIONS(11276),
    [anon_sym_DOLLAR] = ACTIONS(11276),
    [anon_sym_PLUS] = ACTIONS(11276),
    [anon_sym_PLUS_PLUS] = ACTIONS(11302),
    [anon_sym_STAR_STAR] = ACTIONS(11279),
    [anon_sym_PERCENT] = ACTIONS(11279),
    [anon_sym_EQ_EQ] = ACTIONS(11276),
    [anon_sym_BANG_EQ] = ACTIONS(11276),
    [anon_sym_LT_EQ] = ACTIONS(11279),
    [anon_sym_GT_EQ] = ACTIONS(11279),
    [anon_sym_BANG] = ACTIONS(11276),
    [anon_sym_AMP_AMP] = ACTIONS(11276),
    [anon_sym_PIPE_PIPE] = ACTIONS(11279),
    [anon_sym_matches] = ACTIONS(11276),
    [anon_sym_DASH] = ACTIONS(11276),
    [anon_sym_DASH_GT] = ACTIONS(11279),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11279),
    [anon_sym_inside] = ACTIONS(11276),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11306),
    [anon_sym_TILDE] = ACTIONS(11276),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11279),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11279),
    [anon_sym_GT_GT] = ACTIONS(11276),
    [anon_sym_LT_LT] = ACTIONS(11276),
    [anon_sym_std] = ACTIONS(11276),
    [anon_sym_randomize] = ACTIONS(11276),
    [anon_sym_null] = ACTIONS(11276),
    [anon_sym_QMARK] = ACTIONS(11279),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_AMP] = ACTIONS(11276),
    [anon_sym_PIPE] = ACTIONS(11276),
    [anon_sym_CARET] = ACTIONS(11276),
    [anon_sym_CARET_TILDE] = ACTIONS(11279),
    [anon_sym_TILDE_CARET] = ACTIONS(11279),
    [anon_sym_GT_GT_GT] = ACTIONS(11279),
    [anon_sym_LT_LT_LT] = ACTIONS(11279),
    [anon_sym_LT_DASH_GT] = ACTIONS(11279),
    [anon_sym_this] = ACTIONS(11276),
    [anon_sym_SQUOTE] = ACTIONS(11310),
    [anon_sym_TILDE_AMP] = ACTIONS(11279),
    [anon_sym_TILDE_PIPE] = ACTIONS(11279),
    [anon_sym_DASH_DASH] = ACTIONS(11302),
    [aux_sym_decimal_number_token1] = ACTIONS(11279),
    [aux_sym_decimal_number_token2] = ACTIONS(11279),
    [sym_binary_number] = ACTIONS(11279),
    [sym_octal_number] = ACTIONS(11279),
    [sym_hex_number] = ACTIONS(11279),
    [aux_sym_real_number_token1] = ACTIONS(11279),
    [sym_fixed_point_number] = ACTIONS(11276),
    [sym_unsigned_number] = ACTIONS(11276),
    [anon_sym_SQUOTE0] = ACTIONS(11279),
    [anon_sym_SQUOTE1] = ACTIONS(11279),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11279),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11279),
    [anon_sym_DOLLARroot] = ACTIONS(11276),
    [anon_sym_DOLLARunit] = ACTIONS(11276),
    [sym_system_tf_identifier] = ACTIONS(11276),
  },
  [5295] = {
    [sym_parameter_value_assignment] = STATE(11752),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5565),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_constant_select1] = STATE(8350),
    [aux_sym_class_type_repeat1] = STATE(11753),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11276),
    [anon_sym_DQUOTE] = ACTIONS(11279),
    [anon_sym_LT] = ACTIONS(11276),
    [anon_sym_GT] = ACTIONS(11276),
    [anon_sym_LPAREN] = ACTIONS(11438),
    [anon_sym_RPAREN] = ACTIONS(11279),
    [anon_sym_COMMA] = ACTIONS(11279),
    [anon_sym_BQUOTE] = ACTIONS(11279),
    [anon_sym_SLASH] = ACTIONS(11276),
    [anon_sym_COLON] = ACTIONS(11276),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11276),
    [anon_sym_DOT] = ACTIONS(11443),
    [anon_sym_LBRACE] = ACTIONS(11279),
    [anon_sym_const] = ACTIONS(11276),
    [anon_sym_local] = ACTIONS(11276),
    [anon_sym_super] = ACTIONS(11276),
    [anon_sym_LBRACK] = ACTIONS(11448),
    [anon_sym_COLON_COLON] = ACTIONS(11300),
    [anon_sym_STAR] = ACTIONS(11276),
    [anon_sym_string] = ACTIONS(11276),
    [anon_sym_byte] = ACTIONS(11276),
    [anon_sym_shortint] = ACTIONS(11276),
    [anon_sym_int] = ACTIONS(11276),
    [anon_sym_longint] = ACTIONS(11276),
    [anon_sym_integer] = ACTIONS(11276),
    [anon_sym_time] = ACTIONS(11276),
    [anon_sym_bit] = ACTIONS(11276),
    [anon_sym_logic] = ACTIONS(11276),
    [anon_sym_reg] = ACTIONS(11276),
    [anon_sym_shortreal] = ACTIONS(11276),
    [anon_sym_real] = ACTIONS(11276),
    [anon_sym_realtime] = ACTIONS(11276),
    [anon_sym_signed] = ACTIONS(11276),
    [anon_sym_unsigned] = ACTIONS(11276),
    [anon_sym_tagged] = ACTIONS(11276),
    [anon_sym_DOLLAR] = ACTIONS(11276),
    [anon_sym_PLUS] = ACTIONS(11276),
    [anon_sym_PLUS_PLUS] = ACTIONS(11279),
    [anon_sym_STAR_STAR] = ACTIONS(11279),
    [anon_sym_PERCENT] = ACTIONS(11279),
    [anon_sym_EQ_EQ] = ACTIONS(11276),
    [anon_sym_BANG_EQ] = ACTIONS(11276),
    [anon_sym_LT_EQ] = ACTIONS(11279),
    [anon_sym_GT_EQ] = ACTIONS(11279),
    [anon_sym_BANG] = ACTIONS(11276),
    [anon_sym_AMP_AMP] = ACTIONS(11276),
    [anon_sym_PIPE_PIPE] = ACTIONS(11279),
    [anon_sym_matches] = ACTIONS(11276),
    [anon_sym_DASH] = ACTIONS(11276),
    [anon_sym_DASH_GT] = ACTIONS(11279),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11279),
    [anon_sym_inside] = ACTIONS(11276),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11306),
    [anon_sym_TILDE] = ACTIONS(11276),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11279),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11279),
    [anon_sym_GT_GT] = ACTIONS(11276),
    [anon_sym_LT_LT] = ACTIONS(11276),
    [anon_sym_std] = ACTIONS(11276),
    [anon_sym_randomize] = ACTIONS(11276),
    [anon_sym_null] = ACTIONS(11276),
    [anon_sym_QMARK] = ACTIONS(11279),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11279),
    [anon_sym_AMP] = ACTIONS(11276),
    [anon_sym_PIPE] = ACTIONS(11276),
    [anon_sym_CARET] = ACTIONS(11276),
    [anon_sym_CARET_TILDE] = ACTIONS(11279),
    [anon_sym_TILDE_CARET] = ACTIONS(11279),
    [anon_sym_GT_GT_GT] = ACTIONS(11279),
    [anon_sym_LT_LT_LT] = ACTIONS(11279),
    [anon_sym_LT_DASH_GT] = ACTIONS(11279),
    [anon_sym_this] = ACTIONS(11276),
    [anon_sym_SQUOTE] = ACTIONS(11310),
    [anon_sym_TILDE_AMP] = ACTIONS(11279),
    [anon_sym_TILDE_PIPE] = ACTIONS(11279),
    [anon_sym_DASH_DASH] = ACTIONS(11279),
    [aux_sym_decimal_number_token1] = ACTIONS(11279),
    [aux_sym_decimal_number_token2] = ACTIONS(11279),
    [sym_binary_number] = ACTIONS(11279),
    [sym_octal_number] = ACTIONS(11279),
    [sym_hex_number] = ACTIONS(11279),
    [aux_sym_real_number_token1] = ACTIONS(11279),
    [sym_fixed_point_number] = ACTIONS(11276),
    [sym_unsigned_number] = ACTIONS(11276),
    [anon_sym_SQUOTE0] = ACTIONS(11279),
    [anon_sym_SQUOTE1] = ACTIONS(11279),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11279),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11279),
    [anon_sym_DOLLARroot] = ACTIONS(11276),
    [anon_sym_DOLLARunit] = ACTIONS(11276),
    [sym_system_tf_identifier] = ACTIONS(11276),
  },
  [5296] = {
    [sym_data_type] = STATE(12496),
    [sym_class_scope] = STATE(14311),
    [sym_class_type] = STATE(11768),
    [sym_integer_atom_type] = STATE(11402),
    [sym_integer_vector_type] = STATE(11167),
    [sym_non_integer_type] = STATE(11790),
    [sym__var_data_type] = STATE(12496),
    [sym_struct_union] = STATE(16828),
    [sym_type_reference] = STATE(11790),
    [sym_assertion_variable_declaration] = STATE(5296),
    [sym_escaped_identifier] = STATE(103),
    [sym__identifier] = STATE(11276),
    [sym_package_scope] = STATE(14220),
    [aux_sym_property_declaration_repeat1] = STATE(5296),
    [sym_simple_identifier] = ACTIONS(11450),
    [anon_sym_DQUOTE] = ACTIONS(11453),
    [anon_sym_LPAREN] = ACTIONS(11453),
    [anon_sym_BQUOTE] = ACTIONS(11453),
    [anon_sym_virtual] = ACTIONS(11455),
    [anon_sym_type] = ACTIONS(11458),
    [anon_sym_LBRACE] = ACTIONS(11453),
    [anon_sym_disable] = ACTIONS(11461),
    [anon_sym_const] = ACTIONS(11461),
    [anon_sym_local] = ACTIONS(11461),
    [anon_sym_super] = ACTIONS(11461),
    [anon_sym_if] = ACTIONS(11461),
    [anon_sym_var] = ACTIONS(11463),
    [anon_sym_enum] = ACTIONS(11466),
    [anon_sym_struct] = ACTIONS(11469),
    [anon_sym_union] = ACTIONS(11472),
    [anon_sym_string] = ACTIONS(11475),
    [anon_sym_chandle] = ACTIONS(11475),
    [anon_sym_event] = ACTIONS(11475),
    [anon_sym_byte] = ACTIONS(11478),
    [anon_sym_shortint] = ACTIONS(11478),
    [anon_sym_int] = ACTIONS(11478),
    [anon_sym_longint] = ACTIONS(11478),
    [anon_sym_integer] = ACTIONS(11478),
    [anon_sym_time] = ACTIONS(11478),
    [anon_sym_bit] = ACTIONS(11481),
    [anon_sym_logic] = ACTIONS(11481),
    [anon_sym_reg] = ACTIONS(11481),
    [anon_sym_shortreal] = ACTIONS(11484),
    [anon_sym_real] = ACTIONS(11484),
    [anon_sym_realtime] = ACTIONS(11484),
    [anon_sym_signed] = ACTIONS(11461),
    [anon_sym_unsigned] = ACTIONS(11461),
    [anon_sym_tagged] = ACTIONS(11461),
    [anon_sym_DOLLAR] = ACTIONS(11461),
    [anon_sym_PLUS] = ACTIONS(11461),
    [anon_sym_PLUS_PLUS] = ACTIONS(11453),
    [anon_sym_strong] = ACTIONS(11461),
    [anon_sym_weak] = ACTIONS(11461),
    [anon_sym_not] = ACTIONS(11461),
    [anon_sym_case] = ACTIONS(11461),
    [anon_sym_nexttime] = ACTIONS(11461),
    [anon_sym_s_nexttime] = ACTIONS(11461),
    [anon_sym_always] = ACTIONS(11461),
    [anon_sym_s_always] = ACTIONS(11461),
    [anon_sym_s_eventually] = ACTIONS(11461),
    [anon_sym_eventually] = ACTIONS(11461),
    [anon_sym_accept_on] = ACTIONS(11461),
    [anon_sym_reject_on] = ACTIONS(11461),
    [anon_sym_sync_accept_on] = ACTIONS(11461),
    [anon_sym_sync_reject_on] = ACTIONS(11461),
    [anon_sym_first_match] = ACTIONS(11461),
    [anon_sym_POUND_POUND] = ACTIONS(11461),
    [anon_sym_POUND_POUND_LBRACK_STAR_RBRACK] = ACTIONS(11453),
    [anon_sym_POUND_POUND_LBRACK_PLUS_RBRACK] = ACTIONS(11453),
    [anon_sym_BANG] = ACTIONS(11453),
    [anon_sym_DASH] = ACTIONS(11461),
    [anon_sym_AT] = ACTIONS(11453),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11453),
    [anon_sym_TILDE] = ACTIONS(11461),
    [anon_sym_std] = ACTIONS(11461),
    [anon_sym_randomize] = ACTIONS(11461),
    [anon_sym_null] = ACTIONS(11461),
    [anon_sym_AMP] = ACTIONS(11453),
    [anon_sym_PIPE] = ACTIONS(11453),
    [anon_sym_CARET] = ACTIONS(11461),
    [anon_sym_CARET_TILDE] = ACTIONS(11453),
    [anon_sym_TILDE_CARET] = ACTIONS(11453),
    [anon_sym_this] = ACTIONS(11461),
    [anon_sym_TILDE_AMP] = ACTIONS(11453),
    [anon_sym_TILDE_PIPE] = ACTIONS(11453),
    [anon_sym_DASH_DASH] = ACTIONS(11453),
    [aux_sym_decimal_number_token1] = ACTIONS(11453),
    [aux_sym_decimal_number_token2] = ACTIONS(11453),
    [sym_binary_number] = ACTIONS(11453),
    [sym_octal_number] = ACTIONS(11453),
    [sym_hex_number] = ACTIONS(11453),
    [aux_sym_real_number_token1] = ACTIONS(11453),
    [sym_fixed_point_number] = ACTIONS(11461),
    [sym_unsigned_number] = ACTIONS(11461),
    [anon_sym_SQUOTE0] = ACTIONS(11453),
    [anon_sym_SQUOTE1] = ACTIONS(11453),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11453),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11487),
    [anon_sym_DOLLARroot] = ACTIONS(11461),
    [anon_sym_DOLLARunit] = ACTIONS(11490),
    [sym_system_tf_identifier] = ACTIONS(11461),
  },
  [5297] = {
    [aux_sym_bit_select1_repeat1] = STATE(5298),
    [sym_simple_identifier] = ACTIONS(11493),
    [anon_sym_DQUOTE] = ACTIONS(11495),
    [anon_sym_LT] = ACTIONS(11493),
    [anon_sym_GT] = ACTIONS(11493),
    [anon_sym_LPAREN] = ACTIONS(11493),
    [anon_sym_RPAREN] = ACTIONS(11495),
    [anon_sym_COMMA] = ACTIONS(11495),
    [anon_sym_BQUOTE] = ACTIONS(11495),
    [anon_sym_SLASH] = ACTIONS(11493),
    [anon_sym_SEMI] = ACTIONS(11495),
    [anon_sym_COLON] = ACTIONS(11495),
    [anon_sym_type] = ACTIONS(11493),
    [anon_sym_DOT] = ACTIONS(11495),
    [anon_sym_LBRACE] = ACTIONS(11495),
    [anon_sym_RBRACE] = ACTIONS(11495),
    [anon_sym_iff] = ACTIONS(11493),
    [anon_sym_const] = ACTIONS(11493),
    [anon_sym_local] = ACTIONS(11493),
    [anon_sym_super] = ACTIONS(11493),
    [anon_sym_before] = ACTIONS(11493),
    [anon_sym_u2013_GT] = ACTIONS(11495),
    [anon_sym_LBRACK] = ACTIONS(11495),
    [anon_sym_RBRACK] = ACTIONS(11495),
    [anon_sym_STAR] = ACTIONS(11493),
    [anon_sym_with] = ACTIONS(11493),
    [anon_sym_string] = ACTIONS(11493),
    [anon_sym_byte] = ACTIONS(11493),
    [anon_sym_shortint] = ACTIONS(11493),
    [anon_sym_int] = ACTIONS(11493),
    [anon_sym_longint] = ACTIONS(11493),
    [anon_sym_integer] = ACTIONS(11493),
    [anon_sym_time] = ACTIONS(11493),
    [anon_sym_bit] = ACTIONS(11493),
    [anon_sym_logic] = ACTIONS(11493),
    [anon_sym_reg] = ACTIONS(11493),
    [anon_sym_shortreal] = ACTIONS(11493),
    [anon_sym_real] = ACTIONS(11493),
    [anon_sym_realtime] = ACTIONS(11493),
    [anon_sym_signed] = ACTIONS(11493),
    [anon_sym_unsigned] = ACTIONS(11493),
    [anon_sym_tagged] = ACTIONS(11493),
    [anon_sym_DOLLAR] = ACTIONS(11493),
    [anon_sym_PLUS] = ACTIONS(11493),
    [anon_sym_PLUS_PLUS] = ACTIONS(11495),
    [anon_sym_STAR_STAR] = ACTIONS(11495),
    [anon_sym_PERCENT] = ACTIONS(11495),
    [anon_sym_EQ_EQ] = ACTIONS(11493),
    [anon_sym_BANG_EQ] = ACTIONS(11493),
    [anon_sym_LT_EQ] = ACTIONS(11495),
    [anon_sym_GT_EQ] = ACTIONS(11495),
    [anon_sym_or] = ACTIONS(11493),
    [anon_sym_dist] = ACTIONS(11493),
    [anon_sym_BANG] = ACTIONS(11493),
    [anon_sym_AMP_AMP] = ACTIONS(11493),
    [anon_sym_PIPE_PIPE] = ACTIONS(11495),
    [anon_sym_matches] = ACTIONS(11493),
    [anon_sym_DASH] = ACTIONS(11493),
    [anon_sym_DASH_GT] = ACTIONS(11495),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11495),
    [anon_sym_inside] = ACTIONS(11493),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11495),
    [anon_sym_TILDE] = ACTIONS(11493),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11495),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11495),
    [anon_sym_GT_GT] = ACTIONS(11493),
    [anon_sym_LT_LT] = ACTIONS(11493),
    [anon_sym_std] = ACTIONS(11493),
    [anon_sym_randomize] = ACTIONS(11493),
    [anon_sym_null] = ACTIONS(11493),
    [anon_sym_QMARK] = ACTIONS(11495),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11495),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11495),
    [anon_sym_AMP] = ACTIONS(11493),
    [anon_sym_PIPE] = ACTIONS(11493),
    [anon_sym_CARET] = ACTIONS(11493),
    [anon_sym_CARET_TILDE] = ACTIONS(11495),
    [anon_sym_TILDE_CARET] = ACTIONS(11495),
    [anon_sym_GT_GT_GT] = ACTIONS(11495),
    [anon_sym_LT_LT_LT] = ACTIONS(11495),
    [anon_sym_LT_DASH_GT] = ACTIONS(11495),
    [anon_sym_this] = ACTIONS(11493),
    [anon_sym_TILDE_AMP] = ACTIONS(11495),
    [anon_sym_TILDE_PIPE] = ACTIONS(11495),
    [anon_sym_DASH_DASH] = ACTIONS(11495),
    [aux_sym_decimal_number_token1] = ACTIONS(11495),
    [aux_sym_decimal_number_token2] = ACTIONS(11495),
    [sym_binary_number] = ACTIONS(11495),
    [sym_octal_number] = ACTIONS(11495),
    [sym_hex_number] = ACTIONS(11495),
    [aux_sym_real_number_token1] = ACTIONS(11495),
    [sym_fixed_point_number] = ACTIONS(11493),
    [sym_unsigned_number] = ACTIONS(11493),
    [anon_sym_SQUOTE0] = ACTIONS(11495),
    [anon_sym_SQUOTE1] = ACTIONS(11495),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11495),
    [anon_sym_LPAREN_STAR] = ACTIONS(11495),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11495),
    [anon_sym_DOLLARroot] = ACTIONS(11493),
    [anon_sym_DOLLARunit] = ACTIONS(11493),
    [sym_system_tf_identifier] = ACTIONS(11493),
  },
  [5298] = {
    [aux_sym_bit_select1_repeat1] = STATE(5298),
    [sym_simple_identifier] = ACTIONS(11497),
    [anon_sym_DQUOTE] = ACTIONS(11499),
    [anon_sym_LT] = ACTIONS(11497),
    [anon_sym_GT] = ACTIONS(11497),
    [anon_sym_LPAREN] = ACTIONS(11497),
    [anon_sym_RPAREN] = ACTIONS(11499),
    [anon_sym_COMMA] = ACTIONS(11499),
    [anon_sym_BQUOTE] = ACTIONS(11499),
    [anon_sym_SLASH] = ACTIONS(11497),
    [anon_sym_SEMI] = ACTIONS(11499),
    [anon_sym_COLON] = ACTIONS(11499),
    [anon_sym_type] = ACTIONS(11497),
    [anon_sym_DOT] = ACTIONS(11499),
    [anon_sym_LBRACE] = ACTIONS(11499),
    [anon_sym_RBRACE] = ACTIONS(11499),
    [anon_sym_iff] = ACTIONS(11497),
    [anon_sym_const] = ACTIONS(11497),
    [anon_sym_local] = ACTIONS(11497),
    [anon_sym_super] = ACTIONS(11497),
    [anon_sym_before] = ACTIONS(11497),
    [anon_sym_u2013_GT] = ACTIONS(11499),
    [anon_sym_LBRACK] = ACTIONS(11501),
    [anon_sym_RBRACK] = ACTIONS(11499),
    [anon_sym_STAR] = ACTIONS(11497),
    [anon_sym_with] = ACTIONS(11497),
    [anon_sym_string] = ACTIONS(11497),
    [anon_sym_byte] = ACTIONS(11497),
    [anon_sym_shortint] = ACTIONS(11497),
    [anon_sym_int] = ACTIONS(11497),
    [anon_sym_longint] = ACTIONS(11497),
    [anon_sym_integer] = ACTIONS(11497),
    [anon_sym_time] = ACTIONS(11497),
    [anon_sym_bit] = ACTIONS(11497),
    [anon_sym_logic] = ACTIONS(11497),
    [anon_sym_reg] = ACTIONS(11497),
    [anon_sym_shortreal] = ACTIONS(11497),
    [anon_sym_real] = ACTIONS(11497),
    [anon_sym_realtime] = ACTIONS(11497),
    [anon_sym_signed] = ACTIONS(11497),
    [anon_sym_unsigned] = ACTIONS(11497),
    [anon_sym_tagged] = ACTIONS(11497),
    [anon_sym_DOLLAR] = ACTIONS(11497),
    [anon_sym_PLUS] = ACTIONS(11497),
    [anon_sym_PLUS_PLUS] = ACTIONS(11499),
    [anon_sym_STAR_STAR] = ACTIONS(11499),
    [anon_sym_PERCENT] = ACTIONS(11499),
    [anon_sym_EQ_EQ] = ACTIONS(11497),
    [anon_sym_BANG_EQ] = ACTIONS(11497),
    [anon_sym_LT_EQ] = ACTIONS(11499),
    [anon_sym_GT_EQ] = ACTIONS(11499),
    [anon_sym_or] = ACTIONS(11497),
    [anon_sym_dist] = ACTIONS(11497),
    [anon_sym_BANG] = ACTIONS(11497),
    [anon_sym_AMP_AMP] = ACTIONS(11497),
    [anon_sym_PIPE_PIPE] = ACTIONS(11499),
    [anon_sym_matches] = ACTIONS(11497),
    [anon_sym_DASH] = ACTIONS(11497),
    [anon_sym_DASH_GT] = ACTIONS(11499),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11499),
    [anon_sym_inside] = ACTIONS(11497),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11499),
    [anon_sym_TILDE] = ACTIONS(11497),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11499),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11499),
    [anon_sym_GT_GT] = ACTIONS(11497),
    [anon_sym_LT_LT] = ACTIONS(11497),
    [anon_sym_std] = ACTIONS(11497),
    [anon_sym_randomize] = ACTIONS(11497),
    [anon_sym_null] = ACTIONS(11497),
    [anon_sym_QMARK] = ACTIONS(11499),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11499),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11499),
    [anon_sym_AMP] = ACTIONS(11497),
    [anon_sym_PIPE] = ACTIONS(11497),
    [anon_sym_CARET] = ACTIONS(11497),
    [anon_sym_CARET_TILDE] = ACTIONS(11499),
    [anon_sym_TILDE_CARET] = ACTIONS(11499),
    [anon_sym_GT_GT_GT] = ACTIONS(11499),
    [anon_sym_LT_LT_LT] = ACTIONS(11499),
    [anon_sym_LT_DASH_GT] = ACTIONS(11499),
    [anon_sym_this] = ACTIONS(11497),
    [anon_sym_TILDE_AMP] = ACTIONS(11499),
    [anon_sym_TILDE_PIPE] = ACTIONS(11499),
    [anon_sym_DASH_DASH] = ACTIONS(11499),
    [aux_sym_decimal_number_token1] = ACTIONS(11499),
    [aux_sym_decimal_number_token2] = ACTIONS(11499),
    [sym_binary_number] = ACTIONS(11499),
    [sym_octal_number] = ACTIONS(11499),
    [sym_hex_number] = ACTIONS(11499),
    [aux_sym_real_number_token1] = ACTIONS(11499),
    [sym_fixed_point_number] = ACTIONS(11497),
    [sym_unsigned_number] = ACTIONS(11497),
    [anon_sym_SQUOTE0] = ACTIONS(11499),
    [anon_sym_SQUOTE1] = ACTIONS(11499),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11499),
    [anon_sym_LPAREN_STAR] = ACTIONS(11499),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11499),
    [anon_sym_DOLLARroot] = ACTIONS(11497),
    [anon_sym_DOLLARunit] = ACTIONS(11497),
    [sym_system_tf_identifier] = ACTIONS(11497),
  },
  [5299] = {
    [sym_simple_identifier] = ACTIONS(1684),
    [anon_sym_LT] = ACTIONS(1684),
    [anon_sym_GT] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1684),
    [anon_sym_SLASH] = ACTIONS(1684),
    [anon_sym_SEMI] = ACTIONS(1682),
    [anon_sym_COLON] = ACTIONS(1684),
    [anon_sym_POUND] = ACTIONS(1684),
    [anon_sym_type] = ACTIONS(1684),
    [anon_sym_DOT] = ACTIONS(1682),
    [anon_sym_LBRACE] = ACTIONS(1682),
    [anon_sym_disable] = ACTIONS(1684),
    [anon_sym_local] = ACTIONS(1684),
    [anon_sym_super] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1684),
    [anon_sym_else] = ACTIONS(1684),
    [anon_sym_foreach] = ACTIONS(1684),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_RBRACK] = ACTIONS(1682),
    [anon_sym_unique] = ACTIONS(1684),
    [anon_sym_COLON_COLON] = ACTIONS(1682),
    [anon_sym_STAR] = ACTIONS(1684),
    [anon_sym_byte] = ACTIONS(1684),
    [anon_sym_shortint] = ACTIONS(1684),
    [anon_sym_int] = ACTIONS(1684),
    [anon_sym_longint] = ACTIONS(1684),
    [anon_sym_integer] = ACTIONS(1684),
    [anon_sym_time] = ACTIONS(1684),
    [anon_sym_PLUS] = ACTIONS(1684),
    [anon_sym_PLUS_PLUS] = ACTIONS(1682),
    [anon_sym_STAR_STAR] = ACTIONS(1682),
    [anon_sym_PERCENT] = ACTIONS(1682),
    [anon_sym_EQ_EQ] = ACTIONS(1684),
    [anon_sym_BANG_EQ] = ACTIONS(1684),
    [anon_sym_LT_EQ] = ACTIONS(1682),
    [anon_sym_GT_EQ] = ACTIONS(1682),
    [anon_sym_assert] = ACTIONS(1684),
    [anon_sym_assume] = ACTIONS(1684),
    [anon_sym_cover] = ACTIONS(1684),
    [anon_sym_expect] = ACTIONS(1684),
    [anon_sym_restrict] = ACTIONS(1684),
    [anon_sym_case] = ACTIONS(1684),
    [anon_sym_POUND_POUND] = ACTIONS(1682),
    [anon_sym_begin] = ACTIONS(1684),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_AMP_AMP] = ACTIONS(1684),
    [anon_sym_PIPE_PIPE] = ACTIONS(1682),
    [anon_sym_matches] = ACTIONS(1684),
    [anon_sym_for] = ACTIONS(1684),
    [anon_sym_DASH] = ACTIONS(1684),
    [anon_sym_assign] = ACTIONS(1684),
    [anon_sym_deassign] = ACTIONS(1684),
    [anon_sym_force] = ACTIONS(1684),
    [anon_sym_release] = ACTIONS(1684),
    [anon_sym_fork] = ACTIONS(1684),
    [anon_sym_repeat] = ACTIONS(1684),
    [anon_sym_AT] = ACTIONS(1684),
    [anon_sym_AT_STAR] = ACTIONS(1682),
    [anon_sym_return] = ACTIONS(1684),
    [anon_sym_break] = ACTIONS(1684),
    [anon_sym_continue] = ACTIONS(1684),
    [anon_sym_wait] = ACTIONS(1684),
    [anon_sym_wait_order] = ACTIONS(1684),
    [anon_sym_DASH_GT] = ACTIONS(1684),
    [anon_sym_DASH_GT_GT] = ACTIONS(1682),
    [anon_sym_unique0] = ACTIONS(1684),
    [anon_sym_priority] = ACTIONS(1684),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1682),
    [anon_sym_inside] = ACTIONS(1684),
    [anon_sym_casez] = ACTIONS(1684),
    [anon_sym_casex] = ACTIONS(1684),
    [anon_sym_randcase] = ACTIONS(1684),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1682),
    [anon_sym_forever] = ACTIONS(1684),
    [anon_sym_while] = ACTIONS(1684),
    [anon_sym_do] = ACTIONS(1684),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1682),
    [anon_sym_GT_GT] = ACTIONS(1684),
    [anon_sym_LT_LT] = ACTIONS(1684),
    [anon_sym_PLUS_COLON] = ACTIONS(1682),
    [anon_sym_DASH_COLON] = ACTIONS(1682),
    [anon_sym_QMARK] = ACTIONS(1682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1682),
    [anon_sym_AMP] = ACTIONS(1684),
    [anon_sym_PIPE] = ACTIONS(1684),
    [anon_sym_CARET] = ACTIONS(1684),
    [anon_sym_CARET_TILDE] = ACTIONS(1682),
    [anon_sym_TILDE_CARET] = ACTIONS(1682),
    [anon_sym_GT_GT_GT] = ACTIONS(1682),
    [anon_sym_LT_LT_LT] = ACTIONS(1682),
    [anon_sym_LT_DASH_GT] = ACTIONS(1682),
    [anon_sym_this] = ACTIONS(1684),
    [anon_sym_SQUOTE] = ACTIONS(1684),
    [anon_sym_DASH_DASH] = ACTIONS(1682),
    [anon_sym_LPAREN_STAR] = ACTIONS(1682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1682),
    [anon_sym_DOLLARroot] = ACTIONS(1684),
    [anon_sym_DOLLARunit] = ACTIONS(1684),
    [sym_system_tf_identifier] = ACTIONS(1684),
  },
  [5300] = {
    [sym_simple_identifier] = ACTIONS(1688),
    [anon_sym_LT] = ACTIONS(1688),
    [anon_sym_GT] = ACTIONS(1688),
    [anon_sym_LPAREN] = ACTIONS(1688),
    [anon_sym_SLASH] = ACTIONS(1688),
    [anon_sym_SEMI] = ACTIONS(1686),
    [anon_sym_COLON] = ACTIONS(1688),
    [anon_sym_POUND] = ACTIONS(1688),
    [anon_sym_type] = ACTIONS(1688),
    [anon_sym_DOT] = ACTIONS(1686),
    [anon_sym_LBRACE] = ACTIONS(1686),
    [anon_sym_disable] = ACTIONS(1688),
    [anon_sym_local] = ACTIONS(1688),
    [anon_sym_super] = ACTIONS(1688),
    [anon_sym_if] = ACTIONS(1688),
    [anon_sym_else] = ACTIONS(1688),
    [anon_sym_foreach] = ACTIONS(1688),
    [anon_sym_LBRACK] = ACTIONS(1686),
    [anon_sym_RBRACK] = ACTIONS(1686),
    [anon_sym_unique] = ACTIONS(1688),
    [anon_sym_COLON_COLON] = ACTIONS(1686),
    [anon_sym_STAR] = ACTIONS(1688),
    [anon_sym_byte] = ACTIONS(1688),
    [anon_sym_shortint] = ACTIONS(1688),
    [anon_sym_int] = ACTIONS(1688),
    [anon_sym_longint] = ACTIONS(1688),
    [anon_sym_integer] = ACTIONS(1688),
    [anon_sym_time] = ACTIONS(1688),
    [anon_sym_PLUS] = ACTIONS(1688),
    [anon_sym_PLUS_PLUS] = ACTIONS(1686),
    [anon_sym_STAR_STAR] = ACTIONS(1686),
    [anon_sym_PERCENT] = ACTIONS(1686),
    [anon_sym_EQ_EQ] = ACTIONS(1688),
    [anon_sym_BANG_EQ] = ACTIONS(1688),
    [anon_sym_LT_EQ] = ACTIONS(1686),
    [anon_sym_GT_EQ] = ACTIONS(1686),
    [anon_sym_assert] = ACTIONS(1688),
    [anon_sym_assume] = ACTIONS(1688),
    [anon_sym_cover] = ACTIONS(1688),
    [anon_sym_expect] = ACTIONS(1688),
    [anon_sym_restrict] = ACTIONS(1688),
    [anon_sym_case] = ACTIONS(1688),
    [anon_sym_POUND_POUND] = ACTIONS(1686),
    [anon_sym_begin] = ACTIONS(1688),
    [anon_sym_end] = ACTIONS(1688),
    [anon_sym_AMP_AMP] = ACTIONS(1688),
    [anon_sym_PIPE_PIPE] = ACTIONS(1686),
    [anon_sym_matches] = ACTIONS(1688),
    [anon_sym_for] = ACTIONS(1688),
    [anon_sym_DASH] = ACTIONS(1688),
    [anon_sym_assign] = ACTIONS(1688),
    [anon_sym_deassign] = ACTIONS(1688),
    [anon_sym_force] = ACTIONS(1688),
    [anon_sym_release] = ACTIONS(1688),
    [anon_sym_fork] = ACTIONS(1688),
    [anon_sym_repeat] = ACTIONS(1688),
    [anon_sym_AT] = ACTIONS(1688),
    [anon_sym_AT_STAR] = ACTIONS(1686),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_break] = ACTIONS(1688),
    [anon_sym_continue] = ACTIONS(1688),
    [anon_sym_wait] = ACTIONS(1688),
    [anon_sym_wait_order] = ACTIONS(1688),
    [anon_sym_DASH_GT] = ACTIONS(1688),
    [anon_sym_DASH_GT_GT] = ACTIONS(1686),
    [anon_sym_unique0] = ACTIONS(1688),
    [anon_sym_priority] = ACTIONS(1688),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(1686),
    [anon_sym_inside] = ACTIONS(1688),
    [anon_sym_casez] = ACTIONS(1688),
    [anon_sym_casex] = ACTIONS(1688),
    [anon_sym_randcase] = ACTIONS(1688),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(1686),
    [anon_sym_forever] = ACTIONS(1688),
    [anon_sym_while] = ACTIONS(1688),
    [anon_sym_do] = ACTIONS(1688),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1686),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1686),
    [anon_sym_GT_GT] = ACTIONS(1688),
    [anon_sym_LT_LT] = ACTIONS(1688),
    [anon_sym_PLUS_COLON] = ACTIONS(1686),
    [anon_sym_DASH_COLON] = ACTIONS(1686),
    [anon_sym_QMARK] = ACTIONS(1686),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(1686),
    [anon_sym_AMP] = ACTIONS(1688),
    [anon_sym_PIPE] = ACTIONS(1688),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_CARET_TILDE] = ACTIONS(1686),
    [anon_sym_TILDE_CARET] = ACTIONS(1686),
    [anon_sym_GT_GT_GT] = ACTIONS(1686),
    [anon_sym_LT_LT_LT] = ACTIONS(1686),
    [anon_sym_LT_DASH_GT] = ACTIONS(1686),
    [anon_sym_this] = ACTIONS(1688),
    [anon_sym_SQUOTE] = ACTIONS(1688),
    [anon_sym_DASH_DASH] = ACTIONS(1686),
    [anon_sym_LPAREN_STAR] = ACTIONS(1686),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(1686),
    [anon_sym_DOLLARroot] = ACTIONS(1688),
    [anon_sym_DOLLARunit] = ACTIONS(1688),
    [sym_system_tf_identifier] = ACTIONS(1688),
  },
  [5301] = {
    [sym_parameter_value_assignment] = STATE(11752),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5659),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_class_type_repeat1] = STATE(11753),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11504),
    [anon_sym_DQUOTE] = ACTIONS(11314),
    [anon_sym_LT] = ACTIONS(11504),
    [anon_sym_GT] = ACTIONS(11504),
    [anon_sym_LPAREN] = ACTIONS(11314),
    [anon_sym_RPAREN] = ACTIONS(11314),
    [anon_sym_COMMA] = ACTIONS(11314),
    [anon_sym_BQUOTE] = ACTIONS(11314),
    [anon_sym_SLASH] = ACTIONS(11504),
    [anon_sym_COLON] = ACTIONS(11504),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11504),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11314),
    [anon_sym_const] = ACTIONS(11504),
    [anon_sym_local] = ACTIONS(11504),
    [anon_sym_super] = ACTIONS(11504),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_COLON_COLON] = ACTIONS(11300),
    [anon_sym_STAR] = ACTIONS(11504),
    [anon_sym_string] = ACTIONS(11504),
    [anon_sym_byte] = ACTIONS(11504),
    [anon_sym_shortint] = ACTIONS(11504),
    [anon_sym_int] = ACTIONS(11504),
    [anon_sym_longint] = ACTIONS(11504),
    [anon_sym_integer] = ACTIONS(11504),
    [anon_sym_time] = ACTIONS(11504),
    [anon_sym_bit] = ACTIONS(11504),
    [anon_sym_logic] = ACTIONS(11504),
    [anon_sym_reg] = ACTIONS(11504),
    [anon_sym_shortreal] = ACTIONS(11504),
    [anon_sym_real] = ACTIONS(11504),
    [anon_sym_realtime] = ACTIONS(11504),
    [anon_sym_signed] = ACTIONS(11504),
    [anon_sym_unsigned] = ACTIONS(11504),
    [anon_sym_tagged] = ACTIONS(11504),
    [anon_sym_DOLLAR] = ACTIONS(11504),
    [anon_sym_PLUS] = ACTIONS(11504),
    [anon_sym_PLUS_PLUS] = ACTIONS(11314),
    [anon_sym_STAR_STAR] = ACTIONS(11314),
    [anon_sym_PERCENT] = ACTIONS(11314),
    [anon_sym_EQ_EQ] = ACTIONS(11504),
    [anon_sym_BANG_EQ] = ACTIONS(11504),
    [anon_sym_LT_EQ] = ACTIONS(11314),
    [anon_sym_GT_EQ] = ACTIONS(11314),
    [anon_sym_BANG] = ACTIONS(11504),
    [anon_sym_AMP_AMP] = ACTIONS(11504),
    [anon_sym_PIPE_PIPE] = ACTIONS(11314),
    [anon_sym_matches] = ACTIONS(11504),
    [anon_sym_DASH] = ACTIONS(11504),
    [anon_sym_DASH_GT] = ACTIONS(11314),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11314),
    [anon_sym_inside] = ACTIONS(11504),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11510),
    [anon_sym_TILDE] = ACTIONS(11504),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11314),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11314),
    [anon_sym_GT_GT] = ACTIONS(11504),
    [anon_sym_LT_LT] = ACTIONS(11504),
    [anon_sym_std] = ACTIONS(11504),
    [anon_sym_randomize] = ACTIONS(11504),
    [anon_sym_null] = ACTIONS(11504),
    [anon_sym_QMARK] = ACTIONS(11314),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11314),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11314),
    [anon_sym_AMP] = ACTIONS(11504),
    [anon_sym_PIPE] = ACTIONS(11504),
    [anon_sym_CARET] = ACTIONS(11504),
    [anon_sym_CARET_TILDE] = ACTIONS(11314),
    [anon_sym_TILDE_CARET] = ACTIONS(11314),
    [anon_sym_GT_GT_GT] = ACTIONS(11314),
    [anon_sym_LT_LT_LT] = ACTIONS(11314),
    [anon_sym_LT_DASH_GT] = ACTIONS(11314),
    [anon_sym_this] = ACTIONS(11504),
    [anon_sym_TILDE_AMP] = ACTIONS(11314),
    [anon_sym_TILDE_PIPE] = ACTIONS(11314),
    [anon_sym_DASH_DASH] = ACTIONS(11314),
    [aux_sym_decimal_number_token1] = ACTIONS(11314),
    [aux_sym_decimal_number_token2] = ACTIONS(11314),
    [sym_binary_number] = ACTIONS(11314),
    [sym_octal_number] = ACTIONS(11314),
    [sym_hex_number] = ACTIONS(11314),
    [aux_sym_real_number_token1] = ACTIONS(11314),
    [sym_fixed_point_number] = ACTIONS(11504),
    [sym_unsigned_number] = ACTIONS(11504),
    [anon_sym_SQUOTE0] = ACTIONS(11314),
    [anon_sym_SQUOTE1] = ACTIONS(11314),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11314),
    [anon_sym_DOLLARroot] = ACTIONS(11504),
    [anon_sym_DOLLARunit] = ACTIONS(11504),
    [sym_system_tf_identifier] = ACTIONS(11504),
  },
  [5302] = {
    [sym_list_of_arguments_parent] = STATE(5549),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5559),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5436),
    [aux_sym__description_repeat1] = STATE(5436),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11513),
    [anon_sym_DQUOTE] = ACTIONS(11516),
    [anon_sym_LT] = ACTIONS(11513),
    [anon_sym_GT] = ACTIONS(11513),
    [anon_sym_LPAREN] = ACTIONS(11513),
    [anon_sym_RPAREN] = ACTIONS(11516),
    [anon_sym_COMMA] = ACTIONS(11516),
    [anon_sym_BQUOTE] = ACTIONS(11516),
    [anon_sym_SLASH] = ACTIONS(11513),
    [anon_sym_COLON] = ACTIONS(11516),
    [anon_sym_type] = ACTIONS(11513),
    [anon_sym_DOT] = ACTIONS(11519),
    [anon_sym_LBRACE] = ACTIONS(11516),
    [anon_sym_const] = ACTIONS(11513),
    [anon_sym_local] = ACTIONS(11513),
    [anon_sym_super] = ACTIONS(11513),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11513),
    [anon_sym_string] = ACTIONS(11513),
    [anon_sym_byte] = ACTIONS(11513),
    [anon_sym_shortint] = ACTIONS(11513),
    [anon_sym_int] = ACTIONS(11513),
    [anon_sym_longint] = ACTIONS(11513),
    [anon_sym_integer] = ACTIONS(11513),
    [anon_sym_time] = ACTIONS(11513),
    [anon_sym_bit] = ACTIONS(11513),
    [anon_sym_logic] = ACTIONS(11513),
    [anon_sym_reg] = ACTIONS(11513),
    [anon_sym_shortreal] = ACTIONS(11513),
    [anon_sym_real] = ACTIONS(11513),
    [anon_sym_realtime] = ACTIONS(11513),
    [anon_sym_signed] = ACTIONS(11513),
    [anon_sym_unsigned] = ACTIONS(11513),
    [anon_sym_tagged] = ACTIONS(11513),
    [anon_sym_DOLLAR] = ACTIONS(11513),
    [anon_sym_PLUS] = ACTIONS(11513),
    [anon_sym_PLUS_PLUS] = ACTIONS(11516),
    [anon_sym_STAR_STAR] = ACTIONS(11516),
    [anon_sym_PERCENT] = ACTIONS(11516),
    [anon_sym_EQ_EQ] = ACTIONS(11513),
    [anon_sym_BANG_EQ] = ACTIONS(11513),
    [anon_sym_LT_EQ] = ACTIONS(11516),
    [anon_sym_GT_EQ] = ACTIONS(11516),
    [anon_sym_BANG] = ACTIONS(11513),
    [anon_sym_AMP_AMP] = ACTIONS(11513),
    [anon_sym_PIPE_PIPE] = ACTIONS(11516),
    [anon_sym_matches] = ACTIONS(11513),
    [anon_sym_DASH] = ACTIONS(11513),
    [anon_sym_DASH_GT] = ACTIONS(11516),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11516),
    [anon_sym_inside] = ACTIONS(11513),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11516),
    [anon_sym_TILDE] = ACTIONS(11513),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11516),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11516),
    [anon_sym_GT_GT] = ACTIONS(11513),
    [anon_sym_LT_LT] = ACTIONS(11513),
    [anon_sym_std] = ACTIONS(11513),
    [anon_sym_randomize] = ACTIONS(11513),
    [anon_sym_null] = ACTIONS(11513),
    [anon_sym_QMARK] = ACTIONS(11516),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_AMP] = ACTIONS(11513),
    [anon_sym_PIPE] = ACTIONS(11513),
    [anon_sym_CARET] = ACTIONS(11513),
    [anon_sym_CARET_TILDE] = ACTIONS(11516),
    [anon_sym_TILDE_CARET] = ACTIONS(11516),
    [anon_sym_GT_GT_GT] = ACTIONS(11516),
    [anon_sym_LT_LT_LT] = ACTIONS(11516),
    [anon_sym_LT_DASH_GT] = ACTIONS(11516),
    [anon_sym_this] = ACTIONS(11513),
    [anon_sym_TILDE_AMP] = ACTIONS(11516),
    [anon_sym_TILDE_PIPE] = ACTIONS(11516),
    [anon_sym_DASH_DASH] = ACTIONS(11516),
    [aux_sym_decimal_number_token1] = ACTIONS(11516),
    [aux_sym_decimal_number_token2] = ACTIONS(11516),
    [sym_binary_number] = ACTIONS(11516),
    [sym_octal_number] = ACTIONS(11516),
    [sym_hex_number] = ACTIONS(11516),
    [aux_sym_real_number_token1] = ACTIONS(11516),
    [sym_fixed_point_number] = ACTIONS(11513),
    [sym_unsigned_number] = ACTIONS(11513),
    [anon_sym_SQUOTE0] = ACTIONS(11516),
    [anon_sym_SQUOTE1] = ACTIONS(11516),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11516),
    [anon_sym_LPAREN_STAR] = ACTIONS(11330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11516),
    [anon_sym_DOLLARroot] = ACTIONS(11513),
    [anon_sym_DOLLARunit] = ACTIONS(11513),
    [sym_system_tf_identifier] = ACTIONS(11513),
  },
  [5303] = {
    [sym_list_of_arguments_parent] = STATE(5585),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5476),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5442),
    [aux_sym__description_repeat1] = STATE(5442),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11523),
    [anon_sym_DQUOTE] = ACTIONS(11526),
    [anon_sym_LT] = ACTIONS(11523),
    [anon_sym_GT] = ACTIONS(11523),
    [anon_sym_LPAREN] = ACTIONS(11523),
    [anon_sym_RPAREN] = ACTIONS(11526),
    [anon_sym_COMMA] = ACTIONS(11526),
    [anon_sym_BQUOTE] = ACTIONS(11526),
    [anon_sym_SLASH] = ACTIONS(11523),
    [anon_sym_COLON] = ACTIONS(11526),
    [anon_sym_type] = ACTIONS(11523),
    [anon_sym_DOT] = ACTIONS(11529),
    [anon_sym_LBRACE] = ACTIONS(11526),
    [anon_sym_const] = ACTIONS(11523),
    [anon_sym_local] = ACTIONS(11523),
    [anon_sym_super] = ACTIONS(11523),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11523),
    [anon_sym_string] = ACTIONS(11523),
    [anon_sym_byte] = ACTIONS(11523),
    [anon_sym_shortint] = ACTIONS(11523),
    [anon_sym_int] = ACTIONS(11523),
    [anon_sym_longint] = ACTIONS(11523),
    [anon_sym_integer] = ACTIONS(11523),
    [anon_sym_time] = ACTIONS(11523),
    [anon_sym_bit] = ACTIONS(11523),
    [anon_sym_logic] = ACTIONS(11523),
    [anon_sym_reg] = ACTIONS(11523),
    [anon_sym_shortreal] = ACTIONS(11523),
    [anon_sym_real] = ACTIONS(11523),
    [anon_sym_realtime] = ACTIONS(11523),
    [anon_sym_signed] = ACTIONS(11523),
    [anon_sym_unsigned] = ACTIONS(11523),
    [anon_sym_tagged] = ACTIONS(11523),
    [anon_sym_DOLLAR] = ACTIONS(11523),
    [anon_sym_PLUS] = ACTIONS(11523),
    [anon_sym_PLUS_PLUS] = ACTIONS(11535),
    [anon_sym_STAR_STAR] = ACTIONS(11526),
    [anon_sym_PERCENT] = ACTIONS(11526),
    [anon_sym_EQ_EQ] = ACTIONS(11523),
    [anon_sym_BANG_EQ] = ACTIONS(11523),
    [anon_sym_LT_EQ] = ACTIONS(11526),
    [anon_sym_GT_EQ] = ACTIONS(11526),
    [anon_sym_BANG] = ACTIONS(11523),
    [anon_sym_AMP_AMP] = ACTIONS(11523),
    [anon_sym_PIPE_PIPE] = ACTIONS(11526),
    [anon_sym_matches] = ACTIONS(11523),
    [anon_sym_DASH] = ACTIONS(11523),
    [anon_sym_DASH_GT] = ACTIONS(11526),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11526),
    [anon_sym_inside] = ACTIONS(11523),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11526),
    [anon_sym_TILDE] = ACTIONS(11523),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11526),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11526),
    [anon_sym_GT_GT] = ACTIONS(11523),
    [anon_sym_LT_LT] = ACTIONS(11523),
    [anon_sym_std] = ACTIONS(11523),
    [anon_sym_randomize] = ACTIONS(11523),
    [anon_sym_null] = ACTIONS(11523),
    [anon_sym_QMARK] = ACTIONS(11526),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_AMP] = ACTIONS(11523),
    [anon_sym_PIPE] = ACTIONS(11523),
    [anon_sym_CARET] = ACTIONS(11523),
    [anon_sym_CARET_TILDE] = ACTIONS(11526),
    [anon_sym_TILDE_CARET] = ACTIONS(11526),
    [anon_sym_GT_GT_GT] = ACTIONS(11526),
    [anon_sym_LT_LT_LT] = ACTIONS(11526),
    [anon_sym_LT_DASH_GT] = ACTIONS(11526),
    [anon_sym_this] = ACTIONS(11523),
    [anon_sym_TILDE_AMP] = ACTIONS(11526),
    [anon_sym_TILDE_PIPE] = ACTIONS(11526),
    [anon_sym_DASH_DASH] = ACTIONS(11535),
    [aux_sym_decimal_number_token1] = ACTIONS(11526),
    [aux_sym_decimal_number_token2] = ACTIONS(11526),
    [sym_binary_number] = ACTIONS(11526),
    [sym_octal_number] = ACTIONS(11526),
    [sym_hex_number] = ACTIONS(11526),
    [aux_sym_real_number_token1] = ACTIONS(11526),
    [sym_fixed_point_number] = ACTIONS(11523),
    [sym_unsigned_number] = ACTIONS(11523),
    [anon_sym_SQUOTE0] = ACTIONS(11526),
    [anon_sym_SQUOTE1] = ACTIONS(11526),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11526),
    [anon_sym_LPAREN_STAR] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11526),
    [anon_sym_DOLLARroot] = ACTIONS(11523),
    [anon_sym_DOLLARunit] = ACTIONS(11523),
    [sym_system_tf_identifier] = ACTIONS(11523),
  },
  [5304] = {
    [sym_list_of_arguments_parent] = STATE(5596),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5565),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5438),
    [aux_sym__description_repeat1] = STATE(5438),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11541),
    [anon_sym_DQUOTE] = ACTIONS(11544),
    [anon_sym_LT] = ACTIONS(11541),
    [anon_sym_GT] = ACTIONS(11541),
    [anon_sym_LPAREN] = ACTIONS(11541),
    [anon_sym_RPAREN] = ACTIONS(11544),
    [anon_sym_COMMA] = ACTIONS(11544),
    [anon_sym_BQUOTE] = ACTIONS(11544),
    [anon_sym_SLASH] = ACTIONS(11541),
    [anon_sym_COLON] = ACTIONS(11544),
    [anon_sym_type] = ACTIONS(11541),
    [anon_sym_DOT] = ACTIONS(11547),
    [anon_sym_LBRACE] = ACTIONS(11544),
    [anon_sym_const] = ACTIONS(11541),
    [anon_sym_local] = ACTIONS(11541),
    [anon_sym_super] = ACTIONS(11541),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11541),
    [anon_sym_string] = ACTIONS(11541),
    [anon_sym_byte] = ACTIONS(11541),
    [anon_sym_shortint] = ACTIONS(11541),
    [anon_sym_int] = ACTIONS(11541),
    [anon_sym_longint] = ACTIONS(11541),
    [anon_sym_integer] = ACTIONS(11541),
    [anon_sym_time] = ACTIONS(11541),
    [anon_sym_bit] = ACTIONS(11541),
    [anon_sym_logic] = ACTIONS(11541),
    [anon_sym_reg] = ACTIONS(11541),
    [anon_sym_shortreal] = ACTIONS(11541),
    [anon_sym_real] = ACTIONS(11541),
    [anon_sym_realtime] = ACTIONS(11541),
    [anon_sym_signed] = ACTIONS(11541),
    [anon_sym_unsigned] = ACTIONS(11541),
    [anon_sym_tagged] = ACTIONS(11541),
    [anon_sym_DOLLAR] = ACTIONS(11541),
    [anon_sym_PLUS] = ACTIONS(11541),
    [anon_sym_PLUS_PLUS] = ACTIONS(11544),
    [anon_sym_STAR_STAR] = ACTIONS(11544),
    [anon_sym_PERCENT] = ACTIONS(11544),
    [anon_sym_EQ_EQ] = ACTIONS(11541),
    [anon_sym_BANG_EQ] = ACTIONS(11541),
    [anon_sym_LT_EQ] = ACTIONS(11544),
    [anon_sym_GT_EQ] = ACTIONS(11544),
    [anon_sym_BANG] = ACTIONS(11541),
    [anon_sym_AMP_AMP] = ACTIONS(11541),
    [anon_sym_PIPE_PIPE] = ACTIONS(11544),
    [anon_sym_matches] = ACTIONS(11541),
    [anon_sym_DASH] = ACTIONS(11541),
    [anon_sym_DASH_GT] = ACTIONS(11544),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11544),
    [anon_sym_inside] = ACTIONS(11541),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11544),
    [anon_sym_TILDE] = ACTIONS(11541),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11544),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11544),
    [anon_sym_GT_GT] = ACTIONS(11541),
    [anon_sym_LT_LT] = ACTIONS(11541),
    [anon_sym_std] = ACTIONS(11541),
    [anon_sym_randomize] = ACTIONS(11541),
    [anon_sym_null] = ACTIONS(11541),
    [anon_sym_QMARK] = ACTIONS(11544),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_AMP] = ACTIONS(11541),
    [anon_sym_PIPE] = ACTIONS(11541),
    [anon_sym_CARET] = ACTIONS(11541),
    [anon_sym_CARET_TILDE] = ACTIONS(11544),
    [anon_sym_TILDE_CARET] = ACTIONS(11544),
    [anon_sym_GT_GT_GT] = ACTIONS(11544),
    [anon_sym_LT_LT_LT] = ACTIONS(11544),
    [anon_sym_LT_DASH_GT] = ACTIONS(11544),
    [anon_sym_this] = ACTIONS(11541),
    [anon_sym_TILDE_AMP] = ACTIONS(11544),
    [anon_sym_TILDE_PIPE] = ACTIONS(11544),
    [anon_sym_DASH_DASH] = ACTIONS(11544),
    [aux_sym_decimal_number_token1] = ACTIONS(11544),
    [aux_sym_decimal_number_token2] = ACTIONS(11544),
    [sym_binary_number] = ACTIONS(11544),
    [sym_octal_number] = ACTIONS(11544),
    [sym_hex_number] = ACTIONS(11544),
    [aux_sym_real_number_token1] = ACTIONS(11544),
    [sym_fixed_point_number] = ACTIONS(11541),
    [sym_unsigned_number] = ACTIONS(11541),
    [anon_sym_SQUOTE0] = ACTIONS(11544),
    [anon_sym_SQUOTE1] = ACTIONS(11544),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11544),
    [anon_sym_LPAREN_STAR] = ACTIONS(11330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11544),
    [anon_sym_DOLLARroot] = ACTIONS(11541),
    [anon_sym_DOLLARunit] = ACTIONS(11541),
    [sym_system_tf_identifier] = ACTIONS(11541),
  },
  [5305] = {
    [sym_list_of_arguments_parent] = STATE(5549),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5463),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5436),
    [aux_sym__description_repeat1] = STATE(5436),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11513),
    [anon_sym_DQUOTE] = ACTIONS(11516),
    [anon_sym_LT] = ACTIONS(11513),
    [anon_sym_GT] = ACTIONS(11513),
    [anon_sym_LPAREN] = ACTIONS(11513),
    [anon_sym_RPAREN] = ACTIONS(11516),
    [anon_sym_COMMA] = ACTIONS(11516),
    [anon_sym_BQUOTE] = ACTIONS(11516),
    [anon_sym_SLASH] = ACTIONS(11513),
    [anon_sym_COLON] = ACTIONS(11516),
    [anon_sym_type] = ACTIONS(11513),
    [anon_sym_DOT] = ACTIONS(11519),
    [anon_sym_LBRACE] = ACTIONS(11516),
    [anon_sym_const] = ACTIONS(11513),
    [anon_sym_local] = ACTIONS(11513),
    [anon_sym_super] = ACTIONS(11513),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11513),
    [anon_sym_string] = ACTIONS(11513),
    [anon_sym_byte] = ACTIONS(11513),
    [anon_sym_shortint] = ACTIONS(11513),
    [anon_sym_int] = ACTIONS(11513),
    [anon_sym_longint] = ACTIONS(11513),
    [anon_sym_integer] = ACTIONS(11513),
    [anon_sym_time] = ACTIONS(11513),
    [anon_sym_bit] = ACTIONS(11513),
    [anon_sym_logic] = ACTIONS(11513),
    [anon_sym_reg] = ACTIONS(11513),
    [anon_sym_shortreal] = ACTIONS(11513),
    [anon_sym_real] = ACTIONS(11513),
    [anon_sym_realtime] = ACTIONS(11513),
    [anon_sym_signed] = ACTIONS(11513),
    [anon_sym_unsigned] = ACTIONS(11513),
    [anon_sym_tagged] = ACTIONS(11513),
    [anon_sym_DOLLAR] = ACTIONS(11513),
    [anon_sym_PLUS] = ACTIONS(11513),
    [anon_sym_PLUS_PLUS] = ACTIONS(11551),
    [anon_sym_STAR_STAR] = ACTIONS(11516),
    [anon_sym_PERCENT] = ACTIONS(11516),
    [anon_sym_EQ_EQ] = ACTIONS(11513),
    [anon_sym_BANG_EQ] = ACTIONS(11513),
    [anon_sym_LT_EQ] = ACTIONS(11516),
    [anon_sym_GT_EQ] = ACTIONS(11516),
    [anon_sym_BANG] = ACTIONS(11513),
    [anon_sym_AMP_AMP] = ACTIONS(11513),
    [anon_sym_PIPE_PIPE] = ACTIONS(11516),
    [anon_sym_matches] = ACTIONS(11513),
    [anon_sym_DASH] = ACTIONS(11513),
    [anon_sym_DASH_GT] = ACTIONS(11516),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11516),
    [anon_sym_inside] = ACTIONS(11513),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11516),
    [anon_sym_TILDE] = ACTIONS(11513),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11516),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11516),
    [anon_sym_GT_GT] = ACTIONS(11513),
    [anon_sym_LT_LT] = ACTIONS(11513),
    [anon_sym_std] = ACTIONS(11513),
    [anon_sym_randomize] = ACTIONS(11513),
    [anon_sym_null] = ACTIONS(11513),
    [anon_sym_QMARK] = ACTIONS(11516),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_AMP] = ACTIONS(11513),
    [anon_sym_PIPE] = ACTIONS(11513),
    [anon_sym_CARET] = ACTIONS(11513),
    [anon_sym_CARET_TILDE] = ACTIONS(11516),
    [anon_sym_TILDE_CARET] = ACTIONS(11516),
    [anon_sym_GT_GT_GT] = ACTIONS(11516),
    [anon_sym_LT_LT_LT] = ACTIONS(11516),
    [anon_sym_LT_DASH_GT] = ACTIONS(11516),
    [anon_sym_this] = ACTIONS(11513),
    [anon_sym_TILDE_AMP] = ACTIONS(11516),
    [anon_sym_TILDE_PIPE] = ACTIONS(11516),
    [anon_sym_DASH_DASH] = ACTIONS(11551),
    [aux_sym_decimal_number_token1] = ACTIONS(11516),
    [aux_sym_decimal_number_token2] = ACTIONS(11516),
    [sym_binary_number] = ACTIONS(11516),
    [sym_octal_number] = ACTIONS(11516),
    [sym_hex_number] = ACTIONS(11516),
    [aux_sym_real_number_token1] = ACTIONS(11516),
    [sym_fixed_point_number] = ACTIONS(11513),
    [sym_unsigned_number] = ACTIONS(11513),
    [anon_sym_SQUOTE0] = ACTIONS(11516),
    [anon_sym_SQUOTE1] = ACTIONS(11516),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11516),
    [anon_sym_LPAREN_STAR] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11516),
    [anon_sym_DOLLARroot] = ACTIONS(11513),
    [anon_sym_DOLLARunit] = ACTIONS(11513),
    [sym_system_tf_identifier] = ACTIONS(11513),
  },
  [5306] = {
    [sym_simple_identifier] = ACTIONS(11557),
    [anon_sym_DQUOTE] = ACTIONS(11559),
    [anon_sym_LT] = ACTIONS(11557),
    [anon_sym_GT] = ACTIONS(11557),
    [anon_sym_LPAREN] = ACTIONS(11557),
    [anon_sym_RPAREN] = ACTIONS(11559),
    [anon_sym_COMMA] = ACTIONS(11559),
    [anon_sym_BQUOTE] = ACTIONS(11559),
    [anon_sym_SLASH] = ACTIONS(11557),
    [anon_sym_SEMI] = ACTIONS(11559),
    [anon_sym_COLON] = ACTIONS(11559),
    [anon_sym_type] = ACTIONS(11557),
    [anon_sym_DOT] = ACTIONS(11559),
    [anon_sym_LBRACE] = ACTIONS(11559),
    [anon_sym_RBRACE] = ACTIONS(11559),
    [anon_sym_iff] = ACTIONS(11557),
    [anon_sym_const] = ACTIONS(11557),
    [anon_sym_local] = ACTIONS(11557),
    [anon_sym_super] = ACTIONS(11557),
    [anon_sym_before] = ACTIONS(11557),
    [anon_sym_u2013_GT] = ACTIONS(11559),
    [anon_sym_LBRACK] = ACTIONS(11559),
    [anon_sym_RBRACK] = ACTIONS(11559),
    [anon_sym_STAR] = ACTIONS(11557),
    [anon_sym_with] = ACTIONS(11557),
    [anon_sym_string] = ACTIONS(11557),
    [anon_sym_byte] = ACTIONS(11557),
    [anon_sym_shortint] = ACTIONS(11557),
    [anon_sym_int] = ACTIONS(11557),
    [anon_sym_longint] = ACTIONS(11557),
    [anon_sym_integer] = ACTIONS(11557),
    [anon_sym_time] = ACTIONS(11557),
    [anon_sym_bit] = ACTIONS(11557),
    [anon_sym_logic] = ACTIONS(11557),
    [anon_sym_reg] = ACTIONS(11557),
    [anon_sym_shortreal] = ACTIONS(11557),
    [anon_sym_real] = ACTIONS(11557),
    [anon_sym_realtime] = ACTIONS(11557),
    [anon_sym_signed] = ACTIONS(11557),
    [anon_sym_unsigned] = ACTIONS(11557),
    [anon_sym_tagged] = ACTIONS(11557),
    [anon_sym_DOLLAR] = ACTIONS(11557),
    [anon_sym_PLUS] = ACTIONS(11557),
    [anon_sym_PLUS_PLUS] = ACTIONS(11559),
    [anon_sym_STAR_STAR] = ACTIONS(11559),
    [anon_sym_PERCENT] = ACTIONS(11559),
    [anon_sym_EQ_EQ] = ACTIONS(11557),
    [anon_sym_BANG_EQ] = ACTIONS(11557),
    [anon_sym_LT_EQ] = ACTIONS(11559),
    [anon_sym_GT_EQ] = ACTIONS(11559),
    [anon_sym_or] = ACTIONS(11557),
    [anon_sym_dist] = ACTIONS(11557),
    [anon_sym_BANG] = ACTIONS(11557),
    [anon_sym_AMP_AMP] = ACTIONS(11557),
    [anon_sym_PIPE_PIPE] = ACTIONS(11559),
    [anon_sym_matches] = ACTIONS(11557),
    [anon_sym_DASH] = ACTIONS(11557),
    [anon_sym_DASH_GT] = ACTIONS(11559),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11559),
    [anon_sym_inside] = ACTIONS(11557),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11559),
    [anon_sym_TILDE] = ACTIONS(11557),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11559),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11559),
    [anon_sym_GT_GT] = ACTIONS(11557),
    [anon_sym_LT_LT] = ACTIONS(11557),
    [anon_sym_std] = ACTIONS(11557),
    [anon_sym_randomize] = ACTIONS(11557),
    [anon_sym_null] = ACTIONS(11557),
    [anon_sym_QMARK] = ACTIONS(11559),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11559),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11559),
    [anon_sym_AMP] = ACTIONS(11557),
    [anon_sym_PIPE] = ACTIONS(11557),
    [anon_sym_CARET] = ACTIONS(11557),
    [anon_sym_CARET_TILDE] = ACTIONS(11559),
    [anon_sym_TILDE_CARET] = ACTIONS(11559),
    [anon_sym_GT_GT_GT] = ACTIONS(11559),
    [anon_sym_LT_LT_LT] = ACTIONS(11559),
    [anon_sym_LT_DASH_GT] = ACTIONS(11559),
    [anon_sym_this] = ACTIONS(11557),
    [anon_sym_TILDE_AMP] = ACTIONS(11559),
    [anon_sym_TILDE_PIPE] = ACTIONS(11559),
    [anon_sym_DASH_DASH] = ACTIONS(11559),
    [aux_sym_decimal_number_token1] = ACTIONS(11559),
    [aux_sym_decimal_number_token2] = ACTIONS(11559),
    [sym_binary_number] = ACTIONS(11559),
    [sym_octal_number] = ACTIONS(11559),
    [sym_hex_number] = ACTIONS(11559),
    [aux_sym_real_number_token1] = ACTIONS(11559),
    [sym_fixed_point_number] = ACTIONS(11557),
    [sym_unsigned_number] = ACTIONS(11557),
    [anon_sym_SQUOTE0] = ACTIONS(11559),
    [anon_sym_SQUOTE1] = ACTIONS(11559),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11559),
    [anon_sym_LPAREN_STAR] = ACTIONS(11559),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11559),
    [anon_sym_DOLLARroot] = ACTIONS(11557),
    [anon_sym_DOLLARunit] = ACTIONS(11557),
    [sym_system_tf_identifier] = ACTIONS(11557),
  },
  [5307] = {
    [sym_parameter_value_assignment] = STATE(11716),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5651),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_class_type_repeat1] = STATE(11664),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11561),
    [anon_sym_DQUOTE] = ACTIONS(11274),
    [anon_sym_LT] = ACTIONS(11561),
    [anon_sym_GT] = ACTIONS(11561),
    [anon_sym_LPAREN] = ACTIONS(11274),
    [anon_sym_RPAREN] = ACTIONS(11274),
    [anon_sym_COMMA] = ACTIONS(11274),
    [anon_sym_BQUOTE] = ACTIONS(11274),
    [anon_sym_SLASH] = ACTIONS(11561),
    [anon_sym_COLON] = ACTIONS(11561),
    [anon_sym_POUND] = ACTIONS(11245),
    [anon_sym_type] = ACTIONS(11561),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11274),
    [anon_sym_const] = ACTIONS(11561),
    [anon_sym_local] = ACTIONS(11561),
    [anon_sym_super] = ACTIONS(11561),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_COLON_COLON] = ACTIONS(11258),
    [anon_sym_STAR] = ACTIONS(11561),
    [anon_sym_string] = ACTIONS(11561),
    [anon_sym_byte] = ACTIONS(11561),
    [anon_sym_shortint] = ACTIONS(11561),
    [anon_sym_int] = ACTIONS(11561),
    [anon_sym_longint] = ACTIONS(11561),
    [anon_sym_integer] = ACTIONS(11561),
    [anon_sym_time] = ACTIONS(11561),
    [anon_sym_bit] = ACTIONS(11561),
    [anon_sym_logic] = ACTIONS(11561),
    [anon_sym_reg] = ACTIONS(11561),
    [anon_sym_shortreal] = ACTIONS(11561),
    [anon_sym_real] = ACTIONS(11561),
    [anon_sym_realtime] = ACTIONS(11561),
    [anon_sym_signed] = ACTIONS(11561),
    [anon_sym_unsigned] = ACTIONS(11561),
    [anon_sym_tagged] = ACTIONS(11561),
    [anon_sym_DOLLAR] = ACTIONS(11561),
    [anon_sym_PLUS] = ACTIONS(11561),
    [anon_sym_PLUS_PLUS] = ACTIONS(11274),
    [anon_sym_STAR_STAR] = ACTIONS(11274),
    [anon_sym_PERCENT] = ACTIONS(11274),
    [anon_sym_EQ_EQ] = ACTIONS(11561),
    [anon_sym_BANG_EQ] = ACTIONS(11561),
    [anon_sym_LT_EQ] = ACTIONS(11274),
    [anon_sym_GT_EQ] = ACTIONS(11274),
    [anon_sym_BANG] = ACTIONS(11561),
    [anon_sym_AMP_AMP] = ACTIONS(11561),
    [anon_sym_PIPE_PIPE] = ACTIONS(11274),
    [anon_sym_matches] = ACTIONS(11561),
    [anon_sym_DASH] = ACTIONS(11561),
    [anon_sym_DASH_GT] = ACTIONS(11274),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11274),
    [anon_sym_inside] = ACTIONS(11561),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11563),
    [anon_sym_TILDE] = ACTIONS(11561),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11274),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11274),
    [anon_sym_GT_GT] = ACTIONS(11561),
    [anon_sym_LT_LT] = ACTIONS(11561),
    [anon_sym_std] = ACTIONS(11561),
    [anon_sym_randomize] = ACTIONS(11561),
    [anon_sym_null] = ACTIONS(11561),
    [anon_sym_QMARK] = ACTIONS(11274),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11274),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11274),
    [anon_sym_AMP] = ACTIONS(11561),
    [anon_sym_PIPE] = ACTIONS(11561),
    [anon_sym_CARET] = ACTIONS(11561),
    [anon_sym_CARET_TILDE] = ACTIONS(11274),
    [anon_sym_TILDE_CARET] = ACTIONS(11274),
    [anon_sym_GT_GT_GT] = ACTIONS(11274),
    [anon_sym_LT_LT_LT] = ACTIONS(11274),
    [anon_sym_LT_DASH_GT] = ACTIONS(11274),
    [anon_sym_this] = ACTIONS(11561),
    [anon_sym_TILDE_AMP] = ACTIONS(11274),
    [anon_sym_TILDE_PIPE] = ACTIONS(11274),
    [anon_sym_DASH_DASH] = ACTIONS(11274),
    [aux_sym_decimal_number_token1] = ACTIONS(11274),
    [aux_sym_decimal_number_token2] = ACTIONS(11274),
    [sym_binary_number] = ACTIONS(11274),
    [sym_octal_number] = ACTIONS(11274),
    [sym_hex_number] = ACTIONS(11274),
    [aux_sym_real_number_token1] = ACTIONS(11274),
    [sym_fixed_point_number] = ACTIONS(11561),
    [sym_unsigned_number] = ACTIONS(11561),
    [anon_sym_SQUOTE0] = ACTIONS(11274),
    [anon_sym_SQUOTE1] = ACTIONS(11274),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11274),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11274),
    [anon_sym_DOLLARroot] = ACTIONS(11561),
    [anon_sym_DOLLARunit] = ACTIONS(11561),
    [sym_system_tf_identifier] = ACTIONS(11561),
  },
  [5308] = {
    [sym_list_of_arguments_parent] = STATE(5585),
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5593),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5442),
    [aux_sym__description_repeat1] = STATE(5442),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11523),
    [anon_sym_DQUOTE] = ACTIONS(11526),
    [anon_sym_LT] = ACTIONS(11523),
    [anon_sym_GT] = ACTIONS(11523),
    [anon_sym_LPAREN] = ACTIONS(11523),
    [anon_sym_RPAREN] = ACTIONS(11526),
    [anon_sym_COMMA] = ACTIONS(11526),
    [anon_sym_BQUOTE] = ACTIONS(11526),
    [anon_sym_SLASH] = ACTIONS(11523),
    [anon_sym_COLON] = ACTIONS(11526),
    [anon_sym_type] = ACTIONS(11523),
    [anon_sym_DOT] = ACTIONS(11529),
    [anon_sym_LBRACE] = ACTIONS(11526),
    [anon_sym_const] = ACTIONS(11523),
    [anon_sym_local] = ACTIONS(11523),
    [anon_sym_super] = ACTIONS(11523),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11523),
    [anon_sym_string] = ACTIONS(11523),
    [anon_sym_byte] = ACTIONS(11523),
    [anon_sym_shortint] = ACTIONS(11523),
    [anon_sym_int] = ACTIONS(11523),
    [anon_sym_longint] = ACTIONS(11523),
    [anon_sym_integer] = ACTIONS(11523),
    [anon_sym_time] = ACTIONS(11523),
    [anon_sym_bit] = ACTIONS(11523),
    [anon_sym_logic] = ACTIONS(11523),
    [anon_sym_reg] = ACTIONS(11523),
    [anon_sym_shortreal] = ACTIONS(11523),
    [anon_sym_real] = ACTIONS(11523),
    [anon_sym_realtime] = ACTIONS(11523),
    [anon_sym_signed] = ACTIONS(11523),
    [anon_sym_unsigned] = ACTIONS(11523),
    [anon_sym_tagged] = ACTIONS(11523),
    [anon_sym_DOLLAR] = ACTIONS(11523),
    [anon_sym_PLUS] = ACTIONS(11523),
    [anon_sym_PLUS_PLUS] = ACTIONS(11526),
    [anon_sym_STAR_STAR] = ACTIONS(11526),
    [anon_sym_PERCENT] = ACTIONS(11526),
    [anon_sym_EQ_EQ] = ACTIONS(11523),
    [anon_sym_BANG_EQ] = ACTIONS(11523),
    [anon_sym_LT_EQ] = ACTIONS(11526),
    [anon_sym_GT_EQ] = ACTIONS(11526),
    [anon_sym_BANG] = ACTIONS(11523),
    [anon_sym_AMP_AMP] = ACTIONS(11523),
    [anon_sym_PIPE_PIPE] = ACTIONS(11526),
    [anon_sym_matches] = ACTIONS(11523),
    [anon_sym_DASH] = ACTIONS(11523),
    [anon_sym_DASH_GT] = ACTIONS(11526),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11526),
    [anon_sym_inside] = ACTIONS(11523),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11526),
    [anon_sym_TILDE] = ACTIONS(11523),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11526),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11526),
    [anon_sym_GT_GT] = ACTIONS(11523),
    [anon_sym_LT_LT] = ACTIONS(11523),
    [anon_sym_std] = ACTIONS(11523),
    [anon_sym_randomize] = ACTIONS(11523),
    [anon_sym_null] = ACTIONS(11523),
    [anon_sym_QMARK] = ACTIONS(11526),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_AMP] = ACTIONS(11523),
    [anon_sym_PIPE] = ACTIONS(11523),
    [anon_sym_CARET] = ACTIONS(11523),
    [anon_sym_CARET_TILDE] = ACTIONS(11526),
    [anon_sym_TILDE_CARET] = ACTIONS(11526),
    [anon_sym_GT_GT_GT] = ACTIONS(11526),
    [anon_sym_LT_LT_LT] = ACTIONS(11526),
    [anon_sym_LT_DASH_GT] = ACTIONS(11526),
    [anon_sym_this] = ACTIONS(11523),
    [anon_sym_TILDE_AMP] = ACTIONS(11526),
    [anon_sym_TILDE_PIPE] = ACTIONS(11526),
    [anon_sym_DASH_DASH] = ACTIONS(11526),
    [aux_sym_decimal_number_token1] = ACTIONS(11526),
    [aux_sym_decimal_number_token2] = ACTIONS(11526),
    [sym_binary_number] = ACTIONS(11526),
    [sym_octal_number] = ACTIONS(11526),
    [sym_hex_number] = ACTIONS(11526),
    [aux_sym_real_number_token1] = ACTIONS(11526),
    [sym_fixed_point_number] = ACTIONS(11523),
    [sym_unsigned_number] = ACTIONS(11523),
    [anon_sym_SQUOTE0] = ACTIONS(11526),
    [anon_sym_SQUOTE1] = ACTIONS(11526),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11526),
    [anon_sym_LPAREN_STAR] = ACTIONS(11330),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11526),
    [anon_sym_DOLLARroot] = ACTIONS(11523),
    [anon_sym_DOLLARunit] = ACTIONS(11523),
    [sym_system_tf_identifier] = ACTIONS(11523),
  },
  [5309] = {
    [sym_list_of_arguments_parent] = STATE(5596),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5461),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5438),
    [aux_sym__description_repeat1] = STATE(5438),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11541),
    [anon_sym_DQUOTE] = ACTIONS(11544),
    [anon_sym_LT] = ACTIONS(11541),
    [anon_sym_GT] = ACTIONS(11541),
    [anon_sym_LPAREN] = ACTIONS(11541),
    [anon_sym_RPAREN] = ACTIONS(11544),
    [anon_sym_COMMA] = ACTIONS(11544),
    [anon_sym_BQUOTE] = ACTIONS(11544),
    [anon_sym_SLASH] = ACTIONS(11541),
    [anon_sym_COLON] = ACTIONS(11544),
    [anon_sym_type] = ACTIONS(11541),
    [anon_sym_DOT] = ACTIONS(11547),
    [anon_sym_LBRACE] = ACTIONS(11544),
    [anon_sym_const] = ACTIONS(11541),
    [anon_sym_local] = ACTIONS(11541),
    [anon_sym_super] = ACTIONS(11541),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11541),
    [anon_sym_string] = ACTIONS(11541),
    [anon_sym_byte] = ACTIONS(11541),
    [anon_sym_shortint] = ACTIONS(11541),
    [anon_sym_int] = ACTIONS(11541),
    [anon_sym_longint] = ACTIONS(11541),
    [anon_sym_integer] = ACTIONS(11541),
    [anon_sym_time] = ACTIONS(11541),
    [anon_sym_bit] = ACTIONS(11541),
    [anon_sym_logic] = ACTIONS(11541),
    [anon_sym_reg] = ACTIONS(11541),
    [anon_sym_shortreal] = ACTIONS(11541),
    [anon_sym_real] = ACTIONS(11541),
    [anon_sym_realtime] = ACTIONS(11541),
    [anon_sym_signed] = ACTIONS(11541),
    [anon_sym_unsigned] = ACTIONS(11541),
    [anon_sym_tagged] = ACTIONS(11541),
    [anon_sym_DOLLAR] = ACTIONS(11541),
    [anon_sym_PLUS] = ACTIONS(11541),
    [anon_sym_PLUS_PLUS] = ACTIONS(11566),
    [anon_sym_STAR_STAR] = ACTIONS(11544),
    [anon_sym_PERCENT] = ACTIONS(11544),
    [anon_sym_EQ_EQ] = ACTIONS(11541),
    [anon_sym_BANG_EQ] = ACTIONS(11541),
    [anon_sym_LT_EQ] = ACTIONS(11544),
    [anon_sym_GT_EQ] = ACTIONS(11544),
    [anon_sym_BANG] = ACTIONS(11541),
    [anon_sym_AMP_AMP] = ACTIONS(11541),
    [anon_sym_PIPE_PIPE] = ACTIONS(11544),
    [anon_sym_matches] = ACTIONS(11541),
    [anon_sym_DASH] = ACTIONS(11541),
    [anon_sym_DASH_GT] = ACTIONS(11544),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11544),
    [anon_sym_inside] = ACTIONS(11541),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11544),
    [anon_sym_TILDE] = ACTIONS(11541),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11544),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11544),
    [anon_sym_GT_GT] = ACTIONS(11541),
    [anon_sym_LT_LT] = ACTIONS(11541),
    [anon_sym_std] = ACTIONS(11541),
    [anon_sym_randomize] = ACTIONS(11541),
    [anon_sym_null] = ACTIONS(11541),
    [anon_sym_QMARK] = ACTIONS(11544),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_AMP] = ACTIONS(11541),
    [anon_sym_PIPE] = ACTIONS(11541),
    [anon_sym_CARET] = ACTIONS(11541),
    [anon_sym_CARET_TILDE] = ACTIONS(11544),
    [anon_sym_TILDE_CARET] = ACTIONS(11544),
    [anon_sym_GT_GT_GT] = ACTIONS(11544),
    [anon_sym_LT_LT_LT] = ACTIONS(11544),
    [anon_sym_LT_DASH_GT] = ACTIONS(11544),
    [anon_sym_this] = ACTIONS(11541),
    [anon_sym_TILDE_AMP] = ACTIONS(11544),
    [anon_sym_TILDE_PIPE] = ACTIONS(11544),
    [anon_sym_DASH_DASH] = ACTIONS(11566),
    [aux_sym_decimal_number_token1] = ACTIONS(11544),
    [aux_sym_decimal_number_token2] = ACTIONS(11544),
    [sym_binary_number] = ACTIONS(11544),
    [sym_octal_number] = ACTIONS(11544),
    [sym_hex_number] = ACTIONS(11544),
    [aux_sym_real_number_token1] = ACTIONS(11544),
    [sym_fixed_point_number] = ACTIONS(11541),
    [sym_unsigned_number] = ACTIONS(11541),
    [anon_sym_SQUOTE0] = ACTIONS(11544),
    [anon_sym_SQUOTE1] = ACTIONS(11544),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11544),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11544),
    [anon_sym_DOLLARroot] = ACTIONS(11541),
    [anon_sym_DOLLARunit] = ACTIONS(11541),
    [sym_system_tf_identifier] = ACTIONS(11541),
  },
  [5310] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_module_path_expression] = STATE(18226),
    [sym_constant_primary] = STATE(17639),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(10871),
    [sym_package_scope] = STATE(12247),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13820),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11198),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11202),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11222),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5311] = {
    [sym_list_of_arguments_parent] = STATE(5585),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5378),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5442),
    [aux_sym__description_repeat1] = STATE(5442),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11523),
    [anon_sym_DQUOTE] = ACTIONS(11526),
    [anon_sym_LT] = ACTIONS(11523),
    [anon_sym_GT] = ACTIONS(11523),
    [anon_sym_LPAREN] = ACTIONS(11523),
    [anon_sym_RPAREN] = ACTIONS(11526),
    [anon_sym_BQUOTE] = ACTIONS(11526),
    [anon_sym_SLASH] = ACTIONS(11523),
    [anon_sym_COLON] = ACTIONS(11526),
    [anon_sym_type] = ACTIONS(11523),
    [anon_sym_DOT] = ACTIONS(11529),
    [anon_sym_LBRACE] = ACTIONS(11526),
    [anon_sym_const] = ACTIONS(11523),
    [anon_sym_local] = ACTIONS(11523),
    [anon_sym_super] = ACTIONS(11523),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11523),
    [anon_sym_string] = ACTIONS(11523),
    [anon_sym_byte] = ACTIONS(11523),
    [anon_sym_shortint] = ACTIONS(11523),
    [anon_sym_int] = ACTIONS(11523),
    [anon_sym_longint] = ACTIONS(11523),
    [anon_sym_integer] = ACTIONS(11523),
    [anon_sym_time] = ACTIONS(11523),
    [anon_sym_bit] = ACTIONS(11523),
    [anon_sym_logic] = ACTIONS(11523),
    [anon_sym_reg] = ACTIONS(11523),
    [anon_sym_shortreal] = ACTIONS(11523),
    [anon_sym_real] = ACTIONS(11523),
    [anon_sym_realtime] = ACTIONS(11523),
    [anon_sym_signed] = ACTIONS(11523),
    [anon_sym_unsigned] = ACTIONS(11523),
    [anon_sym_tagged] = ACTIONS(11523),
    [anon_sym_DOLLAR] = ACTIONS(11523),
    [anon_sym_PLUS] = ACTIONS(11523),
    [anon_sym_PLUS_PLUS] = ACTIONS(11535),
    [anon_sym_STAR_STAR] = ACTIONS(11526),
    [anon_sym_PERCENT] = ACTIONS(11526),
    [anon_sym_EQ_EQ] = ACTIONS(11523),
    [anon_sym_BANG_EQ] = ACTIONS(11523),
    [anon_sym_LT_EQ] = ACTIONS(11526),
    [anon_sym_GT_EQ] = ACTIONS(11526),
    [anon_sym_BANG] = ACTIONS(11523),
    [anon_sym_AMP_AMP] = ACTIONS(11523),
    [anon_sym_PIPE_PIPE] = ACTIONS(11526),
    [anon_sym_matches] = ACTIONS(11523),
    [anon_sym_DASH] = ACTIONS(11523),
    [anon_sym_DASH_GT] = ACTIONS(11526),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11526),
    [anon_sym_inside] = ACTIONS(11523),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11526),
    [anon_sym_TILDE] = ACTIONS(11523),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11526),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11526),
    [anon_sym_GT_GT] = ACTIONS(11523),
    [anon_sym_LT_LT] = ACTIONS(11523),
    [anon_sym_std] = ACTIONS(11523),
    [anon_sym_randomize] = ACTIONS(11523),
    [anon_sym_null] = ACTIONS(11523),
    [anon_sym_QMARK] = ACTIONS(11526),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11526),
    [anon_sym_AMP] = ACTIONS(11523),
    [anon_sym_PIPE] = ACTIONS(11523),
    [anon_sym_CARET] = ACTIONS(11523),
    [anon_sym_CARET_TILDE] = ACTIONS(11526),
    [anon_sym_TILDE_CARET] = ACTIONS(11526),
    [anon_sym_GT_GT_GT] = ACTIONS(11526),
    [anon_sym_LT_LT_LT] = ACTIONS(11526),
    [anon_sym_LT_DASH_GT] = ACTIONS(11526),
    [anon_sym_this] = ACTIONS(11523),
    [anon_sym_TILDE_AMP] = ACTIONS(11526),
    [anon_sym_TILDE_PIPE] = ACTIONS(11526),
    [anon_sym_DASH_DASH] = ACTIONS(11535),
    [aux_sym_decimal_number_token1] = ACTIONS(11526),
    [aux_sym_decimal_number_token2] = ACTIONS(11526),
    [sym_binary_number] = ACTIONS(11526),
    [sym_octal_number] = ACTIONS(11526),
    [sym_hex_number] = ACTIONS(11526),
    [aux_sym_real_number_token1] = ACTIONS(11526),
    [sym_fixed_point_number] = ACTIONS(11523),
    [sym_unsigned_number] = ACTIONS(11523),
    [anon_sym_SQUOTE0] = ACTIONS(11526),
    [anon_sym_SQUOTE1] = ACTIONS(11526),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11526),
    [anon_sym_LPAREN_STAR] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11526),
    [anon_sym_DOLLARroot] = ACTIONS(11523),
    [anon_sym_DOLLARunit] = ACTIONS(11523),
    [sym_system_tf_identifier] = ACTIONS(11523),
  },
  [5312] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_module_path_expression] = STATE(19613),
    [sym_constant_primary] = STATE(17639),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(10871),
    [sym_package_scope] = STATE(12247),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13820),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11198),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11202),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11222),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5313] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8916),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_module_path_expression] = STATE(18022),
    [sym_constant_primary] = STATE(17639),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(8754),
    [sym_integral_number] = STATE(8754),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8754),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(10847),
    [sym_package_scope] = STATE(12247),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13862),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11198),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11202),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11570),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5314] = {
    [sym_simple_text_macro_usage] = STATE(8333),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18707),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_module_path_concatenation] = STATE(14376),
    [sym_module_path_multiple_concatenation] = STATE(14376),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(8957),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18196),
    [sym_module_path_expression] = STATE(16938),
    [sym_constant_primary] = STATE(17639),
    [sym_module_path_primary] = STATE(14379),
    [sym_primary] = STATE(18196),
    [sym_class_qualifier] = STATE(12857),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(8333),
    [sym_string_literal] = STATE(8333),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(8930),
    [sym_integral_number] = STATE(8930),
    [sym_decimal_number] = STATE(8304),
    [sym_real_number] = STATE(8930),
    [sym_unbased_unsized_literal] = STATE(8333),
    [sym_escaped_identifier] = STATE(103),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(10829),
    [sym_package_scope] = STATE(12247),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13820),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(11196),
    [anon_sym_LPAREN] = ACTIONS(11198),
    [anon_sym_BQUOTE] = ACTIONS(11336),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11202),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(11208),
    [aux_sym_decimal_number_token2] = ACTIONS(11208),
    [sym_binary_number] = ACTIONS(11210),
    [sym_octal_number] = ACTIONS(11210),
    [sym_hex_number] = ACTIONS(11210),
    [aux_sym_real_number_token1] = ACTIONS(11212),
    [sym_fixed_point_number] = ACTIONS(11214),
    [sym_unsigned_number] = ACTIONS(11216),
    [anon_sym_SQUOTE0] = ACTIONS(11218),
    [anon_sym_SQUOTE1] = ACTIONS(11218),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11218),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(117),
    [anon_sym_DOLLARroot] = ACTIONS(11222),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5315] = {
    [sym_list_of_arguments_parent] = STATE(5596),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5387),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5438),
    [aux_sym__description_repeat1] = STATE(5438),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11541),
    [anon_sym_DQUOTE] = ACTIONS(11544),
    [anon_sym_LT] = ACTIONS(11541),
    [anon_sym_GT] = ACTIONS(11541),
    [anon_sym_LPAREN] = ACTIONS(11541),
    [anon_sym_RPAREN] = ACTIONS(11544),
    [anon_sym_BQUOTE] = ACTIONS(11544),
    [anon_sym_SLASH] = ACTIONS(11541),
    [anon_sym_COLON] = ACTIONS(11544),
    [anon_sym_type] = ACTIONS(11541),
    [anon_sym_DOT] = ACTIONS(11547),
    [anon_sym_LBRACE] = ACTIONS(11544),
    [anon_sym_const] = ACTIONS(11541),
    [anon_sym_local] = ACTIONS(11541),
    [anon_sym_super] = ACTIONS(11541),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11541),
    [anon_sym_string] = ACTIONS(11541),
    [anon_sym_byte] = ACTIONS(11541),
    [anon_sym_shortint] = ACTIONS(11541),
    [anon_sym_int] = ACTIONS(11541),
    [anon_sym_longint] = ACTIONS(11541),
    [anon_sym_integer] = ACTIONS(11541),
    [anon_sym_time] = ACTIONS(11541),
    [anon_sym_bit] = ACTIONS(11541),
    [anon_sym_logic] = ACTIONS(11541),
    [anon_sym_reg] = ACTIONS(11541),
    [anon_sym_shortreal] = ACTIONS(11541),
    [anon_sym_real] = ACTIONS(11541),
    [anon_sym_realtime] = ACTIONS(11541),
    [anon_sym_signed] = ACTIONS(11541),
    [anon_sym_unsigned] = ACTIONS(11541),
    [anon_sym_tagged] = ACTIONS(11541),
    [anon_sym_DOLLAR] = ACTIONS(11541),
    [anon_sym_PLUS] = ACTIONS(11541),
    [anon_sym_PLUS_PLUS] = ACTIONS(11566),
    [anon_sym_STAR_STAR] = ACTIONS(11544),
    [anon_sym_PERCENT] = ACTIONS(11544),
    [anon_sym_EQ_EQ] = ACTIONS(11541),
    [anon_sym_BANG_EQ] = ACTIONS(11541),
    [anon_sym_LT_EQ] = ACTIONS(11544),
    [anon_sym_GT_EQ] = ACTIONS(11544),
    [anon_sym_BANG] = ACTIONS(11541),
    [anon_sym_AMP_AMP] = ACTIONS(11541),
    [anon_sym_PIPE_PIPE] = ACTIONS(11544),
    [anon_sym_matches] = ACTIONS(11541),
    [anon_sym_DASH] = ACTIONS(11541),
    [anon_sym_DASH_GT] = ACTIONS(11544),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11544),
    [anon_sym_inside] = ACTIONS(11541),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11544),
    [anon_sym_TILDE] = ACTIONS(11541),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11544),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11544),
    [anon_sym_GT_GT] = ACTIONS(11541),
    [anon_sym_LT_LT] = ACTIONS(11541),
    [anon_sym_std] = ACTIONS(11541),
    [anon_sym_randomize] = ACTIONS(11541),
    [anon_sym_null] = ACTIONS(11541),
    [anon_sym_QMARK] = ACTIONS(11544),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11544),
    [anon_sym_AMP] = ACTIONS(11541),
    [anon_sym_PIPE] = ACTIONS(11541),
    [anon_sym_CARET] = ACTIONS(11541),
    [anon_sym_CARET_TILDE] = ACTIONS(11544),
    [anon_sym_TILDE_CARET] = ACTIONS(11544),
    [anon_sym_GT_GT_GT] = ACTIONS(11544),
    [anon_sym_LT_LT_LT] = ACTIONS(11544),
    [anon_sym_LT_DASH_GT] = ACTIONS(11544),
    [anon_sym_this] = ACTIONS(11541),
    [anon_sym_TILDE_AMP] = ACTIONS(11544),
    [anon_sym_TILDE_PIPE] = ACTIONS(11544),
    [anon_sym_DASH_DASH] = ACTIONS(11566),
    [aux_sym_decimal_number_token1] = ACTIONS(11544),
    [aux_sym_decimal_number_token2] = ACTIONS(11544),
    [sym_binary_number] = ACTIONS(11544),
    [sym_octal_number] = ACTIONS(11544),
    [sym_hex_number] = ACTIONS(11544),
    [aux_sym_real_number_token1] = ACTIONS(11544),
    [sym_fixed_point_number] = ACTIONS(11541),
    [sym_unsigned_number] = ACTIONS(11541),
    [anon_sym_SQUOTE0] = ACTIONS(11544),
    [anon_sym_SQUOTE1] = ACTIONS(11544),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11544),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11544),
    [anon_sym_DOLLARroot] = ACTIONS(11541),
    [anon_sym_DOLLARunit] = ACTIONS(11541),
    [sym_system_tf_identifier] = ACTIONS(11541),
  },
  [5316] = {
    [sym_list_of_arguments_parent] = STATE(5549),
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5371),
    [sym_constant_bit_select1] = STATE(18220),
    [sym_attribute_instance] = STATE(5436),
    [aux_sym__description_repeat1] = STATE(5436),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11513),
    [anon_sym_DQUOTE] = ACTIONS(11516),
    [anon_sym_LT] = ACTIONS(11513),
    [anon_sym_GT] = ACTIONS(11513),
    [anon_sym_LPAREN] = ACTIONS(11513),
    [anon_sym_RPAREN] = ACTIONS(11516),
    [anon_sym_BQUOTE] = ACTIONS(11516),
    [anon_sym_SLASH] = ACTIONS(11513),
    [anon_sym_COLON] = ACTIONS(11516),
    [anon_sym_type] = ACTIONS(11513),
    [anon_sym_DOT] = ACTIONS(11519),
    [anon_sym_LBRACE] = ACTIONS(11516),
    [anon_sym_const] = ACTIONS(11513),
    [anon_sym_local] = ACTIONS(11513),
    [anon_sym_super] = ACTIONS(11513),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11513),
    [anon_sym_string] = ACTIONS(11513),
    [anon_sym_byte] = ACTIONS(11513),
    [anon_sym_shortint] = ACTIONS(11513),
    [anon_sym_int] = ACTIONS(11513),
    [anon_sym_longint] = ACTIONS(11513),
    [anon_sym_integer] = ACTIONS(11513),
    [anon_sym_time] = ACTIONS(11513),
    [anon_sym_bit] = ACTIONS(11513),
    [anon_sym_logic] = ACTIONS(11513),
    [anon_sym_reg] = ACTIONS(11513),
    [anon_sym_shortreal] = ACTIONS(11513),
    [anon_sym_real] = ACTIONS(11513),
    [anon_sym_realtime] = ACTIONS(11513),
    [anon_sym_signed] = ACTIONS(11513),
    [anon_sym_unsigned] = ACTIONS(11513),
    [anon_sym_tagged] = ACTIONS(11513),
    [anon_sym_DOLLAR] = ACTIONS(11513),
    [anon_sym_PLUS] = ACTIONS(11513),
    [anon_sym_PLUS_PLUS] = ACTIONS(11551),
    [anon_sym_STAR_STAR] = ACTIONS(11516),
    [anon_sym_PERCENT] = ACTIONS(11516),
    [anon_sym_EQ_EQ] = ACTIONS(11513),
    [anon_sym_BANG_EQ] = ACTIONS(11513),
    [anon_sym_LT_EQ] = ACTIONS(11516),
    [anon_sym_GT_EQ] = ACTIONS(11516),
    [anon_sym_BANG] = ACTIONS(11513),
    [anon_sym_AMP_AMP] = ACTIONS(11513),
    [anon_sym_PIPE_PIPE] = ACTIONS(11516),
    [anon_sym_matches] = ACTIONS(11513),
    [anon_sym_DASH] = ACTIONS(11513),
    [anon_sym_DASH_GT] = ACTIONS(11516),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11516),
    [anon_sym_inside] = ACTIONS(11513),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11516),
    [anon_sym_TILDE] = ACTIONS(11513),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11516),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11516),
    [anon_sym_GT_GT] = ACTIONS(11513),
    [anon_sym_LT_LT] = ACTIONS(11513),
    [anon_sym_std] = ACTIONS(11513),
    [anon_sym_randomize] = ACTIONS(11513),
    [anon_sym_null] = ACTIONS(11513),
    [anon_sym_QMARK] = ACTIONS(11516),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11516),
    [anon_sym_AMP] = ACTIONS(11513),
    [anon_sym_PIPE] = ACTIONS(11513),
    [anon_sym_CARET] = ACTIONS(11513),
    [anon_sym_CARET_TILDE] = ACTIONS(11516),
    [anon_sym_TILDE_CARET] = ACTIONS(11516),
    [anon_sym_GT_GT_GT] = ACTIONS(11516),
    [anon_sym_LT_LT_LT] = ACTIONS(11516),
    [anon_sym_LT_DASH_GT] = ACTIONS(11516),
    [anon_sym_this] = ACTIONS(11513),
    [anon_sym_TILDE_AMP] = ACTIONS(11516),
    [anon_sym_TILDE_PIPE] = ACTIONS(11516),
    [anon_sym_DASH_DASH] = ACTIONS(11551),
    [aux_sym_decimal_number_token1] = ACTIONS(11516),
    [aux_sym_decimal_number_token2] = ACTIONS(11516),
    [sym_binary_number] = ACTIONS(11516),
    [sym_octal_number] = ACTIONS(11516),
    [sym_hex_number] = ACTIONS(11516),
    [aux_sym_real_number_token1] = ACTIONS(11516),
    [sym_fixed_point_number] = ACTIONS(11513),
    [sym_unsigned_number] = ACTIONS(11513),
    [anon_sym_SQUOTE0] = ACTIONS(11516),
    [anon_sym_SQUOTE1] = ACTIONS(11516),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11516),
    [anon_sym_LPAREN_STAR] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11516),
    [anon_sym_DOLLARroot] = ACTIONS(11513),
    [anon_sym_DOLLARunit] = ACTIONS(11513),
    [sym_system_tf_identifier] = ACTIONS(11513),
  },
  [5317] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16917),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6727),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6890),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(6727),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5336),
    [sym_escaped_identifier] = STATE(5853),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5749),
    [sym_package_scope] = STATE(12161),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5336),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13314),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11572),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(11574),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11576),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11578),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_this] = ACTIONS(2672),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11580),
    [anon_sym_DOLLARroot] = ACTIONS(11582),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [5318] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(9021),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7509),
    [sym_package_scope] = STATE(12399),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5319] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5320),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7302),
    [sym_package_scope] = STATE(12280),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5320),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5320] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7302),
    [sym_package_scope] = STATE(12280),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5321] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(8576),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8827),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(5322),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7522),
    [sym_package_scope] = STATE(12169),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5322),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13129),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11610),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(9943),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11616),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5322] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(8543),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8827),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7522),
    [sym_package_scope] = STATE(12169),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13129),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11610),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(9943),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11616),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5323] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(16773),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5543),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5600),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(5543),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(5325),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5237),
    [sym_package_scope] = STATE(12418),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5325),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13677),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(11618),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11620),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11622),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_this] = ACTIONS(7013),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(11624),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [5324] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5327),
    [sym_escaped_identifier] = STATE(7065),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5928),
    [sym_package_scope] = STATE(12339),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5327),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13202),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11626),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11628),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11630),
    [anon_sym_DOLLARroot] = ACTIONS(11632),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5325] = {
    [sym_simple_text_macro_usage] = STATE(5532),
    [sym_casting_type] = STATE(19898),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(5543),
    [sym_sequence_instance] = STATE(18236),
    [sym_let_expression] = STATE(5543),
    [sym_assignment_pattern] = STATE(5555),
    [sym_assignment_pattern_expression] = STATE(5543),
    [sym__assignment_pattern_expression_type] = STATE(16773),
    [sym_concatenation] = STATE(5519),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(5519),
    [sym_streaming_concatenation] = STATE(5543),
    [sym_empty_unpacked_array_concatenation] = STATE(5543),
    [sym_tf_call] = STATE(5561),
    [sym_system_tf_call] = STATE(5561),
    [sym_subroutine_call] = STATE(5563),
    [sym_function_subroutine_call] = STATE(5543),
    [sym_method_call] = STATE(5561),
    [sym_randomize_call] = STATE(5561),
    [sym__method_call_root] = STATE(20142),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(5584),
    [sym_class_qualifier] = STATE(12769),
    [sym_primary_literal] = STATE(5516),
    [sym_time_literal] = STATE(5532),
    [sym_string_literal] = STATE(5532),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(5543),
    [sym__number] = STATE(5532),
    [sym_integral_number] = STATE(5532),
    [sym_decimal_number] = STATE(5514),
    [sym_real_number] = STATE(5532),
    [sym_unbased_unsized_literal] = STATE(5532),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(1426),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5237),
    [sym_package_scope] = STATE(12418),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13677),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(4144),
    [anon_sym_DQUOTE] = ACTIONS(6989),
    [anon_sym_LPAREN] = ACTIONS(11618),
    [anon_sym_BQUOTE] = ACTIONS(6995),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11620),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(9895),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11622),
    [anon_sym_std] = ACTIONS(7007),
    [anon_sym_randomize] = ACTIONS(7009),
    [anon_sym_null] = ACTIONS(7011),
    [anon_sym_this] = ACTIONS(7013),
    [aux_sym_decimal_number_token1] = ACTIONS(7015),
    [aux_sym_decimal_number_token2] = ACTIONS(7015),
    [sym_binary_number] = ACTIONS(7017),
    [sym_octal_number] = ACTIONS(7017),
    [sym_hex_number] = ACTIONS(7017),
    [aux_sym_real_number_token1] = ACTIONS(7019),
    [sym_fixed_point_number] = ACTIONS(7021),
    [sym_unsigned_number] = ACTIONS(7023),
    [anon_sym_SQUOTE0] = ACTIONS(7025),
    [anon_sym_SQUOTE1] = ACTIONS(7025),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(7025),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(4156),
    [anon_sym_DOLLARroot] = ACTIONS(11624),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(7029),
  },
  [5326] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6853),
    [sym_package_scope] = STATE(12201),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5327] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(7065),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5928),
    [sym_package_scope] = STATE(12339),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13202),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11626),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11628),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11630),
    [anon_sym_DOLLARroot] = ACTIONS(11632),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5328] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5330),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7332),
    [sym_package_scope] = STATE(12295),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5330),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5329] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5332),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7612),
    [sym_package_scope] = STATE(12335),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5332),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5330] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18237),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7332),
    [sym_package_scope] = STATE(12295),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5331] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(17309),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(9317),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9168),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9317),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(5334),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7774),
    [sym_package_scope] = STATE(12326),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5334),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13294),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(11638),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11640),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11642),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_this] = ACTIONS(6499),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11644),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [5332] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8872),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7612),
    [sym_package_scope] = STATE(12335),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(8484),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5333] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5326),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6853),
    [sym_package_scope] = STATE(12201),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5326),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5334] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(17309),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(9317),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9233),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9317),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7774),
    [sym_package_scope] = STATE(12326),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13294),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(11638),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11640),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11642),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_this] = ACTIONS(6499),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11644),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [5335] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(9103),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(5345),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7504),
    [sym_package_scope] = STATE(12254),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5345),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5336] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16917),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6727),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(6813),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(6667),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(6727),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5853),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5749),
    [sym_package_scope] = STATE(12161),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13314),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11572),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(11574),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11576),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11578),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(2670),
    [anon_sym_this] = ACTIONS(2672),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11580),
    [anon_sym_DOLLARroot] = ACTIONS(11582),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [5337] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(9103),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8915),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(5318),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7509),
    [sym_package_scope] = STATE(12399),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5318),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8827),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5338] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(17309),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(9317),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(9168),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9317),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(5340),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7734),
    [sym_package_scope] = STATE(12272),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5340),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13294),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(11638),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11640),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11642),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(6499),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11644),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [5339] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8543),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7425),
    [sym_package_scope] = STATE(11975),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13129),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11610),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11616),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5340] = {
    [sym_simple_text_macro_usage] = STATE(9115),
    [sym_casting_type] = STATE(20041),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9317),
    [sym_sequence_instance] = STATE(17757),
    [sym_let_expression] = STATE(9317),
    [sym_assignment_pattern] = STATE(9329),
    [sym_assignment_pattern_expression] = STATE(9317),
    [sym__assignment_pattern_expression_type] = STATE(17309),
    [sym_concatenation] = STATE(8954),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8954),
    [sym_streaming_concatenation] = STATE(9317),
    [sym_empty_unpacked_array_concatenation] = STATE(9317),
    [sym_tf_call] = STATE(9334),
    [sym_system_tf_call] = STATE(9334),
    [sym_subroutine_call] = STATE(9335),
    [sym_function_subroutine_call] = STATE(9317),
    [sym_method_call] = STATE(9334),
    [sym_randomize_call] = STATE(9334),
    [sym__method_call_root] = STATE(17528),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(9233),
    [sym_class_qualifier] = STATE(12623),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(9115),
    [sym_string_literal] = STATE(9115),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9317),
    [sym__number] = STATE(9115),
    [sym_integral_number] = STATE(9115),
    [sym_decimal_number] = STATE(9150),
    [sym_real_number] = STATE(9115),
    [sym_unbased_unsized_literal] = STATE(9115),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7734),
    [sym_package_scope] = STATE(12272),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13294),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(6483),
    [anon_sym_LPAREN] = ACTIONS(11638),
    [anon_sym_BQUOTE] = ACTIONS(6487),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11640),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(6493),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11642),
    [anon_sym_std] = ACTIONS(6497),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(6499),
    [aux_sym_decimal_number_token1] = ACTIONS(6501),
    [aux_sym_decimal_number_token2] = ACTIONS(6501),
    [sym_binary_number] = ACTIONS(6503),
    [sym_octal_number] = ACTIONS(6503),
    [sym_hex_number] = ACTIONS(6503),
    [aux_sym_real_number_token1] = ACTIONS(6505),
    [sym_fixed_point_number] = ACTIONS(6507),
    [sym_unsigned_number] = ACTIONS(6509),
    [anon_sym_SQUOTE0] = ACTIONS(6511),
    [anon_sym_SQUOTE1] = ACTIONS(6511),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6511),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11644),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6515),
  },
  [5341] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5353),
    [sym_escaped_identifier] = STATE(7065),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5850),
    [sym_package_scope] = STATE(12095),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5353),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13202),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11626),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11628),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11630),
    [anon_sym_DOLLARroot] = ACTIONS(11632),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5342] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9742),
    [sym_primary] = STATE(9103),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(5344),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7544),
    [sym_package_scope] = STATE(12378),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5344),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11646),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(11648),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5343] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16917),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6727),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(6890),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(7112),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(6727),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(5358),
    [sym_escaped_identifier] = STATE(5853),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5765),
    [sym_package_scope] = STATE(12443),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5358),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13314),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11572),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(11574),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11576),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11578),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(6557),
    [anon_sym_this] = ACTIONS(2672),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11580),
    [anon_sym_DOLLARroot] = ACTIONS(11582),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [5344] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13444),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9500),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(9558),
    [sym_constant_multiple_concatenation] = STATE(9558),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9620),
    [sym_primary] = STATE(9021),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8880),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7544),
    [sym_package_scope] = STATE(12378),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12814),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11646),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(7677),
    [anon_sym_LBRACE] = ACTIONS(11648),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(7683),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5345] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(9021),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8870),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7504),
    [sym_package_scope] = STATE(12254),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(8692),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5346] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5347),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7332),
    [sym_package_scope] = STATE(12295),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5347),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5347] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(17884),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8653),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8653),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19540),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12528),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8224),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7332),
    [sym_package_scope] = STATE(12295),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(12881),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11596),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11600),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(5160),
    [anon_sym_randomize] = ACTIONS(5162),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11602),
    [anon_sym_DOLLARroot] = ACTIONS(11604),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5348] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5350),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6853),
    [sym_package_scope] = STATE(12201),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5350),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5349] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5351),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7157),
    [sym_package_scope] = STATE(12264),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5351),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5350] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(6853),
    [sym_package_scope] = STATE(12201),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5351] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18992),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7157),
    [sym_package_scope] = STATE(12264),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5352] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9103),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(5354),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7529),
    [sym_package_scope] = STATE(12207),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5354),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5353] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18248),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(7892),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(7892),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(18065),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12574),
    [sym_primary_literal] = STATE(7139),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(7065),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5850),
    [sym_package_scope] = STATE(12095),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13202),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11626),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(3441),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11628),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(3451),
    [anon_sym_randomize] = ACTIONS(3453),
    [anon_sym_null] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11630),
    [anon_sym_DOLLARroot] = ACTIONS(11632),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5354] = {
    [sym_simple_text_macro_usage] = STATE(8901),
    [sym_casting_type] = STATE(19949),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(9136),
    [sym_sequence_instance] = STATE(19538),
    [sym_let_expression] = STATE(9136),
    [sym_assignment_pattern] = STATE(9139),
    [sym_assignment_pattern_expression] = STATE(9136),
    [sym__assignment_pattern_expression_type] = STATE(17357),
    [sym_concatenation] = STATE(8863),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8863),
    [sym_streaming_concatenation] = STATE(9136),
    [sym_empty_unpacked_array_concatenation] = STATE(9136),
    [sym_tf_call] = STATE(9148),
    [sym_system_tf_call] = STATE(9148),
    [sym_subroutine_call] = STATE(9151),
    [sym_function_subroutine_call] = STATE(9136),
    [sym_method_call] = STATE(9148),
    [sym_randomize_call] = STATE(9148),
    [sym__method_call_root] = STATE(18210),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(9021),
    [sym_class_qualifier] = STATE(12835),
    [sym_primary_literal] = STATE(8825),
    [sym_time_literal] = STATE(8901),
    [sym_string_literal] = STATE(8901),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(9136),
    [sym__number] = STATE(8901),
    [sym_integral_number] = STATE(8901),
    [sym_decimal_number] = STATE(8829),
    [sym_real_number] = STATE(8901),
    [sym_unbased_unsized_literal] = STATE(8901),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5230),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7529),
    [sym_package_scope] = STATE(12207),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13987),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11584),
    [anon_sym_DQUOTE] = ACTIONS(5902),
    [anon_sym_LPAREN] = ACTIONS(11586),
    [anon_sym_BQUOTE] = ACTIONS(5906),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11588),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5912),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11590),
    [anon_sym_std] = ACTIONS(5916),
    [anon_sym_randomize] = ACTIONS(5918),
    [anon_sym_null] = ACTIONS(5920),
    [anon_sym_this] = ACTIONS(5922),
    [aux_sym_decimal_number_token1] = ACTIONS(5924),
    [aux_sym_decimal_number_token2] = ACTIONS(5924),
    [sym_binary_number] = ACTIONS(5926),
    [sym_octal_number] = ACTIONS(5926),
    [sym_hex_number] = ACTIONS(5926),
    [aux_sym_real_number_token1] = ACTIONS(5928),
    [sym_fixed_point_number] = ACTIONS(5930),
    [sym_unsigned_number] = ACTIONS(5932),
    [anon_sym_SQUOTE0] = ACTIONS(5934),
    [anon_sym_SQUOTE1] = ACTIONS(5934),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(5934),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11592),
    [anon_sym_DOLLARroot] = ACTIONS(11594),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(5940),
  },
  [5355] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8576),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(5356),
    [sym_escaped_identifier] = STATE(8345),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7610),
    [sym_package_scope] = STATE(12242),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5356),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13485),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11650),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11654),
    [anon_sym_DOLLARroot] = ACTIONS(11656),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5356] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(17606),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8843),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8843),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19970),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8543),
    [sym_class_qualifier] = STATE(12509),
    [sym_primary_literal] = STATE(8835),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(8345),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7610),
    [sym_package_scope] = STATE(12242),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13485),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11650),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(5975),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11652),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(5985),
    [anon_sym_randomize] = ACTIONS(5987),
    [anon_sym_null] = ACTIONS(5989),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11654),
    [anon_sym_DOLLARroot] = ACTIONS(11656),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5357] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7157),
    [sym_package_scope] = STATE(12264),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5358] = {
    [sym_simple_text_macro_usage] = STATE(6693),
    [sym_casting_type] = STATE(19234),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(6727),
    [sym_sequence_instance] = STATE(20430),
    [sym_let_expression] = STATE(6727),
    [sym_assignment_pattern] = STATE(6733),
    [sym_assignment_pattern_expression] = STATE(6727),
    [sym__assignment_pattern_expression_type] = STATE(16917),
    [sym_concatenation] = STATE(6659),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(6659),
    [sym_streaming_concatenation] = STATE(6727),
    [sym_empty_unpacked_array_concatenation] = STATE(6727),
    [sym_tf_call] = STATE(6736),
    [sym_system_tf_call] = STATE(6736),
    [sym_subroutine_call] = STATE(6737),
    [sym_function_subroutine_call] = STATE(6727),
    [sym_method_call] = STATE(6736),
    [sym_randomize_call] = STATE(6736),
    [sym__method_call_root] = STATE(18776),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(6813),
    [sym_class_qualifier] = STATE(12594),
    [sym_primary_literal] = STATE(7112),
    [sym_time_literal] = STATE(6693),
    [sym_string_literal] = STATE(6693),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(6727),
    [sym__number] = STATE(6693),
    [sym_integral_number] = STATE(6693),
    [sym_decimal_number] = STATE(6682),
    [sym_real_number] = STATE(6693),
    [sym_unbased_unsized_literal] = STATE(6693),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(5853),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(5765),
    [sym_package_scope] = STATE(12443),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13314),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11572),
    [anon_sym_DQUOTE] = ACTIONS(2642),
    [anon_sym_LPAREN] = ACTIONS(11574),
    [anon_sym_BQUOTE] = ACTIONS(2650),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11576),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(2660),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11578),
    [anon_sym_std] = ACTIONS(2666),
    [anon_sym_randomize] = ACTIONS(2668),
    [anon_sym_null] = ACTIONS(6557),
    [anon_sym_this] = ACTIONS(2672),
    [aux_sym_decimal_number_token1] = ACTIONS(2676),
    [aux_sym_decimal_number_token2] = ACTIONS(2676),
    [sym_binary_number] = ACTIONS(2678),
    [sym_octal_number] = ACTIONS(2678),
    [sym_hex_number] = ACTIONS(2678),
    [aux_sym_real_number_token1] = ACTIONS(2680),
    [sym_fixed_point_number] = ACTIONS(2682),
    [sym_unsigned_number] = ACTIONS(2684),
    [anon_sym_SQUOTE0] = ACTIONS(2686),
    [anon_sym_SQUOTE1] = ACTIONS(2686),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(2686),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11580),
    [anon_sym_DOLLARroot] = ACTIONS(11582),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2692),
  },
  [5359] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5360),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7814),
    [sym_package_scope] = STATE(11990),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5360),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5360] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(9299),
    [sym_primary] = STATE(7251),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(7925),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(4733),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7814),
    [sym_package_scope] = STATE(11990),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(4733),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7063),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5361] = {
    [sym_simple_text_macro_usage] = STATE(7163),
    [sym_casting_type] = STATE(17763),
    [sym_class_scope] = STATE(13648),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(7174),
    [sym_sequence_instance] = STATE(18528),
    [sym_let_expression] = STATE(7174),
    [sym_assignment_pattern] = STATE(7185),
    [sym_assignment_pattern_expression] = STATE(7174),
    [sym__assignment_pattern_expression_type] = STATE(16859),
    [sym_concatenation] = STATE(8365),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8365),
    [sym_streaming_concatenation] = STATE(7174),
    [sym_empty_unpacked_array_concatenation] = STATE(7174),
    [sym_tf_call] = STATE(7191),
    [sym_system_tf_call] = STATE(7191),
    [sym_subroutine_call] = STATE(7205),
    [sym_function_subroutine_call] = STATE(7174),
    [sym_method_call] = STATE(7191),
    [sym_randomize_call] = STATE(7191),
    [sym__method_call_root] = STATE(19236),
    [sym_constant_primary] = STATE(9215),
    [sym_primary] = STATE(7335),
    [sym_class_qualifier] = STATE(12495),
    [sym_primary_literal] = STATE(8488),
    [sym_time_literal] = STATE(7163),
    [sym_string_literal] = STATE(7163),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(7174),
    [sym__number] = STATE(7163),
    [sym_integral_number] = STATE(7163),
    [sym_decimal_number] = STATE(7150),
    [sym_real_number] = STATE(7163),
    [sym_unbased_unsized_literal] = STATE(7163),
    [sym_attribute_instance] = STATE(5357),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7157),
    [sym_package_scope] = STATE(12264),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5357),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13274),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12502),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(3437),
    [anon_sym_LPAREN] = ACTIONS(11598),
    [anon_sym_BQUOTE] = ACTIONS(4146),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11634),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(3447),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11204),
    [anon_sym_std] = ACTIONS(4152),
    [anon_sym_randomize] = ACTIONS(4154),
    [anon_sym_null] = ACTIONS(7055),
    [anon_sym_this] = ACTIONS(3457),
    [aux_sym_decimal_number_token1] = ACTIONS(3459),
    [aux_sym_decimal_number_token2] = ACTIONS(3459),
    [sym_binary_number] = ACTIONS(3461),
    [sym_octal_number] = ACTIONS(3461),
    [sym_hex_number] = ACTIONS(3461),
    [aux_sym_real_number_token1] = ACTIONS(3463),
    [sym_fixed_point_number] = ACTIONS(3465),
    [sym_unsigned_number] = ACTIONS(3467),
    [anon_sym_SQUOTE0] = ACTIONS(3469),
    [anon_sym_SQUOTE1] = ACTIONS(3469),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(3469),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11636),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(2231),
  },
  [5362] = {
    [sym_simple_text_macro_usage] = STATE(8492),
    [sym_casting_type] = STATE(19999),
    [sym_class_scope] = STATE(13728),
    [sym_class_type] = STATE(19534),
    [sym__integer_type] = STATE(17639),
    [sym_integer_atom_type] = STATE(15263),
    [sym_integer_vector_type] = STATE(17639),
    [sym_non_integer_type] = STATE(17639),
    [sym__signing] = STATE(17639),
    [sym__simple_type] = STATE(17639),
    [sym_type_reference] = STATE(9090),
    [sym_sequence_method_call] = STATE(8619),
    [sym_sequence_instance] = STATE(20398),
    [sym_let_expression] = STATE(8619),
    [sym_assignment_pattern] = STATE(8630),
    [sym_assignment_pattern_expression] = STATE(8619),
    [sym__assignment_pattern_expression_type] = STATE(17014),
    [sym_concatenation] = STATE(8672),
    [sym_constant_concatenation] = STATE(8334),
    [sym_constant_multiple_concatenation] = STATE(8334),
    [sym_multiple_concatenation] = STATE(8672),
    [sym_streaming_concatenation] = STATE(8619),
    [sym_empty_unpacked_array_concatenation] = STATE(8619),
    [sym_tf_call] = STATE(8643),
    [sym_system_tf_call] = STATE(8643),
    [sym_subroutine_call] = STATE(8651),
    [sym_function_subroutine_call] = STATE(8619),
    [sym_method_call] = STATE(8643),
    [sym_randomize_call] = STATE(8643),
    [sym__method_call_root] = STATE(19951),
    [sym_constant_primary] = STATE(17639),
    [sym_primary] = STATE(8576),
    [sym_class_qualifier] = STATE(12553),
    [sym_primary_literal] = STATE(8641),
    [sym_time_literal] = STATE(8492),
    [sym_string_literal] = STATE(8492),
    [sym_implicit_class_handle] = STATE(17735),
    [sym_cast] = STATE(8619),
    [sym__number] = STATE(8492),
    [sym_integral_number] = STATE(8492),
    [sym_decimal_number] = STATE(8459),
    [sym_real_number] = STATE(8492),
    [sym_unbased_unsized_literal] = STATE(8492),
    [sym_attribute_instance] = STATE(5339),
    [sym_escaped_identifier] = STATE(4313),
    [sym_generate_block_identifier] = STATE(16838),
    [sym__identifier] = STATE(7425),
    [sym_package_scope] = STATE(11975),
    [sym__sequence_identifier] = STATE(10689),
    [aux_sym__description_repeat1] = STATE(5339),
    [aux_sym_hierarchical_identifier_repeat1] = STATE(13129),
    [aux_sym_ps_parameter_identifier_repeat1] = STATE(12504),
    [sym_simple_identifier] = ACTIONS(11606),
    [anon_sym_DQUOTE] = ACTIONS(5971),
    [anon_sym_LPAREN] = ACTIONS(11608),
    [anon_sym_BQUOTE] = ACTIONS(6331),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(11610),
    [anon_sym_const] = ACTIONS(2654),
    [anon_sym_local] = ACTIONS(2656),
    [anon_sym_super] = ACTIONS(2147),
    [anon_sym_string] = ACTIONS(2654),
    [anon_sym_byte] = ACTIONS(95),
    [anon_sym_shortint] = ACTIONS(95),
    [anon_sym_int] = ACTIONS(95),
    [anon_sym_longint] = ACTIONS(95),
    [anon_sym_integer] = ACTIONS(95),
    [anon_sym_time] = ACTIONS(95),
    [anon_sym_bit] = ACTIONS(97),
    [anon_sym_logic] = ACTIONS(97),
    [anon_sym_reg] = ACTIONS(97),
    [anon_sym_shortreal] = ACTIONS(99),
    [anon_sym_real] = ACTIONS(99),
    [anon_sym_realtime] = ACTIONS(99),
    [anon_sym_signed] = ACTIONS(2654),
    [anon_sym_unsigned] = ACTIONS(2654),
    [anon_sym_DOLLAR] = ACTIONS(5981),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11612),
    [anon_sym_std] = ACTIONS(6337),
    [anon_sym_randomize] = ACTIONS(6339),
    [anon_sym_null] = ACTIONS(6341),
    [anon_sym_this] = ACTIONS(5991),
    [aux_sym_decimal_number_token1] = ACTIONS(5993),
    [aux_sym_decimal_number_token2] = ACTIONS(5993),
    [sym_binary_number] = ACTIONS(5995),
    [sym_octal_number] = ACTIONS(5995),
    [sym_hex_number] = ACTIONS(5995),
    [aux_sym_real_number_token1] = ACTIONS(5997),
    [sym_fixed_point_number] = ACTIONS(5999),
    [sym_unsigned_number] = ACTIONS(6001),
    [anon_sym_SQUOTE0] = ACTIONS(6003),
    [anon_sym_SQUOTE1] = ACTIONS(6003),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(6003),
    [anon_sym_LPAREN_STAR] = ACTIONS(7039),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11614),
    [anon_sym_DOLLARroot] = ACTIONS(11616),
    [anon_sym_DOLLARunit] = ACTIONS(2229),
    [sym_system_tf_identifier] = ACTIONS(6009),
  },
  [5363] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5476),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11658),
    [anon_sym_DQUOTE] = ACTIONS(11660),
    [anon_sym_LT] = ACTIONS(11658),
    [anon_sym_GT] = ACTIONS(11658),
    [anon_sym_LPAREN] = ACTIONS(11658),
    [anon_sym_RPAREN] = ACTIONS(11660),
    [anon_sym_COMMA] = ACTIONS(11660),
    [anon_sym_BQUOTE] = ACTIONS(11660),
    [anon_sym_SLASH] = ACTIONS(11658),
    [anon_sym_COLON] = ACTIONS(11660),
    [anon_sym_type] = ACTIONS(11658),
    [anon_sym_DOT] = ACTIONS(11660),
    [anon_sym_LBRACE] = ACTIONS(11660),
    [anon_sym_const] = ACTIONS(11658),
    [anon_sym_local] = ACTIONS(11658),
    [anon_sym_super] = ACTIONS(11658),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11658),
    [anon_sym_string] = ACTIONS(11658),
    [anon_sym_byte] = ACTIONS(11658),
    [anon_sym_shortint] = ACTIONS(11658),
    [anon_sym_int] = ACTIONS(11658),
    [anon_sym_longint] = ACTIONS(11658),
    [anon_sym_integer] = ACTIONS(11658),
    [anon_sym_time] = ACTIONS(11658),
    [anon_sym_bit] = ACTIONS(11658),
    [anon_sym_logic] = ACTIONS(11658),
    [anon_sym_reg] = ACTIONS(11658),
    [anon_sym_shortreal] = ACTIONS(11658),
    [anon_sym_real] = ACTIONS(11658),
    [anon_sym_realtime] = ACTIONS(11658),
    [anon_sym_signed] = ACTIONS(11658),
    [anon_sym_unsigned] = ACTIONS(11658),
    [anon_sym_tagged] = ACTIONS(11658),
    [anon_sym_DOLLAR] = ACTIONS(11658),
    [anon_sym_PLUS] = ACTIONS(11658),
    [anon_sym_PLUS_PLUS] = ACTIONS(11662),
    [anon_sym_STAR_STAR] = ACTIONS(11660),
    [anon_sym_PERCENT] = ACTIONS(11660),
    [anon_sym_EQ_EQ] = ACTIONS(11658),
    [anon_sym_BANG_EQ] = ACTIONS(11658),
    [anon_sym_LT_EQ] = ACTIONS(11660),
    [anon_sym_GT_EQ] = ACTIONS(11660),
    [anon_sym_BANG] = ACTIONS(11658),
    [anon_sym_AMP_AMP] = ACTIONS(11658),
    [anon_sym_PIPE_PIPE] = ACTIONS(11660),
    [anon_sym_matches] = ACTIONS(11658),
    [anon_sym_DASH] = ACTIONS(11658),
    [anon_sym_DASH_GT] = ACTIONS(11660),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11660),
    [anon_sym_inside] = ACTIONS(11658),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11660),
    [anon_sym_TILDE] = ACTIONS(11658),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11660),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11660),
    [anon_sym_GT_GT] = ACTIONS(11658),
    [anon_sym_LT_LT] = ACTIONS(11658),
    [anon_sym_std] = ACTIONS(11658),
    [anon_sym_randomize] = ACTIONS(11658),
    [anon_sym_null] = ACTIONS(11658),
    [anon_sym_QMARK] = ACTIONS(11660),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_AMP] = ACTIONS(11658),
    [anon_sym_PIPE] = ACTIONS(11658),
    [anon_sym_CARET] = ACTIONS(11658),
    [anon_sym_CARET_TILDE] = ACTIONS(11660),
    [anon_sym_TILDE_CARET] = ACTIONS(11660),
    [anon_sym_GT_GT_GT] = ACTIONS(11660),
    [anon_sym_LT_LT_LT] = ACTIONS(11660),
    [anon_sym_LT_DASH_GT] = ACTIONS(11660),
    [anon_sym_this] = ACTIONS(11658),
    [anon_sym_TILDE_AMP] = ACTIONS(11660),
    [anon_sym_TILDE_PIPE] = ACTIONS(11660),
    [anon_sym_DASH_DASH] = ACTIONS(11662),
    [aux_sym_decimal_number_token1] = ACTIONS(11660),
    [aux_sym_decimal_number_token2] = ACTIONS(11660),
    [sym_binary_number] = ACTIONS(11660),
    [sym_octal_number] = ACTIONS(11660),
    [sym_hex_number] = ACTIONS(11660),
    [aux_sym_real_number_token1] = ACTIONS(11660),
    [sym_fixed_point_number] = ACTIONS(11658),
    [sym_unsigned_number] = ACTIONS(11658),
    [anon_sym_SQUOTE0] = ACTIONS(11660),
    [anon_sym_SQUOTE1] = ACTIONS(11660),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11660),
    [anon_sym_LPAREN_STAR] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11660),
    [anon_sym_DOLLARroot] = ACTIONS(11658),
    [anon_sym_DOLLARunit] = ACTIONS(11658),
    [sym_system_tf_identifier] = ACTIONS(11658),
  },
  [5364] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5477),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11665),
    [anon_sym_DQUOTE] = ACTIONS(11667),
    [anon_sym_LT] = ACTIONS(11665),
    [anon_sym_GT] = ACTIONS(11665),
    [anon_sym_LPAREN] = ACTIONS(11665),
    [anon_sym_RPAREN] = ACTIONS(11667),
    [anon_sym_COMMA] = ACTIONS(11667),
    [anon_sym_BQUOTE] = ACTIONS(11667),
    [anon_sym_SLASH] = ACTIONS(11665),
    [anon_sym_COLON] = ACTIONS(11667),
    [anon_sym_type] = ACTIONS(11665),
    [anon_sym_DOT] = ACTIONS(11667),
    [anon_sym_LBRACE] = ACTIONS(11667),
    [anon_sym_const] = ACTIONS(11665),
    [anon_sym_local] = ACTIONS(11665),
    [anon_sym_super] = ACTIONS(11665),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11665),
    [anon_sym_string] = ACTIONS(11665),
    [anon_sym_byte] = ACTIONS(11665),
    [anon_sym_shortint] = ACTIONS(11665),
    [anon_sym_int] = ACTIONS(11665),
    [anon_sym_longint] = ACTIONS(11665),
    [anon_sym_integer] = ACTIONS(11665),
    [anon_sym_time] = ACTIONS(11665),
    [anon_sym_bit] = ACTIONS(11665),
    [anon_sym_logic] = ACTIONS(11665),
    [anon_sym_reg] = ACTIONS(11665),
    [anon_sym_shortreal] = ACTIONS(11665),
    [anon_sym_real] = ACTIONS(11665),
    [anon_sym_realtime] = ACTIONS(11665),
    [anon_sym_signed] = ACTIONS(11665),
    [anon_sym_unsigned] = ACTIONS(11665),
    [anon_sym_tagged] = ACTIONS(11665),
    [anon_sym_DOLLAR] = ACTIONS(11665),
    [anon_sym_PLUS] = ACTIONS(11665),
    [anon_sym_PLUS_PLUS] = ACTIONS(11669),
    [anon_sym_STAR_STAR] = ACTIONS(11667),
    [anon_sym_PERCENT] = ACTIONS(11667),
    [anon_sym_EQ_EQ] = ACTIONS(11665),
    [anon_sym_BANG_EQ] = ACTIONS(11665),
    [anon_sym_LT_EQ] = ACTIONS(11667),
    [anon_sym_GT_EQ] = ACTIONS(11667),
    [anon_sym_BANG] = ACTIONS(11665),
    [anon_sym_AMP_AMP] = ACTIONS(11665),
    [anon_sym_PIPE_PIPE] = ACTIONS(11667),
    [anon_sym_matches] = ACTIONS(11665),
    [anon_sym_DASH] = ACTIONS(11665),
    [anon_sym_DASH_GT] = ACTIONS(11667),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11667),
    [anon_sym_inside] = ACTIONS(11665),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11667),
    [anon_sym_TILDE] = ACTIONS(11665),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11667),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11667),
    [anon_sym_GT_GT] = ACTIONS(11665),
    [anon_sym_LT_LT] = ACTIONS(11665),
    [anon_sym_std] = ACTIONS(11665),
    [anon_sym_randomize] = ACTIONS(11665),
    [anon_sym_null] = ACTIONS(11665),
    [anon_sym_QMARK] = ACTIONS(11667),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_AMP] = ACTIONS(11665),
    [anon_sym_PIPE] = ACTIONS(11665),
    [anon_sym_CARET] = ACTIONS(11665),
    [anon_sym_CARET_TILDE] = ACTIONS(11667),
    [anon_sym_TILDE_CARET] = ACTIONS(11667),
    [anon_sym_GT_GT_GT] = ACTIONS(11667),
    [anon_sym_LT_LT_LT] = ACTIONS(11667),
    [anon_sym_LT_DASH_GT] = ACTIONS(11667),
    [anon_sym_this] = ACTIONS(11665),
    [anon_sym_TILDE_AMP] = ACTIONS(11667),
    [anon_sym_TILDE_PIPE] = ACTIONS(11667),
    [anon_sym_DASH_DASH] = ACTIONS(11669),
    [aux_sym_decimal_number_token1] = ACTIONS(11667),
    [aux_sym_decimal_number_token2] = ACTIONS(11667),
    [sym_binary_number] = ACTIONS(11667),
    [sym_octal_number] = ACTIONS(11667),
    [sym_hex_number] = ACTIONS(11667),
    [aux_sym_real_number_token1] = ACTIONS(11667),
    [sym_fixed_point_number] = ACTIONS(11665),
    [sym_unsigned_number] = ACTIONS(11665),
    [anon_sym_SQUOTE0] = ACTIONS(11667),
    [anon_sym_SQUOTE1] = ACTIONS(11667),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11667),
    [anon_sym_LPAREN_STAR] = ACTIONS(11672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11667),
    [anon_sym_DOLLARroot] = ACTIONS(11665),
    [anon_sym_DOLLARunit] = ACTIONS(11665),
    [sym_system_tf_identifier] = ACTIONS(11665),
  },
  [5365] = {
    [sym_bit_select1] = STATE(5396),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [sym_simple_identifier] = ACTIONS(11674),
    [anon_sym_DQUOTE] = ACTIONS(11676),
    [anon_sym_LT] = ACTIONS(11674),
    [anon_sym_GT] = ACTIONS(11674),
    [anon_sym_LPAREN] = ACTIONS(11674),
    [anon_sym_RPAREN] = ACTIONS(11676),
    [anon_sym_COMMA] = ACTIONS(11676),
    [anon_sym_BQUOTE] = ACTIONS(11676),
    [anon_sym_SLASH] = ACTIONS(11674),
    [anon_sym_SEMI] = ACTIONS(11676),
    [anon_sym_COLON] = ACTIONS(11676),
    [anon_sym_type] = ACTIONS(11674),
    [anon_sym_DOT] = ACTIONS(11676),
    [anon_sym_LBRACE] = ACTIONS(11676),
    [anon_sym_RBRACE] = ACTIONS(11676),
    [anon_sym_iff] = ACTIONS(11674),
    [anon_sym_const] = ACTIONS(11674),
    [anon_sym_local] = ACTIONS(11674),
    [anon_sym_super] = ACTIONS(11674),
    [anon_sym_LBRACK] = ACTIONS(11678),
    [anon_sym_STAR] = ACTIONS(11674),
    [anon_sym_with] = ACTIONS(11674),
    [anon_sym_string] = ACTIONS(11674),
    [anon_sym_byte] = ACTIONS(11674),
    [anon_sym_shortint] = ACTIONS(11674),
    [anon_sym_int] = ACTIONS(11674),
    [anon_sym_longint] = ACTIONS(11674),
    [anon_sym_integer] = ACTIONS(11674),
    [anon_sym_time] = ACTIONS(11674),
    [anon_sym_bit] = ACTIONS(11674),
    [anon_sym_logic] = ACTIONS(11674),
    [anon_sym_reg] = ACTIONS(11674),
    [anon_sym_shortreal] = ACTIONS(11674),
    [anon_sym_real] = ACTIONS(11674),
    [anon_sym_realtime] = ACTIONS(11674),
    [anon_sym_signed] = ACTIONS(11674),
    [anon_sym_unsigned] = ACTIONS(11674),
    [anon_sym_tagged] = ACTIONS(11674),
    [anon_sym_DOLLAR] = ACTIONS(11674),
    [anon_sym_PLUS] = ACTIONS(11674),
    [anon_sym_PLUS_PLUS] = ACTIONS(11676),
    [anon_sym_STAR_STAR] = ACTIONS(11676),
    [anon_sym_PERCENT] = ACTIONS(11676),
    [anon_sym_EQ_EQ] = ACTIONS(11674),
    [anon_sym_BANG_EQ] = ACTIONS(11674),
    [anon_sym_LT_EQ] = ACTIONS(11676),
    [anon_sym_GT_EQ] = ACTIONS(11676),
    [anon_sym_BANG] = ACTIONS(11674),
    [anon_sym_AMP_AMP] = ACTIONS(11674),
    [anon_sym_PIPE_PIPE] = ACTIONS(11676),
    [anon_sym_matches] = ACTIONS(11674),
    [anon_sym_DASH] = ACTIONS(11674),
    [anon_sym_DASH_GT] = ACTIONS(11676),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11676),
    [anon_sym_inside] = ACTIONS(11674),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11676),
    [anon_sym_TILDE] = ACTIONS(11674),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11676),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11676),
    [anon_sym_GT_GT] = ACTIONS(11674),
    [anon_sym_LT_LT] = ACTIONS(11674),
    [anon_sym_std] = ACTIONS(11674),
    [anon_sym_randomize] = ACTIONS(11674),
    [anon_sym_null] = ACTIONS(11674),
    [anon_sym_QMARK] = ACTIONS(11676),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11676),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11676),
    [anon_sym_AMP] = ACTIONS(11674),
    [anon_sym_PIPE] = ACTIONS(11674),
    [anon_sym_CARET] = ACTIONS(11674),
    [anon_sym_CARET_TILDE] = ACTIONS(11676),
    [anon_sym_TILDE_CARET] = ACTIONS(11676),
    [anon_sym_GT_GT_GT] = ACTIONS(11676),
    [anon_sym_LT_LT_LT] = ACTIONS(11676),
    [anon_sym_LT_DASH_GT] = ACTIONS(11676),
    [anon_sym_this] = ACTIONS(11674),
    [anon_sym_TILDE_AMP] = ACTIONS(11676),
    [anon_sym_TILDE_PIPE] = ACTIONS(11676),
    [anon_sym_DASH_DASH] = ACTIONS(11676),
    [aux_sym_decimal_number_token1] = ACTIONS(11676),
    [aux_sym_decimal_number_token2] = ACTIONS(11676),
    [sym_binary_number] = ACTIONS(11676),
    [sym_octal_number] = ACTIONS(11676),
    [sym_hex_number] = ACTIONS(11676),
    [aux_sym_real_number_token1] = ACTIONS(11676),
    [sym_fixed_point_number] = ACTIONS(11674),
    [sym_unsigned_number] = ACTIONS(11674),
    [anon_sym_SQUOTE0] = ACTIONS(11676),
    [anon_sym_SQUOTE1] = ACTIONS(11676),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11676),
    [anon_sym_LPAREN_STAR] = ACTIONS(11676),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11676),
    [anon_sym_DOLLARroot] = ACTIONS(11674),
    [anon_sym_DOLLARunit] = ACTIONS(11674),
    [sym_system_tf_identifier] = ACTIONS(11674),
  },
  [5366] = {
    [sym_bit_select1] = STATE(5398),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [sym_simple_identifier] = ACTIONS(11680),
    [anon_sym_DQUOTE] = ACTIONS(11682),
    [anon_sym_LT] = ACTIONS(11680),
    [anon_sym_GT] = ACTIONS(11680),
    [anon_sym_LPAREN] = ACTIONS(11680),
    [anon_sym_RPAREN] = ACTIONS(11682),
    [anon_sym_COMMA] = ACTIONS(11682),
    [anon_sym_BQUOTE] = ACTIONS(11682),
    [anon_sym_SLASH] = ACTIONS(11680),
    [anon_sym_SEMI] = ACTIONS(11682),
    [anon_sym_COLON] = ACTIONS(11682),
    [anon_sym_type] = ACTIONS(11680),
    [anon_sym_DOT] = ACTIONS(11682),
    [anon_sym_LBRACE] = ACTIONS(11682),
    [anon_sym_RBRACE] = ACTIONS(11682),
    [anon_sym_iff] = ACTIONS(11680),
    [anon_sym_const] = ACTIONS(11680),
    [anon_sym_local] = ACTIONS(11680),
    [anon_sym_super] = ACTIONS(11680),
    [anon_sym_LBRACK] = ACTIONS(11684),
    [anon_sym_STAR] = ACTIONS(11680),
    [anon_sym_with] = ACTIONS(11680),
    [anon_sym_string] = ACTIONS(11680),
    [anon_sym_byte] = ACTIONS(11680),
    [anon_sym_shortint] = ACTIONS(11680),
    [anon_sym_int] = ACTIONS(11680),
    [anon_sym_longint] = ACTIONS(11680),
    [anon_sym_integer] = ACTIONS(11680),
    [anon_sym_time] = ACTIONS(11680),
    [anon_sym_bit] = ACTIONS(11680),
    [anon_sym_logic] = ACTIONS(11680),
    [anon_sym_reg] = ACTIONS(11680),
    [anon_sym_shortreal] = ACTIONS(11680),
    [anon_sym_real] = ACTIONS(11680),
    [anon_sym_realtime] = ACTIONS(11680),
    [anon_sym_signed] = ACTIONS(11680),
    [anon_sym_unsigned] = ACTIONS(11680),
    [anon_sym_tagged] = ACTIONS(11680),
    [anon_sym_DOLLAR] = ACTIONS(11680),
    [anon_sym_PLUS] = ACTIONS(11680),
    [anon_sym_PLUS_PLUS] = ACTIONS(11682),
    [anon_sym_STAR_STAR] = ACTIONS(11682),
    [anon_sym_PERCENT] = ACTIONS(11682),
    [anon_sym_EQ_EQ] = ACTIONS(11680),
    [anon_sym_BANG_EQ] = ACTIONS(11680),
    [anon_sym_LT_EQ] = ACTIONS(11682),
    [anon_sym_GT_EQ] = ACTIONS(11682),
    [anon_sym_BANG] = ACTIONS(11680),
    [anon_sym_AMP_AMP] = ACTIONS(11680),
    [anon_sym_PIPE_PIPE] = ACTIONS(11682),
    [anon_sym_matches] = ACTIONS(11680),
    [anon_sym_DASH] = ACTIONS(11680),
    [anon_sym_DASH_GT] = ACTIONS(11682),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11682),
    [anon_sym_inside] = ACTIONS(11680),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11682),
    [anon_sym_TILDE] = ACTIONS(11680),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11682),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11682),
    [anon_sym_GT_GT] = ACTIONS(11680),
    [anon_sym_LT_LT] = ACTIONS(11680),
    [anon_sym_std] = ACTIONS(11680),
    [anon_sym_randomize] = ACTIONS(11680),
    [anon_sym_null] = ACTIONS(11680),
    [anon_sym_QMARK] = ACTIONS(11682),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11682),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11682),
    [anon_sym_AMP] = ACTIONS(11680),
    [anon_sym_PIPE] = ACTIONS(11680),
    [anon_sym_CARET] = ACTIONS(11680),
    [anon_sym_CARET_TILDE] = ACTIONS(11682),
    [anon_sym_TILDE_CARET] = ACTIONS(11682),
    [anon_sym_GT_GT_GT] = ACTIONS(11682),
    [anon_sym_LT_LT_LT] = ACTIONS(11682),
    [anon_sym_LT_DASH_GT] = ACTIONS(11682),
    [anon_sym_this] = ACTIONS(11680),
    [anon_sym_TILDE_AMP] = ACTIONS(11682),
    [anon_sym_TILDE_PIPE] = ACTIONS(11682),
    [anon_sym_DASH_DASH] = ACTIONS(11682),
    [aux_sym_decimal_number_token1] = ACTIONS(11682),
    [aux_sym_decimal_number_token2] = ACTIONS(11682),
    [sym_binary_number] = ACTIONS(11682),
    [sym_octal_number] = ACTIONS(11682),
    [sym_hex_number] = ACTIONS(11682),
    [aux_sym_real_number_token1] = ACTIONS(11682),
    [sym_fixed_point_number] = ACTIONS(11680),
    [sym_unsigned_number] = ACTIONS(11680),
    [anon_sym_SQUOTE0] = ACTIONS(11682),
    [anon_sym_SQUOTE1] = ACTIONS(11682),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11682),
    [anon_sym_LPAREN_STAR] = ACTIONS(11682),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11682),
    [anon_sym_DOLLARroot] = ACTIONS(11680),
    [anon_sym_DOLLARunit] = ACTIONS(11680),
    [sym_system_tf_identifier] = ACTIONS(11680),
  },
  [5367] = {
    [sym_simple_identifier] = ACTIONS(11686),
    [anon_sym_DQUOTE] = ACTIONS(11688),
    [anon_sym_LT] = ACTIONS(11690),
    [anon_sym_GT] = ACTIONS(11690),
    [anon_sym_LPAREN] = ACTIONS(11688),
    [anon_sym_BQUOTE] = ACTIONS(11688),
    [anon_sym_SLASH] = ACTIONS(11690),
    [anon_sym_SEMI] = ACTIONS(11692),
    [anon_sym_type] = ACTIONS(11686),
    [anon_sym_DOT] = ACTIONS(11692),
    [anon_sym_LBRACE] = ACTIONS(11688),
    [anon_sym_RBRACE] = ACTIONS(11688),
    [anon_sym_disable] = ACTIONS(11686),
    [anon_sym_const] = ACTIONS(11686),
    [anon_sym_local] = ACTIONS(11686),
    [anon_sym_super] = ACTIONS(11686),
    [anon_sym_solve] = ACTIONS(11686),
    [anon_sym_soft] = ACTIONS(11686),
    [anon_sym_u2013_GT] = ACTIONS(11692),
    [anon_sym_if] = ACTIONS(11686),
    [anon_sym_else] = ACTIONS(11686),
    [anon_sym_foreach] = ACTIONS(11686),
    [anon_sym_unique] = ACTIONS(11686),
    [anon_sym_STAR] = ACTIONS(11690),
    [anon_sym_string] = ACTIONS(11686),
    [anon_sym_byte] = ACTIONS(11686),
    [anon_sym_shortint] = ACTIONS(11686),
    [anon_sym_int] = ACTIONS(11686),
    [anon_sym_longint] = ACTIONS(11686),
    [anon_sym_integer] = ACTIONS(11686),
    [anon_sym_time] = ACTIONS(11686),
    [anon_sym_bit] = ACTIONS(11686),
    [anon_sym_logic] = ACTIONS(11686),
    [anon_sym_reg] = ACTIONS(11686),
    [anon_sym_shortreal] = ACTIONS(11686),
    [anon_sym_real] = ACTIONS(11686),
    [anon_sym_realtime] = ACTIONS(11686),
    [anon_sym_signed] = ACTIONS(11686),
    [anon_sym_unsigned] = ACTIONS(11686),
    [anon_sym_tagged] = ACTIONS(11686),
    [anon_sym_DOLLAR] = ACTIONS(11686),
    [anon_sym_PLUS] = ACTIONS(11694),
    [anon_sym_PLUS_PLUS] = ACTIONS(11688),
    [anon_sym_STAR_STAR] = ACTIONS(11692),
    [anon_sym_PERCENT] = ACTIONS(11692),
    [anon_sym_EQ_EQ] = ACTIONS(11690),
    [anon_sym_BANG_EQ] = ACTIONS(11690),
    [anon_sym_LT_EQ] = ACTIONS(11692),
    [anon_sym_GT_EQ] = ACTIONS(11692),
    [anon_sym_dist] = ACTIONS(11690),
    [anon_sym_BANG] = ACTIONS(11686),
    [anon_sym_AMP_AMP] = ACTIONS(11690),
    [anon_sym_PIPE_PIPE] = ACTIONS(11692),
    [anon_sym_matches] = ACTIONS(11690),
    [anon_sym_DASH] = ACTIONS(11694),
    [anon_sym_DASH_GT] = ACTIONS(11692),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11692),
    [anon_sym_inside] = ACTIONS(11690),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11688),
    [anon_sym_TILDE] = ACTIONS(11686),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11692),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11692),
    [anon_sym_GT_GT] = ACTIONS(11690),
    [anon_sym_LT_LT] = ACTIONS(11690),
    [anon_sym_std] = ACTIONS(11686),
    [anon_sym_randomize] = ACTIONS(11686),
    [anon_sym_null] = ACTIONS(11686),
    [anon_sym_QMARK] = ACTIONS(11692),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11692),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11692),
    [anon_sym_AMP] = ACTIONS(11694),
    [anon_sym_PIPE] = ACTIONS(11694),
    [anon_sym_CARET] = ACTIONS(11694),
    [anon_sym_CARET_TILDE] = ACTIONS(11697),
    [anon_sym_TILDE_CARET] = ACTIONS(11697),
    [anon_sym_GT_GT_GT] = ACTIONS(11692),
    [anon_sym_LT_LT_LT] = ACTIONS(11692),
    [anon_sym_LT_DASH_GT] = ACTIONS(11692),
    [anon_sym_this] = ACTIONS(11686),
    [anon_sym_TILDE_AMP] = ACTIONS(11688),
    [anon_sym_TILDE_PIPE] = ACTIONS(11688),
    [anon_sym_DASH_DASH] = ACTIONS(11688),
    [aux_sym_decimal_number_token1] = ACTIONS(11688),
    [aux_sym_decimal_number_token2] = ACTIONS(11688),
    [sym_binary_number] = ACTIONS(11688),
    [sym_octal_number] = ACTIONS(11688),
    [sym_hex_number] = ACTIONS(11688),
    [aux_sym_real_number_token1] = ACTIONS(11688),
    [sym_fixed_point_number] = ACTIONS(11686),
    [sym_unsigned_number] = ACTIONS(11686),
    [anon_sym_SQUOTE0] = ACTIONS(11688),
    [anon_sym_SQUOTE1] = ACTIONS(11688),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11688),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11688),
    [anon_sym_DOLLARroot] = ACTIONS(11686),
    [anon_sym_DOLLARunit] = ACTIONS(11686),
    [sym_system_tf_identifier] = ACTIONS(11686),
  },
  [5368] = {
    [sym_time_unit] = STATE(5534),
    [sym_simple_identifier] = ACTIONS(11700),
    [anon_sym_DQUOTE] = ACTIONS(11702),
    [anon_sym_LT] = ACTIONS(11700),
    [anon_sym_GT] = ACTIONS(11700),
    [anon_sym_LPAREN] = ACTIONS(11702),
    [anon_sym_RPAREN] = ACTIONS(11702),
    [anon_sym_COMMA] = ACTIONS(11702),
    [anon_sym_BQUOTE] = ACTIONS(11702),
    [anon_sym_SLASH] = ACTIONS(11700),
    [anon_sym_COLON] = ACTIONS(11702),
    [anon_sym_type] = ACTIONS(11700),
    [anon_sym_DOT] = ACTIONS(11702),
    [anon_sym_LBRACE] = ACTIONS(11702),
    [anon_sym_const] = ACTIONS(11700),
    [anon_sym_local] = ACTIONS(11700),
    [anon_sym_super] = ACTIONS(11700),
    [anon_sym_STAR] = ACTIONS(11700),
    [anon_sym_string] = ACTIONS(11700),
    [anon_sym_byte] = ACTIONS(11700),
    [anon_sym_shortint] = ACTIONS(11700),
    [anon_sym_int] = ACTIONS(11700),
    [anon_sym_longint] = ACTIONS(11700),
    [anon_sym_integer] = ACTIONS(11700),
    [anon_sym_time] = ACTIONS(11700),
    [anon_sym_bit] = ACTIONS(11700),
    [anon_sym_logic] = ACTIONS(11700),
    [anon_sym_reg] = ACTIONS(11700),
    [anon_sym_shortreal] = ACTIONS(11700),
    [anon_sym_real] = ACTIONS(11700),
    [anon_sym_realtime] = ACTIONS(11700),
    [anon_sym_signed] = ACTIONS(11700),
    [anon_sym_unsigned] = ACTIONS(11700),
    [anon_sym_tagged] = ACTIONS(11700),
    [anon_sym_DOLLAR] = ACTIONS(11700),
    [anon_sym_PLUS] = ACTIONS(11700),
    [anon_sym_PLUS_PLUS] = ACTIONS(11702),
    [anon_sym_STAR_STAR] = ACTIONS(11702),
    [anon_sym_PERCENT] = ACTIONS(11702),
    [anon_sym_EQ_EQ] = ACTIONS(11700),
    [anon_sym_BANG_EQ] = ACTIONS(11700),
    [anon_sym_LT_EQ] = ACTIONS(11702),
    [anon_sym_GT_EQ] = ACTIONS(11702),
    [anon_sym_BANG] = ACTIONS(11700),
    [anon_sym_AMP_AMP] = ACTIONS(11700),
    [anon_sym_PIPE_PIPE] = ACTIONS(11702),
    [anon_sym_matches] = ACTIONS(11700),
    [anon_sym_DASH] = ACTIONS(11700),
    [anon_sym_DASH_GT] = ACTIONS(11702),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11702),
    [anon_sym_inside] = ACTIONS(11700),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11702),
    [anon_sym_TILDE] = ACTIONS(11700),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11702),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11702),
    [anon_sym_GT_GT] = ACTIONS(11700),
    [anon_sym_LT_LT] = ACTIONS(11700),
    [anon_sym_std] = ACTIONS(11700),
    [anon_sym_randomize] = ACTIONS(11700),
    [anon_sym_null] = ACTIONS(11700),
    [anon_sym_QMARK] = ACTIONS(11702),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11702),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11702),
    [anon_sym_AMP] = ACTIONS(11700),
    [anon_sym_PIPE] = ACTIONS(11700),
    [anon_sym_CARET] = ACTIONS(11700),
    [anon_sym_CARET_TILDE] = ACTIONS(11702),
    [anon_sym_TILDE_CARET] = ACTIONS(11702),
    [anon_sym_GT_GT_GT] = ACTIONS(11702),
    [anon_sym_LT_LT_LT] = ACTIONS(11702),
    [anon_sym_LT_DASH_GT] = ACTIONS(11702),
    [anon_sym_this] = ACTIONS(11700),
    [anon_sym_s] = ACTIONS(11704),
    [anon_sym_ms] = ACTIONS(11704),
    [anon_sym_us] = ACTIONS(11704),
    [anon_sym_ns] = ACTIONS(11704),
    [anon_sym_ps] = ACTIONS(11704),
    [anon_sym_fs] = ACTIONS(11704),
    [anon_sym_SQUOTE] = ACTIONS(11700),
    [anon_sym_TILDE_AMP] = ACTIONS(11702),
    [anon_sym_TILDE_PIPE] = ACTIONS(11702),
    [anon_sym_DASH_DASH] = ACTIONS(11702),
    [aux_sym_decimal_number_token1] = ACTIONS(11702),
    [aux_sym_decimal_number_token2] = ACTIONS(11702),
    [sym_binary_number] = ACTIONS(11702),
    [sym_octal_number] = ACTIONS(11702),
    [sym_hex_number] = ACTIONS(11702),
    [aux_sym_real_number_token1] = ACTIONS(11702),
    [sym_fixed_point_number] = ACTIONS(11700),
    [sym_unsigned_number] = ACTIONS(11700),
    [anon_sym_SQUOTE0] = ACTIONS(11702),
    [anon_sym_SQUOTE1] = ACTIONS(11702),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11702),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11702),
    [anon_sym_DOLLARroot] = ACTIONS(11700),
    [anon_sym_DOLLARunit] = ACTIONS(11700),
    [sym_system_tf_identifier] = ACTIONS(11700),
  },
  [5369] = {
    [sym_time_unit] = STATE(5534),
    [sym_simple_identifier] = ACTIONS(11706),
    [anon_sym_DQUOTE] = ACTIONS(11708),
    [anon_sym_LT] = ACTIONS(11706),
    [anon_sym_GT] = ACTIONS(11706),
    [anon_sym_LPAREN] = ACTIONS(11708),
    [anon_sym_RPAREN] = ACTIONS(11708),
    [anon_sym_COMMA] = ACTIONS(11708),
    [anon_sym_BQUOTE] = ACTIONS(11708),
    [anon_sym_SLASH] = ACTIONS(11706),
    [anon_sym_COLON] = ACTIONS(11708),
    [anon_sym_type] = ACTIONS(11706),
    [anon_sym_DOT] = ACTIONS(11708),
    [anon_sym_LBRACE] = ACTIONS(11708),
    [anon_sym_const] = ACTIONS(11706),
    [anon_sym_local] = ACTIONS(11706),
    [anon_sym_super] = ACTIONS(11706),
    [anon_sym_STAR] = ACTIONS(11706),
    [anon_sym_string] = ACTIONS(11706),
    [anon_sym_byte] = ACTIONS(11706),
    [anon_sym_shortint] = ACTIONS(11706),
    [anon_sym_int] = ACTIONS(11706),
    [anon_sym_longint] = ACTIONS(11706),
    [anon_sym_integer] = ACTIONS(11706),
    [anon_sym_time] = ACTIONS(11706),
    [anon_sym_bit] = ACTIONS(11706),
    [anon_sym_logic] = ACTIONS(11706),
    [anon_sym_reg] = ACTIONS(11706),
    [anon_sym_shortreal] = ACTIONS(11706),
    [anon_sym_real] = ACTIONS(11706),
    [anon_sym_realtime] = ACTIONS(11706),
    [anon_sym_signed] = ACTIONS(11706),
    [anon_sym_unsigned] = ACTIONS(11706),
    [anon_sym_tagged] = ACTIONS(11706),
    [anon_sym_DOLLAR] = ACTIONS(11706),
    [anon_sym_PLUS] = ACTIONS(11706),
    [anon_sym_PLUS_PLUS] = ACTIONS(11708),
    [anon_sym_STAR_STAR] = ACTIONS(11708),
    [anon_sym_PERCENT] = ACTIONS(11708),
    [anon_sym_EQ_EQ] = ACTIONS(11706),
    [anon_sym_BANG_EQ] = ACTIONS(11706),
    [anon_sym_LT_EQ] = ACTIONS(11708),
    [anon_sym_GT_EQ] = ACTIONS(11708),
    [anon_sym_BANG] = ACTIONS(11706),
    [anon_sym_AMP_AMP] = ACTIONS(11706),
    [anon_sym_PIPE_PIPE] = ACTIONS(11708),
    [anon_sym_matches] = ACTIONS(11706),
    [anon_sym_DASH] = ACTIONS(11706),
    [anon_sym_DASH_GT] = ACTIONS(11708),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11708),
    [anon_sym_inside] = ACTIONS(11706),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11708),
    [anon_sym_TILDE] = ACTIONS(11706),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11708),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11708),
    [anon_sym_GT_GT] = ACTIONS(11706),
    [anon_sym_LT_LT] = ACTIONS(11706),
    [anon_sym_std] = ACTIONS(11706),
    [anon_sym_randomize] = ACTIONS(11706),
    [anon_sym_null] = ACTIONS(11706),
    [anon_sym_QMARK] = ACTIONS(11708),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11708),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11708),
    [anon_sym_AMP] = ACTIONS(11706),
    [anon_sym_PIPE] = ACTIONS(11706),
    [anon_sym_CARET] = ACTIONS(11706),
    [anon_sym_CARET_TILDE] = ACTIONS(11708),
    [anon_sym_TILDE_CARET] = ACTIONS(11708),
    [anon_sym_GT_GT_GT] = ACTIONS(11708),
    [anon_sym_LT_LT_LT] = ACTIONS(11708),
    [anon_sym_LT_DASH_GT] = ACTIONS(11708),
    [anon_sym_this] = ACTIONS(11706),
    [anon_sym_s] = ACTIONS(11704),
    [anon_sym_ms] = ACTIONS(11704),
    [anon_sym_us] = ACTIONS(11704),
    [anon_sym_ns] = ACTIONS(11704),
    [anon_sym_ps] = ACTIONS(11704),
    [anon_sym_fs] = ACTIONS(11704),
    [anon_sym_SQUOTE] = ACTIONS(11706),
    [anon_sym_TILDE_AMP] = ACTIONS(11708),
    [anon_sym_TILDE_PIPE] = ACTIONS(11708),
    [anon_sym_DASH_DASH] = ACTIONS(11708),
    [aux_sym_decimal_number_token1] = ACTIONS(11708),
    [aux_sym_decimal_number_token2] = ACTIONS(11708),
    [sym_binary_number] = ACTIONS(11708),
    [sym_octal_number] = ACTIONS(11708),
    [sym_hex_number] = ACTIONS(11708),
    [aux_sym_real_number_token1] = ACTIONS(11708),
    [sym_fixed_point_number] = ACTIONS(11706),
    [sym_unsigned_number] = ACTIONS(11706),
    [anon_sym_SQUOTE0] = ACTIONS(11708),
    [anon_sym_SQUOTE1] = ACTIONS(11708),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11708),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11708),
    [anon_sym_DOLLARroot] = ACTIONS(11706),
    [anon_sym_DOLLARunit] = ACTIONS(11706),
    [sym_system_tf_identifier] = ACTIONS(11706),
  },
  [5370] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5463),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11710),
    [anon_sym_DQUOTE] = ACTIONS(11712),
    [anon_sym_LT] = ACTIONS(11710),
    [anon_sym_GT] = ACTIONS(11710),
    [anon_sym_LPAREN] = ACTIONS(11710),
    [anon_sym_RPAREN] = ACTIONS(11712),
    [anon_sym_COMMA] = ACTIONS(11712),
    [anon_sym_BQUOTE] = ACTIONS(11712),
    [anon_sym_SLASH] = ACTIONS(11710),
    [anon_sym_COLON] = ACTIONS(11712),
    [anon_sym_type] = ACTIONS(11710),
    [anon_sym_DOT] = ACTIONS(11712),
    [anon_sym_LBRACE] = ACTIONS(11712),
    [anon_sym_const] = ACTIONS(11710),
    [anon_sym_local] = ACTIONS(11710),
    [anon_sym_super] = ACTIONS(11710),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11710),
    [anon_sym_string] = ACTIONS(11710),
    [anon_sym_byte] = ACTIONS(11710),
    [anon_sym_shortint] = ACTIONS(11710),
    [anon_sym_int] = ACTIONS(11710),
    [anon_sym_longint] = ACTIONS(11710),
    [anon_sym_integer] = ACTIONS(11710),
    [anon_sym_time] = ACTIONS(11710),
    [anon_sym_bit] = ACTIONS(11710),
    [anon_sym_logic] = ACTIONS(11710),
    [anon_sym_reg] = ACTIONS(11710),
    [anon_sym_shortreal] = ACTIONS(11710),
    [anon_sym_real] = ACTIONS(11710),
    [anon_sym_realtime] = ACTIONS(11710),
    [anon_sym_signed] = ACTIONS(11710),
    [anon_sym_unsigned] = ACTIONS(11710),
    [anon_sym_tagged] = ACTIONS(11710),
    [anon_sym_DOLLAR] = ACTIONS(11710),
    [anon_sym_PLUS] = ACTIONS(11710),
    [anon_sym_PLUS_PLUS] = ACTIONS(11714),
    [anon_sym_STAR_STAR] = ACTIONS(11712),
    [anon_sym_PERCENT] = ACTIONS(11712),
    [anon_sym_EQ_EQ] = ACTIONS(11710),
    [anon_sym_BANG_EQ] = ACTIONS(11710),
    [anon_sym_LT_EQ] = ACTIONS(11712),
    [anon_sym_GT_EQ] = ACTIONS(11712),
    [anon_sym_BANG] = ACTIONS(11710),
    [anon_sym_AMP_AMP] = ACTIONS(11710),
    [anon_sym_PIPE_PIPE] = ACTIONS(11712),
    [anon_sym_matches] = ACTIONS(11710),
    [anon_sym_DASH] = ACTIONS(11710),
    [anon_sym_DASH_GT] = ACTIONS(11712),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11712),
    [anon_sym_inside] = ACTIONS(11710),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11712),
    [anon_sym_TILDE] = ACTIONS(11710),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11712),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11712),
    [anon_sym_GT_GT] = ACTIONS(11710),
    [anon_sym_LT_LT] = ACTIONS(11710),
    [anon_sym_std] = ACTIONS(11710),
    [anon_sym_randomize] = ACTIONS(11710),
    [anon_sym_null] = ACTIONS(11710),
    [anon_sym_QMARK] = ACTIONS(11712),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_AMP] = ACTIONS(11710),
    [anon_sym_PIPE] = ACTIONS(11710),
    [anon_sym_CARET] = ACTIONS(11710),
    [anon_sym_CARET_TILDE] = ACTIONS(11712),
    [anon_sym_TILDE_CARET] = ACTIONS(11712),
    [anon_sym_GT_GT_GT] = ACTIONS(11712),
    [anon_sym_LT_LT_LT] = ACTIONS(11712),
    [anon_sym_LT_DASH_GT] = ACTIONS(11712),
    [anon_sym_this] = ACTIONS(11710),
    [anon_sym_TILDE_AMP] = ACTIONS(11712),
    [anon_sym_TILDE_PIPE] = ACTIONS(11712),
    [anon_sym_DASH_DASH] = ACTIONS(11714),
    [aux_sym_decimal_number_token1] = ACTIONS(11712),
    [aux_sym_decimal_number_token2] = ACTIONS(11712),
    [sym_binary_number] = ACTIONS(11712),
    [sym_octal_number] = ACTIONS(11712),
    [sym_hex_number] = ACTIONS(11712),
    [aux_sym_real_number_token1] = ACTIONS(11712),
    [sym_fixed_point_number] = ACTIONS(11710),
    [sym_unsigned_number] = ACTIONS(11710),
    [anon_sym_SQUOTE0] = ACTIONS(11712),
    [anon_sym_SQUOTE1] = ACTIONS(11712),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11712),
    [anon_sym_LPAREN_STAR] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11712),
    [anon_sym_DOLLARroot] = ACTIONS(11710),
    [anon_sym_DOLLARunit] = ACTIONS(11710),
    [sym_system_tf_identifier] = ACTIONS(11710),
  },
  [5371] = {
    [sym_simple_identifier] = ACTIONS(11658),
    [anon_sym_DQUOTE] = ACTIONS(11660),
    [anon_sym_LT] = ACTIONS(11658),
    [anon_sym_GT] = ACTIONS(11658),
    [anon_sym_LPAREN] = ACTIONS(11658),
    [anon_sym_RPAREN] = ACTIONS(11660),
    [anon_sym_COMMA] = ACTIONS(11539),
    [anon_sym_BQUOTE] = ACTIONS(11660),
    [anon_sym_SLASH] = ACTIONS(11658),
    [anon_sym_SEMI] = ACTIONS(11660),
    [anon_sym_COLON] = ACTIONS(11660),
    [anon_sym_type] = ACTIONS(11658),
    [anon_sym_DOT] = ACTIONS(11660),
    [anon_sym_LBRACE] = ACTIONS(11660),
    [anon_sym_RBRACE] = ACTIONS(11539),
    [anon_sym_iff] = ACTIONS(11658),
    [anon_sym_const] = ACTIONS(11658),
    [anon_sym_local] = ACTIONS(11658),
    [anon_sym_super] = ACTIONS(11658),
    [anon_sym_u2013_GT] = ACTIONS(11660),
    [anon_sym_STAR] = ACTIONS(11658),
    [anon_sym_with] = ACTIONS(11658),
    [anon_sym_string] = ACTIONS(11658),
    [anon_sym_byte] = ACTIONS(11658),
    [anon_sym_shortint] = ACTIONS(11658),
    [anon_sym_int] = ACTIONS(11658),
    [anon_sym_longint] = ACTIONS(11658),
    [anon_sym_integer] = ACTIONS(11658),
    [anon_sym_time] = ACTIONS(11658),
    [anon_sym_bit] = ACTIONS(11658),
    [anon_sym_logic] = ACTIONS(11658),
    [anon_sym_reg] = ACTIONS(11658),
    [anon_sym_shortreal] = ACTIONS(11658),
    [anon_sym_real] = ACTIONS(11658),
    [anon_sym_realtime] = ACTIONS(11658),
    [anon_sym_signed] = ACTIONS(11658),
    [anon_sym_unsigned] = ACTIONS(11658),
    [anon_sym_tagged] = ACTIONS(11658),
    [anon_sym_DOLLAR] = ACTIONS(11658),
    [anon_sym_PLUS] = ACTIONS(11658),
    [anon_sym_PLUS_PLUS] = ACTIONS(11539),
    [anon_sym_STAR_STAR] = ACTIONS(11660),
    [anon_sym_PERCENT] = ACTIONS(11660),
    [anon_sym_EQ_EQ] = ACTIONS(11658),
    [anon_sym_BANG_EQ] = ACTIONS(11658),
    [anon_sym_LT_EQ] = ACTIONS(11660),
    [anon_sym_GT_EQ] = ACTIONS(11660),
    [anon_sym_dist] = ACTIONS(11658),
    [anon_sym_BANG] = ACTIONS(11658),
    [anon_sym_AMP_AMP] = ACTIONS(11658),
    [anon_sym_PIPE_PIPE] = ACTIONS(11660),
    [anon_sym_matches] = ACTIONS(11658),
    [anon_sym_DASH] = ACTIONS(11658),
    [anon_sym_DASH_GT] = ACTIONS(11660),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11660),
    [anon_sym_inside] = ACTIONS(11658),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11660),
    [anon_sym_TILDE] = ACTIONS(11658),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11660),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11660),
    [anon_sym_GT_GT] = ACTIONS(11658),
    [anon_sym_LT_LT] = ACTIONS(11658),
    [anon_sym_std] = ACTIONS(11658),
    [anon_sym_randomize] = ACTIONS(11658),
    [anon_sym_null] = ACTIONS(11658),
    [anon_sym_QMARK] = ACTIONS(11660),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_AMP] = ACTIONS(11658),
    [anon_sym_PIPE] = ACTIONS(11658),
    [anon_sym_CARET] = ACTIONS(11658),
    [anon_sym_CARET_TILDE] = ACTIONS(11660),
    [anon_sym_TILDE_CARET] = ACTIONS(11660),
    [anon_sym_GT_GT_GT] = ACTIONS(11660),
    [anon_sym_LT_LT_LT] = ACTIONS(11660),
    [anon_sym_LT_DASH_GT] = ACTIONS(11660),
    [anon_sym_this] = ACTIONS(11658),
    [anon_sym_TILDE_AMP] = ACTIONS(11660),
    [anon_sym_TILDE_PIPE] = ACTIONS(11660),
    [anon_sym_DASH_DASH] = ACTIONS(11539),
    [aux_sym_decimal_number_token1] = ACTIONS(11660),
    [aux_sym_decimal_number_token2] = ACTIONS(11660),
    [sym_binary_number] = ACTIONS(11660),
    [sym_octal_number] = ACTIONS(11660),
    [sym_hex_number] = ACTIONS(11660),
    [aux_sym_real_number_token1] = ACTIONS(11660),
    [sym_fixed_point_number] = ACTIONS(11658),
    [sym_unsigned_number] = ACTIONS(11658),
    [anon_sym_SQUOTE0] = ACTIONS(11660),
    [anon_sym_SQUOTE1] = ACTIONS(11660),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11660),
    [anon_sym_LPAREN_STAR] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11660),
    [anon_sym_DOLLARroot] = ACTIONS(11658),
    [anon_sym_DOLLARunit] = ACTIONS(11658),
    [sym_system_tf_identifier] = ACTIONS(11658),
  },
  [5372] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5378),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11658),
    [anon_sym_DQUOTE] = ACTIONS(11660),
    [anon_sym_LT] = ACTIONS(11658),
    [anon_sym_GT] = ACTIONS(11658),
    [anon_sym_LPAREN] = ACTIONS(11658),
    [anon_sym_RPAREN] = ACTIONS(11660),
    [anon_sym_BQUOTE] = ACTIONS(11660),
    [anon_sym_SLASH] = ACTIONS(11658),
    [anon_sym_COLON] = ACTIONS(11660),
    [anon_sym_type] = ACTIONS(11658),
    [anon_sym_DOT] = ACTIONS(11660),
    [anon_sym_LBRACE] = ACTIONS(11660),
    [anon_sym_const] = ACTIONS(11658),
    [anon_sym_local] = ACTIONS(11658),
    [anon_sym_super] = ACTIONS(11658),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11658),
    [anon_sym_string] = ACTIONS(11658),
    [anon_sym_byte] = ACTIONS(11658),
    [anon_sym_shortint] = ACTIONS(11658),
    [anon_sym_int] = ACTIONS(11658),
    [anon_sym_longint] = ACTIONS(11658),
    [anon_sym_integer] = ACTIONS(11658),
    [anon_sym_time] = ACTIONS(11658),
    [anon_sym_bit] = ACTIONS(11658),
    [anon_sym_logic] = ACTIONS(11658),
    [anon_sym_reg] = ACTIONS(11658),
    [anon_sym_shortreal] = ACTIONS(11658),
    [anon_sym_real] = ACTIONS(11658),
    [anon_sym_realtime] = ACTIONS(11658),
    [anon_sym_signed] = ACTIONS(11658),
    [anon_sym_unsigned] = ACTIONS(11658),
    [anon_sym_tagged] = ACTIONS(11658),
    [anon_sym_DOLLAR] = ACTIONS(11658),
    [anon_sym_PLUS] = ACTIONS(11658),
    [anon_sym_PLUS_PLUS] = ACTIONS(11662),
    [anon_sym_STAR_STAR] = ACTIONS(11660),
    [anon_sym_PERCENT] = ACTIONS(11660),
    [anon_sym_EQ_EQ] = ACTIONS(11658),
    [anon_sym_BANG_EQ] = ACTIONS(11658),
    [anon_sym_LT_EQ] = ACTIONS(11660),
    [anon_sym_GT_EQ] = ACTIONS(11660),
    [anon_sym_BANG] = ACTIONS(11658),
    [anon_sym_AMP_AMP] = ACTIONS(11658),
    [anon_sym_PIPE_PIPE] = ACTIONS(11660),
    [anon_sym_matches] = ACTIONS(11658),
    [anon_sym_DASH] = ACTIONS(11658),
    [anon_sym_DASH_GT] = ACTIONS(11660),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11660),
    [anon_sym_inside] = ACTIONS(11658),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11660),
    [anon_sym_TILDE] = ACTIONS(11658),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11660),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11660),
    [anon_sym_GT_GT] = ACTIONS(11658),
    [anon_sym_LT_LT] = ACTIONS(11658),
    [anon_sym_std] = ACTIONS(11658),
    [anon_sym_randomize] = ACTIONS(11658),
    [anon_sym_null] = ACTIONS(11658),
    [anon_sym_QMARK] = ACTIONS(11660),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_AMP] = ACTIONS(11658),
    [anon_sym_PIPE] = ACTIONS(11658),
    [anon_sym_CARET] = ACTIONS(11658),
    [anon_sym_CARET_TILDE] = ACTIONS(11660),
    [anon_sym_TILDE_CARET] = ACTIONS(11660),
    [anon_sym_GT_GT_GT] = ACTIONS(11660),
    [anon_sym_LT_LT_LT] = ACTIONS(11660),
    [anon_sym_LT_DASH_GT] = ACTIONS(11660),
    [anon_sym_this] = ACTIONS(11658),
    [anon_sym_TILDE_AMP] = ACTIONS(11660),
    [anon_sym_TILDE_PIPE] = ACTIONS(11660),
    [anon_sym_DASH_DASH] = ACTIONS(11662),
    [aux_sym_decimal_number_token1] = ACTIONS(11660),
    [aux_sym_decimal_number_token2] = ACTIONS(11660),
    [sym_binary_number] = ACTIONS(11660),
    [sym_octal_number] = ACTIONS(11660),
    [sym_hex_number] = ACTIONS(11660),
    [aux_sym_real_number_token1] = ACTIONS(11660),
    [sym_fixed_point_number] = ACTIONS(11658),
    [sym_unsigned_number] = ACTIONS(11658),
    [anon_sym_SQUOTE0] = ACTIONS(11660),
    [anon_sym_SQUOTE1] = ACTIONS(11660),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11660),
    [anon_sym_LPAREN_STAR] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11660),
    [anon_sym_DOLLARroot] = ACTIONS(11658),
    [anon_sym_DOLLARunit] = ACTIONS(11658),
    [sym_system_tf_identifier] = ACTIONS(11658),
  },
  [5373] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5670),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11717),
    [anon_sym_DQUOTE] = ACTIONS(11719),
    [anon_sym_LT] = ACTIONS(11717),
    [anon_sym_GT] = ACTIONS(11717),
    [anon_sym_LPAREN] = ACTIONS(11719),
    [anon_sym_RPAREN] = ACTIONS(11719),
    [anon_sym_COMMA] = ACTIONS(11719),
    [anon_sym_BQUOTE] = ACTIONS(11719),
    [anon_sym_SLASH] = ACTIONS(11717),
    [anon_sym_COLON] = ACTIONS(11719),
    [anon_sym_type] = ACTIONS(11717),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11719),
    [anon_sym_const] = ACTIONS(11717),
    [anon_sym_local] = ACTIONS(11717),
    [anon_sym_super] = ACTIONS(11717),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11717),
    [anon_sym_string] = ACTIONS(11717),
    [anon_sym_byte] = ACTIONS(11717),
    [anon_sym_shortint] = ACTIONS(11717),
    [anon_sym_int] = ACTIONS(11717),
    [anon_sym_longint] = ACTIONS(11717),
    [anon_sym_integer] = ACTIONS(11717),
    [anon_sym_time] = ACTIONS(11717),
    [anon_sym_bit] = ACTIONS(11717),
    [anon_sym_logic] = ACTIONS(11717),
    [anon_sym_reg] = ACTIONS(11717),
    [anon_sym_shortreal] = ACTIONS(11717),
    [anon_sym_real] = ACTIONS(11717),
    [anon_sym_realtime] = ACTIONS(11717),
    [anon_sym_signed] = ACTIONS(11717),
    [anon_sym_unsigned] = ACTIONS(11717),
    [anon_sym_tagged] = ACTIONS(11717),
    [anon_sym_DOLLAR] = ACTIONS(11717),
    [anon_sym_PLUS] = ACTIONS(11717),
    [anon_sym_PLUS_PLUS] = ACTIONS(11719),
    [anon_sym_STAR_STAR] = ACTIONS(11719),
    [anon_sym_PERCENT] = ACTIONS(11719),
    [anon_sym_EQ_EQ] = ACTIONS(11717),
    [anon_sym_BANG_EQ] = ACTIONS(11717),
    [anon_sym_LT_EQ] = ACTIONS(11719),
    [anon_sym_GT_EQ] = ACTIONS(11719),
    [anon_sym_BANG] = ACTIONS(11717),
    [anon_sym_AMP_AMP] = ACTIONS(11717),
    [anon_sym_PIPE_PIPE] = ACTIONS(11719),
    [anon_sym_matches] = ACTIONS(11717),
    [anon_sym_DASH] = ACTIONS(11717),
    [anon_sym_DASH_GT] = ACTIONS(11719),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11719),
    [anon_sym_inside] = ACTIONS(11717),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11719),
    [anon_sym_TILDE] = ACTIONS(11717),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11719),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11719),
    [anon_sym_GT_GT] = ACTIONS(11717),
    [anon_sym_LT_LT] = ACTIONS(11717),
    [anon_sym_std] = ACTIONS(11717),
    [anon_sym_randomize] = ACTIONS(11717),
    [anon_sym_null] = ACTIONS(11717),
    [anon_sym_QMARK] = ACTIONS(11719),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11719),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11719),
    [anon_sym_AMP] = ACTIONS(11717),
    [anon_sym_PIPE] = ACTIONS(11717),
    [anon_sym_CARET] = ACTIONS(11717),
    [anon_sym_CARET_TILDE] = ACTIONS(11719),
    [anon_sym_TILDE_CARET] = ACTIONS(11719),
    [anon_sym_GT_GT_GT] = ACTIONS(11719),
    [anon_sym_LT_LT_LT] = ACTIONS(11719),
    [anon_sym_LT_DASH_GT] = ACTIONS(11719),
    [anon_sym_this] = ACTIONS(11717),
    [anon_sym_TILDE_AMP] = ACTIONS(11719),
    [anon_sym_TILDE_PIPE] = ACTIONS(11719),
    [anon_sym_DASH_DASH] = ACTIONS(11719),
    [aux_sym_decimal_number_token1] = ACTIONS(11719),
    [aux_sym_decimal_number_token2] = ACTIONS(11719),
    [sym_binary_number] = ACTIONS(11719),
    [sym_octal_number] = ACTIONS(11719),
    [sym_hex_number] = ACTIONS(11719),
    [aux_sym_real_number_token1] = ACTIONS(11719),
    [sym_fixed_point_number] = ACTIONS(11717),
    [sym_unsigned_number] = ACTIONS(11717),
    [anon_sym_SQUOTE0] = ACTIONS(11719),
    [anon_sym_SQUOTE1] = ACTIONS(11719),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11719),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11719),
    [anon_sym_DOLLARroot] = ACTIONS(11717),
    [anon_sym_DOLLARunit] = ACTIONS(11717),
    [sym_system_tf_identifier] = ACTIONS(11717),
  },
  [5374] = {
    [sym_simple_identifier] = ACTIONS(11721),
    [anon_sym_wire] = ACTIONS(11721),
    [anon_sym_tri] = ACTIONS(11721),
    [anon_sym_tri0] = ACTIONS(11721),
    [anon_sym_tri1] = ACTIONS(11721),
    [anon_sym_wand] = ACTIONS(11721),
    [anon_sym_triand] = ACTIONS(11721),
    [anon_sym_wor] = ACTIONS(11721),
    [anon_sym_trior] = ACTIONS(11721),
    [anon_sym_trireg] = ACTIONS(11721),
    [anon_sym_uwire] = ACTIONS(11721),
    [anon_sym_SEMI] = ACTIONS(11723),
    [anon_sym_extern] = ACTIONS(11721),
    [anon_sym_endinterface] = ACTIONS(11721),
    [anon_sym_interface] = ACTIONS(11721),
    [anon_sym_program] = ACTIONS(11721),
    [anon_sym_checker] = ACTIONS(11721),
    [anon_sym_virtual] = ACTIONS(11721),
    [anon_sym_class] = ACTIONS(11721),
    [anon_sym_timeunit] = ACTIONS(11721),
    [anon_sym_timeprecision] = ACTIONS(11721),
    [anon_sym_type] = ACTIONS(11721),
    [anon_sym_input] = ACTIONS(11721),
    [anon_sym_output] = ACTIONS(11721),
    [anon_sym_inout] = ACTIONS(11721),
    [anon_sym_ref] = ACTIONS(11721),
    [anon_sym_DOLLARfatal] = ACTIONS(11723),
    [anon_sym_DOLLARerror] = ACTIONS(11723),
    [anon_sym_DOLLARwarning] = ACTIONS(11723),
    [anon_sym_DOLLARinfo] = ACTIONS(11723),
    [anon_sym_default] = ACTIONS(11721),
    [anon_sym_clocking] = ACTIONS(11721),
    [anon_sym_bind] = ACTIONS(11721),
    [anon_sym_const] = ACTIONS(11721),
    [anon_sym_function] = ACTIONS(11721),
    [anon_sym_static] = ACTIONS(11721),
    [anon_sym_constraint] = ACTIONS(11721),
    [anon_sym_if] = ACTIONS(11721),
    [anon_sym_LBRACK] = ACTIONS(11723),
    [anon_sym_localparam] = ACTIONS(11721),
    [anon_sym_parameter] = ACTIONS(11721),
    [anon_sym_var] = ACTIONS(11721),
    [anon_sym_import] = ACTIONS(11721),
    [anon_sym_export] = ACTIONS(11721),
    [anon_sym_genvar] = ACTIONS(11721),
    [anon_sym_interconnect] = ACTIONS(11721),
    [anon_sym_typedef] = ACTIONS(11721),
    [anon_sym_enum] = ACTIONS(11721),
    [anon_sym_struct] = ACTIONS(11721),
    [anon_sym_union] = ACTIONS(11721),
    [anon_sym_nettype] = ACTIONS(11721),
    [anon_sym_automatic] = ACTIONS(11721),
    [anon_sym_string] = ACTIONS(11721),
    [anon_sym_chandle] = ACTIONS(11721),
    [anon_sym_event] = ACTIONS(11721),
    [anon_sym_byte] = ACTIONS(11721),
    [anon_sym_shortint] = ACTIONS(11721),
    [anon_sym_int] = ACTIONS(11721),
    [anon_sym_longint] = ACTIONS(11721),
    [anon_sym_integer] = ACTIONS(11721),
    [anon_sym_time] = ACTIONS(11721),
    [anon_sym_bit] = ACTIONS(11721),
    [anon_sym_logic] = ACTIONS(11721),
    [anon_sym_reg] = ACTIONS(11721),
    [anon_sym_shortreal] = ACTIONS(11721),
    [anon_sym_real] = ACTIONS(11721),
    [anon_sym_realtime] = ACTIONS(11721),
    [anon_sym_supply0] = ACTIONS(11721),
    [anon_sym_supply1] = ACTIONS(11721),
    [anon_sym_signed] = ACTIONS(11721),
    [anon_sym_unsigned] = ACTIONS(11721),
    [anon_sym_task] = ACTIONS(11721),
    [anon_sym_modport] = ACTIONS(11721),
    [anon_sym_assert] = ACTIONS(11721),
    [anon_sym_property] = ACTIONS(11721),
    [anon_sym_assume] = ACTIONS(11721),
    [anon_sym_cover] = ACTIONS(11721),
    [anon_sym_sequence] = ACTIONS(11721),
    [anon_sym_restrict] = ACTIONS(11721),
    [anon_sym_case] = ACTIONS(11721),
    [anon_sym_always] = ACTIONS(11721),
    [anon_sym_covergroup] = ACTIONS(11721),
    [anon_sym_let] = ACTIONS(11721),
    [anon_sym_generate] = ACTIONS(11721),
    [anon_sym_for] = ACTIONS(11721),
    [anon_sym_initial] = ACTIONS(11721),
    [anon_sym_assign] = ACTIONS(11721),
    [anon_sym_alias] = ACTIONS(11721),
    [anon_sym_always_comb] = ACTIONS(11721),
    [anon_sym_always_latch] = ACTIONS(11721),
    [anon_sym_always_ff] = ACTIONS(11721),
    [anon_sym_final] = ACTIONS(11721),
    [anon_sym_global] = ACTIONS(11721),
    [anon_sym_LPAREN_STAR] = ACTIONS(11723),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11723),
    [anon_sym_DOLLARunit] = ACTIONS(11723),
  },
  [5375] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5668),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11725),
    [anon_sym_DQUOTE] = ACTIONS(11672),
    [anon_sym_LT] = ACTIONS(11725),
    [anon_sym_GT] = ACTIONS(11725),
    [anon_sym_LPAREN] = ACTIONS(11672),
    [anon_sym_RPAREN] = ACTIONS(11672),
    [anon_sym_COMMA] = ACTIONS(11672),
    [anon_sym_BQUOTE] = ACTIONS(11672),
    [anon_sym_SLASH] = ACTIONS(11725),
    [anon_sym_COLON] = ACTIONS(11672),
    [anon_sym_type] = ACTIONS(11725),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11672),
    [anon_sym_const] = ACTIONS(11725),
    [anon_sym_local] = ACTIONS(11725),
    [anon_sym_super] = ACTIONS(11725),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11725),
    [anon_sym_string] = ACTIONS(11725),
    [anon_sym_byte] = ACTIONS(11725),
    [anon_sym_shortint] = ACTIONS(11725),
    [anon_sym_int] = ACTIONS(11725),
    [anon_sym_longint] = ACTIONS(11725),
    [anon_sym_integer] = ACTIONS(11725),
    [anon_sym_time] = ACTIONS(11725),
    [anon_sym_bit] = ACTIONS(11725),
    [anon_sym_logic] = ACTIONS(11725),
    [anon_sym_reg] = ACTIONS(11725),
    [anon_sym_shortreal] = ACTIONS(11725),
    [anon_sym_real] = ACTIONS(11725),
    [anon_sym_realtime] = ACTIONS(11725),
    [anon_sym_signed] = ACTIONS(11725),
    [anon_sym_unsigned] = ACTIONS(11725),
    [anon_sym_tagged] = ACTIONS(11725),
    [anon_sym_DOLLAR] = ACTIONS(11725),
    [anon_sym_PLUS] = ACTIONS(11725),
    [anon_sym_PLUS_PLUS] = ACTIONS(11672),
    [anon_sym_STAR_STAR] = ACTIONS(11672),
    [anon_sym_PERCENT] = ACTIONS(11672),
    [anon_sym_EQ_EQ] = ACTIONS(11725),
    [anon_sym_BANG_EQ] = ACTIONS(11725),
    [anon_sym_LT_EQ] = ACTIONS(11672),
    [anon_sym_GT_EQ] = ACTIONS(11672),
    [anon_sym_BANG] = ACTIONS(11725),
    [anon_sym_AMP_AMP] = ACTIONS(11725),
    [anon_sym_PIPE_PIPE] = ACTIONS(11672),
    [anon_sym_matches] = ACTIONS(11725),
    [anon_sym_DASH] = ACTIONS(11725),
    [anon_sym_DASH_GT] = ACTIONS(11672),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11672),
    [anon_sym_inside] = ACTIONS(11725),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11672),
    [anon_sym_TILDE] = ACTIONS(11725),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11672),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11672),
    [anon_sym_GT_GT] = ACTIONS(11725),
    [anon_sym_LT_LT] = ACTIONS(11725),
    [anon_sym_std] = ACTIONS(11725),
    [anon_sym_randomize] = ACTIONS(11725),
    [anon_sym_null] = ACTIONS(11725),
    [anon_sym_QMARK] = ACTIONS(11672),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11672),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11672),
    [anon_sym_AMP] = ACTIONS(11725),
    [anon_sym_PIPE] = ACTIONS(11725),
    [anon_sym_CARET] = ACTIONS(11725),
    [anon_sym_CARET_TILDE] = ACTIONS(11672),
    [anon_sym_TILDE_CARET] = ACTIONS(11672),
    [anon_sym_GT_GT_GT] = ACTIONS(11672),
    [anon_sym_LT_LT_LT] = ACTIONS(11672),
    [anon_sym_LT_DASH_GT] = ACTIONS(11672),
    [anon_sym_this] = ACTIONS(11725),
    [anon_sym_TILDE_AMP] = ACTIONS(11672),
    [anon_sym_TILDE_PIPE] = ACTIONS(11672),
    [anon_sym_DASH_DASH] = ACTIONS(11672),
    [aux_sym_decimal_number_token1] = ACTIONS(11672),
    [aux_sym_decimal_number_token2] = ACTIONS(11672),
    [sym_binary_number] = ACTIONS(11672),
    [sym_octal_number] = ACTIONS(11672),
    [sym_hex_number] = ACTIONS(11672),
    [aux_sym_real_number_token1] = ACTIONS(11672),
    [sym_fixed_point_number] = ACTIONS(11725),
    [sym_unsigned_number] = ACTIONS(11725),
    [anon_sym_SQUOTE0] = ACTIONS(11672),
    [anon_sym_SQUOTE1] = ACTIONS(11672),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11672),
    [anon_sym_DOLLARroot] = ACTIONS(11725),
    [anon_sym_DOLLARunit] = ACTIONS(11725),
    [sym_system_tf_identifier] = ACTIONS(11725),
  },
  [5376] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5593),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11658),
    [anon_sym_DQUOTE] = ACTIONS(11660),
    [anon_sym_LT] = ACTIONS(11658),
    [anon_sym_GT] = ACTIONS(11658),
    [anon_sym_LPAREN] = ACTIONS(11660),
    [anon_sym_RPAREN] = ACTIONS(11660),
    [anon_sym_COMMA] = ACTIONS(11660),
    [anon_sym_BQUOTE] = ACTIONS(11660),
    [anon_sym_SLASH] = ACTIONS(11658),
    [anon_sym_COLON] = ACTIONS(11660),
    [anon_sym_type] = ACTIONS(11658),
    [anon_sym_DOT] = ACTIONS(11660),
    [anon_sym_LBRACE] = ACTIONS(11660),
    [anon_sym_const] = ACTIONS(11658),
    [anon_sym_local] = ACTIONS(11658),
    [anon_sym_super] = ACTIONS(11658),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11658),
    [anon_sym_string] = ACTIONS(11658),
    [anon_sym_byte] = ACTIONS(11658),
    [anon_sym_shortint] = ACTIONS(11658),
    [anon_sym_int] = ACTIONS(11658),
    [anon_sym_longint] = ACTIONS(11658),
    [anon_sym_integer] = ACTIONS(11658),
    [anon_sym_time] = ACTIONS(11658),
    [anon_sym_bit] = ACTIONS(11658),
    [anon_sym_logic] = ACTIONS(11658),
    [anon_sym_reg] = ACTIONS(11658),
    [anon_sym_shortreal] = ACTIONS(11658),
    [anon_sym_real] = ACTIONS(11658),
    [anon_sym_realtime] = ACTIONS(11658),
    [anon_sym_signed] = ACTIONS(11658),
    [anon_sym_unsigned] = ACTIONS(11658),
    [anon_sym_tagged] = ACTIONS(11658),
    [anon_sym_DOLLAR] = ACTIONS(11658),
    [anon_sym_PLUS] = ACTIONS(11658),
    [anon_sym_PLUS_PLUS] = ACTIONS(11660),
    [anon_sym_STAR_STAR] = ACTIONS(11660),
    [anon_sym_PERCENT] = ACTIONS(11660),
    [anon_sym_EQ_EQ] = ACTIONS(11658),
    [anon_sym_BANG_EQ] = ACTIONS(11658),
    [anon_sym_LT_EQ] = ACTIONS(11660),
    [anon_sym_GT_EQ] = ACTIONS(11660),
    [anon_sym_BANG] = ACTIONS(11658),
    [anon_sym_AMP_AMP] = ACTIONS(11658),
    [anon_sym_PIPE_PIPE] = ACTIONS(11660),
    [anon_sym_matches] = ACTIONS(11658),
    [anon_sym_DASH] = ACTIONS(11658),
    [anon_sym_DASH_GT] = ACTIONS(11660),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11660),
    [anon_sym_inside] = ACTIONS(11658),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11660),
    [anon_sym_TILDE] = ACTIONS(11658),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11660),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11660),
    [anon_sym_GT_GT] = ACTIONS(11658),
    [anon_sym_LT_LT] = ACTIONS(11658),
    [anon_sym_std] = ACTIONS(11658),
    [anon_sym_randomize] = ACTIONS(11658),
    [anon_sym_null] = ACTIONS(11658),
    [anon_sym_QMARK] = ACTIONS(11660),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11660),
    [anon_sym_AMP] = ACTIONS(11658),
    [anon_sym_PIPE] = ACTIONS(11658),
    [anon_sym_CARET] = ACTIONS(11658),
    [anon_sym_CARET_TILDE] = ACTIONS(11660),
    [anon_sym_TILDE_CARET] = ACTIONS(11660),
    [anon_sym_GT_GT_GT] = ACTIONS(11660),
    [anon_sym_LT_LT_LT] = ACTIONS(11660),
    [anon_sym_LT_DASH_GT] = ACTIONS(11660),
    [anon_sym_this] = ACTIONS(11658),
    [anon_sym_TILDE_AMP] = ACTIONS(11660),
    [anon_sym_TILDE_PIPE] = ACTIONS(11660),
    [anon_sym_DASH_DASH] = ACTIONS(11660),
    [aux_sym_decimal_number_token1] = ACTIONS(11660),
    [aux_sym_decimal_number_token2] = ACTIONS(11660),
    [sym_binary_number] = ACTIONS(11660),
    [sym_octal_number] = ACTIONS(11660),
    [sym_hex_number] = ACTIONS(11660),
    [aux_sym_real_number_token1] = ACTIONS(11660),
    [sym_fixed_point_number] = ACTIONS(11658),
    [sym_unsigned_number] = ACTIONS(11658),
    [anon_sym_SQUOTE0] = ACTIONS(11660),
    [anon_sym_SQUOTE1] = ACTIONS(11660),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11660),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11660),
    [anon_sym_DOLLARroot] = ACTIONS(11658),
    [anon_sym_DOLLARunit] = ACTIONS(11658),
    [sym_system_tf_identifier] = ACTIONS(11658),
  },
  [5377] = {
    [sym_simple_identifier] = ACTIONS(11727),
    [anon_sym_wire] = ACTIONS(11727),
    [anon_sym_tri] = ACTIONS(11727),
    [anon_sym_tri0] = ACTIONS(11727),
    [anon_sym_tri1] = ACTIONS(11727),
    [anon_sym_wand] = ACTIONS(11727),
    [anon_sym_triand] = ACTIONS(11727),
    [anon_sym_wor] = ACTIONS(11727),
    [anon_sym_trior] = ACTIONS(11727),
    [anon_sym_trireg] = ACTIONS(11727),
    [anon_sym_uwire] = ACTIONS(11727),
    [anon_sym_SEMI] = ACTIONS(11730),
    [anon_sym_extern] = ACTIONS(11727),
    [anon_sym_endinterface] = ACTIONS(11727),
    [anon_sym_interface] = ACTIONS(11727),
    [anon_sym_program] = ACTIONS(11727),
    [anon_sym_checker] = ACTIONS(11727),
    [anon_sym_virtual] = ACTIONS(11727),
    [anon_sym_class] = ACTIONS(11727),
    [anon_sym_timeunit] = ACTIONS(11727),
    [anon_sym_timeprecision] = ACTIONS(11727),
    [anon_sym_type] = ACTIONS(11727),
    [anon_sym_input] = ACTIONS(11727),
    [anon_sym_output] = ACTIONS(11727),
    [anon_sym_inout] = ACTIONS(11727),
    [anon_sym_ref] = ACTIONS(11727),
    [anon_sym_DOLLARfatal] = ACTIONS(11730),
    [anon_sym_DOLLARerror] = ACTIONS(11730),
    [anon_sym_DOLLARwarning] = ACTIONS(11730),
    [anon_sym_DOLLARinfo] = ACTIONS(11730),
    [anon_sym_default] = ACTIONS(11727),
    [anon_sym_clocking] = ACTIONS(11727),
    [anon_sym_bind] = ACTIONS(11727),
    [anon_sym_const] = ACTIONS(11727),
    [anon_sym_function] = ACTIONS(11727),
    [anon_sym_static] = ACTIONS(11727),
    [anon_sym_constraint] = ACTIONS(11727),
    [anon_sym_if] = ACTIONS(11727),
    [anon_sym_LBRACK] = ACTIONS(11730),
    [anon_sym_localparam] = ACTIONS(11727),
    [anon_sym_parameter] = ACTIONS(11727),
    [anon_sym_var] = ACTIONS(11727),
    [anon_sym_import] = ACTIONS(11727),
    [anon_sym_export] = ACTIONS(11727),
    [anon_sym_genvar] = ACTIONS(11727),
    [anon_sym_interconnect] = ACTIONS(11727),
    [anon_sym_typedef] = ACTIONS(11727),
    [anon_sym_enum] = ACTIONS(11727),
    [anon_sym_struct] = ACTIONS(11727),
    [anon_sym_union] = ACTIONS(11727),
    [anon_sym_nettype] = ACTIONS(11727),
    [anon_sym_automatic] = ACTIONS(11727),
    [anon_sym_string] = ACTIONS(11727),
    [anon_sym_chandle] = ACTIONS(11727),
    [anon_sym_event] = ACTIONS(11727),
    [anon_sym_byte] = ACTIONS(11727),
    [anon_sym_shortint] = ACTIONS(11727),
    [anon_sym_int] = ACTIONS(11727),
    [anon_sym_longint] = ACTIONS(11727),
    [anon_sym_integer] = ACTIONS(11727),
    [anon_sym_time] = ACTIONS(11727),
    [anon_sym_bit] = ACTIONS(11727),
    [anon_sym_logic] = ACTIONS(11727),
    [anon_sym_reg] = ACTIONS(11727),
    [anon_sym_shortreal] = ACTIONS(11727),
    [anon_sym_real] = ACTIONS(11727),
    [anon_sym_realtime] = ACTIONS(11727),
    [anon_sym_supply0] = ACTIONS(11727),
    [anon_sym_supply1] = ACTIONS(11727),
    [anon_sym_signed] = ACTIONS(11727),
    [anon_sym_unsigned] = ACTIONS(11727),
    [anon_sym_task] = ACTIONS(11727),
    [anon_sym_modport] = ACTIONS(11727),
    [anon_sym_assert] = ACTIONS(11727),
    [anon_sym_property] = ACTIONS(11727),
    [anon_sym_assume] = ACTIONS(11727),
    [anon_sym_cover] = ACTIONS(11727),
    [anon_sym_sequence] = ACTIONS(11727),
    [anon_sym_restrict] = ACTIONS(11727),
    [anon_sym_case] = ACTIONS(11727),
    [anon_sym_always] = ACTIONS(11727),
    [anon_sym_covergroup] = ACTIONS(11727),
    [anon_sym_let] = ACTIONS(11727),
    [anon_sym_generate] = ACTIONS(11727),
    [anon_sym_for] = ACTIONS(11727),
    [anon_sym_initial] = ACTIONS(11727),
    [anon_sym_assign] = ACTIONS(11727),
    [anon_sym_alias] = ACTIONS(11727),
    [anon_sym_always_comb] = ACTIONS(11727),
    [anon_sym_always_latch] = ACTIONS(11727),
    [anon_sym_always_ff] = ACTIONS(11727),
    [anon_sym_final] = ACTIONS(11727),
    [anon_sym_global] = ACTIONS(11727),
    [anon_sym_LPAREN_STAR] = ACTIONS(11730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11730),
    [anon_sym_DOLLARunit] = ACTIONS(11730),
  },
  [5378] = {
    [sym_simple_identifier] = ACTIONS(11665),
    [anon_sym_DQUOTE] = ACTIONS(11667),
    [anon_sym_LT] = ACTIONS(11665),
    [anon_sym_GT] = ACTIONS(11665),
    [anon_sym_LPAREN] = ACTIONS(11665),
    [anon_sym_RPAREN] = ACTIONS(11667),
    [anon_sym_COMMA] = ACTIONS(11672),
    [anon_sym_BQUOTE] = ACTIONS(11667),
    [anon_sym_SLASH] = ACTIONS(11665),
    [anon_sym_SEMI] = ACTIONS(11667),
    [anon_sym_COLON] = ACTIONS(11667),
    [anon_sym_type] = ACTIONS(11665),
    [anon_sym_DOT] = ACTIONS(11667),
    [anon_sym_LBRACE] = ACTIONS(11667),
    [anon_sym_RBRACE] = ACTIONS(11672),
    [anon_sym_iff] = ACTIONS(11665),
    [anon_sym_const] = ACTIONS(11665),
    [anon_sym_local] = ACTIONS(11665),
    [anon_sym_super] = ACTIONS(11665),
    [anon_sym_u2013_GT] = ACTIONS(11667),
    [anon_sym_STAR] = ACTIONS(11665),
    [anon_sym_with] = ACTIONS(11665),
    [anon_sym_string] = ACTIONS(11665),
    [anon_sym_byte] = ACTIONS(11665),
    [anon_sym_shortint] = ACTIONS(11665),
    [anon_sym_int] = ACTIONS(11665),
    [anon_sym_longint] = ACTIONS(11665),
    [anon_sym_integer] = ACTIONS(11665),
    [anon_sym_time] = ACTIONS(11665),
    [anon_sym_bit] = ACTIONS(11665),
    [anon_sym_logic] = ACTIONS(11665),
    [anon_sym_reg] = ACTIONS(11665),
    [anon_sym_shortreal] = ACTIONS(11665),
    [anon_sym_real] = ACTIONS(11665),
    [anon_sym_realtime] = ACTIONS(11665),
    [anon_sym_signed] = ACTIONS(11665),
    [anon_sym_unsigned] = ACTIONS(11665),
    [anon_sym_tagged] = ACTIONS(11665),
    [anon_sym_DOLLAR] = ACTIONS(11665),
    [anon_sym_PLUS] = ACTIONS(11665),
    [anon_sym_PLUS_PLUS] = ACTIONS(11672),
    [anon_sym_STAR_STAR] = ACTIONS(11667),
    [anon_sym_PERCENT] = ACTIONS(11667),
    [anon_sym_EQ_EQ] = ACTIONS(11665),
    [anon_sym_BANG_EQ] = ACTIONS(11665),
    [anon_sym_LT_EQ] = ACTIONS(11667),
    [anon_sym_GT_EQ] = ACTIONS(11667),
    [anon_sym_dist] = ACTIONS(11665),
    [anon_sym_BANG] = ACTIONS(11665),
    [anon_sym_AMP_AMP] = ACTIONS(11665),
    [anon_sym_PIPE_PIPE] = ACTIONS(11667),
    [anon_sym_matches] = ACTIONS(11665),
    [anon_sym_DASH] = ACTIONS(11665),
    [anon_sym_DASH_GT] = ACTIONS(11667),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11667),
    [anon_sym_inside] = ACTIONS(11665),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11667),
    [anon_sym_TILDE] = ACTIONS(11665),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11667),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11667),
    [anon_sym_GT_GT] = ACTIONS(11665),
    [anon_sym_LT_LT] = ACTIONS(11665),
    [anon_sym_std] = ACTIONS(11665),
    [anon_sym_randomize] = ACTIONS(11665),
    [anon_sym_null] = ACTIONS(11665),
    [anon_sym_QMARK] = ACTIONS(11667),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_AMP] = ACTIONS(11665),
    [anon_sym_PIPE] = ACTIONS(11665),
    [anon_sym_CARET] = ACTIONS(11665),
    [anon_sym_CARET_TILDE] = ACTIONS(11667),
    [anon_sym_TILDE_CARET] = ACTIONS(11667),
    [anon_sym_GT_GT_GT] = ACTIONS(11667),
    [anon_sym_LT_LT_LT] = ACTIONS(11667),
    [anon_sym_LT_DASH_GT] = ACTIONS(11667),
    [anon_sym_this] = ACTIONS(11665),
    [anon_sym_TILDE_AMP] = ACTIONS(11667),
    [anon_sym_TILDE_PIPE] = ACTIONS(11667),
    [anon_sym_DASH_DASH] = ACTIONS(11672),
    [aux_sym_decimal_number_token1] = ACTIONS(11667),
    [aux_sym_decimal_number_token2] = ACTIONS(11667),
    [sym_binary_number] = ACTIONS(11667),
    [sym_octal_number] = ACTIONS(11667),
    [sym_hex_number] = ACTIONS(11667),
    [aux_sym_real_number_token1] = ACTIONS(11667),
    [sym_fixed_point_number] = ACTIONS(11665),
    [sym_unsigned_number] = ACTIONS(11665),
    [anon_sym_SQUOTE0] = ACTIONS(11667),
    [anon_sym_SQUOTE1] = ACTIONS(11667),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11667),
    [anon_sym_LPAREN_STAR] = ACTIONS(11672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11667),
    [anon_sym_DOLLARroot] = ACTIONS(11665),
    [anon_sym_DOLLARunit] = ACTIONS(11665),
    [sym_system_tf_identifier] = ACTIONS(11665),
  },
  [5379] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5667),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11733),
    [anon_sym_DQUOTE] = ACTIONS(11539),
    [anon_sym_LT] = ACTIONS(11733),
    [anon_sym_GT] = ACTIONS(11733),
    [anon_sym_LPAREN] = ACTIONS(11539),
    [anon_sym_RPAREN] = ACTIONS(11539),
    [anon_sym_COMMA] = ACTIONS(11539),
    [anon_sym_BQUOTE] = ACTIONS(11539),
    [anon_sym_SLASH] = ACTIONS(11733),
    [anon_sym_COLON] = ACTIONS(11539),
    [anon_sym_type] = ACTIONS(11733),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11539),
    [anon_sym_const] = ACTIONS(11733),
    [anon_sym_local] = ACTIONS(11733),
    [anon_sym_super] = ACTIONS(11733),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11733),
    [anon_sym_string] = ACTIONS(11733),
    [anon_sym_byte] = ACTIONS(11733),
    [anon_sym_shortint] = ACTIONS(11733),
    [anon_sym_int] = ACTIONS(11733),
    [anon_sym_longint] = ACTIONS(11733),
    [anon_sym_integer] = ACTIONS(11733),
    [anon_sym_time] = ACTIONS(11733),
    [anon_sym_bit] = ACTIONS(11733),
    [anon_sym_logic] = ACTIONS(11733),
    [anon_sym_reg] = ACTIONS(11733),
    [anon_sym_shortreal] = ACTIONS(11733),
    [anon_sym_real] = ACTIONS(11733),
    [anon_sym_realtime] = ACTIONS(11733),
    [anon_sym_signed] = ACTIONS(11733),
    [anon_sym_unsigned] = ACTIONS(11733),
    [anon_sym_tagged] = ACTIONS(11733),
    [anon_sym_DOLLAR] = ACTIONS(11733),
    [anon_sym_PLUS] = ACTIONS(11733),
    [anon_sym_PLUS_PLUS] = ACTIONS(11539),
    [anon_sym_STAR_STAR] = ACTIONS(11539),
    [anon_sym_PERCENT] = ACTIONS(11539),
    [anon_sym_EQ_EQ] = ACTIONS(11733),
    [anon_sym_BANG_EQ] = ACTIONS(11733),
    [anon_sym_LT_EQ] = ACTIONS(11539),
    [anon_sym_GT_EQ] = ACTIONS(11539),
    [anon_sym_BANG] = ACTIONS(11733),
    [anon_sym_AMP_AMP] = ACTIONS(11733),
    [anon_sym_PIPE_PIPE] = ACTIONS(11539),
    [anon_sym_matches] = ACTIONS(11733),
    [anon_sym_DASH] = ACTIONS(11733),
    [anon_sym_DASH_GT] = ACTIONS(11539),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11539),
    [anon_sym_inside] = ACTIONS(11733),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11539),
    [anon_sym_TILDE] = ACTIONS(11733),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11539),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11539),
    [anon_sym_GT_GT] = ACTIONS(11733),
    [anon_sym_LT_LT] = ACTIONS(11733),
    [anon_sym_std] = ACTIONS(11733),
    [anon_sym_randomize] = ACTIONS(11733),
    [anon_sym_null] = ACTIONS(11733),
    [anon_sym_QMARK] = ACTIONS(11539),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11539),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11539),
    [anon_sym_AMP] = ACTIONS(11733),
    [anon_sym_PIPE] = ACTIONS(11733),
    [anon_sym_CARET] = ACTIONS(11733),
    [anon_sym_CARET_TILDE] = ACTIONS(11539),
    [anon_sym_TILDE_CARET] = ACTIONS(11539),
    [anon_sym_GT_GT_GT] = ACTIONS(11539),
    [anon_sym_LT_LT_LT] = ACTIONS(11539),
    [anon_sym_LT_DASH_GT] = ACTIONS(11539),
    [anon_sym_this] = ACTIONS(11733),
    [anon_sym_TILDE_AMP] = ACTIONS(11539),
    [anon_sym_TILDE_PIPE] = ACTIONS(11539),
    [anon_sym_DASH_DASH] = ACTIONS(11539),
    [aux_sym_decimal_number_token1] = ACTIONS(11539),
    [aux_sym_decimal_number_token2] = ACTIONS(11539),
    [sym_binary_number] = ACTIONS(11539),
    [sym_octal_number] = ACTIONS(11539),
    [sym_hex_number] = ACTIONS(11539),
    [aux_sym_real_number_token1] = ACTIONS(11539),
    [sym_fixed_point_number] = ACTIONS(11733),
    [sym_unsigned_number] = ACTIONS(11733),
    [anon_sym_SQUOTE0] = ACTIONS(11539),
    [anon_sym_SQUOTE1] = ACTIONS(11539),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11539),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11539),
    [anon_sym_DOLLARroot] = ACTIONS(11733),
    [anon_sym_DOLLARunit] = ACTIONS(11733),
    [sym_system_tf_identifier] = ACTIONS(11733),
  },
  [5380] = {
    [sym_simple_identifier] = ACTIONS(11735),
    [anon_sym_DQUOTE] = ACTIONS(11737),
    [anon_sym_LT] = ACTIONS(11735),
    [anon_sym_GT] = ACTIONS(11735),
    [anon_sym_LPAREN] = ACTIONS(11735),
    [anon_sym_RPAREN] = ACTIONS(11737),
    [anon_sym_COMMA] = ACTIONS(11314),
    [anon_sym_BQUOTE] = ACTIONS(11737),
    [anon_sym_SLASH] = ACTIONS(11735),
    [anon_sym_SEMI] = ACTIONS(11737),
    [anon_sym_COLON] = ACTIONS(11737),
    [anon_sym_type] = ACTIONS(11735),
    [anon_sym_DOT] = ACTIONS(11737),
    [anon_sym_LBRACE] = ACTIONS(11737),
    [anon_sym_RBRACE] = ACTIONS(11314),
    [anon_sym_iff] = ACTIONS(11735),
    [anon_sym_const] = ACTIONS(11735),
    [anon_sym_local] = ACTIONS(11735),
    [anon_sym_super] = ACTIONS(11735),
    [anon_sym_u2013_GT] = ACTIONS(11737),
    [anon_sym_STAR] = ACTIONS(11735),
    [anon_sym_with] = ACTIONS(11735),
    [anon_sym_string] = ACTIONS(11735),
    [anon_sym_byte] = ACTIONS(11735),
    [anon_sym_shortint] = ACTIONS(11735),
    [anon_sym_int] = ACTIONS(11735),
    [anon_sym_longint] = ACTIONS(11735),
    [anon_sym_integer] = ACTIONS(11735),
    [anon_sym_time] = ACTIONS(11735),
    [anon_sym_bit] = ACTIONS(11735),
    [anon_sym_logic] = ACTIONS(11735),
    [anon_sym_reg] = ACTIONS(11735),
    [anon_sym_shortreal] = ACTIONS(11735),
    [anon_sym_real] = ACTIONS(11735),
    [anon_sym_realtime] = ACTIONS(11735),
    [anon_sym_signed] = ACTIONS(11735),
    [anon_sym_unsigned] = ACTIONS(11735),
    [anon_sym_tagged] = ACTIONS(11735),
    [anon_sym_DOLLAR] = ACTIONS(11735),
    [anon_sym_PLUS] = ACTIONS(11735),
    [anon_sym_PLUS_PLUS] = ACTIONS(11314),
    [anon_sym_STAR_STAR] = ACTIONS(11737),
    [anon_sym_PERCENT] = ACTIONS(11737),
    [anon_sym_EQ_EQ] = ACTIONS(11735),
    [anon_sym_BANG_EQ] = ACTIONS(11735),
    [anon_sym_LT_EQ] = ACTIONS(11737),
    [anon_sym_GT_EQ] = ACTIONS(11737),
    [anon_sym_dist] = ACTIONS(11735),
    [anon_sym_BANG] = ACTIONS(11735),
    [anon_sym_AMP_AMP] = ACTIONS(11735),
    [anon_sym_PIPE_PIPE] = ACTIONS(11737),
    [anon_sym_matches] = ACTIONS(11735),
    [anon_sym_DASH] = ACTIONS(11735),
    [anon_sym_DASH_GT] = ACTIONS(11737),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11737),
    [anon_sym_inside] = ACTIONS(11735),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11737),
    [anon_sym_TILDE] = ACTIONS(11735),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11737),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11737),
    [anon_sym_GT_GT] = ACTIONS(11735),
    [anon_sym_LT_LT] = ACTIONS(11735),
    [anon_sym_std] = ACTIONS(11735),
    [anon_sym_randomize] = ACTIONS(11735),
    [anon_sym_null] = ACTIONS(11735),
    [anon_sym_QMARK] = ACTIONS(11737),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11737),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11737),
    [anon_sym_AMP] = ACTIONS(11735),
    [anon_sym_PIPE] = ACTIONS(11735),
    [anon_sym_CARET] = ACTIONS(11735),
    [anon_sym_CARET_TILDE] = ACTIONS(11737),
    [anon_sym_TILDE_CARET] = ACTIONS(11737),
    [anon_sym_GT_GT_GT] = ACTIONS(11737),
    [anon_sym_LT_LT_LT] = ACTIONS(11737),
    [anon_sym_LT_DASH_GT] = ACTIONS(11737),
    [anon_sym_this] = ACTIONS(11735),
    [anon_sym_TILDE_AMP] = ACTIONS(11737),
    [anon_sym_TILDE_PIPE] = ACTIONS(11737),
    [anon_sym_DASH_DASH] = ACTIONS(11314),
    [aux_sym_decimal_number_token1] = ACTIONS(11737),
    [aux_sym_decimal_number_token2] = ACTIONS(11737),
    [sym_binary_number] = ACTIONS(11737),
    [sym_octal_number] = ACTIONS(11737),
    [sym_hex_number] = ACTIONS(11737),
    [aux_sym_real_number_token1] = ACTIONS(11737),
    [sym_fixed_point_number] = ACTIONS(11735),
    [sym_unsigned_number] = ACTIONS(11735),
    [anon_sym_SQUOTE0] = ACTIONS(11737),
    [anon_sym_SQUOTE1] = ACTIONS(11737),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11737),
    [anon_sym_LPAREN_STAR] = ACTIONS(11314),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11737),
    [anon_sym_DOLLARroot] = ACTIONS(11735),
    [anon_sym_DOLLARunit] = ACTIONS(11735),
    [sym_system_tf_identifier] = ACTIONS(11735),
  },
  [5381] = {
    [sym_simple_identifier] = ACTIONS(11739),
    [anon_sym_wire] = ACTIONS(11739),
    [anon_sym_tri] = ACTIONS(11739),
    [anon_sym_tri0] = ACTIONS(11739),
    [anon_sym_tri1] = ACTIONS(11739),
    [anon_sym_wand] = ACTIONS(11739),
    [anon_sym_triand] = ACTIONS(11739),
    [anon_sym_wor] = ACTIONS(11739),
    [anon_sym_trior] = ACTIONS(11739),
    [anon_sym_trireg] = ACTIONS(11739),
    [anon_sym_uwire] = ACTIONS(11739),
    [anon_sym_SEMI] = ACTIONS(11742),
    [anon_sym_extern] = ACTIONS(11739),
    [anon_sym_endinterface] = ACTIONS(11739),
    [anon_sym_interface] = ACTIONS(11739),
    [anon_sym_program] = ACTIONS(11739),
    [anon_sym_checker] = ACTIONS(11739),
    [anon_sym_virtual] = ACTIONS(11739),
    [anon_sym_class] = ACTIONS(11739),
    [anon_sym_timeunit] = ACTIONS(11739),
    [anon_sym_timeprecision] = ACTIONS(11739),
    [anon_sym_type] = ACTIONS(11739),
    [anon_sym_input] = ACTIONS(11739),
    [anon_sym_output] = ACTIONS(11739),
    [anon_sym_inout] = ACTIONS(11739),
    [anon_sym_ref] = ACTIONS(11739),
    [anon_sym_DOLLARfatal] = ACTIONS(11742),
    [anon_sym_DOLLARerror] = ACTIONS(11742),
    [anon_sym_DOLLARwarning] = ACTIONS(11742),
    [anon_sym_DOLLARinfo] = ACTIONS(11742),
    [anon_sym_default] = ACTIONS(11739),
    [anon_sym_clocking] = ACTIONS(11739),
    [anon_sym_bind] = ACTIONS(11739),
    [anon_sym_const] = ACTIONS(11739),
    [anon_sym_function] = ACTIONS(11739),
    [anon_sym_static] = ACTIONS(11739),
    [anon_sym_constraint] = ACTIONS(11739),
    [anon_sym_if] = ACTIONS(11739),
    [anon_sym_LBRACK] = ACTIONS(11742),
    [anon_sym_localparam] = ACTIONS(11739),
    [anon_sym_parameter] = ACTIONS(11739),
    [anon_sym_var] = ACTIONS(11739),
    [anon_sym_import] = ACTIONS(11739),
    [anon_sym_export] = ACTIONS(11739),
    [anon_sym_genvar] = ACTIONS(11739),
    [anon_sym_interconnect] = ACTIONS(11739),
    [anon_sym_typedef] = ACTIONS(11739),
    [anon_sym_enum] = ACTIONS(11739),
    [anon_sym_struct] = ACTIONS(11739),
    [anon_sym_union] = ACTIONS(11739),
    [anon_sym_nettype] = ACTIONS(11739),
    [anon_sym_automatic] = ACTIONS(11739),
    [anon_sym_string] = ACTIONS(11739),
    [anon_sym_chandle] = ACTIONS(11739),
    [anon_sym_event] = ACTIONS(11739),
    [anon_sym_byte] = ACTIONS(11739),
    [anon_sym_shortint] = ACTIONS(11739),
    [anon_sym_int] = ACTIONS(11739),
    [anon_sym_longint] = ACTIONS(11739),
    [anon_sym_integer] = ACTIONS(11739),
    [anon_sym_time] = ACTIONS(11739),
    [anon_sym_bit] = ACTIONS(11739),
    [anon_sym_logic] = ACTIONS(11739),
    [anon_sym_reg] = ACTIONS(11739),
    [anon_sym_shortreal] = ACTIONS(11739),
    [anon_sym_real] = ACTIONS(11739),
    [anon_sym_realtime] = ACTIONS(11739),
    [anon_sym_supply0] = ACTIONS(11739),
    [anon_sym_supply1] = ACTIONS(11739),
    [anon_sym_signed] = ACTIONS(11739),
    [anon_sym_unsigned] = ACTIONS(11739),
    [anon_sym_task] = ACTIONS(11739),
    [anon_sym_modport] = ACTIONS(11739),
    [anon_sym_assert] = ACTIONS(11739),
    [anon_sym_property] = ACTIONS(11739),
    [anon_sym_assume] = ACTIONS(11739),
    [anon_sym_cover] = ACTIONS(11739),
    [anon_sym_sequence] = ACTIONS(11739),
    [anon_sym_restrict] = ACTIONS(11739),
    [anon_sym_case] = ACTIONS(11739),
    [anon_sym_always] = ACTIONS(11739),
    [anon_sym_covergroup] = ACTIONS(11739),
    [anon_sym_let] = ACTIONS(11739),
    [anon_sym_generate] = ACTIONS(11739),
    [anon_sym_for] = ACTIONS(11739),
    [anon_sym_initial] = ACTIONS(11739),
    [anon_sym_assign] = ACTIONS(11739),
    [anon_sym_alias] = ACTIONS(11739),
    [anon_sym_always_comb] = ACTIONS(11739),
    [anon_sym_always_latch] = ACTIONS(11739),
    [anon_sym_always_ff] = ACTIONS(11739),
    [anon_sym_final] = ACTIONS(11739),
    [anon_sym_global] = ACTIONS(11739),
    [anon_sym_LPAREN_STAR] = ACTIONS(11742),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11742),
    [anon_sym_DOLLARunit] = ACTIONS(11742),
  },
  [5382] = {
    [sym_simple_identifier] = ACTIONS(11745),
    [anon_sym_wire] = ACTIONS(11745),
    [anon_sym_tri] = ACTIONS(11745),
    [anon_sym_tri0] = ACTIONS(11745),
    [anon_sym_tri1] = ACTIONS(11745),
    [anon_sym_wand] = ACTIONS(11745),
    [anon_sym_triand] = ACTIONS(11745),
    [anon_sym_wor] = ACTIONS(11745),
    [anon_sym_trior] = ACTIONS(11745),
    [anon_sym_trireg] = ACTIONS(11745),
    [anon_sym_uwire] = ACTIONS(11745),
    [anon_sym_SEMI] = ACTIONS(11747),
    [anon_sym_extern] = ACTIONS(11745),
    [anon_sym_endinterface] = ACTIONS(11745),
    [anon_sym_interface] = ACTIONS(11745),
    [anon_sym_program] = ACTIONS(11745),
    [anon_sym_checker] = ACTIONS(11745),
    [anon_sym_virtual] = ACTIONS(11745),
    [anon_sym_class] = ACTIONS(11745),
    [anon_sym_timeunit] = ACTIONS(11745),
    [anon_sym_timeprecision] = ACTIONS(11745),
    [anon_sym_type] = ACTIONS(11745),
    [anon_sym_input] = ACTIONS(11745),
    [anon_sym_output] = ACTIONS(11745),
    [anon_sym_inout] = ACTIONS(11745),
    [anon_sym_ref] = ACTIONS(11745),
    [anon_sym_DOLLARfatal] = ACTIONS(11747),
    [anon_sym_DOLLARerror] = ACTIONS(11747),
    [anon_sym_DOLLARwarning] = ACTIONS(11747),
    [anon_sym_DOLLARinfo] = ACTIONS(11747),
    [anon_sym_default] = ACTIONS(11745),
    [anon_sym_clocking] = ACTIONS(11745),
    [anon_sym_bind] = ACTIONS(11745),
    [anon_sym_const] = ACTIONS(11745),
    [anon_sym_function] = ACTIONS(11745),
    [anon_sym_static] = ACTIONS(11745),
    [anon_sym_constraint] = ACTIONS(11745),
    [anon_sym_if] = ACTIONS(11745),
    [anon_sym_LBRACK] = ACTIONS(11747),
    [anon_sym_localparam] = ACTIONS(11745),
    [anon_sym_parameter] = ACTIONS(11745),
    [anon_sym_var] = ACTIONS(11745),
    [anon_sym_import] = ACTIONS(11745),
    [anon_sym_export] = ACTIONS(11745),
    [anon_sym_genvar] = ACTIONS(11745),
    [anon_sym_interconnect] = ACTIONS(11745),
    [anon_sym_typedef] = ACTIONS(11745),
    [anon_sym_enum] = ACTIONS(11745),
    [anon_sym_struct] = ACTIONS(11745),
    [anon_sym_union] = ACTIONS(11745),
    [anon_sym_nettype] = ACTIONS(11745),
    [anon_sym_automatic] = ACTIONS(11745),
    [anon_sym_string] = ACTIONS(11745),
    [anon_sym_chandle] = ACTIONS(11745),
    [anon_sym_event] = ACTIONS(11745),
    [anon_sym_byte] = ACTIONS(11745),
    [anon_sym_shortint] = ACTIONS(11745),
    [anon_sym_int] = ACTIONS(11745),
    [anon_sym_longint] = ACTIONS(11745),
    [anon_sym_integer] = ACTIONS(11745),
    [anon_sym_time] = ACTIONS(11745),
    [anon_sym_bit] = ACTIONS(11745),
    [anon_sym_logic] = ACTIONS(11745),
    [anon_sym_reg] = ACTIONS(11745),
    [anon_sym_shortreal] = ACTIONS(11745),
    [anon_sym_real] = ACTIONS(11745),
    [anon_sym_realtime] = ACTIONS(11745),
    [anon_sym_supply0] = ACTIONS(11745),
    [anon_sym_supply1] = ACTIONS(11745),
    [anon_sym_signed] = ACTIONS(11745),
    [anon_sym_unsigned] = ACTIONS(11745),
    [anon_sym_task] = ACTIONS(11745),
    [anon_sym_modport] = ACTIONS(11745),
    [anon_sym_assert] = ACTIONS(11745),
    [anon_sym_property] = ACTIONS(11745),
    [anon_sym_assume] = ACTIONS(11745),
    [anon_sym_cover] = ACTIONS(11745),
    [anon_sym_sequence] = ACTIONS(11745),
    [anon_sym_restrict] = ACTIONS(11745),
    [anon_sym_case] = ACTIONS(11745),
    [anon_sym_always] = ACTIONS(11745),
    [anon_sym_covergroup] = ACTIONS(11745),
    [anon_sym_let] = ACTIONS(11745),
    [anon_sym_generate] = ACTIONS(11745),
    [anon_sym_for] = ACTIONS(11745),
    [anon_sym_initial] = ACTIONS(11745),
    [anon_sym_assign] = ACTIONS(11745),
    [anon_sym_alias] = ACTIONS(11745),
    [anon_sym_always_comb] = ACTIONS(11745),
    [anon_sym_always_latch] = ACTIONS(11745),
    [anon_sym_always_ff] = ACTIONS(11745),
    [anon_sym_final] = ACTIONS(11745),
    [anon_sym_global] = ACTIONS(11745),
    [anon_sym_LPAREN_STAR] = ACTIONS(11747),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11747),
    [anon_sym_DOLLARunit] = ACTIONS(11747),
  },
  [5383] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5606),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16934),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11665),
    [anon_sym_DQUOTE] = ACTIONS(11667),
    [anon_sym_LT] = ACTIONS(11665),
    [anon_sym_GT] = ACTIONS(11665),
    [anon_sym_LPAREN] = ACTIONS(11667),
    [anon_sym_RPAREN] = ACTIONS(11667),
    [anon_sym_COMMA] = ACTIONS(11667),
    [anon_sym_BQUOTE] = ACTIONS(11667),
    [anon_sym_SLASH] = ACTIONS(11665),
    [anon_sym_COLON] = ACTIONS(11667),
    [anon_sym_type] = ACTIONS(11665),
    [anon_sym_DOT] = ACTIONS(11667),
    [anon_sym_LBRACE] = ACTIONS(11667),
    [anon_sym_const] = ACTIONS(11665),
    [anon_sym_local] = ACTIONS(11665),
    [anon_sym_super] = ACTIONS(11665),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11665),
    [anon_sym_string] = ACTIONS(11665),
    [anon_sym_byte] = ACTIONS(11665),
    [anon_sym_shortint] = ACTIONS(11665),
    [anon_sym_int] = ACTIONS(11665),
    [anon_sym_longint] = ACTIONS(11665),
    [anon_sym_integer] = ACTIONS(11665),
    [anon_sym_time] = ACTIONS(11665),
    [anon_sym_bit] = ACTIONS(11665),
    [anon_sym_logic] = ACTIONS(11665),
    [anon_sym_reg] = ACTIONS(11665),
    [anon_sym_shortreal] = ACTIONS(11665),
    [anon_sym_real] = ACTIONS(11665),
    [anon_sym_realtime] = ACTIONS(11665),
    [anon_sym_signed] = ACTIONS(11665),
    [anon_sym_unsigned] = ACTIONS(11665),
    [anon_sym_tagged] = ACTIONS(11665),
    [anon_sym_DOLLAR] = ACTIONS(11665),
    [anon_sym_PLUS] = ACTIONS(11665),
    [anon_sym_PLUS_PLUS] = ACTIONS(11667),
    [anon_sym_STAR_STAR] = ACTIONS(11667),
    [anon_sym_PERCENT] = ACTIONS(11667),
    [anon_sym_EQ_EQ] = ACTIONS(11665),
    [anon_sym_BANG_EQ] = ACTIONS(11665),
    [anon_sym_LT_EQ] = ACTIONS(11667),
    [anon_sym_GT_EQ] = ACTIONS(11667),
    [anon_sym_BANG] = ACTIONS(11665),
    [anon_sym_AMP_AMP] = ACTIONS(11665),
    [anon_sym_PIPE_PIPE] = ACTIONS(11667),
    [anon_sym_matches] = ACTIONS(11665),
    [anon_sym_DASH] = ACTIONS(11665),
    [anon_sym_DASH_GT] = ACTIONS(11667),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11667),
    [anon_sym_inside] = ACTIONS(11665),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11667),
    [anon_sym_TILDE] = ACTIONS(11665),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11667),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11667),
    [anon_sym_GT_GT] = ACTIONS(11665),
    [anon_sym_LT_LT] = ACTIONS(11665),
    [anon_sym_std] = ACTIONS(11665),
    [anon_sym_randomize] = ACTIONS(11665),
    [anon_sym_null] = ACTIONS(11665),
    [anon_sym_QMARK] = ACTIONS(11667),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_AMP] = ACTIONS(11665),
    [anon_sym_PIPE] = ACTIONS(11665),
    [anon_sym_CARET] = ACTIONS(11665),
    [anon_sym_CARET_TILDE] = ACTIONS(11667),
    [anon_sym_TILDE_CARET] = ACTIONS(11667),
    [anon_sym_GT_GT_GT] = ACTIONS(11667),
    [anon_sym_LT_LT_LT] = ACTIONS(11667),
    [anon_sym_LT_DASH_GT] = ACTIONS(11667),
    [anon_sym_this] = ACTIONS(11665),
    [anon_sym_TILDE_AMP] = ACTIONS(11667),
    [anon_sym_TILDE_PIPE] = ACTIONS(11667),
    [anon_sym_DASH_DASH] = ACTIONS(11667),
    [aux_sym_decimal_number_token1] = ACTIONS(11667),
    [aux_sym_decimal_number_token2] = ACTIONS(11667),
    [sym_binary_number] = ACTIONS(11667),
    [sym_octal_number] = ACTIONS(11667),
    [sym_hex_number] = ACTIONS(11667),
    [aux_sym_real_number_token1] = ACTIONS(11667),
    [sym_fixed_point_number] = ACTIONS(11665),
    [sym_unsigned_number] = ACTIONS(11665),
    [anon_sym_SQUOTE0] = ACTIONS(11667),
    [anon_sym_SQUOTE1] = ACTIONS(11667),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11667),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11667),
    [anon_sym_DOLLARroot] = ACTIONS(11665),
    [anon_sym_DOLLARunit] = ACTIONS(11665),
    [sym_system_tf_identifier] = ACTIONS(11665),
  },
  [5384] = {
    [sym_simple_identifier] = ACTIONS(11749),
    [anon_sym_DQUOTE] = ACTIONS(11751),
    [anon_sym_LT] = ACTIONS(11749),
    [anon_sym_GT] = ACTIONS(11749),
    [anon_sym_LPAREN] = ACTIONS(11749),
    [anon_sym_RPAREN] = ACTIONS(11751),
    [anon_sym_COMMA] = ACTIONS(11719),
    [anon_sym_BQUOTE] = ACTIONS(11751),
    [anon_sym_SLASH] = ACTIONS(11749),
    [anon_sym_SEMI] = ACTIONS(11751),
    [anon_sym_COLON] = ACTIONS(11751),
    [anon_sym_type] = ACTIONS(11749),
    [anon_sym_DOT] = ACTIONS(11751),
    [anon_sym_LBRACE] = ACTIONS(11751),
    [anon_sym_RBRACE] = ACTIONS(11719),
    [anon_sym_iff] = ACTIONS(11749),
    [anon_sym_const] = ACTIONS(11749),
    [anon_sym_local] = ACTIONS(11749),
    [anon_sym_super] = ACTIONS(11749),
    [anon_sym_u2013_GT] = ACTIONS(11751),
    [anon_sym_STAR] = ACTIONS(11749),
    [anon_sym_with] = ACTIONS(11749),
    [anon_sym_string] = ACTIONS(11749),
    [anon_sym_byte] = ACTIONS(11749),
    [anon_sym_shortint] = ACTIONS(11749),
    [anon_sym_int] = ACTIONS(11749),
    [anon_sym_longint] = ACTIONS(11749),
    [anon_sym_integer] = ACTIONS(11749),
    [anon_sym_time] = ACTIONS(11749),
    [anon_sym_bit] = ACTIONS(11749),
    [anon_sym_logic] = ACTIONS(11749),
    [anon_sym_reg] = ACTIONS(11749),
    [anon_sym_shortreal] = ACTIONS(11749),
    [anon_sym_real] = ACTIONS(11749),
    [anon_sym_realtime] = ACTIONS(11749),
    [anon_sym_signed] = ACTIONS(11749),
    [anon_sym_unsigned] = ACTIONS(11749),
    [anon_sym_tagged] = ACTIONS(11749),
    [anon_sym_DOLLAR] = ACTIONS(11749),
    [anon_sym_PLUS] = ACTIONS(11749),
    [anon_sym_PLUS_PLUS] = ACTIONS(11719),
    [anon_sym_STAR_STAR] = ACTIONS(11751),
    [anon_sym_PERCENT] = ACTIONS(11751),
    [anon_sym_EQ_EQ] = ACTIONS(11749),
    [anon_sym_BANG_EQ] = ACTIONS(11749),
    [anon_sym_LT_EQ] = ACTIONS(11751),
    [anon_sym_GT_EQ] = ACTIONS(11751),
    [anon_sym_dist] = ACTIONS(11749),
    [anon_sym_BANG] = ACTIONS(11749),
    [anon_sym_AMP_AMP] = ACTIONS(11749),
    [anon_sym_PIPE_PIPE] = ACTIONS(11751),
    [anon_sym_matches] = ACTIONS(11749),
    [anon_sym_DASH] = ACTIONS(11749),
    [anon_sym_DASH_GT] = ACTIONS(11751),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11751),
    [anon_sym_inside] = ACTIONS(11749),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11751),
    [anon_sym_TILDE] = ACTIONS(11749),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11751),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11751),
    [anon_sym_GT_GT] = ACTIONS(11749),
    [anon_sym_LT_LT] = ACTIONS(11749),
    [anon_sym_std] = ACTIONS(11749),
    [anon_sym_randomize] = ACTIONS(11749),
    [anon_sym_null] = ACTIONS(11749),
    [anon_sym_QMARK] = ACTIONS(11751),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11751),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11751),
    [anon_sym_AMP] = ACTIONS(11749),
    [anon_sym_PIPE] = ACTIONS(11749),
    [anon_sym_CARET] = ACTIONS(11749),
    [anon_sym_CARET_TILDE] = ACTIONS(11751),
    [anon_sym_TILDE_CARET] = ACTIONS(11751),
    [anon_sym_GT_GT_GT] = ACTIONS(11751),
    [anon_sym_LT_LT_LT] = ACTIONS(11751),
    [anon_sym_LT_DASH_GT] = ACTIONS(11751),
    [anon_sym_this] = ACTIONS(11749),
    [anon_sym_TILDE_AMP] = ACTIONS(11751),
    [anon_sym_TILDE_PIPE] = ACTIONS(11751),
    [anon_sym_DASH_DASH] = ACTIONS(11719),
    [aux_sym_decimal_number_token1] = ACTIONS(11751),
    [aux_sym_decimal_number_token2] = ACTIONS(11751),
    [sym_binary_number] = ACTIONS(11751),
    [sym_octal_number] = ACTIONS(11751),
    [sym_hex_number] = ACTIONS(11751),
    [aux_sym_real_number_token1] = ACTIONS(11751),
    [sym_fixed_point_number] = ACTIONS(11749),
    [sym_unsigned_number] = ACTIONS(11749),
    [anon_sym_SQUOTE0] = ACTIONS(11751),
    [anon_sym_SQUOTE1] = ACTIONS(11751),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11751),
    [anon_sym_LPAREN_STAR] = ACTIONS(11719),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11751),
    [anon_sym_DOLLARroot] = ACTIONS(11749),
    [anon_sym_DOLLARunit] = ACTIONS(11749),
    [sym_system_tf_identifier] = ACTIONS(11749),
  },
  [5385] = {
    [sym_simple_identifier] = ACTIONS(11753),
    [anon_sym_wire] = ACTIONS(11753),
    [anon_sym_tri] = ACTIONS(11753),
    [anon_sym_tri0] = ACTIONS(11753),
    [anon_sym_tri1] = ACTIONS(11753),
    [anon_sym_wand] = ACTIONS(11753),
    [anon_sym_triand] = ACTIONS(11753),
    [anon_sym_wor] = ACTIONS(11753),
    [anon_sym_trior] = ACTIONS(11753),
    [anon_sym_trireg] = ACTIONS(11753),
    [anon_sym_uwire] = ACTIONS(11753),
    [anon_sym_SEMI] = ACTIONS(11755),
    [anon_sym_extern] = ACTIONS(11753),
    [anon_sym_endinterface] = ACTIONS(11753),
    [anon_sym_interface] = ACTIONS(11753),
    [anon_sym_program] = ACTIONS(11753),
    [anon_sym_checker] = ACTIONS(11753),
    [anon_sym_virtual] = ACTIONS(11753),
    [anon_sym_class] = ACTIONS(11753),
    [anon_sym_timeunit] = ACTIONS(11753),
    [anon_sym_timeprecision] = ACTIONS(11753),
    [anon_sym_type] = ACTIONS(11753),
    [anon_sym_input] = ACTIONS(11753),
    [anon_sym_output] = ACTIONS(11753),
    [anon_sym_inout] = ACTIONS(11753),
    [anon_sym_ref] = ACTIONS(11753),
    [anon_sym_DOLLARfatal] = ACTIONS(11755),
    [anon_sym_DOLLARerror] = ACTIONS(11755),
    [anon_sym_DOLLARwarning] = ACTIONS(11755),
    [anon_sym_DOLLARinfo] = ACTIONS(11755),
    [anon_sym_default] = ACTIONS(11753),
    [anon_sym_clocking] = ACTIONS(11753),
    [anon_sym_bind] = ACTIONS(11753),
    [anon_sym_const] = ACTIONS(11753),
    [anon_sym_function] = ACTIONS(11753),
    [anon_sym_static] = ACTIONS(11753),
    [anon_sym_constraint] = ACTIONS(11753),
    [anon_sym_if] = ACTIONS(11753),
    [anon_sym_LBRACK] = ACTIONS(11755),
    [anon_sym_localparam] = ACTIONS(11753),
    [anon_sym_parameter] = ACTIONS(11753),
    [anon_sym_var] = ACTIONS(11753),
    [anon_sym_import] = ACTIONS(11753),
    [anon_sym_export] = ACTIONS(11753),
    [anon_sym_genvar] = ACTIONS(11753),
    [anon_sym_interconnect] = ACTIONS(11753),
    [anon_sym_typedef] = ACTIONS(11753),
    [anon_sym_enum] = ACTIONS(11753),
    [anon_sym_struct] = ACTIONS(11753),
    [anon_sym_union] = ACTIONS(11753),
    [anon_sym_nettype] = ACTIONS(11753),
    [anon_sym_automatic] = ACTIONS(11753),
    [anon_sym_string] = ACTIONS(11753),
    [anon_sym_chandle] = ACTIONS(11753),
    [anon_sym_event] = ACTIONS(11753),
    [anon_sym_byte] = ACTIONS(11753),
    [anon_sym_shortint] = ACTIONS(11753),
    [anon_sym_int] = ACTIONS(11753),
    [anon_sym_longint] = ACTIONS(11753),
    [anon_sym_integer] = ACTIONS(11753),
    [anon_sym_time] = ACTIONS(11753),
    [anon_sym_bit] = ACTIONS(11753),
    [anon_sym_logic] = ACTIONS(11753),
    [anon_sym_reg] = ACTIONS(11753),
    [anon_sym_shortreal] = ACTIONS(11753),
    [anon_sym_real] = ACTIONS(11753),
    [anon_sym_realtime] = ACTIONS(11753),
    [anon_sym_supply0] = ACTIONS(11753),
    [anon_sym_supply1] = ACTIONS(11753),
    [anon_sym_signed] = ACTIONS(11753),
    [anon_sym_unsigned] = ACTIONS(11753),
    [anon_sym_task] = ACTIONS(11753),
    [anon_sym_modport] = ACTIONS(11753),
    [anon_sym_assert] = ACTIONS(11753),
    [anon_sym_property] = ACTIONS(11753),
    [anon_sym_assume] = ACTIONS(11753),
    [anon_sym_cover] = ACTIONS(11753),
    [anon_sym_sequence] = ACTIONS(11753),
    [anon_sym_restrict] = ACTIONS(11753),
    [anon_sym_case] = ACTIONS(11753),
    [anon_sym_always] = ACTIONS(11753),
    [anon_sym_covergroup] = ACTIONS(11753),
    [anon_sym_let] = ACTIONS(11753),
    [anon_sym_generate] = ACTIONS(11753),
    [anon_sym_for] = ACTIONS(11753),
    [anon_sym_initial] = ACTIONS(11753),
    [anon_sym_assign] = ACTIONS(11753),
    [anon_sym_alias] = ACTIONS(11753),
    [anon_sym_always_comb] = ACTIONS(11753),
    [anon_sym_always_latch] = ACTIONS(11753),
    [anon_sym_always_ff] = ACTIONS(11753),
    [anon_sym_final] = ACTIONS(11753),
    [anon_sym_global] = ACTIONS(11753),
    [anon_sym_LPAREN_STAR] = ACTIONS(11755),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11755),
    [anon_sym_DOLLARunit] = ACTIONS(11755),
  },
  [5386] = {
    [sym_simple_identifier] = ACTIONS(11757),
    [anon_sym_wire] = ACTIONS(11757),
    [anon_sym_tri] = ACTIONS(11757),
    [anon_sym_tri0] = ACTIONS(11757),
    [anon_sym_tri1] = ACTIONS(11757),
    [anon_sym_wand] = ACTIONS(11757),
    [anon_sym_triand] = ACTIONS(11757),
    [anon_sym_wor] = ACTIONS(11757),
    [anon_sym_trior] = ACTIONS(11757),
    [anon_sym_trireg] = ACTIONS(11757),
    [anon_sym_uwire] = ACTIONS(11757),
    [anon_sym_SEMI] = ACTIONS(11759),
    [anon_sym_extern] = ACTIONS(11757),
    [anon_sym_endinterface] = ACTIONS(11757),
    [anon_sym_interface] = ACTIONS(11757),
    [anon_sym_program] = ACTIONS(11757),
    [anon_sym_checker] = ACTIONS(11757),
    [anon_sym_virtual] = ACTIONS(11757),
    [anon_sym_class] = ACTIONS(11757),
    [anon_sym_timeunit] = ACTIONS(11757),
    [anon_sym_timeprecision] = ACTIONS(11757),
    [anon_sym_type] = ACTIONS(11757),
    [anon_sym_input] = ACTIONS(11757),
    [anon_sym_output] = ACTIONS(11757),
    [anon_sym_inout] = ACTIONS(11757),
    [anon_sym_ref] = ACTIONS(11757),
    [anon_sym_DOLLARfatal] = ACTIONS(11759),
    [anon_sym_DOLLARerror] = ACTIONS(11759),
    [anon_sym_DOLLARwarning] = ACTIONS(11759),
    [anon_sym_DOLLARinfo] = ACTIONS(11759),
    [anon_sym_default] = ACTIONS(11757),
    [anon_sym_clocking] = ACTIONS(11757),
    [anon_sym_bind] = ACTIONS(11757),
    [anon_sym_const] = ACTIONS(11757),
    [anon_sym_function] = ACTIONS(11757),
    [anon_sym_static] = ACTIONS(11757),
    [anon_sym_constraint] = ACTIONS(11757),
    [anon_sym_if] = ACTIONS(11757),
    [anon_sym_LBRACK] = ACTIONS(11759),
    [anon_sym_localparam] = ACTIONS(11757),
    [anon_sym_parameter] = ACTIONS(11757),
    [anon_sym_var] = ACTIONS(11757),
    [anon_sym_import] = ACTIONS(11757),
    [anon_sym_export] = ACTIONS(11757),
    [anon_sym_genvar] = ACTIONS(11757),
    [anon_sym_interconnect] = ACTIONS(11757),
    [anon_sym_typedef] = ACTIONS(11757),
    [anon_sym_enum] = ACTIONS(11757),
    [anon_sym_struct] = ACTIONS(11757),
    [anon_sym_union] = ACTIONS(11757),
    [anon_sym_nettype] = ACTIONS(11757),
    [anon_sym_automatic] = ACTIONS(11757),
    [anon_sym_string] = ACTIONS(11757),
    [anon_sym_chandle] = ACTIONS(11757),
    [anon_sym_event] = ACTIONS(11757),
    [anon_sym_byte] = ACTIONS(11757),
    [anon_sym_shortint] = ACTIONS(11757),
    [anon_sym_int] = ACTIONS(11757),
    [anon_sym_longint] = ACTIONS(11757),
    [anon_sym_integer] = ACTIONS(11757),
    [anon_sym_time] = ACTIONS(11757),
    [anon_sym_bit] = ACTIONS(11757),
    [anon_sym_logic] = ACTIONS(11757),
    [anon_sym_reg] = ACTIONS(11757),
    [anon_sym_shortreal] = ACTIONS(11757),
    [anon_sym_real] = ACTIONS(11757),
    [anon_sym_realtime] = ACTIONS(11757),
    [anon_sym_supply0] = ACTIONS(11757),
    [anon_sym_supply1] = ACTIONS(11757),
    [anon_sym_signed] = ACTIONS(11757),
    [anon_sym_unsigned] = ACTIONS(11757),
    [anon_sym_task] = ACTIONS(11757),
    [anon_sym_modport] = ACTIONS(11757),
    [anon_sym_assert] = ACTIONS(11757),
    [anon_sym_property] = ACTIONS(11757),
    [anon_sym_assume] = ACTIONS(11757),
    [anon_sym_cover] = ACTIONS(11757),
    [anon_sym_sequence] = ACTIONS(11757),
    [anon_sym_restrict] = ACTIONS(11757),
    [anon_sym_case] = ACTIONS(11757),
    [anon_sym_always] = ACTIONS(11757),
    [anon_sym_covergroup] = ACTIONS(11757),
    [anon_sym_let] = ACTIONS(11757),
    [anon_sym_generate] = ACTIONS(11757),
    [anon_sym_for] = ACTIONS(11757),
    [anon_sym_initial] = ACTIONS(11757),
    [anon_sym_assign] = ACTIONS(11757),
    [anon_sym_alias] = ACTIONS(11757),
    [anon_sym_always_comb] = ACTIONS(11757),
    [anon_sym_always_latch] = ACTIONS(11757),
    [anon_sym_always_ff] = ACTIONS(11757),
    [anon_sym_final] = ACTIONS(11757),
    [anon_sym_global] = ACTIONS(11757),
    [anon_sym_LPAREN_STAR] = ACTIONS(11759),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11759),
    [anon_sym_DOLLARunit] = ACTIONS(11759),
  },
  [5387] = {
    [sym_simple_identifier] = ACTIONS(11710),
    [anon_sym_DQUOTE] = ACTIONS(11712),
    [anon_sym_LT] = ACTIONS(11710),
    [anon_sym_GT] = ACTIONS(11710),
    [anon_sym_LPAREN] = ACTIONS(11710),
    [anon_sym_RPAREN] = ACTIONS(11712),
    [anon_sym_COMMA] = ACTIONS(11555),
    [anon_sym_BQUOTE] = ACTIONS(11712),
    [anon_sym_SLASH] = ACTIONS(11710),
    [anon_sym_SEMI] = ACTIONS(11712),
    [anon_sym_COLON] = ACTIONS(11712),
    [anon_sym_type] = ACTIONS(11710),
    [anon_sym_DOT] = ACTIONS(11712),
    [anon_sym_LBRACE] = ACTIONS(11712),
    [anon_sym_RBRACE] = ACTIONS(11555),
    [anon_sym_iff] = ACTIONS(11710),
    [anon_sym_const] = ACTIONS(11710),
    [anon_sym_local] = ACTIONS(11710),
    [anon_sym_super] = ACTIONS(11710),
    [anon_sym_u2013_GT] = ACTIONS(11712),
    [anon_sym_STAR] = ACTIONS(11710),
    [anon_sym_with] = ACTIONS(11710),
    [anon_sym_string] = ACTIONS(11710),
    [anon_sym_byte] = ACTIONS(11710),
    [anon_sym_shortint] = ACTIONS(11710),
    [anon_sym_int] = ACTIONS(11710),
    [anon_sym_longint] = ACTIONS(11710),
    [anon_sym_integer] = ACTIONS(11710),
    [anon_sym_time] = ACTIONS(11710),
    [anon_sym_bit] = ACTIONS(11710),
    [anon_sym_logic] = ACTIONS(11710),
    [anon_sym_reg] = ACTIONS(11710),
    [anon_sym_shortreal] = ACTIONS(11710),
    [anon_sym_real] = ACTIONS(11710),
    [anon_sym_realtime] = ACTIONS(11710),
    [anon_sym_signed] = ACTIONS(11710),
    [anon_sym_unsigned] = ACTIONS(11710),
    [anon_sym_tagged] = ACTIONS(11710),
    [anon_sym_DOLLAR] = ACTIONS(11710),
    [anon_sym_PLUS] = ACTIONS(11710),
    [anon_sym_PLUS_PLUS] = ACTIONS(11555),
    [anon_sym_STAR_STAR] = ACTIONS(11712),
    [anon_sym_PERCENT] = ACTIONS(11712),
    [anon_sym_EQ_EQ] = ACTIONS(11710),
    [anon_sym_BANG_EQ] = ACTIONS(11710),
    [anon_sym_LT_EQ] = ACTIONS(11712),
    [anon_sym_GT_EQ] = ACTIONS(11712),
    [anon_sym_dist] = ACTIONS(11710),
    [anon_sym_BANG] = ACTIONS(11710),
    [anon_sym_AMP_AMP] = ACTIONS(11710),
    [anon_sym_PIPE_PIPE] = ACTIONS(11712),
    [anon_sym_matches] = ACTIONS(11710),
    [anon_sym_DASH] = ACTIONS(11710),
    [anon_sym_DASH_GT] = ACTIONS(11712),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11712),
    [anon_sym_inside] = ACTIONS(11710),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11712),
    [anon_sym_TILDE] = ACTIONS(11710),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11712),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11712),
    [anon_sym_GT_GT] = ACTIONS(11710),
    [anon_sym_LT_LT] = ACTIONS(11710),
    [anon_sym_std] = ACTIONS(11710),
    [anon_sym_randomize] = ACTIONS(11710),
    [anon_sym_null] = ACTIONS(11710),
    [anon_sym_QMARK] = ACTIONS(11712),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_AMP] = ACTIONS(11710),
    [anon_sym_PIPE] = ACTIONS(11710),
    [anon_sym_CARET] = ACTIONS(11710),
    [anon_sym_CARET_TILDE] = ACTIONS(11712),
    [anon_sym_TILDE_CARET] = ACTIONS(11712),
    [anon_sym_GT_GT_GT] = ACTIONS(11712),
    [anon_sym_LT_LT_LT] = ACTIONS(11712),
    [anon_sym_LT_DASH_GT] = ACTIONS(11712),
    [anon_sym_this] = ACTIONS(11710),
    [anon_sym_TILDE_AMP] = ACTIONS(11712),
    [anon_sym_TILDE_PIPE] = ACTIONS(11712),
    [anon_sym_DASH_DASH] = ACTIONS(11555),
    [aux_sym_decimal_number_token1] = ACTIONS(11712),
    [aux_sym_decimal_number_token2] = ACTIONS(11712),
    [sym_binary_number] = ACTIONS(11712),
    [sym_octal_number] = ACTIONS(11712),
    [sym_hex_number] = ACTIONS(11712),
    [aux_sym_real_number_token1] = ACTIONS(11712),
    [sym_fixed_point_number] = ACTIONS(11710),
    [sym_unsigned_number] = ACTIONS(11710),
    [anon_sym_SQUOTE0] = ACTIONS(11712),
    [anon_sym_SQUOTE1] = ACTIONS(11712),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11712),
    [anon_sym_LPAREN_STAR] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11712),
    [anon_sym_DOLLARroot] = ACTIONS(11710),
    [anon_sym_DOLLARunit] = ACTIONS(11710),
    [sym_system_tf_identifier] = ACTIONS(11710),
  },
  [5388] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5384),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11665),
    [anon_sym_DQUOTE] = ACTIONS(11667),
    [anon_sym_LT] = ACTIONS(11665),
    [anon_sym_GT] = ACTIONS(11665),
    [anon_sym_LPAREN] = ACTIONS(11665),
    [anon_sym_RPAREN] = ACTIONS(11667),
    [anon_sym_BQUOTE] = ACTIONS(11667),
    [anon_sym_SLASH] = ACTIONS(11665),
    [anon_sym_COLON] = ACTIONS(11667),
    [anon_sym_type] = ACTIONS(11665),
    [anon_sym_DOT] = ACTIONS(11667),
    [anon_sym_LBRACE] = ACTIONS(11667),
    [anon_sym_const] = ACTIONS(11665),
    [anon_sym_local] = ACTIONS(11665),
    [anon_sym_super] = ACTIONS(11665),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11665),
    [anon_sym_string] = ACTIONS(11665),
    [anon_sym_byte] = ACTIONS(11665),
    [anon_sym_shortint] = ACTIONS(11665),
    [anon_sym_int] = ACTIONS(11665),
    [anon_sym_longint] = ACTIONS(11665),
    [anon_sym_integer] = ACTIONS(11665),
    [anon_sym_time] = ACTIONS(11665),
    [anon_sym_bit] = ACTIONS(11665),
    [anon_sym_logic] = ACTIONS(11665),
    [anon_sym_reg] = ACTIONS(11665),
    [anon_sym_shortreal] = ACTIONS(11665),
    [anon_sym_real] = ACTIONS(11665),
    [anon_sym_realtime] = ACTIONS(11665),
    [anon_sym_signed] = ACTIONS(11665),
    [anon_sym_unsigned] = ACTIONS(11665),
    [anon_sym_tagged] = ACTIONS(11665),
    [anon_sym_DOLLAR] = ACTIONS(11665),
    [anon_sym_PLUS] = ACTIONS(11665),
    [anon_sym_PLUS_PLUS] = ACTIONS(11669),
    [anon_sym_STAR_STAR] = ACTIONS(11667),
    [anon_sym_PERCENT] = ACTIONS(11667),
    [anon_sym_EQ_EQ] = ACTIONS(11665),
    [anon_sym_BANG_EQ] = ACTIONS(11665),
    [anon_sym_LT_EQ] = ACTIONS(11667),
    [anon_sym_GT_EQ] = ACTIONS(11667),
    [anon_sym_BANG] = ACTIONS(11665),
    [anon_sym_AMP_AMP] = ACTIONS(11665),
    [anon_sym_PIPE_PIPE] = ACTIONS(11667),
    [anon_sym_matches] = ACTIONS(11665),
    [anon_sym_DASH] = ACTIONS(11665),
    [anon_sym_DASH_GT] = ACTIONS(11667),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11667),
    [anon_sym_inside] = ACTIONS(11665),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11667),
    [anon_sym_TILDE] = ACTIONS(11665),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11667),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11667),
    [anon_sym_GT_GT] = ACTIONS(11665),
    [anon_sym_LT_LT] = ACTIONS(11665),
    [anon_sym_std] = ACTIONS(11665),
    [anon_sym_randomize] = ACTIONS(11665),
    [anon_sym_null] = ACTIONS(11665),
    [anon_sym_QMARK] = ACTIONS(11667),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11667),
    [anon_sym_AMP] = ACTIONS(11665),
    [anon_sym_PIPE] = ACTIONS(11665),
    [anon_sym_CARET] = ACTIONS(11665),
    [anon_sym_CARET_TILDE] = ACTIONS(11667),
    [anon_sym_TILDE_CARET] = ACTIONS(11667),
    [anon_sym_GT_GT_GT] = ACTIONS(11667),
    [anon_sym_LT_LT_LT] = ACTIONS(11667),
    [anon_sym_LT_DASH_GT] = ACTIONS(11667),
    [anon_sym_this] = ACTIONS(11665),
    [anon_sym_TILDE_AMP] = ACTIONS(11667),
    [anon_sym_TILDE_PIPE] = ACTIONS(11667),
    [anon_sym_DASH_DASH] = ACTIONS(11669),
    [aux_sym_decimal_number_token1] = ACTIONS(11667),
    [aux_sym_decimal_number_token2] = ACTIONS(11667),
    [sym_binary_number] = ACTIONS(11667),
    [sym_octal_number] = ACTIONS(11667),
    [sym_hex_number] = ACTIONS(11667),
    [aux_sym_real_number_token1] = ACTIONS(11667),
    [sym_fixed_point_number] = ACTIONS(11665),
    [sym_unsigned_number] = ACTIONS(11665),
    [anon_sym_SQUOTE0] = ACTIONS(11667),
    [anon_sym_SQUOTE1] = ACTIONS(11667),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11667),
    [anon_sym_LPAREN_STAR] = ACTIONS(11672),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11667),
    [anon_sym_DOLLARroot] = ACTIONS(11665),
    [anon_sym_DOLLARunit] = ACTIONS(11665),
    [sym_system_tf_identifier] = ACTIONS(11665),
  },
  [5389] = {
    [sym_bit_select1] = STATE(5395),
    [sym_select1] = STATE(5371),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5297),
    [aux_sym_select1_repeat1] = STATE(17318),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11710),
    [anon_sym_DQUOTE] = ACTIONS(11712),
    [anon_sym_LT] = ACTIONS(11710),
    [anon_sym_GT] = ACTIONS(11710),
    [anon_sym_LPAREN] = ACTIONS(11710),
    [anon_sym_RPAREN] = ACTIONS(11712),
    [anon_sym_BQUOTE] = ACTIONS(11712),
    [anon_sym_SLASH] = ACTIONS(11710),
    [anon_sym_COLON] = ACTIONS(11712),
    [anon_sym_type] = ACTIONS(11710),
    [anon_sym_DOT] = ACTIONS(11712),
    [anon_sym_LBRACE] = ACTIONS(11712),
    [anon_sym_const] = ACTIONS(11710),
    [anon_sym_local] = ACTIONS(11710),
    [anon_sym_super] = ACTIONS(11710),
    [anon_sym_LBRACK] = ACTIONS(11533),
    [anon_sym_STAR] = ACTIONS(11710),
    [anon_sym_string] = ACTIONS(11710),
    [anon_sym_byte] = ACTIONS(11710),
    [anon_sym_shortint] = ACTIONS(11710),
    [anon_sym_int] = ACTIONS(11710),
    [anon_sym_longint] = ACTIONS(11710),
    [anon_sym_integer] = ACTIONS(11710),
    [anon_sym_time] = ACTIONS(11710),
    [anon_sym_bit] = ACTIONS(11710),
    [anon_sym_logic] = ACTIONS(11710),
    [anon_sym_reg] = ACTIONS(11710),
    [anon_sym_shortreal] = ACTIONS(11710),
    [anon_sym_real] = ACTIONS(11710),
    [anon_sym_realtime] = ACTIONS(11710),
    [anon_sym_signed] = ACTIONS(11710),
    [anon_sym_unsigned] = ACTIONS(11710),
    [anon_sym_tagged] = ACTIONS(11710),
    [anon_sym_DOLLAR] = ACTIONS(11710),
    [anon_sym_PLUS] = ACTIONS(11710),
    [anon_sym_PLUS_PLUS] = ACTIONS(11714),
    [anon_sym_STAR_STAR] = ACTIONS(11712),
    [anon_sym_PERCENT] = ACTIONS(11712),
    [anon_sym_EQ_EQ] = ACTIONS(11710),
    [anon_sym_BANG_EQ] = ACTIONS(11710),
    [anon_sym_LT_EQ] = ACTIONS(11712),
    [anon_sym_GT_EQ] = ACTIONS(11712),
    [anon_sym_BANG] = ACTIONS(11710),
    [anon_sym_AMP_AMP] = ACTIONS(11710),
    [anon_sym_PIPE_PIPE] = ACTIONS(11712),
    [anon_sym_matches] = ACTIONS(11710),
    [anon_sym_DASH] = ACTIONS(11710),
    [anon_sym_DASH_GT] = ACTIONS(11712),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11712),
    [anon_sym_inside] = ACTIONS(11710),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11712),
    [anon_sym_TILDE] = ACTIONS(11710),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11712),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11712),
    [anon_sym_GT_GT] = ACTIONS(11710),
    [anon_sym_LT_LT] = ACTIONS(11710),
    [anon_sym_std] = ACTIONS(11710),
    [anon_sym_randomize] = ACTIONS(11710),
    [anon_sym_null] = ACTIONS(11710),
    [anon_sym_QMARK] = ACTIONS(11712),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11712),
    [anon_sym_AMP] = ACTIONS(11710),
    [anon_sym_PIPE] = ACTIONS(11710),
    [anon_sym_CARET] = ACTIONS(11710),
    [anon_sym_CARET_TILDE] = ACTIONS(11712),
    [anon_sym_TILDE_CARET] = ACTIONS(11712),
    [anon_sym_GT_GT_GT] = ACTIONS(11712),
    [anon_sym_LT_LT_LT] = ACTIONS(11712),
    [anon_sym_LT_DASH_GT] = ACTIONS(11712),
    [anon_sym_this] = ACTIONS(11710),
    [anon_sym_TILDE_AMP] = ACTIONS(11712),
    [anon_sym_TILDE_PIPE] = ACTIONS(11712),
    [anon_sym_DASH_DASH] = ACTIONS(11714),
    [aux_sym_decimal_number_token1] = ACTIONS(11712),
    [aux_sym_decimal_number_token2] = ACTIONS(11712),
    [sym_binary_number] = ACTIONS(11712),
    [sym_octal_number] = ACTIONS(11712),
    [sym_hex_number] = ACTIONS(11712),
    [aux_sym_real_number_token1] = ACTIONS(11712),
    [sym_fixed_point_number] = ACTIONS(11710),
    [sym_unsigned_number] = ACTIONS(11710),
    [anon_sym_SQUOTE0] = ACTIONS(11712),
    [anon_sym_SQUOTE1] = ACTIONS(11712),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11712),
    [anon_sym_LPAREN_STAR] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11712),
    [anon_sym_DOLLARroot] = ACTIONS(11710),
    [anon_sym_DOLLARunit] = ACTIONS(11710),
    [sym_system_tf_identifier] = ACTIONS(11710),
  },
  [5390] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5663),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11761),
    [anon_sym_DQUOTE] = ACTIONS(11555),
    [anon_sym_LT] = ACTIONS(11761),
    [anon_sym_GT] = ACTIONS(11761),
    [anon_sym_LPAREN] = ACTIONS(11555),
    [anon_sym_RPAREN] = ACTIONS(11555),
    [anon_sym_COMMA] = ACTIONS(11555),
    [anon_sym_BQUOTE] = ACTIONS(11555),
    [anon_sym_SLASH] = ACTIONS(11761),
    [anon_sym_COLON] = ACTIONS(11555),
    [anon_sym_type] = ACTIONS(11761),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11555),
    [anon_sym_const] = ACTIONS(11761),
    [anon_sym_local] = ACTIONS(11761),
    [anon_sym_super] = ACTIONS(11761),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11761),
    [anon_sym_string] = ACTIONS(11761),
    [anon_sym_byte] = ACTIONS(11761),
    [anon_sym_shortint] = ACTIONS(11761),
    [anon_sym_int] = ACTIONS(11761),
    [anon_sym_longint] = ACTIONS(11761),
    [anon_sym_integer] = ACTIONS(11761),
    [anon_sym_time] = ACTIONS(11761),
    [anon_sym_bit] = ACTIONS(11761),
    [anon_sym_logic] = ACTIONS(11761),
    [anon_sym_reg] = ACTIONS(11761),
    [anon_sym_shortreal] = ACTIONS(11761),
    [anon_sym_real] = ACTIONS(11761),
    [anon_sym_realtime] = ACTIONS(11761),
    [anon_sym_signed] = ACTIONS(11761),
    [anon_sym_unsigned] = ACTIONS(11761),
    [anon_sym_tagged] = ACTIONS(11761),
    [anon_sym_DOLLAR] = ACTIONS(11761),
    [anon_sym_PLUS] = ACTIONS(11761),
    [anon_sym_PLUS_PLUS] = ACTIONS(11555),
    [anon_sym_STAR_STAR] = ACTIONS(11555),
    [anon_sym_PERCENT] = ACTIONS(11555),
    [anon_sym_EQ_EQ] = ACTIONS(11761),
    [anon_sym_BANG_EQ] = ACTIONS(11761),
    [anon_sym_LT_EQ] = ACTIONS(11555),
    [anon_sym_GT_EQ] = ACTIONS(11555),
    [anon_sym_BANG] = ACTIONS(11761),
    [anon_sym_AMP_AMP] = ACTIONS(11761),
    [anon_sym_PIPE_PIPE] = ACTIONS(11555),
    [anon_sym_matches] = ACTIONS(11761),
    [anon_sym_DASH] = ACTIONS(11761),
    [anon_sym_DASH_GT] = ACTIONS(11555),
    [anon_sym_AMP_AMP_AMP] = ACTIONS(11555),
    [anon_sym_inside] = ACTIONS(11761),
    [anon_sym_SQUOTE_LBRACE] = ACTIONS(11555),
    [anon_sym_TILDE] = ACTIONS(11761),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(11555),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(11555),
    [anon_sym_GT_GT] = ACTIONS(11761),
    [anon_sym_LT_LT] = ACTIONS(11761),
    [anon_sym_std] = ACTIONS(11761),
    [anon_sym_randomize] = ACTIONS(11761),
    [anon_sym_null] = ACTIONS(11761),
    [anon_sym_QMARK] = ACTIONS(11555),
    [anon_sym_EQ_EQ_QMARK] = ACTIONS(11555),
    [anon_sym_BANG_EQ_QMARK] = ACTIONS(11555),
    [anon_sym_AMP] = ACTIONS(11761),
    [anon_sym_PIPE] = ACTIONS(11761),
    [anon_sym_CARET] = ACTIONS(11761),
    [anon_sym_CARET_TILDE] = ACTIONS(11555),
    [anon_sym_TILDE_CARET] = ACTIONS(11555),
    [anon_sym_GT_GT_GT] = ACTIONS(11555),
    [anon_sym_LT_LT_LT] = ACTIONS(11555),
    [anon_sym_LT_DASH_GT] = ACTIONS(11555),
    [anon_sym_this] = ACTIONS(11761),
    [anon_sym_TILDE_AMP] = ACTIONS(11555),
    [anon_sym_TILDE_PIPE] = ACTIONS(11555),
    [anon_sym_DASH_DASH] = ACTIONS(11555),
    [aux_sym_decimal_number_token1] = ACTIONS(11555),
    [aux_sym_decimal_number_token2] = ACTIONS(11555),
    [sym_binary_number] = ACTIONS(11555),
    [sym_octal_number] = ACTIONS(11555),
    [sym_hex_number] = ACTIONS(11555),
    [aux_sym_real_number_token1] = ACTIONS(11555),
    [sym_fixed_point_number] = ACTIONS(11761),
    [sym_unsigned_number] = ACTIONS(11761),
    [anon_sym_SQUOTE0] = ACTIONS(11555),
    [anon_sym_SQUOTE1] = ACTIONS(11555),
    [aux_sym_unbased_unsized_literal_token1] = ACTIONS(11555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_BSLASH] = ACTIONS(11555),
    [anon_sym_DOLLARroot] = ACTIONS(11761),
    [anon_sym_DOLLARunit] = ACTIONS(11761),
    [sym_system_tf_identifier] = ACTIONS(11761),
  },
  [5391] = {
    [sym_bit_select1] = STATE(5541),
    [sym_select1] = STATE(5659),
    [sym_constant_bit_select1] = STATE(18220),
    [aux_sym_bit_select1_repeat1] = STATE(5506),
    [aux_sym_select1_repeat1] = STATE(16939),
    [aux_sym_constant_bit_select1_repeat1] = STATE(12480),
    [sym_simple_identifier] = ACTIONS(11504),
    [anon_sym_DQUOTE] = ACTIONS(11314),
    [anon_sym_LT] = ACTIONS(11504),
    [anon_sym_GT] = ACTIONS(11504),
    [anon_sym_LPAREN] = ACTIONS(11314),
    [anon_sym_RPAREN] = ACTIONS(11314),
    [anon_sym_COMMA] = ACTIONS(11314),
    [anon_sym_BQUOTE] = ACTIONS(11314),
    [anon_sym_SLASH] = ACTIONS(11504),
    [anon_sym_COLON] = ACTIONS(11314),
    [anon_sym_type] = ACTIONS(11504),
    [anon_sym_DOT] = ACTIONS(11506),
    [anon_sym_LBRACE] = ACTIONS(11314),
    [anon_sym_const] = ACTIONS(11504),
    [anon_sym_local] = ACTIONS(11504),
    [anon_sym_super] = ACTIONS(11504),
    [anon_sym_LBRACK] = ACTIONS(11508),
    [anon_sym_STAR] = ACTIONS(11504),
    [anon_sym_string] = ACTIONS(11504),
    [anon_sym_byte] = ACTIONS(11504),
    [anon_sym_shortint] = ACTIONS(11504),
    [anon_sym_int] = ACTIONS(11504),
    [anon_sym_longint] = ACTIONS(11504),
    [anon_sym_integer] = ACTIONS(11504),
    [anon_sym_time] = ACTIONS(11504),
    [anon_sym_bit] = ACTIONS(11504),
    [anon_sym_logic] = ACTIONS(11504),
    [anon_sym_reg] = ACTIONS(11504),
    [anon_sym_shortreal] = ACTIONS(11504),
    [anon_sym_real] = ACTIONS(11504),
    [anon_sym_realtime] = ACTIONS(11504),
    [anon_sym_signed] = ACTIONS(11504),
    [anon_sym_unsigned] = ACTIONS(